(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  13417649,     464319]*)
(*NotebookOutlinePosition[  13422329,     464421]*)
(*  CellTagsIndexPosition[  13421100,     464394]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Phase Plane Analysis of Linear Differential Equations", "Title",
  CellTags->"mmtag:25:phase_plane_analysis"],

Cell["\<\
Description of behavior from coefficients of linear expansion about \
fixed point\
\>", "Subtitle",
  CellTags->"mmtag:25:fixed_point__linearization_about"],

Cell[TextData[{
  "Write a set of function that predict the behavior of the system  ",
  Cell[BoxData[
      \(TraditionalForm\`\(d \( y\& \[Rule] \)\)\/\(d\ t\)\)]],
  "= ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", GridBox[{
              {"a", "b"},
              {"c", "d"}
              }], ")"}], TraditionalForm]]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\& \[Rule] \)\)]],
  " for real matrices."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "Note: This is a first-order ODE with constant coefficients. Its solution \
will be a sum of two exponential functions with the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\[Lambda]t\)]],
  ". The characteristics of the system of two equations are determined by the \
eigenvalues and eigenvectors of the matrix of coefficients, as detailed by \
the analysis and examples presented below."
}], "Subsubsection"],

Cell["\<\
Note that the eigenvalues are either real or they are complex \
conjugates (i.e., the eigenvalues are the solutions to  the quadratic \
equation)\
\>", "Text"],

Cell["\<\
Here is a function to print out a warning if the eigenvalues are \
inconsistent with a real coefficient matrix:\
\>", "Text"],

Cell[BoxData[
    \(EigenConsistency[eval1_, \ eval2_]\  := \ 
      If[And[And[Im[eval1]\  \[NotEqual] 0, Im[eval2]\  \[NotEqual] \ 0], 
          Conjugate[eval1]\  \[NotEqual] \ eval2], 
        Print["\<Coefficients are not real\>"]]\)], "Input",
  CellTags->"mmtag:25:warning_function__example"],

Cell["\<\
Here is a function that prints out information about stability \
based on the eigenvalues:\
\>", "Text"],

Cell[BoxData[
    \(EigenStability[eval1_, \ eval2_]\  := \ 
      If[And[Re[eval1] < 0, Re[eval2]\  < 0], 
        Print["\<Stable and Attractive\>"], 
        If[Or[Re[eval1] > 0, Re[eval2] > 0], Print["\<Unstable\>"], 
          Print["\<Stable Orbits about Fixed Point\>"]]]\)], "Input",
  CellTags->"mmtag:25:fixed_point__function_to_determine_stability"],

Cell["\<\
Here is a function that prints out information about the type of \
fixed point:\
\>", "Text"],

Cell[BoxData[
    \(EigenTrajectory[eval1_, \ eval2_]\  := \ 
      If[Or[Im[eval1]\  \[NotEqual] \ 0\ , Im[eval2]\  \[NotEqual] \ 0], 
        Print["\<Circulation\>"], \[IndentingNewLine]If[\((s1 = 
                Sign[Re[eval1]])\)\  \[NotEqual] \ \((s2 = 
                Sign[Re[eval2]])\), Print["\<Saddle\>"], 
          Print["\<Node\>"]]]\)], "Input",
  CellTags->"mmtag:25:fixed_point__function_to_determine_type"],

Cell["Here is a function that collects our other functions", "Text"],

Cell[BoxData[
    \(EigenDescription[eval1_, \ eval2_]\  := \ 
      Module[{}, EigenConsistency[eval1, eval2]; 
        EigenStability[eval1, eval2]; 
        EigenTrajectory[eval1, eval2]]\)], "Input",
  CellTags->
  "mmtag:25:EigenDescription[]__example_of_function_for_analysis_of_system_of_\
ODEs"],

Cell[CellGroupData[{

Cell[BoxData[
    \(EigenDescription[\ \(-1\)\  + \[ImaginaryI], \(-1\)\  - \
\[ImaginaryI]]\)], "Input"],

Cell[BoxData[
    \("Stable and Attractive"\)], "Print"],

Cell[BoxData[
    \("Circulation"\)], "Print"]
}, Open  ]],

Cell[BoxData[
    \(EigenConsistency[1 + \ \[ImaginaryI], 1]\)], "Input"],

Cell["\<\
Here is a function that prints out information about the direction \
of the eigenvectors\
\>", "Text"],

Cell[BoxData[
    \(EigenDirector[eval_, \ {ex_, \ ey_}]\  := \ 
      Module[{theta\  = \ N[180*ArcTan[ex, ey]/\[Pi]]}, 
        If[eval > 0, \ 
          Print["\<Unstable (\[Lambda]=\>", 
            eval, "\<) direction is \[Theta] = \>", \ 
            theta]]; \[IndentingNewLine]If[eval < 0, \ 
          Print["\<Stable (\[Lambda]=\>", 
            eval, "\<) direction is \[Theta] = \>", \ theta]]]\)], "Input"],

Cell["\<\
Here is a function that uses the coefficients to collect and print \
the physical information about the fixed point\
\>", "Text"],

Cell[BoxData[
    \(LinearDescription[a_, \ b_\ , \ c_\ , \ d_]\  := \ 
      Module[{esys, eval1, eval2, evec1, evec2}, \[IndentingNewLine]esys = 
          Eigensystem[{{a, b}, {c, d}}]; eval1 = Chop[esys[\([1, 1]\)]]; 
        eval2 = Chop[esys[\([1, 2]\)]]; evec1\  = \ Chop[esys[\([2, 1]\)]]; 
        evec2 = Chop[esys[\([2, 2]\)]]; \[IndentingNewLine]EigenDescription[
          eval1, eval2]; \[IndentingNewLine]Print["\<Eigenvalues = \>", \ 
          eval1, \ "\< and \>", \ eval2]; \[IndentingNewLine]If[
          And[Im[eval1]\  \[Equal] \ 0, \ Im[eval1]\  \[Equal] \ 0], \ 
          EigenDirector[eval1, evec1]; \ EigenDirector[eval2, evec2]]; 
        esys]\)], "Input",
  CellTags->
  "mmtag:25:LinearDescription[]__example_of_function_for_analysis_of_system_\
of_ODEs"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LinearDescription[1,  .1, 1, \(-3\)]\)], "Input"],

Cell[BoxData[
    \("Unstable"\)], "Print"],

Cell[BoxData[
    \("Saddle"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Eigenvalues = \
"\[InvisibleSpace]\(-3.024845673131659`\)\[InvisibleSpace]" and "\
\[InvisibleSpace]1.0248456731316589`\),
      SequenceForm[ 
      "Eigenvalues = ", -3.0248456731316589, " and ", 1.0248456731316589],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Stable \
(\[Lambda]="\[InvisibleSpace]\(-3.024845673131659`\)\[InvisibleSpace]") \
direction is \[Theta] = "\[InvisibleSpace]91.42325939491276`\),
      SequenceForm[ 
      "Stable (\[Lambda]=", -3.0248456731316589, ") direction is \[Theta] = ",
         91.423259394912762],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Unstable \
(\[Lambda]="\[InvisibleSpace]1.0248456731316589`\[InvisibleSpace]") direction \
is \[Theta] = "\[InvisibleSpace]13.952991853913426`\),
      SequenceForm[ 
      "Unstable (\[Lambda]=", 1.0248456731316589, 
        ") direction is \[Theta] = ", 13.952991853913426],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{\(-3.024845673131659`\), 
        1.0248456731316589`}, {{\(-0.024838007970444692`\), 
          0.9996914890905396`}, {0.9704938837598415`, 
          0.2411257381217099`}}}\)], "Output"]
}, Open  ]],

Cell["Visualization of Trajectories near Fixed Points in the Plane", \
"Subtitle",
  CellTags->"mmtag:25:fixed_point_stability__visualization"],

Cell["\<\
Functions to find the solutions for input coefficients (first one \
for specified initial point; the second one for initial points picked \
randomly\
\>", "Text"],

Cell[BoxData[
    \(LinSol[a_, \ b_\ , \ c_\ , \ d_\ \ , \ xo_\ , \ 
        yo_]\  := \ \[IndentingNewLine]{x[t], p[t]} /. 
        Flatten[DSolve[{\(x'\)[t]\  \[Equal] \ 
                a\ x[t]\  + \ b\ p[t], \(p'\)[t]\  \[Equal] \ 
                c\ x[t]\  + \ d\ p[t], \ x[0]\  \[Equal] \ xo, \ 
              p[0]\  \[Equal] \ \ yo}, {x[t], p[t]}, t]]\)], "Input"],

Cell[BoxData[
    \(LinSol[a_, \ b_\ , \ c_\ , \ 
        d_\ ]\  := \ \[IndentingNewLine]{x[t], p[t]} /. 
        Flatten[DSolve[{\(x'\)[t]\  \[Equal] \ 
                a\ x[t]\  + \ b\ p[t], \(p'\)[t]\  \[Equal] \ 
                c\ x[t]\  + \ d\ p[t], \ 
              x[0]\  \[Equal] \ Random[Real, {\(-10\), 10}], \ 
              p[0]\  \[Equal] \ \ Random[Real, {\(-10\), 10}]}, {x[t], p[t]}, 
            t]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LinSol[3, 2, \(-3\), 2]\)], "Input"],

Cell[BoxData[
    \({4.284814892121187`\ \[ExponentialE]\^\(\(5\ t\)/2\)\ Cos[\(\@23\ \
t\)\/2] - 
        6.117391826839953`\ \[ExponentialE]\^\(\(5\ t\)/2\)\ Sin[\(\@23\ \
t\)\/2], \(-8.405698863933955`\)\ \[ExponentialE]\^\(\(5\ t\)/2\)\ Cos[\(\@23\
\ t\)\/2] - 
        3.6079646260886564`\ \[ExponentialE]\^\(\(5\ t\)/2\)\ Sin[\(\@23\ t\)\
\/2]}\)], "Output"]
}, Open  ]],

Cell["Example of a plot for a single directory", "Text"],

Cell[BoxData[
    \(CritPointPlot[a_, \ b_\ , \ c_\ , \ d_\ ]\  := 
      ParametricPlot[Evaluate[LinSol[a, b, c, d]], {t, 0, 20}, 
        PlotRange \[Rule] {{\(-15\), 15}, {\(-15\), 15}}]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CritPointPlot[\(-1\), \(- .2\), 1, \(-2\)]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0333333 0.309017 0.0206011 [
[0 .29652 -18.4688 -20 ]
[0 .29652 18.4688 0 ]
[.16667 .29652 -18.4688 -20 ]
[.16667 .29652 18.4688 0 ]
[.33333 .29652 -13.4688 -20 ]
[.33333 .29652 13.4688 0 ]
[.66667 .29652 -7 -20 ]
[.66667 .29652 7 0 ]
[.83333 .29652 -12 -20 ]
[.83333 .29652 12 0 ]
[1 .29652 -12 -20 ]
[1 .29652 12 0 ]
[.4875 0 -36.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .10301 -36.9375 -10 ]
[.4875 .10301 0 10 ]
[.4875 .20601 -26.9375 -10 ]
[.4875 .20601 0 10 ]
[.4875 .41202 -14 -10 ]
[.4875 .41202 0 10 ]
[.4875 .51503 -24 -10 ]
[.4875 .51503 0 10 ]
[.4875 .61803 -24 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
gsave
0 .29652 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.16667 .30902 m
.16667 .31527 L
s
gsave
.16667 .29652 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.33333 .30902 m
.33333 .31527 L
s
gsave
.33333 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.66667 .30902 m
.66667 .31527 L
s
gsave
.66667 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.83333 .30902 m
.83333 .31527 L
s
gsave
.83333 .29652 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 .30902 m
1 .31527 L
s
gsave
1 .29652 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.03333 .30902 m
.03333 .31277 L
s
.06667 .30902 m
.06667 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.13333 .30902 m
.13333 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.23333 .30902 m
.23333 .31277 L
s
.26667 .30902 m
.26667 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.43333 .30902 m
.43333 .31277 L
s
.46667 .30902 m
.46667 .31277 L
s
.53333 .30902 m
.53333 .31277 L
s
.56667 .30902 m
.56667 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.73333 .30902 m
.73333 .31277 L
s
.76667 .30902 m
.76667 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.86667 .30902 m
.86667 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.93333 .30902 m
.93333 .31277 L
s
.96667 .30902 m
.96667 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
gsave
.4875 .10301 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 .20601 m
.50625 .20601 L
s
gsave
.4875 .20601 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .41202 m
.50625 .41202 L
s
gsave
.4875 .41202 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .51503 m
.50625 .51503 L
s
gsave
.4875 .51503 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.2938 .39255 m
.31087 .36693 L
.32596 .34798 L
.34281 .33048 L
.35708 .31839 L
.37008 .30936 L
.38311 .30211 L
.39569 .29672 L
.4065 .29329 L
.41177 .292 L
.41648 .29108 L
.42138 .29032 L
.42401 .29 L
.42637 .28977 L
.42876 .28959 L
.43009 .28951 L
.43128 .28945 L
.4324 .2894 L
.43344 .28937 L
.43452 .28935 L
.43567 .28934 L
.43663 .28934 L
.43767 .28934 L
.43873 .28936 L
.43972 .28939 L
.44144 .28945 L
.44323 .28955 L
.44499 .28967 L
.44658 .2898 L
.45002 .29017 L
.45575 .29101 L
.46042 .29192 L
.46488 .29297 L
.47816 .29726 L
.48614 .30073 L
.49481 .30546 L
.49821 .30768 L
.49937 .30852 L
.49977 .30883 L
.49992 .30895 L
.49997 .30899 L
.49999 .30901 L
.5 .30901 L
.5 .30902 L
.5 .30902 L
.5 .30902 L
.5 .30902 L
.5 .30902 L
.5 .30902 L
.5 .30902 L
Mistroke
.5 .30902 L
.5 .30902 L
.5 .30902 L
.5 .30902 L
.5 .30902 L
.5 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX:oookJP?o001o1OoonfX5o`00
Oooooo]Z:ooonfX00?oooo]Z2_oonfX3o`00O`Cooo]Z1ol007oooookJR[ooo]Z003ooookJP[ooo]Z
0ol007l3oookJPCo001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`000?oooo]Z7?oonfX00?[ooo]Z
2_l007l5oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXLoookJP00n_oo
nfX:o`00O`Gooo]Z0ol007l9oookJP?o001o2?oonfX7o`000?oooo]Z6_oonfX00?oooo]Z2_oonfX3
o`00O`Wooo]Z0ol007l8oookJPGo0000oooonfXLoookJP00oooonfX:oookJP?o001o1?oonfX2o`00
O`;ooo]Z1?l007l8oookJPGo0000oooonfXLoookJP00oooonfX:oookJP?o001o1?oonfX7o`00O`Wo
oo]Z1Ol0003ooookJQcooo]Z003ooookJP[ooo]Z0ol007l4oookJPKo001o2_oonfX5o`000?oooo]Z
7?oonfX00?oooo]Z1ooonfX6o`00O`Cooo]Z0_l007l>oookJPGo0000oooonfXLoookJP00oooonfX7
oookJPKo001o1?oonfX2o`00O`kooo]Z1Ol0003ooookJQcooo]Z003ooookJPWooo]Z1?l007l5oook
JPOo001o2?oonfX5o`000?oooo]Z7?oonfX00?oooo]Z2_oonfX3o`00O`Gooo]Z1ol007l8oookJPGo
0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooo
nfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoook
JP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooo
nfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoook
JPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000
oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXL
oookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00
oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQ
oookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo
0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooo
nfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoook
JP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooo
nfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoook
JPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000
oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXL
oookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00
oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQ
oookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo
0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooo
nfXLoookJP00oooonfX:oookJP?o001o1OoonfX5o`00O`[ooo]Z1Ol0003ooookJQcooo]Z003ooook
JP[ooo]Z0ol007l4oookJPOo001o2OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z2_oonfX3o`00O`Co
oo]Z0ol007l01?oonf[o001oo`00Ool007l9oookJPGo0000oooonfXLoookJP00n_oonfX:o`00O`Go
oo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJQcooo]Z003joookJP[o001o
1OoonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o2?oonfX7o`000?oooo]Z6_oonfX00?oooo]Z2_oo
nfX3o`00O`?ooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7?oonfX00?oooo]Z2_oonfX3
o`00O`?ooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7?oonfX00?oooo]Z2_oonfX3o`00
O`?ooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7?oonfX00?oooo]Z2_oonfX3o`00O`?o
oo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7?oonfX00?oooo]Z1ooonfX6o`00O`?ooo]Z
0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7?oonfX00?oooo]Z1ooonfX6o`00O`Cooo]Z0ol0
07l01?oonf[o001oo`00Ool007l9oookJPGo0000oooonfXLoookJP00oooonfX9oookJPCo001o1?oo
nfX7o`00O`Wooo]Z1Ol0003ooookJQcooo]Z003ooookJP[ooo]Z0ol007l5oookJPGo001o2_oonfX5
o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oo
oo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oo
nfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oo
oo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z8Ooo
nfX5o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`00
0?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z
7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX0
0?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z
8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5
o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oo
oo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oo
nfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oo
oo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z8Ooo
nfX5o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`00
0?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z
7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX0
0?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z
8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5
o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oo
oo]Z7?oonfX00?oooo]Z8OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z4_oonfX5o`00O`[ooo]Z1Ol0
003ooookJQcooo]Z003ooookJQ7ooo]Z1ol007l9oookJPGo0000oooonfXLoookJP00oooonfX@oook
JPCo001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z1OoonfX:o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXLoookJP00oooonfX5oook
JP[o001o1ooonfX3o`00O`Sooo]Z1ol0003ooookJQ[ooo]Z003ooookJQKooo]Z0ol007l8oookJPGo
0000oooonfXLoookJP00oooonfXAoookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0003ooookJQcooo]Z
003ooookJQ7ooo]Z1ol007l9oookJPGo0000oooonfXLoookJP00oooonfXAoookJPKo001o2_oonfX5
o`000?oooo]Z7?oonfX00?oooo]Z4OoonfX2o`00O`kooo]Z1Ol0003ooookJQcooo]Z003ooookJQ7o
oo]Z0_l007l>oookJPGo0000oooonfXLoookJP00oooonfXBoookJPOo001o2?oonfX5o`000?oooo]Z
7?oonfX00?oooo]Z4_oonfX7o`00O`Sooo]Z1Ol0003ooookJQcooo]Z003ooookJR7ooo]Z1Ol0003o
oookJQcooo]Z003ooookJR7ooo]Z1Ol0003ooookJQcooo]Z003ooookJR7ooo]Z1Ol0003ooookJQco
oo]Z003ooookJR7ooo]Z1Ol0003ooookJQcooo]Z003ooookJR7ooo]Z1Ol0003ooookJQcooo]Z003o
oookJR7ooo]Z1Ol0003ooookJQcooo]Z003ooookJR7ooo]Z1Ol0003ooookJQcooo]Z003ooookJR7o
oo]Z1Ol0003ooookJQcooo]Z003ooookJR7ooo]Z1Ol0003ooookJQcooo]Z003ooookJR7ooo]Z1Ol0
003ooookJQcooo]Z003ooookJR7ooo]Z1Ol0003ooookJQcooo]Z003ooookJR7ooo]Z1Ol0003ooook
JQcooo]Z003ooookJR7ooo]Z1Ol0003ooookJQcooo]Z003ooookJR7ooo]Z1Ol0003ooookJQcooo]Z
003ooookJR7ooo]Z1Ol0003ooookJQcooo]Z003ooookJR7ooo]Z1Ol0003ooookJQcooo]Z003ooook
JR7ooo]Z1Ol0003ooookJQcooo]Z003ooookJR7ooo]Z1Ol0003ooookJQcooo]Z003ooookJR7ooo]Z
1Ol0003ooookJQcooo]Z003ooookJR7ooo]Z1Ol0003ooookJQcooo]Z003ooookJR7ooo]Z1Ol0003o
oookJQcooo]Z003ooookJR7ooo]Z1Ol0003ooookJQcooo]Z003ooookJR7ooo]Z1Ol0003ooookJQco
oo]Z003ooookJR7ooo]Z1Ol0003ooookJQcooo]Z003ooookJR7ooo]Z1Ol0003ooookJQcooo]Z003o
oookJR7ooo]Z1Ol0003ooookJQcooo]Z000DoookJP?o001o1OoonfX5o`00Odgooo]Z0ol007l5oook
JPGo001oD?oonfX5o`00Oe3ooo]Z1Ol0001EoookJPGo001oD_oonfX3o`00O`Gooo]Z1Ol007m=oook
JP?o001o1OoonfX5o`00O`Sooo]Z000DoookJP?o001o1?oonfX7o`00Odcooo]Z0ol007l4oookJPOo
001oC_oonfX7o`00Odoooo]Z1Ol0001DoookJPOo001oDOoonfX3o`00O`Cooo]Z1ol007m<oookJP?o
001o1?oonfX7o`00O`Oooo]Z000DoookJP?o001o0ooonfX4o`00O`04oookJ_l007oo001oo`00Odco
oo]Z0ol007l4oookJP?o001o00Cooo]Zo`00Ool007oo001oCOoonfX4o`00O`04oookJ_l007oo001o
o`00Odoooo]Z1Ol0001CoookJPCo001o00Cooo]Zo`00Ool007oo001oDOoonfX3o`00O`Cooo]Z0ol0
07l01?oonf[o001oo`00Ool007m<oookJP?o001o0ooonfX4o`00O`04oookJ_l007oo001oo`00O`Oo
oo]Z0004oookJP[o001o1_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o>ooonfX:o`00O`Kooo]Z
0ol007l3oookJP?o001o0ooonfX3o`00Od3ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00Odkooo]Z
1Ol0001CoookJP?o001o0ooonfX3o`00Oe3ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00Od_ooo]Z
0ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z0004oookJP[o001o1_oonfX3o`00O`Wooo]Z0ol0
07lkoookJP[o001o1_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o@?oonfX:o`00O`Sooo]Z0ol0
07m>oookJPGo0000FOoonfX3o`00Oe3ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00Od_ooo]Z0ol0
07l9oookJP?o001o1_oonfX001Cooo]Z0ol007l9oookJP?o001oBooonfX3o`00O`?ooo]Z0ol007l3
oookJP?o001oD_oonfX3o`00Odkooo]Z1Ol0001IoookJP?o001oD?oonfX3o`00O`?ooo]Z0ol007l3
oookJP?o001oBooonfX3o`00O`Wooo]Z0ol007l6oookJP005?oonfX3o`00O`Cooo]Z0_l007l2oook
JPCo001oBooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001oCOoonfX2o`00O`;ooo]Z1?l007m>oook
JPGo0000E?oonfX2o`00O`;ooo]Z1?l007m@oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007m;oook
JP?o001o1?oonfX2o`00O`;ooo]Z1?l007l6oookJP005?oonfX3o`00O`Cooo]Z1ol007m<oookJP?o
001o0ooonfX3o`00O`?ooo]Z0ol007m=oookJPOo001oCooonfX5o`0005Cooo]Z1ol007mAoookJP?o
001o0ooonfX3o`00O`?ooo]Z0ol007m;oookJP?o001o1?oonfX7o`00O`Oooo]Z000DoookJP?o001o
1?oonfX6o`00Odgooo]Z0ol007l3oookJP?o001o0ooonfX3o`00Odgooo]Z1_l007m@oookJPGo0000
E?oonfX6o`00Oe;ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00Od_ooo]Z0ol007l4oookJPKo001o
2?oonfX0017ooo]Z1_l007l4oookJP;o001oC_oonfX6o`00O`?ooo]Z0ol007l3oookJP?o001oCOoo
nfX2o`00Obkooo]Z2ol0000KoookJPGo0000E?oonfX2o`00Oe?ooo]Z1_l007l3oookJP?o001o0ooo
nfX3o`00OdSooo]Z1_l007l4oookJP;o001o3?oonfX0017ooo]Z1_l007l4oookJP;o001oC_oonfX6
o`00O`Cooo]Z0ol007l01?oonf[o001oo`00Ool007m>oookJP;o001o9_oonfXLo`0001;ooo]Z1Ol0
001DoookJP;o001oDooonfX6o`00O`Cooo]Z0ol007l01?oonf[o001oo`00Ool007m9oookJPKo001o
1?oonfX2o`00O`cooo]Z000CoookJPCo001o1OoonfX7o`00Od[ooo]Z1?l007l4oookJPOo001oCooo
nfX7o`00Oagooo]Z8ol0000>oookJPGo0000EOoonfX7o`00Odoooo]Z1?l007l4oookJPOo001oBooo
nfX4o`00O`Gooo]Z1ol007l6oookJP005?oonfX3o`00O`Gooo]Z1ol007m;oookJP?o001o1OoonfX5
o`00Oe3ooo]Z1ol007lIoookJR[o00002ooonfX5o`0005Gooo]Z1ol007m@oookJP?o001o1OoonfX5
o`00Odgooo]Z0ol007l5oookJPOo001o1_oonfX00>Oooo]Z5ol00004oookJQGo00002OoonfX5o`00
0?oooo]Z7?oonfX00>Cooo]Z4Ol0000FoookJPko00001ooonfX5o`000?oooo]Z7?oonfX00>;ooo]Z
4?l0000MoookJPgo00001?oonfX5o`000?oooo]Z7?oonfX00>3ooo]Z3_l0000ToookJPco00000_oo
nfX5o`000?oooo]Z7?oonfX00=kooo]Z3?l0000ZoookJQ7o0000oooonfXLoookJP00gOoonfX:o`00
02oooo]Z3ol0003ooookJQcooo]Z000AoookJ_oo0000ool0000Uo`0000cooo]Z000AoookJ_oo0000
ool0000Uo`0000cooo]Z000AoookJ_oo0000ool0000Uo`0000cooo]Z000AoookJ_oo0000ool0000U
o`0000cooo]Z000AoookJ_oo0000ool0000Uo`0000cooo]Z000CoookJP03o`000?oonf[ooo]Z05So
oo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP09oookJPSo0000A?oonfX5o`0005So
oo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z00co
oo]Z003BoookJPWo0000AOoonfX5o`000?oooo]Z7?oonfX00=7ooo]Z2?l00017oookJPGo0000oooo
nfXLoookJP00d?oonfX8o`0004Sooo]Z1Ol0003ooookJQcooo]Z003?oookJPSo0000BOoonfX5o`00
0?oooo]Z7?oonfX00<kooo]Z1ol0001;oookJPGo0000oooonfXLoookJP00cOoonfX7o`0004cooo]Z
1Ol0003ooookJQcooo]Z003<oookJPOo0000COoonfX5o`000?oooo]Z7?oonfX00<_ooo]Z1ol0001>
oookJPGo0000oooonfXLoookJP00b_oonfX7o`0004oooo]Z1Ol0003ooookJQcooo]Z0039oookJPOo
0000D?oonfX5o`000?oooo]Z7?oonfX00<Sooo]Z1ol0001AoookJPGo0000oooonfXLoookJP00aooo
nfX7o`0005;ooo]Z1Ol0003ooookJQcooo]Z0036oookJPOo0000DooonfX5o`000?oooo]Z7?oonfX0
0<Gooo]Z1ol0001DoookJPGo0000oooonfXLoookJP00a?oonfX7o`0005Gooo]Z1Ol0003ooookJQco
oo]Z0033oookJPOo0000E_oonfX5o`000?oooo]Z7?oonfX00<;ooo]Z1ol0001GoookJPGo0000oooo
nfXLoookJP00`_oonfX6o`0005Sooo]Z1Ol0003ooookJQcooo]Z0031oookJPKo0000FOoonfX5o`00
0?oooo]Z7?oonfX00<3ooo]Z1_l0001JoookJPGo0000oooonfXLoookJP00_ooonfX7o`0005[ooo]Z
1Ol0003ooookJQcooo]Z002noookJPOo0000FooonfX5o`000?oooo]Z7?oonfX00;kooo]Z1_l0001L
oookJPGo0000oooonfXLoookJP00_OoonfX6o`0005gooo]Z1Ol0003ooookJQcooo]Z002loookJPKo
0000G_oonfX5o`000?oooo]Z7?oonfX00;_ooo]Z1ol0001NoookJPGo0000oooonfXLoookJP00^_oo
nfX7o`0005oooo]Z1Ol0003ooookJQcooo]Z002joookJPKo0000H?oonfX5o`000?oooo]Z7?oonfX0
0;Wooo]Z1_l0001QoookJPGo0000oooonfXLoookJP00^?oonfX6o`0006;ooo]Z1Ol0003ooookJQco
oo]Z002goookJPOo0000H_oonfX5o`000?oooo]Z7?oonfX00;Oooo]Z1_l0001SoookJPGo0000oooo
nfXLoookJP00]_oonfX6o`0006Cooo]Z1Ol0003ooookJQcooo]Z002eoookJPKo0000IOoonfX5o`00
0?oooo]Z7?oonfX00;Gooo]Z1_l0001UoookJPGo0000oooonfXLoookJP00]?oonfX6o`0006Kooo]Z
1Ol0003ooookJQcooo]Z002coookJPKo0000IooonfX5o`000?oooo]Z7?oonfX00;;ooo]Z1ol0001W
oookJPGo0000oooonfXLoookJP00/_oonfX6o`0006Sooo]Z1Ol0003ooookJQcooo]Z002aoookJPKo
0000JOoonfX5o`000?oooo]Z7?oonfX00;3ooo]Z1_l0001ZoookJPGo0000oooonfXLoookJP00/?oo
nfX6o`0006[ooo]Z1Ol0003ooookJQcooo]Z002`oookJPGo0000JooonfX5o`000?oooo]Z7?oonfX0
0;3ooo]Z1?l0001/oookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00
oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQ
oookJPGo0000oooonfXLoookJP00oooonfXBoookJPGo001o2_oonfX5o`000?oooo]Z7?oonfX00?oo
oo]Z4OoonfX7o`00O`Wooo]Z1Ol0003ooookJQcooo]Z003ooookJQ3ooo]Z1?l007l01?oonf[o001o
o`00Ool007l9oookJPGo0000oooonfXLoookJP00oooonfX@oookJP?o001o0ooonfX3o`00O`Sooo]Z
1Ol0003ooookJQcooo]Z003ooookJQKooo]Z0ol007l8oookJPOo0000oooonfXJoookJP00oooonfXF
oookJP?o001o2?oonfX5o`000?oooo]Z7?oonfX00?oooo]Z4OoonfX2o`00O`;ooo]Z1?l007l8oook
JPGo0000oooonfXLoookJP00oooonfXAoookJPOo001o2OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z
4OoonfX6o`00O`[ooo]Z1Ol0003ooookJQcooo]Z003ooookJQ7ooo]Z0_l007l>oookJPGo0000oooo
nfXLoookJP00oooonfXAoookJP;o001o3_oonfX5o`000?oooo]Z7?oonfX00?oooo]Z4_oonfX7o`00
O`Sooo]Z1Ol0003ooookJQcooo]Z003ooookJQ;ooo]Z1ol007l8oookJPGo0000oooonfXLoookJP00
oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQ
oookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo
0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooo
nfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoook
JP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooo
nfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoook
JPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000
oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXL
oookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00
oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQ
oookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo
0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooo
nfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoook
JP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooo
nfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoook
JPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000
oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXL
oookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00
oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQ
oookJPGo0000oooonfXLoookJP00oooonfX:oookJP?o001o1OoonfX5o`00O`[ooo]Z1Ol0003ooook
JQcooo]Z003ooookJP[ooo]Z0ol007l4oookJPOo001o2OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z
2_oonfX3o`00O`Cooo]Z0ol007l01?oonf[o001oo`00Ool007l9oookJPGo0000oooonfXLoookJP00
oooonfX:oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXLoookJP00oooo
nfX:oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l8oookJPOo0000oooonfXJoookJP00oooonfX:
oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXLoookJP00oooonfX:oook
JP?o001o0ooonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXLoookJP00oooonfX:oookJP?o
001o0ooonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXLoookJP00oooonfX:oookJP?o001o
0ooonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXLoookJP00oooonfX7oookJPKo001o0ooo
nfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXLoookJP00oooonfX7oookJPKo001o1?oonfX3
o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQcooo]Z003ooookJPWooo]Z1?l007l4
oookJPOo001o2OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z2_oonfX3o`00O`Gooo]Z1Ol007l:oook
JPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000
oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXL
oookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00
oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQ
oookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo
0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooo
nfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoook
JP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooo
nfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoook
JPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000
oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXL
oookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00
oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQ
oookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo
0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooo
nfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoook
JP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooo
nfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoook
JPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000oooonfXLoookJP00oooonfXQoookJPGo0000
oooonfXLoookJP00oooonfX:oookJP?o001o1OoonfX5o`00O`[ooo]Z1Ol0003ooookJQcooo]Z003o
oookJP[ooo]Z0ol007l4oookJPOo001o2OoonfX5o`000?oooo]Z7?oonfX00?oooo]Z2_oonfX3o`00
O`?ooo]Z1?l007l01?oonf[o001oo`00Ool007l9oookJPGo0000oooonfXLoookJP00oooonfX:oook
JP?o001o0ooonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXLoookJP00oooonfX:oookJP?o
001o2OoonfX3o`00O`Sooo]Z1ol0003ooookJQ[ooo]Z003ooookJP[ooo]Z0ol007l9oookJP?o001o
2?oonfX5o`000?oooo]Z7?oonfX00?oooo]Z2_oonfX3o`00O`Cooo]Z0_l007l2oookJPCo001o2?oo
nfX5o`000?oooo]Z7?oonfX00?oooo]Z2_oonfX3o`00O`Cooo]Z1ol007oooookJR[ooo]Z003ooook
JP[ooo]Z0ol007l4oookJPKo001ooooonfX[oookJP00oooonfX7oookJPKo001o1?oonfX2o`00Oooo
oo]Z;ooonfX00?oooo]Z1ooonfX6o`00O`Cooo]Z0_l007oooookJRoooo]Z003ooookJPWooo]Z1?l0
07l5oookJPOo001ooooonfXYoookJP00oooonfX:oookJP?o001o1OoonfX7o`00Oooooo]Z:OoonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-16.0942, -15.8959, \
0.0553569, 0.0895694}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
This is not terribly informative.  Construct a function that takes \
input and plots many paths with arrows that describe the trajectory.  Print \
out physical interpretations as well.  Supply an argument with  a default \
definition that indicates the number of trajectories to plot.\
\>", "Text"],

Cell[BoxData[
    \(<< Graphics`Arrow`\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(CritPointPlotPointsMany[a_, \ b_\ , \ c_\ , \ 
        d_\ , \ \ howmany_:  100]\  := 
      Module[{esys, eval1, eval2, funcs\ , data, lendata, gstack, lp, rstack, 
          lstack, magrange, rstackmag, lstackmag}, \[IndentingNewLine]esys = 
          LinearDescription[a, b, c, d]; Print[esys]; 
        eval1 = \ esys[\([1, 1]\)]; \ 
        eval2 = \ esys[\([1, 2]\)]; \[IndentingNewLine]funcs = 
          Table[Chop[LinSol[a, b, c, d]], {i, howmany}]; \ lstack\  = {}; 
        rstack = {}; 
        For[imany = 1, imany\  \[LessEqual] \ howmany, \(imany++\), 
          data = Chop[
              Table[Evaluate[funcs[\([imany]\)] /. t \[Rule] itime], {itime, 
                  0, 20,  .1}]]; lendata\  = \ Length[data]; 
          gstack = {Hue[0], 
              Arrow[data[\([1]\)], data[\([2]\)], 
                HeadScaling \[Rule] Absolute]}; \[IndentingNewLine]For[
            iend\  = \ 4, \ iend\  \[LessEqual] \ \ lendata/2, 
            iend\  += \ 8, \ AppendTo[gstack, Hue[iend*0.66*2/lendata]]; 
            AppendTo[gstack, 
              Arrow[data[\([iend - 1]\)], data[\([iend]\)], 
                HeadScaling \[Rule] Absolute]]]; 
          lp = ListPlot[data, PlotJoined \[Rule] True, AspectRatio \[Rule] 1, 
              PlotRange \[Rule] {{\(-15\), 15}, {\(-15\), 15}}, 
              PlotStyle \[Rule] Hue[Random[]], 
              DisplayFunction \[Rule] Identity]; 
          lstack = Show[lp, Graphics[gstack], lstack]; 
          rstack\  = \ Show[lp, rstack]]; \[IndentingNewLine]If[
          Or[Re[eval1] > 0, Re[eval2] > \ 0], 
          magrange = {{\(-60\), 60}, {\(-60\), 60}}, 
          magrange = \ {{\(-1\), 1}, {\(-1\), 
                1}}]; \[IndentingNewLine]rstackmag\  = \ 
          Show[rstack, 
            PlotRange \[Rule] \ 
              magrange]; \[IndentingNewLine]lstackmag\  = \ \ Show[lstack, 
            PlotRange \[Rule] \ magrange]; \[IndentingNewLine]Show[
          GraphicsArray[{{lstack, rstack}, {lstackmag, rstackmag}}], 
          ImageSize \[Rule] 1000, 
          DisplayFunction \[Rule] $DisplayFunction]]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\)], "Input",
  CellTags->"mmtag:25:fixed_point__visualization_of_trajectories_near"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(rstack\\)\\\" is similar to existing symbol \
\\\"\\!\\(gstack\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"spell"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(lstack\\)\\\" is similar to existing symbols \
\\!\\({gstack, rstack}\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(lstackmag\\)\\\" is similar to existing \
symbol \\\"\\!\\(rstackmag\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"]
}, Open  ]],

Cell["\<\
In this first example, the eigenvalues are real and negative, and \
the system of equations has a stable, attractive node. The eigenvectors are \
real and correspond to directions along which the system will evolve along a \
straight trajectory.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CritPointPlotPointsMany[\(-1\), 0.25, 0.75, \(-1\)]\)], "Input",
  CellTags->"mmtag:25:fixed_point__stable_attractive_node_visualization"],

Cell[BoxData[
    \("Stable and Attractive"\)], "Print"],

Cell[BoxData[
    \("Node"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Eigenvalues = \
"\[InvisibleSpace]\(-1.4330127018922194`\)\[InvisibleSpace]" and "\
\[InvisibleSpace]\(-0.5669872981077807`\)\),
      SequenceForm[ 
      "Eigenvalues = ", -1.4330127018922194, " and ", -0.5669872981077807],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Stable \
(\[Lambda]="\[InvisibleSpace]\(-1.4330127018922194`\)\[InvisibleSpace]") \
direction is \[Theta] = "\[InvisibleSpace]120.00000000000001`\),
      SequenceForm[ 
      "Stable (\[Lambda]=", -1.4330127018922194, ") direction is \[Theta] = ",
         120.00000000000001],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Stable \
(\[Lambda]="\[InvisibleSpace]\(-0.5669872981077807`\)\[InvisibleSpace]") \
direction is \[Theta] = "\[InvisibleSpace]60.00000000000001`\),
      SequenceForm[ 
      "Stable (\[Lambda]=", -0.5669872981077807, ") direction is \[Theta] = ",
         60.000000000000007],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{\(-1.4330127018922194`\), \(-0.5669872981077807`\)}, {{\(-0.5`\), 
          0.8660254037844385`}, {0.5`, 0.8660254037844387`}}}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 1000 1000 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto fill
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto
-15. 3.75 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -13.4688 -20 ]
[0 .4875 13.4688 0 ]
[.125 .4875 -25.9688 -20 ]
[.125 .4875 25.9688 0 ]
[.25 .4875 -20.9688 -20 ]
[.25 .4875 20.9688 0 ]
[.375 .4875 -25.9688 -20 ]
[.375 .4875 25.9688 0 ]
[.625 .4875 -19.5 -20 ]
[.625 .4875 19.5 0 ]
[.75 .4875 -14.5 -20 ]
[.75 .4875 14.5 0 ]
[.875 .4875 -19.5 -20 ]
[.875 .4875 19.5 0 ]
[1 .4875 -7 -20 ]
[1 .4875 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .125 -51.9375 -10 ]
[.4875 .125 0 10 ]
[.4875 .25 -41.9375 -10 ]
[.4875 .25 0 10 ]
[.4875 .375 -51.9375 -10 ]
[.4875 .375 0 10 ]
[.4875 .625 -39 -10 ]
[.4875 .625 0 10 ]
[.4875 .75 -29 -10 ]
[.4875 .75 0 10 ]
[.4875 .875 -39 -10 ]
[.4875 .875 0 10 ]
[.4875 1 -14 -10 ]
[.4875 1 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 .5 m
.125 .50625 L
s
gsave
.125 .4875 -86.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.25 .5 m
.25 .50625 L
s
gsave
.25 .4875 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.375 .5 m
.375 .50625 L
s
gsave
.375 .4875 -86.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.625 .5 m
.625 .50625 L
s
gsave
.625 .4875 -80.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.75 .5 m
.75 .50625 L
s
gsave
.75 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.875 .5 m
.875 .50625 L
s
gsave
.875 .4875 -80.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .125 m
.50625 .125 L
s
gsave
.4875 .125 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.5 .25 m
.50625 .25 L
s
gsave
.4875 .25 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .375 m
.50625 .375 L
s
gsave
.4875 .375 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.5 .625 m
.50625 .625 L
s
gsave
.4875 .625 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.5 .75 m
.50625 .75 L
s
gsave
.4875 .75 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .875 m
.50625 .875 L
s
gsave
.4875 .875 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.01 w
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 .147 1 r
.5 Mabswid
.11214 0 m
.12931 .01384 L
.15327 .03453 L
.17544 .05489 L
.19598 .07484 L
.21503 .0943 L
.23273 .11322 L
.24918 .13155 L
.2645 .14927 L
.27877 .16637 L
.29209 .18282 L
.30452 .19862 L
.31614 .21377 L
.327 .22829 L
.33717 .24217 L
.34669 .25543 L
.35562 .26809 L
.36399 .28016 L
.37184 .29166 L
.37921 .30261 L
.38614 .31303 L
.39265 .32293 L
.39877 .33235 L
.40452 .34129 L
.40993 .34977 L
.41503 .35783 L
.41983 .36547 L
.42434 .37271 L
.4286 .37958 L
.43261 .38609 L
.43639 .39226 L
.43995 .3981 L
.44331 .40364 L
.44647 .40888 L
.44946 .41384 L
.45228 .41853 L
.45493 .42298 L
.45744 .42718 L
.45981 .43116 L
.46204 .43492 L
.46415 .43849 L
.46614 .44185 L
.46802 .44504 L
.46979 .44805 L
.47146 .4509 L
.47304 .45359 L
.47454 .45614 L
.47594 .45855 L
.47728 .46082 L
.47853 .46298 L
Mistroke
.47972 .46501 L
.48084 .46693 L
.4819 .46875 L
.4829 .47047 L
.48384 .47209 L
.48474 .47363 L
.48558 .47508 L
.48638 .47645 L
.48713 .47775 L
.48784 .47897 L
.48851 .48013 L
.48914 .48122 L
.48974 .48226 L
.49031 .48324 L
.49084 .48416 L
.49135 .48503 L
.49183 .48586 L
.49228 .48663 L
.4927 .48737 L
.4931 .48807 L
.49349 .48872 L
.49384 .48935 L
.49418 .48993 L
.4945 .49049 L
.49481 .49101 L
.49509 .49151 L
.49536 .49197 L
.49562 .49242 L
.49586 .49283 L
.49609 .49323 L
.49631 .4936 L
.49651 .49396 L
.4967 .49429 L
.49688 .4946 L
.49706 .4949 L
.49722 .49518 L
.49737 .49545 L
.49752 .4957 L
.49765 .49594 L
.49778 .49616 L
.4979 .49637 L
.49802 .49657 L
.49813 .49676 L
.49823 .49694 L
.49833 .49711 L
.49842 .49727 L
.49851 .49742 L
.49859 .49756 L
.49867 .49769 L
.49874 .49782 L
Mistroke
.49881 .49794 L
.49888 .49805 L
.49894 .49816 L
.499 .49826 L
.49905 .49836 L
.4991 .49845 L
.49915 .49853 L
.4992 .49862 L
.49924 .49869 L
.49929 .49876 L
.49933 .49883 L
.49936 .4989 L
.4994 .49896 L
.49943 .49901 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49921 L
.49957 .49926 L
.4996 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.4997 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.4998 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
Mistroke
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
Mfstroke
1 0 0 r
% Start of user PostScript
-9.1146369 4.1049912 -8.1621098 3.0990942 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-7.3221809 2.2527289 -6.5806208 1.5432056 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-3.2829375 -0.94020005 -2.9945848 -1.0743848 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.6507065 -1.3509404 -1.5255906 -1.3355842 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-0.91050567 -1.0977836 -0.84947274 -1.0560558 MAarrowhead1
% End of user PostScript
.581 1 0 r
.23273 .11322 m
.24918 .13155 L
s
% Start of user PostScript
-0.53454814 -0.77356793 -0.50163698 -0.73689679 MAarrowhead1
% End of user PostScript
.266 1 0 r
.33717 .24217 m
.34669 .25543 L
s
% Start of user PostScript
-0.32565994 -0.51566343 -0.30661403 -0.48913617 MAarrowhead1
% End of user PostScript
0 1 .049 r
.39877 .33235 m
.40452 .34129 L
s
% Start of user PostScript
-0.20246919 -0.33530782 -0.19096082 -0.31742796 MAarrowhead1
% End of user PostScript
0 1 .364 r
.43639 .39226 m
.43995 .3981 L
s
% Start of user PostScript
-0.12722757 -0.21547752 -0.12010404 -0.20379166 MAarrowhead1
% End of user PostScript
0 1 .679 r
.45981 .43116 m
.46204 .43492 L
s
% Start of user PostScript
-0.080385163 -0.13767819 -0.075919087 -0.13015005 MAarrowhead1
% End of user PostScript
0 1 .995 r
.47454 .45614 m
.47594 .45855 L
s
% Start of user PostScript
-0.050929803 -0.087719501 -0.048111319 -0.082903629 MAarrowhead1
% End of user PostScript
0 .69 1 r
.48384 .47209 m
.48474 .47363 L
s
% Start of user PostScript
-0.032312666 -0.055810356 -0.030528001 -0.052740162 MAarrowhead1
% End of user PostScript
0 .375 1 r
.48974 .48226 m
.49031 .48324 L
s
% Start of user PostScript
-0.020515258 -0.035483635 -0.019383303 -0.033529684 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49349 .48872 m
.49384 .48935 L
s
% Start of user PostScript
-0.013029663 -0.022552202 -0.012311092 -0.021309716 MAarrowhead1
% End of user PostScript
0 .063 1 r
.20856 1 m
.24008 .94562 L
.27467 .88595 L
.30466 .83425 L
.33065 .78946 L
.35317 .75067 L
.37269 .71706 L
.38961 .68794 L
.40427 .66272 L
.41698 .64088 L
.428 .62196 L
.43755 .60557 L
.44583 .59137 L
.45301 .57908 L
.45923 .56843 L
.46462 .55921 L
.4693 .55122 L
.47335 .54431 L
.47687 .53832 L
.47992 .53313 L
.48256 .52865 L
.48485 .52476 L
.48684 .5214 L
.48857 .51849 L
.49006 .51597 L
.49136 .51379 L
.49249 .5119 L
.49347 .51027 L
.49432 .50885 L
.49505 .50763 L
.49569 .50658 L
.49625 .50567 L
.49673 .50488 L
.49715 .50419 L
.49751 .5036 L
.49783 .5031 L
.4981 .50266 L
.49834 .50228 L
.49855 .50195 L
.49873 .50167 L
.49889 .50142 L
.49903 .50121 L
.49914 .50103 L
.49925 .50088 L
.49934 .50074 L
.49942 .50063 L
.49949 .50053 L
.49955 .50045 L
.4996 .50037 L
.49965 .50031 L
Mistroke
.49969 .50026 L
.49972 .50021 L
.49975 .50017 L
.49978 .50014 L
.4998 .50011 L
.49983 .50009 L
.49984 .50007 L
.49986 .50005 L
.49987 .50004 L
.49989 .50002 L
.4999 .50001 L
.49991 .50001 L
.49992 .5 L
.49992 .49999 L
.49993 .49999 L
.49994 .49999 L
.49994 .49998 L
.49995 .49998 L
.49995 .49998 L
.49996 .49998 L
.49996 .49998 L
.49996 .49998 L
.49997 .49998 L
.49997 .49998 L
.49997 .49998 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49998 .49998 L
.49998 .49998 L
.49998 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
Mistroke
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-3.3376028 5.7617385 -2.892443 4.991755 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-2.5066912 4.3246112 -2.1724174 3.7465748 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-0.79813312 1.3715394 -0.69182266 1.1880033 MAarrowhead1
% End of user PostScript
1 .788 0 r
.37269 .71706 m
.38961 .68794 L
s
% Start of user PostScript
-0.25462343 0.43411597 -0.22078565 0.37588783 MAarrowhead1
% End of user PostScript
.897 1 0 r
.45923 .56843 m
.46462 .55921 L
s
% Start of user PostScript
-0.081546069 0.13685505 -0.070758363 0.11841201 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48684 .5214 m
.48857 .51849 L
s
% Start of user PostScript
-0.026315504 0.042792615 -0.022865268 0.036970263 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49569 .50658 m
.49625 .50567 L
s
% Start of user PostScript
-0.0086179335 0.013155885 -0.0075074489 0.011330079 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49855 .50195 m
.49873 .50167 L
s
% Start of user PostScript
-0.0029009054 0.0038994412 -0.0025390724 0.0033347436 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49949 .50053 m
.49955 .50045 L
s
% Start of user PostScript
-0.0010249766 0.0010605031 -0.00090430974 0.00089090315 MAarrowhead1
% End of user PostScript
0 1 .679 r
.4998 .50011 m
.49983 .50009 L
s
% Start of user PostScript
-0.00039124174 0.00022350184 -0.0003492847 0.00017586339 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49992 .5 m
.49992 .49999 L
s
% Start of user PostScript
-0.00016596063 -0.0000010880981 -0.00015033281 -0.000012251549 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49996 .49998 m
.49996 .49998 L
s
% Start of user PostScript
-0.000079189845 -0.00004616133 -0.00007276566 -0.000047183387 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49998 .49998 m
.49998 .49998 L
s
% Start of user PostScript
-0.000041970454 -0.000043777546 -0.000039002644 -0.000042497826 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49999 .49998 m
.49999 .49998 L
s
% Start of user PostScript
-0.000024014673 -0.000032405389 -0.000022483018 -0.000030979314 MAarrowhead1
% End of user PostScript
1 .719 0 r
.77306 1 m
.76242 .97884 L
.7485 .95149 L
.73528 .92578 L
.72273 .90159 L
.71081 .87884 L
.6995 .85742 L
.68877 .83725 L
.6786 .81826 L
.66895 .80037 L
.65982 .78351 L
.65116 .76762 L
.64296 .75264 L
.63519 .73851 L
.62784 .7252 L
.62088 .71264 L
.61429 .70079 L
.60805 .68961 L
.60215 .67906 L
.59657 .66911 L
.59129 .65971 L
.58629 .65085 L
.58157 .64248 L
.5771 .63458 L
.57287 .62712 L
.56888 .62008 L
.5651 .61343 L
.56152 .60715 L
.55815 .60122 L
.55495 .59562 L
.55193 .59033 L
.54908 .58534 L
.54638 .58062 L
.54383 .57617 L
.54142 .57196 L
.53914 .56798 L
.53699 .56423 L
.53495 .56068 L
.53303 .55733 L
.53121 .55417 L
.52949 .55118 L
.52787 .54835 L
.52634 .54568 L
.52489 .54316 L
.52352 .54078 L
.52222 .53853 L
.521 .53641 L
.51984 .5344 L
.51875 .5325 L
.51771 .53071 L
Mistroke
.51674 .52901 L
.51582 .52741 L
.51495 .5259 L
.51412 .52447 L
.51334 .52312 L
.51261 .52185 L
.51191 .52064 L
.51126 .51951 L
.51064 .51843 L
.51005 .51741 L
.5095 .51645 L
.50897 .51555 L
.50848 .51469 L
.50801 .51388 L
.50757 .51311 L
.50715 .51239 L
.50676 .51171 L
.50639 .51106 L
.50603 .51045 L
.5057 .50988 L
.50539 .50933 L
.50509 .50882 L
.50481 .50833 L
.50454 .50787 L
.50429 .50744 L
.50406 .50703 L
.50383 .50664 L
.50362 .50628 L
.50342 .50593 L
.50323 .5056 L
.50306 .50529 L
.50289 .505 L
.50273 .50473 L
.50258 .50447 L
.50244 .50422 L
.5023 .50399 L
.50217 .50377 L
.50205 .50356 L
.50194 .50336 L
.50183 .50318 L
.50173 .503 L
.50164 .50284 L
.50155 .50268 L
.50146 .50253 L
.50138 .50239 L
.50131 .50226 L
.50123 .50214 L
.50117 .50202 L
.5011 .50191 L
.50104 .5018 L
Mistroke
.50098 .5017 L
.50093 .50161 L
.50088 .50152 L
.50083 .50144 L
.50078 .50136 L
.50074 .50128 L
.5007 .50121 L
.50066 .50115 L
.50062 .50108 L
.50059 .50102 L
.50056 .50097 L
.50053 .50091 L
.5005 .50086 L
.50047 .50081 L
.50044 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50035 .50061 L
.50033 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
Mistroke
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
Mfstroke
1 0 0 r
% Start of user PostScript
1.8181448 5.4791687 1.7706507 5.0858285 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
1.7187354 4.7263617 1.6635824 4.3972735 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.2523636 2.7250816 1.1959111 2.5530833 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
0.84664454 1.6430905 0.80397383 1.5455974 MAarrowhead1
% End of user PostScript
.897 1 0 r
.77306 1 m
.76242 .97884 L
s
% Start of user PostScript
0.55410495 1.0158759 0.52483225 0.95767924 MAarrowhead1
% End of user PostScript
.581 1 0 r
.6786 .81826 m
.66895 .80037 L
s
% Start of user PostScript
0.35719324 0.63651609 0.33790794 0.60073132 MAarrowhead1
% End of user PostScript
.266 1 0 r
.61429 .70079 m
.60805 .68961 L
s
% Start of user PostScript
0.22857571 0.40157363 0.2161046 0.37921619 MAarrowhead1
% End of user PostScript
0 1 .049 r
.57287 .62712 m
.56888 .62008 L
s
% Start of user PostScript
0.14574373 0.25423698 0.13775091 0.2401525 MAarrowhead1
% End of user PostScript
0 1 .364 r
.54638 .58062 m
.54383 .57617 L
s
% Start of user PostScript
0.092762443 0.16124172 0.087662209 0.15233142 MAarrowhead1
% End of user PostScript
0 1 .679 r
.52949 .55118 m
.52787 .54835 L
s
% Start of user PostScript
0.058988473 0.10235294 0.055741068 0.096703985 MAarrowhead1
% End of user PostScript
0 1 .995 r
.51875 .5325 m
.51771 .53071 L
s
% Start of user PostScript
0.037494606 0.06500037 0.035429162 0.061415198 MAarrowhead1
% End of user PostScript
0 .69 1 r
.51191 .52064 m
.51126 .51951 L
s
% Start of user PostScript
0.023827245 0.041288369 0.022514272 0.03901178 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50757 .51311 m
.50715 .51239 L
s
% Start of user PostScript
0.015140164 0.026229371 0.01430575 0.024783344 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50481 .50833 m
.50454 .50787 L
s
% Start of user PostScript
0.0096197364 0.016663727 0.0090895259 0.015745128 MAarrowhead1
% End of user PostScript
0 1 .274 r
.4794 1 m
.48513 .97986 L
.49739 .93359 L
.50745 .89252 L
.51563 .856 L
.52221 .82349 L
.52743 .79449 L
.53151 .76857 L
.53461 .74538 L
.5369 .72459 L
.5385 .70591 L
.53953 .68911 L
.54008 .67395 L
.54024 .66027 L
.54007 .64788 L
.53964 .63666 L
.53899 .62646 L
.53818 .61718 L
.53723 .60872 L
.53618 .60099 L
.53505 .59392 L
.53387 .58744 L
.53265 .5815 L
.53142 .57603 L
.53017 .57099 L
.52893 .56634 L
.52771 .56205 L
.5265 .55808 L
.52531 .5544 L
.52416 .55099 L
.52303 .54782 L
.52194 .54487 L
.52089 .54213 L
.51987 .53957 L
.51889 .53719 L
.51795 .53497 L
.51705 .53289 L
.51619 .53094 L
.51536 .52912 L
.51457 .52742 L
.51382 .52582 L
.5131 .52432 L
.51241 .52292 L
.51176 .5216 L
.51114 .52036 L
.51055 .5192 L
.50999 .5181 L
.50946 .51707 L
.50895 .51611 L
.50847 .51519 L
Mistroke
.50802 .51434 L
.50758 .51353 L
.50718 .51277 L
.50679 .51205 L
.50642 .51137 L
.50607 .51074 L
.50574 .51014 L
.50543 .50957 L
.50513 .50904 L
.50485 .50853 L
.50459 .50806 L
.50434 .50761 L
.5041 .50719 L
.50388 .50679 L
.50367 .50641 L
.50347 .50605 L
.50328 .50572 L
.5031 .5054 L
.50293 .5051 L
.50277 .50482 L
.50261 .50455 L
.50247 .5043 L
.50233 .50406 L
.50221 .50384 L
.50209 .50363 L
.50197 .50343 L
.50186 .50324 L
.50176 .50306 L
.50166 .50289 L
.50157 .50273 L
.50149 .50258 L
.5014 .50244 L
.50133 .5023 L
.50125 .50217 L
.50118 .50205 L
.50112 .50194 L
.50106 .50183 L
.501 .50173 L
.50094 .50164 L
.50089 .50155 L
.50084 .50146 L
.5008 .50138 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50063 .5011 L
.5006 .50104 L
.50057 .50098 L
.50054 .50093 L
.50051 .50088 L
Mistroke
.50048 .50083 L
.50045 .50078 L
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50056 L
.5003 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .5004 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
Mistroke
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
Mfstroke
1 0 0 r
% Start of user PostScript
-0.92287751 3.292964 -0.76132389 2.9197422 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-0.62345232 2.5926874 -0.50598459 2.3058379 MAarrowhead1
% End of user PostScript
1 .473 0 r
.4794 1 m
.48513 .97986 L
s
% Start of user PostScript
-0.05943022 1.0641066 -0.029746499 0.95971188 MAarrowhead1
% End of user PostScript
1 .788 0 r
.53461 .74538 m
.5369 .72459 L
s
% Start of user PostScript
0.069228795 0.49076536 0.07380458 0.44917876 MAarrowhead1
% End of user PostScript
.897 1 0 r
.53899 .62646 m
.53818 .61718 L
s
% Start of user PostScript
0.077982018 0.25291826 0.076350244 0.23435822 MAarrowhead1
% End of user PostScript
.581 1 0 r
.53017 .57099 m
.52893 .56634 L
s
% Start of user PostScript
0.060349071 0.14197732 0.057869963 0.13268359 MAarrowhead1
% End of user PostScript
.266 1 0 r
.52089 .54213 m
.51987 .53957 L
s
% Start of user PostScript
0.041775534 0.084257933 0.039742098 0.079147108 MAarrowhead1
% End of user PostScript
0 1 .049 r
.51382 .52582 m
.5131 .52432 L
s
% Start of user PostScript
0.027632778 0.05164309 0.026195196 0.048648239 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50895 .51611 m
.50847 .51519 L
s
% Start of user PostScript
0.017902984 0.032210614 0.016943341 0.030388024 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50574 .51014 m
.50543 .50957 L
s
% Start of user PostScript
0.011484708 0.020273981 0.010860297 0.019141485 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50367 .50641 m
.50347 .50605 L
s
% Start of user PostScript
0.0073317409 0.012820301 0.0069303517 0.012108873 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50233 .50406 m
.50221 .50384 L
s
% Start of user PostScript
0.0046692971 0.0081260228 0.004412792 0.0076765944 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50149 .50258 m
.5014 .50244 L
s
% Start of user PostScript
0.0029701418 0.0051566908 0.0028067009 0.0048719669 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50094 .50164 m
.50089 .50155 L
s
% Start of user PostScript
0.001888183 0.003274323 0.001784192 0.0030936854 MAarrowhead1
% End of user PostScript
0 .472 1 r
1 .30166 m
.96801 .33487 L
.92013 .38222 L
.87784 .42184 L
.84044 .45487 L
.80731 .48223 L
.77792 .50477 L
.75182 .52319 L
.72859 .53809 L
.7079 .55002 L
.68942 .55941 L
.6729 .56667 L
.6581 .57212 L
.64482 .57605 L
.63288 .57871 L
.62213 .58031 L
.61243 .58102 L
.60366 .58101 L
.59572 .58041 L
.58851 .57932 L
.58196 .57785 L
.57599 .57607 L
.57054 .57406 L
.56557 .57186 L
.56101 .56953 L
.55683 .56712 L
.55299 .56464 L
.54945 .56214 L
.54619 .55964 L
.54319 .55715 L
.54041 .55469 L
.53783 .55228 L
.53545 .54992 L
.53323 .54761 L
.53118 .54538 L
.52926 .54322 L
.52748 .54113 L
.52582 .53911 L
.52427 .53718 L
.52282 .53532 L
.52147 .53354 L
.5202 .53183 L
.51902 .5302 L
.51791 .52864 L
.51687 .52716 L
.51589 .52574 L
.51497 .52439 L
.51411 .52311 L
.51331 .52189 L
.51255 .52073 L
Mistroke
.51183 .51962 L
.51116 .51858 L
.51053 .51758 L
.50993 .51664 L
.50937 .51574 L
.50884 .51489 L
.50835 .51409 L
.50788 .51333 L
.50744 .51261 L
.50702 .51192 L
.50663 .51127 L
.50626 .51066 L
.50591 .51008 L
.50558 .50953 L
.50527 .50901 L
.50498 .50852 L
.5047 .50805 L
.50444 .50761 L
.50419 .5072 L
.50396 .5068 L
.50374 .50643 L
.50353 .50608 L
.50334 .50574 L
.50315 .50543 L
.50298 .50513 L
.50281 .50485 L
.50266 .50458 L
.50251 .50433 L
.50237 .50409 L
.50224 .50387 L
.50212 .50365 L
.502 .50345 L
.50189 .50326 L
.50179 .50308 L
.50169 .50291 L
.50159 .50275 L
.50151 .5026 L
.50142 .50246 L
.50134 .50232 L
.50127 .5022 L
.5012 .50208 L
.50113 .50196 L
.50107 .50185 L
.50101 .50175 L
.50096 .50165 L
.5009 .50156 L
.50085 .50148 L
.50081 .5014 L
.50076 .50132 L
.50072 .50125 L
Mistroke
.50068 .50118 L
.50064 .50111 L
.50061 .50105 L
.50057 .50099 L
.50054 .50094 L
.50051 .50089 L
.50048 .50084 L
.50046 .50079 L
.50043 .50075 L
.50041 .50071 L
.50039 .50067 L
.50036 .50063 L
.50034 .5006 L
.50033 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50048 L
.50026 .50045 L
.50025 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50029 L
.50016 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
Mistroke
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
Mfstroke
1 0 0 r
% Start of user PostScript
3.8807153 -4.1723819 3.4202962 -3.5154286 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
3.0181667 -2.9516905 2.6667199 -2.468419 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.1677426 -0.57659425 1.0445607 -0.44294219 MAarrowhead1
% End of user PostScript
1 .788 0 r
.75182 .52319 m
.72859 .53809 L
s
% Start of user PostScript
0.50364003 0.046373235 0.45718897 0.076188689 MAarrowhead1
% End of user PostScript
.897 1 0 r
.62213 .58031 m
.61243 .58102 L
s
% Start of user PostScript
0.24426559 0.16061157 0.22486221 0.16204535 MAarrowhead1
% End of user PostScript
.581 1 0 r
.56557 .57186 m
.56101 .56953 L
s
% Start of user PostScript
0.13113095 0.14371931 0.12201553 0.13906624 MAarrowhead1
% End of user PostScript
.266 1 0 r
.53783 .55228 m
.53545 .54992 L
s
% Start of user PostScript
0.075666999 0.10455465 0.070896392 0.099830246 MAarrowhead1
% End of user PostScript
0 1 .049 r
.52282 .53532 m
.52147 .53354 L
s
% Start of user PostScript
0.045644753 0.070636572 0.042938171 0.067073091 MAarrowhead1
% End of user PostScript
0 1 .364 r
.51411 .52311 m
.51331 .52189 L
s
% Start of user PostScript
0.028227967 0.046215822 0.026611442 0.043773243 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50884 .51489 m
.50835 .51409 L
s
% Start of user PostScript
0.017689088 0.029787889 0.016694797 0.028179275 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50558 .50953 m
.50527 .50901 L
s
% Start of user PostScript
0.011160673 0.019060582 0.010539367 0.018020531 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50353 .50608 m
.50334 .50574 L
s
% Start of user PostScript
0.007066082 0.012152927 0.0066746469 0.011486408 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50224 .50387 m
.50212 .50365 L
s
% Start of user PostScript
0.0044815142 0.0077349179 0.0042338697 0.0073096288 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50142 .50246 m
.50134 .50232 L
s
% Start of user PostScript
0.0028447979 0.0049186616 0.0026877927 0.0046478785 MAarrowhead1
% End of user PostScript
1 0 .577 r
.28981 0 m
.29666 .02681 L
.30513 .05764 L
.3135 .08613 L
.32172 .1125 L
.32977 .13695 L
.33761 .15963 L
.34522 .18071 L
.35259 .20032 L
.35972 .21857 L
.36658 .23559 L
.37318 .25147 L
.37952 .2663 L
.38559 .28017 L
.39141 .29313 L
.39697 .30527 L
.40228 .31664 L
.40735 .3273 L
.41218 .3373 L
.41678 .34668 L
.42116 .35549 L
.42532 .36377 L
.42928 .37155 L
.43305 .37886 L
.43662 .38574 L
.44001 .39222 L
.44323 .39831 L
.44629 .40405 L
.44918 .40945 L
.45192 .41454 L
.45452 .41934 L
.45699 .42386 L
.45932 .42812 L
.46153 .43214 L
.46362 .43593 L
.46561 .4395 L
.46748 .44287 L
.46925 .44605 L
.47093 .44905 L
.47252 .45188 L
.47402 .45456 L
.47545 .45708 L
.47679 .45946 L
.47806 .46171 L
.47927 .46383 L
.4804 .46583 L
.48148 .46773 L
.48249 .46951 L
.48346 .4712 L
.48436 .47279 L
Mistroke
.48522 .4743 L
.48604 .47572 L
.4868 .47706 L
.48753 .47833 L
.48821 .47953 L
.48886 .48066 L
.48948 .48173 L
.49005 .48273 L
.4906 .48369 L
.49112 .48459 L
.49161 .48544 L
.49207 .48624 L
.49251 .487 L
.49292 .48772 L
.49331 .4884 L
.49368 .48904 L
.49403 .48964 L
.49435 .49021 L
.49467 .49075 L
.49496 .49126 L
.49524 .49174 L
.4955 .4922 L
.49575 .49263 L
.49598 .49304 L
.4962 .49342 L
.49641 .49378 L
.49661 .49413 L
.4968 .49445 L
.49697 .49476 L
.49714 .49505 L
.4973 .49532 L
.49745 .49558 L
.49759 .49582 L
.49772 .49605 L
.49785 .49627 L
.49796 .49647 L
.49808 .49667 L
.49818 .49685 L
.49828 .49703 L
.49838 .49719 L
.49847 .49734 L
.49855 .49749 L
.49863 .49763 L
.49871 .49776 L
.49878 .49788 L
.49885 .498 L
.49891 .49811 L
.49897 .49821 L
.49903 .49831 L
.49908 .49841 L
Mistroke
.49913 .49849 L
.49918 .49858 L
.49922 .49866 L
.49927 .49873 L
.49931 .4988 L
.49935 .49887 L
.49938 .49893 L
.49942 .49899 L
.49945 .49904 L
.49948 .4991 L
.49951 .49915 L
.49953 .49919 L
.49956 .49924 L
.49958 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .49939 L
.49967 .49943 L
.49969 .49946 L
.4997 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49976 .49959 L
.49978 .49961 L
.49979 .49964 L
.4998 .49966 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49982 L
.4999 .49983 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
Mistroke
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
1 0 0 r
% Start of user PostScript
0.54556408 -7.7571472 0.31858089 -6.9885032 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
0.13039831 -6.3077618 -0.024632162 -5.7039986 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-0.51611474 -2.9701607 -0.53464662 -2.7250684 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.5182456 -1.5574007 -0.50460857 -1.4456964 MAarrowhead1
% End of user PostScript
.897 1 0 r
.30513 .05764 m
.3135 .08613 L
s
% Start of user PostScript
-0.38974784 -0.88472275 -0.37300861 -0.82773851 MAarrowhead1
% End of user PostScript
.581 1 0 r
.36658 .23559 m
.37318 .25147 L
s
% Start of user PostScript
-0.26684399 -0.52881206 -0.25364279 -0.49705204 MAarrowhead1
% End of user PostScript
.266 1 0 r
.41218 .3373 m
.41678 .34668 L
s
% Start of user PostScript
-0.17564528 -0.32539826 -0.16644256 -0.3066321 MAarrowhead1
% End of user PostScript
0 1 .049 r
.44323 .39831 m
.44629 .40405 L
s
% Start of user PostScript
-0.11353594 -0.20337787 -0.10742993 -0.19190373 MAarrowhead1
% End of user PostScript
0 1 .364 r
.46362 .43593 m
.46561 .4395 L
s
% Start of user PostScript
-0.072751066 -0.12814649 -0.068789309 -0.12099909 MAarrowhead1
% End of user PostScript
0 1 .679 r
.47679 .45946 m
.47806 .46171 L
s
% Start of user PostScript
-0.046417894 -0.081077537 -0.043874652 -0.07658181 MAarrowhead1
% End of user PostScript
0 1 .995 r
.48522 .4743 m
.48604 .47572 L
s
% Start of user PostScript
-0.029553579 -0.051404192 -0.027929432 -0.048562265 MAarrowhead1
% End of user PostScript
0 .69 1 r
.4906 .48369 m
.49112 .48459 L
s
% Start of user PostScript
-0.018796459 -0.032625028 -0.017761926 -0.030824005 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49403 .48964 m
.49435 .49021 L
s
% Start of user PostScript
-0.011948493 -0.020717198 -0.01129037 -0.019574385 MAarrowhead1
% End of user PostScript
0 .06 1 r
.4962 .49342 m
.49641 .49378 L
s
% Start of user PostScript
-0.0075933934 -0.013159071 -0.0071749924 -0.012433454 MAarrowhead1
% End of user PostScript
0 .944 1 r
.81344 1 m
.80328 .9857 L
.78566 .96048 L
.76914 .93644 L
.75363 .91355 L
.73907 .89177 L
.72539 .87105 L
.71253 .85135 L
.70043 .83264 L
.68906 .81487 L
.67835 .79801 L
.66827 .78201 L
.65878 .76684 L
.64985 .75245 L
.64143 .73881 L
.63349 .72589 L
.62601 .71365 L
.61896 .70205 L
.61231 .69107 L
.60605 .68067 L
.60013 .67083 L
.59455 .66152 L
.58929 .6527 L
.58432 .64436 L
.57964 .63647 L
.57522 .62901 L
.57104 .62195 L
.5671 .61527 L
.56338 .60895 L
.55987 .60298 L
.55655 .59733 L
.55342 .59199 L
.55046 .58694 L
.54767 .58217 L
.54503 .57765 L
.54254 .57339 L
.54019 .56935 L
.53797 .56554 L
.53587 .56194 L
.53389 .55853 L
.53202 .55531 L
.53025 .55227 L
.52858 .54939 L
.527 .54667 L
.52551 .5441 L
.5241 .54168 L
.52277 .53938 L
.52152 .53721 L
.52033 .53516 L
.51921 .53323 L
Mistroke
.51815 .5314 L
.51715 .52967 L
.5162 .52803 L
.51531 .52649 L
.51446 .52503 L
.51367 .52365 L
.51291 .52235 L
.5122 .52112 L
.51153 .51995 L
.51089 .51885 L
.51029 .51782 L
.50972 .51683 L
.50919 .51591 L
.50868 .51503 L
.5082 .5142 L
.50775 .51342 L
.50732 .51268 L
.50692 .51198 L
.50654 .51132 L
.50618 .5107 L
.50584 .51011 L
.50551 .50955 L
.50521 .50902 L
.50492 .50853 L
.50465 .50806 L
.5044 .50761 L
.50415 .50719 L
.50392 .5068 L
.50371 .50642 L
.5035 .50607 L
.50331 .50573 L
.50313 .50542 L
.50296 .50512 L
.50279 .50484 L
.50264 .50457 L
.50249 .50432 L
.50236 .50408 L
.50223 .50386 L
.5021 .50364 L
.50199 .50344 L
.50188 .50325 L
.50177 .50307 L
.50168 .5029 L
.50158 .50274 L
.5015 .50259 L
.50141 .50245 L
.50134 .50231 L
.50126 .50219 L
.50119 .50207 L
.50113 .50195 L
Mistroke
.50107 .50184 L
.50101 .50174 L
.50095 .50165 L
.5009 .50156 L
.50085 .50147 L
.5008 .50139 L
.50076 .50131 L
.50072 .50124 L
.50068 .50117 L
.50064 .50111 L
.5006 .50105 L
.50057 .50099 L
.50054 .50093 L
.50051 .50088 L
.50048 .50083 L
.50046 .50079 L
.50043 .50074 L
.50041 .5007 L
.50038 .50066 L
.50036 .50063 L
.50034 .50059 L
.50032 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.50019 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
Mfstroke
1 0 0 r
% Start of user PostScript
9.3451264 0.29027207 8.4703168 0.89728001 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
7.6917496 1.3876529 6.9977085 1.7789244 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.792787 2.7766976 3.4979046 2.7722853 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
2.062039 2.3663603 1.9211055 2.2831585 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
1.1996176 1.6948168 1.124827 1.6164064 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
0.72705951 1.1376018 0.68422916 1.0796656 MAarrowhead1
% End of user PostScript
.266 1 0 r
.72539 .87105 m
.71253 .85135 L
s
% Start of user PostScript
0.45077545 0.742092 0.425053 0.70270266 MAarrowhead1
% End of user PostScript
0 1 .049 r
.64143 .73881 m
.63349 .72589 L
s
% Start of user PostScript
0.28285175 0.47762396 0.2669825 0.45177837 MAarrowhead1
% End of user PostScript
0 1 .364 r
.58929 .6527 m
.58432 .64436 L
s
% Start of user PostScript
0.17858132 0.30540657 0.16864931 0.28872522 MAarrowhead1
% End of user PostScript
0 1 .679 r
.55655 .59733 m
.55342 .59199 L
s
% Start of user PostScript
0.11310242 0.19465812 0.10683999 0.18397695 MAarrowhead1
% End of user PostScript
0 1 .995 r
.53587 .56194 m
.53389 .55853 L
s
% Start of user PostScript
0.071745093 0.12387178 0.067781486 0.11705926 MAarrowhead1
% End of user PostScript
0 .69 1 r
.52277 .53938 m
.52152 .53721 L
s
% Start of user PostScript
0.045546609 0.078763721 0.043033185 0.074427073 MAarrowhead1
% End of user PostScript
0 .375 1 r
.51446 .52503 m
.51367 .52365 L
s
% Start of user PostScript
0.028926243 0.050061899 0.02733089 0.047303982 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50919 .51591 m
.50868 .51503 L
s
% Start of user PostScript
0.018374443 0.031812814 0.017361333 0.030059746 MAarrowhead1
% End of user PostScript
0 1 .93 r
0 .49221 m
.03201 .46894 L
.07544 .4401 L
.11413 .41693 L
.14864 .39857 L
.17949 .38428 L
.2071 .37344 L
.23186 .36549 L
.2541 .35998 L
.27413 .35649 L
.29218 .35469 L
.30849 .35429 L
.32326 .35503 L
.33665 .35671 L
.34881 .35913 L
.35988 .36215 L
.36998 .36564 L
.3792 .36949 L
.38764 .3736 L
.39538 .37789 L
.40248 .38231 L
.40902 .38679 L
.41504 .39129 L
.42059 .39577 L
.42572 .40021 L
.43047 .40458 L
.43487 .40886 L
.43895 .41304 L
.44274 .41709 L
.44626 .42102 L
.44954 .42483 L
.4526 .42849 L
.45545 .43202 L
.45812 .4354 L
.46061 .43865 L
.46293 .44177 L
.46511 .44474 L
.46715 .44758 L
.46906 .4503 L
.47086 .45289 L
.47254 .45535 L
.47412 .4577 L
.4756 .45993 L
.477 .46205 L
.47831 .46407 L
.47954 .46599 L
.4807 .46781 L
.48179 .46953 L
.48282 .47117 L
.48379 .47272 L
Mistroke
.4847 .47419 L
.48556 .47559 L
.48637 .47691 L
.48713 .47816 L
.48785 .47935 L
.48853 .48047 L
.48917 .48154 L
.48977 .48254 L
.49034 .48349 L
.49088 .4844 L
.49139 .48525 L
.49187 .48605 L
.49232 .48682 L
.49274 .48754 L
.49315 .48822 L
.49353 .48887 L
.49388 .48948 L
.49422 .49006 L
.49454 .4906 L
.49485 .49112 L
.49513 .4916 L
.4954 .49207 L
.49565 .4925 L
.49589 .49291 L
.49612 .4933 L
.49634 .49367 L
.49654 .49402 L
.49673 .49435 L
.49691 .49466 L
.49708 .49495 L
.49724 .49523 L
.49739 .49549 L
.49754 .49574 L
.49767 .49598 L
.4978 .4962 L
.49792 .49641 L
.49804 .49661 L
.49815 .49679 L
.49825 .49697 L
.49834 .49714 L
.49844 .49729 L
.49852 .49744 L
.4986 .49758 L
.49868 .49772 L
.49875 .49784 L
.49882 .49796 L
.49889 .49807 L
.49895 .49818 L
.49901 .49828 L
.49906 .49837 L
Mistroke
.49911 .49846 L
.49916 .49855 L
.49921 .49863 L
.49925 .4987 L
.49929 .49878 L
.49933 .49884 L
.49937 .49891 L
.4994 .49897 L
.49944 .49902 L
.49947 .49908 L
.4995 .49913 L
.49952 .49918 L
.49955 .49922 L
.49958 .49927 L
.4996 .49931 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49945 L
.4997 .49948 L
.49971 .49951 L
.49973 .49953 L
.49975 .49956 L
.49976 .49958 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
Mistroke
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
Mfstroke
1 0 0 r
% Start of user PostScript
-2.4439428 1.4290535 -2.1811078 1.1283688 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-1.9498657 0.87388532 -1.7461915 0.65910085 MAarrowhead1
% End of user PostScript
1 .473 0 r
.07544 .4401 m
.11413 .41693 L
s
% Start of user PostScript
-0.84911429 -0.11979727 -0.77174156 -0.16613997 MAarrowhead1
% End of user PostScript
1 .788 0 r
.29218 .35469 m
.30849 .35429 L
s
% Start of user PostScript
-0.41563566 -0.29061543 -0.38301138 -0.29142129 MAarrowhead1
% End of user PostScript
.897 1 0 r
.38764 .3736 m
.39538 .37789 L
s
% Start of user PostScript
-0.22471693 -0.25280436 -0.2092434 -0.24421602 MAarrowhead1
% End of user PostScript
.581 1 0 r
.43487 .40886 m
.43895 .41304 L
s
% Start of user PostScript
-0.13026653 -0.18227834 -0.12210515 -0.17392992 MAarrowhead1
% End of user PostScript
.266 1 0 r
.46061 .43865 m
.46293 .44177 L
s
% Start of user PostScript
-0.078789907 -0.12269258 -0.074135191 -0.11646951 MAarrowhead1
% End of user PostScript
0 1 .049 r
.4756 .45993 m
.477 .46205 L
s
% Start of user PostScript
-0.04879578 -0.080139241 -0.046007038 -0.075893429 MAarrowhead1
% End of user PostScript
0 1 .364 r
.4847 .47419 m
.48556 .47559 L
s
% Start of user PostScript
-0.030600765 -0.051611009 -0.028882534 -0.048820662 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49034 .48349 m
.49088 .4844 L
s
% Start of user PostScript
-0.019314465 -0.033011587 -0.018239824 -0.03120927 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49388 .48948 m
.49422 .49006 L
s
% Start of user PostScript
-0.012230791 -0.02104388 -0.011553435 -0.019889419 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49612 .4933 m
.49634 .49367 L
s
% Start of user PostScript
-0.0077578733 -0.013392392 -0.0073292391 -0.012655936 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49754 .49574 m
.49767 .49598 L
s
% Start of user PostScript
-0.0049248205 -0.0085158542 -0.0046530369 -0.0080470051 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49844 .49729 m
.49852 .49744 L
s
% Start of user PostScript
-0.0031276511 -0.005412743 -0.0029551489 -0.0051145622 MAarrowhead1
% End of user PostScript
1 0 .968 r
.80966 1 m
.80813 .9978 L
.79034 .97177 L
.77363 .94699 L
.75794 .9234 L
.74319 .90098 L
.72933 .87967 L
.71629 .85943 L
.70402 .84021 L
.69248 .82198 L
.68161 .80468 L
.67138 .78827 L
.66174 .77271 L
.65265 .75797 L
.64409 .74401 L
.63602 .73077 L
.62842 .71824 L
.62124 .70638 L
.61448 .69514 L
.6081 .68451 L
.60208 .67445 L
.5964 .66492 L
.59104 .65591 L
.58598 .64739 L
.58121 .63932 L
.5767 .6317 L
.57245 .62448 L
.56843 .61766 L
.56464 .61121 L
.56106 .60511 L
.55768 .59934 L
.55449 .59389 L
.55147 .58873 L
.54862 .58385 L
.54594 .57925 L
.5434 .57489 L
.541 .57077 L
.53873 .56688 L
.53659 .5632 L
.53457 .55973 L
.53266 .55644 L
.53086 .55333 L
.52916 .5504 L
.52755 .54763 L
.52603 .545 L
.52459 .54253 L
.52323 .54018 L
.52195 .53797 L
.52074 .53588 L
.5196 .5339 L
Mistroke
.51852 .53204 L
.51749 .53027 L
.51653 .5286 L
.51562 .52703 L
.51476 .52554 L
.51394 .52413 L
.51317 .5228 L
.51245 .52155 L
.51176 .52036 L
.51111 .51924 L
.5105 .51818 L
.50992 .51718 L
.50937 .51623 L
.50886 .51534 L
.50837 .51449 L
.50791 .51369 L
.50747 .51294 L
.50706 .51222 L
.50667 .51155 L
.5063 .51091 L
.50595 .51031 L
.50563 .50974 L
.50532 .50921 L
.50502 .5087 L
.50475 .50822 L
.50448 .50777 L
.50424 .50734 L
.504 .50693 L
.50378 .50655 L
.50357 .50619 L
.50338 .50585 L
.50319 .50553 L
.50302 .50522 L
.50285 .50493 L
.50269 .50466 L
.50254 .50441 L
.5024 .50416 L
.50227 .50393 L
.50215 .50372 L
.50203 .50351 L
.50192 .50332 L
.50181 .50314 L
.50171 .50296 L
.50162 .5028 L
.50153 .50264 L
.50144 .5025 L
.50136 .50236 L
.50129 .50223 L
.50122 .50211 L
.50115 .50199 L
Mistroke
.50109 .50188 L
.50103 .50178 L
.50097 .50168 L
.50092 .50159 L
.50087 .5015 L
.50082 .50142 L
.50077 .50134 L
.50073 .50127 L
.50069 .5012 L
.50065 .50113 L
.50062 .50107 L
.50058 .50101 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .5008 L
.50044 .50076 L
.50041 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .50061 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50016 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
Mfstroke
1 0 0 r
% Start of user PostScript
9.013786 1.1984082 8.1907759 1.6972733 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
7.4566756 2.0932191 6.8007709 2.401988 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.7454423 3.0482913 3.4611708 3.01505 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
2.0643745 2.48277 1.9258549 2.3887477 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
1.2114023 1.7509353 1.1367701 1.6680321 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
0.73782023 1.1675866 0.69465349 1.1075529 MAarrowhead1
% End of user PostScript
.266 1 0 r
.72933 .87967 m
.71629 .85943 L
s
% Start of user PostScript
0.4586524 0.75934099 0.43257735 0.71885954 MAarrowhead1
% End of user PostScript
0 1 .049 r
.64409 .74401 m
.63602 .73077 L
s
% Start of user PostScript
0.28818687 0.48801047 0.27204947 0.46154745 MAarrowhead1
% End of user PostScript
0 1 .364 r
.59104 .65591 m
.58598 .64739 L
s
% Start of user PostScript
0.18207599 0.31182363 0.17195959 0.29477429 MAarrowhead1
% End of user PostScript
0 1 .679 r
.55768 .59934 m
.55449 .59389 L
s
% Start of user PostScript
0.11535612 0.19867734 0.10897207 0.18777009 MAarrowhead1
% End of user PostScript
0 1 .995 r
.53659 .5632 m
.53457 .55973 L
s
% Start of user PostScript
0.07318757 0.12640699 0.069145284 0.11945329 MAarrowhead1
% End of user PostScript
0 .69 1 r
.52323 .54018 m
.52195 .53797 L
s
% Start of user PostScript
0.046466448 0.080368613 0.043902585 0.075943043 MAarrowhead1
% End of user PostScript
0 .375 1 r
.51476 .52554 m
.51394 .52413 L
s
% Start of user PostScript
0.029511728 0.051079701 0.027884186 0.048265536 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50937 .51623 m
.50886 .51534 L
s
% Start of user PostScript
0.018746767 0.032458878 0.017713161 0.030670152 MAarrowhead1
% End of user PostScript
1 .641 0 r
.23301 0 m
.23358 .00122 L
.24742 .03017 L
.26061 .05734 L
.27317 .08284 L
.28513 .10678 L
.29649 .12928 L
.3073 .15043 L
.31756 .17032 L
.32731 .18903 L
.33656 .20664 L
.34534 .22321 L
.35366 .23881 L
.36155 .25351 L
.36903 .26736 L
.37612 .28041 L
.38284 .29271 L
.38919 .30431 L
.39522 .31524 L
.40092 .32556 L
.40632 .33528 L
.41143 .34446 L
.41626 .35312 L
.42083 .36128 L
.42516 .36899 L
.42926 .37627 L
.43313 .38314 L
.43679 .38962 L
.44025 .39574 L
.44353 .40152 L
.44663 .40697 L
.44956 .41212 L
.45232 .41699 L
.45494 .42158 L
.45742 .42592 L
.45976 .43001 L
.46197 .43388 L
.46406 .43754 L
.46604 .44099 L
.4679 .44425 L
.46967 .44733 L
.47134 .45024 L
.47292 .45298 L
.47441 .45558 L
.47581 .45803 L
.47715 .46035 L
.4784 .46254 L
.47959 .4646 L
.48072 .46656 L
.48178 .4684 L
Mistroke
.48278 .47015 L
.48373 .47179 L
.48463 .47335 L
.48547 .47482 L
.48627 .47621 L
.48703 .47752 L
.48774 .47876 L
.48842 .47993 L
.48906 .48104 L
.48966 .48208 L
.49023 .48307 L
.49077 .484 L
.49128 .48489 L
.49176 .48572 L
.49221 .48651 L
.49264 .48725 L
.49305 .48795 L
.49343 .48862 L
.49379 .48925 L
.49413 .48984 L
.49446 .4904 L
.49476 .49093 L
.49505 .49143 L
.49532 .4919 L
.49558 .49235 L
.49583 .49277 L
.49606 .49317 L
.49627 .49354 L
.49648 .4939 L
.49667 .49424 L
.49686 .49455 L
.49703 .49485 L
.49719 .49514 L
.49735 .49541 L
.49749 .49566 L
.49763 .4959 L
.49776 .49612 L
.49789 .49634 L
.498 .49654 L
.49811 .49673 L
.49822 .49691 L
.49831 .49708 L
.49841 .49724 L
.4985 .49739 L
.49858 .49754 L
.49866 .49767 L
.49873 .4978 L
.4988 .49792 L
.49887 .49804 L
.49893 .49815 L
Mistroke
.49899 .49825 L
.49904 .49834 L
.4991 .49844 L
.49915 .49852 L
.49919 .4986 L
.49924 .49868 L
.49928 .49875 L
.49932 .49882 L
.49936 .49889 L
.49939 .49895 L
.49943 .49901 L
.49946 .49906 L
.49949 .49911 L
.49952 .49916 L
.49954 .49921 L
.49957 .49925 L
.49959 .49929 L
.49961 .49933 L
.49964 .49937 L
.49966 .4994 L
.49967 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49952 L
.49974 .49955 L
.49975 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49971 L
.49984 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49978 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
Mistroke
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
1 0 0 r
% Start of user PostScript
-1.3866054 -3.9153263 -1.3444249 -3.6401839 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-1.2999967 -3.388128 -1.2540552 -3.1568285 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-0.9301286 -1.9721716 -0.88703061 -1.8493087 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.62405821 -1.1956625 -0.59225614 -1.1252581 MAarrowhead1
% End of user PostScript
.897 1 0 r
.29649 .12928 m
.3073 .15043 L
s
% Start of user PostScript
-0.40701186 -0.74143376 -0.38540205 -0.69913565 MAarrowhead1
% End of user PostScript
.581 1 0 r
.36903 .26736 m
.37612 .28041 L
s
% Start of user PostScript
-0.26193546 -0.46527434 -0.24775947 -0.43917361 MAarrowhead1
% End of user PostScript
.266 1 0 r
.41626 .35312 m
.42083 .36128 L
s
% Start of user PostScript
-0.16748133 -0.2937688 -0.15833287 -0.27743155 MAarrowhead1
% End of user PostScript
0 1 .049 r
.44663 .40697 m
.44956 .41212 L
s
% Start of user PostScript
-0.10674574 -0.18605929 -0.10088825 -0.17575759 MAarrowhead1
% End of user PostScript
0 1 .364 r
.46604 .44099 m
.4679 .44425 L
s
% Start of user PostScript
-0.067927467 -0.1180257 -0.064191631 -0.11150539 MAarrowhead1
% End of user PostScript
0 1 .679 r
.4784 .46254 m
.47959 .4646 L
s
% Start of user PostScript
-0.043191351 -0.074927787 -0.040813261 -0.070793038 MAarrowhead1
% End of user PostScript
0 1 .995 r
.48627 .47621 m
.48703 .47752 L
s
% Start of user PostScript
-0.027452167 -0.047586101 -0.025939818 -0.044961621 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49128 .48489 m
.49176 .48572 L
s
% Start of user PostScript
-0.017444993 -0.030227547 -0.016483672 -0.028560897 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49446 .4904 m
.49476 .49093 L
s
% Start of user PostScript
-0.011084653 -0.019202974 -0.010473738 -0.018144332 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49648 .4939 m
.49667 .49424 L
s
% Start of user PostScript
-0.0070429071 -0.012199878 -0.0066547201 -0.011527358 MAarrowhead1
% End of user PostScript
1 0 .882 r
.93722 1 m
.91913 .98991 L
.89069 .97216 L
.86452 .95415 L
.84042 .93606 L
.81818 .91804 L
.79763 .90021 L
.77862 .88267 L
.761 .86549 L
.74465 .84874 L
.72947 .83246 L
.71535 .81668 L
.7022 .80143 L
.68995 .78673 L
.67853 .77258 L
.66786 .75899 L
.65789 .74596 L
.64856 .73348 L
.63983 .72154 L
.63166 .71014 L
.624 .69926 L
.61681 .68888 L
.61007 .679 L
.60374 .66959 L
.59779 .66064 L
.5922 .65212 L
.58695 .64404 L
.58201 .63635 L
.57736 .62906 L
.57298 .62214 L
.56886 .61557 L
.56498 .60935 L
.56133 .60345 L
.55789 .59785 L
.55464 .59255 L
.55158 .58753 L
.5487 .58278 L
.54598 .57828 L
.54341 .57402 L
.54099 .56998 L
.53871 .56617 L
.53656 .56255 L
.53452 .55914 L
.53261 .5559 L
.5308 .55284 L
.52909 .54995 L
.52747 .54721 L
.52595 .54463 L
.52451 .54218 L
.52316 .53986 L
Mistroke
.52187 .53768 L
.52066 .53561 L
.51952 .53365 L
.51844 .5318 L
.51742 .53006 L
.51646 .5284 L
.51555 .52684 L
.51469 .52537 L
.51388 .52397 L
.51311 .52265 L
.51239 .52141 L
.5117 .52023 L
.51106 .51911 L
.51045 .51806 L
.50987 .51707 L
.50933 .51613 L
.50881 .51524 L
.50833 .5144 L
.50787 .51361 L
.50743 .51286 L
.50702 .51215 L
.50663 .51148 L
.50627 .51085 L
.50592 .51025 L
.5056 .50969 L
.50529 .50915 L
.505 .50865 L
.50472 .50817 L
.50446 .50772 L
.50421 .5073 L
.50398 .50689 L
.50376 .50651 L
.50355 .50616 L
.50336 .50582 L
.50317 .5055 L
.503 .50519 L
.50283 .50491 L
.50268 .50464 L
.50253 .50438 L
.50239 .50414 L
.50226 .50391 L
.50213 .5037 L
.50202 .50349 L
.50191 .5033 L
.5018 .50312 L
.5017 .50295 L
.50161 .50278 L
.50152 .50263 L
.50143 .50248 L
.50136 .50235 L
Mistroke
.50128 .50222 L
.50121 .5021 L
.50114 .50198 L
.50108 .50187 L
.50102 .50177 L
.50096 .50167 L
.50091 .50158 L
.50086 .50149 L
.50081 .50141 L
.50077 .50133 L
.50073 .50126 L
.50069 .50119 L
.50065 .50112 L
.50061 .50106 L
.50058 .501 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .5008 L
.50044 .50076 L
.50041 .50071 L
.50039 .50067 L
.50037 .50064 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .5003 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50015 L
.50008 .50014 L
Mistroke
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
Mfstroke
1 0 0 r
% Start of user PostScript
6.9840519 -2.6149771 6.2661852 -1.8942423 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
5.6323322 -1.2902146 5.0719285 -0.78618374 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.5658617 0.93415012 2.3450026 1.0202275 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.3084227 1.1508458 1.2110612 1.1311258 MAarrowhead1
% End of user PostScript
.897 1 0 r
.86452 .95415 m
.84042 .93606 L
s
% Start of user PostScript
0.72904365 0.9082911 0.68083732 0.87211679 MAarrowhead1
% End of user PostScript
.581 1 0 r
.71535 .81668 m
.7022 .80143 L
s
% Start of user PostScript
0.4306992 0.63335752 0.40440978 0.60286052 MAarrowhead1
% End of user PostScript
.266 1 0 r
.63166 .71014 m
.624 .69926 L
s
% Start of user PostScript
0.26331611 0.42028412 0.24799186 0.39852033 MAarrowhead1
% End of user PostScript
0 1 .049 r
.58201 .63635 m
.57736 .62906 L
s
% Start of user PostScript
0.16401486 0.272708 0.15471677 0.25812176 MAarrowhead1
% End of user PostScript
0 1 .364 r
.55158 .58753 m
.5487 .58278 L
s
% Start of user PostScript
0.10316303 0.17506921 0.097394763 0.16556083 MAarrowhead1
% End of user PostScript
0 1 .679 r
.53261 .5559 m
.5308 .55284 L
s
% Start of user PostScript
0.065212592 0.11180296 0.061591999 0.10568525 MAarrowhead1
% End of user PostScript
0 1 .995 r
.52066 .53561 m
.51952 .53365 L
s
% Start of user PostScript
0.041327088 0.07121563 0.039040826 0.067304436 MAarrowhead1
% End of user PostScript
0 .69 1 r
.51311 .52265 m
.51239 .52141 L
s
% Start of user PostScript
0.026223428 0.045304325 0.024775333 0.042811637 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50833 .5144 m
.50787 .51361 L
s
% Start of user PostScript
0.016650246 0.028802215 0.015731628 0.027216043 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50529 .50915 m
.505 .50865 L
s
% Start of user PostScript
0.010575243 0.018305146 0.0099920565 0.017296601 MAarrowhead1
% End of user PostScript
1 0 .675 r
0 .02604 m
.00272 .02666 L
.03891 .03755 L
.07193 .04986 L
.10212 .06326 L
.12976 .07744 L
.15512 .09216 L
.17842 .10721 L
.19986 .12243 L
.21962 .13766 L
.23787 .1528 L
.25473 .16776 L
.27035 .18244 L
.28482 .1968 L
.29826 .21079 L
.31074 .22437 L
.32235 .23752 L
.33317 .25022 L
.34325 .26245 L
.35266 .27421 L
.36145 .28551 L
.36966 .29633 L
.37734 .30669 L
.38454 .3166 L
.39128 .32606 L
.3976 .33508 L
.40352 .34368 L
.40908 .35188 L
.41431 .35968 L
.41921 .36709 L
.42383 .37414 L
.42816 .38084 L
.43224 .3872 L
.43608 .39324 L
.43969 .39897 L
.44309 .40441 L
.4463 .40956 L
.44932 .41444 L
.45216 .41907 L
.45484 .42346 L
.45737 .42761 L
.45975 .43154 L
.462 .43527 L
.46412 .43879 L
.46612 .44213 L
.468 .44529 L
.46978 .44828 L
.47146 .4511 L
.47305 .45378 L
.47454 .45631 L
Mistroke
.47596 .4587 L
.47729 .46096 L
.47855 .4631 L
.47974 .46513 L
.48086 .46704 L
.48192 .46885 L
.48292 .47056 L
.48386 .47218 L
.48476 .47371 L
.4856 .47515 L
.48639 .47652 L
.48715 .47781 L
.48786 .47903 L
.48853 .48018 L
.48916 .48127 L
.48976 .4823 L
.49032 .48328 L
.49086 .4842 L
.49136 .48507 L
.49184 .48589 L
.49229 .48667 L
.49272 .4874 L
.49312 .48809 L
.4935 .48875 L
.49386 .48937 L
.49419 .48995 L
.49452 .49051 L
.49482 .49103 L
.4951 .49153 L
.49537 .49199 L
.49563 .49243 L
.49587 .49285 L
.4961 .49324 L
.49631 .49362 L
.49652 .49397 L
.49671 .4943 L
.49689 .49461 L
.49706 .49491 L
.49722 .49519 L
.49738 .49546 L
.49752 .49571 L
.49766 .49594 L
.49779 .49617 L
.49791 .49638 L
.49802 .49658 L
.49813 .49677 L
.49824 .49694 L
.49833 .49711 L
.49842 .49727 L
.49851 .49742 L
Mistroke
.49859 .49756 L
.49867 .4977 L
.49874 .49783 L
.49881 .49795 L
.49888 .49806 L
.49894 .49817 L
.499 .49827 L
.49905 .49836 L
.49911 .49845 L
.49916 .49854 L
.4992 .49862 L
.49925 .49869 L
.49929 .49877 L
.49933 .49883 L
.49936 .4989 L
.4994 .49896 L
.49943 .49902 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49922 L
.49957 .49926 L
.4996 .4993 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49944 L
.4997 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49956 L
.49976 .49958 L
.49977 .4996 L
.49978 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
Mistroke
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
1 0 0 r
% Start of user PostScript
-4.1271437 0.53569059 -3.725774 0.2050003 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-3.369742 -0.067254634 -3.0534494 -0.28966319 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.6120476 -0.95880323 -1.4817045 -0.97780677 MAarrowhead1
% End of user PostScript
1 .788 0 r
.07193 .04986 m
.10212 .06326 L
s
% Start of user PostScript
-0.85613368 -0.90027487 -0.79575957 -0.87348399 MAarrowhead1
% End of user PostScript
.897 1 0 r
.25473 .16776 m
.27035 .18244 L
s
% Start of user PostScript
-0.49053026 -0.66448983 -0.45930239 -0.63511819 MAarrowhead1
% End of user PostScript
.581 1 0 r
.35266 .27421 m
.36145 .28551 L
s
% Start of user PostScript
-0.29468319 -0.45157536 -0.27710864 -0.42898969 MAarrowhead1
% End of user PostScript
.266 1 0 r
.40908 .35188 m
.41431 .35968 L
s
% Start of user PostScript
-0.18183172 -0.29624677 -0.17138589 -0.28064997 MAarrowhead1
% End of user PostScript
0 1 .049 r
.44309 .40441 m
.4463 .40956 L
s
% Start of user PostScript
-0.11381172 -0.19118686 -0.10740384 -0.18088123 MAarrowhead1
% End of user PostScript
0 1 .364 r
.46412 .43879 m
.46612 .44213 L
s
% Start of user PostScript
-0.071764891 -0.12241259 -0.067766398 -0.11573904 MAarrowhead1
% End of user PostScript
0 1 .679 r
.47729 .46096 m
.47855 .4631 L
s
% Start of user PostScript
-0.045422274 -0.078073775 -0.042904964 -0.073793759 MAarrowhead1
% End of user PostScript
0 1 .995 r
.4856 .47515 m
.48639 .47652 L
s
% Start of user PostScript
-0.02880374 -0.049698904 -0.027211727 -0.046966907 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49086 .4842 m
.49136 .48507 L
s
% Start of user PostScript
-0.018282786 -0.031606135 -0.017273644 -0.029866337 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49419 .48995 m
.49452 .49051 L
s
% Start of user PostScript
-0.011610292 -0.020090364 -0.010969881 -0.018983711 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49631 .49362 m
.49652 .49397 L
s
% Start of user PostScript
-0.0073747559 -0.012767334 -0.0069681112 -0.012063822 MAarrowhead1
% End of user PostScript
0 .704 1 r
.29499 0 m
.29591 .00412 L
.30394 .03703 L
.31195 .06739 L
.3199 .09542 L
.32773 .12135 L
.33541 .14537 L
.34291 .16765 L
.3502 .18833 L
.35728 .20755 L
.36412 .22545 L
.37072 .24212 L
.37708 .25766 L
.38319 .27217 L
.38905 .28573 L
.39467 .29841 L
.40004 .31027 L
.40518 .32138 L
.41008 .33179 L
.41475 .34155 L
.41921 .35071 L
.42345 .3593 L
.42748 .36738 L
.43132 .37496 L
.43497 .38209 L
.43844 .3888 L
.44173 .39511 L
.44485 .40104 L
.44781 .40663 L
.45062 .4119 L
.45328 .41685 L
.45581 .42152 L
.4582 .42593 L
.46047 .43007 L
.46261 .43399 L
.46465 .43767 L
.46657 .44115 L
.46839 .44443 L
.47011 .44753 L
.47175 .45045 L
.47329 .4532 L
.47475 .4558 L
.47613 .45826 L
.47744 .46057 L
.47867 .46276 L
.47984 .46483 L
.48095 .46677 L
.48199 .46861 L
.48298 .47035 L
.48392 .47199 L
Mistroke
.4848 .47354 L
.48563 .47501 L
.48642 .47639 L
.48717 .47769 L
.48787 .47893 L
.48854 .48009 L
.48917 .48119 L
.48977 .48223 L
.49033 .48321 L
.49086 .48414 L
.49137 .48501 L
.49184 .48584 L
.49229 .48662 L
.49271 .48736 L
.49312 .48806 L
.49349 .48872 L
.49385 .48934 L
.49419 .48993 L
.49451 .49048 L
.49481 .49101 L
.4951 .4915 L
.49537 .49197 L
.49562 .49242 L
.49587 .49283 L
.49609 .49323 L
.49631 .4936 L
.49651 .49396 L
.4967 .49429 L
.49689 .4946 L
.49706 .4949 L
.49722 .49518 L
.49737 .49545 L
.49752 .4957 L
.49765 .49594 L
.49778 .49616 L
.49791 .49637 L
.49802 .49657 L
.49813 .49676 L
.49823 .49694 L
.49833 .49711 L
.49842 .49727 L
.49851 .49742 L
.49859 .49756 L
.49867 .49769 L
.49874 .49782 L
.49881 .49794 L
.49888 .49806 L
.49894 .49816 L
.499 .49826 L
.49905 .49836 L
Mistroke
.49911 .49845 L
.49915 .49854 L
.4992 .49862 L
.49925 .49869 L
.49929 .49876 L
.49933 .49883 L
.49936 .4989 L
.4994 .49896 L
.49943 .49902 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49922 L
.49957 .49926 L
.4996 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.4997 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.4998 .49965 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
Mistroke
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
1 0 0 r
% Start of user PostScript
0.93278171 -8.6258224 0.64962203 -7.7489642 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
0.41300987 -6.9740282 0.21624884 -6.2882418 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-0.4425128 -3.2099518 -0.47341238 -2.9372475 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.50515251 -1.6514333 -0.49487811 -1.5299715 MAarrowhead1
% End of user PostScript
.897 1 0 r
.30394 .03703 m
.31195 .06739 L
s
% Start of user PostScript
-0.39212854 -0.92593397 -0.3760973 -0.86522454 MAarrowhead1
% End of user PostScript
.581 1 0 r
.36412 .22545 m
.37072 .24212 L
s
% Start of user PostScript
-0.27175653 -0.5491064 -0.25855122 -0.51576582 MAarrowhead1
% End of user PostScript
.266 1 0 r
.41008 .33179 m
.41475 .34155 L
s
% Start of user PostScript
-0.17984686 -0.33642077 -0.17049729 -0.31690025 MAarrowhead1
% End of user PostScript
0 1 .049 r
.44173 .39511 m
.44485 .40104 L
s
% Start of user PostScript
-0.11654872 -0.20978628 -0.11030357 -0.19791225 MAarrowhead1
% End of user PostScript
0 1 .364 r
.46261 .43399 m
.46465 .43767 L
s
% Start of user PostScript
-0.074774317 -0.13202905 -0.070709594 -0.12465282 MAarrowhead1
% End of user PostScript
0 1 .679 r
.47613 .45826 m
.47744 .46057 L
s
% Start of user PostScript
-0.047738024 -0.083484249 -0.045124734 -0.078851151 MAarrowhead1
% End of user PostScript
0 1 .995 r
.4848 .47354 m
.48563 .47501 L
s
% Start of user PostScript
-0.030403332 -0.052914198 -0.02873321 -0.04998754 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49033 .48321 m
.49086 .48414 L
s
% Start of user PostScript
-0.019339845 -0.033578335 -0.018275634 -0.031724289 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49385 .48934 m
.49419 .48993 L
s
% Start of user PostScript
-0.012294842 -0.021320949 -0.011617715 -0.020144705 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49609 .49323 m
.49631 .4936 L
s
% Start of user PostScript
-0.0078137975 -0.013542048 -0.0073832752 -0.012795273 MAarrowhead1
% End of user PostScript
1 .108 0 r
0 .37718 m
.02843 .36216 L
.06979 .34314 L
.10681 .32873 L
.14002 .3182 L
.16986 .31091 L
.19672 .30633 L
.22094 .30401 L
.24282 .30355 L
.26263 .30462 L
.2806 .30693 L
.29692 .31025 L
.31178 .31436 L
.32533 .31909 L
.33771 .32429 L
.34904 .32985 L
.35943 .33565 L
.36897 .34161 L
.37774 .34765 L
.38583 .35372 L
.39328 .35977 L
.40018 .36575 L
.40655 .37163 L
.41246 .3774 L
.41794 .38302 L
.42304 .38848 L
.42777 .39377 L
.43218 .39889 L
.43629 .40382 L
.44012 .40857 L
.4437 .41313 L
.44704 .4175 L
.45017 .42168 L
.4531 .42569 L
.45584 .42951 L
.45841 .43316 L
.46082 .43664 L
.46308 .43996 L
.46521 .44312 L
.4672 .44612 L
.46907 .44897 L
.47084 .45169 L
.47249 .45426 L
.47405 .45671 L
.47552 .45903 L
.4769 .46123 L
.4782 .46332 L
.47943 .4653 L
.48058 .46718 L
.48167 .46895 L
Mistroke
.4827 .47064 L
.48367 .47223 L
.48458 .47374 L
.48544 .47517 L
.48625 .47653 L
.48702 .47781 L
.48774 .47902 L
.48842 .48016 L
.48906 .48125 L
.48967 .48228 L
.49024 .48325 L
.49078 .48416 L
.4913 .48503 L
.49178 .48585 L
.49223 .48663 L
.49266 .48736 L
.49307 .48806 L
.49345 .48871 L
.49381 .48933 L
.49416 .48992 L
.49448 .49047 L
.49478 .491 L
.49507 .49149 L
.49534 .49196 L
.4956 .4924 L
.49584 .49282 L
.49607 .49322 L
.49629 .49359 L
.4965 .49394 L
.49669 .49427 L
.49687 .49459 L
.49704 .49489 L
.49721 .49517 L
.49736 .49544 L
.49751 .49569 L
.49764 .49592 L
.49777 .49615 L
.4979 .49636 L
.49801 .49656 L
.49812 .49675 L
.49823 .49693 L
.49832 .4971 L
.49842 .49726 L
.4985 .49741 L
.49859 .49755 L
.49866 .49769 L
.49874 .49782 L
.49881 .49794 L
.49887 .49805 L
.49894 .49816 L
Mistroke
.49899 .49826 L
.49905 .49835 L
.4991 .49844 L
.49915 .49853 L
.4992 .49861 L
.49924 .49869 L
.49928 .49876 L
.49932 .49883 L
.49936 .49889 L
.4994 .49895 L
.49943 .49901 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49921 L
.49957 .49926 L
.49959 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
Mistroke
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
1 0 0 r
% Start of user PostScript
-7.5852747 7.5312255 -6.6994592 6.3060054 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-5.924913 5.2564736 -5.2471663 4.3585068 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.3416913 0.87554173 -2.1010249 0.63400233 MAarrowhead1
% End of user PostScript
1 .788 0 r
0 .37718 m
.02843 .36216 L
s
% Start of user PostScript
-1.0356906 -0.22676847 -0.94314164 -0.27568783 MAarrowhead1
% End of user PostScript
.897 1 0 r
.24282 .30355 m
.26263 .30462 L
s
% Start of user PostScript
-0.51435683 -0.39290611 -0.47473638 -0.3907661 MAarrowhead1
% End of user PostScript
.581 1 0 r
.35943 .33565 m
.36897 .34161 L
s
% Start of user PostScript
-0.28114082 -0.32870242 -0.26206314 -0.31678609 MAarrowhead1
% End of user PostScript
.266 1 0 r
.41794 .38302 m
.42304 .38848 L
s
% Start of user PostScript
-0.16411373 -0.23396607 -0.15392967 -0.22304045 MAarrowhead1
% End of user PostScript
0 1 .049 r
.45017 .42168 m
.4531 .42569 L
s
% Start of user PostScript
-0.099658526 -0.15663357 -0.093803621 -0.14862603 MAarrowhead1
% End of user PostScript
0 1 .364 r
.46907 .44897 m
.47084 .45169 L
s
% Start of user PostScript
-0.06185242 -0.10205346 -0.058328127 -0.096627166 MAarrowhead1
% End of user PostScript
0 1 .679 r
.48058 .46718 m
.48167 .46895 L
s
% Start of user PostScript
-0.038831992 -0.065645297 -0.036655007 -0.062090087 MAarrowhead1
% End of user PostScript
0 1 .995 r
.48774 .47902 m
.48842 .48016 L
s
% Start of user PostScript
-0.024523712 -0.041963525 -0.023160329 -0.039670538 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49223 .48663 m
.49266 .48736 L
s
% Start of user PostScript
-0.015533966 -0.026742666 -0.014674026 -0.025274962 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49507 .49149 m
.49534 .49196 L
s
% Start of user PostScript
-0.0098544623 -0.017016647 -0.0093100997 -0.016080697 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49687 .49459 m
.49704 .49489 L
s
% Start of user PostScript
-0.0062562193 -0.010819635 -0.0059109959 -0.010223887 MAarrowhead1
% End of user PostScript
.263 0 1 r
.172 0 m
.18425 .01539 L
.20307 .03966 L
.22065 .06292 L
.23711 .08518 L
.25252 .10646 L
.26695 .12677 L
.28049 .14615 L
.29318 .16462 L
.3051 .18222 L
.31629 .19896 L
.32681 .21488 L
.33669 .23001 L
.34598 .24439 L
.35472 .25804 L
.36295 .271 L
.37069 .28329 L
.37799 .29496 L
.38485 .30601 L
.39132 .31649 L
.39742 .32642 L
.40317 .33583 L
.40859 .34474 L
.41369 .35318 L
.41851 .36117 L
.42306 .36873 L
.42734 .37589 L
.43139 .38266 L
.4352 .38907 L
.4388 .39513 L
.4422 .40087 L
.44541 .40629 L
.44844 .41143 L
.4513 .41628 L
.454 .42087 L
.45654 .42521 L
.45895 .42931 L
.46122 .43319 L
.46337 .43686 L
.46539 .44033 L
.46731 .44361 L
.46912 .44671 L
.47082 .44964 L
.47243 .45241 L
.47396 .45502 L
.4754 .4575 L
.47675 .45984 L
.47804 .46205 L
.47925 .46414 L
.4804 .46611 L
Mistroke
.48148 .46797 L
.4825 .46974 L
.48347 .4714 L
.48438 .47298 L
.48524 .47447 L
.48605 .47587 L
.48682 .4772 L
.48755 .47846 L
.48824 .47964 L
.48889 .48077 L
.4895 .48183 L
.49008 .48283 L
.49063 .48377 L
.49114 .48467 L
.49163 .48551 L
.49209 .48631 L
.49253 .48706 L
.49294 .48778 L
.49333 .48845 L
.4937 .48909 L
.49404 .48969 L
.49437 .49026 L
.49468 .49079 L
.49498 .4913 L
.49525 .49178 L
.49552 .49223 L
.49576 .49266 L
.496 .49307 L
.49622 .49345 L
.49643 .49381 L
.49662 .49415 L
.49681 .49447 L
.49698 .49478 L
.49715 .49507 L
.49731 .49534 L
.49746 .49559 L
.4976 .49584 L
.49773 .49607 L
.49785 .49628 L
.49797 .49649 L
.49808 .49668 L
.49819 .49686 L
.49829 .49704 L
.49838 .4972 L
.49847 .49736 L
.49856 .4975 L
.49864 .49764 L
.49871 .49777 L
.49878 .49789 L
.49885 .49801 L
Mistroke
.49891 .49812 L
.49897 .49822 L
.49903 .49832 L
.49908 .49841 L
.49913 .4985 L
.49918 .49858 L
.49923 .49866 L
.49927 .49873 L
.49931 .4988 L
.49935 .49887 L
.49938 .49893 L
.49942 .49899 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
.49956 .49924 L
.49959 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .49939 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49976 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
Mistroke
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
Mfstroke
1 0 0 r
% Start of user PostScript
-7.9374295 0.34844938 -7.1809328 -0.22323892 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-6.5087206 -0.68965488 -5.9104615 -1.0664487 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-3.1650152 -2.1187014 -2.9144514 -2.1337317 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.7025474 -1.8801351 -1.5845167 -1.8183875 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-0.98372427 -1.3642336 -0.92181502 -1.3023462 MAarrowhead1
% End of user PostScript
.581 1 0 r
.20307 .03966 m
.22065 .06292 L
s
% Start of user PostScript
-0.59386767 -0.92068391 -0.55869078 -0.8741645 MAarrowhead1
% End of user PostScript
.266 1 0 r
.31629 .19896 m
.32681 .21488 L
s
% Start of user PostScript
-0.36741592 -0.60208709 -0.34638742 -0.57024342 MAarrowhead1
% End of user PostScript
0 1 .049 r
.38485 .30601 m
.39132 .31649 L
s
% Start of user PostScript
-0.23029119 -0.38797763 -0.21735063 -0.36701893 MAarrowhead1
% End of user PostScript
0 1 .364 r
.42734 .37589 m
.43139 .38266 L
s
% Start of user PostScript
-0.14531486 -0.24822947 -0.13722655 -0.23468247 MAarrowhead1
% End of user PostScript
0 1 .679 r
.454 .42087 m
.45654 .42521 L
s
% Start of user PostScript
-0.092007327 -0.15826083 -0.08691086 -0.14958042 MAarrowhead1
% End of user PostScript
0 1 .995 r
.47082 .44964 m
.47243 .45241 L
s
% Start of user PostScript
-0.058355346 -0.1007247 -0.055130809 -0.09518633 MAarrowhead1
% End of user PostScript
0 .69 1 r
.48148 .46797 m
.4825 .46974 L
s
% Start of user PostScript
-0.037043616 -0.064050292 -0.034999209 -0.060524111 MAarrowhead1
% End of user PostScript
0 .375 1 r
.48824 .47964 m
.48889 .48077 L
s
% Start of user PostScript
-0.023525224 -0.040711568 -0.022227684 -0.038468877 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49253 .48706 m
.49294 .48778 L
s
% Start of user PostScript
-0.014943355 -0.025871429 -0.014119404 -0.024445801 MAarrowhead1
% End of user PostScript
0 1 .723 r
.18779 0 m
.19191 .00582 L
.20978 .03152 L
.22655 .056 L
.2423 .07931 L
.25708 .1015 L
.27098 .12259 L
.28404 .14264 L
.29632 .16168 L
.30787 .17976 L
.31875 .19692 L
.32898 .2132 L
.33862 .22864 L
.3477 .24328 L
.35626 .25715 L
.36432 .2703 L
.37192 .28275 L
.37908 .29455 L
.38584 .30572 L
.39221 .31629 L
.39822 .3263 L
.40389 .33577 L
.40924 .34474 L
.41428 .35322 L
.41905 .36124 L
.42354 .36884 L
.42778 .37602 L
.43179 .38281 L
.43557 .38923 L
.43914 .3953 L
.44251 .40105 L
.44569 .40648 L
.4487 .41161 L
.45154 .41646 L
.45422 .42105 L
.45675 .42539 L
.45914 .42949 L
.4614 .43337 L
.46353 .43703 L
.46555 .4405 L
.46745 .44377 L
.46925 .44686 L
.47095 .44979 L
.47255 .45255 L
.47406 .45516 L
.4755 .45763 L
.47685 .45996 L
.47813 .46217 L
.47933 .46425 L
.48047 .46622 L
Mistroke
.48155 .46808 L
.48257 .46984 L
.48353 .4715 L
.48444 .47307 L
.4853 .47455 L
.48611 .47595 L
.48687 .47728 L
.4876 .47853 L
.48828 .47971 L
.48893 .48083 L
.48954 .48189 L
.49011 .48289 L
.49066 .48383 L
.49118 .48472 L
.49166 .48556 L
.49212 .48636 L
.49256 .48711 L
.49297 .48782 L
.49335 .48849 L
.49372 .48913 L
.49407 .48972 L
.49439 .49029 L
.4947 .49083 L
.49499 .49133 L
.49527 .49181 L
.49553 .49226 L
.49578 .49269 L
.49601 .49309 L
.49623 .49347 L
.49644 .49383 L
.49663 .49417 L
.49682 .49449 L
.497 .4948 L
.49716 .49508 L
.49732 .49535 L
.49747 .49561 L
.49761 .49585 L
.49774 .49608 L
.49786 .4963 L
.49798 .4965 L
.49809 .49669 L
.4982 .49688 L
.4983 .49705 L
.49839 .49721 L
.49848 .49736 L
.49856 .49751 L
.49864 .49765 L
.49872 .49778 L
.49879 .4979 L
.49885 .49802 L
Mistroke
.49892 .49812 L
.49898 .49823 L
.49903 .49833 L
.49909 .49842 L
.49914 .49851 L
.49918 .49859 L
.49923 .49867 L
.49927 .49874 L
.49931 .49881 L
.49935 .49887 L
.49939 .49894 L
.49942 .49899 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
.49956 .49924 L
.49959 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
Mistroke
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
Mfstroke
1 0 0 r
% Start of user PostScript
-8.5315584 -1.0501112 -7.7506735 -1.5302272 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-7.0543012 -1.912052 -6.4322466 -2.2105927 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-3.5370787 -2.8512927 -3.2680012 -2.8224865 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.9470172 -2.3315839 -1.816145 -2.2438539 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-1.1416148 -1.6466103 -1.0712038 -1.568809 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-0.69499846 -1.0986765 -0.65431112 -1.042235 MAarrowhead1
% End of user PostScript
.266 1 0 r
.28404 .14264 m
.29632 .16168 L
s
% Start of user PostScript
-0.43192802 -0.7147243 -0.40736388 -0.67663669 MAarrowhead1
% End of user PostScript
0 1 .049 r
.36432 .2703 m
.37192 .28275 L
s
% Start of user PostScript
-0.27136093 -0.45939818 -0.25616302 -0.43449149 MAarrowhead1
% End of user PostScript
0 1 .364 r
.41428 .35322 m
.41905 .36124 L
s
% Start of user PostScript
-0.17143443 -0.29356068 -0.16190843 -0.2775114 MAarrowhead1
% End of user PostScript
0 1 .679 r
.44569 .40648 m
.4487 .41161 L
s
% Start of user PostScript
-0.10861054 -0.18704729 -0.10259954 -0.176779 MAarrowhead1
% End of user PostScript
0 1 .995 r
.46555 .4405 m
.46745 .44377 L
s
% Start of user PostScript
-0.068906733 -0.11900941 -0.065100798 -0.1124628 MAarrowhead1
% End of user PostScript
0 .69 1 r
.47813 .46217 m
.47933 .46425 L
s
% Start of user PostScript
-0.043748209 -0.075665901 -0.041334302 -0.071499339 MAarrowhead1
% End of user PostScript
0 .375 1 r
.48611 .47595 m
.48687 .47728 L
s
% Start of user PostScript
-0.027785209 -0.048091005 -0.026252874 -0.045441513 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49118 .48472 m
.49166 .48556 L
s
% Start of user PostScript
-0.017649993 -0.030559757 -0.016676855 -0.028875691 MAarrowhead1
% End of user PostScript
.734 1 0 r
.20571 0 m
.21622 .01735 L
.23206 .0436 L
.247 .06846 L
.2611 .09198 L
.2744 .11425 L
.28695 .13532 L
.29879 .15525 L
.30996 .1741 L
.32051 .19194 L
.33047 .20881 L
.33987 .22476 L
.34874 .23985 L
.35712 .25412 L
.36504 .26761 L
.37251 .28037 L
.37956 .29243 L
.38622 .30383 L
.39251 .31461 L
.39846 .32479 L
.40407 .33443 L
.40937 .34353 L
.41438 .35213 L
.41911 .36027 L
.42357 .36796 L
.42779 .37522 L
.43178 .38209 L
.43555 .38858 L
.4391 .39471 L
.44247 .40051 L
.44564 .40599 L
.44864 .41116 L
.45147 .41605 L
.45415 .42068 L
.45668 .42505 L
.45907 .42917 L
.46133 .43308 L
.46346 .43676 L
.46548 .44025 L
.46738 .44354 L
.46918 .44665 L
.47088 .44959 L
.47248 .45237 L
.474 .45499 L
.47544 .45747 L
.47679 .45981 L
.47807 .46203 L
.47928 .46412 L
.48042 .4661 L
.4815 .46797 L
Mistroke
.48252 .46973 L
.48348 .4714 L
.48439 .47298 L
.48525 .47447 L
.48607 .47587 L
.48684 .4772 L
.48756 .47846 L
.48825 .47965 L
.4889 .48077 L
.48951 .48183 L
.49009 .48283 L
.49063 .48378 L
.49115 .48467 L
.49164 .48552 L
.4921 .48631 L
.49253 .48707 L
.49294 .48778 L
.49333 .48845 L
.4937 .48909 L
.49405 .48969 L
.49438 .49026 L
.49469 .4908 L
.49498 .4913 L
.49526 .49178 L
.49552 .49224 L
.49576 .49266 L
.496 .49307 L
.49622 .49345 L
.49643 .49381 L
.49662 .49415 L
.49681 .49448 L
.49699 .49478 L
.49715 .49507 L
.49731 .49534 L
.49746 .4956 L
.4976 .49584 L
.49773 .49607 L
.49786 .49629 L
.49797 .49649 L
.49809 .49668 L
.49819 .49687 L
.49829 .49704 L
.49838 .4972 L
.49847 .49736 L
.49856 .4975 L
.49864 .49764 L
.49871 .49777 L
.49878 .49789 L
.49885 .49801 L
.49891 .49812 L
Mistroke
.49897 .49822 L
.49903 .49832 L
.49908 .49841 L
.49913 .4985 L
.49918 .49858 L
.49923 .49866 L
.49927 .49873 L
.49931 .4988 L
.49935 .49887 L
.49938 .49893 L
.49942 .49899 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
.49956 .49924 L
.49959 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .49939 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49977 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
Mistroke
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
Mfstroke
1 0 0 r
% Start of user PostScript
-4.5355889 -5.537346 -4.2331177 -5.3229899 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-3.9543234 -5.1083176 -3.6969657 -4.8949662 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.3527694 -3.5219417 -2.2105645 -3.3494881 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.4441046 -2.3254772 -1.3605259 -2.2041833 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-0.90138718 -1.5053881 -0.85043754 -1.4245985 MAarrowhead1
% End of user PostScript
.581 1 0 r
.21622 .01735 m
.23206 .0436 L
s
% Start of user PostScript
-0.56756935 -0.96530794 -0.53588252 -0.91279461 MAarrowhead1
% End of user PostScript
.266 1 0 r
.32051 .19194 m
.33047 .20881 L
s
% Start of user PostScript
-0.35897407 -0.61612048 -0.3390593 -0.58238019 MAarrowhead1
% End of user PostScript
0 1 .049 r
.38622 .30383 m
.39251 .31461 L
s
% Start of user PostScript
-0.22755464 -0.39234368 -0.21497097 -0.37078743 MAarrowhead1
% End of user PostScript
0 1 .364 r
.42779 .37522 m
.43178 .38209 L
s
% Start of user PostScript
-0.14441098 -0.24955754 -0.13643797 -0.23582393 MAarrowhead1
% End of user PostScript
0 1 .679 r
.45415 .42068 m
.45668 .42505 L
s
% Start of user PostScript
-0.091698327 -0.15864515 -0.086639699 -0.14990752 MAarrowhead1
% End of user PostScript
0 1 .995 r
.47088 .44959 m
.47248 .45237 L
s
% Start of user PostScript
-0.058243321 -0.10082287 -0.055031572 -0.095267637 MAarrowhead1
% End of user PostScript
0 .69 1 r
.4815 .46797 m
.48252 .46973 L
s
% Start of user PostScript
-0.036999229 -0.064066266 -0.03495937 -0.060535566 MAarrowhead1
% End of user PostScript
0 .375 1 r
.48825 .47965 m
.4889 .48077 L
s
% Start of user PostScript
-0.023505536 -0.040706974 -0.022209748 -0.03846338 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49253 .48707 m
.49294 .48778 L
s
% Start of user PostScript
-0.014933552 -0.025863824 -0.014110353 -0.024438249 MAarrowhead1
% End of user PostScript
0 .488 1 r
.84869 1 m
.84515 .99628 L
.82383 .9729 L
.80399 .95028 L
.78551 .92845 L
.76827 .90742 L
.75219 .88721 L
.73717 .86781 L
.72312 .84922 L
.70998 .83143 L
.69768 .81443 L
.68615 .79819 L
.67534 .7827 L
.6652 .76794 L
.65568 .75389 L
.64674 .74051 L
.63835 .72779 L
.63045 .7157 L
.62303 .70421 L
.61605 .6933 L
.60948 .68295 L
.60329 .67312 L
.59747 .66381 L
.59198 .65497 L
.58681 .6466 L
.58194 .63867 L
.57735 .63115 L
.57302 .62403 L
.56894 .61729 L
.5651 .61091 L
.56147 .60487 L
.55804 .59915 L
.55481 .59374 L
.55176 .58862 L
.54889 .58378 L
.54617 .57919 L
.54361 .57486 L
.54119 .57076 L
.53891 .56688 L
.53675 .56321 L
.53471 .55975 L
.53279 .55647 L
.53098 .55337 L
.52926 .55044 L
.52764 .54767 L
.52612 .54505 L
.52467 .54257 L
.52331 .54023 L
.52202 .53802 L
.5208 .53593 L
Mistroke
.51965 .53395 L
.51857 .53208 L
.51754 .53032 L
.51658 .52865 L
.51566 .52707 L
.5148 .52558 L
.51398 .52417 L
.51321 .52284 L
.51248 .52159 L
.51179 .5204 L
.51114 .51927 L
.51053 .51821 L
.50995 .51721 L
.5094 .51626 L
.50888 .51537 L
.50839 .51452 L
.50793 .51372 L
.50749 .51296 L
.50708 .51225 L
.50669 .51157 L
.50632 .51094 L
.50597 .51033 L
.50564 .50976 L
.50533 .50923 L
.50503 .50872 L
.50476 .50824 L
.5045 .50778 L
.50425 .50735 L
.50401 .50695 L
.50379 .50657 L
.50358 .5062 L
.50339 .50586 L
.5032 .50554 L
.50302 .50523 L
.50286 .50495 L
.5027 .50467 L
.50255 .50442 L
.50241 .50417 L
.50228 .50394 L
.50215 .50372 L
.50203 .50352 L
.50192 .50333 L
.50181 .50314 L
.50171 .50297 L
.50162 .50281 L
.50153 .50265 L
.50145 .5025 L
.50137 .50237 L
.50129 .50224 L
.50122 .50211 L
Mistroke
.50115 .502 L
.50109 .50189 L
.50103 .50178 L
.50097 .50168 L
.50092 .50159 L
.50087 .5015 L
.50082 .50142 L
.50078 .50134 L
.50073 .50127 L
.50069 .5012 L
.50065 .50113 L
.50062 .50107 L
.50058 .50101 L
.50055 .50096 L
.50052 .5009 L
.50049 .50085 L
.50047 .50081 L
.50044 .50076 L
.50042 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .50061 L
.50033 .50057 L
.50031 .50054 L
.5003 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50039 L
.50021 .50036 L
.5002 .50034 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50025 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50018 L
.5001 .50017 L
.5001 .50016 L
.50009 .50016 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
Mistroke
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
Mfstroke
1 0 0 r
% Start of user PostScript
7.0104931 -0.81379936 6.3308896 -0.26114614 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
5.7278879 0.19324985 5.1920398 0.56385568 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.7473947 1.6673889 2.5260061 1.6966347 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.4621528 1.5502032 1.3593291 1.5032538 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
0.83891583 1.1408877 0.78561019 1.0902348 MAarrowhead1
% End of user PostScript
.581 1 0 r
.75219 .88721 m
.73717 .86781 L
s
% Start of user PostScript
0.50438286 0.77442085 0.47433601 0.73562153 MAarrowhead1
% End of user PostScript
.266 1 0 r
.65568 .75389 m
.64674 .74051 L
s
% Start of user PostScript
0.31136258 0.50777379 0.29348659 0.48102007 MAarrowhead1
% End of user PostScript
0 1 .049 r
.59747 .66381 m
.59198 .65497 L
s
% Start of user PostScript
0.19493237 0.32761585 0.18396078 0.30994983 MAarrowhead1
% End of user PostScript
0 1 .364 r
.56147 .60487 m
.55804 .59915 L
s
% Start of user PostScript
0.12293068 0.20973905 0.11608255 0.19830272 MAarrowhead1
% End of user PostScript
0 1 .679 r
.53891 .56688 m
.53675 .56321 L
s
% Start of user PostScript
0.077811371 0.13376173 0.073499418 0.12642825 MAarrowhead1
% End of user PostScript
0 1 .995 r
.52467 .54257 m
.52331 .54023 L
s
% Start of user PostScript
0.049344201 0.085145226 0.046617011 0.080464508 MAarrowhead1
% End of user PostScript
0 .69 1 r
.51566 .52707 m
.5148 .52558 L
s
% Start of user PostScript
0.031321039 0.054147486 0.029592271 0.051166809 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50995 .51721 m
.5094 .51626 L
s
% Start of user PostScript
0.019890247 0.03441846 0.018793136 0.032522541 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50632 .51094 m
.50597 .51033 L
s
% Start of user PostScript
0.012634159 0.021872691 0.011937514 0.020667444 MAarrowhead1
% End of user PostScript
1 0 .586 r
1 .768 m
.97678 .77364 L
.938 .7802 L
.90303 .78351 L
.87144 .78413 L
.84283 .78254 L
.81689 .77917 L
.79332 .77435 L
.77187 .76839 L
.7523 .76153 L
.73442 .75399 L
.71806 .74595 L
.70306 .73756 L
.68928 .72894 L
.67661 .72019 L
.66494 .71142 L
.65416 .70267 L
.64421 .69402 L
.635 .68551 L
.62647 .67718 L
.61855 .66906 L
.61119 .66116 L
.60435 .65351 L
.59798 .64611 L
.59205 .63898 L
.58651 .63212 L
.58134 .62554 L
.57651 .61922 L
.57199 .61317 L
.56776 .60738 L
.5638 .60185 L
.56009 .59658 L
.55661 .59155 L
.55334 .58676 L
.55027 .5822 L
.54739 .57786 L
.54468 .57373 L
.54214 .56981 L
.53974 .56609 L
.53749 .56255 L
.53537 .5592 L
.53337 .55602 L
.53149 .553 L
.52972 .55014 L
.52805 .54743 L
.52648 .54486 L
.525 .54242 L
.5236 .54012 L
.52228 .53794 L
.52104 .53587 L
Mistroke
.51987 .53392 L
.51876 .53207 L
.51772 .53032 L
.51673 .52866 L
.5158 .52709 L
.51493 .52561 L
.5141 .52421 L
.51332 .52288 L
.51258 .52163 L
.51188 .52044 L
.51122 .51932 L
.5106 .51826 L
.51001 .51726 L
.50946 .51631 L
.50894 .51541 L
.50844 .51457 L
.50798 .51377 L
.50754 .51301 L
.50712 .51229 L
.50673 .51162 L
.50635 .51098 L
.506 .51037 L
.50567 .5098 L
.50536 .50926 L
.50506 .50875 L
.50478 .50827 L
.50452 .50782 L
.50427 .50739 L
.50403 .50698 L
.50381 .5066 L
.5036 .50623 L
.5034 .50589 L
.50322 .50556 L
.50304 .50526 L
.50287 .50497 L
.50271 .50469 L
.50256 .50444 L
.50242 .50419 L
.50229 .50396 L
.50216 .50374 L
.50204 .50354 L
.50193 .50334 L
.50182 .50316 L
.50172 .50298 L
.50163 .50282 L
.50154 .50266 L
.50145 .50252 L
.50137 .50238 L
.5013 .50225 L
.50123 .50212 L
Mistroke
.50116 .50201 L
.50109 .5019 L
.50103 .50179 L
.50098 .50169 L
.50092 .5016 L
.50087 .50151 L
.50082 .50143 L
.50078 .50135 L
.50074 .50127 L
.5007 .5012 L
.50066 .50114 L
.50062 .50108 L
.50059 .50102 L
.50055 .50096 L
.50052 .50091 L
.50049 .50086 L
.50047 .50081 L
.50044 .50077 L
.50042 .50072 L
.50039 .50068 L
.50037 .50065 L
.50035 .50061 L
.50033 .50058 L
.50031 .50054 L
.5003 .50051 L
.50028 .50049 L
.50027 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
Mistroke
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
Mfstroke
1 0 0 r
% Start of user PostScript
9.6686597 -9.0918639 8.5510374 -7.5780249 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
7.5730778 -6.2828311 6.7166614 -5.1761802 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.0330495 -0.91138082 2.7263672 -0.61952912 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.3618783 0.39982757 1.2424812 0.45456793 MAarrowhead1
% End of user PostScript
.897 1 0 r
.84283 .78254 m
.81689 .77917 L
s
% Start of user PostScript
0.68566966 0.56508777 0.6337881 0.558338 MAarrowhead1
% End of user PostScript
.581 1 0 r
.68928 .72894 m
.67661 .72019 L
s
% Start of user PostScript
0.37856612 0.45787196 0.3532227 0.44038674 MAarrowhead1
% End of user PostScript
.266 1 0 r
.61119 .66116 m
.60435 .65351 L
s
% Start of user PostScript
0.22238415 0.3223171 0.20870357 0.30701436 MAarrowhead1
% End of user PostScript
0 1 .049 r
.56776 .60738 m
.5638 .60185 L
s
% Start of user PostScript
0.13552733 0.21476372 0.12760486 0.2037086 MAarrowhead1
% End of user PostScript
0 1 .364 r
.54214 .56981 m
.53974 .56609 L
s
% Start of user PostScript
0.084275052 0.13962063 0.079486058 0.13217336 MAarrowhead1
% End of user PostScript
0 1 .679 r
.52648 .54486 m
.525 .54242 L
s
% Start of user PostScript
0.052961638 0.089714996 0.049996677 0.084848849 MAarrowhead1
% End of user PostScript
0 1 .995 r
.51673 .52866 m
.5158 .52709 L
s
% Start of user PostScript
0.033463891 0.057320126 0.031604812 0.05418569 MAarrowhead1
% End of user PostScript
0 .69 1 r
.5106 .51826 m
.51001 .51726 L
s
% Start of user PostScript
0.021202292 0.036519742 0.020028984 0.03451471 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50673 .51162 m
.50635 .51098 L
s
% Start of user PostScript
0.013452059 0.023234918 0.012709099 0.021956716 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50427 .50739 m
.50403 .50698 L
s
% Start of user PostScript
0.008540741 0.014772427 0.0080694987 0.013958958 MAarrowhead1
% End of user PostScript
1 .624 0 r
.06973 0 m
.07191 .0012 L
.101 .01918 L
.12775 .03745 L
.15239 .0558 L
.17512 .0741 L
.19613 .09221 L
.21556 .11005 L
.23356 .12751 L
.25026 .14456 L
.26577 .16113 L
.2802 .17719 L
.29362 .19271 L
.30613 .20768 L
.3178 .22209 L
.3287 .23594 L
.33888 .24921 L
.3484 .26193 L
.35731 .27409 L
.36566 .28571 L
.37348 .2968 L
.38081 .30738 L
.3877 .31745 L
.39416 .32705 L
.40023 .33617 L
.40593 .34485 L
.41129 .3531 L
.41633 .36093 L
.42108 .36837 L
.42554 .37542 L
.42975 .38212 L
.4337 .38847 L
.43743 .39449 L
.44095 .40019 L
.44426 .4056 L
.44738 .41072 L
.45032 .41556 L
.4531 .42015 L
.45571 .4245 L
.45818 .42862 L
.46051 .43251 L
.46271 .43619 L
.46478 .43968 L
.46674 .44298 L
.46858 .4461 L
.47033 .44905 L
.47197 .45184 L
.47353 .45448 L
.47499 .45698 L
.47638 .45934 L
Mistroke
.47769 .46157 L
.47892 .46368 L
.48009 .46567 L
.48119 .46756 L
.48223 .46934 L
.48321 .47103 L
.48414 .47262 L
.48502 .47412 L
.48584 .47555 L
.48662 .47689 L
.48736 .47816 L
.48806 .47937 L
.48872 .4805 L
.48934 .48158 L
.48993 .48259 L
.49049 .48355 L
.49101 .48445 L
.49151 .48531 L
.49198 .48612 L
.49242 .48688 L
.49284 .48761 L
.49323 .48829 L
.49361 .48893 L
.49396 .48954 L
.49429 .49012 L
.49461 .49066 L
.4949 .49118 L
.49518 .49166 L
.49545 .49212 L
.4957 .49256 L
.49594 .49297 L
.49616 .49336 L
.49637 .49372 L
.49657 .49407 L
.49676 .49439 L
.49694 .4947 L
.49711 .495 L
.49727 .49527 L
.49742 .49553 L
.49756 .49578 L
.4977 .49601 L
.49782 .49623 L
.49794 .49644 L
.49806 .49663 L
.49816 .49682 L
.49826 .497 L
.49836 .49716 L
.49845 .49732 L
.49854 .49747 L
.49862 .4976 L
Mistroke
.49869 .49774 L
.49877 .49786 L
.49883 .49798 L
.4989 .49809 L
.49896 .4982 L
.49902 .4983 L
.49907 .49839 L
.49912 .49848 L
.49917 .49856 L
.49922 .49864 L
.49926 .49872 L
.4993 .49879 L
.49934 .49885 L
.49937 .49892 L
.49941 .49898 L
.49944 .49903 L
.49947 .49909 L
.4995 .49914 L
.49953 .49918 L
.49956 .49923 L
.49958 .49927 L
.4996 .49931 L
.49962 .49935 L
.49965 .49939 L
.49966 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
Mistroke
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
Mfstroke
1 0 0 r
% Start of user PostScript
-8.9426626 4.6556202 -7.9938954 3.6094655 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-7.1582829 2.726384 -6.4214628 1.9833144 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-3.1614085 -0.66939975 -2.8783901 -0.82087498 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.5679654 -1.1884649 -1.4469766 -1.1828156 MAarrowhead1
% End of user PostScript
.897 1 0 r
.07191 .0012 m
.101 .01918 L
s
% Start of user PostScript
-0.85617985 -0.99759871 -0.79800363 -0.96163195 MAarrowhead1
% End of user PostScript
.581 1 0 r
.25026 .14456 m
.26577 .16113 L
s
% Start of user PostScript
-0.49947433 -0.71088312 -0.46845269 -0.6777431 MAarrowhead1
% End of user PostScript
.266 1 0 r
.3484 .26193 m
.35731 .27409 L
s
% Start of user PostScript
-0.30319862 -0.47614433 -0.28537689 -0.45181952 MAarrowhead1
% End of user PostScript
0 1 .049 r
.40593 .34485 m
.41129 .3531 L
s
% Start of user PostScript
-0.18814217 -0.31029727 -0.1774191 -0.29380369 MAarrowhead1
% End of user PostScript
0 1 .364 r
.44095 .40019 m
.44426 .4056 L
s
% Start of user PostScript
-0.11810708 -0.19961827 -0.11148487 -0.18880902 MAarrowhead1
% End of user PostScript
0 1 .679 r
.46271 .43619 m
.46478 .43968 L
s
% Start of user PostScript
-0.074584827 -0.12761198 -0.070438026 -0.12063948 MAarrowhead1
% End of user PostScript
0 1 .995 r
.47638 .45934 m
.47769 .46157 L
s
% Start of user PostScript
-0.04724279 -0.081327135 -0.044627396 -0.076863865 MAarrowhead1
% End of user PostScript
0 .69 1 r
.48502 .47412 m
.48584 .47555 L
s
% Start of user PostScript
-0.029969572 -0.051750005 -0.028314016 -0.048903701 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49049 .48355 m
.49101 .48445 L
s
% Start of user PostScript
-0.019026407 -0.032904235 -0.017976504 -0.031092488 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49396 .48954 m
.49429 .49012 L
s
% Start of user PostScript
-0.012083673 -0.020913498 -0.011417242 -0.019761347 MAarrowhead1
% End of user PostScript
1 .118 0 r
.79542 1 m
.78534 .98353 L
.76937 .9573 L
.75432 .93246 L
.74012 .90893 L
.72672 .88667 L
.71409 .86559 L
.70217 .84564 L
.69092 .82677 L
.68031 .80891 L
.67029 .79201 L
.66084 .77603 L
.65192 .76092 L
.64349 .74662 L
.63554 .7331 L
.62803 .72032 L
.62094 .70823 L
.61425 .6968 L
.60793 .686 L
.60196 .67578 L
.59632 .66612 L
.59099 .65699 L
.58596 .64836 L
.58121 .64021 L
.57673 .6325 L
.57249 .62521 L
.56848 .61832 L
.5647 .61181 L
.56113 .60566 L
.55776 .59984 L
.55457 .59435 L
.55156 .58915 L
.54871 .58424 L
.54602 .57961 L
.54348 .57522 L
.54108 .57108 L
.53882 .56716 L
.53668 .56346 L
.53465 .55997 L
.53274 .55667 L
.53094 .55354 L
.52923 .55059 L
.52762 .54781 L
.5261 .54517 L
.52466 .54268 L
.5233 .54033 L
.52201 .53811 L
.5208 .53601 L
.51965 .53402 L
.51857 .53215 L
Mistroke
.51754 .53038 L
.51658 .5287 L
.51566 .52712 L
.5148 .52563 L
.51398 .52422 L
.51321 .52288 L
.51248 .52162 L
.5118 .52043 L
.51115 .5193 L
.51053 .51824 L
.50995 .51723 L
.5094 .51628 L
.50888 .51539 L
.50839 .51454 L
.50793 .51374 L
.50749 .51298 L
.50708 .51226 L
.50669 .51159 L
.50632 .51095 L
.50597 .51035 L
.50564 .50978 L
.50533 .50924 L
.50504 .50873 L
.50476 .50825 L
.5045 .50779 L
.50425 .50736 L
.50402 .50696 L
.5038 .50657 L
.50359 .50621 L
.50339 .50587 L
.5032 .50555 L
.50303 .50524 L
.50286 .50495 L
.5027 .50468 L
.50255 .50442 L
.50241 .50418 L
.50228 .50395 L
.50215 .50373 L
.50203 .50352 L
.50192 .50333 L
.50182 .50315 L
.50172 .50297 L
.50162 .50281 L
.50153 .50265 L
.50145 .50251 L
.50137 .50237 L
.50129 .50224 L
.50122 .50211 L
.50115 .502 L
.50109 .50189 L
Mistroke
.50103 .50178 L
.50097 .50169 L
.50092 .50159 L
.50087 .50151 L
.50082 .50142 L
.50078 .50134 L
.50073 .50127 L
.50069 .5012 L
.50065 .50113 L
.50062 .50107 L
.50058 .50101 L
.50055 .50096 L
.50052 .5009 L
.50049 .50085 L
.50047 .50081 L
.50044 .50076 L
.50042 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .50061 L
.50033 .50057 L
.50031 .50054 L
.5003 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50039 L
.50021 .50036 L
.5002 .50034 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50025 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50018 L
.5001 .50017 L
.5001 .50016 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
Mfstroke
1 0 0 r
% Start of user PostScript
7.9702659 6.1866147 7.3585477 6.144183 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
6.803563 6.0642273 6.299112 5.9541379 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.7982333 4.7610923 3.5477401 4.5698932 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
2.2465517 3.31354 2.1096489 3.1535312 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
1.3743805 2.1969492 1.2944695 2.0830443 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
0.85637687 1.4249613 0.80785244 1.3487016 MAarrowhead1
% End of user PostScript
.266 1 0 r
.76937 .9573 m
.75432 .93246 L
s
% Start of user PostScript
0.53874623 0.91460096 0.50863042 0.8649134 MAarrowhead1
% End of user PostScript
0 1 .049 r
.67029 .79201 m
.66084 .77603 L
s
% Start of user PostScript
0.34058963 0.58402861 0.3216826 0.55206703 MAarrowhead1
% End of user PostScript
0 1 .364 r
.60793 .686 m
.60196 .67578 L
s
% Start of user PostScript
0.21585138 0.37199387 0.20391101 0.35156244 MAarrowhead1
% End of user PostScript
0 1 .679 r
.56848 .61832 m
.5647 .61181 L
s
% Start of user PostScript
0.13696814 0.236641 0.12940481 0.22362035 MAarrowhead1
% End of user PostScript
0 1 .995 r
.54348 .57522 m
.54108 .57108 L
s
% Start of user PostScript
0.086967258 0.15044271 0.082169232 0.14215751 MAarrowhead1
% End of user PostScript
0 .69 1 r
.52762 .54781 m
.5261 .54517 L
s
% Start of user PostScript
0.055236736 0.095612772 0.052190656 0.090344825 MAarrowhead1
% End of user PostScript
0 .375 1 r
.51754 .53038 m
.51658 .5287 L
s
% Start of user PostScript
0.035088783 0.060756468 0.033154211 0.05740824 MAarrowhead1
% End of user PostScript
0 .06 1 r
.51115 .5193 m
.51053 .51824 L
s
% Start of user PostScript
0.022291672 0.038604244 0.021062789 0.036476565 MAarrowhead1
% End of user PostScript
.805 0 1 r
1 .80314 m
.97514 .80715 L
.93728 .81044 L
.90306 .81084 L
.87208 .80889 L
.84398 .80501 L
.81844 .7996 L
.79518 .79296 L
.77397 .78536 L
.75459 .77705 L
.73685 .7682 L
.72058 .75899 L
.70564 .74953 L
.69189 .73996 L
.67922 .73035 L
.66753 .72079 L
.65672 .71134 L
.64673 .70205 L
.63746 .69295 L
.62886 .68409 L
.62087 .67547 L
.61344 .66713 L
.60653 .65907 L
.60008 .6513 L
.59406 .64382 L
.58845 .63664 L
.5832 .62976 L
.57829 .62317 L
.57369 .61687 L
.56938 .61085 L
.56535 .6051 L
.56156 .59962 L
.55801 .59441 L
.55468 .58944 L
.55154 .58472 L
.5486 .58023 L
.54583 .57596 L
.54323 .57191 L
.54078 .56806 L
.53847 .56441 L
.5363 .56095 L
.53426 .55766 L
.53233 .55455 L
.53052 .5516 L
.5288 .5488 L
.52719 .54616 L
.52567 .54365 L
.52424 .54127 L
.52289 .53903 L
.52161 .5369 L
Mistroke
.52041 .53489 L
.51927 .53298 L
.5182 .53118 L
.51719 .52947 L
.51624 .52786 L
.51533 .52634 L
.51448 .52489 L
.51368 .52353 L
.51292 .52224 L
.51221 .52102 L
.51153 .51986 L
.51089 .51877 L
.51029 .51774 L
.50972 .51677 L
.50918 .51585 L
.50868 .51498 L
.5082 .51415 L
.50774 .51337 L
.50732 .51264 L
.50691 .51194 L
.50653 .51129 L
.50617 .51066 L
.50583 .51008 L
.50551 .50952 L
.5052 .509 L
.50492 .5085 L
.50465 .50804 L
.50439 .50759 L
.50415 .50717 L
.50392 .50678 L
.5037 .50641 L
.5035 .50605 L
.5033 .50572 L
.50312 .5054 L
.50295 .50511 L
.50279 .50483 L
.50263 .50456 L
.50249 .50431 L
.50235 .50407 L
.50222 .50385 L
.5021 .50363 L
.50198 .50343 L
.50187 .50325 L
.50177 .50307 L
.50167 .5029 L
.50158 .50274 L
.50149 .50259 L
.50141 .50244 L
.50133 .50231 L
.50126 .50218 L
Mistroke
.50119 .50206 L
.50113 .50195 L
.50106 .50184 L
.501 .50174 L
.50095 .50164 L
.5009 .50155 L
.50085 .50147 L
.5008 .50139 L
.50076 .50131 L
.50071 .50124 L
.50068 .50117 L
.50064 .50111 L
.5006 .50104 L
.50057 .50099 L
.50054 .50093 L
.50051 .50088 L
.50048 .50083 L
.50045 .50079 L
.50043 .50074 L
.50041 .5007 L
.50038 .50066 L
.50036 .50063 L
.50034 .50059 L
.50032 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.50019 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
Mistroke
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
Mfstroke
1 0 0 r
% Start of user PostScript
7.2594617 -5.5489831 6.4492292 -4.532834 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
5.7384066 -3.667524 5.1142048 -2.9320784 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.3984752 -0.16960621 2.1684271 0.0092081794 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.1274674 0.57880545 1.0342284 0.60075291 MAarrowhead1
% End of user PostScript
.897 1 0 r
.79518 .79296 m
.77397 .78536 L
s
% Start of user PostScript
0.59036652 0.58591324 0.54794464 0.57072977 MAarrowhead1
% End of user PostScript
.581 1 0 r
.66753 .72079 m
.65672 .71134 L
s
% Start of user PostScript
0.33505767 0.4415861 0.3134492 0.42268333 MAarrowhead1
% End of user PostScript
.266 1 0 r
.60008 .6513 m
.59406 .64382 L
s
% Start of user PostScript
0.2001568 0.30259015 0.18812619 0.28763906 MAarrowhead1
% End of user PostScript
0 1 .049 r
.56156 .59962 m
.55801 .59441 L
s
% Start of user PostScript
0.12312623 0.19924965 0.1160223 0.18881589 MAarrowhead1
% End of user PostScript
0 1 .364 r
.53847 .56441 m
.5363 .56095 L
s
% Start of user PostScript
0.076942957 0.12881668 0.072601011 0.12189064 MAarrowhead1
% End of user PostScript
0 1 .679 r
.52424 .54127 m
.52289 .53903 L
s
% Start of user PostScript
0.048477019 0.082549787 0.045772886 0.078054988 MAarrowhead1
% End of user PostScript
0 1 .995 r
.51533 .52634 m
.51448 .52489 L
s
% Start of user PostScript
0.030669841 0.052672111 0.028969105 0.049786377 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50972 .51677 m
.50918 .51585 L
s
% Start of user PostScript
0.019444659 0.033536262 0.018369611 0.031693299 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50617 .51066 m
.50583 .51008 L
s
% Start of user PostScript
0.012340936 0.021329725 0.01165966 0.020155782 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50392 .50678 m
.5037 .50641 L
s
% Start of user PostScript
0.0078365682 0.013558907 0.0074042798 0.012812087 MAarrowhead1
% End of user PostScript
1 .225 0 r
.80083 1 m
.79084 .9844 L
.77437 .95845 L
.75887 .93384 L
.74427 .9105 L
.73052 .88836 L
.71757 .86738 L
.70536 .8475 L
.69386 .82867 L
.68301 .81083 L
.67278 .79394 L
.66314 .77795 L
.65404 .76281 L
.64546 .74848 L
.63736 .73492 L
.62972 .72208 L
.62251 .70995 L
.61571 .69846 L
.60929 .6876 L
.60323 .67732 L
.5975 .66761 L
.5921 .65842 L
.587 .64973 L
.58218 .64151 L
.57763 .63375 L
.57334 .6264 L
.56928 .61946 L
.56545 .61289 L
.56183 .60669 L
.55841 .60083 L
.55519 .59528 L
.55214 .59004 L
.54926 .58509 L
.54654 .58041 L
.54397 .57598 L
.54154 .5718 L
.53925 .56785 L
.53708 .56411 L
.53503 .56058 L
.5331 .55725 L
.53127 .5541 L
.52955 .55112 L
.52792 .5483 L
.52638 .54564 L
.52492 .54313 L
.52355 .54075 L
.52225 .53851 L
.52102 .53639 L
.51986 .53438 L
.51877 .53249 L
Mistroke
.51773 .5307 L
.51676 .52901 L
.51583 .52741 L
.51496 .5259 L
.51413 .52447 L
.51335 .52312 L
.51262 .52185 L
.51192 .52064 L
.51126 .51951 L
.51064 .51843 L
.51006 .51742 L
.5095 .51646 L
.50898 .51555 L
.50848 .51469 L
.50802 .51388 L
.50757 .51312 L
.50716 .51239 L
.50676 .51171 L
.50639 .51107 L
.50604 .51046 L
.5057 .50988 L
.50539 .50933 L
.50509 .50882 L
.50481 .50833 L
.50455 .50787 L
.5043 .50744 L
.50406 .50703 L
.50384 .50664 L
.50362 .50628 L
.50342 .50593 L
.50324 .5056 L
.50306 .5053 L
.50289 .505 L
.50273 .50473 L
.50258 .50447 L
.50244 .50422 L
.5023 .50399 L
.50218 .50377 L
.50206 .50356 L
.50194 .50336 L
.50184 .50318 L
.50173 .503 L
.50164 .50284 L
.50155 .50268 L
.50146 .50253 L
.50138 .50239 L
.50131 .50226 L
.50123 .50214 L
.50117 .50202 L
.5011 .50191 L
Mistroke
.50104 .5018 L
.50098 .5017 L
.50093 .50161 L
.50088 .50152 L
.50083 .50144 L
.50078 .50136 L
.50074 .50128 L
.5007 .50121 L
.50066 .50115 L
.50062 .50108 L
.50059 .50102 L
.50056 .50097 L
.50053 .50091 L
.5005 .50086 L
.50047 .50082 L
.50044 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50035 .50061 L
.50033 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
Mfstroke
1 0 0 r
% Start of user PostScript
3.9487298 3.9891547 3.6665753 3.8809766 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
3.4085841 3.7638473 3.1722747 3.6402516 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.9694394 2.7311316 1.8454934 2.6072406 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.1889283 1.8431851 1.1185032 1.7500558 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
0.73556696 1.2053683 0.69346766 1.1416182 MAarrowhead1
% End of user PostScript
.581 1 0 r
.73052 .88836 m
.71757 .86738 L
s
% Start of user PostScript
0.46104218 0.7767265 0.43513514 0.73476759 MAarrowhead1
% End of user PostScript
.266 1 0 r
.64546 .74848 m
.63736 .73492 L
s
% Start of user PostScript
0.29091954 0.49695294 0.27472676 0.46983202 MAarrowhead1
% End of user PostScript
0 1 .049 r
.5921 .65842 m
.587 .64973 L
s
% Start of user PostScript
0.18419806 0.31683679 0.17399496 0.2994587 MAarrowhead1
% End of user PostScript
0 1 .364 r
.55841 .60083 m
.55519 .59528 L
s
% Start of user PostScript
0.11682699 0.20165002 0.11037148 0.19056225 MAarrowhead1
% End of user PostScript
0 1 .679 r
.53708 .56411 m
.53503 .56058 L
s
% Start of user PostScript
0.074161044 0.12822817 0.070068155 0.12116879 MAarrowhead1
% End of user PostScript
0 1 .995 r
.52355 .54075 m
.52225 .53851 L
s
% Start of user PostScript
0.047097321 0.081504241 0.044499655 0.077014392 MAarrowhead1
% End of user PostScript
0 .69 1 r
.51496 .5259 m
.51413 .52447 L
s
% Start of user PostScript
0.029916484 0.051794399 0.028266939 0.048940305 MAarrowhead1
% End of user PostScript
0 .375 1 r
.5095 .51646 m
.50898 .51555 L
s
% Start of user PostScript
0.019005177 0.032910791 0.017957425 0.031096985 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50604 .51046 m
.5057 .50988 L
s
% Start of user PostScript
0.012074157 0.020910784 0.011408562 0.019758243 MAarrowhead1
% End of user PostScript
1 .528 0 r
1 .96458 m
.96743 .95607 L
.93366 .94478 L
.90283 .93227 L
.87462 .91885 L
.84876 .90478 L
.82503 .89028 L
.80321 .87553 L
.78311 .8607 L
.76457 .8459 L
.74744 .83123 L
.7316 .81679 L
.71692 .80263 L
.70331 .78882 L
.69067 .77538 L
.67892 .76235 L
.66798 .74975 L
.65779 .7376 L
.64829 .7259 L
.63941 .71466 L
.63112 .70388 L
.62337 .69355 L
.61611 .68367 L
.60932 .67423 L
.60295 .66522 L
.59698 .65663 L
.59138 .64844 L
.58612 .64064 L
.58118 .63322 L
.57654 .62617 L
.57217 .61947 L
.56807 .6131 L
.56421 .60705 L
.56057 .60131 L
.55715 .59587 L
.55393 .59071 L
.5509 .58581 L
.54804 .58118 L
.54535 .57678 L
.54281 .57262 L
.54041 .56868 L
.53816 .56494 L
.53603 .56141 L
.53402 .55806 L
.53212 .55489 L
.53034 .5519 L
.52865 .54906 L
.52706 .54638 L
.52555 .54384 L
.52414 .54144 L
Mistroke
.5228 .53917 L
.52153 .53703 L
.52034 .53499 L
.51921 .53308 L
.51815 .53126 L
.51715 .52954 L
.5162 .52792 L
.5153 .52639 L
.51446 .52494 L
.51366 .52357 L
.5129 .52227 L
.51219 .52105 L
.51152 .51989 L
.51088 .5188 L
.51028 .51776 L
.50971 .51678 L
.50918 .51586 L
.50867 .51499 L
.50819 .51416 L
.50774 .51338 L
.50731 .51265 L
.50691 .51195 L
.50653 .51129 L
.50617 .51067 L
.50583 .51008 L
.50551 .50953 L
.5052 .509 L
.50491 .50851 L
.50464 .50804 L
.50439 .50759 L
.50415 .50718 L
.50392 .50678 L
.5037 .50641 L
.5035 .50605 L
.5033 .50572 L
.50312 .50541 L
.50295 .50511 L
.50279 .50483 L
.50263 .50456 L
.50249 .50431 L
.50235 .50407 L
.50222 .50385 L
.5021 .50363 L
.50198 .50343 L
.50187 .50325 L
.50177 .50307 L
.50167 .5029 L
.50158 .50274 L
.50149 .50259 L
.50141 .50244 L
Mistroke
.50133 .50231 L
.50126 .50218 L
.50119 .50206 L
.50112 .50195 L
.50106 .50184 L
.501 .50174 L
.50095 .50164 L
.5009 .50155 L
.50085 .50147 L
.5008 .50139 L
.50076 .50131 L
.50071 .50124 L
.50068 .50117 L
.50064 .50111 L
.5006 .50104 L
.50057 .50099 L
.50054 .50093 L
.50051 .50088 L
.50048 .50083 L
.50045 .50079 L
.50043 .50074 L
.50041 .5007 L
.50038 .50066 L
.50036 .50063 L
.50034 .50059 L
.50032 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.50019 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
Mistroke
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
Mfstroke
1 0 0 r
% Start of user PostScript
6.541869 -3.004465 5.8568931 -2.2770131 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
5.2529808 -1.6646691 4.7198822 -1.1510738 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.3507505 0.65137041 2.1437807 0.74951534 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.1799859 0.95692426 1.0903498 0.94677492 MAarrowhead1
% End of user PostScript
.897 1 0 r
.82503 .89028 m
.80321 .87553 L
s
% Start of user PostScript
0.65005835 0.78055304 0.606411 0.7510644 MAarrowhead1
% End of user PostScript
.581 1 0 r
.69067 .77538 m
.67892 .76235 L
s
% Start of user PostScript
0.38134776 0.55076007 0.35784387 0.52470301 MAarrowhead1
% End of user PostScript
.266 1 0 r
.61611 .68367 m
.60932 .67423 L
s
% Start of user PostScript
0.23222519 0.36734882 0.21863544 0.348467 MAarrowhead1
% End of user PostScript
0 1 .049 r
.57217 .61947 m
.56807 .6131 L
s
% Start of user PostScript
0.1443454 0.23893051 0.13613811 0.22619472 MAarrowhead1
% End of user PostScript
0 1 .364 r
.54535 .57678 m
.54281 .57262 L
s
% Start of user PostScript
0.090692851 0.1535627 0.085614048 0.14523616 MAarrowhead1
% End of user PostScript
0 1 .679 r
.52865 .54906 m
.52706 .54638 L
s
% Start of user PostScript
0.057298224 0.098124254 0.054114546 0.092759381 MAarrowhead1
% End of user PostScript
0 1 .995 r
.51815 .53126 m
.51715 .52954 L
s
% Start of user PostScript
0.036301442 0.062520293 0.034292411 0.059088031 MAarrowhead1
% End of user PostScript
0 .69 1 r
.51152 .51989 m
.51088 .5188 L
s
% Start of user PostScript
0.023031273 0.039778319 0.021759202 0.037590115 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50731 .51265 m
.50691 .51195 L
s
% Start of user PostScript
0.014622404 0.025290832 0.013815585 0.023898176 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50464 .50804 m
.50439 .50759 L
s
% Start of user PostScript
0.0092869535 0.016074063 0.0087747862 0.015188487 MAarrowhead1
% End of user PostScript
1 0 .326 r
1 .07387 m
.94321 .14799 L
.89344 .21127 L
.8498 .26521 L
.8115 .3111 L
.77785 .35007 L
.74825 .38307 L
.72219 .41095 L
.69922 .43443 L
.67895 .45414 L
.66103 .47061 L
.64518 .48431 L
.63113 .49565 L
.61867 .50496 L
.60759 .51255 L
.59772 .51867 L
.58893 .52354 L
.58107 .52736 L
.57405 .53028 L
.56775 .53245 L
.56209 .53399 L
.55701 .535 L
.55242 .53557 L
.54828 .53577 L
.54454 .53568 L
.54114 .53533 L
.53806 .5348 L
.53526 .5341 L
.53271 .53328 L
.53038 .53236 L
.52824 .53137 L
.52629 .53033 L
.5245 .52925 L
.52285 .52815 L
.52133 .52705 L
.51993 .52595 L
.51864 .52485 L
.51744 .52377 L
.51633 .52272 L
.51531 .52168 L
.51436 .52068 L
.51347 .5197 L
.51264 .51876 L
.51188 .51785 L
.51116 .51697 L
.51049 .51613 L
.50987 .51532 L
.50928 .51454 L
.50874 .5138 L
.50822 .51309 L
Mistroke
.50775 .51242 L
.5073 .51177 L
.50687 .51116 L
.50648 .51057 L
.50611 .51001 L
.50576 .50948 L
.50543 .50898 L
.50512 .5085 L
.50483 .50805 L
.50456 .50762 L
.5043 .50721 L
.50406 .50682 L
.50383 .50645 L
.50361 .5061 L
.50341 .50577 L
.50322 .50546 L
.50304 .50516 L
.50287 .50488 L
.50271 .50462 L
.50256 .50437 L
.50242 .50413 L
.50228 .5039 L
.50215 .50369 L
.50203 .50349 L
.50192 .5033 L
.50182 .50312 L
.50171 .50295 L
.50162 .50278 L
.50153 .50263 L
.50144 .50249 L
.50136 .50235 L
.50129 .50222 L
.50122 .5021 L
.50115 .50198 L
.50109 .50188 L
.50103 .50177 L
.50097 .50167 L
.50092 .50158 L
.50087 .5015 L
.50082 .50141 L
.50077 .50134 L
.50073 .50126 L
.50069 .50119 L
.50065 .50113 L
.50062 .50106 L
.50058 .50101 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .5008 L
Mistroke
.50044 .50076 L
.50041 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50023 .50041 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50016 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
Mistroke
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
Mfstroke
1 0 0 r
% Start of user PostScript
1.1297888 -1.0257282 1.0000235 -0.8522929 MAarrowhead1
% End of user PostScript
1 .158 0 r
.94321 .14799 m
.89344 .21127 L
s
% Start of user PostScript
0.88642142 -0.704024 0.78688867 -0.57745072 MAarrowhead1
% End of user PostScript
1 .473 0 r
.67895 .45414 m
.66103 .47061 L
s
% Start of user PostScript
0.3578918 -0.091724052 0.322062 -0.058778042 MAarrowhead1
% End of user PostScript
1 .788 0 r
.58107 .52736 m
.57405 .53028 L
s
% Start of user PostScript
0.16214799 0.054716079 0.14809325 0.060562835 MAarrowhead1
% End of user PostScript
.897 1 0 r
.54114 .53533 m
.53806 .5348 L
s
% Start of user PostScript
0.082289184 0.070669688 0.076127262 0.069590656 MAarrowhead1
% End of user PostScript
.581 1 0 r
.52285 .52815 m
.52133 .52705 L
s
% Start of user PostScript
0.04569425 0.05630962 0.042658809 0.054100734 MAarrowhead1
% End of user PostScript
.266 1 0 r
.51347 .5197 m
.51264 .51876 L
s
% Start of user PostScript
0.026938147 0.039401791 0.025289082 0.037514314 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50822 .51309 m
.50775 .51242 L
s
% Start of user PostScript
0.016449744 0.02618587 0.015490834 0.024832846 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50512 .5085 m
.50483 .50805 L
s
% Start of user PostScript
0.010239841 0.01700316 0.0096588265 0.016094642 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50322 .50546 m
.50304 .50516 L
s
% Start of user PostScript
0.0064386386 0.010919194 0.0060784634 0.01032644 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50203 .50349 m
.50192 .5033 L
s
% Start of user PostScript
0.004069399 0.0069744103 0.0038434141 0.0065928718 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50129 .50222 m
.50122 .5021 L
s
% Start of user PostScript
0.0025786818 0.004442894 0.0024360094 0.0041989174 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50082 .50141 m
.50077 .50134 L
s
% Start of user PostScript
0.0016361925 0.0028264964 0.0015458344 0.0026709891 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50052 .5009 m
.50049 .50085 L
s
% Start of user PostScript
0.0010388589 0.001796982 0.00098154193 0.001698023 MAarrowhead1
% End of user PostScript
.514 1 0 r
.80847 1 m
.79508 .98032 L
.77812 .95505 L
.76219 .93102 L
.74721 .90816 L
.73313 .88645 L
.71989 .86583 L
.70743 .84625 L
.6957 .82768 L
.68466 .81006 L
.67426 .79335 L
.66446 .77751 L
.65523 .7625 L
.64653 .74828 L
.63833 .73481 L
.6306 .72206 L
.6233 .70998 L
.61643 .69855 L
.60994 .68772 L
.60382 .67748 L
.59804 .66779 L
.59259 .65862 L
.58745 .64995 L
.58259 .64174 L
.57801 .63398 L
.57368 .62664 L
.5696 .6197 L
.56575 .61313 L
.5621 .60693 L
.55867 .60106 L
.55542 .59551 L
.55235 .59026 L
.54946 .5853 L
.54672 .58062 L
.54414 .57618 L
.5417 .572 L
.5394 .56804 L
.53722 .56429 L
.53517 .56076 L
.53322 .55741 L
.53139 .55425 L
.52966 .55127 L
.52802 .54845 L
.52647 .54578 L
.52501 .54326 L
.52363 .54088 L
.52233 .53863 L
.5211 .5365 L
.51993 .53449 L
.51883 .53259 L
Mistroke
.51779 .53079 L
.51681 .5291 L
.51589 .52749 L
.51501 .52598 L
.51418 .52455 L
.5134 .5232 L
.51266 .52192 L
.51196 .52071 L
.5113 .51957 L
.51068 .51849 L
.51009 .51747 L
.50953 .51651 L
.50901 .5156 L
.50851 .51474 L
.50804 .51393 L
.5076 .51316 L
.50718 .51243 L
.50678 .51175 L
.50641 .5111 L
.50606 .51049 L
.50572 .50991 L
.50541 .50937 L
.50511 .50885 L
.50483 .50836 L
.50456 .5079 L
.50431 .50747 L
.50407 .50705 L
.50385 .50666 L
.50364 .5063 L
.50344 .50595 L
.50325 .50562 L
.50307 .50531 L
.5029 .50502 L
.50274 .50474 L
.50259 .50448 L
.50244 .50423 L
.50231 .504 L
.50218 .50378 L
.50206 .50357 L
.50195 .50338 L
.50184 .50319 L
.50174 .50301 L
.50164 .50285 L
.50155 .50269 L
.50147 .50254 L
.50139 .5024 L
.50131 .50227 L
.50124 .50214 L
.50117 .50203 L
.50111 .50191 L
Mistroke
.50104 .50181 L
.50099 .50171 L
.50093 .50162 L
.50088 .50153 L
.50083 .50144 L
.50079 .50136 L
.50074 .50129 L
.5007 .50122 L
.50066 .50115 L
.50063 .50109 L
.50059 .50103 L
.50056 .50097 L
.50053 .50092 L
.5005 .50087 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50036 .50062 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
Mfstroke
1 0 0 r
% Start of user PostScript
9.0537163 1.4186633 8.2319241 1.8994659 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
7.4985182 2.2791354 6.842874 2.5732102 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.7824265 3.1483991 3.4969321 3.1082268 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
2.0911769 2.5406487 1.9514391 2.4429871 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
1.2294812 1.7858892 1.1539348 1.7009166 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
0.74964027 1.1892163 0.70584817 1.127945 MAarrowhead1
% End of user PostScript
.266 1 0 r
.73313 .88645 m
.71989 .86583 L
s
% Start of user PostScript
0.46626823 0.77289959 0.43978171 0.73165637 MAarrowhead1
% End of user PostScript
0 1 .049 r
.64653 .74828 m
.63833 .73481 L
s
% Start of user PostScript
0.29305924 0.49656646 0.27665591 0.46962725 MAarrowhead1
% End of user PostScript
0 1 .364 r
.59259 .65862 m
.58745 .64995 L
s
% Start of user PostScript
0.18518232 0.31724108 0.17489554 0.29989167 MAarrowhead1
% End of user PostScript
0 1 .679 r
.55867 .60106 m
.55542 .59551 L
s
% Start of user PostScript
0.11733311 0.20211338 0.11084036 0.19101627 MAarrowhead1
% End of user PostScript
0 1 .995 r
.53722 .56429 m
.53517 .56076 L
s
% Start of user PostScript
0.07444472 0.12858819 0.070333222 0.12151411 MAarrowhead1
% End of user PostScript
0 .69 1 r
.52363 .54088 m
.52233 .53863 L
s
% Start of user PostScript
0.047265513 0.081753825 0.044657632 0.077251854 MAarrowhead1
% End of user PostScript
0 .375 1 r
.51501 .52598 m
.51418 .52455 L
s
% Start of user PostScript
0.030019517 0.051959597 0.028363994 0.049096917 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50953 .51651 m
.50901 .5156 L
s
% Start of user PostScript
0.019069423 0.033017854 0.018018034 0.031198312 MAarrowhead1
% End of user PostScript
0 1 .337 r
0 .13265 m
.03262 .13285 L
.06839 .13575 L
.10086 .14081 L
.13038 .14759 L
.15726 .15574 L
.1818 .16494 L
.20423 .17494 L
.22477 .18552 L
.24361 .19649 L
.26092 .20771 L
.27686 .21905 L
.29155 .2304 L
.3051 .24168 L
.31764 .25281 L
.32925 .26374 L
.34 .27444 L
.34999 .28485 L
.35927 .29496 L
.3679 .30474 L
.37594 .31419 L
.38344 .32329 L
.39043 .33205 L
.39697 .34045 L
.40307 .3485 L
.40879 .35621 L
.41414 .36358 L
.41915 .37062 L
.42385 .37733 L
.42825 .38373 L
.43239 .38983 L
.43627 .39563 L
.43992 .40115 L
.44335 .40639 L
.44658 .41137 L
.44961 .41611 L
.45246 .4206 L
.45515 .42486 L
.45768 .4289 L
.46006 .43273 L
.46231 .43637 L
.46442 .43981 L
.46642 .44307 L
.46829 .44616 L
.47007 .44909 L
.47174 .45186 L
.47331 .45448 L
.4748 .45696 L
.4762 .45931 L
.47753 .46153 L
Mistroke
.47878 .46363 L
.47995 .46562 L
.48107 .4675 L
.48212 .46928 L
.48311 .47097 L
.48405 .47256 L
.48493 .47406 L
.48576 .47549 L
.48655 .47683 L
.4873 .4781 L
.488 .47931 L
.48866 .48044 L
.48929 .48152 L
.48988 .48253 L
.49044 .48349 L
.49097 .4844 L
.49147 .48526 L
.49194 .48607 L
.49238 .48684 L
.4928 .48756 L
.4932 .48825 L
.49358 .48889 L
.49393 .48951 L
.49427 .49008 L
.49458 .49063 L
.49488 .49115 L
.49516 .49163 L
.49543 .49209 L
.49568 .49253 L
.49592 .49294 L
.49615 .49333 L
.49636 .4937 L
.49656 .49404 L
.49675 .49437 L
.49693 .49468 L
.4971 .49498 L
.49726 .49525 L
.49741 .49551 L
.49755 .49576 L
.49769 .49599 L
.49781 .49622 L
.49793 .49642 L
.49805 .49662 L
.49816 .49681 L
.49826 .49698 L
.49835 .49715 L
.49844 .49731 L
.49853 .49746 L
.49861 .4976 L
.49869 .49773 L
Mistroke
.49876 .49785 L
.49883 .49797 L
.49889 .49808 L
.49895 .49819 L
.49901 .49829 L
.49907 .49838 L
.49912 .49847 L
.49917 .49856 L
.49921 .49864 L
.49926 .49871 L
.4993 .49878 L
.49934 .49885 L
.49937 .49891 L
.49941 .49897 L
.49944 .49903 L
.49947 .49908 L
.4995 .49913 L
.49953 .49918 L
.49955 .49923 L
.49958 .49927 L
.4996 .49931 L
.49962 .49935 L
.49964 .49938 L
.49966 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
Mistroke
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
1 0 0 r
% Start of user PostScript
-6.5981594 4.1142046 -5.8827633 3.2782673 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-5.2537547 2.5697346 -4.7001033 1.9707263 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.2681484 -0.22026578 -2.0592141 -0.35346262 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.1011 -0.72875992 -1.0137411 -0.73477463 MAarrowhead1
% End of user PostScript
.897 1 0 r
.20423 .17494 m
.22477 .18552 L
s
% Start of user PostScript
-0.59154783 -0.65012386 -0.5504675 -0.62896461 MAarrowhead1
% End of user PostScript
.581 1 0 r
.32925 .26374 m
.34 .27444 L
s
% Start of user PostScript
-0.34150707 -0.47251115 -0.3199901 -0.45112953 MAarrowhead1
% End of user PostScript
.266 1 0 r
.39697 .34045 m
.40307 .3485 L
s
% Start of user PostScript
-0.20606535 -0.3191015 -0.1938511 -0.30299425 MAarrowhead1
% End of user PostScript
0 1 .049 r
.43627 .39563 m
.43992 .40115 L
s
% Start of user PostScript
-0.12745566 -0.20874327 -0.12015823 -0.19770803 MAarrowhead1
% End of user PostScript
0 1 .364 r
.46006 .43273 m
.46231 .43637 L
s
% Start of user PostScript
-0.079876506 -0.13453165 -0.075387203 -0.12726574 MAarrowhead1
% End of user PostScript
0 1 .679 r
.4748 .45696 m
.4762 .45931 L
s
% Start of user PostScript
-0.050398942 -0.086080096 -0.047593429 -0.081382806 MAarrowhead1
% End of user PostScript
0 1 .995 r
.48405 .47256 m
.48493 .47406 L
s
% Start of user PostScript
-0.031909389 -0.054883083 -0.030141776 -0.051872969 MAarrowhead1
% End of user PostScript
0 .69 1 r
.48988 .48253 m
.49044 .48349 L
s
% Start of user PostScript
-0.020238066 -0.034930825 -0.019119745 -0.033010194 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49358 .48889 m
.49393 .48951 L
s
% Start of user PostScript
-0.012846886 -0.022212521 -0.012137868 -0.020989664 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49592 .49294 m
.49615 .49333 L
s
% Start of user PostScript
-0.008158613 -0.014118759 -0.0077086195 -0.013340999 MAarrowhead1
% End of user PostScript
1 .656 0 r
.76958 0 m
.73548 .06075 L
.70333 .11816 L
.67552 .16798 L
.65145 .21121 L
.63063 .24872 L
.61262 .28129 L
.59705 .30956 L
.58359 .33411 L
.57195 .35543 L
.5619 .37395 L
.55321 .39004 L
.5457 .40402 L
.53922 .41618 L
.53362 .42675 L
.52879 .43594 L
.52463 .44393 L
.52104 .45089 L
.51794 .45695 L
.51528 .46223 L
.51298 .46683 L
.51101 .47084 L
.50931 .47434 L
.50785 .47739 L
.5066 .48005 L
.50552 .48238 L
.5046 .48442 L
.50382 .4862 L
.50315 .48776 L
.50257 .48913 L
.50208 .49033 L
.50167 .49138 L
.50132 .49231 L
.50102 .49312 L
.50077 .49384 L
.50055 .49447 L
.50038 .49503 L
.50023 .49553 L
.50011 .49596 L
.5 .49635 L
.49992 .4967 L
.49985 .497 L
.4998 .49728 L
.49976 .49752 L
.49972 .49774 L
.4997 .49793 L
.49968 .49811 L
.49967 .49826 L
.49966 .4984 L
.49966 .49853 L
Mistroke
.49966 .49865 L
.49966 .49875 L
.49966 .49885 L
.49967 .49893 L
.49967 .49901 L
.49968 .49908 L
.49969 .49915 L
.4997 .49921 L
.49971 .49926 L
.49972 .49931 L
.49973 .49936 L
.49974 .4994 L
.49975 .49944 L
.49976 .49947 L
.49977 .49951 L
.49978 .49954 L
.49979 .49957 L
.4998 .49959 L
.49981 .49962 L
.49982 .49964 L
.49983 .49966 L
.49984 .49968 L
.49985 .4997 L
.49986 .49972 L
.49986 .49974 L
.49987 .49975 L
.49988 .49977 L
.49988 .49978 L
.49989 .49979 L
.49989 .49981 L
.4999 .49982 L
.49991 .49983 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
Mistroke
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
5.5420515 -9.7636882 4.7984248 -8.4666174 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
4.1542827 -7.3423591 3.596332 -6.3678613 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.3066595 -2.3565519 1.1300989 -2.0455944 MAarrowhead1
% End of user PostScript
1 .788 0 r
.70333 .11816 m
.67552 .16798 L
s
% Start of user PostScript
0.40666648 -0.76367712 0.35103158 -0.6640454 MAarrowhead1
% End of user PostScript
.897 1 0 r
.5619 .37395 m
.55321 .39004 L
s
% Start of user PostScript
0.12379145 -0.25209536 0.10641175 -0.21991574 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51794 .45695 m
.51528 .46223 L
s
% Start of user PostScript
0.035883405 -0.086093065 0.030550978 -0.075537359 MAarrowhead1
% End of user PostScript
.266 1 0 r
.5046 .48442 m
.50382 .4862 L
s
% Start of user PostScript
0.0092080845 -0.03115974 0.0076345489 -0.027595853 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50077 .49384 m
.50055 .49447 L
s
% Start of user PostScript
0.0015316634 -0.012317043 0.0011084958 -0.011051396 MAarrowhead1
% End of user PostScript
0 1 .364 r
.4998 .49728 m
.49976 .49752 L
s
% Start of user PostScript
-0.00039922304 -0.0054485614 -0.00048486073 -0.0049617857 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49966 .49865 m
.49966 .49875 L
s
% Start of user PostScript
-0.00068974449 -0.0027063581 -0.00068593129 -0.0024979328 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49971 .49926 m
.49972 .49931 L
s
% Start of user PostScript
-0.00057680667 -0.0014794351 -0.00055588229 -0.0013790593 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49979 .49957 m
.4998 .49959 L
s
% Start of user PostScript
-0.00041050824 -0.00086367305 -0.0003913347 -0.0008100834 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49986 .49974 m
.49987 .49975 L
s
% Start of user PostScript
-0.00027480785 -0.0005244902 -0.00026075775 -0.0004936784 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49991 .49984 m
.49992 .49985 L
s
% Start of user PostScript
-0.00017904433 -0.00032552887 -0.00016952399 -0.00030698113 MAarrowhead1
% End of user PostScript
.496 1 0 r
.79055 1 m
.78917 .99765 L
.77315 .97034 L
.75803 .94452 L
.74376 .92012 L
.73027 .89704 L
.71754 .87523 L
.70551 .8546 L
.69415 .83511 L
.68343 .81668 L
.67329 .79927 L
.66372 .78281 L
.65468 .76725 L
.64614 .75254 L
.63807 .73865 L
.63045 .72551 L
.62325 .7131 L
.61644 .70137 L
.61002 .69028 L
.60395 .6798 L
.59821 .6699 L
.59279 .66054 L
.58768 .6517 L
.58284 .64334 L
.57827 .63545 L
.57395 .62799 L
.56987 .62094 L
.56602 .61427 L
.56238 .60798 L
.55894 .60203 L
.55569 .59641 L
.55262 .59109 L
.54972 .58608 L
.54698 .58133 L
.54439 .57685 L
.54194 .57262 L
.53963 .56861 L
.53744 .56483 L
.53538 .56126 L
.53343 .55788 L
.53158 .55469 L
.52984 .55168 L
.5282 .54883 L
.52664 .54614 L
.52517 .5436 L
.52379 .54119 L
.52248 .53892 L
.52124 .53678 L
.52007 .53475 L
.51896 .53284 L
Mistroke
.51791 .53103 L
.51693 .52932 L
.51599 .5277 L
.51511 .52617 L
.51428 .52473 L
.51349 .52337 L
.51275 .52208 L
.51205 .52086 L
.51138 .51971 L
.51075 .51863 L
.51016 .5176 L
.5096 .51663 L
.50907 .51571 L
.50857 .51485 L
.5081 .51403 L
.50765 .51325 L
.50723 .51252 L
.50683 .51183 L
.50646 .51118 L
.5061 .51057 L
.50576 .50998 L
.50545 .50943 L
.50515 .50891 L
.50486 .50842 L
.50459 .50796 L
.50434 .50752 L
.5041 .5071 L
.50388 .50671 L
.50366 .50634 L
.50346 .50599 L
.50327 .50566 L
.50309 .50535 L
.50292 .50506 L
.50276 .50478 L
.50261 .50451 L
.50246 .50426 L
.50233 .50403 L
.5022 .50381 L
.50208 .5036 L
.50196 .5034 L
.50185 .50321 L
.50175 .50304 L
.50166 .50287 L
.50156 .50271 L
.50148 .50256 L
.5014 .50242 L
.50132 .50229 L
.50125 .50216 L
.50118 .50204 L
.50111 .50193 L
Mistroke
.50105 .50182 L
.50099 .50172 L
.50094 .50163 L
.50089 .50154 L
.50084 .50145 L
.50079 .50137 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50063 .50109 L
.5006 .50103 L
.50056 .50098 L
.50053 .50092 L
.5005 .50087 L
.50048 .50082 L
.50045 .50078 L
.50042 .50074 L
.5004 .50069 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50055 L
.5003 .50052 L
.50029 .50049 L
.50027 .50047 L
.50025 .50044 L
.50024 .50042 L
.50023 .50039 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
Mfstroke
1 0 0 r
% Start of user PostScript
4.2042486 6.4454821 3.9535768 6.1229831 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
3.7192494 5.8138838 3.5000281 5.5180298 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.3054247 3.7935354 2.1738307 3.5922528 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.44644 2.4418869 1.3652753 2.3097725 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
0.91317192 1.5615066 0.86238066 1.4762242 MAarrowhead1
% End of user PostScript
.581 1 0 r
.78917 .99765 m
.77315 .97034 L
s
% Start of user PostScript
0.57833008 0.99529277 0.54630685 0.94068194 MAarrowhead1
% End of user PostScript
.266 1 0 r
.68343 .81668 m
.67329 .79927 L
s
% Start of user PostScript
0.36685102 0.63336947 0.34658366 0.59853708 MAarrowhead1
% End of user PostScript
0 1 .049 r
.61644 .70137 m
.61002 .69028 L
s
% Start of user PostScript
0.23288976 0.40273018 0.22003794 0.38055651 MAarrowhead1
% End of user PostScript
0 1 .364 r
.57395 .62799 m
.56987 .62094 L
s
% Start of user PostScript
0.14790565 0.2559746 0.13974825 0.241873 MAarrowhead1
% End of user PostScript
0 1 .679 r
.54698 .58133 m
.54439 .57685 L
s
% Start of user PostScript
0.093952023 0.16266437 0.088771786 0.15370066 MAarrowhead1
% End of user PostScript
0 1 .995 r
.52984 .55168 m
.5282 .54883 L
s
% Start of user PostScript
0.059685799 0.10335808 0.05639537 0.097661664 MAarrowhead1
% End of user PostScript
0 .69 1 r
.51896 .53284 m
.51791 .53103 L
s
% Start of user PostScript
0.037919068 0.065671158 0.03582877 0.062051536 MAarrowhead1
% End of user PostScript
0 .375 1 r
.51205 .52086 m
.51138 .51971 L
s
% Start of user PostScript
0.02409102 0.041724776 0.022763044 0.039424933 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50765 .51325 m
.50723 .51252 L
s
% Start of user PostScript
0.015305876 0.026509888 0.014462181 0.025048655 MAarrowhead1
% End of user PostScript
.782 1 0 r
.20028 0 m
.21697 .0264 L
.23295 .05185 L
.248 .07599 L
.26217 .09888 L
.27552 .12056 L
.28811 .14111 L
.29997 .16057 L
.31116 .17901 L
.3217 .19646 L
.33165 .21299 L
.34104 .22863 L
.34989 .24343 L
.35824 .25744 L
.36612 .27069 L
.37356 .28323 L
.38058 .29509 L
.38721 .30631 L
.39346 .31692 L
.39937 .32696 L
.40494 .33645 L
.41021 .34542 L
.41518 .3539 L
.41987 .36192 L
.4243 .36951 L
.42849 .37668 L
.43244 .38345 L
.43618 .38986 L
.43971 .39591 L
.44304 .40164 L
.44618 .40705 L
.44916 .41216 L
.45196 .41699 L
.45462 .42156 L
.45712 .42588 L
.45949 .42996 L
.46172 .43381 L
.46384 .43746 L
.46583 .4409 L
.46772 .44416 L
.4695 .44723 L
.47118 .45014 L
.47277 .45288 L
.47427 .45548 L
.47569 .45793 L
.47703 .46025 L
.4783 .46244 L
.4795 .46451 L
.48063 .46646 L
.48169 .46831 L
Mistroke
.4827 .47006 L
.48366 .47171 L
.48456 .47327 L
.48541 .47474 L
.48621 .47613 L
.48697 .47745 L
.48769 .47869 L
.48837 .47986 L
.48901 .48097 L
.48962 .48202 L
.49019 .48301 L
.49073 .48395 L
.49124 .48483 L
.49173 .48567 L
.49218 .48646 L
.49261 .48721 L
.49302 .48791 L
.4934 .48858 L
.49377 .48921 L
.49411 .4898 L
.49444 .49036 L
.49474 .4909 L
.49503 .4914 L
.49531 .49187 L
.49557 .49232 L
.49581 .49274 L
.49604 .49314 L
.49626 .49352 L
.49647 .49388 L
.49666 .49422 L
.49684 .49453 L
.49702 .49484 L
.49718 .49512 L
.49734 .49539 L
.49748 .49564 L
.49762 .49588 L
.49775 .49611 L
.49788 .49632 L
.49799 .49653 L
.49811 .49672 L
.49821 .4969 L
.49831 .49707 L
.4984 .49723 L
.49849 .49738 L
.49857 .49753 L
.49865 .49766 L
.49873 .49779 L
.4988 .49792 L
.49886 .49803 L
.49893 .49814 L
Mistroke
.49898 .49824 L
.49904 .49834 L
.49909 .49843 L
.49914 .49852 L
.49919 .4986 L
.49924 .49868 L
.49928 .49875 L
.49932 .49882 L
.49935 .49888 L
.49939 .49894 L
.49942 .499 L
.49946 .49906 L
.49949 .49911 L
.49951 .49916 L
.49954 .4992 L
.49957 .49925 L
.49959 .49929 L
.49961 .49933 L
.49963 .49937 L
.49965 .4994 L
.49967 .49943 L
.49969 .49947 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .4997 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49988 .49978 L
.49988 .4998 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
Mistroke
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
Mfstroke
1 0 0 r
% Start of user PostScript
-5.9531557 -4.5305804 -5.4942068 -4.5074066 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-5.0780189 -4.4552631 -4.6999035 -4.379785 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.828409 -3.5197632 -2.6412952 -3.3798034 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.6705753 -2.4552502 -1.5685738 -2.3370907 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-1.0212108 -1.6295171 -0.96176884 -1.5451544 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-0.63605179 -1.0574168 -0.59999033 -1.0008652 MAarrowhead1
% End of user PostScript
.266 1 0 r
.29997 .16057 m
.31116 .17901 L
s
% Start of user PostScript
-0.400054 -0.67885001 -0.37768426 -0.64198211 MAarrowhead1
% End of user PostScript
0 1 .049 r
.37356 .28323 m
.38058 .29509 L
s
% Start of user PostScript
-0.25288233 -0.4335359 -0.238842 -0.40981399 MAarrowhead1
% End of user PostScript
0 1 .364 r
.41987 .36192 m
.4243 .36951 L
s
% Start of user PostScript
-0.16025738 -0.27615374 -0.15139165 -0.26098745 MAarrowhead1
% End of user PostScript
0 1 .679 r
.44916 .41216 m
.45196 .41699 L
s
% Start of user PostScript
-0.10168826 -0.17567793 -0.096072854 -0.16601202 MAarrowhead1
% End of user PostScript
0 1 .995 r
.46772 .44416 m
.4695 .44723 L
s
% Start of user PostScript
-0.064565577 -0.11168745 -0.061003393 -0.10553671 MAarrowhead1
% End of user PostScript
0 .69 1 r
.4795 .46451 m
.48063 .46646 L
s
% Start of user PostScript
-0.041008158 -0.07098264 -0.038746703 -0.06707177 MAarrowhead1
% End of user PostScript
0 .375 1 r
.48697 .47745 m
.48769 .47869 L
s
% Start of user PostScript
-0.026050079 -0.045105579 -0.024613837 -0.042619868 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49173 .48567 m
.49218 .48646 L
s
% Start of user PostScript
-0.016549415 -0.028659826 -0.015637086 -0.027080239 MAarrowhead1
% End of user PostScript
0 1 .062 r
.79713 1 m
.78123 .97432 L
.76543 .94868 L
.75055 .92438 L
.73653 .90136 L
.7233 .87956 L
.71083 .85892 L
.69907 .83938 L
.68797 .82089 L
.6775 .80338 L
.66763 .78682 L
.65831 .77115 L
.64951 .75632 L
.64121 .7423 L
.63338 .72903 L
.62598 .71648 L
.619 .70462 L
.6124 .6934 L
.60618 .68279 L
.6003 .67276 L
.59475 .66327 L
.58951 .65431 L
.58456 .64583 L
.57988 .63781 L
.57547 .63024 L
.5713 .62308 L
.56736 .61631 L
.56364 .60991 L
.56012 .60387 L
.5568 .59815 L
.55367 .59275 L
.5507 .58765 L
.5479 .58282 L
.54526 .57826 L
.54276 .57395 L
.5404 .56988 L
.53817 .56603 L
.53607 .5624 L
.53408 .55896 L
.5322 .55571 L
.53042 .55264 L
.52874 .54974 L
.52716 .547 L
.52566 .54441 L
.52425 .54197 L
.52291 .53966 L
.52165 .53747 L
.52045 .53541 L
.51932 .53345 L
.51826 .53161 L
Mistroke
.51725 .52987 L
.5163 .52822 L
.5154 .52667 L
.51455 .5252 L
.51375 .52381 L
.51299 .5225 L
.51228 .52126 L
.5116 .52009 L
.51096 .51898 L
.51036 .51793 L
.50978 .51694 L
.50925 .51601 L
.50874 .51513 L
.50825 .51429 L
.5078 .51351 L
.50737 .51276 L
.50696 .51206 L
.50658 .51139 L
.50622 .51077 L
.50587 .51017 L
.50555 .50961 L
.50524 .50908 L
.50495 .50858 L
.50468 .50811 L
.50442 .50766 L
.50418 .50724 L
.50395 .50684 L
.50373 .50646 L
.50353 .50611 L
.50333 .50577 L
.50315 .50545 L
.50297 .50515 L
.50281 .50487 L
.50266 .5046 L
.50251 .50435 L
.50237 .50411 L
.50224 .50388 L
.50212 .50367 L
.502 .50346 L
.50189 .50327 L
.50179 .50309 L
.50169 .50292 L
.50159 .50276 L
.50151 .50261 L
.50142 .50247 L
.50134 .50233 L
.50127 .5022 L
.5012 .50208 L
.50113 .50196 L
.50107 .50186 L
Mistroke
.50101 .50175 L
.50096 .50166 L
.5009 .50157 L
.50085 .50148 L
.50081 .5014 L
.50076 .50132 L
.50072 .50125 L
.50068 .50118 L
.50064 .50111 L
.50061 .50105 L
.50057 .501 L
.50054 .50094 L
.50051 .50089 L
.50048 .50084 L
.50046 .50079 L
.50043 .50075 L
.50041 .50071 L
.50039 .50067 L
.50037 .50063 L
.50034 .5006 L
.50033 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50018 .50032 L
.50017 .5003 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50012 .50022 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
Mfstroke
1 0 0 r
% Start of user PostScript
8.3016062 5.2784786 7.6380886 5.3441897 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
7.038637 5.358661 6.4960497 5.3310743 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.845578 4.4894986 3.5844739 4.3271286 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
2.2442162 3.1971303 2.1048995 3.0479421 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
1.3625958 2.1408308 1.2825264 2.0314186 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
0.84561615 1.3949765 0.7974281 1.3208143 MAarrowhead1
% End of user PostScript
.266 1 0 r
.76543 .94868 m
.75055 .92438 L
s
% Start of user PostScript
0.53086927 0.89735198 0.50110607 0.84875651 MAarrowhead1
% End of user PostScript
0 1 .049 r
.66763 .78682 m
.65831 .77115 L
s
% Start of user PostScript
0.33525451 0.57364211 0.31661564 0.54229796 MAarrowhead1
% End of user PostScript
0 1 .364 r
.60618 .68279 m
.6003 .67276 L
s
% Start of user PostScript
0.2123567 0.36557682 0.20060073 0.34551337 MAarrowhead1
% End of user PostScript
0 1 .679 r
.56736 .61631 m
.56364 .60991 L
s
% Start of user PostScript
0.13471444 0.23262178 0.12727273 0.21982721 MAarrowhead1
% End of user PostScript
0 1 .995 r
.54276 .57395 m
.5404 .56988 L
s
% Start of user PostScript
0.085524781 0.14790749 0.080805434 0.13976349 MAarrowhead1
% End of user PostScript
0 .69 1 r
.52716 .547 m
.52566 .54441 L
s
% Start of user PostScript
0.054316897 0.09400788 0.051321255 0.088828855 MAarrowhead1
% End of user PostScript
0 .375 1 r
.51725 .52987 m
.5163 .52822 L
s
% Start of user PostScript
0.034503298 0.059738666 0.032600915 0.056446686 MAarrowhead1
% End of user PostScript
0 .06 1 r
.51096 .51898 m
.51036 .51793 L
s
% Start of user PostScript
0.021919348 0.03795818 0.020710961 0.035866159 MAarrowhead1
% End of user PostScript
0 1 .395 r
.8499 1 m
.83951 .98904 L
.81855 .96596 L
.79905 .94364 L
.78089 .9221 L
.76395 .90136 L
.74814 .88142 L
.73336 .86229 L
.71955 .84396 L
.70663 .82643 L
.69453 .80967 L
.68319 .79367 L
.67256 .7784 L
.66258 .76386 L
.65322 .75001 L
.64442 .73683 L
.63616 .7243 L
.6284 .71239 L
.62109 .70107 L
.61422 .69033 L
.60776 .68013 L
.60167 .67046 L
.59594 .66128 L
.59054 .65258 L
.58545 .64434 L
.58066 .63653 L
.57614 .62913 L
.57188 .62212 L
.56787 .61548 L
.56408 .60919 L
.56051 .60325 L
.55713 .59762 L
.55396 .59229 L
.55095 .58725 L
.54812 .58248 L
.54545 .57796 L
.54293 .5737 L
.54055 .56966 L
.5383 .56584 L
.53618 .56223 L
.53417 .55882 L
.53228 .55559 L
.53049 .55254 L
.52881 .54965 L
.52721 .54693 L
.52571 .54435 L
.52429 .54191 L
.52295 .53961 L
.52168 .53743 L
.52048 .53537 L
Mistroke
.51935 .53343 L
.51828 .53159 L
.51727 .52985 L
.51632 .52821 L
.51542 .52665 L
.51457 .52519 L
.51376 .5238 L
.513 .52249 L
.51229 .52125 L
.51161 .52008 L
.51097 .51897 L
.51036 .51793 L
.50979 .51694 L
.50925 .51601 L
.50874 .51513 L
.50826 .51429 L
.5078 .51351 L
.50737 .51276 L
.50697 .51206 L
.50658 .51139 L
.50622 .51077 L
.50588 .51017 L
.50555 .50961 L
.50525 .50908 L
.50496 .50858 L
.50468 .50811 L
.50443 .50766 L
.50418 .50724 L
.50395 .50684 L
.50373 .50646 L
.50353 .50611 L
.50333 .50577 L
.50315 .50545 L
.50298 .50515 L
.50281 .50487 L
.50266 .5046 L
.50251 .50435 L
.50237 .50411 L
.50224 .50388 L
.50212 .50367 L
.502 .50346 L
.50189 .50327 L
.50179 .50309 L
.50169 .50292 L
.50159 .50276 L
.50151 .50261 L
.50142 .50247 L
.50135 .50233 L
.50127 .5022 L
.5012 .50208 L
Mistroke
.50113 .50197 L
.50107 .50186 L
.50101 .50175 L
.50096 .50166 L
.5009 .50157 L
.50085 .50148 L
.50081 .5014 L
.50076 .50132 L
.50072 .50125 L
.50068 .50118 L
.50064 .50111 L
.50061 .50105 L
.50057 .501 L
.50054 .50094 L
.50051 .50089 L
.50048 .50084 L
.50046 .50079 L
.50043 .50075 L
.50041 .50071 L
.50039 .50067 L
.50037 .50063 L
.50034 .5006 L
.50033 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50018 .50032 L
.50017 .5003 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50012 .50022 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
Mistroke
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
Mfstroke
1 0 0 r
% Start of user PostScript
6.2021243 -0.20460334 5.6125463 0.23571876 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
5.0885376 0.59448932 4.6220685 0.88385092 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.4794895 1.6827681 2.2837162 1.6923769 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.3358899 1.4838525 1.2434732 1.4345898 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
0.77266145 1.0745426 0.72410329 1.0256494 MAarrowhead1
% End of user PostScript
.581 1 0 r
.73336 .86229 m
.71955 .84396 L
s
% Start of user PostScript
0.4667266 0.72458209 0.43910352 0.68792701 MAarrowhead1
% End of user PostScript
.266 1 0 r
.64442 .73683 m
.63616 .7243 L
s
% Start of user PostScript
0.28884822 0.47366637 0.27232387 0.4486011 MAarrowhead1
% End of user PostScript
0 1 .049 r
.59054 .65258 m
.58545 .64434 L
s
% Start of user PostScript
0.18107618 0.3051697 0.17090352 0.28868005 MAarrowhead1
% End of user PostScript
0 1 .364 r
.55713 .59762 m
.55396 .59229 L
s
% Start of user PostScript
0.11426966 0.19523138 0.10791011 0.18457538 MAarrowhead1
% End of user PostScript
0 1 .679 r
.53618 .56223 m
.53417 .55882 L
s
% Start of user PostScript
0.072353904 0.12446599 0.068346323 0.11763876 MAarrowhead1
% End of user PostScript
0 1 .995 r
.52295 .53961 m
.52168 .53743 L
s
% Start of user PostScript
0.045891217 0.079214333 0.043355487 0.074858579 MAarrowhead1
% End of user PostScript
0 .69 1 r
.51457 .52519 m
.51376 .5238 L
s
% Start of user PostScript
0.029131779 0.050371417 0.027524044 0.047598261 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50925 .51601 m
.50874 .51513 L
s
% Start of user PostScript
0.018500768 0.032016845 0.017480361 0.030253109 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50588 .51017 m
.50555 .50961 L
s
% Start of user PostScript
0.011751824 0.020346041 0.011103851 0.019224883 MAarrowhead1
% End of user PostScript
.264 0 1 r
.79151 1 m
.78852 .99496 L
.77251 .96787 L
.7574 .94224 L
.74313 .918 L
.72966 .89509 L
.71694 .87341 L
.70493 .85292 L
.69358 .83355 L
.68287 .81523 L
.67276 .79791 L
.66321 .78154 L
.65419 .76607 L
.64566 .75144 L
.63762 .73762 L
.63001 .72455 L
.62283 .7122 L
.61605 .70052 L
.60964 .68949 L
.60359 .67906 L
.59787 .6692 L
.59247 .65989 L
.58737 .65109 L
.58254 .64277 L
.57799 .63491 L
.57369 .62748 L
.56962 .62046 L
.56578 .61382 L
.56215 .60755 L
.55872 .60163 L
.55549 .59603 L
.55243 .59074 L
.54953 .58574 L
.5468 .58102 L
.54422 .57655 L
.54178 .57233 L
.53948 .56835 L
.5373 .56458 L
.53525 .56102 L
.5333 .55766 L
.53147 .55448 L
.52973 .55148 L
.52809 .54864 L
.52654 .54596 L
.52508 .54343 L
.5237 .54104 L
.52239 .53877 L
.52116 .53664 L
.51999 .53462 L
.51889 .53271 L
Mistroke
.51785 .53091 L
.51686 .5292 L
.51593 .52759 L
.51505 .52607 L
.51423 .52464 L
.51344 .52328 L
.5127 .522 L
.512 .52078 L
.51134 .51964 L
.51071 .51855 L
.51012 .51753 L
.50956 .51657 L
.50904 .51565 L
.50854 .51479 L
.50807 .51397 L
.50762 .5132 L
.5072 .51248 L
.50681 .51179 L
.50643 .51114 L
.50608 .51053 L
.50574 .50995 L
.50543 .5094 L
.50513 .50888 L
.50484 .50839 L
.50458 .50793 L
.50432 .50749 L
.50409 .50708 L
.50386 .50669 L
.50365 .50632 L
.50345 .50597 L
.50326 .50564 L
.50308 .50533 L
.50291 .50504 L
.50275 .50476 L
.5026 .5045 L
.50245 .50425 L
.50232 .50401 L
.50219 .50379 L
.50207 .50358 L
.50196 .50339 L
.50185 .5032 L
.50175 .50302 L
.50165 .50286 L
.50156 .5027 L
.50147 .50255 L
.50139 .50241 L
.50131 .50228 L
.50124 .50215 L
.50117 .50203 L
.50111 .50192 L
Mistroke
.50105 .50182 L
.50099 .50172 L
.50094 .50162 L
.50088 .50153 L
.50084 .50145 L
.50079 .50137 L
.50075 .50129 L
.5007 .50122 L
.50067 .50115 L
.50063 .50109 L
.50059 .50103 L
.50056 .50097 L
.50053 .50092 L
.5005 .50087 L
.50047 .50082 L
.50045 .50078 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50036 .50062 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50047 L
.50025 .50044 L
.50024 .50042 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .5003 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50005 .5001 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
Mfstroke
1 0 0 r
% Start of user PostScript
5.9784639 7.80254 5.591166 7.4724921 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
5.2329275 7.147281 4.901117 6.8284233 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.14902 4.8452728 2.9616616 4.6020631 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.9448802 3.1751092 1.8332968 3.0076777 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
1.2179256 2.0480125 1.1494004 1.9375336 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
0.76816321 1.3109556 0.72537885 1.2394599 MAarrowhead1
% End of user PostScript
.266 1 0 r
.74313 .918 m
.72966 .89509 L
s
% Start of user PostScript
0.48625583 0.8360098 0.45931225 0.79017123 MAarrowhead1
% End of user PostScript
0 1 .049 r
.65419 .76607 m
.64566 .75144 L
s
% Start of user PostScript
0.30837008 0.53213925 0.29132766 0.50288438 MAarrowhead1
% End of user PostScript
0 1 .364 r
.59787 .6692 m
.59247 .65989 L
s
% Start of user PostScript
0.19573994 0.33840444 0.18493631 0.31977572 MAarrowhead1
% End of user PostScript
0 1 .679 r
.56215 .60755 m
.55872 .60163 L
s
% Start of user PostScript
0.12430457 0.21510255 0.11744823 0.20325363 MAarrowhead1
% End of user PostScript
0 1 .995 r
.53948 .56835 m
.5373 .56458 L
s
% Start of user PostScript
0.078957804 0.1366956 0.074604113 0.12916324 MAarrowhead1
% End of user PostScript
0 .69 1 r
.52508 .54343 m
.5237 .54104 L
s
% Start of user PostScript
0.050159504 0.086858687 0.047394191 0.082071711 MAarrowhead1
% End of user PostScript
0 .375 1 r
.51593 .52759 m
.51505 .52607 L
s
% Start of user PostScript
0.031866659 0.055188277 0.030109982 0.052146478 MAarrowhead1
% End of user PostScript
0 .06 1 r
.51012 .51753 m
.50956 .51657 L
s
% Start of user PostScript
0.020245681 0.035064516 0.019129667 0.033131794 MAarrowhead1
% End of user PostScript
1 0 .533 r
1 .86771 m
.96358 .86719 L
.92817 .86402 L
.89602 .85876 L
.86679 .8518 L
.84016 .84352 L
.81585 .83422 L
.79362 .82414 L
.77326 .8135 L
.75458 .80248 L
.73742 .79123 L
.72162 .77988 L
.70705 .76853 L
.6936 .75726 L
.68116 .74614 L
.66964 .73522 L
.65897 .72455 L
.64905 .71417 L
.63984 .70409 L
.63127 .69433 L
.62329 .68491 L
.61584 .67584 L
.6089 .66712 L
.60241 .65875 L
.59634 .65073 L
.59067 .64306 L
.58535 .63572 L
.58037 .62871 L
.57571 .62203 L
.57133 .61566 L
.56722 .60959 L
.56336 .60382 L
.55973 .59833 L
.55632 .59311 L
.55312 .58815 L
.5501 .58344 L
.54727 .57897 L
.54459 .57473 L
.54208 .57071 L
.53971 .5669 L
.53748 .56329 L
.53538 .55986 L
.53339 .55662 L
.53153 .55355 L
.52976 .55064 L
.5281 .54788 L
.52654 .54527 L
.52506 .5428 L
.52366 .54047 L
.52235 .53826 L
Mistroke
.5211 .53617 L
.51993 .53419 L
.51883 .53232 L
.51778 .53055 L
.5168 .52887 L
.51587 .52729 L
.51499 .52579 L
.51416 .52438 L
.51337 .52304 L
.51263 .52177 L
.51193 .52058 L
.51127 .51945 L
.51065 .51838 L
.51006 .51737 L
.50951 .51641 L
.50898 .51551 L
.50849 .51466 L
.50802 .51385 L
.50757 .51309 L
.50716 .51237 L
.50676 .51169 L
.50639 .51104 L
.50604 .51044 L
.5057 .50986 L
.50539 .50932 L
.50509 .50881 L
.50481 .50832 L
.50454 .50786 L
.50429 .50743 L
.50406 .50702 L
.50383 .50663 L
.50362 .50627 L
.50342 .50592 L
.50323 .5056 L
.50305 .50529 L
.50289 .505 L
.50273 .50472 L
.50258 .50446 L
.50243 .50422 L
.5023 .50398 L
.50217 .50376 L
.50205 .50356 L
.50194 .50336 L
.50183 .50318 L
.50173 .503 L
.50164 .50283 L
.50155 .50268 L
.50146 .50253 L
.50138 .50239 L
.5013 .50226 L
Mistroke
.50123 .50214 L
.50116 .50202 L
.5011 .50191 L
.50104 .5018 L
.50098 .5017 L
.50093 .50161 L
.50088 .50152 L
.50083 .50144 L
.50078 .50136 L
.50074 .50128 L
.5007 .50121 L
.50066 .50114 L
.50062 .50108 L
.50059 .50102 L
.50056 .50097 L
.50053 .50091 L
.5005 .50086 L
.50047 .50081 L
.50044 .50077 L
.50042 .50073 L
.5004 .50069 L
.50037 .50065 L
.50035 .50061 L
.50033 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50022 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
Mistroke
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
Mfstroke
1 0 0 r
% Start of user PostScript
9.2824073 -7.4554819 8.2382421 -6.1221973 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
7.3227261 -4.9855424 6.5192764 -4.0182391 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.0326696 -0.36199791 2.7384546 -0.12198659 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.4120614 0.66153666 1.2938532 0.69500077 MAarrowhead1
% End of user PostScript
.897 1 0 r
.86679 .8518 m
.84016 .84352 L
s
% Start of user PostScript
0.73357675 0.70360911 0.68031134 0.68704694 MAarrowhead1
% End of user PostScript
.581 1 0 r
.70705 .76853 m
.6936 .75726 L
s
% Start of user PostScript
0.41409549 0.5370611 0.38719304 0.5145191 MAarrowhead1
% End of user PostScript
.266 1 0 r
.62329 .68491 m
.61584 .67584 L
s
% Start of user PostScript
0.24657559 0.36982678 0.23168846 0.35168542 MAarrowhead1
% End of user PostScript
0 1 .049 r
.57571 .62203 m
.57133 .61566 L
s
% Start of user PostScript
0.15141138 0.24405808 0.14265369 0.23131835 MAarrowhead1
% End of user PostScript
0 1 .364 r
.54727 .57897 m
.54459 .57473 L
s
% Start of user PostScript
0.094530275 0.15794959 0.089188815 0.1494698 MAarrowhead1
% End of user PostScript
0 1 .679 r
.52976 .55064 m
.5281 .54788 L
s
% Start of user PostScript
0.059529148 0.10127024 0.05620625 0.095760102 MAarrowhead1
% End of user PostScript
0 1 .995 r
.51883 .53232 m
.51778 .53055 L
s
% Start of user PostScript
0.037653014 0.064633096 0.03556432 0.061093317 MAarrowhead1
% End of user PostScript
0 .69 1 r
.51193 .52058 m
.51127 .51945 L
s
% Start of user PostScript
0.023869067 0.041156907 0.022549174 0.038895556 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50757 .51309 m
.50716 .51237 L
s
% Start of user PostScript
0.015148043 0.026178223 0.014311729 0.024737556 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50481 .50832 m
.50454 .50786 L
s
% Start of user PostScript
0.0096188023 0.016641519 0.0090881773 0.015724951 MAarrowhead1
% End of user PostScript
1 0 .855 r
.79811 1 m
.79625 .99703 L
.77955 .97027 L
.76383 .94489 L
.74901 .92084 L
.73505 .89805 L
.72189 .87647 L
.70948 .85602 L
.69778 .83667 L
.68674 .81834 L
.67634 .80099 L
.66652 .78458 L
.65725 .76904 L
.64851 .75434 L
.64026 .74043 L
.63247 .72728 L
.62512 .71484 L
.61818 .70307 L
.61163 .69194 L
.60544 .68141 L
.5996 .67146 L
.59409 .66205 L
.58888 .65315 L
.58396 .64474 L
.57932 .63679 L
.57493 .62927 L
.57079 .62217 L
.56688 .61545 L
.56319 .6091 L
.55969 .6031 L
.5564 .59743 L
.55328 .59207 L
.55034 .587 L
.54756 .58222 L
.54494 .57769 L
.54246 .57341 L
.54011 .56937 L
.5379 .56555 L
.53581 .56194 L
.53383 .55853 L
.53197 .55531 L
.5302 .55226 L
.52854 .54938 L
.52696 .54666 L
.52548 .54409 L
.52407 .54166 L
.52274 .53937 L
.52149 .5372 L
.5203 .53515 L
.51918 .53321 L
Mistroke
.51813 .53138 L
.51713 .52965 L
.51618 .52802 L
.51529 .52647 L
.51445 .52502 L
.51365 .52364 L
.5129 .52233 L
.51219 .5211 L
.51152 .51994 L
.51088 .51884 L
.51028 .5178 L
.50971 .51682 L
.50918 .51589 L
.50867 .51502 L
.50819 .51419 L
.50774 .51341 L
.50732 .51267 L
.50691 .51197 L
.50653 .51131 L
.50617 .51069 L
.50583 .5101 L
.50551 .50954 L
.50521 .50902 L
.50492 .50852 L
.50465 .50805 L
.50439 .50761 L
.50415 .50719 L
.50392 .50679 L
.5037 .50642 L
.5035 .50606 L
.50331 .50573 L
.50313 .50541 L
.50295 .50511 L
.50279 .50483 L
.50264 .50457 L
.50249 .50431 L
.50235 .50408 L
.50222 .50385 L
.5021 .50364 L
.50199 .50344 L
.50188 .50325 L
.50177 .50307 L
.50168 .5029 L
.50158 .50274 L
.5015 .50259 L
.50141 .50245 L
.50134 .50231 L
.50126 .50219 L
.50119 .50206 L
.50113 .50195 L
Mistroke
.50106 .50184 L
.50101 .50174 L
.50095 .50165 L
.5009 .50155 L
.50085 .50147 L
.5008 .50139 L
.50076 .50131 L
.50072 .50124 L
.50068 .50117 L
.50064 .50111 L
.5006 .50105 L
.50057 .50099 L
.50054 .50093 L
.50051 .50088 L
.50048 .50083 L
.50045 .50079 L
.50043 .50074 L
.50041 .5007 L
.50038 .50066 L
.50036 .50063 L
.50034 .50059 L
.50032 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.50019 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
Mfstroke
1 0 0 r
% Start of user PostScript
7.1810589 4.9851171 6.6165866 5.0024291 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
6.1057438 4.9797896 5.6425684 4.9246073 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.3662663 4.0523779 3.140477 3.8986969 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.9757232 2.8569952 1.8540326 2.7216601 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
1.2034614 1.9048948 1.1330619 1.806932 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
0.74814998 1.2387735 0.70561982 1.1727271 MAarrowhead1
% End of user PostScript
.266 1 0 r
.73505 .89805 m
.72189 .87647 L
s
% Start of user PostScript
0.47010112 0.79610668 0.44377823 0.7529349 MAarrowhead1
% End of user PostScript
0 1 .049 r
.64851 .75434 m
.64026 .74043 L
s
% Start of user PostScript
0.29701332 0.50868015 0.28051118 0.48086686 MAarrowhead1
% End of user PostScript
0 1 .364 r
.59409 .66205 m
.58888 .65315 L
s
% Start of user PostScript
0.18817719 0.32410143 0.17776318 0.30630829 MAarrowhead1
% End of user PostScript
0 1 .679 r
.55969 .6031 m
.5564 .59743 L
s
% Start of user PostScript
0.11938925 0.2062064 0.1127952 0.19486284 MAarrowhead1
% End of user PostScript
0 1 .995 r
.5379 .56555 m
.53581 .56194 L
s
% Start of user PostScript
0.075799819 0.13110424 0.07161745 0.12388485 MAarrowhead1
% End of user PostScript
0 .69 1 r
.52407 .54166 m
.52274 .53937 L
s
% Start of user PostScript
0.048141954 0.083325555 0.045486977 0.078734844 MAarrowhead1
% End of user PostScript
0 .375 1 r
.51529 .52647 m
.51445 .52502 L
s
% Start of user PostScript
0.03058128 0.05294966 0.028895178 0.050031737 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50971 .51682 m
.50918 .51589 L
s
% Start of user PostScript
0.019427899 0.033644175 0.018356874 0.031789897 MAarrowhead1
% End of user PostScript
0 .602 1 r
.20339 0 m
.21941 .02598 L
.23515 .05164 L
.24998 .07595 L
.26397 .09897 L
.27715 .12077 L
.28959 .14141 L
.30132 .16094 L
.31239 .17943 L
.32283 .19693 L
.33268 .21349 L
.34198 .22915 L
.35075 .24397 L
.35903 .25799 L
.36685 .27124 L
.37423 .28378 L
.3812 .29563 L
.38778 .30684 L
.394 .31744 L
.39986 .32747 L
.4054 .33694 L
.41063 .3459 L
.41558 .35436 L
.42024 .36237 L
.42465 .36994 L
.42881 .37709 L
.43275 .38385 L
.43646 .39024 L
.43997 .39628 L
.44329 .40198 L
.44642 .40738 L
.44937 .41248 L
.45217 .41729 L
.45481 .42185 L
.4573 .42615 L
.45966 .43022 L
.46188 .43406 L
.46399 .43769 L
.46597 .44112 L
.46785 .44437 L
.46962 .44743 L
.4713 .45033 L
.47288 .45306 L
.47438 .45565 L
.47579 .45809 L
.47713 .4604 L
.47839 .46258 L
.47958 .46465 L
.4807 .46659 L
.48177 .46843 L
Mistroke
.48277 .47017 L
.48372 .47182 L
.48462 .47337 L
.48547 .47484 L
.48627 .47622 L
.48703 .47754 L
.48774 .47877 L
.48842 .47994 L
.48906 .48105 L
.48966 .48209 L
.49023 .48308 L
.49077 .48401 L
.49128 .48489 L
.49176 .48573 L
.49221 .48651 L
.49264 .48726 L
.49305 .48796 L
.49343 .48862 L
.49379 .48925 L
.49413 .48984 L
.49446 .4904 L
.49476 .49093 L
.49505 .49143 L
.49533 .4919 L
.49558 .49235 L
.49583 .49277 L
.49606 .49317 L
.49627 .49355 L
.49648 .4939 L
.49667 .49424 L
.49686 .49456 L
.49703 .49486 L
.49719 .49514 L
.49735 .49541 L
.49749 .49566 L
.49763 .4959 L
.49776 .49613 L
.49789 .49634 L
.498 .49654 L
.49811 .49673 L
.49822 .49691 L
.49832 .49708 L
.49841 .49724 L
.4985 .49739 L
.49858 .49754 L
.49866 .49767 L
.49873 .4978 L
.4988 .49792 L
.49887 .49804 L
.49893 .49815 L
Mistroke
.49899 .49825 L
.49904 .49834 L
.4991 .49844 L
.49915 .49852 L
.49919 .4986 L
.49924 .49868 L
.49928 .49875 L
.49932 .49882 L
.49936 .49889 L
.49939 .49895 L
.49943 .49901 L
.49946 .49906 L
.49949 .49911 L
.49952 .49916 L
.49954 .49921 L
.49957 .49925 L
.49959 .49929 L
.49961 .49933 L
.49964 .49937 L
.49966 .4994 L
.49967 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49952 L
.49974 .49955 L
.49975 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49971 L
.49984 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
Mistroke
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
Mfstroke
1 0 0 r
% Start of user PostScript
-7.4881528 -5.5768717 -6.9081074 -5.5592195 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-6.382369 -5.5038565 -5.9049625 -5.4180257 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-3.546138 -4.3782049 -3.310757 -4.2060042 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-2.0913125 -3.0617397 -1.9633532 -2.914941 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-1.2773163 -2.0342573 -1.2028785 -1.9291073 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-0.7952054 -1.3207342 -0.75009185 -1.250152 MAarrowhead1
% End of user PostScript
.266 1 0 r
.24998 .07595 m
.26397 .09897 L
s
% Start of user PostScript
-0.50003948 -0.84810705 -0.47206964 -0.80206323 MAarrowhead1
% End of user PostScript
0 1 .049 r
.34198 .22915 m
.35075 .24397 L
s
% Start of user PostScript
-0.3160478 -0.54169511 -0.2984975 -0.51206019 MAarrowhead1
% End of user PostScript
0 1 .364 r
.39986 .32747 m
.4054 .33694 L
s
% Start of user PostScript
-0.20027486 -0.34506991 -0.18919435 -0.3261204 MAarrowhead1
% End of user PostScript
0 1 .679 r
.43646 .39024 m
.43997 .39628 L
s
% Start of user PostScript
-0.12707678 -0.21952625 -0.12005908 -0.2074483 MAarrowhead1
% End of user PostScript
0 1 .995 r
.45966 .43022 m
.46188 .43406 L
s
% Start of user PostScript
-0.080684463 -0.13956617 -0.076232879 -0.13188029 MAarrowhead1
% End of user PostScript
0 .69 1 r
.47438 .45565 m
.47579 .45809 L
s
% Start of user PostScript
-0.051245516 -0.088701553 -0.048419478 -0.083814492 MAarrowhead1
% End of user PostScript
0 .375 1 r
.48372 .47182 m
.48462 .47337 L
s
% Start of user PostScript
-0.032553151 -0.05636519 -0.03075836 -0.053258993 MAarrowhead1
% End of user PostScript
0 .06 1 r
.48966 .48209 m
.49023 .48308 L
s
% Start of user PostScript
-0.020680728 -0.035814185 -0.019540646 -0.033840291 MAarrowhead1
% End of user PostScript
0 .03 1 r
.65487 0 m
.63318 .04807 L
.61039 .09974 L
.59093 .14498 L
.57432 .18464 L
.56017 .21942 L
.54815 .24997 L
.53795 .27682 L
.52932 .30045 L
.52204 .32126 L
.51592 .33961 L
.51079 .35582 L
.50651 .37015 L
.50295 .38284 L
.50002 .39409 L
.49763 .40408 L
.49568 .41296 L
.49412 .42088 L
.49288 .42794 L
.49192 .43426 L
.4912 .43991 L
.49067 .44498 L
.4903 .44953 L
.49007 .45363 L
.48996 .45733 L
.48994 .46068 L
.49 .4637 L
.49012 .46645 L
.4903 .46894 L
.49051 .47121 L
.49075 .47328 L
.49102 .47517 L
.4913 .47691 L
.4916 .47849 L
.49191 .47995 L
.49222 .48129 L
.49253 .48253 L
.49284 .48367 L
.49314 .48472 L
.49344 .4857 L
.49374 .4866 L
.49403 .48744 L
.49431 .48822 L
.49458 .48894 L
.49484 .48962 L
.49509 .49025 L
.49533 .49083 L
.49556 .49138 L
.49579 .49189 L
.496 .49237 L
Mistroke
.49621 .49282 L
.4964 .49324 L
.49659 .49363 L
.49677 .494 L
.49694 .49435 L
.4971 .49467 L
.49725 .49498 L
.4974 .49527 L
.49753 .49554 L
.49767 .49579 L
.49779 .49603 L
.49791 .49625 L
.49802 .49646 L
.49813 .49666 L
.49823 .49685 L
.49832 .49703 L
.49842 .49719 L
.4985 .49735 L
.49858 .4975 L
.49866 .49764 L
.49873 .49777 L
.4988 .49789 L
.49887 .49801 L
.49893 .49812 L
.49899 .49823 L
.49904 .49833 L
.4991 .49842 L
.49914 .49851 L
.49919 .49859 L
.49924 .49867 L
.49928 .49874 L
.49932 .49881 L
.49936 .49888 L
.49939 .49894 L
.49942 .499 L
.49946 .49905 L
.49949 .49911 L
.49951 .49915 L
.49954 .4992 L
.49957 .49925 L
.49959 .49929 L
.49961 .49933 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
Mistroke
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .4997 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49988 .49978 L
.49988 .4998 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
2.2720519 -4.8600672 1.9477916 -4.247458 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
1.6679757 -3.7146387 1.4266071 -3.2510667 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
0.45435398 -1.3115163 0.38182496 -1.1569783 MAarrowhead1
% End of user PostScript
1 .788 0 r
.54815 .24997 m
.53795 .27682 L
s
% Start of user PostScript
0.096294808 -0.50005814 0.075897525 -0.4463587 MAarrowhead1
% End of user PostScript
.897 1 0 r
.50002 .39409 m
.49763 .40408 L
s
% Start of user PostScript
0.000047901918 -0.21182423 -0.0047497757 -0.19184295 MAarrowhead1
% End of user PostScript
.581 1 0 r
.4903 .44953 m
.49007 .45363 L
s
% Start of user PostScript
-0.01939593 -0.10093365 -0.019850546 -0.092730851 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49075 .47328 m
.49102 .47517 L
s
% Start of user PostScript
-0.018496296 -0.053435181 -0.017960965 -0.049651089 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49314 .48472 m
.49344 .4857 L
s
% Start of user PostScript
-0.013713196 -0.030551921 -0.013111176 -0.028601349 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49533 .49083 m
.49556 .49138 L
s
% Start of user PostScript
-0.0093359667 -0.018331232 -0.008870252 -0.0172361 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49694 .49435 m
.4971 .49467 L
s
% Start of user PostScript
-0.0061296384 -0.011303515 -0.0058073027 -0.010653537 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49802 .49646 m
.49813 .49666 L
s
% Start of user PostScript
-0.0039573742 -0.0070725799 -0.0037441761 -0.0066741779 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49873 .49777 m
.4988 .49789 L
s
% Start of user PostScript
-0.002534295 -0.0044588684 -0.0023961703 -0.004210372 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49919 .49859 m
.49924 .49867 L
s
% Start of user PostScript
-0.001616504 -0.0028219018 -0.0015278988 -0.0026654913 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49949 .49911 m
.49951 .49915 L
s
% Start of user PostScript
-0.0010290549 -0.0017893776 -0.00097249054 -0.0016904703 MAarrowhead1
% End of user PostScript
0 .596 1 r
.87463 1 m
.85144 .97906 L
.82913 .95774 L
.80845 .93691 L
.78925 .91664 L
.77139 .89698 L
.75478 .87796 L
.7393 .85961 L
.72487 .84194 L
.7114 .82496 L
.69881 .80866 L
.68705 .79304 L
.67604 .7781 L
.66573 .76382 L
.65607 .75019 L
.64701 .73719 L
.63851 .7248 L
.63053 .713 L
.62304 .70177 L
.616 .6911 L
.60939 .68095 L
.60316 .67131 L
.59731 .66215 L
.5918 .65347 L
.58662 .64522 L
.58173 .63741 L
.57713 .63 L
.5728 .62297 L
.56872 .61632 L
.56487 .61001 L
.56124 .60404 L
.55782 .59838 L
.55459 .59303 L
.55155 .58796 L
.54868 .58316 L
.54597 .57863 L
.54341 .57433 L
.541 .57027 L
.53872 .56642 L
.53657 .56279 L
.53454 .55935 L
.53263 .5561 L
.53082 .55302 L
.52911 .55011 L
.5275 .54736 L
.52598 .54476 L
.52454 .5423 L
.52319 .53998 L
.5219 .53778 L
.52069 .53571 L
Mistroke
.51955 .53374 L
.51847 .53189 L
.51745 .53013 L
.51648 .52848 L
.51557 .52691 L
.51471 .52543 L
.5139 .52403 L
.51313 .52271 L
.51241 .52146 L
.51172 .52028 L
.51108 .51916 L
.51047 .5181 L
.50989 .51711 L
.50934 .51617 L
.50883 .51527 L
.50834 .51443 L
.50788 .51364 L
.50745 .51289 L
.50704 .51218 L
.50665 .51151 L
.50628 .51087 L
.50593 .51027 L
.50561 .50971 L
.5053 .50917 L
.50501 .50867 L
.50473 .50819 L
.50447 .50774 L
.50422 .50731 L
.50399 .50691 L
.50377 .50653 L
.50356 .50617 L
.50337 .50583 L
.50318 .50551 L
.503 .5052 L
.50284 .50492 L
.50268 .50465 L
.50253 .50439 L
.5024 .50415 L
.50226 .50392 L
.50214 .5037 L
.50202 .5035 L
.50191 .50331 L
.5018 .50312 L
.5017 .50295 L
.50161 .50279 L
.50152 .50264 L
.50144 .50249 L
.50136 .50235 L
.50128 .50222 L
.50121 .5021 L
Mistroke
.50115 .50198 L
.50108 .50188 L
.50102 .50177 L
.50097 .50167 L
.50091 .50158 L
.50086 .50149 L
.50082 .50141 L
.50077 .50133 L
.50073 .50126 L
.50069 .50119 L
.50065 .50113 L
.50061 .50106 L
.50058 .50101 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .5008 L
.50044 .50076 L
.50041 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .50041 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
Mistroke
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
Mfstroke
1 0 0 r
% Start of user PostScript
6.4883352 -1.1823515 5.8496391 -0.63038477 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
5.2836709 -0.17383357 4.7814124 0.2012382 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.5020469 1.3702825 2.2970752 1.4108944 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.3179931 1.3411384 1.224035 1.3041207 MAarrowhead1
% End of user PostScript
.897 1 0 r
.87463 1 m
.85144 .97906 L
s
% Start of user PostScript
0.75104939 1.0016089 0.70287921 0.9581272 MAarrowhead1
% End of user PostScript
.581 1 0 r
.72487 .84194 m
.7114 .82496 L
s
% Start of user PostScript
0.44974105 0.68388103 0.42279896 0.64991159 MAarrowhead1
% End of user PostScript
.266 1 0 r
.63851 .7248 m
.63053 .713 L
s
% Start of user PostScript
0.27702237 0.4495985 0.26106875 0.42600038 MAarrowhead1
% End of user PostScript
0 1 .049 r
.58662 .64522 m
.58173 .63741 L
s
% Start of user PostScript
0.17323407 0.29044756 0.16346789 0.27481407 MAarrowhead1
% End of user PostScript
0 1 .364 r
.55459 .59303 m
.55155 .58796 L
s
% Start of user PostScript
0.10918279 0.18605865 0.10309544 0.17592245 MAarrowhead1
% End of user PostScript
0 1 .679 r
.53454 .55935 m
.53263 .5561 L
s
% Start of user PostScript
0.069088808 0.11869564 0.065258601 0.11219098 MAarrowhead1
% End of user PostScript
0 1 .995 r
.5219 .53778 m
.52069 .53571 L
s
% Start of user PostScript
0.043806215 0.075566447 0.041384586 0.071413202 MAarrowhead1
% End of user PostScript
0 .69 1 r
.5139 .52403 m
.51313 .52271 L
s
% Start of user PostScript
0.027803735 0.048059562 0.026268941 0.045414293 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50883 .51527 m
.50834 .51443 L
s
% Start of user PostScript
0.017655939 0.030549867 0.016682017 0.028867138 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50561 .50971 m
.5053 .50917 L
s
% Start of user PostScript
0.01121473 0.019414594 0.010596335 0.018344823 MAarrowhead1
% End of user PostScript
.849 1 0 r
.30446 0 m
.30953 .02475 L
.31674 .05664 L
.32399 .08602 L
.33122 .11311 L
.33839 .13815 L
.34544 .1613 L
.35235 .18275 L
.3591 .20265 L
.36566 .22113 L
.37202 .23831 L
.37817 .25431 L
.3841 .26921 L
.38981 .28311 L
.39529 .29608 L
.40055 .30821 L
.40559 .31955 L
.41041 .33016 L
.41502 .34009 L
.41942 .34941 L
.42361 .35814 L
.4276 .36633 L
.43141 .37403 L
.43503 .38125 L
.43847 .38804 L
.44174 .39442 L
.44484 .40042 L
.44779 .40607 L
.45059 .41139 L
.45325 .41639 L
.45576 .4211 L
.45815 .42554 L
.46041 .42972 L
.46256 .43366 L
.46459 .43738 L
.46651 .44088 L
.46833 .44418 L
.47005 .4473 L
.47169 .45023 L
.47323 .45301 L
.47469 .45562 L
.47607 .45809 L
.47738 .46042 L
.47862 .46261 L
.47979 .46469 L
.4809 .46665 L
.48194 .4685 L
.48293 .47024 L
.48387 .47189 L
.48476 .47345 L
Mistroke
.48559 .47492 L
.48638 .4763 L
.48713 .47761 L
.48784 .47885 L
.48851 .48002 L
.48914 .48113 L
.48974 .48217 L
.4903 .48315 L
.49083 .48408 L
.49134 .48496 L
.49182 .48579 L
.49227 .48658 L
.49269 .48732 L
.49309 .48802 L
.49347 .48868 L
.49383 .4893 L
.49417 .48989 L
.49449 .49045 L
.4948 .49098 L
.49508 .49148 L
.49535 .49195 L
.49561 .49239 L
.49585 .49281 L
.49608 .49321 L
.4963 .49358 L
.4965 .49394 L
.49669 .49427 L
.49688 .49459 L
.49705 .49488 L
.49721 .49517 L
.49736 .49543 L
.49751 .49568 L
.49765 .49592 L
.49778 .49615 L
.4979 .49636 L
.49801 .49656 L
.49812 .49675 L
.49823 .49693 L
.49833 .4971 L
.49842 .49726 L
.4985 .49741 L
.49859 .49755 L
.49867 .49769 L
.49874 .49781 L
.49881 .49794 L
.49887 .49805 L
.49894 .49816 L
.49899 .49826 L
.49905 .49835 L
.4991 .49845 L
Mistroke
.49915 .49853 L
.4992 .49861 L
.49924 .49869 L
.49928 .49876 L
.49932 .49883 L
.49936 .49889 L
.4994 .49895 L
.49943 .49901 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49921 L
.49957 .49926 L
.49959 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
Mistroke
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
1 0 0 r
% Start of user PostScript
0.80240797 -7.6687225 0.55320164 -6.8909826 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
0.3450977 -6.2035118 0.172177 -5.5950062 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-0.40424072 -2.8614324 -0.4308636 -2.6190002 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.45496344 -1.4748174 -0.44542612 -1.366606 MAarrowhead1
% End of user PostScript
.897 1 0 r
.32399 .08602 m
.33122 .11311 L
s
% Start of user PostScript
-0.3520194 -0.82796293 -0.33755413 -0.77377079 MAarrowhead1
% End of user PostScript
.581 1 0 r
.37817 .25431 m
.3841 .26921 L
s
% Start of user PostScript
-0.24366076 -0.4913865 -0.23179919 -0.46158246 MAarrowhead1
% End of user PostScript
.266 1 0 r
.41942 .34941 m
.42361 .35814 L
s
% Start of user PostScript
-0.16116615 -0.30118686 -0.15278115 -0.28372128 MAarrowhead1
% End of user PostScript
0 1 .049 r
.44779 .40607 m
.45059 .41139 L
s
% Start of user PostScript
-0.10441622 -0.18785762 -0.098819135 -0.17722818 MAarrowhead1
% End of user PostScript
0 1 .364 r
.46651 .44088 m
.46833 .44418 L
s
% Start of user PostScript
-0.066982174 -0.11824205 -0.063340388 -0.11163716 MAarrowhead1
% End of user PostScript
0 1 .679 r
.47862 .46261 m
.47979 .46469 L
s
% Start of user PostScript
-0.042760696 -0.074770912 -0.040419673 -0.070621723 MAarrowhead1
% End of user PostScript
0 1 .995 r
.48638 .4763 m
.48713 .47761 L
s
% Start of user PostScript
-0.027232553 -0.047392902 -0.025736545 -0.044771735 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49134 .48496 m
.49182 .48579 L
s
% Start of user PostScript
-0.017322622 -0.030075077 -0.016369392 -0.0284145 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49449 .49045 m
.4948 .49098 L
s
% Start of user PostScript
-0.011012358 -0.019096658 -0.010405856 -0.018043136 MAarrowhead1
% End of user PostScript
0 .06 1 r
.4965 .49394 m
.49669 .49427 L
s
% Start of user PostScript
-0.0069987082 -0.01212933 -0.0066130934 -0.011460463 MAarrowhead1
% End of user PostScript
0 .099 1 r
.23261 0 m
.23776 .01086 L
.25142 .03919 L
.26444 .06577 L
.27683 .09074 L
.28862 .11419 L
.29983 .13622 L
.31047 .15695 L
.32059 .17643 L
.33019 .19477 L
.33929 .21203 L
.34794 .22828 L
.35613 .24359 L
.3639 .258 L
.37126 .27159 L
.37823 .28439 L
.38484 .29646 L
.39109 .30784 L
.39702 .31857 L
.40262 .32869 L
.40793 .33824 L
.41295 .34724 L
.41771 .35574 L
.4222 .36376 L
.42646 .37133 L
.43048 .37847 L
.43429 .38521 L
.43789 .39158 L
.44129 .39759 L
.44451 .40326 L
.44756 .40862 L
.45044 .41368 L
.45316 .41845 L
.45573 .42297 L
.45816 .42723 L
.46046 .43125 L
.46263 .43505 L
.46469 .43864 L
.46663 .44203 L
.46847 .44523 L
.4702 .44826 L
.47184 .45111 L
.47339 .45381 L
.47485 .45636 L
.47624 .45877 L
.47755 .46105 L
.47878 .4632 L
.47995 .46523 L
.48106 .46715 L
.4821 .46896 L
Mistroke
.48308 .47067 L
.48402 .47229 L
.4849 .47382 L
.48573 .47526 L
.48651 .47663 L
.48726 .47791 L
.48796 .47913 L
.48862 .48028 L
.48925 .48137 L
.48984 .4824 L
.4904 .48337 L
.49093 .48429 L
.49143 .48515 L
.4919 .48597 L
.49235 .48674 L
.49277 .48748 L
.49317 .48817 L
.49355 .48882 L
.4939 .48943 L
.49424 .49002 L
.49456 .49057 L
.49486 .49109 L
.49514 .49158 L
.49541 .49204 L
.49566 .49248 L
.4959 .4929 L
.49613 .49329 L
.49634 .49366 L
.49654 .49401 L
.49673 .49434 L
.49691 .49465 L
.49708 .49494 L
.49724 .49522 L
.49739 .49549 L
.49754 .49574 L
.49767 .49597 L
.4978 .49619 L
.49792 .4964 L
.49804 .4966 L
.49815 .49679 L
.49825 .49697 L
.49834 .49713 L
.49844 .49729 L
.49852 .49744 L
.4986 .49758 L
.49868 .49771 L
.49875 .49784 L
.49882 .49796 L
.49889 .49807 L
.49895 .49818 L
Mistroke
.49901 .49828 L
.49906 .49837 L
.49911 .49846 L
.49916 .49855 L
.49921 .49863 L
.49925 .4987 L
.49929 .49878 L
.49933 .49884 L
.49937 .49891 L
.4994 .49897 L
.49944 .49902 L
.49947 .49908 L
.4995 .49913 L
.49952 .49918 L
.49955 .49922 L
.49958 .49926 L
.4996 .49931 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49945 L
.4997 .49948 L
.49971 .49951 L
.49973 .49953 L
.49975 .49956 L
.49976 .49958 L
.49977 .49961 L
.49978 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
Mistroke
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
1 0 0 r
% Start of user PostScript
-1.4952072 -4.7668922 -1.4620532 -4.4188074 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-1.4241497 -4.1013013 -1.3826365 -3.8111675 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.0546743 -2.3461858 -1.008293 -2.1965028 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.71769897 -1.4081552 -0.68187354 -1.3240665 MAarrowhead1
% End of user PostScript
.897 1 0 r
.26444 .06577 m
.27683 .09074 L
s
% Start of user PostScript
-0.47111729 -0.86845242 -0.4463356 -0.81852639 MAarrowhead1
% End of user PostScript
.581 1 0 r
.34794 .22828 m
.35613 .24359 L
s
% Start of user PostScript
-0.3041298 -0.54343666 -0.28774294 -0.51282844 MAarrowhead1
% End of user PostScript
.266 1 0 r
.40262 .32869 m
.40793 .33824 L
s
% Start of user PostScript
-0.19475488 -0.34262215 -0.18413959 -0.32352878 MAarrowhead1
% End of user PostScript
0 1 .049 r
.43789 .39158 m
.44129 .39759 L
s
% Start of user PostScript
-0.12422178 -0.21684163 -0.1174126 -0.20482307 MAarrowhead1
% End of user PostScript
0 1 .364 r
.46046 .43125 m
.46263 .43505 L
s
% Start of user PostScript
-0.079077779 -0.13750161 -0.074731012 -0.12990138 MAarrowhead1
% End of user PostScript
0 1 .679 r
.47485 .45636 m
.47624 .45877 L
s
% Start of user PostScript
-0.050290569 -0.087275793 -0.047522334 -0.082458375 MAarrowhead1
% End of user PostScript
0 1 .995 r
.48402 .47229 m
.4849 .47382 L
s
% Start of user PostScript
-0.031967357 -0.055423099 -0.030206497 -0.052365988 MAarrowhead1
% End of user PostScript
0 .69 1 r
.48984 .4824 m
.4904 .48337 L
s
% Start of user PostScript
-0.020315197 -0.035204117 -0.019195785 -0.033262947 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49355 .48882 m
.4939 .48943 L
s
% Start of user PostScript
-0.012908697 -0.022363973 -0.012197276 -0.021131028 MAarrowhead1
% End of user PostScript
0 .06 1 r
.4959 .4929 m
.49613 .49329 L
s
% Start of user PostScript
-0.0082019539 -0.014207934 -0.0077498906 -0.013424706 MAarrowhead1
% End of user PostScript
.852 0 1 r
.02787 1 m
.0393 .98357 L
.09369 .90669 L
.14122 .84075 L
.18276 .78426 L
.21912 .73591 L
.25095 .6946 L
.27884 .65934 L
.3033 .62929 L
.32478 .60375 L
.34365 .58207 L
.36026 .56371 L
.37488 .54822 L
.38777 .53518 L
.39915 .52424 L
.40921 .51511 L
.41812 .50752 L
.42601 .50125 L
.43301 .49611 L
.43924 .49193 L
.44479 .48857 L
.44974 .4859 L
.45416 .48382 L
.45812 .48223 L
.46167 .48106 L
.46485 .48025 L
.46772 .47972 L
.47031 .47945 L
.47264 .47937 L
.47476 .47946 L
.47667 .47968 L
.47841 .48001 L
.48 .48043 L
.48144 .48092 L
.48276 .48146 L
.48397 .48204 L
.48507 .48264 L
.48609 .48327 L
.48702 .4839 L
.48788 .48454 L
.48867 .48517 L
.48941 .4858 L
.49008 .48642 L
.49071 .48703 L
.49129 .48762 L
.49184 .4882 L
.49234 .48876 L
.49281 .4893 L
.49324 .48982 L
.49365 .49032 L
Mistroke
.49403 .4908 L
.49438 .49126 L
.49472 .49171 L
.49503 .49213 L
.49532 .49254 L
.49559 .49292 L
.49585 .49329 L
.49609 .49364 L
.49631 .49397 L
.49652 .49429 L
.49672 .4946 L
.49691 .49488 L
.49708 .49516 L
.49725 .49541 L
.49741 .49566 L
.49755 .49589 L
.49769 .49611 L
.49782 .49632 L
.49794 .49652 L
.49806 .49671 L
.49817 .49689 L
.49827 .49706 L
.49837 .49722 L
.49846 .49737 L
.49854 .49751 L
.49862 .49765 L
.4987 .49778 L
.49877 .4979 L
.49884 .49801 L
.49891 .49812 L
.49897 .49822 L
.49902 .49832 L
.49908 .49841 L
.49913 .4985 L
.49918 .49858 L
.49922 .49866 L
.49927 .49873 L
.49931 .4988 L
.49934 .49887 L
.49938 .49893 L
.49942 .49899 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49953 .49919 L
.49956 .49924 L
.49958 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .49939 L
Mistroke
.49967 .49943 L
.49969 .49946 L
.4997 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49976 .49959 L
.49978 .49961 L
.49979 .49964 L
.4998 .49966 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49982 L
.4999 .49983 L
.4999 .49984 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
Mistroke
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-5.9026424 8.8329965 -5.1460665 7.5992248 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-4.4887642 6.5331746 -3.9175775 5.6122883 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.540241 1.8789377 -1.3524578 1.5971696 MAarrowhead1
% End of user PostScript
1 .788 0 r
.21912 .73591 m
.25095 .6946 L
s
% Start of user PostScript
-0.56176668 0.47182561 -0.49810765 0.38919079 MAarrowhead1
% End of user PostScript
.897 1 0 r
.38777 .53518 m
.39915 .52424 L
s
% Start of user PostScript
-0.22446108 0.070354853 -0.20169923 0.048482074 MAarrowhead1
% End of user PostScript
.581 1 0 r
.44974 .4859 m
.45416 .48382 L
s
% Start of user PostScript
-0.10051933 -0.028203418 -0.091677117 -0.032367091 MAarrowhead1
% End of user PostScript
.266 1 0 r
.47476 .47946 m
.47667 .47968 L
s
% Start of user PostScript
-0.050488946 -0.041085606 -0.046656808 -0.040638044 MAarrowhead1
% End of user PostScript
0 1 .049 r
.48609 .48327 m
.48702 .4839 L
s
% Start of user PostScript
-0.027827459 -0.03346529 -0.025960189 -0.032198079 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49184 .4882 m
.49234 .48876 L
s
% Start of user PostScript
-0.016329331 -0.023601355 -0.015323296 -0.022483914 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49503 .49213 m
.49532 .49254 L
s
% Start of user PostScript
-0.0099455248 -0.015738369 -0.0093636488 -0.01492916 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49691 .49488 m
.49708 .49516 L
s
% Start of user PostScript
-0.0061824311 -0.010235503 -0.0058309493 -0.0096898384 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49806 .49671 m
.49817 .49689 L
s
% Start of user PostScript
-0.0038846243 -0.0065781282 -0.0036670991 -0.0062214214 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49877 .4979 m
.49884 .49801 L
s
% Start of user PostScript
-0.002454297 -0.0042032249 -0.0023179326 -0.0039734088 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49922 .49866 m
.49927 .49873 L
s
% Start of user PostScript
-0.0015549444 -0.0026780714 -0.0014688905 -0.0025310472 MAarrowhead1
% End of user PostScript
.707 1 0 r
.54452 0 m
.53855 .01862 L
.52402 .06664 L
.51195 .10914 L
.50198 .14682 L
.4938 .18026 L
.48715 .21 L
.4818 .23648 L
.47755 .2601 L
.47424 .2812 L
.47172 .30009 L
.46986 .31702 L
.46857 .33223 L
.46773 .34592 L
.46729 .35826 L
.46717 .36941 L
.46731 .3795 L
.46767 .38864 L
.4682 .39695 L
.46886 .40451 L
.46964 .4114 L
.4705 .4177 L
.47142 .42346 L
.47238 .42874 L
.47337 .43358 L
.47438 .43804 L
.4754 .44214 L
.47641 .44593 L
.47741 .44943 L
.4784 .45267 L
.47936 .45566 L
.48031 .45844 L
.48122 .46103 L
.48211 .46343 L
.48297 .46566 L
.4838 .46774 L
.4846 .46969 L
.48537 .4715 L
.4861 .4732 L
.4868 .47478 L
.48748 .47626 L
.48812 .47765 L
.48874 .47895 L
.48932 .48017 L
.48988 .48132 L
.49041 .48239 L
.49092 .4834 L
.4914 .48435 L
.49186 .48524 L
.49229 .48608 L
Mistroke
.4927 .48687 L
.49309 .48761 L
.49347 .48831 L
.49382 .48897 L
.49415 .48959 L
.49447 .49018 L
.49477 .49073 L
.49505 .49125 L
.49532 .49174 L
.49557 .4922 L
.49581 .49263 L
.49604 .49304 L
.49626 .49343 L
.49646 .4938 L
.49666 .49414 L
.49684 .49447 L
.49701 .49477 L
.49718 .49506 L
.49733 .49534 L
.49748 .4956 L
.49761 .49584 L
.49775 .49607 L
.49787 .49629 L
.49799 .49649 L
.4981 .49669 L
.4982 .49687 L
.4983 .49704 L
.49839 .49721 L
.49848 .49736 L
.49857 .49751 L
.49864 .49765 L
.49872 .49778 L
.49879 .4979 L
.49886 .49801 L
.49892 .49812 L
.49898 .49823 L
.49903 .49833 L
.49909 .49842 L
.49914 .49851 L
.49919 .49859 L
.49923 .49867 L
.49927 .49874 L
.49931 .49881 L
.49935 .49887 L
.49939 .49894 L
.49942 .499 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
Mistroke
.49956 .49924 L
.49959 .49929 L
.49961 .49932 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
Mistroke
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
Mfstroke
1 0 0 r
% Start of user PostScript
2.1552799 -5.6740229 1.8236147 -4.9925731 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
1.53865 -4.3979085 1.2940176 -3.8786737 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
0.33008458 -1.6727023 0.26110301 -1.4925353 MAarrowhead1
% End of user PostScript
1 .788 0 r
.50198 .14682 m
.4938 .18026 L
s
% Start of user PostScript
0.0039617191 -0.70636152 -0.012395479 -0.63947269 MAarrowhead1
% End of user PostScript
.897 1 0 r
.46857 .33223 m
.46773 .34592 L
s
% Start of user PostScript
-0.062866938 -0.33553365 -0.064530152 -0.30815573 MAarrowhead1
% End of user PostScript
.581 1 0 r
.46964 .4114 m
.4705 .4177 L
s
% Start of user PostScript
-0.060719515 -0.17719148 -0.059002294 -0.1646017 MAarrowhead1
% End of user PostScript
.266 1 0 r
.47741 .44943 m
.4784 .45267 L
s
% Start of user PostScript
-0.045180293 -0.10114145 -0.043207781 -0.094669401 MAarrowhead1
% End of user PostScript
0 1 .049 r
.4846 .46969 m
.48537 .4715 L
s
% Start of user PostScript
-0.030803126 -0.060625472 -0.029269789 -0.056998671 MAarrowhead1
% End of user PostScript
0 1 .364 r
.48988 .48132 m
.49041 .48239 L
s
% Start of user PostScript
-0.020237294 -0.037363168 -0.019174084 -0.035213081 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49347 .48831 m
.49382 .48897 L
s
% Start of user PostScript
-0.0130695 -0.023371464 -0.012365711 -0.022054414 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49581 .49263 m
.49604 .49304 L
s
% Start of user PostScript
-0.0083709468 -0.014732288 -0.0079148102 -0.013911078 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49733 .49534 m
.49748 .4956 L
s
% Start of user PostScript
-0.0053398198 -0.0093230025 -0.0050471601 -0.0088061997 MAarrowhead1
% End of user PostScript
0 .375 1 r
.4983 .49704 m
.49839 .49721 L
s
% Start of user PostScript
-0.0033994174 -0.005911531 -0.0032125704 -0.005584756 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49892 .49812 m
.49898 .49823 L
s
% Start of user PostScript
-0.0021619575 -0.0037521093 -0.002042957 -0.0035449946 MAarrowhead1
% End of user PostScript
1 .811 0 r
1 .64584 m
.98306 .65436 L
.941 .67259 L
.90331 .68625 L
.86949 .69606 L
.83908 .70265 L
.81168 .70656 L
.78696 .70824 L
.76461 .70808 L
.74436 .70641 L
.72598 .70353 L
.70928 .69968 L
.69406 .69505 L
.68017 .68983 L
.66747 .68416 L
.65584 .67816 L
.64518 .67193 L
.63537 .66557 L
.62635 .65915 L
.61804 .65271 L
.61036 .64632 L
.60326 .64002 L
.59669 .63382 L
.5906 .62776 L
.58495 .62186 L
.57969 .61614 L
.5748 .61059 L
.57025 .60524 L
.56601 .60008 L
.56205 .59513 L
.55835 .59037 L
.55489 .5858 L
.55165 .58144 L
.54862 .57726 L
.54579 .57328 L
.54313 .56947 L
.54063 .56585 L
.53829 .5624 L
.53609 .55911 L
.53402 .55599 L
.53208 .55302 L
.53026 .55019 L
.52854 .54751 L
.52692 .54497 L
.5254 .54256 L
.52397 .54027 L
.52262 .5381 L
.52135 .53604 L
.52015 .53409 L
.51902 .53224 L
Mistroke
.51796 .53049 L
.51695 .52883 L
.51601 .52727 L
.51511 .52578 L
.51427 .52438 L
.51348 .52305 L
.51273 .52179 L
.51202 .5206 L
.51135 .51947 L
.51072 .5184 L
.51013 .5174 L
.50957 .51644 L
.50904 .51554 L
.50854 .51469 L
.50806 .51388 L
.50762 .51312 L
.50719 .5124 L
.5068 .51172 L
.50642 .51108 L
.50607 .51047 L
.50573 .50989 L
.50541 .50935 L
.50511 .50883 L
.50483 .50835 L
.50457 .50789 L
.50431 .50745 L
.50408 .50704 L
.50385 .50666 L
.50364 .50629 L
.50344 .50594 L
.50325 .50562 L
.50307 .50531 L
.5029 .50501 L
.50274 .50474 L
.50259 .50448 L
.50245 .50423 L
.50231 .504 L
.50218 .50378 L
.50206 .50357 L
.50195 .50337 L
.50184 .50319 L
.50174 .50301 L
.50164 .50285 L
.50155 .50269 L
.50147 .50254 L
.50139 .5024 L
.50131 .50227 L
.50124 .50214 L
.50117 .50203 L
.50111 .50191 L
Mistroke
.50104 .50181 L
.50099 .50171 L
.50093 .50161 L
.50088 .50153 L
.50083 .50144 L
.50079 .50136 L
.50074 .50129 L
.5007 .50122 L
.50066 .50115 L
.50063 .50109 L
.50059 .50103 L
.50056 .50097 L
.50053 .50092 L
.5005 .50087 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50036 .50062 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
Mfstroke
1 0 0 r
% Start of user PostScript
7.6768577 -7.4759386 6.7836557 -6.2497158 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
6.0024423 -5.1997773 5.3186664 -4.3018948 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.3838362 -0.82720033 2.1402888 -0.58735925 MAarrowhead1
% End of user PostScript
1 .788 0 r
1 .64584 m
.98306 .65436 L
s
% Start of user PostScript
1.0602068 0.26139677 0.96612917 0.30871445 MAarrowhead1
% End of user PostScript
.897 1 0 r
.76461 .70808 m
.74436 .70641 L
s
% Start of user PostScript
0.52921476 0.41615103 0.48871898 0.41282732 MAarrowhead1
% End of user PostScript
.581 1 0 r
.64518 .67193 m
.63537 .66557 L
s
% Start of user PostScript
0.29035246 0.34386626 0.27074912 0.33114509 MAarrowhead1
% End of user PostScript
.266 1 0 r
.58495 .62186 m
.57969 .61614 L
s
% Start of user PostScript
0.16989376 0.24372594 0.1593854 0.2322722 MAarrowhead1
% End of user PostScript
0 1 .049 r
.55165 .58144 m
.54862 .57726 L
s
% Start of user PostScript
0.10330778 0.16287436 0.097249912 0.15452595 MAarrowhead1
% End of user PostScript
0 1 .364 r
.53208 .55302 m
.53026 .55019 L
s
% Start of user PostScript
0.064163622 0.10603119 0.060511358 0.10038663 MAarrowhead1
% End of user PostScript
0 1 .679 r
.52015 .53409 m
.51902 .53224 L
s
% Start of user PostScript
0.040298071 0.068176553 0.038040092 0.064482133 MAarrowhead1
% End of user PostScript
0 1 .995 r
.51273 .52179 m
.51202 .5206 L
s
% Start of user PostScript
0.025454436 0.043573023 0.024039693 0.041191419 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50806 .51388 m
.50762 .51312 L
s
% Start of user PostScript
0.01612506 0.027765657 0.01523252 0.026241596 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50511 .50883 m
.50483 .50835 L
s
% Start of user PostScript
0.010229935 0.017666727 0.0096648703 0.016694953 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50325 .50562 m
.50307 .50531 L
s
% Start of user PostScript
0.0064947498 0.011232699 0.0061363765 0.010614186 MAarrowhead1
% End of user PostScript
1 0 .097 r
.03868 0 m
.0594 .00969 L
.08986 .02602 L
.11781 .04288 L
.14352 .06005 L
.16718 .07734 L
.18901 .09461 L
.20917 .11173 L
.22781 .12861 L
.24508 .14516 L
.26109 .16132 L
.27596 .17705 L
.28978 .1923 L
.30265 .20705 L
.31463 .22128 L
.32581 .23498 L
.33624 .24815 L
.34598 .26079 L
.3551 .27289 L
.36362 .28448 L
.37161 .29555 L
.37909 .30611 L
.38611 .31619 L
.39269 .3258 L
.39887 .33494 L
.40467 .34364 L
.41013 .35192 L
.41525 .35978 L
.42007 .36726 L
.42461 .37435 L
.42887 .38108 L
.43289 .38747 L
.43667 .39353 L
.44024 .39927 L
.44359 .40471 L
.44676 .40987 L
.44974 .41476 L
.45255 .41939 L
.4552 .42377 L
.4577 .42792 L
.46006 .43184 L
.46229 .43556 L
.46438 .43908 L
.46636 .44241 L
.46823 .44555 L
.47 .44853 L
.47166 .45135 L
.47323 .45401 L
.47472 .45654 L
.47612 .45892 L
Mistroke
.47744 .46117 L
.47869 .4633 L
.47987 .46532 L
.48098 .46722 L
.48204 .46902 L
.48303 .47072 L
.48397 .47233 L
.48485 .47385 L
.48569 .47529 L
.48648 .47665 L
.48723 .47794 L
.48793 .47915 L
.4886 .4803 L
.48923 .48138 L
.48982 .48241 L
.49038 .48337 L
.49092 .48429 L
.49142 .48515 L
.49189 .48597 L
.49234 .48674 L
.49276 .48747 L
.49316 .48816 L
.49354 .48882 L
.49389 .48943 L
.49423 .49001 L
.49455 .49056 L
.49485 .49108 L
.49513 .49158 L
.4954 .49204 L
.49566 .49248 L
.49589 .49289 L
.49612 .49328 L
.49634 .49365 L
.49654 .494 L
.49673 .49433 L
.49691 .49465 L
.49708 .49494 L
.49724 .49522 L
.49739 .49548 L
.49754 .49573 L
.49767 .49597 L
.4978 .49619 L
.49792 .4964 L
.49804 .4966 L
.49814 .49679 L
.49825 .49696 L
.49834 .49713 L
.49843 .49729 L
.49852 .49744 L
.4986 .49758 L
Mistroke
.49868 .49771 L
.49875 .49784 L
.49882 .49796 L
.49889 .49807 L
.49895 .49818 L
.49901 .49828 L
.49906 .49837 L
.49911 .49846 L
.49916 .49855 L
.49921 .49863 L
.49925 .4987 L
.49929 .49877 L
.49933 .49884 L
.49937 .49891 L
.4994 .49897 L
.49944 .49902 L
.49947 .49908 L
.4995 .49913 L
.49952 .49918 L
.49955 .49922 L
.49958 .49926 L
.4996 .4993 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49945 L
.4997 .49948 L
.49971 .49951 L
.49973 .49953 L
.49974 .49956 L
.49976 .49958 L
.49977 .49961 L
.49978 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
Mistroke
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
Mfstroke
1 0 0 r
% Start of user PostScript
-6.919717 2.7491214 -6.2048825 2.0201021 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-5.5739633 1.4083656 -5.0163911 0.89715372 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.5272141 -0.86179145 -2.3083626 -0.95206975 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.2833714 -1.1057337 -1.1873518 -1.0885677 MAarrowhead1
% End of user PostScript
.897 1 0 r
.14352 .06005 m
.16718 .07734 L
s
% Start of user PostScript
-0.71296962 -0.87990284 -0.66563693 -0.84531478 MAarrowhead1
% End of user PostScript
.581 1 0 r
.28978 .1923 m
.30265 .20705 L
s
% Start of user PostScript
-0.42043651 -0.61540812 -0.39470885 -0.58590733 MAarrowhead1
% End of user PostScript
.266 1 0 r
.37161 .29555 m
.37909 .30611 L
s
% Start of user PostScript
-0.25677984 -0.4089077 -0.24181463 -0.38777316 MAarrowhead1
% End of user PostScript
0 1 .049 r
.42007 .36726 m
.42461 .37435 L
s
% Start of user PostScript
-0.15985701 -0.26548885 -0.15078772 -0.25130122 MAarrowhead1
% End of user PostScript
0 1 .364 r
.44974 .41476 m
.45255 .41939 L
s
% Start of user PostScript
-0.10051976 -0.17048536 -0.09489707 -0.16122986 MAarrowhead1
% End of user PostScript
0 1 .679 r
.46823 .44555 m
.47 .44853 L
s
% Start of user PostScript
-0.063532698 -0.10889152 -0.060004663 -0.10293436 MAarrowhead1
% End of user PostScript
0 1 .995 r
.47987 .46532 m
.48098 .46722 L
s
% Start of user PostScript
-0.040259616 -0.069366151 -0.038032182 -0.065556924 MAarrowhead1
% End of user PostScript
0 .69 1 r
.48723 .47794 m
.48793 .47915 L
s
% Start of user PostScript
-0.025545165 -0.044129361 -0.024134453 -0.041701445 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49189 .48597 m
.49234 .48674 L
s
% Start of user PostScript
-0.0162193 -0.028055737 -0.015324435 -0.026510715 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49485 .49108 m
.49513 .49158 L
s
% Start of user PostScript
-0.010301439 -0.017830885 -0.0097333446 -0.016848483 MAarrowhead1
% End of user PostScript
1 0 .444 r
0 .16324 m
.02771 .16109 L
.06459 .16099 L
.09798 .16341 L
.12828 .16787 L
.15583 .17396 L
.18091 .18134 L
.20379 .18974 L
.22471 .19889 L
.24386 .2086 L
.26142 .2187 L
.27756 .22903 L
.29241 .23949 L
.30609 .24997 L
.31872 .26038 L
.3304 .27068 L
.3412 .28079 L
.35122 .29069 L
.36052 .30033 L
.36915 .30969 L
.37719 .31876 L
.38467 .32751 L
.39164 .33595 L
.39815 .34407 L
.40423 .35186 L
.40991 .35933 L
.41522 .36648 L
.4202 .37332 L
.42486 .37985 L
.42923 .38608 L
.43332 .39202 L
.43717 .39768 L
.44078 .40306 L
.44417 .40819 L
.44736 .41306 L
.45036 .41768 L
.45318 .42208 L
.45583 .42625 L
.45833 .4302 L
.46068 .43396 L
.46289 .43752 L
.46498 .44089 L
.46694 .44409 L
.4688 .44712 L
.47054 .44999 L
.47219 .4527 L
.47374 .45528 L
.47521 .45771 L
.47659 .46002 L
.47789 .4622 L
Mistroke
.47912 .46426 L
.48028 .46622 L
.48138 .46806 L
.48241 .46981 L
.48339 .47146 L
.48431 .47303 L
.48518 .47451 L
.486 .47591 L
.48677 .47723 L
.48751 .47848 L
.4882 .47966 L
.48885 .48078 L
.48947 .48183 L
.49005 .48283 L
.4906 .48377 L
.49112 .48467 L
.49161 .48551 L
.49207 .48631 L
.49251 .48706 L
.49292 .48777 L
.49331 .48845 L
.49368 .48908 L
.49403 .48968 L
.49436 .49025 L
.49467 .49079 L
.49497 .49129 L
.49524 .49177 L
.49551 .49223 L
.49575 .49265 L
.49599 .49306 L
.49621 .49344 L
.49642 .4938 L
.49662 .49414 L
.4968 .49447 L
.49698 .49477 L
.49715 .49506 L
.4973 .49533 L
.49745 .49559 L
.49759 .49583 L
.49773 .49606 L
.49785 .49628 L
.49797 .49648 L
.49808 .49668 L
.49819 .49686 L
.49829 .49703 L
.49838 .4972 L
.49847 .49735 L
.49856 .4975 L
.49863 .49764 L
.49871 .49777 L
Mistroke
.49878 .49789 L
.49885 .49801 L
.49891 .49812 L
.49897 .49822 L
.49903 .49832 L
.49908 .49841 L
.49913 .4985 L
.49918 .49858 L
.49923 .49866 L
.49927 .49873 L
.49931 .4988 L
.49935 .49887 L
.49938 .49893 L
.49942 .49899 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .49919 L
.49956 .49924 L
.49958 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .49939 L
.49967 .49943 L
.49969 .49946 L
.4997 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49976 .49959 L
.49978 .49961 L
.49979 .49964 L
.4998 .49966 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49982 L
.4999 .49983 L
.4999 .49984 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
Mistroke
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
Mfstroke
1 0 0 r
% Start of user PostScript
-8.797405 7.1825771 -7.8051577 5.9079552 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-6.9353355 4.8209059 -6.1721477 3.8954277 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.8631479 0.39007965 -2.5842857 0.15892764 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.3286998 -0.60153187 -1.2169961 -0.63499638 MAarrowhead1
% End of user PostScript
.897 1 0 r
.15583 .17396 m
.18091 .18134 L
s
% Start of user PostScript
-0.68834916 -0.65208704 -0.63818351 -0.6373139 MAarrowhead1
% End of user PostScript
.581 1 0 r
.30609 .24997 m
.31872 .26038 L
s
% Start of user PostScript
-0.38781862 -0.5000692 -0.3625574 -0.47923227 MAarrowhead1
% End of user PostScript
.266 1 0 r
.38467 .32751 m
.39164 .33595 L
s
% Start of user PostScript
-0.23066191 -0.34497123 -0.21671323 -0.32809381 MAarrowhead1
% End of user PostScript
0 1 .049 r
.42923 .38608 m
.43332 .39202 L
s
% Start of user PostScript
-0.14154896 -0.22783632 -0.13335437 -0.21595704 MAarrowhead1
% End of user PostScript
0 1 .364 r
.45583 .42625 m
.45833 .4302 L
s
% Start of user PostScript
-0.088343135 -0.14750658 -0.083348906 -0.13959171 MAarrowhead1
% End of user PostScript
0 1 .679 r
.47219 .4527 m
.47374 .45528 L
s
% Start of user PostScript
-0.055623257 -0.094591931 -0.052517623 -0.089446502 MAarrowhead1
% End of user PostScript
0 1 .995 r
.48241 .46981 m
.48339 .47146 L
s
% Start of user PostScript
-0.035179398 -0.060376279 -0.033227678 -0.057070059 MAarrowhead1
% End of user PostScript
0 .69 1 r
.48885 .48078 m
.48947 .48183 L
s
% Start of user PostScript
-0.022300003 -0.038447982 -0.021066798 -0.036335607 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49292 .48777 m
.49331 .48845 L
s
% Start of user PostScript
-0.014151953 -0.024455733 -0.013370608 -0.023109902 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49551 .49223 m
.49575 .49265 L
s
% Start of user PostScript
-0.0089861988 -0.015546704 -0.0084904639 -0.014690449 MAarrowhead1
% End of user PostScript
0 1 .681 r
.20813 0 m
.2183 .01715 L
.23395 .04357 L
.24871 .06855 L
.26265 .09219 L
.27581 .11454 L
.28823 .13567 L
.29996 .15566 L
.31103 .17455 L
.32149 .19242 L
.33137 .20931 L
.34069 .22528 L
.3495 .24038 L
.35782 .25465 L
.36568 .26813 L
.3731 .28088 L
.38011 .29294 L
.38673 .30433 L
.39299 .31509 L
.3989 .32527 L
.40448 .33488 L
.40975 .34397 L
.41473 .35256 L
.41944 .36068 L
.42388 .36835 L
.42808 .3756 L
.43205 .38245 L
.4358 .38892 L
.43934 .39504 L
.44269 .40082 L
.44585 .40629 L
.44884 .41145 L
.45166 .41633 L
.45432 .42094 L
.45684 .42529 L
.45922 .42941 L
.46147 .4333 L
.4636 .43697 L
.4656 .44045 L
.4675 .44373 L
.46929 .44683 L
.47098 .44976 L
.47258 .45253 L
.4741 .45514 L
.47552 .45762 L
.47687 .45995 L
.47815 .46216 L
.47935 .46424 L
.48049 .46622 L
.48157 .46808 L
Mistroke
.48258 .46984 L
.48354 .4715 L
.48445 .47307 L
.48531 .47455 L
.48612 .47596 L
.48688 .47728 L
.48761 .47853 L
.48829 .47972 L
.48893 .48084 L
.48954 .48189 L
.49012 .48289 L
.49067 .48383 L
.49118 .48472 L
.49167 .48557 L
.49213 .48636 L
.49256 .48711 L
.49297 .48782 L
.49336 .48849 L
.49372 .48913 L
.49407 .48973 L
.4944 .49029 L
.49471 .49083 L
.495 .49133 L
.49527 .49181 L
.49553 .49226 L
.49578 .49269 L
.49601 .49309 L
.49623 .49347 L
.49644 .49383 L
.49664 .49417 L
.49682 .49449 L
.497 .4948 L
.49716 .49508 L
.49732 .49536 L
.49747 .49561 L
.49761 .49585 L
.49774 .49608 L
.49786 .4963 L
.49798 .4965 L
.49809 .49669 L
.4982 .49688 L
.4983 .49705 L
.49839 .49721 L
.49848 .49737 L
.49856 .49751 L
.49864 .49765 L
.49872 .49778 L
.49879 .4979 L
.49885 .49802 L
.49892 .49813 L
Mistroke
.49898 .49823 L
.49903 .49833 L
.49909 .49842 L
.49914 .49851 L
.49918 .49859 L
.49923 .49867 L
.49927 .49874 L
.49931 .49881 L
.49935 .49887 L
.49939 .49894 L
.49942 .499 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
.49956 .49924 L
.49959 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
Mistroke
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
Mfstroke
1 0 0 r
% Start of user PostScript
-6.7705601 -8.1213897 -6.3157712 -7.8150404 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-5.8969433 -7.5067113 -5.5106399 -7.1990303 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-3.4984133 -5.1991815 -3.2861105 -4.9463114 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-2.143831 -3.4398585 -2.0194746 -3.260963 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-1.3370081 -2.2288971 -1.2613448 -2.109442 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-0.8414955 -1.4299081 -0.79448652 -1.3521716 MAarrowhead1
% End of user PostScript
.266 1 0 r
.23395 .04357 m
.24871 .06855 L
s
% Start of user PostScript
-0.53210786 -0.91286572 -0.50257889 -0.86289117 MAarrowhead1
% End of user PostScript
0 1 .049 r
.33137 .20931 m
.34069 .22528 L
s
% Start of user PostScript
-0.33726698 -0.58137597 -0.3186133 -0.54943902 MAarrowhead1
% End of user PostScript
0 1 .364 r
.39299 .31509 m
.3989 .32527 L
s
% Start of user PostScript
-0.21402476 -0.36981593 -0.20220739 -0.34946591 MAarrowhead1
% End of user PostScript
0 1 .679 r
.43205 .38245 m
.4358 .38892 L
s
% Start of user PostScript
-0.13589798 -0.23510072 -0.12840074 -0.22215269 MAarrowhead1
% End of user PostScript
0 1 .995 r
.45684 .42529 m
.45922 .42941 L
s
% Start of user PostScript
-0.086316064 -0.14941436 -0.081556185 -0.14118195 MAarrowhead1
% End of user PostScript
0 .69 1 r
.47258 .45253 m
.4741 .45514 L
s
% Start of user PostScript
-0.05483213 -0.09494361 -0.051809068 -0.089711308 MAarrowhead1
% End of user PostScript
0 .375 1 r
.48258 .46984 m
.48354 .4715 L
s
% Start of user PostScript
-0.034834619 -0.060326297 -0.032914285 -0.057001387 MAarrowhead1
% End of user PostScript
0 .06 1 r
.48893 .48084 m
.48954 .48189 L
s
% Start of user PostScript
-0.022131113 -0.038329341 -0.020911152 -0.03621669 MAarrowhead1
% End of user PostScript
0 1 .111 r
.86616 1 m
.8486 .98336 L
.82666 .96144 L
.8063 .94009 L
.78737 .91938 L
.76975 .89933 L
.75335 .87998 L
.73805 .86134 L
.72378 .84342 L
.71044 .82622 L
.69798 .80974 L
.68631 .79397 L
.67539 .77889 L
.66516 .76449 L
.65557 .75076 L
.64657 .73767 L
.63813 .7252 L
.63019 .71334 L
.62274 .70206 L
.61574 .69133 L
.60915 .68114 L
.60296 .67147 L
.59713 .66229 L
.59164 .65357 L
.58647 .64531 L
.5816 .63748 L
.57702 .63005 L
.5727 .62301 L
.56862 .61635 L
.56478 .61003 L
.56116 .60405 L
.55775 .59839 L
.55453 .59303 L
.55149 .58796 L
.54863 .58316 L
.54592 .57862 L
.54337 .57432 L
.54096 .57025 L
.53869 .56641 L
.53654 .56277 L
.53451 .55933 L
.5326 .55608 L
.5308 .553 L
.52909 .55009 L
.52748 .54734 L
.52596 .54474 L
.52452 .54229 L
.52317 .53996 L
.52189 .53777 L
.52068 .53569 L
Mistroke
.51954 .53373 L
.51846 .53187 L
.51744 .53012 L
.51647 .52846 L
.51556 .5269 L
.5147 .52542 L
.51389 .52402 L
.51313 .5227 L
.5124 .52145 L
.51172 .52027 L
.51107 .51915 L
.51046 .5181 L
.50988 .5171 L
.50934 .51616 L
.50882 .51527 L
.50834 .51443 L
.50788 .51363 L
.50744 .51288 L
.50703 .51217 L
.50664 .5115 L
.50628 .51087 L
.50593 .51027 L
.5056 .5097 L
.5053 .50917 L
.505 .50866 L
.50473 .50818 L
.50447 .50773 L
.50422 .50731 L
.50399 .5069 L
.50377 .50652 L
.50356 .50616 L
.50336 .50583 L
.50318 .5055 L
.503 .5052 L
.50284 .50491 L
.50268 .50464 L
.50253 .50439 L
.50239 .50415 L
.50226 .50392 L
.50214 .5037 L
.50202 .5035 L
.50191 .5033 L
.5018 .50312 L
.5017 .50295 L
.50161 .50279 L
.50152 .50263 L
.50144 .50249 L
.50136 .50235 L
.50128 .50222 L
.50121 .5021 L
Mistroke
.50115 .50198 L
.50108 .50187 L
.50102 .50177 L
.50097 .50167 L
.50091 .50158 L
.50086 .50149 L
.50082 .50141 L
.50077 .50133 L
.50073 .50126 L
.50069 .50119 L
.50065 .50113 L
.50061 .50106 L
.50058 .501 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .5008 L
.50044 .50076 L
.50041 .50071 L
.50039 .50068 L
.50037 .50064 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .50041 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
Mistroke
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
Mfstroke
1 0 0 r
% Start of user PostScript
5.0909929 0.15481568 4.6143434 0.48581141 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
4.1901384 0.75323267 3.8119931 0.96663558 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.0659015 1.5113394 1.9052564 1.5090403 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.1230752 1.2884108 1.0463074 1.2431343 MAarrowhead1
% End of user PostScript
.897 1 0 r
.82666 .96144 m
.8063 .94009 L
s
% Start of user PostScript
0.65332568 0.92287439 0.61259062 0.88018464 MAarrowhead1
% End of user PostScript
.581 1 0 r
.69798 .80974 m
.68631 .79397 L
s
% Start of user PostScript
0.395952 0.61948323 0.37262579 0.587936 MAarrowhead1
% End of user PostScript
.266 1 0 r
.62274 .70206 m
.61574 .69133 L
s
% Start of user PostScript
0.2454851 0.40411597 0.23147671 0.38266662 MAarrowhead1
% End of user PostScript
0 1 .049 r
.57702 .63005 m
.5727 .62301 L
s
% Start of user PostScript
0.15403512 0.260099 0.14539295 0.2460245 MAarrowhead1
% End of user PostScript
0 1 .364 r
.54863 .58316 m
.54592 .57862 L
s
% Start of user PostScript
0.097251178 0.16631563 0.091842405 0.15723151 MAarrowhead1
% End of user PostScript
0 1 .679 r
.5308 .553 m
.52909 .55009 L
s
% Start of user PostScript
0.061592767 0.10600546 0.058182389 0.10018881 MAarrowhead1
% End of user PostScript
0 1 .995 r
.51954 .53373 m
.51846 .53187 L
s
% Start of user PostScript
0.039070548 0.06745725 0.036912065 0.063747342 MAarrowhead1
% End of user PostScript
0 .69 1 r
.5124 .52145 m
.51172 .52027 L
s
% Start of user PostScript
0.024803507 0.042892637 0.02343476 0.040531015 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50788 .51363 m
.50744 .51288 L
s
% Start of user PostScript
0.01575248 0.027262393 0.014883692 0.025760505 MAarrowhead1
% End of user PostScript
0 .06 1 r
.505 .50866 m
.50473 .50818 L
s
% Start of user PostScript
0.010006243 0.017324424 0.0094545294 0.016369749 MAarrowhead1
% End of user PostScript
1 .128 0 r
.9904 0 m
.97196 .02609 L
.91673 .10283 L
.86844 .16857 L
.82619 .22484 L
.7892 .27294 L
.75678 .31398 L
.72836 .34896 L
.7034 .37871 L
.68147 .40395 L
.66218 .42533 L
.6452 .44338 L
.63022 .45858 L
.617 .47133 L
.60532 .48197 L
.59498 .49082 L
.58581 .49814 L
.57768 .50414 L
.57045 .50902 L
.56401 .51295 L
.55826 .51608 L
.55313 .51851 L
.54854 .52037 L
.54442 .52175 L
.54072 .52271 L
.5374 .52333 L
.5344 .52367 L
.53169 .52378 L
.52924 .52368 L
.52702 .52344 L
.525 .52306 L
.52316 .52258 L
.52149 .52202 L
.51996 .52141 L
.51856 .52074 L
.51728 .52005 L
.51611 .51933 L
.51502 .5186 L
.51403 .51786 L
.51311 .51713 L
.51226 .51641 L
.51148 .51569 L
.51075 .51499 L
.51007 .51431 L
.50945 .51364 L
.50886 .513 L
.50832 .51237 L
.50782 .51177 L
.50735 .51119 L
.50691 .51063 L
Mistroke
.5065 .5101 L
.50611 .50959 L
.50575 .5091 L
.50542 .50863 L
.5051 .50818 L
.5048 .50776 L
.50453 .50735 L
.50427 .50697 L
.50402 .5066 L
.50379 .50625 L
.50358 .50592 L
.50337 .5056 L
.50318 .5053 L
.503 .50502 L
.50283 .50475 L
.50267 .50449 L
.50252 .50425 L
.50238 .50402 L
.50225 .5038 L
.50212 .5036 L
.502 .5034 L
.50189 .50322 L
.50178 .50304 L
.50169 .50288 L
.50159 .50272 L
.5015 .50257 L
.50142 .50243 L
.50134 .5023 L
.50127 .50217 L
.5012 .50205 L
.50113 .50194 L
.50107 .50183 L
.50101 .50173 L
.50095 .50164 L
.5009 .50155 L
.50085 .50146 L
.5008 .50138 L
.50076 .50131 L
.50072 .50124 L
.50068 .50117 L
.50064 .5011 L
.5006 .50104 L
.50057 .50099 L
.50054 .50093 L
.50051 .50088 L
.50048 .50083 L
.50045 .50079 L
.50043 .50074 L
.50041 .5007 L
.50038 .50066 L
Mistroke
.50036 .50063 L
.50034 .50059 L
.50032 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.50019 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
Mistroke
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
3.976488 -5.6054799 3.474608 -4.8068637 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
3.0381335 -4.1176381 2.6584206 -3.5230458 MAarrowhead1
% End of user PostScript
1 .473 0 r
.9904 0 m
.97196 .02609 L
s
% Start of user PostScript
1.070371 -1.1267462 0.94392383 -0.94781697 MAarrowhead1
% End of user PostScript
1 .788 0 r
.7034 .37871 m
.68147 .40395 L
s
% Start of user PostScript
0.4068021 -0.24258613 0.36294566 -0.19209146 MAarrowhead1
% End of user PostScript
.897 1 0 r
.58581 .49814 m
.57768 .50414 L
s
% Start of user PostScript
0.17162653 -0.0037272645 0.15535538 0.0082749675 MAarrowhead1
% End of user PostScript
.581 1 0 r
.54072 .52271 m
.5374 .52333 L
s
% Start of user PostScript
0.081448541 0.04542477 0.074794662 0.046669625 MAarrowhead1
% End of user PostScript
.266 1 0 r
.52149 .52202 m
.51996 .52141 L
s
% Start of user PostScript
0.042979333 0.044047722 0.039922485 0.042811008 MAarrowhead1
% End of user PostScript
0 1 .049 r
.51226 .51641 m
.51148 .51569 L
s
% Start of user PostScript
0.024520232 0.032811607 0.022950088 0.03138154 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50735 .51119 m
.50691 .51063 L
s
% Start of user PostScript
0.014693315 0.022380277 0.013813949 0.021266941 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50453 .50735 m
.50427 .50697 L
s
% Start of user PostScript
0.009053925 0.014706512 0.0085327907 0.013934097 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50283 .50475 m
.50267 .50449 L
s
% Start of user PostScript
0.0056629366 0.0094985529 0.0053437747 0.0089871277 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50178 .50304 m
.50169 .50288 L
s
% Start of user PostScript
0.0035694952 0.0060840553 0.0033705112 0.0057525544 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50113 .50194 m
.50107 .50183 L
s
% Start of user PostScript
0.0022588256 0.0038811025 0.002133608 0.0036683977 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50072 .50124 m
.50068 .50117 L
s
% Start of user PostScript
0.0014322604 0.002470802 0.0013530873 0.002334998 MAarrowhead1
% End of user PostScript
.17 1 0 r
.79392 1 m
.7792 .97559 L
.76363 .94969 L
.74894 .92517 L
.73508 .90197 L
.72201 .88002 L
.70967 .85925 L
.69802 .8396 L
.68703 .82101 L
.67665 .80343 L
.66686 .78681 L
.65761 .77108 L
.64888 .75622 L
.64064 .74216 L
.63285 .72887 L
.6255 .7163 L
.61856 .70442 L
.612 .69319 L
.60581 .68257 L
.59996 .67253 L
.59444 .66305 L
.58922 .65408 L
.58429 .64561 L
.57964 .6376 L
.57524 .63002 L
.57109 .62287 L
.56716 .61611 L
.56345 .60971 L
.55995 .60367 L
.55664 .59797 L
.55352 .59257 L
.55057 .58747 L
.54778 .58266 L
.54514 .5781 L
.54265 .5738 L
.5403 .56974 L
.53808 .5659 L
.53598 .56227 L
.53399 .55883 L
.53212 .55559 L
.53035 .55253 L
.52867 .54964 L
.52709 .5469 L
.5256 .54432 L
.52419 .54187 L
.52285 .53957 L
.52159 .53739 L
.5204 .53533 L
.51928 .53338 L
.51821 .53154 L
Mistroke
.51721 .5298 L
.51626 .52816 L
.51536 .52661 L
.51452 .52514 L
.51372 .52376 L
.51296 .52245 L
.51225 .52121 L
.51157 .52004 L
.51093 .51894 L
.51033 .51789 L
.50976 .51691 L
.50922 .51597 L
.50871 .51509 L
.50823 .51426 L
.50778 .51348 L
.50735 .51273 L
.50695 .51203 L
.50656 .51137 L
.5062 .51074 L
.50586 .51015 L
.50554 .50959 L
.50523 .50906 L
.50494 .50856 L
.50467 .50809 L
.50441 .50764 L
.50417 .50722 L
.50394 .50682 L
.50372 .50645 L
.50352 .50609 L
.50332 .50576 L
.50314 .50544 L
.50297 .50514 L
.5028 .50486 L
.50265 .50459 L
.5025 .50434 L
.50237 .5041 L
.50223 .50387 L
.50211 .50366 L
.502 .50346 L
.50189 .50327 L
.50178 .50309 L
.50168 .50292 L
.50159 .50275 L
.5015 .5026 L
.50142 .50246 L
.50134 .50232 L
.50127 .5022 L
.5012 .50207 L
.50113 .50196 L
.50107 .50185 L
Mistroke
.50101 .50175 L
.50095 .50165 L
.5009 .50156 L
.50085 .50148 L
.50081 .5014 L
.50076 .50132 L
.50072 .50125 L
.50068 .50118 L
.50064 .50111 L
.50061 .50105 L
.50057 .50099 L
.50054 .50094 L
.50051 .50089 L
.50048 .50084 L
.50046 .50079 L
.50043 .50075 L
.50041 .50071 L
.50039 .50067 L
.50036 .50063 L
.50034 .5006 L
.50033 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50048 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50029 L
.50016 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
Mfstroke
1 0 0 r
% Start of user PostScript
8.5303561 7.1913448 7.8885485 7.0921739 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
7.3050284 6.9587878 6.7735242 6.7983702 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
4.1192192 5.3253174 3.8512198 5.1026937 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
2.4512453 3.6707049 2.3031189 3.4909058 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
1.5046719 2.4234547 1.4175979 2.2970317 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
0.93923308 1.5687376 0.8861475 1.4845423 MAarrowhead1
% End of user PostScript
.266 1 0 r
.79392 1 m
.7792 .97559 L
s
% Start of user PostScript
0.59141266 1.0059062 0.55839572 0.95118242 MAarrowhead1
% End of user PostScript
0 1 .049 r
.68703 .82101 m
.67665 .80343 L
s
% Start of user PostScript
0.37405862 0.64202537 0.35330734 0.60686589 MAarrowhead1
% End of user PostScript
0 1 .364 r
.61856 .70442 m
.612 .69319 L
s
% Start of user PostScript
0.23711813 0.40883748 0.22400571 0.38637484 MAarrowhead1
% End of user PostScript
0 1 .679 r
.57524 .63002 m
.57109 .62287 L
s
% Start of user PostScript
0.1504806 0.26004798 0.14217252 0.245737 MAarrowhead1
% End of user PostScript
0 1 .995 r
.54778 .58266 m
.54514 .5781 L
s
% Start of user PostScript
0.095552562 0.16531375 0.090281322 0.15620881 MAarrowhead1
% End of user PostScript
0 .69 1 r
.53035 .55253 m
.52867 .54964 L
s
% Start of user PostScript
0.060691429 0.10506085 0.057344685 0.099272103 MAarrowhead1
% End of user PostScript
0 .375 1 r
.51928 .53338 m
.51821 .53154 L
s
% Start of user PostScript
0.03855441 0.066759198 0.036428811 0.063080089 MAarrowhead1
% End of user PostScript
0 .06 1 r
.51225 .52121 m
.51157 .52004 L
s
% Start of user PostScript
0.024493544 0.042418024 0.023143291 0.040080124 MAarrowhead1
% End of user PostScript
1 0 .268 r
.77476 1 m
.76962 .9899 L
.75528 .962 L
.74165 .93576 L
.72872 .91106 L
.71645 .88782 L
.70481 .86594 L
.69378 .84533 L
.68332 .82591 L
.6734 .80762 L
.66401 .79038 L
.65511 .77412 L
.64668 .7588 L
.63871 .74435 L
.63115 .73072 L
.624 .71786 L
.61724 .70573 L
.61084 .69429 L
.60478 .68349 L
.59905 .67329 L
.59363 .66367 L
.5885 .65459 L
.58365 .64602 L
.57907 .63793 L
.57473 .63029 L
.57063 .62307 L
.56675 .61626 L
.56309 .60983 L
.55962 .60375 L
.55635 .59801 L
.55325 .59259 L
.55032 .58748 L
.54756 .58264 L
.54494 .57808 L
.54247 .57376 L
.54013 .56969 L
.53793 .56584 L
.53584 .56221 L
.53387 .55877 L
.532 .55553 L
.53024 .55246 L
.52858 .54957 L
.527 .54683 L
.52551 .54425 L
.52411 .54181 L
.52278 .5395 L
.52153 .53732 L
.52034 .53526 L
.51922 .53332 L
.51816 .53148 L
Mistroke
.51716 .52974 L
.51622 .5281 L
.51532 .52655 L
.51448 .52509 L
.51368 .52371 L
.51293 .5224 L
.51221 .52116 L
.51154 .52 L
.51091 .51889 L
.5103 .51785 L
.50974 .51687 L
.5092 .51594 L
.50869 .51506 L
.50821 .51423 L
.50776 .51345 L
.50733 .5127 L
.50693 .512 L
.50655 .51134 L
.50619 .51072 L
.50585 .51013 L
.50552 .50957 L
.50522 .50904 L
.50493 .50854 L
.50466 .50807 L
.5044 .50763 L
.50416 .50721 L
.50393 .50681 L
.50371 .50643 L
.50351 .50608 L
.50332 .50574 L
.50313 .50543 L
.50296 .50513 L
.5028 .50485 L
.50264 .50458 L
.5025 .50433 L
.50236 .50409 L
.50223 .50386 L
.50211 .50365 L
.50199 .50345 L
.50188 .50326 L
.50178 .50308 L
.50168 .50291 L
.50159 .50275 L
.5015 .5026 L
.50142 .50245 L
.50134 .50232 L
.50126 .50219 L
.5012 .50207 L
.50113 .50196 L
.50107 .50185 L
Mistroke
.50101 .50175 L
.50095 .50165 L
.5009 .50156 L
.50085 .50147 L
.5008 .50139 L
.50076 .50132 L
.50072 .50124 L
.50068 .50117 L
.50064 .50111 L
.50061 .50105 L
.50057 .50099 L
.50054 .50094 L
.50051 .50088 L
.50048 .50084 L
.50046 .50079 L
.50043 .50075 L
.50041 .5007 L
.50038 .50067 L
.50036 .50063 L
.50034 .50059 L
.50032 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.50019 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50016 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
Mistroke
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
Mfstroke
1 0 0 r
% Start of user PostScript
2.0164576 6.4154593 1.9714461 5.9472759 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
1.9200858 5.5201932 1.8639055 5.1299039 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.4210927 3.1587653 1.3585401 2.9573184 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
0.96681145 1.8961706 0.918534 1.7829659 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
0.63457247 1.1695321 0.60118748 1.102306 MAarrowhead1
% End of user PostScript
.581 1 0 r
.70481 .86594 m
.69378 .84533 L
s
% Start of user PostScript
0.40962706 0.73187274 0.38755424 0.6906539 MAarrowhead1
% End of user PostScript
.266 1 0 r
.63115 .73072 m
.624 .71786 L
s
% Start of user PostScript
0.26230526 0.46143718 0.24800756 0.43572345 MAarrowhead1
% End of user PostScript
0 1 .049 r
.58365 .64602 m
.57907 .63793 L
s
% Start of user PostScript
0.16730579 0.29204187 0.15813481 0.27585558 MAarrowhead1
% End of user PostScript
0 1 .364 r
.55325 .59259 m
.55032 .58748 L
s
% Start of user PostScript
0.10650377 0.18518803 0.10064939 0.17495208 MAarrowhead1
% End of user PostScript
0 1 .679 r
.53387 .55877 m
.532 .55553 L
s
% Start of user PostScript
0.067732283 0.11754395 0.064003954 0.11105583 MAarrowhead1
% End of user PostScript
0 1 .995 r
.52153 .53732 m
.52034 .53526 L
s
% Start of user PostScript
0.043054169 0.074644523 0.040682608 0.070527177 MAarrowhead1
% End of user PostScript
0 .69 1 r
.51368 .52371 m
.51293 .5224 L
s
% Start of user PostScript
0.027360825 0.047413381 0.025853181 0.04479899 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50869 .51506 m
.50821 .51423 L
s
% Start of user PostScript
0.017385628 0.030120114 0.016427475 0.028459567 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50552 .50957 m
.50522 .50904 L
s
% Start of user PostScript
0.011046513 0.019135449 0.010437668 0.018080587 MAarrowhead1
% End of user PostScript
1 0 .274 r
.78633 1 m
.78596 .99936 L
.77029 .97167 L
.75547 .94554 L
.74146 .92086 L
.72821 .89756 L
.71568 .87555 L
.70384 .85477 L
.69264 .83515 L
.68206 .81662 L
.67205 .79912 L
.66259 .78258 L
.65365 .76697 L
.6452 .75222 L
.63721 .73829 L
.62966 .72513 L
.62253 .7127 L
.61579 .70096 L
.60941 .68986 L
.60339 .67938 L
.5977 .66948 L
.59232 .66013 L
.58724 .6513 L
.58243 .64295 L
.57789 .63506 L
.5736 .62761 L
.56955 .62057 L
.56572 .61392 L
.5621 .60764 L
.55868 .6017 L
.55544 .59609 L
.55239 .59079 L
.5495 .58579 L
.54677 .58106 L
.5442 .57659 L
.54176 .57236 L
.53946 .56837 L
.53729 .5646 L
.53523 .56104 L
.53329 .55768 L
.53145 .5545 L
.52972 .55149 L
.52808 .54865 L
.52654 .54597 L
.52507 .54344 L
.52369 .54104 L
.52239 .53878 L
.52115 .53664 L
.51999 .53462 L
.51888 .53271 L
Mistroke
.51784 .53091 L
.51686 .52921 L
.51593 .5276 L
.51505 .52607 L
.51422 .52464 L
.51344 .52328 L
.5127 .522 L
.512 .52078 L
.51134 .51964 L
.51071 .51856 L
.51012 .51753 L
.50956 .51657 L
.50904 .51565 L
.50854 .51479 L
.50807 .51397 L
.50762 .5132 L
.5072 .51248 L
.50681 .51179 L
.50643 .51114 L
.50608 .51052 L
.50574 .50994 L
.50543 .5094 L
.50513 .50888 L
.50484 .50839 L
.50458 .50793 L
.50432 .50749 L
.50409 .50708 L
.50386 .50669 L
.50365 .50632 L
.50345 .50597 L
.50326 .50564 L
.50308 .50533 L
.50291 .50504 L
.50275 .50476 L
.5026 .5045 L
.50245 .50425 L
.50232 .50401 L
.50219 .50379 L
.50207 .50358 L
.50196 .50339 L
.50185 .5032 L
.50175 .50302 L
.50165 .50286 L
.50156 .5027 L
.50147 .50255 L
.50139 .50241 L
.50131 .50228 L
.50124 .50215 L
.50117 .50203 L
.50111 .50192 L
Mistroke
.50105 .50181 L
.50099 .50171 L
.50094 .50162 L
.50088 .50153 L
.50084 .50145 L
.50079 .50137 L
.50075 .50129 L
.5007 .50122 L
.50067 .50115 L
.50063 .50109 L
.50059 .50103 L
.50056 .50097 L
.50053 .50092 L
.5005 .50087 L
.50047 .50082 L
.50045 .50078 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50036 .50062 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50047 L
.50025 .50044 L
.50024 .50042 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .5003 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50005 .5001 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
Mfstroke
1 0 0 r
% Start of user PostScript
3.2949497 6.501719 3.1313102 6.1121892 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
2.9742899 5.7482891 2.8238446 5.4080507 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.944394 3.5573956 1.8415068 3.353876 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.2527396 2.2300609 1.1850503 2.1047756 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
0.80144324 1.4072871 0.75769989 1.3289652 MAarrowhead1
% End of user PostScript
.581 1 0 r
.75547 .94554 m
.74146 .92086 L
s
% Start of user PostScript
0.51094682 0.89107021 0.48292044 0.84171479 MAarrowhead1
% End of user PostScript
.266 1 0 r
.66259 .78258 m
.65365 .76697 L
s
% Start of user PostScript
0.3251844 0.56516936 0.30730356 0.53394071 MAarrowhead1
% End of user PostScript
0 1 .049 r
.60339 .67938 m
.5977 .66948 L
s
% Start of user PostScript
0.20678097 0.35876955 0.19539684 0.33896962 MAarrowhead1
% End of user PostScript
0 1 .364 r
.56572 .61392 m
.5621 .60764 L
s
% Start of user PostScript
0.13143322 0.22784426 0.12419287 0.21527754 MAarrowhead1
% End of user PostScript
0 1 .679 r
.54176 .57236 m
.53946 .56837 L
s
% Start of user PostScript
0.083523113 0.14472832 0.078920614 0.13674827 MAarrowhead1
% End of user PostScript
0 1 .995 r
.52654 .54597 m
.52507 .54344 L
s
% Start of user PostScript
0.053071536 0.091942312 0.050146609 0.086873559 MAarrowhead1
% End of user PostScript
0 .69 1 r
.51686 .52921 m
.51593 .5276 L
s
% Start of user PostScript
0.033720451 0.058411799 0.031861877 0.055191819 MAarrowhead1
% End of user PostScript
0 .375 1 r
.51071 .51856 m
.51012 .51753 L
s
% Start of user PostScript
0.021424636 0.037110549 0.020243727 0.035064889 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50681 .51179 m
.50643 .51114 L
s
% Start of user PostScript
0.013612181 0.023577621 0.012861874 0.022277967 MAarrowhead1
% End of user PostScript
.261 1 0 r
0 .94118 m
.0446 .8819 L
.09619 .81497 L
.1414 .75785 L
.18106 .70919 L
.21587 .66781 L
.24647 .63269 L
.27338 .60297 L
.29708 .57787 L
.31798 .55675 L
.33644 .53904 L
.35275 .52426 L
.36718 .51197 L
.37998 .50183 L
.39134 .49351 L
.40144 .48675 L
.41044 .4813 L
.41846 .47699 L
.42563 .47362 L
.43205 .47106 L
.4378 .46918 L
.44297 .46786 L
.44762 .46702 L
.45182 .46658 L
.4556 .46646 L
.45903 .46661 L
.46214 .46698 L
.46496 .46752 L
.46753 .46821 L
.46988 .469 L
.47202 .46988 L
.47397 .47082 L
.47577 .47181 L
.47742 .47282 L
.47893 .47385 L
.48033 .47489 L
.48161 .47592 L
.4828 .47694 L
.4839 .47795 L
.48492 .47894 L
.48587 .4799 L
.48675 .48084 L
.48756 .48174 L
.48832 .48262 L
.48903 .48347 L
.48969 .48428 L
.49031 .48506 L
.49088 .48582 L
.49142 .48653 L
.49193 .48722 L
Mistroke
.4924 .48788 L
.49284 .48851 L
.49326 .4891 L
.49365 .48967 L
.49401 .49022 L
.49436 .49073 L
.49468 .49122 L
.49498 .49169 L
.49527 .49213 L
.49553 .49255 L
.49579 .49295 L
.49603 .49333 L
.49625 .49369 L
.49646 .49403 L
.49666 .49435 L
.49685 .49466 L
.49702 .49495 L
.49719 .49522 L
.49735 .49548 L
.49749 .49573 L
.49763 .49596 L
.49777 .49618 L
.49789 .49639 L
.49801 .49659 L
.49812 .49677 L
.49822 .49695 L
.49832 .49712 L
.49841 .49728 L
.4985 .49742 L
.49859 .49757 L
.49866 .4977 L
.49874 .49783 L
.49881 .49795 L
.49887 .49806 L
.49894 .49816 L
.49899 .49827 L
.49905 .49836 L
.4991 .49845 L
.49915 .49854 L
.4992 .49862 L
.49924 .49869 L
.49929 .49876 L
.49932 .49883 L
.49936 .4989 L
.4994 .49896 L
.49943 .49902 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49921 L
Mistroke
.49957 .49926 L
.49959 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
Mistroke
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
Mfstroke
1 0 0 r
% Start of user PostScript
-6.3495129 9.0928693 -5.5449104 7.8042525 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-4.8453522 6.6917901 -4.236945 5.7317376 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.6956354 1.856458 -1.493705 1.5662612 MAarrowhead1
% End of user PostScript
1 .788 0 r
.18106 .70919 m
.21587 .66781 L
s
% Start of user PostScript
-0.63788215 0.41837585 -0.56825381 0.33561508 MAarrowhead1
% End of user PostScript
.897 1 0 r
.36718 .51197 m
.37998 .50183 L
s
% Start of user PostScript
-0.26563456 0.023949458 -0.24003953 0.003658344 MAarrowhead1
% End of user PostScript
.581 1 0 r
.4378 .46918 m
.44297 .46786 L
s
% Start of user PostScript
-0.1243951 -0.061641949 -0.11405772 -0.064272679 MAarrowhead1
% End of user PostScript
.266 1 0 r
.46753 .46821 m
.46988 .469 L
s
% Start of user PostScript
-0.064932612 -0.063587411 -0.060247404 -0.061998104 MAarrowhead1
% End of user PostScript
0 1 .049 r
.48161 .47592 m
.4828 .47694 L
s
% Start of user PostScript
-0.036773553 -0.048161059 -0.034395075 -0.046115125 MAarrowhead1
% End of user PostScript
0 1 .364 r
.48903 .48347 m
.48969 .48428 L
s
% Start of user PostScript
-0.021939895 -0.033065132 -0.02061885 -0.03143599 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49326 .4891 m
.49365 .48967 L
s
% Start of user PostScript
-0.013486873 -0.021791448 -0.012707967 -0.020651748 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49579 .49295 m
.49603 .49333 L
s
% Start of user PostScript
-0.0084250033 -0.014094102 -0.0079493276 -0.013336752 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49735 .49548 m
.49749 .49573 L
s
% Start of user PostScript
-0.005307076 -0.009033736 -0.005010959 -0.0085419924 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49832 .49712 m
.49841 .49728 L
s
% Start of user PostScript
-0.0033572949 -0.0057646731 -0.0031710975 -0.0054488894 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49894 .49816 m
.49899 .49827 L
s
% Start of user PostScript
-0.0021284206 -0.0036705382 -0.0020107373 -0.0034688402 MAarrowhead1
% End of user PostScript
0 1 .76 r
.77359 0 m
.77271 .00155 L
.73571 .06708 L
.70369 .12391 L
.67597 .17321 L
.65198 .21597 L
.63122 .25308 L
.61325 .28527 L
.59771 .31321 L
.58427 .33746 L
.57264 .35851 L
.56259 .37679 L
.5539 .39266 L
.54639 .40644 L
.5399 .41841 L
.53429 .42882 L
.52944 .43786 L
.52526 .44572 L
.52165 .45255 L
.51853 .4585 L
.51585 .46367 L
.51353 .46817 L
.51153 .47209 L
.50981 .47551 L
.50833 .47848 L
.50706 .48108 L
.50597 .48334 L
.50503 .48532 L
.50422 .48704 L
.50353 .48855 L
.50294 .48987 L
.50243 .49103 L
.502 .49204 L
.50163 .49292 L
.50132 .4937 L
.50105 .49439 L
.50082 .49499 L
.50063 .49552 L
.50047 .49598 L
.50034 .49639 L
.50022 .49676 L
.50013 .49708 L
.50005 .49736 L
.49999 .49761 L
.49993 .49784 L
.49989 .49804 L
.49986 .49821 L
.49983 .49837 L
.49981 .49851 L
.49979 .49864 L
Mistroke
.49978 .49876 L
.49977 .49886 L
.49977 .49895 L
.49977 .49903 L
.49977 .49911 L
.49977 .49918 L
.49977 .49924 L
.49978 .4993 L
.49978 .49935 L
.49979 .49939 L
.49979 .49944 L
.4998 .49948 L
.49981 .49951 L
.49981 .49954 L
.49982 .49958 L
.49983 .4996 L
.49984 .49963 L
.49984 .49965 L
.49985 .49967 L
.49986 .4997 L
.49986 .49971 L
.49987 .49973 L
.49988 .49975 L
.49988 .49976 L
.49989 .49978 L
.49989 .49979 L
.4999 .4998 L
.4999 .49982 L
.49991 .49983 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49993 .49986 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
Mistroke
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
3.5795001 -6.3089351 3.0991439 -5.4709224 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
2.6830547 -4.7445546 2.3226448 -4.1149393 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
0.84368294 -1.5231635 0.72964554 -1.322235 MAarrowhead1
% End of user PostScript
1 .788 0 r
.63122 .25308 m
.61325 .28527 L
s
% Start of user PostScript
0.26243064 -0.49384669 0.22650495 -0.42945511 MAarrowhead1
% End of user PostScript
.897 1 0 r
.5399 .41841 m
.53429 .42882 L
s
% Start of user PostScript
0.079790921 -0.16317313 0.068573225 -0.14236707 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51153 .47209 m
.50981 .47551 L
s
% Start of user PostScript
0.023066391 -0.055817446 0.019627866 -0.048987231 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50294 .48987 m
.50243 .49103 L
s
% Start of user PostScript
0.0058755006 -0.020256568 0.0048629919 -0.017947234 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50047 .49598 m
.50034 .49639 L
s
% Start of user PostScript
0.00094302586 -0.0080375669 0.00067221106 -0.0072154941 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49986 .49821 m
.49983 .49837 L
s
% Start of user PostScript
-0.00028742747 -0.0035710253 -0.00034112417 -0.0032537387 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49977 .49911 m
.49977 .49918 L
s
% Start of user PostScript
-0.00046434615 -0.0017808544 -0.00046084892 -0.0016444163 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49981 .49951 m
.49981 .49954 L
s
% Start of user PostScript
-0.00038454643 -0.00097638817 -0.00037037197 -0.00091040549 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49986 .49971 m
.49987 .49973 L
s
% Start of user PostScript
-0.00027276854 -0.00057106558 -0.00025996468 -0.00053572263 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49991 .49983 m
.49991 .49984 L
s
% Start of user PostScript
-0.00018234223 -0.00034716395 -0.0001730004 -0.00032679959 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49994 .49989 m
.49994 .4999 L
s
% Start of user PostScript
-0.00011872278 -0.00021559232 -0.00011240396 -0.00020331829 MAarrowhead1
% End of user PostScript
.249 0 1 r
.79478 0 m
.76157 .05703 L
.72688 .11656 L
.6968 .16813 L
.67073 .21279 L
.64813 .25147 L
.62854 .28496 L
.61155 .31397 L
.59682 .33909 L
.58405 .36083 L
.57297 .37967 L
.56336 .39597 L
.55503 .41008 L
.54781 .4223 L
.54154 .43287 L
.5361 .44202 L
.53139 .44994 L
.52729 .45679 L
.52374 .46272 L
.52066 .46785 L
.51798 .47228 L
.51566 .47612 L
.51364 .47943 L
.51189 .4823 L
.51037 .48478 L
.50905 .48692 L
.5079 .48876 L
.5069 .49036 L
.50603 .49174 L
.50527 .49293 L
.50462 .49395 L
.50404 .49484 L
.50355 .4956 L
.50311 .49625 L
.50273 .49682 L
.5024 .4973 L
.50212 .49772 L
.50186 .49808 L
.50165 .49839 L
.50145 .49865 L
.50129 .49888 L
.50114 .49907 L
.50101 .49924 L
.5009 .49938 L
.5008 .4995 L
.50071 .4996 L
.50064 .49968 L
.50057 .49976 L
.50051 .49982 L
.50046 .49987 L
Mistroke
.50041 .49991 L
.50037 .49995 L
.50033 .49998 L
.5003 .5 L
.50027 .50002 L
.50025 .50004 L
.50023 .50005 L
.50021 .50006 L
.50019 .50007 L
.50017 .50008 L
.50016 .50008 L
.50014 .50009 L
.50013 .50009 L
.50012 .50009 L
.50011 .50009 L
.5001 .50009 L
.5001 .50009 L
.50009 .50008 L
.50008 .50008 L
.50008 .50008 L
.50007 .50008 L
.50007 .50008 L
.50006 .50007 L
.50006 .50007 L
.50005 .50007 L
.50005 .50006 L
.50005 .50006 L
.50004 .50006 L
.50004 .50006 L
.50004 .50005 L
.50004 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50003 .50004 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
Mistroke
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
0.92500309 -1.5768557 0.8020811 -1.3653429 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
0.69553851 -1.1821233 0.60319028 -1.0234163 MAarrowhead1
% End of user PostScript
1 .473 0 r
.61155 .31397 m
.59682 .33909 L
s
% Start of user PostScript
0.22309552 -0.3720637 0.19363539 -0.3218282 MAarrowhead1
% End of user PostScript
1 .788 0 r
.5361 .44202 m
.53139 .44994 L
s
% Start of user PostScript
0.072209725 -0.11595432 0.06277551 -0.1001163 MAarrowhead1
% End of user PostScript
.897 1 0 r
.51189 .4823 m
.51037 .48478 L
s
% Start of user PostScript
0.023782234 -0.035399872 0.020738204 -0.030446729 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50404 .49484 m
.50355 .4956 L
s
% Start of user PostScript
0.0080884017 -0.010329509 0.0070918146 -0.0088062167 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50145 .49865 m
.50129 .49888 L
s
% Start of user PostScript
0.0029076571 -0.0026981378 0.0025723704 -0.0022462818 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50057 .49976 m
.50051 .49982 L
s
% Start of user PostScript
0.0011383224 -0.00048615389 0.0010199618 -0.0003630288 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50025 .50004 m
.50023 .50005 L
s
% Start of user PostScript
0.00049791057 0.000081382236 0.00045279207 0.00010750691 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50012 .50009 m
.50011 .50009 L
s
% Start of user PostScript
0.00024474458 0.00017571971 0.00022563789 0.0001757611 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50007 .50008 m
.50006 .50007 L
s
% Start of user PostScript
0.00013274424 0.00015105097 0.00012364256 0.00014581593 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50004 .50005 m
.50004 .50005 L
s
% Start of user PostScript
0.000077107948 0.00010849231 0.000072290541 0.00010349435 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50002 .50004 m
.50002 .50003 L
s
% Start of user PostScript
0.000046692432 0.000072909393 0.000043938468 0.000069202674 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50001 .50002 m
.50001 .50002 L
s
% Start of user PostScript
0.000028935606 0.00004758709 0.00002728337 0.000045063219 MAarrowhead1
% End of user PostScript
0 .918 1 r
0 .20758 m
.0273 .20263 L
.06516 .19859 L
.09935 .1975 L
.13029 .19883 L
.15834 .20214 L
.18383 .20704 L
.20702 .21321 L
.22816 .22037 L
.24747 .22829 L
.26514 .23677 L
.28133 .24565 L
.2962 .2548 L
.30987 .26409 L
.32247 .27343 L
.33408 .28275 L
.34482 .29198 L
.35475 .30106 L
.36394 .30996 L
.37248 .31865 L
.3804 .3271 L
.38777 .33529 L
.39463 .3432 L
.40102 .35084 L
.40698 .35819 L
.41254 .36525 L
.41774 .37202 L
.4226 .3785 L
.42715 .38471 L
.43141 .39064 L
.43541 .3963 L
.43915 .40169 L
.44267 .40683 L
.44597 .41173 L
.44907 .41639 L
.45198 .42081 L
.45471 .42502 L
.45729 .42902 L
.45971 .43281 L
.46199 .43642 L
.46414 .43983 L
.46616 .44307 L
.46806 .44614 L
.46986 .44906 L
.47155 .45181 L
.47314 .45443 L
.47464 .4569 L
.47606 .45925 L
.47739 .46146 L
.47865 .46356 L
Mistroke
.47984 .46555 L
.48096 .46743 L
.48202 .46921 L
.48302 .47089 L
.48396 .47249 L
.48485 .47399 L
.48569 .47542 L
.48649 .47677 L
.48724 .47804 L
.48794 .47924 L
.48861 .48038 L
.48924 .48146 L
.48984 .48248 L
.4904 .48344 L
.49093 .48435 L
.49143 .48521 L
.4919 .48602 L
.49235 .48679 L
.49277 .48752 L
.49317 .48821 L
.49355 .48885 L
.49391 .48947 L
.49424 .49005 L
.49456 .4906 L
.49486 .49111 L
.49514 .4916 L
.49541 .49206 L
.49567 .4925 L
.4959 .49291 L
.49613 .4933 L
.49634 .49367 L
.49655 .49402 L
.49674 .49435 L
.49692 .49466 L
.49709 .49496 L
.49725 .49523 L
.4974 .4955 L
.49754 .49575 L
.49768 .49598 L
.49781 .4962 L
.49793 .49641 L
.49804 .49661 L
.49815 .4968 L
.49825 .49697 L
.49835 .49714 L
.49844 .4973 L
.49852 .49745 L
.49861 .49759 L
.49868 .49772 L
.49876 .49784 L
Mistroke
.49882 .49796 L
.49889 .49808 L
.49895 .49818 L
.49901 .49828 L
.49906 .49838 L
.49911 .49847 L
.49916 .49855 L
.49921 .49863 L
.49925 .49871 L
.49929 .49878 L
.49933 .49884 L
.49937 .49891 L
.4994 .49897 L
.49944 .49903 L
.49947 .49908 L
.4995 .49913 L
.49953 .49918 L
.49955 .49922 L
.49958 .49927 L
.4996 .49931 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49953 L
.49975 .49956 L
.49976 .49958 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
Mistroke
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
1 0 0 r
% Start of user PostScript
-6.4742627 4.6585157 -5.7582351 3.7796528 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-5.129626 3.0322859 -4.577215 2.3980787 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.1665898 0.034305445 -1.9614735 -0.11600686 MAarrowhead1
% End of user PostScript
1 .788 0 r
0 .20758 m
.0273 .20263 L
s
% Start of user PostScript
-1.0293638 -0.57951079 -0.94539338 -0.59473206 MAarrowhead1
% End of user PostScript
.897 1 0 r
.22816 .22037 m
.24747 .22829 L
s
% Start of user PostScript
-0.543679 -0.55926876 -0.50505751 -0.54342891 MAarrowhead1
% End of user PostScript
.581 1 0 r
.34482 .29198 m
.35475 .30106 L
s
% Start of user PostScript
-0.31036569 -0.41604833 -0.29050815 -0.39787795 MAarrowhead1
% End of user PostScript
.266 1 0 r
.40698 .35819 m
.41254 .36525 L
s
% Start of user PostScript
-0.18604846 -0.28362906 -0.17491942 -0.26950854 MAarrowhead1
% End of user PostScript
0 1 .049 r
.44267 .40683 m
.44597 .41173 L
s
% Start of user PostScript
-0.11466453 -0.18633347 -0.10806639 -0.17654347 MAarrowhead1
% End of user PostScript
0 1 .364 r
.46414 .43983 m
.46616 .44307 L
s
% Start of user PostScript
-0.071726377 -0.1203342 -0.067684486 -0.11385406 MAarrowhead1
% End of user PostScript
0 1 .679 r
.47739 .46146 m
.47865 .46356 L
s
% Start of user PostScript
-0.045213386 -0.077072708 -0.042693125 -0.072872926 MAarrowhead1
% End of user PostScript
0 1 .995 r
.48569 .47542 m
.48649 .47677 L
s
% Start of user PostScript
-0.028612421 -0.049164387 -0.027026356 -0.046469815 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49093 .48435 m
.49143 .48521 L
s
% Start of user PostScript
-0.01814261 -0.031298789 -0.017139734 -0.029578463 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49424 .49005 m
.49456 .4906 L
s
% Start of user PostScript
-0.011515314 -0.019905344 -0.010879675 -0.018809694 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49634 .49367 m
.49655 .49402 L
s
% Start of user PostScript
-0.0073125317 -0.01265304 -0.0069091694 -0.011956083 MAarrowhead1
% End of user PostScript
.997 1 0 r
.19139 0 m
.20767 .02395 L
.22447 .049 L
.24025 .07283 L
.25508 .09549 L
.26903 .11701 L
.28215 .13745 L
.29449 .15686 L
.30611 .17527 L
.31705 .19274 L
.32735 .20929 L
.33705 .22499 L
.3462 .23987 L
.35482 .25396 L
.36294 .26731 L
.3706 .27995 L
.37783 .29192 L
.38464 .30325 L
.39107 .31398 L
.39714 .32413 L
.40286 .33373 L
.40826 .34282 L
.41335 .35142 L
.41816 .35955 L
.4227 .36724 L
.42699 .37451 L
.43104 .38139 L
.43486 .3879 L
.43846 .39405 L
.44187 .39986 L
.44509 .40536 L
.44812 .41056 L
.45099 .41547 L
.4537 .42012 L
.45626 .42451 L
.45868 .42866 L
.46096 .43258 L
.46312 .43629 L
.46515 .4398 L
.46708 .44311 L
.4689 .44624 L
.47061 .4492 L
.47224 .452 L
.47377 .45464 L
.47522 .45714 L
.47658 .4595 L
.47787 .46173 L
.4791 .46383 L
.48025 .46583 L
.48134 .46771 L
Mistroke
.48237 .46949 L
.48334 .47117 L
.48426 .47276 L
.48513 .47426 L
.48595 .47568 L
.48672 .47702 L
.48745 .47828 L
.48815 .47948 L
.4888 .48061 L
.48942 .48168 L
.49 .48269 L
.49055 .48364 L
.49107 .48454 L
.49157 .48539 L
.49203 .4862 L
.49247 .48696 L
.49288 .48768 L
.49328 .48836 L
.49365 .489 L
.494 .48961 L
.49433 .49018 L
.49464 .49072 L
.49494 .49123 L
.49522 .49171 L
.49548 .49217 L
.49573 .4926 L
.49596 .49301 L
.49619 .4934 L
.4964 .49376 L
.4966 .4941 L
.49678 .49443 L
.49696 .49474 L
.49713 .49503 L
.49729 .4953 L
.49744 .49556 L
.49758 .4958 L
.49771 .49604 L
.49784 .49625 L
.49796 .49646 L
.49807 .49666 L
.49818 .49684 L
.49828 .49701 L
.49837 .49718 L
.49846 .49733 L
.49855 .49748 L
.49863 .49762 L
.4987 .49775 L
.49877 .49788 L
.49884 .49799 L
.4989 .4981 L
Mistroke
.49897 .49821 L
.49902 .49831 L
.49908 .4984 L
.49913 .49849 L
.49918 .49857 L
.49922 .49865 L
.49926 .49872 L
.4993 .49879 L
.49934 .49886 L
.49938 .49892 L
.49941 .49898 L
.49945 .49904 L
.49948 .49909 L
.4995 .49914 L
.49953 .49919 L
.49956 .49923 L
.49958 .49928 L
.49961 .49932 L
.49963 .49935 L
.49965 .49939 L
.49967 .49942 L
.49969 .49946 L
.4997 .49949 L
.49972 .49951 L
.49973 .49954 L
.49975 .49957 L
.49976 .49959 L
.49978 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
Mistroke
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
Mfstroke
1 0 0 r
% Start of user PostScript
-9.8508431 -0.87051112 -8.941467 -1.4571244 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-8.1311318 -1.9266796 -7.4078478 -2.2969403 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-4.0515934 -3.1544155 -3.7408489 -3.1319479 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-2.2200025 -2.6175427 -2.0698546 -2.521374 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-1.2979234 -1.8579635 -1.2175529 -1.7708395 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-0.78886439 -1.2423871 -0.74257604 -1.1787637 MAarrowhead1
% End of user PostScript
.266 1 0 r
.25508 .09549 m
.26903 .11701 L
s
% Start of user PostScript
-0.48983523 -0.80902613 -0.46194347 -0.76597549 MAarrowhead1
% End of user PostScript
0 1 .049 r
.3462 .23987 m
.35482 .25396 L
s
% Start of user PostScript
-0.30760217 -0.52026434 -0.29036347 -0.49207732 MAarrowhead1
% End of user PostScript
0 1 .364 r
.40286 .33373 m
.40826 .34282 L
s
% Start of user PostScript
-0.19428537 -0.33253415 -0.1834861 -0.31436034 MAarrowhead1
% End of user PostScript
0 1 .679 r
.43846 .39405 m
.44187 .39986 L
s
% Start of user PostScript
-0.12307323 -0.21190497 -0.11626067 -0.20027404 MAarrowhead1
% End of user PostScript
0 1 .995 r
.46096 .43258 m
.46312 .43629 L
s
% Start of user PostScript
-0.078077861 -0.13483312 -0.073765018 -0.12741669 MAarrowhead1
% End of user PostScript
0 .69 1 r
.47522 .45714 m
.47658 .4595 L
s
% Start of user PostScript
-0.049569418 -0.0857291 -0.046834198 -0.081008602 MAarrowhead1
% End of user PostScript
0 .375 1 r
.48426 .47276 m
.48513 .47426 L
s
% Start of user PostScript
-0.031481894 -0.054487676 -0.029745653 -0.051485834 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49 .48269 m
.49055 .48364 L
s
% Start of user PostScript
-0.019998091 -0.034624819 -0.018895478 -0.032716759 MAarrowhead1
% End of user PostScript
1 0 .294 r
.81073 1 m
.79624 .97907 L
.77914 .954 L
.76309 .93013 L
.74801 .90742 L
.73384 .88583 L
.72051 .86532 L
.70798 .84583 L
.69619 .82733 L
.6851 .80978 L
.67465 .79313 L
.66481 .77734 L
.65554 .76237 L
.64681 .74818 L
.63858 .73474 L
.63082 .72201 L
.62351 .70995 L
.61661 .69853 L
.6101 .68773 L
.60397 .67749 L
.59818 .66781 L
.59271 .65865 L
.58756 .64998 L
.5827 .64178 L
.5781 .63402 L
.57377 .62668 L
.56968 .61974 L
.56582 .61318 L
.56217 .60697 L
.55873 .6011 L
.55548 .59556 L
.55241 .59031 L
.54951 .58535 L
.54677 .58066 L
.54418 .57623 L
.54174 .57204 L
.53943 .56808 L
.53726 .56433 L
.5352 .5608 L
.53325 .55745 L
.53142 .55429 L
.52968 .5513 L
.52804 .54848 L
.5265 .54581 L
.52503 .54329 L
.52365 .54091 L
.52235 .53865 L
.52111 .53652 L
.51995 .53451 L
.51885 .53261 L
Mistroke
.51781 .53082 L
.51683 .52912 L
.5159 .52751 L
.51502 .526 L
.51419 .52457 L
.51341 .52321 L
.51267 .52193 L
.51197 .52073 L
.51131 .51958 L
.51069 .5185 L
.5101 .51748 L
.50954 .51652 L
.50902 .51561 L
.50852 .51475 L
.50805 .51394 L
.50761 .51317 L
.50719 .51244 L
.50679 .51176 L
.50642 .51111 L
.50606 .5105 L
.50573 .50992 L
.50541 .50937 L
.50511 .50886 L
.50483 .50837 L
.50457 .50791 L
.50431 .50747 L
.50408 .50706 L
.50385 .50667 L
.50364 .5063 L
.50344 .50595 L
.50325 .50563 L
.50307 .50532 L
.5029 .50502 L
.50274 .50475 L
.50259 .50448 L
.50245 .50424 L
.50231 .504 L
.50218 .50378 L
.50206 .50357 L
.50195 .50338 L
.50184 .50319 L
.50174 .50302 L
.50165 .50285 L
.50155 .50269 L
.50147 .50254 L
.50139 .5024 L
.50131 .50227 L
.50124 .50215 L
.50117 .50203 L
.50111 .50192 L
Mistroke
.50105 .50181 L
.50099 .50171 L
.50093 .50162 L
.50088 .50153 L
.50083 .50144 L
.50079 .50136 L
.50074 .50129 L
.5007 .50122 L
.50066 .50115 L
.50063 .50109 L
.50059 .50103 L
.50056 .50097 L
.50053 .50092 L
.5005 .50087 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50036 .50062 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .5003 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
Mfstroke
1 0 0 r
% Start of user PostScript
3.8883979 2.9722386 3.5889228 2.9558744 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
3.3173221 2.9207241 3.0705418 2.8704516 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.8486552 2.3042343 1.726441 2.2124065 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.0922322 1.6065249 1.0255717 1.5291519 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
0.66778992 1.0659921 0.62892915 1.0107862 MAarrowhead1
% End of user PostScript
.581 1 0 r
.70798 .84583 m
.69619 .82733 L
s
% Start of user PostScript
0.41596523 0.69166531 0.39238482 0.65466886 MAarrowhead1
% End of user PostScript
.266 1 0 r
.63082 .72201 m
.62351 .70995 L
s
% Start of user PostScript
0.2616398 0.44401908 0.24701073 0.41990296 MAarrowhead1
% End of user PostScript
0 1 .049 r
.5827 .64178 m
.5781 .63402 L
s
% Start of user PostScript
0.16539187 0.2835581 0.15620943 0.26804202 MAarrowhead1
% End of user PostScript
0 1 .364 r
.55241 .59031 m
.54951 .58535 L
s
% Start of user PostScript
0.10481393 0.18061864 0.099015534 0.17069893 MAarrowhead1
% End of user PostScript
0 1 .679 r
.53325 .55745 m
.53142 .55429 L
s
% Start of user PostScript
0.066508082 0.11490162 0.062835422 0.10857961 MAarrowhead1
% End of user PostScript
0 1 .995 r
.52111 .53652 m
.51995 .53451 L
s
% Start of user PostScript
0.042228533 0.073048615 0.039898728 0.069025739 MAarrowhead1
% End of user PostScript
0 .69 1 r
.51341 .52321 m
.51267 .52193 L
s
% Start of user PostScript
0.026821057 0.046425769 0.025341974 0.043867882 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50852 .51475 m
.50805 .51394 L
s
% Start of user PostScript
0.017037858 0.02950101 0.016098496 0.027875245 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50541 .50937 m
.50511 .50886 L
s
% Start of user PostScript
0.010824025 0.018744765 0.010227322 0.017711646 MAarrowhead1
% End of user PostScript
0 .063 1 r
.30468 0 m
.31151 .03269 L
.31872 .06397 L
.32595 .09279 L
.33315 .11938 L
.34027 .14395 L
.34728 .16669 L
.35414 .18776 L
.36083 .2073 L
.36734 .22546 L
.37364 .24235 L
.37972 .25807 L
.38559 .27272 L
.39124 .28639 L
.39666 .29916 L
.40187 .31108 L
.40685 .32224 L
.41161 .33268 L
.41616 .34246 L
.4205 .35163 L
.42464 .36022 L
.42859 .36829 L
.43234 .37587 L
.43591 .38298 L
.43931 .38967 L
.44254 .39595 L
.4456 .40187 L
.44851 .40743 L
.45127 .41266 L
.45389 .41759 L
.45638 .42224 L
.45873 .42661 L
.46096 .43073 L
.46308 .43461 L
.46508 .43827 L
.46698 .44172 L
.46877 .44498 L
.47047 .44805 L
.47208 .45094 L
.47361 .45367 L
.47505 .45625 L
.47641 .45868 L
.4777 .46098 L
.47892 .46315 L
.48007 .46519 L
.48117 .46712 L
.4822 .46894 L
.48317 .47066 L
.4841 .47229 L
.48497 .47382 L
Mistroke
.4858 .47527 L
.48658 .47664 L
.48731 .47793 L
.48801 .47915 L
.48867 .4803 L
.48929 .48139 L
.48988 .48242 L
.49044 .48339 L
.49096 .48431 L
.49146 .48518 L
.49193 .48599 L
.49237 .48677 L
.49279 .4875 L
.49319 .48819 L
.49357 .48884 L
.49392 .48946 L
.49426 .49004 L
.49457 .49059 L
.49487 .49111 L
.49515 .4916 L
.49542 .49206 L
.49567 .4925 L
.49591 .49291 L
.49614 .4933 L
.49635 .49367 L
.49655 .49402 L
.49674 .49435 L
.49692 .49466 L
.49709 .49496 L
.49725 .49523 L
.4974 .4955 L
.49754 .49575 L
.49768 .49598 L
.49781 .4962 L
.49793 .49641 L
.49804 .49661 L
.49815 .4968 L
.49825 .49697 L
.49835 .49714 L
.49844 .4973 L
.49853 .49745 L
.49861 .49759 L
.49868 .49772 L
.49876 .49785 L
.49882 .49796 L
.49889 .49808 L
.49895 .49818 L
.49901 .49828 L
.49906 .49838 L
.49911 .49847 L
Mistroke
.49916 .49855 L
.49921 .49863 L
.49925 .49871 L
.49929 .49878 L
.49933 .49885 L
.49937 .49891 L
.4994 .49897 L
.49944 .49903 L
.49947 .49908 L
.4995 .49913 L
.49953 .49918 L
.49955 .49922 L
.49958 .49927 L
.4996 .49931 L
.49962 .49935 L
.49964 .49938 L
.49966 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49953 L
.49975 .49956 L
.49976 .49958 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
Mistroke
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
1 0 0 r
% Start of user PostScript
0.74704807 -7.4840901 0.50724082 -6.7275218 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
0.30717043 -6.0585877 0.14110615 -5.4663251 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-0.40902955 -2.8027982 -0.43387401 -2.5662212 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.45187038 -1.4481918 -0.4420223 -1.3422816 MAarrowhead1
% End of user PostScript
.897 1 0 r
.32595 .09279 m
.33315 .11938 L
s
% Start of user PostScript
-0.34810449 -0.81442359 -0.33370209 -0.76124264 MAarrowhead1
% End of user PostScript
.581 1 0 r
.37972 .25807 m
.38559 .27272 L
s
% Start of user PostScript
-0.24055387 -0.48385751 -0.22881496 -0.45455266 MAarrowhead1
% End of user PostScript
.266 1 0 r
.4205 .35163 m
.42464 .36022 L
s
% Start of user PostScript
-0.15899532 -0.29674439 -0.15071454 -0.27955043 MAarrowhead1
% End of user PostScript
0 1 .049 r
.44851 .40743 m
.45127 .41266 L
s
% Start of user PostScript
-0.10297443 -0.1851435 -0.097451913 -0.17467216 MAarrowhead1
% End of user PostScript
0 1 .364 r
.46698 .44172 m
.46877 .44498 L
s
% Start of user PostScript
-0.066046263 -0.11655208 -0.062454506 -0.11004305 MAarrowhead1
% End of user PostScript
0 1 .679 r
.47892 .46315 m
.48007 .46519 L
s
% Start of user PostScript
-0.042159752 -0.073708147 -0.039851359 -0.069618398 MAarrowhead1
% End of user PostScript
0 1 .995 r
.48658 .47664 m
.48731 .47793 L
s
% Start of user PostScript
-0.026848741 -0.046721159 -0.025373731 -0.044137292 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49146 .48518 m
.49193 .48599 L
s
% Start of user PostScript
-0.017078131 -0.029649395 -0.016138328 -0.028012369 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49457 .49059 m
.49487 .49111 L
s
% Start of user PostScript
-0.01085682 -0.018826555 -0.010258875 -0.017787949 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49655 .49402 m
.49674 .49435 L
s
% Start of user PostScript
-0.0068998235 -0.011957833 -0.0065196543 -0.011298428 MAarrowhead1
% End of user PostScript
0 1 .007 r
.19322 0 m
.20771 .02161 L
.22445 .04688 L
.24019 .07091 L
.25498 .09375 L
.2689 .11543 L
.28199 .13601 L
.29432 .15554 L
.30592 .17407 L
.31685 .19163 L
.32715 .20828 L
.33685 .22406 L
.34599 .23901 L
.35461 .25317 L
.36274 .26658 L
.3704 .27928 L
.37763 .2913 L
.38445 .30267 L
.39088 .31344 L
.39695 .32363 L
.40268 .33327 L
.40809 .34239 L
.41319 .35101 L
.418 .35917 L
.42255 .36689 L
.42684 .37418 L
.4309 .38108 L
.43472 .38761 L
.43834 .39378 L
.44175 .39961 L
.44497 .40512 L
.44801 .41034 L
.45089 .41526 L
.4536 .41992 L
.45617 .42432 L
.45859 .42849 L
.46088 .43242 L
.46304 .43614 L
.46508 .43965 L
.46701 .44297 L
.46883 .44611 L
.47055 .44908 L
.47217 .45188 L
.47371 .45453 L
.47516 .45703 L
.47653 .4594 L
.47783 .46164 L
.47905 .46375 L
.4802 .46575 L
.4813 .46763 L
Mistroke
.48233 .46942 L
.4833 .4711 L
.48422 .47269 L
.48509 .4742 L
.48592 .47562 L
.48669 .47696 L
.48743 .47823 L
.48812 .47943 L
.48877 .48056 L
.48939 .48164 L
.48998 .48265 L
.49053 .4836 L
.49105 .48451 L
.49155 .48536 L
.49201 .48617 L
.49245 .48693 L
.49287 .48765 L
.49326 .48833 L
.49363 .48897 L
.49398 .48958 L
.49432 .49016 L
.49463 .4907 L
.49493 .49121 L
.4952 .4917 L
.49547 .49215 L
.49572 .49259 L
.49596 .49299 L
.49618 .49338 L
.49639 .49375 L
.49659 .49409 L
.49678 .49442 L
.49695 .49472 L
.49712 .49501 L
.49728 .49529 L
.49743 .49555 L
.49757 .49579 L
.49771 .49603 L
.49783 .49625 L
.49795 .49645 L
.49806 .49665 L
.49817 .49683 L
.49827 .49701 L
.49837 .49717 L
.49846 .49733 L
.49854 .49748 L
.49862 .49761 L
.4987 .49775 L
.49877 .49787 L
.49884 .49799 L
.4989 .4981 L
Mistroke
.49896 .4982 L
.49902 .4983 L
.49907 .4984 L
.49912 .49848 L
.49917 .49857 L
.49922 .49865 L
.49926 .49872 L
.4993 .49879 L
.49934 .49886 L
.49938 .49892 L
.49941 .49898 L
.49944 .49904 L
.49947 .49909 L
.4995 .49914 L
.49953 .49919 L
.49956 .49923 L
.49958 .49927 L
.4996 .49931 L
.49963 .49935 L
.49965 .49939 L
.49967 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49978 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
Mistroke
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
Mfstroke
1 0 0 r
% Start of user PostScript
-6.5606368 -2.9634709 -6.0089333 -3.129336 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-5.5130164 -3.2421058 -5.0664232 -3.310575 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.9244962 -3.0612555 -2.7179449 -2.9710623 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.6743334 -2.2631701 -1.5676311 -2.1633816 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-1.005393 -1.5390131 -0.94539498 -1.4621125 MAarrowhead1
% End of user PostScript
.581 1 0 r
.19322 0 m
.20771 .02161 L
s
% Start of user PostScript
-0.62021682 -1.0099361 -0.58457443 -0.95678761 MAarrowhead1
% End of user PostScript
.266 1 0 r
.30592 .17407 m
.31685 .19163 L
s
% Start of user PostScript
-0.38815495 -0.65186764 -0.3662969 -0.61673681 MAarrowhead1
% End of user PostScript
0 1 .049 r
.37763 .2913 m
.38445 .30267 L
s
% Start of user PostScript
-0.24473815 -0.4174047 -0.23110091 -0.39465133 MAarrowhead1
% End of user PostScript
0 1 .364 r
.42255 .36689 m
.42684 .37418 L
s
% Start of user PostScript
-0.15489739 -0.26622644 -0.14631254 -0.25163258 MAarrowhead1
% End of user PostScript
0 1 .679 r
.45089 .41526 m
.4536 .41992 L
s
% Start of user PostScript
-0.098223825 -0.16947286 -0.092794759 -0.160157 MAarrowhead1
% End of user PostScript
0 1 .995 r
.46883 .44611 m
.47055 .44908 L
s
% Start of user PostScript
-0.062345727 -0.10777757 -0.058904433 -0.1018449 MAarrowhead1
% End of user PostScript
0 .69 1 r
.4802 .46575 m
.4813 .46763 L
s
% Start of user PostScript
-0.039591834 -0.068508845 -0.037407982 -0.064735143 MAarrowhead1
% End of user PostScript
0 .375 1 r
.48743 .47823 m
.48812 .47943 L
s
% Start of user PostScript
-0.025148334 -0.043537149 -0.023761649 -0.041138149 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49201 .48617 m
.49245 .48693 L
s
% Start of user PostScript
-0.015975896 -0.027664376 -0.015095132 -0.026139742 MAarrowhead1
% End of user PostScript
1 .503 0 r
.80836 1 m
.79102 .97442 L
.77431 .94943 L
.75861 .92566 L
.74385 .90307 L
.72997 .88161 L
.71692 .86123 L
.70463 .84188 L
.69307 .82353 L
.68218 .80612 L
.67193 .78962 L
.66226 .77398 L
.65316 .75915 L
.64458 .74511 L
.63649 .7318 L
.62886 .71921 L
.62167 .70728 L
.61488 .69599 L
.60848 .6853 L
.60244 .67519 L
.59675 .66562 L
.59137 .65657 L
.5863 .64801 L
.58151 .6399 L
.57698 .63224 L
.57272 .625 L
.56869 .61814 L
.56488 .61166 L
.56129 .60554 L
.5579 .59974 L
.55469 .59427 L
.55167 .58909 L
.54881 .58419 L
.54611 .57957 L
.54356 .57519 L
.54116 .57106 L
.53888 .56715 L
.53674 .56346 L
.53471 .55997 L
.53279 .55667 L
.53098 .55355 L
.52927 .5506 L
.52765 .54781 L
.52613 .54518 L
.52469 .54269 L
.52332 .54034 L
.52204 .53812 L
.52082 .53602 L
.51967 .53404 L
.51859 .53216 L
Mistroke
.51756 .53039 L
.51659 .52872 L
.51568 .52714 L
.51481 .52564 L
.514 .52423 L
.51322 .52289 L
.5125 .52163 L
.51181 .52044 L
.51116 .51931 L
.51054 .51825 L
.50996 .51724 L
.50941 .51629 L
.50889 .5154 L
.5084 .51455 L
.50794 .51375 L
.5075 .51299 L
.50709 .51227 L
.5067 .5116 L
.50633 .51096 L
.50598 .51035 L
.50565 .50978 L
.50534 .50924 L
.50504 .50873 L
.50476 .50825 L
.5045 .5078 L
.50425 .50737 L
.50402 .50696 L
.5038 .50658 L
.50359 .50622 L
.50339 .50587 L
.5032 .50555 L
.50303 .50524 L
.50286 .50495 L
.5027 .50468 L
.50255 .50442 L
.50241 .50418 L
.50228 .50395 L
.50215 .50373 L
.50204 .50353 L
.50192 .50333 L
.50182 .50315 L
.50172 .50297 L
.50162 .50281 L
.50153 .50266 L
.50145 .50251 L
.50137 .50237 L
.50129 .50224 L
.50122 .50212 L
.50115 .502 L
.50109 .50189 L
Mistroke
.50103 .50179 L
.50097 .50169 L
.50092 .50159 L
.50087 .50151 L
.50082 .50142 L
.50078 .50134 L
.50073 .50127 L
.50069 .5012 L
.50065 .50113 L
.50062 .50107 L
.50058 .50101 L
.50055 .50096 L
.50052 .5009 L
.50049 .50085 L
.50047 .50081 L
.50044 .50076 L
.50042 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .50061 L
.50033 .50057 L
.50031 .50054 L
.5003 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50039 L
.50021 .50036 L
.5002 .50034 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50025 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50018 L
.5001 .50017 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
Mfstroke
1 0 0 r
% Start of user PostScript
8.0399696 2.0209392 7.3274164 2.3761214 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
6.6901042 2.649434 6.119084 2.8537059 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.4311159 3.1025369 3.1777173 3.0428416 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.9195522 2.4221746 1.7933202 2.3240362 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
1.1368309 1.6822287 1.0676771 1.6007433 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
0.69598391 1.1143351 0.65555795 1.0564837 MAarrowhead1
% End of user PostScript
.266 1 0 r
.71692 .86123 m
.70463 .84188 L
s
% Start of user PostScript
0.43383313 0.72245757 0.4092643 0.68376992 MAarrowhead1
% End of user PostScript
0 1 .049 r
.63649 .7318 m
.62886 .71921 L
s
% Start of user PostScript
0.27297777 0.46360749 0.25772261 0.43841356 MAarrowhead1
% End of user PostScript
0 1 .364 r
.5863 .64801 m
.58151 .6399 L
s
% Start of user PostScript
0.17259083 0.29601132 0.16301122 0.27980942 MAarrowhead1
% End of user PostScript
0 1 .679 r
.55469 .59427 m
.55167 .58909 L
s
% Start of user PostScript
0.1093863 0.18853321 0.10333575 0.17817744 MAarrowhead1
% End of user PostScript
0 1 .995 r
.53471 .55997 m
.53279 .55667 L
s
% Start of user PostScript
0.069412646 0.11993088 0.065579847 0.11333171 MAarrowhead1
% End of user PostScript
0 .69 1 r
.52204 .53812 m
.52082 .53602 L
s
% Start of user PostScript
0.044073782 0.076244176 0.041642254 0.072045176 MAarrowhead1
% End of user PostScript
0 .375 1 r
.514 .52423 m
.51322 .52289 L
s
% Start of user PostScript
0.027993377 0.048456127 0.026449671 0.045786331 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50889 .5154 m
.5084 .51455 L
s
% Start of user PostScript
0.01778267 0.03079101 0.016802251 0.029094141 MAarrowhead1
% End of user PostScript
1 .883 0 r
.78742 1 m
.77717 .98205 L
.76194 .9554 L
.74754 .93023 L
.73393 .90646 L
.72106 .88401 L
.7089 .86279 L
.69741 .84276 L
.68655 .82383 L
.67628 .80595 L
.66658 .78907 L
.65741 .77311 L
.64874 .75804 L
.64055 .7438 L
.63281 .73035 L
.6255 .71764 L
.61859 .70563 L
.61206 .69429 L
.60588 .68357 L
.60005 .67344 L
.59454 .66388 L
.58933 .65484 L
.58441 .6463 L
.57976 .63823 L
.57536 .63061 L
.57121 .62341 L
.56729 .6166 L
.56358 .61017 L
.56008 .6041 L
.55677 .59836 L
.55364 .59294 L
.55068 .58781 L
.54789 .58297 L
.54525 .5784 L
.54276 .57407 L
.5404 .56999 L
.53817 .56613 L
.53607 .56249 L
.53408 .55904 L
.5322 .55579 L
.53043 .55271 L
.52875 .5498 L
.52717 .54706 L
.52567 .54447 L
.52425 .54201 L
.52292 .5397 L
.52165 .53751 L
.52046 .53544 L
.51933 .53349 L
.51827 .53164 L
Mistroke
.51726 .5299 L
.51631 .52825 L
.51541 .52669 L
.51456 .52522 L
.51376 .52383 L
.513 .52252 L
.51228 .52128 L
.51161 .5201 L
.51097 .519 L
.51036 .51795 L
.50979 .51696 L
.50925 .51602 L
.50874 .51514 L
.50826 .51431 L
.5078 .51352 L
.50737 .51277 L
.50697 .51207 L
.50658 .5114 L
.50622 .51077 L
.50588 .51018 L
.50555 .50962 L
.50525 .50909 L
.50496 .50859 L
.50469 .50811 L
.50443 .50767 L
.50418 .50724 L
.50395 .50685 L
.50373 .50647 L
.50353 .50611 L
.50333 .50577 L
.50315 .50546 L
.50298 .50516 L
.50281 .50487 L
.50266 .5046 L
.50251 .50435 L
.50237 .50411 L
.50224 .50388 L
.50212 .50367 L
.502 .50347 L
.50189 .50328 L
.50179 .5031 L
.50169 .50292 L
.5016 .50276 L
.50151 .50261 L
.50142 .50247 L
.50135 .50233 L
.50127 .5022 L
.5012 .50208 L
.50114 .50197 L
.50107 .50186 L
Mistroke
.50101 .50176 L
.50096 .50166 L
.5009 .50157 L
.50086 .50148 L
.50081 .5014 L
.50076 .50132 L
.50072 .50125 L
.50068 .50118 L
.50064 .50112 L
.50061 .50105 L
.50057 .501 L
.50054 .50094 L
.50051 .50089 L
.50049 .50084 L
.50046 .50079 L
.50043 .50075 L
.50041 .50071 L
.50039 .50067 L
.50037 .50063 L
.50035 .5006 L
.50033 .50056 L
.50031 .50053 L
.50029 .5005 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50018 .50032 L
.50017 .5003 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50012 .50022 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
Mfstroke
1 0 0 r
% Start of user PostScript
4.7645936 9.3103742 4.5259001 8.7557138 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
4.297168 8.2371622 4.0782747 7.7519902 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.8029887 5.1073117 2.6541954 4.815898 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.8039978 3.2048202 1.706374 3.0250229 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
1.1535105 2.0234258 1.0905042 1.910893 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
0.73521165 1.2815231 0.69486909 1.2105664 MAarrowhead1
% End of user PostScript
.266 1 0 r
.73393 .90646 m
.72106 .88401 L
s
% Start of user PostScript
0.46785425 0.81292104 0.44212375 0.7680109 MAarrowhead1
% End of user PostScript
0 1 .049 r
.64874 .75804 m
.64055 .7438 L
s
% Start of user PostScript
0.29748399 0.51607525 0.28110479 0.48759645 MAarrowhead1
% End of user PostScript
0 1 .364 r
.59454 .66388 m
.58933 .65484 L
s
% Start of user PostScript
0.18907943 0.32775508 0.17866301 0.3096786 MAarrowhead1
% End of user PostScript
0 1 .679 r
.56008 .6041 m
.55677 .59836 L
s
% Start of user PostScript
0.12015417 0.20819572 0.11353298 0.19671646 MAarrowhead1
% End of user PostScript
0 1 .995 r
.53817 .56613 m
.53607 .56249 L
s
% Start of user PostScript
0.076346715 0.13226263 0.072138978 0.12497112 MAarrowhead1
% End of user PostScript
0 .69 1 r
.52425 .54201 m
.52292 .5397 L
s
% Start of user PostScript
0.048508778 0.084028008 0.045835099 0.079395947 MAarrowhead1
% End of user PostScript
0 .375 1 r
.51541 .52669 m
.51456 .52522 L
s
% Start of user PostScript
0.03082049 0.053385305 0.029121684 0.050442533 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50979 .51696 m
.50925 .51602 L
s
% Start of user PostScript
0.019581834 0.033917574 0.018502477 0.03204796 MAarrowhead1
% End of user PostScript
0 .11 1 r
.37484 0 m
.37515 .03336 L
.37637 .0689 L
.37827 .10117 L
.38073 .13052 L
.38362 .15727 L
.38684 .18169 L
.39031 .20403 L
.39396 .2245 L
.39772 .24328 L
.40156 .26055 L
.40543 .27645 L
.40929 .29112 L
.41312 .30466 L
.41689 .31719 L
.42059 .32879 L
.42421 .33954 L
.42773 .34953 L
.43114 .35882 L
.43444 .36746 L
.43762 .37551 L
.44069 .38301 L
.44363 .39002 L
.44646 .39657 L
.44917 .40269 L
.45176 .40842 L
.45424 .41378 L
.4566 .4188 L
.45886 .42352 L
.46101 .42794 L
.46306 .43209 L
.465 .43598 L
.46686 .43965 L
.46862 .44309 L
.47029 .44633 L
.47188 .44937 L
.47338 .45224 L
.47481 .45493 L
.47617 .45748 L
.47745 .45987 L
.47867 .46212 L
.47983 .46425 L
.48092 .46625 L
.48196 .46814 L
.48294 .46992 L
.48387 .4716 L
.48474 .47318 L
.48558 .47467 L
.48636 .47608 L
.48711 .47741 L
Mistroke
.48781 .47867 L
.48848 .47985 L
.48911 .48097 L
.48971 .48203 L
.49027 .48302 L
.4908 .48396 L
.49131 .48485 L
.49179 .48569 L
.49224 .48648 L
.49266 .48723 L
.49307 .48794 L
.49345 .4886 L
.49381 .48923 L
.49415 .48983 L
.49447 .49039 L
.49477 .49092 L
.49506 .49142 L
.49533 .4919 L
.49559 .49234 L
.49583 .49277 L
.49606 .49317 L
.49628 .49354 L
.49648 .4939 L
.49668 .49424 L
.49686 .49455 L
.49703 .49485 L
.4972 .49514 L
.49735 .49541 L
.4975 .49566 L
.49763 .4959 L
.49776 .49613 L
.49789 .49634 L
.498 .49654 L
.49811 .49673 L
.49822 .49691 L
.49832 .49708 L
.49841 .49724 L
.4985 .4974 L
.49858 .49754 L
.49866 .49767 L
.49873 .4978 L
.4988 .49792 L
.49887 .49804 L
.49893 .49815 L
.49899 .49825 L
.49904 .49835 L
.4991 .49844 L
.49915 .49852 L
.49919 .4986 L
.49924 .49868 L
Mistroke
.49928 .49875 L
.49932 .49882 L
.49936 .49889 L
.49939 .49895 L
.49943 .49901 L
.49946 .49906 L
.49949 .49911 L
.49952 .49916 L
.49954 .49921 L
.49957 .49925 L
.49959 .49929 L
.49961 .49933 L
.49964 .49937 L
.49966 .4994 L
.49967 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49952 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49971 L
.49984 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
Mistroke
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
Mfstroke
1 0 0 r
% Start of user PostScript
1.6340295 -7.32259 1.3142217 -6.5210416 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
1.0427139 -5.8168004 0.81274858 -5.1974101 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-0.036333842 -2.4852818 -0.089144015 -2.253351 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.24515076 -1.1943769 -0.24905594 -1.0983721 MAarrowhead1
% End of user PostScript
.897 1 0 r
.38684 .18169 m
.39031 .20403 L
s
% Start of user PostScript
-0.22632212 -0.63661333 -0.21938202 -0.59193533 MAarrowhead1
% End of user PostScript
.581 1 0 r
.41689 .31719 m
.42059 .32879 L
s
% Start of user PostScript
-0.16621677 -0.36562756 -0.1588136 -0.34242717 MAarrowhead1
% End of user PostScript
.266 1 0 r
.44363 .39002 m
.44646 .39657 L
s
% Start of user PostScript
-0.11273067 -0.21995647 -0.10707575 -0.20686407 MAarrowhead1
% End of user PostScript
0 1 .049 r
.46306 .43209 m
.465 .43598 L
s
% Start of user PostScript
-0.073887133 -0.13582571 -0.069991994 -0.12803118 MAarrowhead1
% End of user PostScript
0 1 .364 r
.47617 .45748 m
.47745 .45987 L
s
% Start of user PostScript
-0.047663282 -0.085049586 -0.045092462 -0.080263781 MAarrowhead1
% End of user PostScript
0 1 .679 r
.48474 .47318 m
.48558 .47467 L
s
% Start of user PostScript
-0.030511213 -0.053639618 -0.028847331 -0.050651866 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49027 .48302 m
.4908 .48396 L
s
% Start of user PostScript
-0.019457759 -0.033953711 -0.018390922 -0.032072266 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49381 .48923 m
.49415 .48983 L
s
% Start of user PostScript
-0.012385448 -0.021532267 -0.011704557 -0.020342243 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49606 .49317 m
.49628 .49354 L
s
% Start of user PostScript
-0.0078763486 -0.013667671 -0.0074427695 -0.012913295 MAarrowhead1
% End of user PostScript
0 .06 1 r
.4975 .49566 m
.49763 .4959 L
s
% Start of user PostScript
-0.0050065169 -0.0086796244 -0.004730734 -0.0082008753 MAarrowhead1
% End of user PostScript
1 0 .34 r
.19799 0 m
.2 .00309 L
.21705 .02959 L
.23309 .05475 L
.24819 .07863 L
.2624 .10127 L
.27579 .12275 L
.2884 .14311 L
.30028 .16241 L
.31148 .18069 L
.32203 .19801 L
.33198 .21441 L
.34137 .22994 L
.35022 .24464 L
.35857 .25856 L
.36644 .27173 L
.37387 .28419 L
.38089 .29598 L
.3875 .30714 L
.39375 .31769 L
.39965 .32767 L
.40521 .33711 L
.41046 .34604 L
.41543 .35448 L
.42011 .36247 L
.42453 .37001 L
.42871 .37715 L
.43265 .3839 L
.43638 .39028 L
.43989 .39631 L
.44322 .40201 L
.44636 .40739 L
.44932 .41249 L
.45212 .4173 L
.45476 .42185 L
.45726 .42615 L
.45962 .43021 L
.46185 .43405 L
.46396 .43768 L
.46595 .44111 L
.46782 .44436 L
.4696 .44742 L
.47128 .45031 L
.47286 .45305 L
.47436 .45564 L
.47577 .45808 L
.47711 .46039 L
.47837 .46257 L
.47957 .46463 L
.48069 .46658 L
Mistroke
.48176 .46842 L
.48276 .47016 L
.48371 .47181 L
.48461 .47336 L
.48546 .47483 L
.48626 .47622 L
.48702 .47753 L
.48774 .47876 L
.48841 .47993 L
.48905 .48104 L
.48965 .48209 L
.49022 .48307 L
.49076 .48401 L
.49127 .48489 L
.49175 .48572 L
.49221 .48651 L
.49264 .48725 L
.49304 .48795 L
.49343 .48862 L
.49379 .48924 L
.49413 .48984 L
.49446 .4904 L
.49476 .49093 L
.49505 .49143 L
.49532 .4919 L
.49558 .49235 L
.49582 .49277 L
.49605 .49317 L
.49627 .49354 L
.49648 .4939 L
.49667 .49424 L
.49686 .49455 L
.49703 .49485 L
.49719 .49514 L
.49735 .4954 L
.49749 .49566 L
.49763 .4959 L
.49776 .49612 L
.49789 .49634 L
.498 .49654 L
.49811 .49673 L
.49822 .49691 L
.49831 .49708 L
.49841 .49724 L
.4985 .49739 L
.49858 .49754 L
.49866 .49767 L
.49873 .4978 L
.4988 .49792 L
.49887 .49804 L
Mistroke
.49893 .49815 L
.49899 .49825 L
.49904 .49834 L
.4991 .49844 L
.49915 .49852 L
.49919 .4986 L
.49924 .49868 L
.49928 .49875 L
.49932 .49882 L
.49936 .49889 L
.49939 .49895 L
.49943 .49901 L
.49946 .49906 L
.49949 .49911 L
.49952 .49916 L
.49954 .49921 L
.49957 .49925 L
.49959 .49929 L
.49961 .49933 L
.49964 .49937 L
.49966 .4994 L
.49967 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49952 L
.49974 .49955 L
.49975 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49971 L
.49984 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49978 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
Mistroke
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
Mfstroke
1 0 0 r
% Start of user PostScript
-9.7154496 -2.8106541 -8.8627446 -3.2050933 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-8.0993871 -3.5044463 -7.4147988 -3.7237463 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-4.1811052 -3.8975846 -3.8749624 -3.8138173 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-2.3498518 -3.0073254 -2.1962773 -2.8832094 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-1.3955372 -2.0794295 -1.3109716 -1.9780446 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-0.85568582 -1.3747748 -0.80609094 -1.3032014 MAarrowhead1
% End of user PostScript
.266 1 0 r
.23309 .05475 m
.24819 .07863 L
s
% Start of user PostScript
-0.5338161 -0.89049404 -0.50361979 -0.84274542 MAarrowhead1
% End of user PostScript
0 1 .049 r
.33198 .21441 m
.34137 .22994 L
s
% Start of user PostScript
-0.33603015 -0.57118434 -0.31726251 -0.54012464 MAarrowhead1
% End of user PostScript
0 1 .364 r
.39375 .31769 m
.39965 .32767 L
s
% Start of user PostScript
-0.21250103 -0.36461886 -0.20070977 -0.34465556 MAarrowhead1
% End of user PostScript
0 1 .679 r
.43265 .3839 m
.43638 .39028 L
s
% Start of user PostScript
-0.1346954 -0.23220495 -0.12724605 -0.2194484 MAarrowhead1
% End of user PostScript
0 1 .995 r
.45726 .42615 m
.45962 .43021 L
s
% Start of user PostScript
-0.085477496 -0.14770361 -0.080757995 -0.13957563 MAarrowhead1
% End of user PostScript
0 .69 1 r
.47286 .45305 m
.47436 .45564 L
s
% Start of user PostScript
-0.054275672 -0.093897715 -0.051281426 -0.088726281 MAarrowhead1
% End of user PostScript
0 .375 1 r
.48276 .47016 m
.48371 .47181 L
s
% Start of user PostScript
-0.034473553 -0.059674828 -0.032572531 -0.05638685 MAarrowhead1
% End of user PostScript
0 .06 1 r
.48905 .48104 m
.48965 .48209 L
s
% Start of user PostScript
-0.021899321 -0.037919577 -0.020691949 -0.035829837 MAarrowhead1
% End of user PostScript
0 1 .002 r
.00401 0 m
.03695 .01236 L
.06958 .02692 L
.09947 .04232 L
.12689 .05829 L
.15209 .07462 L
.17527 .09113 L
.19665 .10764 L
.21638 .12406 L
.23462 .14026 L
.25151 .15617 L
.26717 .17173 L
.2817 .18689 L
.2952 .2016 L
.30777 .21584 L
.31947 .22959 L
.33037 .24284 L
.34055 .25558 L
.35006 .26781 L
.35895 .27953 L
.36726 .29075 L
.37505 .30147 L
.38234 .31171 L
.38918 .32148 L
.39559 .3308 L
.40161 .33967 L
.40726 .34811 L
.41257 .35614 L
.41756 .36377 L
.42225 .37102 L
.42667 .37791 L
.43082 .38445 L
.43473 .39065 L
.43841 .39653 L
.44188 .40211 L
.44515 .4074 L
.44822 .41241 L
.45112 .41715 L
.45386 .42165 L
.45644 .42591 L
.45887 .42994 L
.46116 .43375 L
.46333 .43736 L
.46537 .44078 L
.4673 .44402 L
.46911 .44708 L
.47083 .44997 L
.47245 .45271 L
.47398 .4553 L
.47542 .45775 L
Mistroke
.47678 .46006 L
.47807 .46226 L
.47928 .46433 L
.48043 .46628 L
.48151 .46814 L
.48253 .46989 L
.4835 .47154 L
.48441 .4731 L
.48527 .47458 L
.48609 .47598 L
.48686 .4773 L
.48758 .47855 L
.48827 .47973 L
.48892 .48085 L
.48953 .4819 L
.49011 .4829 L
.49065 .48384 L
.49117 .48473 L
.49166 .48557 L
.49212 .48636 L
.49255 .48711 L
.49296 .48782 L
.49335 .48849 L
.49372 .48913 L
.49406 .48973 L
.49439 .49029 L
.4947 .49083 L
.49499 .49133 L
.49527 .49181 L
.49553 .49226 L
.49578 .49269 L
.49601 .49309 L
.49623 .49347 L
.49644 .49383 L
.49663 .49417 L
.49682 .49449 L
.49699 .4948 L
.49716 .49508 L
.49732 .49535 L
.49746 .49561 L
.4976 .49585 L
.49774 .49608 L
.49786 .4963 L
.49798 .4965 L
.49809 .49669 L
.4982 .49688 L
.4983 .49705 L
.49839 .49721 L
.49848 .49736 L
.49856 .49751 L
Mistroke
.49864 .49765 L
.49872 .49778 L
.49879 .4979 L
.49885 .49801 L
.49892 .49812 L
.49898 .49823 L
.49903 .49833 L
.49909 .49842 L
.49914 .4985 L
.49918 .49859 L
.49923 .49867 L
.49927 .49874 L
.49931 .49881 L
.49935 .49887 L
.49939 .49894 L
.49942 .49899 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
.49956 .49924 L
.49959 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
Mistroke
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
1 0 0 r
% Start of user PostScript
-2.725484 -0.66972494 -2.4835868 -0.79157719 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-2.2672612 -0.88551609 -2.0734638 -0.95591018 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.1616633 -1.0455472 -1.0757607 -1.0257956 MAarrowhead1
% End of user PostScript
1 .788 0 r
.17527 .09113 m
.19665 .10764 L
s
% Start of user PostScript
-0.64945097 -0.81774802 -0.60670255 -0.78471014 MAarrowhead1
% End of user PostScript
.897 1 0 r
.30777 .21584 m
.31947 .22959 L
s
% Start of user PostScript
-0.38446812 -0.56831864 -0.36106725 -0.54081739 MAarrowhead1
% End of user PostScript
.581 1 0 r
.38234 .31171 m
.38918 .32148 L
s
% Start of user PostScript
-0.23532189 -0.37657468 -0.22164883 -0.35703295 MAarrowhead1
% End of user PostScript
.266 1 0 r
.42667 .37791 m
.43082 .38445 L
s
% Start of user PostScript
-0.14666693 -0.24417884 -0.13835944 -0.23110566 MAarrowhead1
% End of user PostScript
0 1 .049 r
.45386 .42165 m
.45644 .42591 L
s
% Start of user PostScript
-0.092280334 -0.15670232 -0.087122853 -0.14818743 MAarrowhead1
% End of user PostScript
0 1 .364 r
.47083 .44997 m
.47245 .45271 L
s
% Start of user PostScript
-0.058342575 -0.10005706 -0.055104136 -0.09458079 MAarrowhead1
% End of user PostScript
0 1 .679 r
.48151 .46814 m
.48253 .46989 L
s
% Start of user PostScript
-0.036976325 -0.063728609 -0.034930985 -0.060228199 MAarrowhead1
% End of user PostScript
0 1 .995 r
.48827 .47973 m
.48892 .48085 L
s
% Start of user PostScript
-0.023463666 -0.04053976 -0.022168044 -0.038309095 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49255 .48711 m
.49296 .48782 L
s
% Start of user PostScript
-0.014898269 -0.025772622 -0.014076334 -0.024353253 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49527 .49181 m
.49553 .49226 L
s
% Start of user PostScript
-0.0094625872 -0.016379533 -0.0089407674 -0.01547707 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49699 .4948 m
.49716 .49508 L
s
% Start of user PostScript
-0.0060110608 -0.010408238 -0.0056796502 -0.0098346483 MAarrowhead1
% End of user PostScript
1 .704 0 r
.47312 .98373 m
.4866 .93628 L
.49774 .89422 L
.50687 .85689 L
.5143 .82369 L
.52027 .79414 L
.52502 .76777 L
.52872 .74421 L
.53153 .72313 L
.53361 .70423 L
.53506 .68725 L
.53599 .67197 L
.53649 .65819 L
.53663 .64575 L
.53647 .63449 L
.53607 .62428 L
.53548 .61501 L
.53474 .60657 L
.53387 .59888 L
.53292 .59185 L
.53189 .58542 L
.53082 .57953 L
.52971 .57412 L
.52858 .56915 L
.52745 .56457 L
.52632 .56034 L
.52521 .55644 L
.52411 .55283 L
.52303 .54948 L
.52198 .54638 L
.52095 .54349 L
.51996 .54081 L
.519 .53832 L
.51808 .536 L
.51719 .53383 L
.51633 .5318 L
.51551 .52991 L
.51472 .52815 L
.51397 .52649 L
.51325 .52494 L
.51257 .52349 L
.51191 .52213 L
.51129 .52085 L
.5107 .51965 L
.51013 .51852 L
.5096 .51746 L
.50909 .51647 L
.5086 .51553 L
.50814 .51465 L
.50771 .51382 L
Mistroke
.50729 .51304 L
.5069 .51231 L
.50653 .51161 L
.50617 .51096 L
.50584 .51035 L
.50552 .50977 L
.50522 .50922 L
.50494 .50871 L
.50467 .50822 L
.50442 .50776 L
.50418 .50733 L
.50395 .50692 L
.50373 .50654 L
.50353 .50617 L
.50333 .50583 L
.50315 .50551 L
.50298 .5052 L
.50282 .50491 L
.50266 .50464 L
.50252 .50438 L
.50238 .50414 L
.50225 .50391 L
.50212 .5037 L
.50201 .50349 L
.5019 .5033 L
.50179 .50312 L
.50169 .50294 L
.5016 .50278 L
.50151 .50263 L
.50143 .50248 L
.50135 .50235 L
.50128 .50222 L
.50121 .50209 L
.50114 .50198 L
.50108 .50187 L
.50102 .50177 L
.50096 .50167 L
.50091 .50158 L
.50086 .50149 L
.50081 .50141 L
.50077 .50133 L
.50072 .50126 L
.50068 .50119 L
.50065 .50112 L
.50061 .50106 L
.50058 .501 L
.50055 .50095 L
.50052 .50089 L
.50049 .50084 L
.50046 .5008 L
Mistroke
.50044 .50075 L
.50041 .50071 L
.50039 .50067 L
.50037 .50064 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .5003 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .5002 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
Mistroke
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.47312 .98373 m
.4866 .93628 L
s
% Start of user PostScript
-0.053762816 0.96745089 -0.026800737 0.87255693 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49774 .89422 m
.50687 .85689 L
s
% Start of user PostScript
-0.0045288255 0.78844311 0.013739202 0.71377432 MAarrowhead1
% End of user PostScript
1 .473 0 r
.53506 .68725 m
.53599 .67197 L
s
% Start of user PostScript
0.070121419 0.37449443 0.071982038 0.34393443 MAarrowhead1
% End of user PostScript
1 .788 0 r
.53387 .59888 m
.53292 .59185 L
s
% Start of user PostScript
0.067748394 0.19775375 0.065833534 0.18370181 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52521 .55644 m
.52411 .55283 L
s
% Start of user PostScript
0.050414995 0.11287369 0.048214253 0.10565047 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51719 .53383 m
.51633 .5318 L
s
% Start of user PostScript
0.034373313 0.067656236 0.032662348 0.063608694 MAarrowhead1
% End of user PostScript
.266 1 0 r
.51129 .52085 m
.5107 .51965 L
s
% Start of user PostScript
0.022583237 0.041695623 0.021396807 0.039296176 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50729 .51304 m
.5069 .51231 L
s
% Start of user PostScript
0.014584655 0.026081322 0.013799284 0.024611549 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50467 .50822 m
.50442 .50776 L
s
% Start of user PostScript
0.0093414313 0.016440396 0.0088324154 0.015523968 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50298 .5052 m
.50282 .50491 L
s
% Start of user PostScript
0.0059589023 0.010403922 0.0056323134 0.0098271991 MAarrowhead1
% End of user PostScript
0 1 .995 r
.5019 .5033 m
.50179 .50312 L
s
% Start of user PostScript
0.0037935392 0.0065969145 0.0035850297 0.0062322527 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50121 .50209 m
.50114 .50198 L
s
% Start of user PostScript
0.0024126117 0.0041871274 0.0022798146 0.0039559997 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50077 .50133 m
.50072 .50126 L
s
% Start of user PostScript
0.0015336031 0.0026589356 0.001449129 0.0025122674 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50049 .50084 m
.50046 .5008 L
s
% Start of user PostScript
0.00097460801 0.0016889149 0.00092090545 0.0015957866 MAarrowhead1
% End of user PostScript
.612 1 0 r
.2408 0 m
.24873 .01801 L
.26152 .04641 L
.27375 .073 L
.28543 .09791 L
.29657 .12127 L
.30718 .14318 L
.31729 .16374 L
.32692 .18306 L
.33607 .2012 L
.34477 .21825 L
.35303 .23429 L
.36088 .24937 L
.36833 .26356 L
.3754 .27693 L
.3821 .28951 L
.38846 .30136 L
.39448 .31252 L
.40019 .32304 L
.4056 .33295 L
.41073 .3423 L
.41558 .35111 L
.42017 .35942 L
.42452 .36726 L
.42863 .37466 L
.43253 .38163 L
.43621 .38822 L
.4397 .39443 L
.443 .40029 L
.44612 .40583 L
.44907 .41105 L
.45186 .41598 L
.4545 .42064 L
.45699 .42504 L
.45935 .42919 L
.46159 .43311 L
.46369 .43681 L
.46569 .4403 L
.46757 .4436 L
.46936 .44672 L
.47104 .44967 L
.47263 .45245 L
.47414 .45507 L
.47556 .45756 L
.47691 .4599 L
.47818 .46211 L
.47938 .46421 L
.48051 .46618 L
.48159 .46805 L
.4826 .46981 L
Mistroke
.48356 .47148 L
.48446 .47305 L
.48532 .47454 L
.48613 .47594 L
.48689 .47727 L
.48761 .47852 L
.4883 .47971 L
.48894 .48083 L
.48955 .48189 L
.49012 .48288 L
.49067 .48383 L
.49118 .48472 L
.49167 .48556 L
.49213 .48636 L
.49256 .48711 L
.49297 .48782 L
.49336 .48849 L
.49372 .48913 L
.49407 .48973 L
.4944 .49029 L
.49471 .49083 L
.495 .49133 L
.49527 .49181 L
.49553 .49226 L
.49578 .49269 L
.49601 .49309 L
.49623 .49347 L
.49644 .49383 L
.49664 .49417 L
.49682 .49449 L
.497 .4948 L
.49716 .49508 L
.49732 .49536 L
.49747 .49561 L
.49761 .49585 L
.49774 .49608 L
.49786 .4963 L
.49798 .4965 L
.49809 .4967 L
.4982 .49688 L
.4983 .49705 L
.49839 .49721 L
.49848 .49737 L
.49856 .49751 L
.49864 .49765 L
.49872 .49778 L
.49879 .4979 L
.49885 .49802 L
.49892 .49813 L
.49898 .49823 L
Mistroke
.49903 .49833 L
.49909 .49842 L
.49914 .49851 L
.49918 .49859 L
.49923 .49867 L
.49927 .49874 L
.49931 .49881 L
.49935 .49887 L
.49939 .49894 L
.49942 .499 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
.49956 .49924 L
.49959 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
Mistroke
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
Mfstroke
1 0 0 r
% Start of user PostScript
-0.77584619 -9.2936554 -0.91296979 -8.4697997 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-1.0185185 -7.7329536 -1.0974391 -7.0727677 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.1942947 -3.9653263 -1.1713832 -3.6724134 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.93266938 -2.2181705 -0.89489822 -2.072279 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-0.64782074 -1.3135944 -0.61644608 -1.2336805 MAarrowhead1
% End of user PostScript
.581 1 0 r
.28543 .09791 m
.29657 .12127 L
s
% Start of user PostScript
-0.4291474 -0.80417052 -0.40686949 -0.75745809 MAarrowhead1
% End of user PostScript
.266 1 0 r
.36088 .24937 m
.36833 .26356 L
s
% Start of user PostScript
-0.27823568 -0.50125988 -0.26333663 -0.47287173 MAarrowhead1
% End of user PostScript
0 1 .049 r
.41073 .3423 m
.41558 .35111 L
s
% Start of user PostScript
-0.17854828 -0.31540097 -0.16884555 -0.29777476 MAarrowhead1
% End of user PostScript
0 1 .364 r
.443 .40029 m
.44612 .40583 L
s
% Start of user PostScript
-0.1140029 -0.19941195 -0.10776311 -0.18834356 MAarrowhead1
% End of user PostScript
0 1 .679 r
.46369 .43681 m
.46569 .4403 L
s
% Start of user PostScript
-0.072610029 -0.12638492 -0.068621714 -0.11939409 MAarrowhead1
% End of user PostScript
0 1 .995 r
.47691 .4599 m
.47818 .46211 L
s
% Start of user PostScript
-0.046189192 -0.080199257 -0.043647646 -0.075770839 MAarrowhead1
% End of user PostScript
0 .69 1 r
.48532 .47454 m
.48613 .47594 L
s
% Start of user PostScript
-0.029364073 -0.050922742 -0.027746905 -0.048113357 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49067 .48383 m
.49118 .48472 L
s
% Start of user PostScript
-0.018662012 -0.03234347 -0.017633788 -0.030559875 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49407 .48973 m
.4944 .49029 L
s
% Start of user PostScript
-0.01185861 -0.020546043 -0.011205091 -0.019413271 MAarrowhead1
% End of user PostScript
.699 1 0 r
.74695 1 m
.74377 .99174 L
.73191 .96191 L
.72049 .93409 L
.70951 .90811 L
.69899 .88384 L
.68891 .86115 L
.67926 .83991 L
.67005 .82002 L
.66125 .80138 L
.65286 .78391 L
.64487 .76751 L
.63726 .75211 L
.63002 .73765 L
.62313 .72406 L
.61659 .71129 L
.61038 .69928 L
.60447 .68798 L
.59887 .67734 L
.59356 .66733 L
.58852 .6579 L
.58375 .64901 L
.57922 .64064 L
.57493 .63276 L
.57087 .62532 L
.56702 .61831 L
.56338 .61171 L
.55993 .60547 L
.55666 .59959 L
.55357 .59405 L
.55065 .58881 L
.54788 .58387 L
.54526 .57921 L
.54279 .57482 L
.54044 .57066 L
.53823 .56674 L
.53613 .56305 L
.53415 .55955 L
.53228 .55625 L
.53051 .55314 L
.52883 .5502 L
.52725 .54742 L
.52575 .5448 L
.52434 .54232 L
.523 .53998 L
.52173 .53777 L
.52054 .53569 L
.51941 .53371 L
.51834 .53185 L
.51733 .53009 L
Mistroke
.51638 .52843 L
.51548 .52686 L
.51463 .52538 L
.51382 .52398 L
.51306 .52265 L
.51234 .5214 L
.51166 .52022 L
.51102 .51911 L
.51041 .51805 L
.50984 .51706 L
.5093 .51612 L
.50878 .51523 L
.5083 .51439 L
.50784 .51359 L
.50741 .51284 L
.507 .51214 L
.50662 .51147 L
.50625 .51083 L
.50591 .51024 L
.50558 .50967 L
.50527 .50914 L
.50498 .50864 L
.50471 .50816 L
.50445 .50771 L
.5042 .50728 L
.50397 .50688 L
.50375 .5065 L
.50355 .50615 L
.50335 .50581 L
.50317 .50549 L
.50299 .50518 L
.50283 .5049 L
.50267 .50463 L
.50252 .50437 L
.50239 .50413 L
.50225 .5039 L
.50213 .50369 L
.50201 .50349 L
.5019 .50329 L
.5018 .50311 L
.5017 .50294 L
.5016 .50278 L
.50152 .50263 L
.50143 .50248 L
.50135 .50234 L
.50128 .50221 L
.50121 .50209 L
.50114 .50198 L
.50108 .50187 L
.50102 .50177 L
Mistroke
.50096 .50167 L
.50091 .50158 L
.50086 .50149 L
.50081 .50141 L
.50077 .50133 L
.50073 .50126 L
.50069 .50119 L
.50065 .50112 L
.50061 .50106 L
.50058 .501 L
.50055 .50095 L
.50052 .50089 L
.50049 .50084 L
.50046 .5008 L
.50044 .50075 L
.50041 .50071 L
.50039 .50067 L
.50037 .50064 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .5003 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .5002 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
Mistroke
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
Mfstroke
1 0 0 r
% Start of user PostScript
0.36266067 8.3137228 0.51657959 7.5542399 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
0.6387962 6.8768355 0.73415774 6.2716166 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
0.93485082 3.4529033 0.92481346 3.1907071 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
0.76205312 1.9026178 0.73323316 1.7749052 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
0.537584 1.1162916 0.51214167 1.0475028 MAarrowhead1
% End of user PostScript
.581 1 0 r
.67926 .83991 m
.67005 .82002 L
s
% Start of user PostScript
0.35852553 0.67982652 0.34009461 0.6400474 MAarrowhead1
% End of user PostScript
.266 1 0 r
.61659 .71129 m
.61038 .69928 L
s
% Start of user PostScript
0.23318107 0.42258003 0.22075093 0.39855401 MAarrowhead1
% End of user PostScript
0 1 .049 r
.57493 .63276 m
.57087 .62532 L
s
% Start of user PostScript
0.14986419 0.26551435 0.14173794 0.25064597 MAarrowhead1
% End of user PostScript
0 1 .364 r
.54788 .58387 m
.54526 .57921 L
s
% Start of user PostScript
0.095759929 0.16774927 0.090524243 0.1584287 MAarrowhead1
% End of user PostScript
0 1 .679 r
.53051 .55314 m
.52883 .5502 L
s
% Start of user PostScript
0.061013526 0.10627855 0.057663958 0.10039682 MAarrowhead1
% End of user PostScript
0 1 .995 r
.51941 .53371 m
.51834 .53185 L
s
% Start of user PostScript
0.03881954 0.067428089 0.036684071 0.063703891 MAarrowhead1
% End of user PostScript
0 .69 1 r
.51234 .5214 m
.51166 .52022 L
s
% Start of user PostScript
0.024681213 0.042809707 0.023322124 0.040447605 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50784 .51359 m
.50741 .51284 L
s
% Start of user PostScript
0.015686598 0.027189238 0.014822367 0.025689777 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50498 .50864 m
.50471 .50816 L
s
% Start of user PostScript
0.0099681394 0.017271442 0.0094188209 0.016319178 MAarrowhead1
% End of user PostScript
1 .225 0 r
.72172 1 m
.71375 .97307 L
.70429 .94297 L
.69505 .91506 L
.68605 .88915 L
.67731 .86508 L
.66884 .84268 L
.66067 .82182 L
.6528 .80238 L
.64523 .78423 L
.63797 .76729 L
.631 .75144 L
.62434 .73662 L
.61796 .72274 L
.61188 .70974 L
.60607 .69756 L
.60054 .68613 L
.59527 .6754 L
.59025 .66532 L
.58548 .65586 L
.58095 .64696 L
.57664 .63859 L
.57255 .63072 L
.56866 .62332 L
.56498 .61635 L
.56148 .60979 L
.55817 .60361 L
.55502 .59778 L
.55205 .5923 L
.54923 .58713 L
.54656 .58225 L
.54403 .57765 L
.54163 .57332 L
.53936 .56923 L
.53722 .56537 L
.53519 .56173 L
.53327 .5583 L
.53145 .55506 L
.52973 .552 L
.5281 .54911 L
.52656 .54639 L
.52511 .54382 L
.52373 .54139 L
.52243 .5391 L
.5212 .53693 L
.52003 .53489 L
.51893 .53296 L
.51789 .53113 L
.51691 .52941 L
.51598 .52779 L
Mistroke
.5151 .52625 L
.51427 .5248 L
.51349 .52343 L
.51275 .52214 L
.51204 .52091 L
.51138 .51976 L
.51076 .51867 L
.51016 .51764 L
.5096 .51666 L
.50908 .51574 L
.50858 .51488 L
.5081 .51405 L
.50766 .51328 L
.50724 .51255 L
.50684 .51185 L
.50646 .5112 L
.5061 .51058 L
.50577 .51 L
.50545 .50945 L
.50515 .50893 L
.50487 .50843 L
.5046 .50797 L
.50434 .50753 L
.50411 .50711 L
.50388 .50672 L
.50367 .50635 L
.50346 .506 L
.50327 .50567 L
.50309 .50536 L
.50292 .50506 L
.50276 .50478 L
.50261 .50452 L
.50246 .50427 L
.50233 .50403 L
.5022 .50381 L
.50208 .5036 L
.50196 .5034 L
.50186 .50322 L
.50175 .50304 L
.50166 .50287 L
.50157 .50271 L
.50148 .50256 L
.5014 .50242 L
.50132 .50229 L
.50125 .50216 L
.50118 .50204 L
.50111 .50193 L
.50105 .50182 L
.501 .50172 L
.50094 .50163 L
Mistroke
.50089 .50154 L
.50084 .50145 L
.50079 .50137 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50063 .5011 L
.5006 .50103 L
.50056 .50098 L
.50053 .50092 L
.5005 .50087 L
.50048 .50082 L
.50045 .50078 L
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50055 L
.5003 .50052 L
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .50039 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
Mistroke
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
Mfstroke
1 0 0 r
% Start of user PostScript
0.59789117 3.386421 0.61812951 3.1076208 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
0.6301504 2.8564892 0.63535495 2.629859 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
0.56216966 1.5345918 0.54387385 1.4280204 MAarrowhead1
% End of user PostScript
1 .788 0 r
.70429 .94297 m
.69505 .91506 L
s
% Start of user PostScript
0.40858928 0.88593302 0.39010042 0.83011366 MAarrowhead1
% End of user PostScript
.897 1 0 r
.63797 .76729 m
.631 .75144 L
s
% Start of user PostScript
0.27593401 0.53457063 0.26200579 0.50288456 MAarrowhead1
% End of user PostScript
.581 1 0 r
.59025 .66532 m
.58548 .65586 L
s
% Start of user PostScript
0.18050513 0.33064251 0.17096272 0.31171165 MAarrowhead1
% End of user PostScript
.266 1 0 r
.55817 .60361 m
.55502 .59778 L
s
% Start of user PostScript
0.11633271 0.20721363 0.11004972 0.19556758 MAarrowhead1
% End of user PostScript
0 1 .049 r
.53722 .56537 m
.53519 .56173 L
s
% Start of user PostScript
0.074435529 0.13074363 0.070373672 0.12346563 MAarrowhead1
% End of user PostScript
0 1 .364 r
.52373 .54139 m
.52243 .5391 L
s
% Start of user PostScript
0.047458731 0.082778492 0.044855812 0.078192997 MAarrowhead1
% End of user PostScript
0 1 .679 r
.5151 .52625 m
.51427 .5248 L
s
% Start of user PostScript
0.030205533 0.052501051 0.028544717 0.049599931 MAarrowhead1
% End of user PostScript
0 1 .995 r
.5096 .51666 m
.50908 .51574 L
s
% Start of user PostScript
0.019207707 0.033327047 0.018150273 0.031487731 MAarrowhead1
% End of user PostScript
0 .69 1 r
.5061 .51058 m
.50577 .51 L
s
% Start of user PostScript
0.012208834 0.021164855 0.011536287 0.019997494 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50388 .50672 m
.50367 .50635 L
s
% Start of user PostScript
0.0077584997 0.013444005 0.0073309743 0.012702723 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50246 .50427 m
.50233 .50403 L
s
% Start of user PostScript
0.0049298505 0.0085406231 0.0046581531 0.0080697794 MAarrowhead1
% End of user PostScript
0 1 .273 r
.62107 1 m
.62121 .99208 L
.62091 .9539 L
.61978 .9193 L
.61797 .88788 L
.61562 .85931 L
.61285 .83327 L
.60974 .8095 L
.6064 .78776 L
.60287 .76784 L
.59923 .74956 L
.59552 .73276 L
.59178 .71729 L
.58804 .70303 L
.58433 .68986 L
.58067 .67768 L
.57708 .6664 L
.57358 .65593 L
.57017 .64622 L
.56686 .6372 L
.56366 .62879 L
.56057 .62097 L
.55759 .61367 L
.55473 .60686 L
.55199 .6005 L
.54936 .59455 L
.54684 .58898 L
.54444 .58377 L
.54214 .57889 L
.53995 .57431 L
.53787 .57001 L
.53588 .56598 L
.53399 .56219 L
.53219 .55863 L
.53048 .55529 L
.52886 .55214 L
.52732 .54918 L
.52585 .5464 L
.52446 .54378 L
.52315 .54131 L
.5219 .53899 L
.52072 .5368 L
.51959 .53473 L
.51853 .53279 L
.51753 .53095 L
.51657 .52922 L
.51567 .52759 L
.51482 .52605 L
.51401 .5246 L
.51325 .52323 L
Mistroke
.51252 .52194 L
.51184 .52072 L
.51119 .51957 L
.51058 .51848 L
.51 .51746 L
.50945 .51649 L
.50893 .51558 L
.50844 .51471 L
.50798 .5139 L
.50754 .51313 L
.50713 .5124 L
.50674 .51172 L
.50637 .51107 L
.50602 .51046 L
.50568 .50988 L
.50537 .50933 L
.50508 .50882 L
.5048 .50833 L
.50453 .50787 L
.50428 .50744 L
.50405 .50703 L
.50383 .50664 L
.50361 .50627 L
.50342 .50593 L
.50323 .5056 L
.50305 .50529 L
.50288 .505 L
.50272 .50472 L
.50257 .50446 L
.50243 .50422 L
.5023 .50398 L
.50217 .50376 L
.50205 .50356 L
.50194 .50336 L
.50183 .50317 L
.50173 .503 L
.50164 .50283 L
.50155 .50268 L
.50146 .50253 L
.50138 .50239 L
.5013 .50226 L
.50123 .50213 L
.50116 .50202 L
.5011 .50191 L
.50104 .5018 L
.50098 .5017 L
.50093 .50161 L
.50088 .50152 L
.50083 .50143 L
.50078 .50136 L
Mistroke
.50074 .50128 L
.5007 .50121 L
.50066 .50114 L
.50062 .50108 L
.50059 .50102 L
.50056 .50096 L
.50053 .50091 L
.5005 .50086 L
.50047 .50081 L
.50044 .50077 L
.50042 .50073 L
.5004 .50069 L
.50037 .50065 L
.50035 .50061 L
.50033 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50022 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
Mistroke
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
Mfstroke
1 0 0 r
% Start of user PostScript
-0.44903476 4.0642905 -0.31471763 3.6504881 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-0.20243204 3.284831 -0.10901066 2.961283 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
0.20466246 1.5097438 0.21952238 1.3812469 MAarrowhead1
% End of user PostScript
1 .788 0 r
.61797 .88788 m
.61562 .85931 L
s
% Start of user PostScript
0.23593796 0.77576921 0.23123977 0.7186196 MAarrowhead1
% End of user PostScript
.897 1 0 r
.59178 .71729 m
.58804 .70303 L
s
% Start of user PostScript
0.18355625 0.43458817 0.17607816 0.40606089 MAarrowhead1
% End of user PostScript
.581 1 0 r
.56366 .62879 m
.56057 .62097 L
s
% Start of user PostScript
0.12731586 0.25758903 0.12113689 0.24193745 MAarrowhead1
% End of user PostScript
.266 1 0 r
.54214 .57889 m
.53995 .57431 L
s
% Start of user PostScript
0.084287763 0.1577711 0.079908279 0.14861285 MAarrowhead1
% End of user PostScript
0 1 .049 r
.52732 .54918 m
.52585 .5464 L
s
% Start of user PostScript
0.05463162 0.098368269 0.051704962 0.092799362 MAarrowhead1
% End of user PostScript
0 1 .364 r
.51753 .53095 m
.51657 .52922 L
s
% Start of user PostScript
0.035053016 0.061903206 0.033147766 0.058444397 MAarrowhead1
% End of user PostScript
0 1 .679 r
.51119 .51957 m
.51058 .51848 L
s
% Start of user PostScript
0.022379753 0.039140896 0.021154706 0.036968583 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50713 .5124 m
.50674 .51172 L
s
% Start of user PostScript
0.014253481 0.024807881 0.013470529 0.02343573 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50453 .50787 m
.50428 .50744 L
s
% Start of user PostScript
0.0090668658 0.015742446 0.0085679521 0.014873205 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50288 .505 m
.50272 .50472 L
s
% Start of user PostScript
0.0057640717 0.0099957957 0.005446623 0.0094443389 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50183 .50317 m
.50173 .503 L
s
% Start of user PostScript
0.0036632762 0.0063488354 0.0034614389 0.0059987282 MAarrowhead1
% End of user PostScript
0 .949 1 r
0 .02847 m
.01265 .03152 L
.04802 .04262 L
.0803 .05508 L
.10981 .06855 L
.13685 .08275 L
.16166 .09745 L
.18446 .11245 L
.20545 .12758 L
.2248 .14271 L
.24267 .15773 L
.2592 .17254 L
.2745 .18708 L
.28869 .20128 L
.30186 .21511 L
.3141 .22853 L
.32549 .24151 L
.3361 .25405 L
.34599 .26612 L
.35522 .27772 L
.36385 .28886 L
.37191 .29953 L
.37946 .30974 L
.38652 .3195 L
.39314 .32882 L
.39934 .33771 L
.40516 .34618 L
.41063 .35425 L
.41576 .36193 L
.42058 .36924 L
.42511 .37618 L
.42937 .38277 L
.43338 .38903 L
.43715 .39498 L
.4407 .40062 L
.44405 .40596 L
.4472 .41103 L
.45016 .41584 L
.45296 .4204 L
.4556 .42471 L
.45808 .4288 L
.46042 .43267 L
.46263 .43633 L
.46471 .4398 L
.46668 .44308 L
.46854 .44619 L
.47028 .44913 L
.47194 .45191 L
.47349 .45454 L
.47497 .45703 L
Mistroke
.47635 .45938 L
.47767 .46161 L
.4789 .46371 L
.48007 .4657 L
.48118 .46758 L
.48222 .46936 L
.4832 .47105 L
.48413 .47264 L
.48501 .47414 L
.48584 .47556 L
.48662 .4769 L
.48736 .47817 L
.48806 .47937 L
.48872 .48051 L
.48934 .48158 L
.48993 .48259 L
.49048 .48355 L
.49101 .48446 L
.49151 .48531 L
.49197 .48612 L
.49242 .48689 L
.49284 .48761 L
.49323 .48829 L
.4936 .48894 L
.49396 .48954 L
.49429 .49012 L
.49461 .49066 L
.4949 .49118 L
.49518 .49167 L
.49545 .49212 L
.4957 .49256 L
.49594 .49297 L
.49616 .49336 L
.49637 .49372 L
.49657 .49407 L
.49676 .49439 L
.49694 .4947 L
.49711 .495 L
.49727 .49527 L
.49742 .49553 L
.49756 .49578 L
.4977 .49601 L
.49782 .49623 L
.49794 .49644 L
.49806 .49663 L
.49816 .49682 L
.49827 .497 L
.49836 .49716 L
.49845 .49732 L
.49854 .49747 L
Mistroke
.49862 .49761 L
.49869 .49774 L
.49877 .49786 L
.49883 .49798 L
.4989 .49809 L
.49896 .4982 L
.49902 .4983 L
.49907 .49839 L
.49912 .49848 L
.49917 .49856 L
.49922 .49864 L
.49926 .49872 L
.4993 .49879 L
.49934 .49885 L
.49937 .49892 L
.49941 .49898 L
.49944 .49903 L
.49947 .49909 L
.4995 .49914 L
.49953 .49918 L
.49956 .49923 L
.49958 .49927 L
.4996 .49931 L
.49962 .49935 L
.49965 .49939 L
.49966 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
Mistroke
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
1 0 0 r
% Start of user PostScript
-2.7070784 -0.49497067 -2.4629628 -0.63205528 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-2.2449727 -0.73963932 -2.0499765 -0.82227862 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.1376684 -0.96989842 -1.052317 -0.95565276 MAarrowhead1
% End of user PostScript
1 .788 0 r
.18446 .11245 m
.20545 .12758 L
s
% Start of user PostScript
-0.63108095 -0.77509777 -0.5891 -0.74483538 MAarrowhead1
% End of user PostScript
.897 1 0 r
.3141 .22853 m
.32549 .24151 L
s
% Start of user PostScript
-0.3718038 -0.54294111 -0.34902311 -0.51697361 MAarrowhead1
% End of user PostScript
.581 1 0 r
.38652 .3195 m
.39314 .32882 L
s
% Start of user PostScript
-0.22696013 -0.36099782 -0.21372324 -0.34235758 MAarrowhead1
% End of user PostScript
.266 1 0 r
.42937 .38277 m
.43338 .38903 L
s
% Start of user PostScript
-0.14125407 -0.23445587 -0.13323708 -0.22193226 MAarrowhead1
% End of user PostScript
0 1 .049 r
.4556 .42471 m
.45808 .4288 L
s
% Start of user PostScript
-0.08880944 -0.15058009 -0.083840779 -0.142407 MAarrowhead1
% End of user PostScript
0 1 .364 r
.47194 .45191 m
.47349 .45454 L
s
% Start of user PostScript
-0.056127239 -0.096184884 -0.053010118 -0.090923429 MAarrowhead1
% End of user PostScript
0 1 .679 r
.48222 .46936 m
.4832 .47105 L
s
% Start of user PostScript
-0.035565608 -0.061274021 -0.033597776 -0.057909349 MAarrowhead1
% End of user PostScript
0 1 .995 r
.48872 .48051 m
.48934 .48158 L
s
% Start of user PostScript
-0.022566354 -0.038982026 -0.021320113 -0.036837364 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49284 .48761 m
.49323 .48829 L
s
% Start of user PostScript
-0.014327843 -0.024783489 -0.013537325 -0.023418686 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49545 .49212 m
.4957 .49256 L
s
% Start of user PostScript
-0.0091000676 -0.015751273 -0.0085982222 -0.014883454 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49711 .495 m
.49727 .49527 L
s
% Start of user PostScript
-0.0057807036 -0.010009133 -0.0054619881 -0.0094575478 MAarrowhead1
% End of user PostScript
0 .386 1 r
.78945 1 m
.78211 .98738 L
.76653 .96056 L
.75182 .93522 L
.73791 .91126 L
.72478 .88863 L
.71238 .86723 L
.70065 .84701 L
.68958 .82791 L
.67912 .80985 L
.66924 .79279 L
.6599 .77666 L
.65108 .76142 L
.64275 .74702 L
.63487 .73342 L
.62744 .72056 L
.62041 .70841 L
.61377 .69692 L
.60749 .68607 L
.60157 .67582 L
.59597 .66613 L
.59067 .65698 L
.58567 .64833 L
.58095 .64016 L
.57649 .63243 L
.57227 .62513 L
.56829 .61824 L
.56452 .61172 L
.56096 .60557 L
.5576 .59975 L
.55443 .59425 L
.55143 .58906 L
.54859 .58415 L
.54591 .57951 L
.54338 .57513 L
.54099 .57099 L
.53873 .56707 L
.5366 .56338 L
.53458 .55988 L
.53267 .55658 L
.53087 .55346 L
.52917 .55052 L
.52756 .54773 L
.52604 .5451 L
.52461 .54262 L
.52325 .54027 L
.52197 .53805 L
.52076 .53595 L
.51961 .53397 L
.51853 .5321 L
Mistroke
.51751 .53033 L
.51655 .52866 L
.51563 .52708 L
.51477 .52558 L
.51396 .52417 L
.51319 .52284 L
.51246 .52158 L
.51177 .52039 L
.51113 .51927 L
.51051 .51821 L
.50993 .5172 L
.50938 .51625 L
.50887 .51536 L
.50838 .51451 L
.50792 .51371 L
.50748 .51296 L
.50707 .51224 L
.50668 .51157 L
.50631 .51093 L
.50596 .51033 L
.50563 .50976 L
.50532 .50922 L
.50503 .50871 L
.50475 .50823 L
.50449 .50778 L
.50424 .50735 L
.50401 .50694 L
.50379 .50656 L
.50358 .5062 L
.50338 .50586 L
.5032 .50554 L
.50302 .50523 L
.50285 .50494 L
.5027 .50467 L
.50255 .50441 L
.50241 .50417 L
.50227 .50394 L
.50215 .50372 L
.50203 .50352 L
.50192 .50332 L
.50181 .50314 L
.50171 .50297 L
.50162 .5028 L
.50153 .50265 L
.50144 .5025 L
.50137 .50236 L
.50129 .50223 L
.50122 .50211 L
.50115 .50199 L
.50109 .50188 L
Mistroke
.50103 .50178 L
.50097 .50168 L
.50092 .50159 L
.50087 .5015 L
.50082 .50142 L
.50077 .50134 L
.50073 .50127 L
.50069 .5012 L
.50065 .50113 L
.50062 .50107 L
.50058 .50101 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .50081 L
.50044 .50076 L
.50042 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .50061 L
.50033 .50057 L
.50031 .50054 L
.5003 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50039 L
.50021 .50036 L
.5002 .50034 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50018 L
.5001 .50017 L
.5001 .50016 L
.50009 .50016 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
Mfstroke
1 0 0 r
% Start of user PostScript
1.3252304 2.2738451 1.251695 2.1493513 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
1.1822779 2.0316071 1.1167436 1.9202555 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
0.74967103 1.2933336 0.70823199 1.2222446 MAarrowhead1
% End of user PostScript
1 .788 0 r
.73791 .91126 m
.72478 .88863 L
s
% Start of user PostScript
0.47582773 0.8225261 0.44956256 0.77725134 MAarrowhead1
% End of user PostScript
.897 1 0 r
.65108 .76142 m
.64275 .74702 L
s
% Start of user PostScript
0.30216436 0.52284551 0.28549693 0.49404591 MAarrowhead1
% End of user PostScript
.581 1 0 r
.59597 .66613 m
.59067 .65698 L
s
% Start of user PostScript
0.19193056 0.33226871 0.18134737 0.31396008 MAarrowhead1
% End of user PostScript
.266 1 0 r
.56096 .60557 m
.5576 .59975 L
s
% Start of user PostScript
0.12192669 0.21113085 0.11520474 0.1994951 MAarrowhead1
% End of user PostScript
0 1 .049 r
.53873 .56707 m
.5366 .56338 L
s
% Start of user PostScript
0.077460499 0.13414888 0.073190399 0.12675507 MAarrowhead1
% End of user PostScript
0 1 .364 r
.52461 .54262 m
.52325 .54027 L
s
% Start of user PostScript
0.049212482 0.085233232 0.046499706 0.080535271 MAarrowhead1
% End of user PostScript
0 1 .679 r
.51563 .52708 m
.51477 .52558 L
s
% Start of user PostScript
0.031266335 0.0541532 0.029542855 0.05116827 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50993 .5172 m
.50938 .51625 L
s
% Start of user PostScript
0.019864701 0.034406138 0.018769721 0.032509648 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50631 .51093 m
.50596 .51033 L
s
% Start of user PostScript
0.012620855 0.021859793 0.011925173 0.020654859 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50401 .50694 m
.50379 .50656 L
s
% Start of user PostScript
0.00801856 0.013888499 0.0075765653 0.013122949 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50255 .50441 m
.50241 .50417 L
s
% Start of user PostScript
0.0050945332 0.0088239733 0.0048137155 0.008337585 MAarrowhead1
% End of user PostScript
.389 1 0 r
.89884 1 m
.89103 .99437 L
.86534 .97429 L
.84162 .95436 L
.81968 .9347 L
.79936 .9154 L
.78053 .89654 L
.76304 .87819 L
.74679 .86038 L
.73167 .84314 L
.71759 .8265 L
.70445 .81048 L
.6922 .79508 L
.68075 .78029 L
.67004 .76613 L
.66003 .75257 L
.65065 .73961 L
.64186 .72724 L
.63362 .71544 L
.6259 .70419 L
.61864 .69348 L
.61183 .68329 L
.60543 .67359 L
.59942 .66438 L
.59376 .65562 L
.58844 .64731 L
.58343 .63942 L
.57872 .63193 L
.57428 .62483 L
.5701 .6181 L
.56616 .61172 L
.56245 .60568 L
.55895 .59995 L
.55565 .59452 L
.55254 .58939 L
.54961 .58452 L
.54684 .57992 L
.54423 .57556 L
.54177 .57144 L
.53945 .56754 L
.53726 .56384 L
.53519 .56035 L
.53323 .55705 L
.53139 .55392 L
.52965 .55097 L
.52801 .54817 L
.52646 .54553 L
.52499 .54303 L
.52361 .54067 L
.5223 .53844 L
Mistroke
.52107 .53633 L
.5199 .53433 L
.5188 .53244 L
.51776 .53066 L
.51678 .52897 L
.51585 .52738 L
.51498 .52587 L
.51415 .52445 L
.51337 .52311 L
.51263 .52183 L
.51193 .52063 L
.51128 .5195 L
.51065 .51842 L
.51007 .51741 L
.50951 .51645 L
.50899 .51554 L
.50849 .51469 L
.50802 .51388 L
.50758 .51311 L
.50716 .51239 L
.50677 .51171 L
.50639 .51106 L
.50604 .51046 L
.50571 .50988 L
.50539 .50933 L
.5051 .50882 L
.50481 .50833 L
.50455 .50788 L
.5043 .50744 L
.50406 .50703 L
.50384 .50664 L
.50363 .50628 L
.50343 .50593 L
.50324 .5056 L
.50306 .5053 L
.50289 .505 L
.50273 .50473 L
.50258 .50447 L
.50244 .50422 L
.5023 .50399 L
.50218 .50377 L
.50206 .50356 L
.50194 .50336 L
.50184 .50318 L
.50173 .503 L
.50164 .50284 L
.50155 .50268 L
.50146 .50253 L
.50138 .50239 L
.50131 .50226 L
Mistroke
.50123 .50214 L
.50117 .50202 L
.5011 .50191 L
.50104 .5018 L
.50098 .5017 L
.50093 .50161 L
.50088 .50152 L
.50083 .50144 L
.50078 .50136 L
.50074 .50128 L
.5007 .50121 L
.50066 .50115 L
.50063 .50108 L
.50059 .50102 L
.50056 .50097 L
.50053 .50091 L
.5005 .50086 L
.50047 .50082 L
.50044 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50035 .50061 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
Mistroke
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
Mfstroke
1 0 0 r
% Start of user PostScript
3.5940599 0.65647078 3.2699437 0.8385355 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
2.9805161 0.98142663 2.7216189 1.0911936 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.5103641 1.2874149 1.397047 1.268523 MAarrowhead1
% End of user PostScript
1 .788 0 r
.89884 1 m
.89103 .99437 L
s
% Start of user PostScript
0.83780057 1.0289127 0.78206635 0.98874489 MAarrowhead1
% End of user PostScript
.897 1 0 r
.74679 .86038 m
.73167 .84314 L
s
% Start of user PostScript
0.49358618 0.72075137 0.46334318 0.68628092 MAarrowhead1
% End of user PostScript
.581 1 0 r
.65065 .73961 m
.64186 .72724 L
s
% Start of user PostScript
0.30129723 0.47922777 0.2837246 0.45448307 MAarrowhead1
% End of user PostScript
.266 1 0 r
.59376 .65562 m
.58844 .64731 L
s
% Start of user PostScript
0.18751871 0.31124379 0.17687587 0.29461861 MAarrowhead1
% End of user PostScript
0 1 .049 r
.55895 .59995 m
.55565 .59452 L
s
% Start of user PostScript
0.11789674 0.19989787 0.1113007 0.18904798 MAarrowhead1
% End of user PostScript
0 1 .364 r
.53726 .56384 m
.53519 .56035 L
s
% Start of user PostScript
0.07451022 0.12768738 0.070372161 0.1207027 MAarrowhead1
% End of user PostScript
0 1 .679 r
.52361 .54067 m
.5223 .53844 L
s
% Start of user PostScript
0.047214147 0.08134255 0.044601804 0.076875881 MAarrowhead1
% End of user PostScript
0 1 .995 r
.51498 .52587 m
.51415 .52445 L
s
% Start of user PostScript
0.029957335 0.051749473 0.028302922 0.048902389 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50951 .51645 m
.50899 .51554 L
s
% Start of user PostScript
0.019020526 0.032900616 0.017971097 0.031088812 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50604 .51046 m
.50571 .50988 L
s
% Start of user PostScript
0.012080539 0.020910156 0.011414328 0.019758108 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50384 .50664 m
.50363 .50628 L
s
% Start of user PostScript
0.0076740102 0.013287342 0.0072509084 0.0125551 MAarrowhead1
% End of user PostScript
1 .93 0 r
.17823 0 m
.19374 .02054 L
.21177 .04497 L
.22866 .06832 L
.24448 .09061 L
.25932 .11188 L
.27324 .13215 L
.2863 .15145 L
.29857 .16981 L
.31009 .18728 L
.32093 .20388 L
.33112 .21965 L
.3407 .23463 L
.34972 .24885 L
.35821 .26233 L
.36621 .27512 L
.37374 .28725 L
.38083 .29874 L
.38752 .30963 L
.39382 .31995 L
.39976 .32973 L
.40536 .33898 L
.41064 .34774 L
.41562 .35604 L
.42032 .36389 L
.42476 .37131 L
.42894 .37834 L
.43289 .38499 L
.43662 .39129 L
.44014 .39724 L
.44346 .40286 L
.44659 .40819 L
.44955 .41322 L
.45235 .41798 L
.45498 .42248 L
.45748 .42674 L
.45983 .43076 L
.46205 .43456 L
.46415 .43816 L
.46613 .44156 L
.468 .44477 L
.46977 .44781 L
.47144 .45068 L
.47302 .45339 L
.47451 .45595 L
.47592 .45838 L
.47725 .46067 L
.4785 .46283 L
.47969 .46488 L
.48081 .46681 L
Mistroke
.48187 .46864 L
.48287 .47037 L
.48381 .472 L
.48471 .47354 L
.48555 .475 L
.48635 .47638 L
.4871 .47768 L
.48781 .47891 L
.48848 .48007 L
.48912 .48117 L
.48972 .4822 L
.49029 .48318 L
.49082 .48411 L
.49133 .48499 L
.49181 .48581 L
.49226 .4866 L
.49268 .48733 L
.49309 .48803 L
.49347 .48869 L
.49383 .48932 L
.49417 .4899 L
.49449 .49046 L
.49479 .49099 L
.49508 .49148 L
.49535 .49195 L
.49561 .4924 L
.49585 .49281 L
.49608 .49321 L
.4963 .49359 L
.4965 .49394 L
.49669 .49427 L
.49688 .49459 L
.49705 .49489 L
.49721 .49517 L
.49736 .49543 L
.49751 .49569 L
.49765 .49592 L
.49778 .49615 L
.4979 .49636 L
.49801 .49656 L
.49812 .49675 L
.49823 .49693 L
.49833 .4971 L
.49842 .49726 L
.4985 .49741 L
.49859 .49755 L
.49867 .49769 L
.49874 .49782 L
.49881 .49794 L
.49887 .49805 L
Mistroke
.49894 .49816 L
.49899 .49826 L
.49905 .49835 L
.4991 .49845 L
.49915 .49853 L
.4992 .49861 L
.49924 .49869 L
.49928 .49876 L
.49932 .49883 L
.49936 .49889 L
.4994 .49895 L
.49943 .49901 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49921 L
.49957 .49926 L
.49959 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
Mistroke
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
Mfstroke
1 0 0 r
% Start of user PostScript
-4.4800432 -2.1210283 -4.1055063 -2.2251086 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-3.7686486 -2.2939476 -3.4651192 -2.3334269 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.00628 -2.1296627 -1.8652494 -2.0649997 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.1513461 -1.5666814 -1.0782087 -1.4970792 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-0.69230862 -1.063262 -0.65107361 -1.009978 MAarrowhead1
% End of user PostScript
.581 1 0 r
.2863 .15145 m
.29857 .16981 L
s
% Start of user PostScript
-0.42739956 -0.6971074 -0.40286388 -0.6603739 MAarrowhead1
% End of user PostScript
.266 1 0 r
.36621 .27512 m
.37374 .28725 L
s
% Start of user PostScript
-0.26758784 -0.44975726 -0.25252763 -0.42550371 MAarrowhead1
% End of user PostScript
0 1 .049 r
.41562 .35604 m
.42032 .36389 L
s
% Start of user PostScript
-0.16875251 -0.28792852 -0.159352 -0.27222838 MAarrowhead1
% End of user PostScript
0 1 .364 r
.44659 .40819 m
.44955 .41322 L
s
% Start of user PostScript
-0.10681613 -0.18362565 -0.10089694 -0.17355826 MAarrowhead1
% End of user PostScript
0 1 .679 r
.46613 .44156 m
.468 .44477 L
s
% Start of user PostScript
-0.067737911 -0.11688529 -0.063994148 -0.11045967 MAarrowhead1
% End of user PostScript
0 1 .995 r
.4785 .46283 m
.47969 .46488 L
s
% Start of user PostScript
-0.04299647 -0.07433218 -0.040623283 -0.070240376 MAarrowhead1
% End of user PostScript
0 .69 1 r
.48635 .47638 m
.4871 .47768 L
s
% Start of user PostScript
-0.027304694 -0.047248663 -0.025798617 -0.044645997 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49133 .48499 m
.49181 .48581 L
s
% Start of user PostScript
-0.017343778 -0.030026179 -0.016387447 -0.02837165 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49449 .49046 m
.49479 .49099 L
s
% Start of user PostScript
-0.011017958 -0.019079174 -0.010410532 -0.018027681 MAarrowhead1
% End of user PostScript
.517 0 1 r
1 .82758 m
.97762 .83002 L
.94004 .83132 L
.90604 .82994 L
.87521 .82639 L
.84721 .82108 L
.82173 .81436 L
.7985 .80656 L
.77728 .79791 L
.75787 .78863 L
.74008 .77892 L
.72375 .76891 L
.70873 .75873 L
.6949 .7485 L
.68214 .73829 L
.67035 .72818 L
.65945 .71823 L
.64935 .70847 L
.63998 .69895 L
.63128 .68969 L
.62319 .68071 L
.61566 .67203 L
.60865 .66365 L
.6021 .65559 L
.59599 .64785 L
.59029 .64042 L
.58495 .63331 L
.57995 .6265 L
.57527 .62 L
.57089 .61379 L
.56678 .60787 L
.56292 .60223 L
.5593 .59686 L
.5559 .59175 L
.5527 .58689 L
.5497 .58227 L
.54687 .57789 L
.54422 .57372 L
.54171 .56977 L
.53936 .56602 L
.53714 .56247 L
.53505 .5591 L
.53308 .5559 L
.53123 .55288 L
.52948 .55001 L
.52783 .54729 L
.52628 .54472 L
.52481 .54229 L
.52343 .53998 L
.52212 .5378 L
Mistroke
.52089 .53574 L
.51973 .53379 L
.51863 .53194 L
.5176 .53019 L
.51662 .52854 L
.5157 .52698 L
.51483 .5255 L
.51401 .5241 L
.51323 .52278 L
.5125 .52153 L
.51181 .52035 L
.51115 .51923 L
.51054 .51817 L
.50995 .51717 L
.5094 .51623 L
.50888 .51534 L
.50839 .51449 L
.50793 .5137 L
.50749 .51294 L
.50708 .51223 L
.50669 .51156 L
.50632 .51092 L
.50597 .51032 L
.50564 .50975 L
.50533 .50922 L
.50503 .50871 L
.50476 .50823 L
.50449 .50778 L
.50425 .50735 L
.50401 .50694 L
.50379 .50656 L
.50358 .5062 L
.50338 .50586 L
.5032 .50553 L
.50302 .50523 L
.50285 .50494 L
.5027 .50467 L
.50255 .50441 L
.50241 .50417 L
.50228 .50394 L
.50215 .50372 L
.50203 .50352 L
.50192 .50332 L
.50181 .50314 L
.50171 .50297 L
.50162 .5028 L
.50153 .50265 L
.50145 .5025 L
.50137 .50237 L
.50129 .50223 L
Mistroke
.50122 .50211 L
.50115 .502 L
.50109 .50189 L
.50103 .50178 L
.50097 .50168 L
.50092 .50159 L
.50087 .5015 L
.50082 .50142 L
.50077 .50134 L
.50073 .50127 L
.50069 .5012 L
.50065 .50113 L
.50062 .50107 L
.50058 .50101 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50047 .50081 L
.50044 .50076 L
.50042 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .50061 L
.50033 .50057 L
.50031 .50054 L
.5003 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50039 L
.50021 .50036 L
.5002 .50034 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50018 L
.5001 .50017 L
.5001 .50016 L
.50009 .50016 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
Mistroke
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
Mfstroke
1 0 0 r
% Start of user PostScript
5.6404865 -3.3471349 5.0327698 -2.6485538 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
4.4981768 -2.057113 4.0273867 -1.5577438 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.9550647 0.25676004 1.7764844 0.36526157 MAarrowhead1
% End of user PostScript
1 .788 0 r
.97762 .83002 m
.94004 .83132 L
s
% Start of user PostScript
0.95524263 0.66004677 0.88008527 0.66264071 MAarrowhead1
% End of user PostScript
.897 1 0 r
.75787 .78863 m
.74008 .77892 L
s
% Start of user PostScript
0.51573891 0.577264 0.48015976 0.55783026 MAarrowhead1
% End of user PostScript
.581 1 0 r
.64935 .70847 m
.63998 .69895 L
s
% Start of user PostScript
0.29870027 0.41694 0.27996313 0.39789363 MAarrowhead1
% End of user PostScript
.266 1 0 r
.59029 .64042 m
.58495 .63331 L
s
% Start of user PostScript
0.18057094 0.28084575 0.16989552 0.2666159 MAarrowhead1
% End of user PostScript
0 1 .049 r
.5559 .59175 m
.5527 .58689 L
s
% Start of user PostScript
0.11179901 0.18350062 0.10540703 0.17378327 MAarrowhead1
% End of user PostScript
0 1 .364 r
.53505 .5591 m
.53308 .5559 L
s
% Start of user PostScript
0.070101087 0.1181961 0.066164104 0.11180728 MAarrowhead1
% End of user PostScript
0 1 .679 r
.52212 .5378 m
.52089 .53574 L
s
% Start of user PostScript
0.044242831 0.075606786 0.041780936 0.071479376 MAarrowhead1
% End of user PostScript
0 1 .995 r
.51401 .5241 m
.51323 .52278 L
s
% Start of user PostScript
0.028015507 0.048198865 0.026463892 0.045554834 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50888 .51534 m
.50839 .51449 L
s
% Start of user PostScript
0.017769632 0.030674495 0.016787806 0.02898773 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50564 .50975 m
.50533 .50922 L
s
% Start of user PostScript
0.011280336 0.019505254 0.010657805 0.018431387 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50358 .5062 m
.50338 .50586 L
s
% Start of user PostScript
0.0071638731 0.01239775 0.0067687547 0.011714779 MAarrowhead1
% End of user PostScript
0 .643 1 r
.26807 0 m
.27409 .01829 L
.2845 .04839 L
.29461 .07635 L
.30439 .10237 L
.31384 .12659 L
.32295 .14917 L
.33171 .17024 L
.34012 .18992 L
.34818 .20831 L
.3559 .22551 L
.36328 .24162 L
.37033 .25671 L
.37705 .27085 L
.38346 .28412 L
.38957 .29657 L
.39538 .30826 L
.40091 .31924 L
.40617 .32956 L
.41116 .33927 L
.4159 .34839 L
.4204 .35698 L
.42467 .36507 L
.42872 .37268 L
.43257 .37985 L
.43621 .3866 L
.43966 .39297 L
.44293 .39897 L
.44602 .40462 L
.44896 .40995 L
.45173 .41498 L
.45436 .41972 L
.45685 .4242 L
.4592 .42842 L
.46143 .4324 L
.46354 .43616 L
.46553 .4397 L
.46742 .44305 L
.4692 .44621 L
.47089 .44919 L
.47249 .45201 L
.474 .45467 L
.47542 .45718 L
.47677 .45955 L
.47805 .46179 L
.47925 .4639 L
.48039 .4659 L
.48147 .46778 L
.48249 .46956 L
.48345 .47124 L
Mistroke
.48436 .47283 L
.48522 .47433 L
.48603 .47575 L
.4868 .47709 L
.48753 .47835 L
.48822 .47955 L
.48886 .48068 L
.48948 .48174 L
.49006 .48275 L
.4906 .4837 L
.49112 .4846 L
.49161 .48545 L
.49207 .48626 L
.49251 .48701 L
.49292 .48773 L
.49331 .48841 L
.49368 .48905 L
.49403 .48965 L
.49436 .49022 L
.49467 .49076 L
.49496 .49127 L
.49524 .49175 L
.4955 .49221 L
.49575 .49264 L
.49598 .49304 L
.49621 .49343 L
.49641 .49379 L
.49661 .49413 L
.4968 .49445 L
.49698 .49476 L
.49714 .49505 L
.4973 .49532 L
.49745 .49558 L
.49759 .49582 L
.49772 .49605 L
.49785 .49627 L
.49797 .49648 L
.49808 .49667 L
.49818 .49685 L
.49828 .49703 L
.49838 .49719 L
.49847 .49735 L
.49855 .49749 L
.49863 .49763 L
.49871 .49776 L
.49878 .49788 L
.49885 .498 L
.49891 .49811 L
.49897 .49822 L
.49903 .49831 L
Mistroke
.49908 .49841 L
.49913 .49849 L
.49918 .49858 L
.49922 .49866 L
.49927 .49873 L
.49931 .4988 L
.49935 .49887 L
.49938 .49893 L
.49942 .49899 L
.49945 .49904 L
.49948 .4991 L
.49951 .49915 L
.49953 .49919 L
.49956 .49924 L
.49958 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .49939 L
.49967 .49943 L
.49969 .49946 L
.4997 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49976 .49959 L
.49978 .49961 L
.49979 .49964 L
.4998 .49966 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49982 L
.4999 .49983 L
.4999 .49984 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
Mistroke
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
1 0 0 r
% Start of user PostScript
-0.33831323 -6.221895 -0.44719457 -5.6580482 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-0.53304814 -5.1547715 -0.59941634 -4.704789 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-0.72658722 -2.6031546 -0.71696395 -2.4069639 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.58490335 -1.440385 -0.56233171 -1.3442419 MAarrowhead1
% End of user PostScript
.897 1 0 r
.29461 .07635 m
.30439 .10237 L
s
% Start of user PostScript
-0.41078692 -0.84729015 -0.39121638 -0.79526455 MAarrowhead1
% End of user PostScript
.581 1 0 r
.36328 .24162 m
.37033 .25671 L
s
% Start of user PostScript
-0.27343877 -0.51675941 -0.25934286 -0.4865838 MAarrowhead1
% End of user PostScript
.266 1 0 r
.41116 .33927 m
.4159 .34839 L
s
% Start of user PostScript
-0.17768318 -0.32146816 -0.16819932 -0.30321101 MAarrowhead1
% End of user PostScript
0 1 .049 r
.44293 .39897 m
.44602 .40462 L
s
% Start of user PostScript
-0.11414683 -0.20206541 -0.10795351 -0.19075652 MAarrowhead1
% End of user PostScript
0 1 .364 r
.46354 .43616 m
.46553 .4397 L
s
% Start of user PostScript
-0.072921872 -0.12768903 -0.068933655 -0.12059638 MAarrowhead1
% End of user PostScript
0 1 .679 r
.47677 .45955 m
.47805 .46179 L
s
% Start of user PostScript
-0.046457356 -0.080906507 -0.043906523 -0.076429589 MAarrowhead1
% End of user PostScript
0 1 .995 r
.48522 .47433 m
.48603 .47575 L
s
% Start of user PostScript
-0.029556706 -0.051333539 -0.027930666 -0.048498487 MAarrowhead1
% End of user PostScript
0 .69 1 r
.4906 .4837 m
.49112 .4846 L
s
% Start of user PostScript
-0.018791472 -0.032592217 -0.017756667 -0.03079395 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49403 .48965 m
.49436 .49022 L
s
% Start of user PostScript
-0.011943109 -0.020700191 -0.011285109 -0.019558616 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49621 .49343 m
.49641 .49379 L
s
% Start of user PostScript
-0.0075892683 -0.013149485 -0.0071710394 -0.012424492 MAarrowhead1
% End of user PostScript
1 0 .736 r
.15822 0 m
.16116 .00326 L
.18188 .02711 L
.20118 .05011 L
.21918 .07226 L
.23599 .09354 L
.25169 .11395 L
.26638 .1335 L
.28012 .15221 L
.29299 .17009 L
.30504 .18715 L
.31635 .20342 L
.32696 .21893 L
.33692 .23369 L
.34628 .24773 L
.35507 .26109 L
.36333 .27379 L
.3711 .28584 L
.37841 .29729 L
.38529 .30816 L
.39177 .31846 L
.39787 .32824 L
.40362 .3375 L
.40903 .34629 L
.41413 .35461 L
.41894 .36249 L
.42347 .36996 L
.42775 .37703 L
.43178 .38372 L
.43558 .39006 L
.43917 .39605 L
.44256 .40173 L
.44575 .4071 L
.44876 .41218 L
.45161 .41698 L
.45429 .42153 L
.45683 .42582 L
.45922 .42989 L
.46148 .43373 L
.46362 .43737 L
.46563 .44081 L
.46753 .44406 L
.46933 .44713 L
.47102 .45003 L
.47263 .45278 L
.47414 .45537 L
.47557 .45783 L
.47692 .46015 L
.47819 .46234 L
.4794 .46441 L
Mistroke
.48054 .46637 L
.48161 .46822 L
.48263 .46997 L
.48358 .47162 L
.48449 .47318 L
.48535 .47466 L
.48616 .47605 L
.48692 .47737 L
.48764 .47862 L
.48832 .4798 L
.48897 .48091 L
.48958 .48196 L
.49015 .48295 L
.49069 .48389 L
.49121 .48478 L
.49169 .48562 L
.49215 .48641 L
.49258 .48716 L
.49299 .48787 L
.49338 .48854 L
.49374 .48917 L
.49409 .48976 L
.49441 .49033 L
.49472 .49086 L
.49501 .49137 L
.49529 .49184 L
.49555 .49229 L
.49579 .49272 L
.49603 .49312 L
.49624 .4935 L
.49645 .49386 L
.49665 .49419 L
.49683 .49451 L
.49701 .49482 L
.49717 .4951 L
.49733 .49537 L
.49747 .49563 L
.49761 .49587 L
.49775 .4961 L
.49787 .49631 L
.49799 .49651 L
.4981 .49671 L
.4982 .49689 L
.4983 .49706 L
.4984 .49722 L
.49848 .49737 L
.49857 .49752 L
.49865 .49766 L
.49872 .49779 L
.49879 .49791 L
Mistroke
.49886 .49802 L
.49892 .49813 L
.49898 .49823 L
.49904 .49833 L
.49909 .49842 L
.49914 .49851 L
.49919 .49859 L
.49923 .49867 L
.49927 .49874 L
.49931 .49881 L
.49935 .49888 L
.49939 .49894 L
.49942 .499 L
.49945 .49905 L
.49948 .49911 L
.49951 .49916 L
.49954 .4992 L
.49956 .49925 L
.49959 .49929 L
.49961 .49933 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .4997 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .4998 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
Mistroke
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
Mfstroke
1 0 0 r
% Start of user PostScript
-8.0503622 1.3760695 -7.2599613 0.69979574 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-6.5594091 0.14095976 -5.9375743 -0.31761377 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-3.1130256 -1.7368046 -2.8587236 -1.784324 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.6427613 -1.6838403 -1.5259275 -1.6365476 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-0.93723754 -1.254245 -0.87722382 -1.1995754 MAarrowhead1
% End of user PostScript
.581 1 0 r
.21918 .07226 m
.23599 .09354 L
s
% Start of user PostScript
-0.5616309 -0.85548296 -0.52801902 -0.81292456 MAarrowhead1
% End of user PostScript
.266 1 0 r
.32696 .21893 m
.33692 .23369 L
s
% Start of user PostScript
-0.34607595 -0.56214915 -0.3261564 -0.53262355 MAarrowhead1
% End of user PostScript
0 1 .049 r
.39177 .31846 m
.39787 .32824 L
s
% Start of user PostScript
-0.21646016 -0.36307587 -0.20426058 -0.34352686 MAarrowhead1
% End of user PostScript
0 1 .364 r
.43178 .38372 m
.43558 .39006 L
s
% Start of user PostScript
-0.13644071 -0.23255847 -0.12883475 -0.21988705 MAarrowhead1
% End of user PostScript
0 1 .679 r
.45683 .42582 m
.45922 .42989 L
s
% Start of user PostScript
-0.086341647 -0.14835209 -0.081555319 -0.1402216 MAarrowhead1
% End of user PostScript
0 1 .995 r
.47263 .45278 m
.47414 .45537 L
s
% Start of user PostScript
-0.05474694 -0.09444441 -0.051720616 -0.089253407 MAarrowhead1
% End of user PostScript
0 .69 1 r
.48263 .46997 m
.48358 .47162 L
s
% Start of user PostScript
-0.034748257 -0.06006497 -0.032830155 -0.056758844 MAarrowhead1
% End of user PostScript
0 .375 1 r
.48897 .48091 m
.48958 .48196 L
s
% Start of user PostScript
-0.022065999 -0.038181052 -0.020848824 -0.036077967 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49299 .48787 m
.49338 .48854 L
s
% Start of user PostScript
-0.014015966 -0.024264169 -0.013243111 -0.022927174 MAarrowhead1
% End of user PostScript
0 1 .946 r
.19732 0 m
.20579 .01301 L
.22252 .03897 L
.23826 .06361 L
.25307 .087 L
.26701 .10919 L
.28014 .13023 L
.29251 .15018 L
.30417 .16909 L
.31515 .18701 L
.3255 .20398 L
.33526 .22005 L
.34446 .23527 L
.35314 .24968 L
.36133 .26332 L
.36905 .27623 L
.37634 .28844 L
.38321 .3 L
.3897 .31094 L
.39583 .32128 L
.40161 .33106 L
.40707 .34032 L
.41222 .34907 L
.41708 .35735 L
.42167 .36517 L
.42601 .37257 L
.4301 .37957 L
.43397 .38618 L
.43762 .39243 L
.44107 .39834 L
.44433 .40393 L
.44741 .40921 L
.45031 .4142 L
.45306 .41892 L
.45565 .42338 L
.4581 .4276 L
.46041 .43158 L
.4626 .43535 L
.46466 .43891 L
.46661 .44227 L
.46846 .44545 L
.4702 .44845 L
.47184 .45129 L
.47339 .45397 L
.47486 .45651 L
.47625 .4589 L
.47756 .46117 L
.4788 .46331 L
.47997 .46533 L
.48107 .46724 L
Mistroke
.48212 .46904 L
.4831 .47075 L
.48403 .47236 L
.48491 .47388 L
.48575 .47532 L
.48653 .47668 L
.48727 .47797 L
.48798 .47918 L
.48864 .48033 L
.48927 .48141 L
.48986 .48244 L
.49042 .4834 L
.49094 .48432 L
.49144 .48518 L
.49192 .486 L
.49236 .48677 L
.49278 .4875 L
.49318 .48819 L
.49356 .48884 L
.49391 .48946 L
.49425 .49004 L
.49456 .49059 L
.49486 .4911 L
.49515 .4916 L
.49541 .49206 L
.49567 .4925 L
.49591 .49291 L
.49613 .4933 L
.49634 .49367 L
.49655 .49402 L
.49674 .49435 L
.49692 .49466 L
.49709 .49495 L
.49725 .49523 L
.4974 .4955 L
.49754 .49574 L
.49768 .49598 L
.49781 .4962 L
.49793 .49641 L
.49804 .49661 L
.49815 .49679 L
.49825 .49697 L
.49835 .49714 L
.49844 .4973 L
.49852 .49744 L
.49861 .49759 L
.49868 .49772 L
.49876 .49784 L
.49882 .49796 L
.49889 .49808 L
Mistroke
.49895 .49818 L
.49901 .49828 L
.49906 .49838 L
.49911 .49847 L
.49916 .49855 L
.49921 .49863 L
.49925 .49871 L
.49929 .49878 L
.49933 .49884 L
.49937 .49891 L
.4994 .49897 L
.49944 .49903 L
.49947 .49908 L
.4995 .49913 L
.49953 .49918 L
.49955 .49922 L
.49958 .49927 L
.4996 .49931 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49953 L
.49975 .49956 L
.49976 .49958 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
Mistroke
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
Mfstroke
1 0 0 r
% Start of user PostScript
-9.5835765 -2.6537281 -8.7397581 -3.0540156 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-7.9845814 -3.3592685 -7.3075358 -3.5844674 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-4.1130845 -3.7968246 -3.8110769 -3.717943 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-2.3081988 -2.9406002 -2.1570429 -2.8199497 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-1.3695701 -2.0361755 -1.2864749 -1.9371072 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-0.8393457 -1.3470201 -0.79066389 -1.2769552 MAarrowhead1
% End of user PostScript
.266 1 0 r
.23826 .06361 m
.25307 .087 L
s
% Start of user PostScript
-0.52348469 -0.87277342 -0.49386179 -0.82599477 MAarrowhead1
% End of user PostScript
0 1 .049 r
.33526 .22005 m
.34446 .23527 L
s
% Start of user PostScript
-0.3294821 -0.55989805 -0.31107665 -0.5294583 MAarrowhead1
% End of user PostScript
0 1 .364 r
.39583 .32128 m
.40161 .33106 L
s
% Start of user PostScript
-0.20834584 -0.35743942 -0.19678401 -0.33787117 MAarrowhead1
% End of user PostScript
0 1 .679 r
.43397 .38618 m
.43762 .39243 L
s
% Start of user PostScript
-0.13205704 -0.22764075 -0.12475324 -0.21513556 MAarrowhead1
% End of user PostScript
0 1 .995 r
.4581 .4276 m
.46041 .43158 L
s
% Start of user PostScript
-0.08380174 -0.14480289 -0.07917465 -0.13683473 MAarrowhead1
% End of user PostScript
0 .69 1 r
.47339 .45397 m
.47486 .45651 L
s
% Start of user PostScript
-0.053211155 -0.09205448 -0.050275598 -0.086984626 MAarrowhead1
% End of user PostScript
0 .375 1 r
.4831 .47075 m
.48403 .47236 L
s
% Start of user PostScript
-0.03379727 -0.058503652 -0.03193353 -0.055280223 MAarrowhead1
% End of user PostScript
0 .06 1 r
.48927 .48141 m
.48986 .48244 L
s
% Start of user PostScript
-0.021469665 -0.037175449 -0.020285978 -0.035126725 MAarrowhead1
% End of user PostScript
1 0 .313 r
.14206 0 m
.14247 .0004 L
.16488 .02325 L
.1857 .04546 L
.20506 .06699 L
.22308 .08781 L
.23987 .10789 L
.25553 .12721 L
.27015 .14577 L
.28381 .16358 L
.29659 .18063 L
.30855 .19695 L
.31975 .21253 L
.33024 .22741 L
.34009 .24159 L
.34932 .25511 L
.35799 .26798 L
.36613 .28022 L
.37379 .29186 L
.38098 .30292 L
.38775 .31343 L
.39411 .32341 L
.4001 .33287 L
.40574 .34185 L
.41105 .35037 L
.41606 .35845 L
.42077 .3661 L
.42521 .37335 L
.4294 .38022 L
.43335 .38672 L
.43707 .39288 L
.44058 .39871 L
.44389 .40423 L
.44702 .40945 L
.44997 .4144 L
.45275 .41907 L
.45537 .4235 L
.45785 .42769 L
.46019 .43164 L
.4624 .43539 L
.46448 .43893 L
.46645 .44228 L
.46831 .44545 L
.47006 .44844 L
.47172 .45127 L
.47328 .45395 L
.47476 .45648 L
.47616 .45887 L
.47748 .46113 L
.47872 .46327 L
Mistroke
.4799 .46529 L
.48101 .4672 L
.48206 .469 L
.48305 .47071 L
.48398 .47232 L
.48487 .47384 L
.4857 .47528 L
.48649 .47664 L
.48724 .47793 L
.48794 .47914 L
.48861 .48029 L
.48924 .48138 L
.48983 .4824 L
.49039 .48337 L
.49092 .48429 L
.49142 .48515 L
.49189 .48597 L
.49234 .48674 L
.49276 .48747 L
.49316 .48816 L
.49354 .48882 L
.4939 .48943 L
.49423 .49001 L
.49455 .49057 L
.49485 .49109 L
.49513 .49158 L
.4954 .49204 L
.49566 .49248 L
.4959 .49289 L
.49612 .49329 L
.49634 .49366 L
.49654 .49401 L
.49673 .49434 L
.49691 .49465 L
.49708 .49494 L
.49724 .49522 L
.49739 .49548 L
.49754 .49573 L
.49767 .49597 L
.4978 .49619 L
.49792 .4964 L
.49804 .4966 L
.49814 .49679 L
.49825 .49696 L
.49834 .49713 L
.49843 .49729 L
.49852 .49744 L
.4986 .49758 L
.49868 .49771 L
.49875 .49784 L
Mistroke
.49882 .49796 L
.49889 .49807 L
.49895 .49818 L
.49901 .49828 L
.49906 .49837 L
.49911 .49846 L
.49916 .49855 L
.49921 .49863 L
.49925 .4987 L
.49929 .49877 L
.49933 .49884 L
.49937 .49891 L
.4994 .49897 L
.49944 .49902 L
.49947 .49908 L
.4995 .49913 L
.49952 .49918 L
.49955 .49922 L
.49958 .49926 L
.4996 .4993 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49945 L
.4997 .49948 L
.49971 .49951 L
.49973 .49953 L
.49974 .49956 L
.49976 .49958 L
.49977 .49961 L
.49978 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
Mistroke
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
Mfstroke
1 0 0 r
% Start of user PostScript
-8.6262626 2.6800764 -7.7520391 1.8417219 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-6.9792375 1.1417819 -6.2951603 0.56031702 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-3.2213495 -1.3753154 -2.9486512 -1.4642818 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.6612449 -1.5413607 -1.5394439 -1.5087605 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-0.93298441 -1.1914284 -0.87195041 -1.1423946 MAarrowhead1
% End of user PostScript
.581 1 0 r
.22308 .08781 m
.23987 .10789 L
s
% Start of user PostScript
-0.55384539 -0.8243774 -0.52026394 -0.78422418 MAarrowhead1
% End of user PostScript
.266 1 0 r
.33024 .22741 m
.34009 .24159 L
s
% Start of user PostScript
-0.33951412 -0.54518432 -0.31982957 -0.5168133 MAarrowhead1
% End of user PostScript
0 1 .049 r
.39411 .32341 m
.4001 .33287 L
s
% Start of user PostScript
-0.21177783 -0.35318648 -0.19979608 -0.33425232 MAarrowhead1
% End of user PostScript
0 1 .364 r
.43335 .38672 m
.43707 .39288 L
s
% Start of user PostScript
-0.1333027 -0.22655784 -0.12585692 -0.21423935 MAarrowhead1
% End of user PostScript
0 1 .679 r
.45785 .42769 m
.46019 .43164 L
s
% Start of user PostScript
-0.084296098 -0.14462941 -0.079618457 -0.13671116 MAarrowhead1
% End of user PostScript
0 1 .995 r
.47328 .45395 m
.47476 .45648 L
s
% Start of user PostScript
-0.053430842 -0.092107764 -0.050475771 -0.087047797 MAarrowhead1
% End of user PostScript
0 .69 1 r
.48305 .47071 m
.48398 .47232 L
s
% Start of user PostScript
-0.033906849 -0.058589463 -0.032034715 -0.05536538 MAarrowhead1
% End of user PostScript
0 .375 1 r
.48924 .48138 m
.48983 .4824 L
s
% Start of user PostScript
-0.021529753 -0.03724648 -0.020342006 -0.035195135 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49316 .48816 m
.49354 .48882 L
s
% Start of user PostScript
-0.013674737 -0.02367131 -0.01292065 -0.022367066 MAarrowhead1
% End of user PostScript
.924 0 1 r
.79603 1 m
.79259 .99442 L
.77619 .96766 L
.76072 .9423 L
.74614 .91828 L
.73239 .89554 L
.71942 .87401 L
.70719 .85363 L
.69565 .83434 L
.68476 .81609 L
.67449 .79882 L
.6648 .78248 L
.65565 .76703 L
.64701 .75241 L
.63885 .73858 L
.63116 .72551 L
.62389 .71314 L
.61703 .70145 L
.61055 .6904 L
.60443 .67994 L
.59865 .67006 L
.5932 .66072 L
.58804 .65189 L
.58318 .64354 L
.57858 .63565 L
.57424 .62819 L
.57014 .62114 L
.56626 .61447 L
.5626 .60818 L
.55915 .60222 L
.55588 .5966 L
.5528 .59128 L
.54988 .58626 L
.54713 .58151 L
.54453 .57702 L
.54207 .57278 L
.53975 .56877 L
.53756 .56498 L
.53549 .5614 L
.53353 .55802 L
.53168 .55483 L
.52993 .5518 L
.52828 .54895 L
.52672 .54625 L
.52525 .54371 L
.52386 .5413 L
.52254 .53902 L
.5213 .53687 L
.52012 .53484 L
.51901 .53292 L
Mistroke
.51797 .53111 L
.51697 .52939 L
.51604 .52777 L
.51515 .52624 L
.51432 .5248 L
.51353 .52343 L
.51278 .52214 L
.51208 .52092 L
.51141 .51976 L
.51078 .51868 L
.51019 .51765 L
.50963 .51667 L
.5091 .51575 L
.5086 .51489 L
.50812 .51407 L
.50767 .51329 L
.50725 .51256 L
.50685 .51187 L
.50647 .51121 L
.50612 .51059 L
.50578 .51001 L
.50546 .50946 L
.50516 .50894 L
.50488 .50844 L
.50461 .50798 L
.50435 .50754 L
.50411 .50712 L
.50389 .50673 L
.50367 .50636 L
.50347 .50601 L
.50328 .50568 L
.5031 .50537 L
.50293 .50507 L
.50277 .50479 L
.50261 .50453 L
.50247 .50428 L
.50233 .50404 L
.5022 .50382 L
.50208 .50361 L
.50197 .50341 L
.50186 .50322 L
.50176 .50304 L
.50166 .50288 L
.50157 .50272 L
.50148 .50257 L
.5014 .50243 L
.50132 .50229 L
.50125 .50217 L
.50118 .50205 L
.50112 .50193 L
Mistroke
.50105 .50183 L
.501 .50173 L
.50094 .50163 L
.50089 .50154 L
.50084 .50146 L
.50079 .50138 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50063 .5011 L
.5006 .50104 L
.50057 .50098 L
.50053 .50093 L
.5005 .50087 L
.50048 .50083 L
.50045 .50078 L
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50056 L
.5003 .50052 L
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .5004 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
Mfstroke
1 0 0 r
% Start of user PostScript
9.1883046 5.7505677 8.4518412 5.8319467 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
7.7866782 5.8556564 7.1847859 5.8319761 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
4.2476255 4.932074 3.9586173 4.7552555 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
2.4763884 3.5186156 2.3224491 3.3548675 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
1.5027114 2.35789 1.4143388 2.2375177 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
0.93228824 1.5369529 0.87913843 1.455284 MAarrowhead1
% End of user PostScript
.266 1 0 r
.79259 .99442 m
.77619 .96766 L
s
% Start of user PostScript
0.58518921 0.9888489 0.55237326 0.93531144 MAarrowhead1
% End of user PostScript
0 1 .049 r
.68476 .81609 m
.67449 .79882 L
s
% Start of user PostScript
0.36952907 0.63218499 0.34898233 0.59764611 MAarrowhead1
% End of user PostScript
0 1 .364 r
.61703 .70145 m
.61055 .6904 L
s
% Start of user PostScript
0.23405742 0.40290223 0.22109937 0.3807916 MAarrowhead1
% End of user PostScript
0 1 .679 r
.57424 .62819 m
.57014 .62114 L
s
% Start of user PostScript
0.14847789 0.25637772 0.14027564 0.24227695 MAarrowhead1
% End of user PostScript
0 1 .995 r
.54713 .58151 m
.54453 .57702 L
s
% Start of user PostScript
0.094261682 0.16301386 0.089060148 0.15403821 MAarrowhead1
% End of user PostScript
0 .69 1 r
.52993 .5518 m
.52828 .54895 L
s
% Start of user PostScript
0.059865409 0.1036098 0.056563736 0.097901831 MAarrowhead1
% End of user PostScript
0 .375 1 r
.51901 .53292 m
.51797 .53111 L
s
% Start of user PostScript
0.038027739 0.065840512 0.035931024 0.062212295 MAarrowhead1
% End of user PostScript
0 .06 1 r
.51208 .52092 m
.51141 .51976 L
s
% Start of user PostScript
0.024158334 0.04183537 0.022826512 0.039529666 MAarrowhead1
% End of user PostScript
1 0 .499 r
.79525 1 m
.7831 .9801 L
.76726 .95404 L
.75233 .92936 L
.73825 .90599 L
.72496 .88388 L
.71243 .86294 L
.70061 .84313 L
.68945 .82439 L
.67893 .80666 L
.66899 .78988 L
.65961 .77401 L
.65076 .759 L
.6424 .74481 L
.63451 .73139 L
.62706 .7187 L
.62002 .70669 L
.61338 .69535 L
.60711 .68462 L
.60118 .67448 L
.59559 .66489 L
.5903 .65583 L
.58531 .64726 L
.5806 .63917 L
.57615 .63151 L
.57194 .62428 L
.56797 .61744 L
.56422 .61098 L
.56067 .60487 L
.55732 .5991 L
.55416 .59364 L
.55117 .58849 L
.54834 .58362 L
.54568 .57901 L
.54316 .57466 L
.54078 .57055 L
.53853 .56666 L
.5364 .56299 L
.53439 .55952 L
.5325 .55624 L
.5307 .55314 L
.52901 .55022 L
.52741 .54745 L
.5259 .54483 L
.52447 .54236 L
.52312 .54003 L
.52185 .53782 L
.52064 .53574 L
.5195 .53377 L
.51843 .53191 L
Mistroke
.51741 .53015 L
.51645 .52849 L
.51555 .52692 L
.51469 .52544 L
.51388 .52403 L
.51311 .52271 L
.51239 .52146 L
.51171 .52028 L
.51106 .51916 L
.51045 .5181 L
.50988 .5171 L
.50933 .51616 L
.50882 .51527 L
.50833 .51443 L
.50787 .51363 L
.50744 .51288 L
.50703 .51217 L
.50664 .5115 L
.50627 .51087 L
.50593 .51027 L
.5056 .5097 L
.50529 .50917 L
.505 .50866 L
.50473 .50818 L
.50447 .50773 L
.50422 .50731 L
.50399 .5069 L
.50377 .50652 L
.50356 .50616 L
.50336 .50582 L
.50318 .5055 L
.503 .5052 L
.50284 .50491 L
.50268 .50464 L
.50253 .50439 L
.50239 .50415 L
.50226 .50392 L
.50214 .5037 L
.50202 .5035 L
.50191 .5033 L
.5018 .50312 L
.5017 .50295 L
.50161 .50279 L
.50152 .50263 L
.50144 .50249 L
.50136 .50235 L
.50128 .50222 L
.50121 .5021 L
.50115 .50198 L
.50108 .50187 L
Mistroke
.50102 .50177 L
.50097 .50167 L
.50091 .50158 L
.50086 .50149 L
.50081 .50141 L
.50077 .50133 L
.50073 .50126 L
.50069 .50119 L
.50065 .50113 L
.50061 .50106 L
.50058 .501 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .5008 L
.50044 .50076 L
.50041 .50071 L
.50039 .50068 L
.50037 .50064 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .50041 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
Mfstroke
1 0 0 r
% Start of user PostScript
6.6950304 6.1186084 6.2020461 5.9960225 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
5.7527833 5.8515324 5.3426229 5.6901721 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.2779758 4.3707433 3.0677174 4.1810425 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.9628333 2.9844334 1.8452421 2.8362041 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
1.2090013 1.9620816 1.1393734 1.8591014 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
0.75603265 1.2675501 0.71341019 1.1993247 MAarrowhead1
% End of user PostScript
.266 1 0 r
.73825 .90599 m
.72496 .88388 L
s
% Start of user PostScript
0.47649574 0.81198833 0.44992912 0.76775277 MAarrowhead1
% End of user PostScript
0 1 .049 r
.65076 .759 m
.6424 .74481 L
s
% Start of user PostScript
0.30151667 0.51800736 0.28480085 0.48962009 MAarrowhead1
% End of user PostScript
0 1 .364 r
.59559 .66489 m
.5903 .65583 L
s
% Start of user PostScript
0.19117836 0.32978491 0.18060991 0.31165948 MAarrowhead1
% End of user PostScript
0 1 .679 r
.56067 .60487 m
.55732 .5991 L
s
% Start of user PostScript
0.12134052 0.20974031 0.11464239 0.19819591 MAarrowhead1
% End of user PostScript
0 1 .995 r
.53853 .56666 m
.5364 .56299 L
s
% Start of user PostScript
0.07705368 0.13332499 0.072803305 0.12598127 MAarrowhead1
% End of user PostScript
0 .69 1 r
.52447 .54236 m
.52312 .54003 L
s
% Start of user PostScript
0.048943079 0.084728716 0.046244295 0.080060051 MAarrowhead1
% End of user PostScript
0 .375 1 r
.51555 .52692 m
.51469 .52544 L
s
% Start of user PostScript
0.031091697 0.053838677 0.029377572 0.050871556 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50988 .5171 m
.50933 .51616 L
s
% Start of user PostScript
0.019752643 0.03420822 0.018663753 0.032322789 MAarrowhead1
% End of user PostScript
.823 1 0 r
0 .3503 m
.03508 .33392 L
.07517 .31802 L
.11112 .30635 L
.14342 .29821 L
.17248 .29304 L
.19869 .29032 L
.22236 .28964 L
.24379 .29064 L
.26321 .29299 L
.28086 .29644 L
.29692 .30076 L
.31157 .30577 L
.32494 .31129 L
.33719 .31721 L
.3484 .3234 L
.35871 .32976 L
.36818 .33623 L
.37691 .34272 L
.38496 .3492 L
.3924 .35561 L
.39928 .36193 L
.40565 .36811 L
.41157 .37415 L
.41706 .38001 L
.42217 .3857 L
.42692 .3912 L
.43135 .3965 L
.43548 .4016 L
.43934 .4065 L
.44295 .4112 L
.44632 .4157 L
.44947 .42001 L
.45243 .42412 L
.4552 .42805 L
.4578 .43179 L
.46023 .43536 L
.46252 .43876 L
.46467 .44199 L
.46669 .44506 L
.46859 .44798 L
.47037 .45076 L
.47205 .45339 L
.47363 .45589 L
.47512 .45826 L
.47652 .46051 L
.47785 .46264 L
.47909 .46466 L
.48026 .46657 L
.48137 .46838 L
Mistroke
.48241 .4701 L
.48339 .47173 L
.48432 .47327 L
.48519 .47472 L
.48602 .4761 L
.48679 .47741 L
.48753 .47864 L
.48822 .47981 L
.48888 .48091 L
.48949 .48196 L
.49008 .48295 L
.49063 .48388 L
.49115 .48477 L
.49164 .4856 L
.4921 .48639 L
.49254 .48714 L
.49295 .48784 L
.49334 .48851 L
.49371 .48914 L
.49406 .48974 L
.49438 .4903 L
.49469 .49084 L
.49499 .49134 L
.49526 .49182 L
.49553 .49227 L
.49577 .49269 L
.49601 .4931 L
.49623 .49348 L
.49643 .49383 L
.49663 .49417 L
.49682 .4945 L
.49699 .4948 L
.49716 .49508 L
.49732 .49536 L
.49746 .49561 L
.4976 .49585 L
.49774 .49608 L
.49786 .4963 L
.49798 .4965 L
.49809 .49669 L
.4982 .49688 L
.49829 .49705 L
.49839 .49721 L
.49848 .49736 L
.49856 .49751 L
.49864 .49765 L
.49872 .49778 L
.49879 .4979 L
.49885 .49802 L
.49892 .49812 L
Mistroke
.49898 .49823 L
.49903 .49833 L
.49909 .49842 L
.49914 .4985 L
.49918 .49859 L
.49923 .49867 L
.49927 .49874 L
.49931 .49881 L
.49935 .49887 L
.49939 .49894 L
.49942 .49899 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
.49956 .49924 L
.49959 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
Mistroke
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
1 0 0 r
% Start of user PostScript
-8.2257349 8.2095546 -7.2641657 6.8768814 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-6.4234419 5.7351733 -5.6878448 4.7582162 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.5353856 0.9665643 -2.2743914 0.70329144 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.1196531 -0.23666096 -1.0194091 -0.29034703 MAarrowhead1
% End of user PostScript
.897 1 0 r
.22236 .28964 m
.24379 .29064 L
s
% Start of user PostScript
-0.55527681 -0.42071197 -0.51242621 -0.41872729 MAarrowhead1
% End of user PostScript
.581 1 0 r
.3484 .3234 m
.35871 .32976 L
s
% Start of user PostScript
-0.30319069 -0.35320745 -0.28258789 -0.34047678 MAarrowhead1
% End of user PostScript
.266 1 0 r
.41157 .37415 m
.41706 .38001 L
s
% Start of user PostScript
-0.17686828 -0.25170836 -0.16588275 -0.23997523 MAarrowhead1
% End of user PostScript
0 1 .049 r
.44632 .4157 m
.44947 .42001 L
s
% Start of user PostScript
-0.10736333 -0.16859661 -0.10105245 -0.15998381 MAarrowhead1
% End of user PostScript
0 1 .364 r
.46669 .44506 m
.46859 .44798 L
s
% Start of user PostScript
-0.066620915 -0.10987355 -0.062823838 -0.10403341 MAarrowhead1
% End of user PostScript
0 1 .679 r
.47909 .46466 m
.48026 .46657 L
s
% Start of user PostScript
-0.041821361 -0.070683472 -0.03947644 -0.066856021 MAarrowhead1
% End of user PostScript
0 1 .995 r
.48679 .47741 m
.48753 .47864 L
s
% Start of user PostScript
-0.026410193 -0.045186656 -0.024941822 -0.042717745 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49164 .4856 m
.4921 .48639 L
s
% Start of user PostScript
-0.016728463 -0.028797503 -0.015802362 -0.027217086 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49469 .49084 m
.49499 .49134 L
s
% Start of user PostScript
-0.010612086 -0.018324412 -0.010025861 -0.017316551 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49663 .49417 m
.49682 .4945 L
s
% Start of user PostScript
-0.00673716 -0.011651225 -0.0063653943 -0.011009695 MAarrowhead1
% End of user PostScript
1 0 .047 r
.2154 0 m
.21605 .00116 L
.23154 .02893 L
.2462 .05514 L
.26007 .07986 L
.27319 .1032 L
.2856 .12523 L
.29735 .14602 L
.30845 .16565 L
.31895 .18418 L
.32888 .20168 L
.33827 .2182 L
.34714 .23379 L
.35554 .24852 L
.36347 .26244 L
.37097 .27557 L
.37806 .28798 L
.38477 .2997 L
.3911 .31077 L
.39709 .32122 L
.40275 .3311 L
.4081 .34043 L
.41316 .34924 L
.41794 .35756 L
.42245 .36543 L
.42672 .37285 L
.43076 .37987 L
.43457 .3865 L
.43817 .39276 L
.44158 .39868 L
.44479 .40427 L
.44783 .40955 L
.45071 .41454 L
.45342 .41925 L
.45599 .42371 L
.45841 .42792 L
.4607 .43189 L
.46287 .43565 L
.46491 .4392 L
.46685 .44255 L
.46867 .44572 L
.4704 .44871 L
.47203 .45154 L
.47357 .45421 L
.47503 .45673 L
.47641 .45912 L
.47771 .46137 L
.47893 .4635 L
.4801 .46552 L
.48119 .46742 L
Mistroke
.48223 .46921 L
.48321 .47091 L
.48413 .47251 L
.48501 .47403 L
.48583 .47546 L
.48662 .47681 L
.48735 .47809 L
.48805 .4793 L
.48871 .48044 L
.48933 .48152 L
.48992 .48254 L
.49047 .4835 L
.491 .48441 L
.4915 .48527 L
.49196 .48608 L
.49241 .48685 L
.49283 .48757 L
.49322 .48826 L
.49359 .48891 L
.49395 .48952 L
.49428 .4901 L
.4946 .49064 L
.49489 .49116 L
.49518 .49164 L
.49544 .4921 L
.49569 .49254 L
.49593 .49295 L
.49615 .49334 L
.49637 .49371 L
.49657 .49405 L
.49676 .49438 L
.49694 .49469 L
.4971 .49498 L
.49726 .49526 L
.49741 .49552 L
.49756 .49577 L
.49769 .496 L
.49782 .49622 L
.49794 .49643 L
.49805 .49663 L
.49816 .49681 L
.49826 .49699 L
.49836 .49715 L
.49845 .49731 L
.49853 .49746 L
.49861 .4976 L
.49869 .49773 L
.49876 .49786 L
.49883 .49798 L
.4989 .49809 L
Mistroke
.49896 .49819 L
.49901 .49829 L
.49907 .49839 L
.49912 .49848 L
.49917 .49856 L
.49921 .49864 L
.49926 .49871 L
.4993 .49878 L
.49934 .49885 L
.49937 .49891 L
.49941 .49897 L
.49944 .49903 L
.49947 .49908 L
.4995 .49914 L
.49953 .49918 L
.49955 .49923 L
.49958 .49927 L
.4996 .49931 L
.49962 .49935 L
.49964 .49938 L
.49966 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
Mistroke
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
Mfstroke
1 0 0 r
% Start of user PostScript
-3.6988617 -8.8485586 -3.5502319 -8.2651077 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-3.4024176 -7.726595 -3.2563589 -7.2288374 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.3297813 -4.6179202 -2.2145443 -4.3405399 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.533622 -2.8414538 -1.4532762 -2.6775729 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-0.99134917 -1.7759009 -0.93803599 -1.675705 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-0.63524055 -1.1189648 -0.60064831 -1.0565533 MAarrowhead1
% End of user PostScript
.266 1 0 r
.29735 .14602 m
.30845 .16565 L
s
% Start of user PostScript
-0.40530974 -0.70795817 -0.38310297 -0.66870174 MAarrowhead1
% End of user PostScript
0 1 .049 r
.37097 .27557 m
.37806 .28798 L
s
% Start of user PostScript
-0.25805546 -0.44885311 -0.24387383 -0.42403774 MAarrowhead1
% End of user PostScript
0 1 .364 r
.41794 .35756 m
.42245 .36543 L
s
% Start of user PostScript
-0.16412688 -0.28487603 -0.15509356 -0.26914977 MAarrowhead1
% End of user PostScript
0 1 .679 r
.44783 .40955 m
.45071 .41454 L
s
% Start of user PostScript
-0.10433191 -0.18089881 -0.098585308 -0.17091996 MAarrowhead1
% End of user PostScript
0 1 .995 r
.46685 .44255 m
.46867 .44572 L
s
% Start of user PostScript
-0.066304051 -0.11490257 -0.062650656 -0.10856661 MAarrowhead1
% End of user PostScript
0 .69 1 r
.47893 .4635 m
.4801 .46552 L
s
% Start of user PostScript
-0.042131387 -0.072992954 -0.039809485 -0.068968733 MAarrowhead1
% End of user PostScript
0 .375 1 r
.48662 .47681 m
.48735 .47809 L
s
% Start of user PostScript
-0.026769658 -0.046372526 -0.025294218 -0.043816172 MAarrowhead1
% End of user PostScript
0 .06 1 r
.4915 .48527 m
.49196 .48608 L
s
% Start of user PostScript
-0.017008483 -0.029461501 -0.016070997 -0.027837468 MAarrowhead1
% End of user PostScript
0 .347 1 r
.7931 1 m
.78813 .99172 L
.77208 .96491 L
.75694 .93953 L
.74265 .91552 L
.72917 .8928 L
.71645 .87131 L
.70443 .85099 L
.69309 .83176 L
.68239 .81358 L
.67228 .79638 L
.66274 .78013 L
.65373 .76475 L
.64522 .75022 L
.63719 .73648 L
.6296 .72349 L
.62243 .71121 L
.61567 .6996 L
.60927 .68863 L
.60324 .67825 L
.59753 .66845 L
.59215 .65918 L
.58706 .65043 L
.58225 .64215 L
.57771 .63433 L
.57342 .62693 L
.56937 .61994 L
.56554 .61334 L
.56192 .6071 L
.55851 .6012 L
.55528 .59563 L
.55223 .59036 L
.54935 .58539 L
.54663 .58068 L
.54405 .57624 L
.54162 .57204 L
.53933 .56807 L
.53716 .56432 L
.53511 .56078 L
.53317 .55743 L
.53134 .55426 L
.52962 .55127 L
.52798 .54845 L
.52644 .54578 L
.52498 .54326 L
.52361 .54087 L
.5223 .53862 L
.52107 .53649 L
.51991 .53448 L
.51881 .53258 L
Mistroke
.51778 .53078 L
.5168 .52909 L
.51587 .52748 L
.515 .52597 L
.51417 .52454 L
.51339 .52319 L
.51265 .52191 L
.51195 .5207 L
.51129 .51956 L
.51067 .51848 L
.51008 .51746 L
.50953 .5165 L
.509 .51559 L
.50851 .51473 L
.50804 .51392 L
.50759 .51315 L
.50718 .51243 L
.50678 .51174 L
.50641 .5111 L
.50605 .51048 L
.50572 .50991 L
.5054 .50936 L
.50511 .50884 L
.50482 .50836 L
.50456 .5079 L
.50431 .50746 L
.50407 .50705 L
.50385 .50666 L
.50363 .50629 L
.50343 .50595 L
.50324 .50562 L
.50307 .50531 L
.5029 .50502 L
.50274 .50474 L
.50259 .50448 L
.50244 .50423 L
.50231 .504 L
.50218 .50378 L
.50206 .50357 L
.50195 .50337 L
.50184 .50319 L
.50174 .50301 L
.50164 .50285 L
.50155 .50269 L
.50147 .50254 L
.50139 .5024 L
.50131 .50227 L
.50124 .50214 L
.50117 .50203 L
.5011 .50191 L
Mistroke
.50104 .50181 L
.50099 .50171 L
.50093 .50161 L
.50088 .50153 L
.50083 .50144 L
.50079 .50136 L
.50074 .50129 L
.5007 .50122 L
.50066 .50115 L
.50063 .50109 L
.50059 .50103 L
.50056 .50097 L
.50053 .50092 L
.5005 .50087 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50036 .50062 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
Mfstroke
1 0 0 r
% Start of user PostScript
4.1947265 5.6051266 3.9259372 5.3612386 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
3.6769798 5.1221063 3.4460916 4.8886273 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.2218628 3.4522373 2.0904269 3.2774714 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.3753297 2.2562567 1.2966712 2.1368226 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
0.86226617 1.4534859 0.81383174 1.3749357 MAarrowhead1
% End of user PostScript
.581 1 0 r
.77208 .96491 m
.75694 .93953 L
s
% Start of user PostScript
0.54416779 0.92981431 0.5138849 0.87905994 MAarrowhead1
% End of user PostScript
.266 1 0 r
.67228 .79638 m
.66274 .78013 L
s
% Start of user PostScript
0.34456799 0.59276972 0.32548354 0.5602538 MAarrowhead1
% End of user PostScript
0 1 .049 r
.60927 .68863 m
.60324 .67825 L
s
% Start of user PostScript
0.21854863 0.37725367 0.2064729 0.35650926 MAarrowhead1
% End of user PostScript
0 1 .364 r
.56937 .61994 m
.56554 .61334 L
s
% Start of user PostScript
0.13873573 0.23988941 0.1310792 0.22668238 MAarrowhead1
% End of user PostScript
0 1 .679 r
.54405 .57624 m
.54162 .57204 L
s
% Start of user PostScript
0.088107414 0.15247689 0.083247885 0.14407725 MAarrowhead1
% End of user PostScript
0 1 .995 r
.52798 .54845 m
.52644 .54578 L
s
% Start of user PostScript
0.05596657 0.09689575 0.052880687 0.091556344 MAarrowhead1
% End of user PostScript
0 .69 1 r
.51778 .53078 m
.5168 .52909 L
s
% Start of user PostScript
0.035554207 0.061568604 0.033594117 0.058175375 MAarrowhead1
% End of user PostScript
0 .375 1 r
.51129 .51956 m
.51067 .51848 L
s
% Start of user PostScript
0.022587926 0.039119277 0.021342756 0.036963134 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50718 .51243 m
.50678 .51174 L
s
% Start of user PostScript
0.014350706 0.02485483 0.013559646 0.023484851 MAarrowhead1
% End of user PostScript
.501 1 0 r
0 .15386 m
.01786 .15254 L
.05547 .15258 L
.08953 .15517 L
.12044 .15983 L
.14854 .16614 L
.17413 .17377 L
.19749 .18242 L
.21883 .19184 L
.23838 .20181 L
.2563 .21218 L
.27277 .22278 L
.28793 .2335 L
.3019 .24424 L
.3148 .25491 L
.32672 .26546 L
.33776 .27581 L
.34798 .28594 L
.35748 .29581 L
.3663 .3054 L
.37451 .31467 L
.38215 .32363 L
.38927 .33227 L
.39592 .34057 L
.40213 .34854 L
.40793 .35618 L
.41336 .3635 L
.41844 .37049 L
.42321 .37717 L
.42767 .38354 L
.43186 .38961 L
.43578 .3954 L
.43947 .4009 L
.44294 .40614 L
.4462 .41112 L
.44926 .41585 L
.45214 .42034 L
.45485 .42461 L
.45741 .42865 L
.45981 .43249 L
.46207 .43613 L
.4642 .43958 L
.46621 .44285 L
.46811 .44594 L
.46989 .44888 L
.47157 .45165 L
.47316 .45428 L
.47466 .45677 L
.47607 .45913 L
.4774 .46136 L
Mistroke
.47866 .46347 L
.47984 .46547 L
.48096 .46736 L
.48202 .46914 L
.48302 .47083 L
.48396 .47243 L
.48485 .47394 L
.48569 .47537 L
.48648 .47672 L
.48723 .478 L
.48794 .47921 L
.4886 .48035 L
.48923 .48143 L
.48983 .48245 L
.49039 .48341 L
.49092 .48433 L
.49142 .48519 L
.4919 .486 L
.49234 .48677 L
.49277 .4875 L
.49317 .48819 L
.49354 .48884 L
.4939 .48945 L
.49424 .49003 L
.49455 .49058 L
.49486 .4911 L
.49514 .49159 L
.49541 .49205 L
.49566 .49249 L
.4959 .49291 L
.49613 .4933 L
.49634 .49367 L
.49654 .49401 L
.49673 .49434 L
.49691 .49466 L
.49708 .49495 L
.49724 .49523 L
.4974 .49549 L
.49754 .49574 L
.49768 .49597 L
.4978 .4962 L
.49792 .49641 L
.49804 .4966 L
.49815 .49679 L
.49825 .49697 L
.49835 .49714 L
.49844 .49729 L
.49852 .49744 L
.4986 .49758 L
.49868 .49772 L
Mistroke
.49875 .49784 L
.49882 .49796 L
.49889 .49807 L
.49895 .49818 L
.49901 .49828 L
.49906 .49837 L
.49911 .49846 L
.49916 .49855 L
.49921 .49863 L
.49925 .4987 L
.49929 .49878 L
.49933 .49884 L
.49937 .49891 L
.4994 .49897 L
.49944 .49902 L
.49947 .49908 L
.4995 .49913 L
.49952 .49918 L
.49955 .49922 L
.49958 .49927 L
.4996 .49931 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49945 L
.4997 .49948 L
.49971 .49951 L
.49973 .49953 L
.49975 .49956 L
.49976 .49958 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
Mistroke
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
1 0 0 r
% Start of user PostScript
-7.9535733 5.9963943 -7.0677523 4.8909289 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-6.2904911 3.9498576 -5.6078313 3.1503063 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.6356936 0.15231969 -2.3836637 -0.040967677 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.2421008 -0.65228375 -1.139713 -0.67508294 MAarrowhead1
% End of user PostScript
.897 1 0 r
.17413 .17377 m
.19749 .18242 L
s
% Start of user PostScript
-0.65173218 -0.65245669 -0.6050284 -0.63516298 MAarrowhead1
% End of user PostScript
.581 1 0 r
.3148 .25491 m
.32672 .26546 L
s
% Start of user PostScript
-0.37040235 -0.49017489 -0.34655984 -0.46908886 MAarrowhead1
% End of user PostScript
.266 1 0 r
.38927 .33227 m
.39592 .34057 L
s
% Start of user PostScript
-0.22145497 -0.33546615 -0.20815956 -0.3188602 MAarrowhead1
% End of user PostScript
0 1 .049 r
.43186 .38961 m
.43578 .3954 L
s
% Start of user PostScript
-0.13628994 -0.22077448 -0.12843156 -0.20920423 MAarrowhead1
% End of user PostScript
0 1 .364 r
.45741 .42865 m
.45981 .43249 L
s
% Start of user PostScript
-0.085189513 -0.14269485 -0.080383835 -0.13501971 MAarrowhead1
% End of user PostScript
0 1 .679 r
.47316 .45428 m
.47466 .45677 L
s
% Start of user PostScript
-0.053679258 -0.09143154 -0.050685457 -0.086452214 MAarrowhead1
% End of user PostScript
0 1 .995 r
.48302 .47083 m
.48396 .47243 L
s
% Start of user PostScript
-0.033963242 -0.058335523 -0.032080044 -0.055139218 MAarrowhead1
% End of user PostScript
0 .69 1 r
.48923 .48143 m
.48983 .48245 L
s
% Start of user PostScript
-0.021533348 -0.037140972 -0.020342874 -0.035099822 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49317 .48819 m
.49354 .48884 L
s
% Start of user PostScript
-0.013666777 -0.023622018 -0.012912326 -0.022321883 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49566 .49249 m
.4959 .49291 L
s
% Start of user PostScript
-0.008678554 -0.015015955 -0.0081998246 -0.014188873 MAarrowhead1
% End of user PostScript
1 0 .179 r
0 .49024 m
.01864 .47643 L
.0635 .44597 L
.10345 .42144 L
.13907 .40193 L
.17089 .38668 L
.19937 .37502 L
.22489 .3664 L
.24782 .36033 L
.26844 .35638 L
.28703 .35421 L
.30382 .3535 L
.31901 .354 L
.33277 .35548 L
.34527 .35776 L
.35665 .36067 L
.36702 .36408 L
.37648 .36787 L
.38514 .37195 L
.39308 .37623 L
.40036 .38065 L
.40706 .38514 L
.41322 .38966 L
.41891 .39418 L
.42417 .39865 L
.42902 .40306 L
.43352 .40739 L
.4377 .41161 L
.44157 .41572 L
.44518 .4197 L
.44853 .42355 L
.45166 .42727 L
.45457 .43085 L
.45729 .43428 L
.45983 .43758 L
.46221 .44074 L
.46443 .44377 L
.46651 .44666 L
.46846 .44941 L
.47029 .45204 L
.47201 .45455 L
.47362 .45694 L
.47513 .45921 L
.47656 .46137 L
.47789 .46342 L
.47915 .46537 L
.48033 .46722 L
.48145 .46898 L
.48249 .47064 L
.48348 .47222 L
Mistroke
.48441 .47372 L
.48529 .47514 L
.48611 .47649 L
.48689 .47776 L
.48762 .47897 L
.48831 .48011 L
.48897 .48119 L
.48958 .48222 L
.49016 .48319 L
.49071 .48411 L
.49123 .48498 L
.49171 .4858 L
.49217 .48657 L
.49261 .48731 L
.49302 .488 L
.4934 .48866 L
.49377 .48928 L
.49412 .48987 L
.49444 .49043 L
.49475 .49095 L
.49504 .49145 L
.49531 .49192 L
.49557 .49236 L
.49582 .49278 L
.49605 .49318 L
.49627 .49355 L
.49647 .49391 L
.49667 .49424 L
.49685 .49456 L
.49703 .49486 L
.49719 .49514 L
.49735 .49541 L
.49749 .49566 L
.49763 .4959 L
.49776 .49613 L
.49788 .49634 L
.498 .49654 L
.49811 .49673 L
.49822 .49691 L
.49831 .49708 L
.49841 .49724 L
.49849 .4974 L
.49858 .49754 L
.49866 .49767 L
.49873 .4978 L
.4988 .49792 L
.49887 .49804 L
.49893 .49815 L
.49899 .49825 L
.49904 .49834 L
Mistroke
.4991 .49844 L
.49915 .49852 L
.49919 .4986 L
.49924 .49868 L
.49928 .49875 L
.49932 .49882 L
.49936 .49889 L
.49939 .49895 L
.49943 .49901 L
.49946 .49906 L
.49949 .49911 L
.49952 .49916 L
.49954 .49921 L
.49957 .49925 L
.49959 .49929 L
.49961 .49933 L
.49964 .49937 L
.49966 .4994 L
.49967 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49952 L
.49974 .49955 L
.49975 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49971 L
.49984 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49978 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
Mistroke
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
Mfstroke
1 0 0 r
% Start of user PostScript
-5.8582701 5.8991333 -5.1722666 4.9450786 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-4.5725513 4.1275734 -4.0478962 3.4278816 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.8007014 0.70948266 -1.6148156 0.52032955 MAarrowhead1
% End of user PostScript
1 .788 0 r
.10345 .42144 m
.13907 .40193 L
s
% Start of user PostScript
-0.79310008 -0.15712147 -0.72185485 -0.19614151 MAarrowhead1
% End of user PostScript
.897 1 0 r
.30382 .3535 m
.31901 .354 L
s
% Start of user PostScript
-0.39236322 -0.2929975 -0.36198776 -0.29199887 MAarrowhead1
% End of user PostScript
.581 1 0 r
.39308 .37623 m
.40036 .38065 L
s
% Start of user PostScript
-0.2138446 -0.24753913 -0.19927735 -0.23870932 MAarrowhead1
% End of user PostScript
.266 1 0 r
.4377 .41161 m
.44157 .41572 L
s
% Start of user PostScript
-0.12460254 -0.17677902 -0.11685091 -0.16856477 MAarrowhead1
% End of user PostScript
0 1 .049 r
.46221 .44074 m
.46443 .44377 L
s
% Start of user PostScript
-0.075586533 -0.11851411 -0.07113939 -0.11246767 MAarrowhead1
% End of user PostScript
0 1 .364 r
.47656 .46137 m
.47789 .46342 L
s
% Start of user PostScript
-0.046886125 -0.077266953 -0.044212496 -0.073162403 MAarrowhead1
% End of user PostScript
0 1 .679 r
.48529 .47514 m
.48611 .47649 L
s
% Start of user PostScript
-0.029427387 -0.049716996 -0.027776964 -0.047025628 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49071 .48411 m
.49123 .48498 L
s
% Start of user PostScript
-0.01858165 -0.031786273 -0.017548397 -0.030049774 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49412 .48987 m
.49444 .49043 L
s
% Start of user PostScript
-0.011769232 -0.020258405 -0.011117634 -0.019146693 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49627 .49355 m
.49647 .49391 L
s
% Start of user PostScript
-0.0074659052 -0.012891128 -0.0070534651 -0.012182127 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49763 .4959 m
.49776 .49613 L
s
% Start of user PostScript
-0.0047397274 -0.0081966743 -0.0044781784 -0.0077453635 MAarrowhead1
% End of user PostScript
0 .501 1 r
.20753 0 m
.20764 .00019 L
.22391 .02748 L
.23925 .0533 L
.25374 .07773 L
.26741 .10084 L
.28031 .1227 L
.29249 .14337 L
.304 .16292 L
.31485 .1814 L
.32511 .19888 L
.33479 .21541 L
.34393 .23104 L
.35256 .24581 L
.36072 .25977 L
.36842 .27298 L
.37569 .28546 L
.38256 .29725 L
.38905 .3084 L
.39518 .31894 L
.40097 .3289 L
.40644 .33831 L
.4116 .34721 L
.41648 .35562 L
.42109 .36357 L
.42545 .37108 L
.42956 .37818 L
.43345 .38489 L
.43712 .39122 L
.44059 .39721 L
.44387 .40288 L
.44696 .40823 L
.44989 .41328 L
.45265 .41806 L
.45526 .42257 L
.45773 .42684 L
.46006 .43087 L
.46226 .43468 L
.46435 .43828 L
.46631 .44168 L
.46817 .44489 L
.46992 .44793 L
.47158 .4508 L
.47315 .45351 L
.47463 .45607 L
.47603 .45849 L
.47735 .46078 L
.4786 .46294 L
.47978 .46498 L
.48089 .46691 L
Mistroke
.48195 .46874 L
.48294 .47046 L
.48388 .47209 L
.48477 .47363 L
.48561 .47508 L
.4864 .47645 L
.48715 .47775 L
.48786 .47898 L
.48853 .48014 L
.48916 .48123 L
.48976 .48227 L
.49032 .48324 L
.49086 .48417 L
.49136 .48504 L
.49184 .48586 L
.49229 .48664 L
.49271 .48738 L
.49311 .48807 L
.49349 .48873 L
.49385 .48935 L
.49419 .48994 L
.49451 .49049 L
.49481 .49102 L
.4951 .49151 L
.49537 .49198 L
.49563 .49242 L
.49587 .49284 L
.49609 .49324 L
.49631 .49361 L
.49651 .49396 L
.49671 .49429 L
.49689 .49461 L
.49706 .49491 L
.49722 .49519 L
.49737 .49545 L
.49752 .4957 L
.49766 .49594 L
.49778 .49616 L
.49791 .49637 L
.49802 .49657 L
.49813 .49676 L
.49823 .49694 L
.49833 .49711 L
.49842 .49727 L
.49851 .49742 L
.49859 .49756 L
.49867 .4977 L
.49874 .49782 L
.49881 .49794 L
.49888 .49806 L
Mistroke
.49894 .49816 L
.499 .49827 L
.49905 .49836 L
.49911 .49845 L
.49916 .49854 L
.4992 .49862 L
.49925 .49869 L
.49929 .49877 L
.49933 .49883 L
.49936 .4989 L
.4994 .49896 L
.49943 .49902 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49922 L
.49957 .49926 L
.4996 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.4997 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49956 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.4998 .49965 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
Mistroke
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
Mfstroke
1 0 0 r
% Start of user PostScript
-3.6908487 -5.2767956 -3.4621528 -5.0296687 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-3.2494341 -4.7903245 -3.0513619 -4.5591137 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.9876961 -3.1765392 -1.872107 -3.0118793 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.2384611 -2.0604693 -1.1682809 -1.9502095 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-0.77909153 -1.3225397 -0.7355386 -1.2506933 MAarrowhead1
% End of user PostScript
.581 1 0 r
.25374 .07773 m
.26741 .10084 L
s
% Start of user PostScript
-0.49252578 -0.84453583 -0.46518378 -0.79831877 MAarrowhead1
% End of user PostScript
.266 1 0 r
.34393 .23104 m
.35256 .24581 L
s
% Start of user PostScript
-0.31213969 -0.53792679 -0.29487271 -0.50838197 MAarrowhead1
% End of user PostScript
0 1 .049 r
.40097 .3289 m
.40644 .33831 L
s
% Start of user PostScript
-0.19806696 -0.34219927 -0.18712973 -0.32337061 MAarrowhead1
% End of user PostScript
0 1 .364 r
.43712 .39122 m
.44059 .39721 L
s
% Start of user PostScript
-0.12576142 -0.217551 -0.11882308 -0.20557005 MAarrowhead1
% End of user PostScript
0 1 .679 r
.46006 .43087 m
.46226 .43468 L
s
% Start of user PostScript
-0.079876536 -0.1382631 -0.075471665 -0.13064527 MAarrowhead1
% End of user PostScript
0 1 .995 r
.47463 .45607 m
.47603 .45849 L
s
% Start of user PostScript
-0.050741033 -0.087858361 -0.047943494 -0.083016578 MAarrowhead1
% End of user PostScript
0 .69 1 r
.48388 .47209 m
.48477 .47363 L
s
% Start of user PostScript
-0.032235436 -0.055824615 -0.030458377 -0.052747834 MAarrowhead1
% End of user PostScript
0 .375 1 r
.48976 .48227 m
.49032 .48324 L
s
% Start of user PostScript
-0.020479761 -0.03546919 -0.019350826 -0.033514192 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49349 .48873 m
.49385 .48935 L
s
% Start of user PostScript
-0.013011422 -0.022535555 -0.012294195 -0.021293401 MAarrowhead1
% End of user PostScript
.359 1 0 r
.32836 0 m
.33023 .01508 L
.33526 .04929 L
.3406 .08061 L
.34615 .10935 L
.35182 .13575 L
.35755 .16004 L
.36329 .18243 L
.369 .20311 L
.37464 .22221 L
.38018 .2399 L
.38559 .2563 L
.39087 .27152 L
.39599 .28566 L
.40095 .29881 L
.40574 .31106 L
.41035 .32248 L
.41479 .33314 L
.41905 .34309 L
.42314 .3524 L
.42705 .3611 L
.43078 .36925 L
.43435 .37688 L
.43776 .38404 L
.441 .39075 L
.4441 .39705 L
.44704 .40296 L
.44984 .40852 L
.4525 .41374 L
.45503 .41865 L
.45743 .42327 L
.45971 .42762 L
.46187 .43171 L
.46392 .43556 L
.46587 .43919 L
.46771 .44261 L
.46946 .44583 L
.47111 .44886 L
.47268 .45173 L
.47416 .45442 L
.47557 .45697 L
.4769 .45937 L
.47816 .46163 L
.47935 .46377 L
.48048 .46578 L
.48154 .46769 L
.48255 .46948 L
.48351 .47117 L
.48441 .47277 L
.48527 .47428 L
Mistroke
.48607 .47571 L
.48684 .47705 L
.48756 .47833 L
.48824 .47952 L
.48889 .48066 L
.4895 .48173 L
.49008 .48274 L
.49062 .48369 L
.49114 .48459 L
.49162 .48545 L
.49208 .48625 L
.49252 .48701 L
.49293 .48773 L
.49332 .4884 L
.49369 .48904 L
.49404 .48965 L
.49436 .49022 L
.49467 .49076 L
.49497 .49127 L
.49524 .49175 L
.49551 .49221 L
.49575 .49264 L
.49599 .49304 L
.49621 .49343 L
.49642 .49379 L
.49661 .49413 L
.4968 .49446 L
.49698 .49476 L
.49714 .49505 L
.4973 .49532 L
.49745 .49558 L
.49759 .49582 L
.49772 .49605 L
.49785 .49627 L
.49797 .49648 L
.49808 .49667 L
.49819 .49686 L
.49829 .49703 L
.49838 .49719 L
.49847 .49735 L
.49855 .49749 L
.49863 .49763 L
.49871 .49776 L
.49878 .49789 L
.49885 .498 L
.49891 .49811 L
.49897 .49822 L
.49903 .49831 L
.49908 .49841 L
.49913 .4985 L
Mistroke
.49918 .49858 L
.49922 .49866 L
.49927 .49873 L
.49931 .4988 L
.49935 .49887 L
.49938 .49893 L
.49942 .49899 L
.49945 .49904 L
.49948 .4991 L
.49951 .49915 L
.49953 .49919 L
.49956 .49924 L
.49958 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .49939 L
.49967 .49943 L
.49969 .49946 L
.4997 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49976 .49959 L
.49978 .49961 L
.49979 .49964 L
.4998 .49966 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49982 L
.4999 .49983 L
.4999 .49984 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
Mistroke
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
1 0 0 r
% Start of user PostScript
0.75473671 -6.4318331 0.5380148 -5.7739855 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
0.35661861 -5.1928943 0.20547958 -4.6789221 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-0.30610305 -2.3766446 -0.33101193 -2.1732729 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.36375262 -1.2167973 -0.35697929 -1.1267291 MAarrowhead1
% End of user PostScript
.897 1 0 r
.35755 .16004 m
.36329 .18243 L
s
% Start of user PostScript
-0.2848983 -0.67991605 -0.2734135 -0.63513038 MAarrowhead1
% End of user PostScript
.581 1 0 r
.40095 .29881 m
.40574 .31106 L
s
% Start of user PostScript
-0.19810153 -0.40237361 -0.18852266 -0.377872 MAarrowhead1
% End of user PostScript
.266 1 0 r
.43435 .37688 m
.43776 .38404 L
s
% Start of user PostScript
-0.13129431 -0.24623715 -0.12448325 -0.23192628 MAarrowhead1
% End of user PostScript
0 1 .049 r
.45743 .42327 m
.45971 .42762 L
s
% Start of user PostScript
-0.085143061 -0.15345542 -0.080585254 -0.14476225 MAarrowhead1
% End of user PostScript
0 1 .364 r
.47268 .45173 m
.47416 .45442 L
s
% Start of user PostScript
-0.054643584 -0.096546814 -0.051674582 -0.091150508 MAarrowhead1
% End of user PostScript
0 1 .679 r
.48255 .46948 m
.48351 .47117 L
s
% Start of user PostScript
-0.034891738 -0.061038465 -0.032982131 -0.057650264 MAarrowhead1
% End of user PostScript
0 1 .995 r
.48889 .48066 m
.4895 .48173 L
s
% Start of user PostScript
-0.022223621 -0.038684441 -0.02100297 -0.036544578 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49293 .48773 m
.49332 .4884 L
s
% Start of user PostScript
-0.014137229 -0.024547412 -0.013359347 -0.023191936 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49551 .49221 m
.49575 .49264 L
s
% Start of user PostScript
-0.0089875868 -0.015586345 -0.008492618 -0.014726446 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49714 .49505 m
.4973 .49532 L
s
% Start of user PostScript
-0.0057119803 -0.0098996012 -0.0053972678 -0.0093536807 MAarrowhead1
% End of user PostScript
.222 0 1 r
1 .77397 m
.97057 .78041 L
.93254 .7859 L
.89821 .7883 L
.86718 .78814 L
.83907 .78589 L
.81356 .78195 L
.79037 .77664 L
.76924 .77026 L
.74996 .76305 L
.73234 .75521 L
.7162 .74691 L
.7014 .7383 L
.6878 .7295 L
.67528 .7206 L
.66374 .71169 L
.65308 .70284 L
.64324 .6941 L
.63412 .68552 L
.62567 .67713 L
.61782 .66895 L
.61053 .66102 L
.60375 .65333 L
.59744 .64592 L
.59155 .63877 L
.58605 .63189 L
.58092 .6253 L
.57613 .61897 L
.57164 .61292 L
.56744 .60713 L
.5635 .60161 L
.55981 .59633 L
.55635 .59131 L
.5531 .58652 L
.55005 .58197 L
.54719 .57763 L
.54449 .57352 L
.54196 .5696 L
.53958 .56589 L
.53734 .56236 L
.53522 .55901 L
.53324 .55584 L
.53137 .55283 L
.5296 .54997 L
.52794 .54727 L
.52638 .54471 L
.5249 .54228 L
.52351 .53999 L
.5222 .53781 L
.52096 .53575 L
Mistroke
.51979 .5338 L
.51869 .53196 L
.51765 .53021 L
.51667 .52856 L
.51574 .527 L
.51487 .52552 L
.51404 .52412 L
.51327 .5228 L
.51253 .52155 L
.51184 .52037 L
.51118 .51925 L
.51056 .5182 L
.50998 .5172 L
.50943 .51625 L
.5089 .51536 L
.50841 .51451 L
.50795 .51372 L
.50751 .51296 L
.50709 .51225 L
.5067 .51158 L
.50633 .51094 L
.50598 .51034 L
.50565 .50977 L
.50534 .50923 L
.50504 .50872 L
.50477 .50824 L
.5045 .50779 L
.50425 .50736 L
.50402 .50695 L
.5038 .50657 L
.50359 .50621 L
.50339 .50587 L
.5032 .50554 L
.50303 .50524 L
.50286 .50495 L
.5027 .50468 L
.50255 .50442 L
.50241 .50418 L
.50228 .50395 L
.50215 .50373 L
.50204 .50352 L
.50192 .50333 L
.50182 .50315 L
.50172 .50297 L
.50162 .50281 L
.50153 .50265 L
.50145 .50251 L
.50137 .50237 L
.50129 .50224 L
.50122 .50212 L
Mistroke
.50115 .502 L
.50109 .50189 L
.50103 .50178 L
.50097 .50169 L
.50092 .50159 L
.50087 .50151 L
.50082 .50142 L
.50078 .50134 L
.50073 .50127 L
.50069 .5012 L
.50065 .50113 L
.50062 .50107 L
.50058 .50101 L
.50055 .50096 L
.50052 .5009 L
.50049 .50085 L
.50047 .50081 L
.50044 .50076 L
.50042 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .50061 L
.50033 .50057 L
.50031 .50054 L
.5003 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50039 L
.50021 .50036 L
.5002 .50034 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50025 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50018 L
.5001 .50017 L
.5001 .50016 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
Mistroke
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
Mfstroke
1 0 0 r
% Start of user PostScript
9.4240996 -8.6959931 8.3385005 -7.236092 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
7.3883235 -5.9875752 6.556013 -4.921313 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.9720703 -0.82148531 2.6731734 -0.54225154 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.3410592 0.42589752 1.2242156 0.47676583 MAarrowhead1
% End of user PostScript
.897 1 0 r
.83907 .78589 m
.81356 .78195 L
s
% Start of user PostScript
0.67813805 0.57178594 0.6271184 0.56389316 MAarrowhead1
% End of user PostScript
.581 1 0 r
.6878 .7295 m
.67528 .7206 L
s
% Start of user PostScript
0.37559091 0.45899268 0.35055345 0.44119979 MAarrowhead1
% End of user PostScript
.266 1 0 r
.61053 .66102 m
.60375 .65333 L
s
% Start of user PostScript
0.22106903 0.32203294 0.20750605 0.30666773 MAarrowhead1
% End of user PostScript
0 1 .049 r
.56744 .60713 m
.5635 .60161 L
s
% Start of user PostScript
0.13487454 0.21426662 0.12700239 0.20321406 MAarrowhead1
% End of user PostScript
0 1 .364 r
.54196 .5696 m
.53958 .56589 L
s
% Start of user PostScript
0.08391839 0.1392042 0.07915361 0.13177199 MAarrowhead1
% End of user PostScript
0 1 .679 r
.52638 .54471 m
.5249 .54228 L
s
% Start of user PostScript
0.052753491 0.089418452 0.049801451 0.084566144 MAarrowhead1
% End of user PostScript
0 1 .995 r
.51667 .52856 m
.51574 .527 L
s
% Start of user PostScript
0.033337511 0.057121561 0.031485859 0.053997272 MAarrowhead1
% End of user PostScript
0 .69 1 r
.51056 .5182 m
.50998 .5172 L
s
% Start of user PostScript
0.021123861 0.036390357 0.019955023 0.034392203 MAarrowhead1
% End of user PostScript
0 .375 1 r
.5067 .51158 m
.50633 .51094 L
s
% Start of user PostScript
0.013402821 0.023151688 0.012662622 0.021877993 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50425 .50736 m
.50402 .50695 L
s
% Start of user PostScript
0.0085096461 0.014719221 0.0080401326 0.013908659 MAarrowhead1
% End of user PostScript
.431 1 0 r
.83514 1 m
.82358 .98629 L
.80407 .96239 L
.78585 .93942 L
.76884 .91738 L
.75293 .89627 L
.73804 .87606 L
.7241 .85675 L
.71103 .83832 L
.69879 .82074 L
.6873 .80398 L
.67651 .78803 L
.66638 .77284 L
.65686 .75841 L
.64791 .74468 L
.6395 .73165 L
.63159 .71927 L
.62414 .70752 L
.61712 .69638 L
.61052 .68581 L
.6043 .67578 L
.59844 .66629 L
.59292 .65729 L
.58772 .64876 L
.58281 .64068 L
.57818 .63304 L
.57382 .6258 L
.5697 .61894 L
.56582 .61246 L
.56216 .60632 L
.5587 .60051 L
.55544 .59502 L
.55236 .58982 L
.54945 .5849 L
.54671 .58025 L
.54412 .57585 L
.54168 .57169 L
.53937 .56776 L
.53719 .56404 L
.53513 .56053 L
.53319 .5572 L
.53135 .55406 L
.52962 .55109 L
.52798 .54828 L
.52643 .54563 L
.52497 .54312 L
.52359 .54075 L
.52229 .53851 L
.52106 .53639 L
.5199 .53439 L
Mistroke
.5188 .53249 L
.51776 .53071 L
.51678 .52901 L
.51585 .52742 L
.51498 .52591 L
.51415 .52448 L
.51337 .52313 L
.51263 .52186 L
.51194 .52066 L
.51128 .51952 L
.51066 .51844 L
.51007 .51743 L
.50951 .51647 L
.50899 .51556 L
.50849 .5147 L
.50802 .51389 L
.50758 .51313 L
.50716 .5124 L
.50677 .51172 L
.5064 .51107 L
.50604 .51046 L
.50571 .50989 L
.5054 .50934 L
.5051 .50883 L
.50482 .50834 L
.50455 .50788 L
.5043 .50745 L
.50406 .50704 L
.50384 .50665 L
.50363 .50628 L
.50343 .50594 L
.50324 .50561 L
.50306 .5053 L
.50289 .50501 L
.50273 .50473 L
.50258 .50447 L
.50244 .50422 L
.5023 .50399 L
.50218 .50377 L
.50206 .50356 L
.50194 .50337 L
.50184 .50318 L
.50174 .50301 L
.50164 .50284 L
.50155 .50268 L
.50146 .50254 L
.50138 .5024 L
.50131 .50226 L
.50124 .50214 L
.50117 .50202 L
Mistroke
.5011 .50191 L
.50104 .5018 L
.50098 .50171 L
.50093 .50161 L
.50088 .50152 L
.50083 .50144 L
.50078 .50136 L
.50074 .50128 L
.5007 .50121 L
.50066 .50115 L
.50063 .50108 L
.50059 .50102 L
.50056 .50097 L
.50053 .50091 L
.5005 .50086 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50035 .50061 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
Mistroke
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
Mfstroke
1 0 0 r
% Start of user PostScript
8.7718811 -1.5957043 7.9084609 -0.84973624 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
7.1433531 -0.23273599 6.4643674 0.2741338 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.3828961 1.8536651 3.1057858 1.9084828 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.7820836 1.8137516 1.6550495 1.7636641 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
1.0155424 1.3544721 0.95041136 1.2956653 MAarrowhead1
% End of user PostScript
.581 1 0 r
.80407 .96239 m
.78585 .93942 L
s
% Start of user PostScript
0.60813603 0.92478266 0.57170617 0.87884527 MAarrowhead1
% End of user PostScript
.266 1 0 r
.6873 .80398 m
.67651 .78803 L
s
% Start of user PostScript
0.37459138 0.6079645 0.35301913 0.5760536 MAarrowhead1
% End of user PostScript
0 1 .049 r
.61712 .69638 m
.61052 .68581 L
s
% Start of user PostScript
0.23424953 0.39275197 0.22104367 0.37161169 MAarrowhead1
% End of user PostScript
0 1 .364 r
.57382 .6258 m
.5697 .61894 L
s
% Start of user PostScript
0.14763892 0.25159336 0.13940754 0.23788686 MAarrowhead1
% End of user PostScript
0 1 .679 r
.54671 .58025 m
.54412 .57585 L
s
% Start of user PostScript
0.093423264 0.16050309 0.088243992 0.15170732 MAarrowhead1
% End of user PostScript
0 1 .995 r
.52962 .55109 m
.52798 .54828 L
s
% Start of user PostScript
0.059235681 0.10218269 0.055961108 0.096566567 MAarrowhead1
% End of user PostScript
0 .69 1 r
.5188 .53249 m
.51776 .53071 L
s
% Start of user PostScript
0.037596807 0.064987219 0.035521427 0.061410226 MAarrowhead1
% End of user PostScript
0 .375 1 r
.51194 .52066 m
.51128 .51952 L
s
% Start of user PostScript
0.023874744 0.041310209 0.022557785 0.039034785 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50758 .51313 m
.50716 .5124 L
s
% Start of user PostScript
0.015164802 0.026252842 0.014328596 0.024806275 MAarrowhead1
% End of user PostScript
.337 1 0 r
1 .24672 m
.97958 .26961 L
.92914 .32389 L
.88468 .36963 L
.84545 .40804 L
.81079 .44016 L
.78012 .46691 L
.75295 .48904 L
.72885 .50725 L
.70743 .5221 L
.68837 .5341 L
.67137 .54367 L
.6562 .55118 L
.64262 .55696 L
.63046 .56127 L
.61954 .56435 L
.60972 .56639 L
.60088 .56758 L
.59289 .56805 L
.58567 .56794 L
.57913 .56735 L
.57319 .56637 L
.56779 .56508 L
.56287 .56354 L
.55838 .56182 L
.55427 .55995 L
.55051 .55798 L
.54706 .55594 L
.54388 .55386 L
.54096 .55176 L
.53827 .54966 L
.53579 .54757 L
.53349 .54551 L
.53136 .54349 L
.52939 .54152 L
.52755 .5396 L
.52585 .53774 L
.52427 .53593 L
.52279 .53419 L
.52141 .53251 L
.52013 .5309 L
.51893 .52935 L
.51781 .52787 L
.51676 .52645 L
.51578 .52509 L
.51486 .5238 L
.514 .52256 L
.51319 .52138 L
.51243 .52026 L
.51171 .51919 L
Mistroke
.51104 .51818 L
.51041 .51721 L
.50982 .5163 L
.50926 .51543 L
.50874 .5146 L
.50824 .51382 L
.50778 .51307 L
.50734 .51237 L
.50693 .5117 L
.50654 .51107 L
.50617 .51047 L
.50583 .5099 L
.5055 .50936 L
.5052 .50885 L
.50491 .50837 L
.50463 .50791 L
.50437 .50748 L
.50413 .50707 L
.5039 .50669 L
.50369 .50632 L
.50348 .50597 L
.50329 .50565 L
.50311 .50534 L
.50293 .50505 L
.50277 .50477 L
.50262 .50451 L
.50247 .50426 L
.50234 .50403 L
.50221 .5038 L
.50208 .5036 L
.50197 .5034 L
.50186 .50321 L
.50176 .50303 L
.50166 .50287 L
.50157 .50271 L
.50148 .50256 L
.5014 .50242 L
.50132 .50229 L
.50125 .50216 L
.50118 .50204 L
.50112 .50193 L
.50105 .50182 L
.501 .50172 L
.50094 .50163 L
.50089 .50154 L
.50084 .50145 L
.50079 .50137 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
Mistroke
.50063 .50109 L
.5006 .50103 L
.50056 .50098 L
.50053 .50092 L
.5005 .50087 L
.50048 .50082 L
.50045 .50078 L
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50055 L
.5003 .50052 L
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .50039 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
Mistroke
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
Mfstroke
1 0 0 r
% Start of user PostScript
5.321293 -6.561468 4.6709468 -5.5813979 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
4.1041144 -4.7379104 3.6098289 -4.0124546 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.5215114 -1.1291748 1.3524603 -0.91939135 MAarrowhead1
% End of user PostScript
1 .788 0 r
.81079 .44016 m
.78012 .46691 L
s
% Start of user PostScript
0.62157464 -0.1196701 0.56024345 -0.066188535 MAarrowhead1
% End of user PostScript
.897 1 0 r
.64262 .55696 m
.63046 .56127 L
s
% Start of user PostScript
0.2852466 0.11391665 0.26092151 0.12253638 MAarrowhead1
% End of user PostScript
.581 1 0 r
.57319 .56637 m
.56779 .56508 L
s
% Start of user PostScript
0.14638013 0.13273707 0.13557798 0.13015496 MAarrowhead1
% End of user PostScript
.266 1 0 r
.54096 .55176 m
.53827 .54966 L
s
% Start of user PostScript
0.081927351 0.10351482 0.076542775 0.099313462 MAarrowhead1
% End of user PostScript
0 1 .049 r
.52427 .53593 m
.52279 .53419 L
s
% Start of user PostScript
0.048532857 0.071862763 0.045581632 0.068379692 MAarrowhead1
% End of user PostScript
0 1 .364 r
.51486 .5238 m
.514 .52256 L
s
% Start of user PostScript
0.02971673 0.047594466 0.027990989 0.045122925 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50926 .51543 m
.50874 .5146 L
s
% Start of user PostScript
0.018524958 0.030854337 0.017475964 0.029201884 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50583 .5099 m
.5055 .50936 L
s
% Start of user PostScript
0.01165678 0.01979869 0.011005386 0.018722702 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50369 .50632 m
.50348 .50597 L
s
% Start of user PostScript
0.0073701717 0.01264112 0.0069611034 0.0119492 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50234 .50403 m
.50221 .5038 L
s
% Start of user PostScript
0.0046711855 0.008051202 0.0044128092 0.0076089584 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50148 .50256 m
.5014 .50242 L
s
% Start of user PostScript
0.0029641825 0.0051215535 0.0028005087 0.0048397391 MAarrowhead1
% End of user PostScript
0 1 .314 r
.20691 0 m
.21008 .00528 L
.22622 .03226 L
.24146 .05779 L
.25584 .08194 L
.26941 .1048 L
.28221 .12642 L
.2943 .14687 L
.30571 .16621 L
.31648 .1845 L
.32665 .2018 L
.33625 .21815 L
.34532 .23362 L
.35388 .24824 L
.36196 .26207 L
.3696 .27514 L
.37681 .28749 L
.38362 .29917 L
.39005 .31021 L
.39613 .32065 L
.40186 .33051 L
.40729 .33984 L
.41241 .34865 L
.41724 .35698 L
.42181 .36485 L
.42613 .37229 L
.4302 .37932 L
.43406 .38596 L
.4377 .39224 L
.44113 .39817 L
.44438 .40378 L
.44745 .40908 L
.45035 .41409 L
.45309 .41882 L
.45567 .42329 L
.45812 .42752 L
.46043 .43151 L
.46261 .43528 L
.46467 .43885 L
.46662 .44222 L
.46846 .4454 L
.4702 .44841 L
.47184 .45125 L
.4734 .45394 L
.47486 .45648 L
.47625 .45888 L
.47756 .46114 L
.4788 .46328 L
.47997 .46531 L
.48107 .46722 L
Mistroke
.48211 .46903 L
.4831 .47073 L
.48403 .47235 L
.48491 .47387 L
.48574 .47531 L
.48653 .47667 L
.48727 .47796 L
.48797 .47917 L
.48864 .48032 L
.48926 .4814 L
.48985 .48243 L
.49041 .4834 L
.49094 .48431 L
.49144 .48518 L
.49191 .48599 L
.49236 .48677 L
.49278 .4875 L
.49318 .48819 L
.49355 .48884 L
.49391 .48945 L
.49425 .49003 L
.49456 .49058 L
.49486 .4911 L
.49515 .49159 L
.49541 .49206 L
.49567 .49249 L
.4959 .49291 L
.49613 .4933 L
.49634 .49367 L
.49655 .49402 L
.49674 .49435 L
.49692 .49466 L
.49709 .49495 L
.49725 .49523 L
.4974 .49549 L
.49754 .49574 L
.49768 .49598 L
.49781 .4962 L
.49793 .49641 L
.49804 .49661 L
.49815 .49679 L
.49825 .49697 L
.49835 .49714 L
.49844 .49729 L
.49852 .49744 L
.49861 .49758 L
.49868 .49772 L
.49876 .49784 L
.49882 .49796 L
.49889 .49807 L
Mistroke
.49895 .49818 L
.49901 .49828 L
.49906 .49838 L
.49911 .49847 L
.49916 .49855 L
.49921 .49863 L
.49925 .49871 L
.49929 .49878 L
.49933 .49884 L
.49937 .49891 L
.4994 .49897 L
.49944 .49903 L
.49947 .49908 L
.4995 .49913 L
.49953 .49918 L
.49955 .49922 L
.49958 .49927 L
.4996 .49931 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49945 L
.4997 .49948 L
.49971 .49951 L
.49973 .49953 L
.49975 .49956 L
.49976 .49958 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
Mistroke
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
Mfstroke
1 0 0 r
% Start of user PostScript
-7.4140394 -7.5410131 -6.8854286 -7.3330835 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-6.4019682 -7.1088804 -5.9590317 -6.8730036 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-3.7026169 -5.1484843 -3.4699077 -4.9142578 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-2.2364986 -3.4718587 -2.1041263 -3.2962358 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-1.3841033 -2.2696326 -1.30492 -2.1495326 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-0.86767354 -1.4622733 -0.81892796 -1.3832613 MAarrowhead1
% End of user PostScript
.266 1 0 r
.22622 .03226 m
.24146 .05779 L
s
% Start of user PostScript
-0.54755029 -0.93548915 -0.5170768 -0.88442919 MAarrowhead1
% End of user PostScript
0 1 .049 r
.32665 .2018 m
.33625 .21815 L
s
% Start of user PostScript
-0.34670019 -0.59640438 -0.32749689 -0.5636904 MAarrowhead1
% End of user PostScript
0 1 .364 r
.39005 .31021 m
.39613 .32065 L
s
% Start of user PostScript
-0.21989796 -0.3795722 -0.20774743 -0.35870072 MAarrowhead1
% End of user PostScript
0 1 .679 r
.4302 .37932 m
.43406 .38596 L
s
% Start of user PostScript
-0.13959131 -0.24136542 -0.13188749 -0.22807726 MAarrowhead1
% End of user PostScript
0 1 .995 r
.45567 .42329 m
.45812 .42752 L
s
% Start of user PostScript
-0.088650461 -0.1534156 -0.083760956 -0.14496429 MAarrowhead1
% End of user PostScript
0 .69 1 r
.47184 .45125 m
.4734 .45394 L
s
% Start of user PostScript
-0.056311419 -0.097492451 -0.053206514 -0.092120177 MAarrowhead1
% End of user PostScript
0 .375 1 r
.48211 .46903 m
.4831 .47073 L
s
% Start of user PostScript
-0.03577325 -0.061947808 -0.033801082 -0.058533684 MAarrowhead1
% End of user PostScript
0 .06 1 r
.48864 .48032 m
.48926 .4814 L
s
% Start of user PostScript
-0.022727077 -0.039360232 -0.021474235 -0.03719081 MAarrowhead1
% End of user PostScript
.614 1 0 r
.27737 0 m
.2826 .01778 L
.2922 .04851 L
.30158 .07698 L
.31072 .10341 L
.3196 .12796 L
.32819 .15081 L
.3365 .17208 L
.3445 .19191 L
.35219 .21041 L
.35958 .22769 L
.36666 .24384 L
.37344 .25894 L
.37992 .27309 L
.38611 .28634 L
.39202 .29876 L
.39765 .31041 L
.40301 .32134 L
.40812 .33161 L
.41297 .34125 L
.41759 .35032 L
.42197 .35884 L
.42614 .36686 L
.43009 .3744 L
.43384 .3815 L
.4374 .38818 L
.44078 .39448 L
.44397 .40041 L
.447 .406 L
.44988 .41127 L
.45259 .41624 L
.45517 .42092 L
.45761 .42533 L
.45992 .4295 L
.4621 .43343 L
.46417 .43713 L
.46613 .44063 L
.46798 .44393 L
.46973 .44704 L
.47139 .44998 L
.47295 .45276 L
.47444 .45538 L
.47584 .45785 L
.47716 .46019 L
.47841 .46239 L
.4796 .46447 L
.48072 .46644 L
.48178 .46829 L
.48278 .47005 L
.48373 .4717 L
Mistroke
.48462 .47327 L
.48547 .47475 L
.48627 .47614 L
.48702 .47746 L
.48774 .4787 L
.48841 .47988 L
.48905 .48099 L
.48965 .48204 L
.49022 .48303 L
.49076 .48397 L
.49127 .48485 L
.49175 .48569 L
.4922 .48648 L
.49263 .48722 L
.49304 .48793 L
.49342 .48859 L
.49378 .48922 L
.49413 .48982 L
.49445 .49038 L
.49476 .49091 L
.49504 .49141 L
.49532 .49189 L
.49558 .49233 L
.49582 .49276 L
.49605 .49315 L
.49627 .49353 L
.49647 .49389 L
.49667 .49423 L
.49685 .49454 L
.49702 .49484 L
.49719 .49513 L
.49734 .4954 L
.49749 .49565 L
.49763 .49589 L
.49776 .49612 L
.49788 .49633 L
.498 .49653 L
.49811 .49672 L
.49821 .49691 L
.49831 .49708 L
.49841 .49724 L
.49849 .49739 L
.49858 .49753 L
.49865 .49767 L
.49873 .4978 L
.4988 .49792 L
.49887 .49803 L
.49893 .49814 L
.49899 .49824 L
.49904 .49834 L
Mistroke
.4991 .49843 L
.49915 .49852 L
.49919 .4986 L
.49924 .49868 L
.49928 .49875 L
.49932 .49882 L
.49936 .49888 L
.49939 .49895 L
.49943 .499 L
.49946 .49906 L
.49949 .49911 L
.49952 .49916 L
.49954 .49921 L
.49957 .49925 L
.49959 .49929 L
.49961 .49933 L
.49963 .49937 L
.49965 .4994 L
.49967 .49944 L
.49969 .49947 L
.49971 .4995 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49982 .49968 L
.49983 .4997 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49988 .49978 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
Mistroke
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
1 0 0 r
% Start of user PostScript
-0.39389208 -4.9671669 -0.46913956 -4.5254317 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-0.52729455 -4.1304665 -0.57102742 -3.7766998 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-0.62994323 -2.11343 -0.61835336 -1.9568667 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.49395178 -1.180423 -0.47407574 -1.1026238 MAarrowhead1
% End of user PostScript
.897 1 0 r
.32819 .15081 m
.3365 .17208 L
s
% Start of user PostScript
-0.34361136 -0.69838914 -0.32700709 -0.65584688 MAarrowhead1
% End of user PostScript
.581 1 0 r
.38611 .28634 m
.39202 .29876 L
s
% Start of user PostScript
-0.22777529 -0.4273245 -0.21596235 -0.40248405 MAarrowhead1
% End of user PostScript
.266 1 0 r
.42614 .36686 m
.43009 .3744 L
s
% Start of user PostScript
-0.14772296 -0.26628866 -0.13981618 -0.2512019 MAarrowhead1
% End of user PostScript
0 1 .049 r
.45259 .41624 m
.45517 .42092 L
s
% Start of user PostScript
-0.094810491 -0.16752939 -0.089659375 -0.15816511 MAarrowhead1
% End of user PostScript
0 1 .364 r
.46973 .44704 m
.47139 .44998 L
s
% Start of user PostScript
-0.060540905 -0.10591265 -0.057227633 -0.10003335 MAarrowhead1
% End of user PostScript
0 1 .679 r
.48072 .46644 m
.48178 .46829 L
s
% Start of user PostScript
-0.038560765 -0.067123735 -0.036442815 -0.063410675 MAarrowhead1
% End of user PostScript
0 1 .995 r
.48774 .4787 m
.48841 .47988 L
s
% Start of user PostScript
-0.02452999 -0.042593495 -0.023180271 -0.04024152 MAarrowhead1
% End of user PostScript
0 .69 1 r
.4922 .48648 m
.49263 .48722 L
s
% Start of user PostScript
-0.01559471 -0.027044611 -0.014735873 -0.025552553 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49504 .49141 m
.49532 .49189 L
s
% Start of user PostScript
-0.0099110908 -0.017177248 -0.0093650214 -0.016229995 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49685 .49454 m
.49702 .49484 L
s
% Start of user PostScript
-0.006297929 -0.010911744 -0.0059508561 -0.010310141 MAarrowhead1
% End of user PostScript
.656 0 1 r
.77825 1 m
.76782 .98021 L
.75343 .9531 L
.73978 .92757 L
.72684 .90352 L
.71457 .88086 L
.70295 .85951 L
.69195 .83938 L
.68152 .8204 L
.67165 .8025 L
.66231 .78563 L
.65346 .7697 L
.64509 .75469 L
.63717 .74051 L
.62968 .72714 L
.62259 .71452 L
.61588 .70261 L
.60953 .69137 L
.60353 .68076 L
.59786 .67074 L
.59249 .66128 L
.58742 .65234 L
.58262 .64391 L
.57809 .63595 L
.5738 .62843 L
.56974 .62132 L
.56591 .61462 L
.56229 .60828 L
.55886 .6023 L
.55563 .59664 L
.55257 .59131 L
.54968 .58626 L
.54694 .5815 L
.54436 .577 L
.54192 .57275 L
.53961 .56873 L
.53743 .56494 L
.53537 .56136 L
.53342 .55797 L
.53158 .55477 L
.52984 .55175 L
.5282 .54889 L
.52665 .5462 L
.52518 .54365 L
.52379 .54124 L
.52248 .53897 L
.52124 .53682 L
.52007 .53479 L
.51897 .53287 L
.51792 .53106 L
Mistroke
.51693 .52934 L
.516 .52773 L
.51512 .5262 L
.51429 .52475 L
.5135 .52339 L
.51275 .5221 L
.51205 .52088 L
.51139 .51973 L
.51076 .51864 L
.51017 .51761 L
.50961 .51664 L
.50908 .51572 L
.50858 .51486 L
.5081 .51404 L
.50766 .51326 L
.50724 .51253 L
.50684 .51184 L
.50646 .51119 L
.5061 .51057 L
.50577 .50999 L
.50545 .50944 L
.50515 .50892 L
.50487 .50843 L
.5046 .50796 L
.50434 .50752 L
.5041 .50711 L
.50388 .50672 L
.50366 .50635 L
.50346 .506 L
.50327 .50567 L
.50309 .50535 L
.50292 .50506 L
.50276 .50478 L
.50261 .50452 L
.50246 .50427 L
.50233 .50403 L
.5022 .50381 L
.50208 .5036 L
.50196 .5034 L
.50186 .50321 L
.50175 .50304 L
.50166 .50287 L
.50157 .50271 L
.50148 .50256 L
.5014 .50242 L
.50132 .50229 L
.50125 .50216 L
.50118 .50204 L
.50111 .50193 L
.50105 .50182 L
Mistroke
.50099 .50172 L
.50094 .50163 L
.50089 .50154 L
.50084 .50145 L
.50079 .50137 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50063 .50109 L
.5006 .50103 L
.50056 .50098 L
.50053 .50092 L
.5005 .50087 L
.50048 .50082 L
.50045 .50078 L
.50042 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50055 L
.5003 .50052 L
.50029 .50049 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .50039 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
Mistroke
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
Mfstroke
1 0 0 r
% Start of user PostScript
2.4204613 7.395572 2.3595246 6.8623754 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
2.2922698 6.3753302 2.2203373 5.9296548 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.6768542 3.6686475 1.6017173 3.4364737 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.1354399 2.2094998 1.0783484 2.0781909 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
0.74365806 1.3652286 0.70441297 1.2869507 MAarrowhead1
% End of user PostScript
.581 1 0 r
.73978 .92757 m
.72684 .90352 L
s
% Start of user PostScript
0.47955308 0.85513463 0.45367443 0.80703731 MAarrowhead1
% End of user PostScript
.266 1 0 r
.65346 .7697 m
.64509 .75469 L
s
% Start of user PostScript
0.30692907 0.53940997 0.29018708 0.50937155 MAarrowhead1
% End of user PostScript
0 1 .049 r
.59786 .67074 m
.59249 .66128 L
s
% Start of user PostScript
0.19571975 0.34147306 0.18498746 0.32255355 MAarrowhead1
% End of user PostScript
0 1 .364 r
.56229 .60828 m
.55886 .6023 L
s
% Start of user PostScript
0.12457626 0.21655938 0.11772726 0.2045915 MAarrowhead1
% End of user PostScript
0 1 .679 r
.53961 .56873 m
.53743 .56494 L
s
% Start of user PostScript
0.079220833 0.13746459 0.074859736 0.12987756 MAarrowhead1
% End of user PostScript
0 1 .995 r
.52518 .54365 m
.52379 .54124 L
s
% Start of user PostScript
0.050355349 0.087297493 0.047581495 0.082482426 MAarrowhead1
% End of user PostScript
0 .69 1 r
.516 .52773 m
.51512 .5262 L
s
% Start of user PostScript
0.032000218 0.055451256 0.030236895 0.052393721 MAarrowhead1
% End of user PostScript
0 .375 1 r
.51017 .51761 m
.50961 .51664 L
s
% Start of user PostScript
0.020333438 0.035226573 0.019212814 0.033284523 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50646 .51119 m
.5061 .51057 L
s
% Start of user PostScript
0.012919449 0.022379692 0.01220737 0.021145994 MAarrowhead1
% End of user PostScript
.534 1 0 r
.79845 1 m
.79844 .99998 L
.78161 .97309 L
.76575 .94758 L
.75082 .92341 L
.73674 .9005 L
.72348 .8788 L
.71097 .85825 L
.69918 .83878 L
.68806 .82035 L
.67757 .8029 L
.66768 .78639 L
.65835 .77076 L
.64954 .75597 L
.64123 .74198 L
.63338 .72875 L
.62598 .71623 L
.61899 .70439 L
.61239 .69319 L
.60616 .6826 L
.60028 .67258 L
.59473 .66311 L
.58949 .65416 L
.58453 .64569 L
.57986 .63769 L
.57544 .63013 L
.57127 .62298 L
.56733 .61622 L
.56361 .60983 L
.5601 .60379 L
.55678 .59808 L
.55364 .59268 L
.55068 .58758 L
.54788 .58276 L
.54524 .57821 L
.54274 .5739 L
.54038 .56983 L
.53815 .56599 L
.53605 .56235 L
.53406 .55892 L
.53218 .55568 L
.53041 .55261 L
.52873 .54971 L
.52714 .54697 L
.52565 .54439 L
.52423 .54194 L
.5229 .53963 L
.52163 .53745 L
.52044 .53538 L
.51931 .53343 L
Mistroke
.51825 .53159 L
.51724 .52985 L
.51629 .52821 L
.51539 .52665 L
.51454 .52518 L
.51374 .5238 L
.51298 .52248 L
.51227 .52124 L
.51159 .52007 L
.51095 .51897 L
.51035 .51792 L
.50978 .51693 L
.50924 .516 L
.50873 .51512 L
.50825 .51429 L
.50779 .5135 L
.50736 .51275 L
.50696 .51205 L
.50658 .51139 L
.50621 .51076 L
.50587 .51017 L
.50555 .50961 L
.50524 .50908 L
.50495 .50858 L
.50468 .5081 L
.50442 .50766 L
.50418 .50724 L
.50395 .50684 L
.50373 .50646 L
.50352 .5061 L
.50333 .50577 L
.50315 .50545 L
.50297 .50515 L
.50281 .50486 L
.50265 .5046 L
.50251 .50434 L
.50237 .5041 L
.50224 .50388 L
.50212 .50366 L
.502 .50346 L
.50189 .50327 L
.50178 .50309 L
.50169 .50292 L
.50159 .50276 L
.50151 .50261 L
.50142 .50246 L
.50134 .50233 L
.50127 .5022 L
.5012 .50208 L
.50113 .50196 L
Mistroke
.50107 .50186 L
.50101 .50175 L
.50096 .50166 L
.5009 .50157 L
.50085 .50148 L
.50081 .5014 L
.50076 .50132 L
.50072 .50125 L
.50068 .50118 L
.50064 .50111 L
.50061 .50105 L
.50057 .50099 L
.50054 .50094 L
.50051 .50089 L
.50048 .50084 L
.50046 .50079 L
.50043 .50075 L
.50041 .50071 L
.50039 .50067 L
.50036 .50063 L
.50034 .5006 L
.50033 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50048 L
.50026 .50045 L
.50025 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50012 .50022 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50012 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
Mfstroke
1 0 0 r
% Start of user PostScript
5.7452884 4.8449529 5.3130579 4.7780184 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
4.9200783 4.6880553 4.5621266 4.5799 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.7744819 3.5872654 2.5939816 3.4372784 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.6510641 2.4725879 1.5512951 2.3514687 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
1.0135019 1.6324135 0.95485258 1.5472544 MAarrowhead1
% End of user PostScript
.581 1 0 r
.79845 1 m
.79844 .99998 L
s
% Start of user PostScript
0.63264359 1.0566771 0.59688683 0.99996384 MAarrowhead1
% End of user PostScript
.266 1 0 r
.69918 .83878 m
.68806 .82035 L
s
% Start of user PostScript
0.39836197 0.67756013 0.37612263 0.64069902 MAarrowhead1
% End of user PostScript
0 1 .049 r
.62598 .71623 m
.61899 .70439 L
s
% Start of user PostScript
0.25195773 0.43245585 0.23798016 0.40877304 MAarrowhead1
% End of user PostScript
0 1 .364 r
.57986 .63769 m
.57544 .63013 L
s
% Start of user PostScript
0.15971774 0.27538475 0.15088551 0.26025435 MAarrowhead1
% End of user PostScript
0 1 .679 r
.55068 .58758 m
.54788 .58276 L
s
% Start of user PostScript
0.10136059 0.17516304 0.09576444 0.16552345 MAarrowhead1
% End of user PostScript
0 1 .995 r
.53218 .55568 m
.53041 .55261 L
s
% Start of user PostScript
0.064362223 0.11135196 0.060811626 0.10521906 MAarrowhead1
% End of user PostScript
0 .69 1 r
.52044 .53538 m
.51931 .53343 L
s
% Start of user PostScript
0.040880492 0.070766833 0.038626195 0.066867651 MAarrowhead1
% End of user PostScript
0 .375 1 r
.51298 .52248 m
.51227 .52124 L
s
% Start of user PostScript
0.025969455 0.044967624 0.024537695 0.042489451 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50825 .51429 m
.50779 .5135 L
s
% Start of user PostScript
0.016498346 0.028571908 0.015588844 0.026997147 MAarrowhead1
% End of user PostScript
1 0 .258 r
.25281 0 m
.26075 .02031 L
.27246 .04931 L
.28372 .07637 L
.29453 .10164 L
.3049 .12527 L
.31482 .14737 L
.3243 .16805 L
.33336 .18743 L
.34201 .2056 L
.35025 .22264 L
.35809 .23863 L
.36556 .25365 L
.37267 .26776 L
.37942 .28102 L
.38584 .29349 L
.39193 .30521 L
.39772 .31625 L
.40321 .32664 L
.40841 .33642 L
.41335 .34563 L
.41803 .3543 L
.42246 .36248 L
.42666 .37019 L
.43064 .37745 L
.43441 .3843 L
.43798 .39076 L
.44136 .39685 L
.44455 .4026 L
.44758 .40802 L
.45044 .41314 L
.45315 .41797 L
.45571 .42252 L
.45814 .42682 L
.46043 .43088 L
.4626 .43472 L
.46465 .43833 L
.46659 .44175 L
.46842 .44498 L
.47015 .44802 L
.47179 .4509 L
.47334 .45361 L
.47481 .45618 L
.47619 .4586 L
.4775 .46089 L
.47874 .46305 L
.47991 .46509 L
.48101 .46702 L
.48206 .46884 L
.48304 .47056 L
Mistroke
.48398 .47219 L
.48486 .47372 L
.48569 .47517 L
.48648 .47654 L
.48722 .47784 L
.48793 .47906 L
.48859 .48022 L
.48922 .48131 L
.48981 .48234 L
.49038 .48331 L
.49091 .48423 L
.49141 .4851 L
.49188 .48592 L
.49233 .4867 L
.49275 .48743 L
.49315 .48813 L
.49353 .48878 L
.49388 .4894 L
.49422 .48999 L
.49454 .49054 L
.49484 .49106 L
.49512 .49155 L
.49539 .49202 L
.49565 .49246 L
.49589 .49287 L
.49611 .49327 L
.49633 .49364 L
.49653 .49399 L
.49672 .49432 L
.4969 .49463 L
.49707 .49493 L
.49723 .49521 L
.49739 .49547 L
.49753 .49572 L
.49767 .49596 L
.4978 .49618 L
.49792 .49639 L
.49803 .49659 L
.49814 .49678 L
.49824 .49696 L
.49834 .49712 L
.49843 .49728 L
.49852 .49743 L
.4986 .49757 L
.49868 .49771 L
.49875 .49783 L
.49882 .49795 L
.49888 .49807 L
.49894 .49817 L
.499 .49827 L
Mistroke
.49906 .49837 L
.49911 .49846 L
.49916 .49854 L
.49921 .49862 L
.49925 .4987 L
.49929 .49877 L
.49933 .49884 L
.49937 .4989 L
.4994 .49896 L
.49943 .49902 L
.49947 .49907 L
.4995 .49913 L
.49952 .49917 L
.49955 .49922 L
.49957 .49926 L
.4996 .4993 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49944 L
.4997 .49948 L
.49971 .4995 L
.49973 .49953 L
.49974 .49956 L
.49976 .49958 L
.49977 .4996 L
.49978 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
Mistroke
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
Mfstroke
1 0 0 r
% Start of user PostScript
-0.052996537 -9.7059933 -0.26762548 -8.7941782 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-0.44137932 -7.9829302 -0.58038878 -7.2599894 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-0.94216998 -3.9257292 -0.94214143 -3.6194356 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.80888694 -2.1299603 -0.7807942 -1.9839854 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-0.58074448 -1.2375141 -0.55397452 -1.1602222 MAarrowhead1
% End of user PostScript
.581 1 0 r
.3049 .12527 m
.31482 .14737 L
s
% Start of user PostScript
-0.390207 -0.74946632 -0.37036388 -0.70526985 MAarrowhead1
% End of user PostScript
.266 1 0 r
.37267 .26776 m
.37942 .28102 L
s
% Start of user PostScript
-0.25466332 -0.46448062 -0.24115524 -0.43796109 MAarrowhead1
% End of user PostScript
0 1 .049 r
.41803 .3543 m
.42246 .36248 L
s
% Start of user PostScript
-0.16394296 -0.29139056 -0.1550744 -0.27503741 MAarrowhead1
% End of user PostScript
0 1 .364 r
.44758 .40802 m
.45044 .41314 L
s
% Start of user PostScript
-0.10484147 -0.18395279 -0.099115918 -0.17372049 MAarrowhead1
% End of user PostScript
0 1 .679 r
.46659 .44175 m
.46842 .44498 L
s
% Start of user PostScript
-0.066826859 -0.11649811 -0.06316026 -0.11004717 MAarrowhead1
% End of user PostScript
0 1 .995 r
.47874 .46305 m
.47991 .46509 L
s
% Start of user PostScript
-0.042526806 -0.073897109 -0.04018807 -0.069814455 MAarrowhead1
% End of user PostScript
0 .69 1 r
.48648 .47654 m
.48722 .47784 L
s
% Start of user PostScript
-0.027040986 -0.046912158 -0.025552167 -0.044323328 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49141 .4851 m
.49188 .48592 L
s
% Start of user PostScript
-0.017187257 -0.029793289 -0.016240418 -0.0281501 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49454 .49054 m
.49484 .49106 L
s
% Start of user PostScript
-0.010922016 -0.018925141 -0.010320154 -0.017881663 MAarrowhead1
% End of user PostScript
0 .347 1 r
.17365 0 m
.1877 .01792 L
.20625 .04219 L
.22359 .06542 L
.23983 .08765 L
.25504 .10888 L
.26929 .12914 L
.28266 .14845 L
.2952 .16685 L
.30698 .18437 L
.31804 .20104 L
.32844 .21688 L
.33821 .23194 L
.3474 .24624 L
.35605 .25981 L
.36419 .27269 L
.37186 .28491 L
.37908 .2965 L
.38588 .30748 L
.39229 .31789 L
.39832 .32776 L
.40402 .3371 L
.40938 .34595 L
.41444 .35432 L
.41922 .36226 L
.42372 .36976 L
.42797 .37687 L
.43197 .38359 L
.43575 .38995 L
.43932 .39597 L
.44269 .40166 L
.44587 .40705 L
.44887 .41214 L
.45171 .41696 L
.45438 .42151 L
.45691 .42582 L
.45929 .42989 L
.46155 .43374 L
.46367 .43738 L
.46568 .44082 L
.46758 .44407 L
.46937 .44714 L
.47107 .45005 L
.47266 .4528 L
.47417 .45539 L
.4756 .45785 L
.47695 .46017 L
.47822 .46236 L
.47942 .46443 L
.48056 .46639 L
Mistroke
.48163 .46824 L
.48265 .46999 L
.4836 .47164 L
.48451 .4732 L
.48536 .47468 L
.48617 .47607 L
.48693 .47739 L
.48765 .47863 L
.48833 .47981 L
.48898 .48092 L
.48959 .48197 L
.49016 .48297 L
.4907 .48391 L
.49122 .48479 L
.4917 .48563 L
.49216 .48642 L
.49259 .48717 L
.493 .48788 L
.49338 .48855 L
.49375 .48918 L
.49409 .48977 L
.49442 .49034 L
.49473 .49087 L
.49502 .49137 L
.49529 .49185 L
.49555 .4923 L
.4958 .49272 L
.49603 .49312 L
.49625 .4935 L
.49645 .49386 L
.49665 .4942 L
.49683 .49452 L
.49701 .49482 L
.49717 .49511 L
.49733 .49538 L
.49748 .49563 L
.49762 .49587 L
.49775 .4961 L
.49787 .49631 L
.49799 .49652 L
.4981 .49671 L
.4982 .49689 L
.4983 .49706 L
.4984 .49722 L
.49849 .49738 L
.49857 .49752 L
.49865 .49766 L
.49872 .49779 L
.49879 .49791 L
.49886 .49802 L
Mistroke
.49892 .49813 L
.49898 .49824 L
.49904 .49833 L
.49909 .49843 L
.49914 .49851 L
.49919 .49859 L
.49923 .49867 L
.49928 .49874 L
.49932 .49881 L
.49935 .49888 L
.49939 .49894 L
.49942 .499 L
.49945 .49905 L
.49948 .49911 L
.49951 .49916 L
.49954 .4992 L
.49956 .49925 L
.49959 .49929 L
.49961 .49933 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .4997 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49988 .49978 L
.49988 .4998 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
Mistroke
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
Mfstroke
1 0 0 r
% Start of user PostScript
-5.7372754 -1.2731899 -5.2249788 -1.5425794 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-4.7670948 -1.7517848 -4.3571296 -1.9101763 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.4323967 -2.1458843 -2.2515443 -2.1086179 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.3559031 -1.6916034 -1.2662999 -1.6241054 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-0.80124427 -1.1790523 -0.75235519 -1.1222427 MAarrowhead1
% End of user PostScript
.581 1 0 r
.25504 .10888 m
.26929 .12914 L
s
% Start of user PostScript
-0.48992882 -0.78224806 -0.46142231 -0.74172933 MAarrowhead1
% End of user PostScript
.266 1 0 r
.3474 .24624 m
.35605 .25981 L
s
% Start of user PostScript
-0.30519193 -0.50752874 -0.28789237 -0.48037925 MAarrowhead1
% End of user PostScript
0 1 .049 r
.40402 .3371 m
.40938 .34595 L
s
% Start of user PostScript
-0.19196923 -0.32580201 -0.18123606 -0.30810591 MAarrowhead1
% End of user PostScript
0 1 .364 r
.43932 .39597 m
.44269 .40166 L
s
% Start of user PostScript
-0.12135228 -0.20805972 -0.11461502 -0.19667462 MAarrowhead1
% End of user PostScript
0 1 .679 r
.46155 .43374 m
.46367 .43738 L
s
% Start of user PostScript
-0.07690522 -0.13252733 -0.072650797 -0.12524876 MAarrowhead1
% End of user PostScript
0 1 .995 r
.4756 .45785 m
.47695 .46017 L
s
% Start of user PostScript
-0.048799204 -0.084307752 -0.046104464 -0.079669023 MAarrowhead1
% End of user PostScript
0 .69 1 r
.48451 .4732 m
.48536 .47468 L
s
% Start of user PostScript
-0.030984541 -0.053598494 -0.029275087 -0.050646752 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49016 .48297 m
.4907 .48391 L
s
% Start of user PostScript
-0.019679558 -0.034064288 -0.018594304 -0.032187471 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49375 .48918 m
.49409 .48977 L
s
% Start of user PostScript
-0.012501285 -0.021645963 -0.011812042 -0.020453079 MAarrowhead1
% End of user PostScript
0 1 .016 r
.17804 0 m
.18018 .00278 L
.19909 .02796 L
.21679 .05206 L
.23336 .07508 L
.2489 .09705 L
.26346 .11801 L
.27713 .13798 L
.28996 .157 L
.302 .17509 L
.31333 .19229 L
.32397 .20864 L
.33398 .22417 L
.34339 .23891 L
.35226 .25291 L
.3606 .26618 L
.36846 .27877 L
.37586 .29071 L
.38283 .30202 L
.3894 .31274 L
.39559 .32289 L
.40143 .33251 L
.40694 .34161 L
.41213 .35023 L
.41703 .35839 L
.42165 .36612 L
.42601 .37343 L
.43013 .38034 L
.43401 .38688 L
.43767 .39307 L
.44113 .39893 L
.4444 .40446 L
.44748 .4097 L
.45039 .41465 L
.45314 .41933 L
.45573 .42376 L
.45818 .42794 L
.46049 .4319 L
.46268 .43564 L
.46474 .43918 L
.46669 .44252 L
.46853 .44568 L
.47027 .44867 L
.47191 .45149 L
.47347 .45416 L
.47493 .45668 L
.47631 .45907 L
.47762 .46132 L
.47886 .46345 L
.48002 .46546 L
Mistroke
.48113 .46736 L
.48217 .46916 L
.48315 .47086 L
.48408 .47246 L
.48496 .47398 L
.48579 .47541 L
.48657 .47677 L
.48731 .47805 L
.48801 .47926 L
.48867 .4804 L
.4893 .48148 L
.48989 .4825 L
.49045 .48346 L
.49097 .48437 L
.49147 .48524 L
.49194 .48605 L
.49239 .48682 L
.49281 .48754 L
.4932 .48823 L
.49358 .48888 L
.49393 .48949 L
.49427 .49007 L
.49458 .49062 L
.49488 .49114 L
.49516 .49162 L
.49543 .49209 L
.49568 .49252 L
.49592 .49293 L
.49614 .49332 L
.49636 .49369 L
.49656 .49404 L
.49675 .49437 L
.49693 .49468 L
.4971 .49497 L
.49726 .49525 L
.49741 .49551 L
.49755 .49576 L
.49769 .49599 L
.49781 .49621 L
.49793 .49642 L
.49805 .49662 L
.49816 .4968 L
.49826 .49698 L
.49835 .49715 L
.49844 .4973 L
.49853 .49745 L
.49861 .49759 L
.49869 .49773 L
.49876 .49785 L
.49883 .49797 L
Mistroke
.49889 .49808 L
.49895 .49819 L
.49901 .49829 L
.49907 .49838 L
.49912 .49847 L
.49917 .49856 L
.49921 .49864 L
.49926 .49871 L
.4993 .49878 L
.49934 .49885 L
.49937 .49891 L
.49941 .49897 L
.49944 .49903 L
.49947 .49908 L
.4995 .49913 L
.49953 .49918 L
.49955 .49923 L
.49958 .49927 L
.4996 .49931 L
.49962 .49935 L
.49964 .49938 L
.49966 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
Mistroke
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .4999 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
Mfstroke
1 0 0 r
% Start of user PostScript
-3.3869932 -2.3309664 -3.1202969 -2.3410459 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-2.8789819 -2.3320704 -2.6602232 -2.30756 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.5857959 -1.9031527 -1.4792974 -1.8313087 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.93019538 -1.3430937 -0.87285631 -1.2795663 MAarrowhead1
% End of user PostScript
.897 1 0 r
.21679 .05206 m
.23336 .07508 L
s
% Start of user PostScript
-0.56642 -0.89588787 -0.53327072 -0.84984382 MAarrowhead1
% End of user PostScript
.581 1 0 r
.32397 .20864 m
.33398 .22417 L
s
% Start of user PostScript
-0.35206232 -0.5827216 -0.33204368 -0.5516621 MAarrowhead1
% End of user PostScript
.266 1 0 r
.3894 .31274 m
.39559 .32289 L
s
% Start of user PostScript
-0.22119898 -0.37452625 -0.20881156 -0.35421899 MAarrowhead1
% End of user PostScript
0 1 .049 r
.43013 .38034 m
.43401 .38688 L
s
% Start of user PostScript
-0.13974874 -0.23931853 -0.13198375 -0.22623411 MAarrowhead1
% End of user PostScript
0 1 .364 r
.45573 .42376 m
.45818 .42794 L
s
% Start of user PostScript
-0.08853784 -0.15248343 -0.083637864 -0.14411239 MAarrowhead1
% End of user PostScript
0 1 .679 r
.47191 .45149 m
.47347 .45416 L
s
% Start of user PostScript
-0.056172293 -0.097017245 -0.053069757 -0.091680345 MAarrowhead1
% End of user PostScript
0 1 .995 r
.48217 .46916 m
.48315 .47086 L
s
% Start of user PostScript
-0.035663385 -0.061683081 -0.033695587 -0.058286467 MAarrowhead1
% End of user PostScript
0 .69 1 r
.48867 .4804 m
.4893 .48148 L
s
% Start of user PostScript
-0.022650451 -0.039203858 -0.021401297 -0.037043983 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49281 .48754 m
.4932 .48823 L
s
% Start of user PostScript
-0.014388256 -0.024912333 -0.013594956 -0.02353948 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49543 .49209 m
.49568 .49252 L
s
% Start of user PostScript
-0.0091406698 -0.01582929 -0.0086367604 -0.014956869 MAarrowhead1
% End of user PostScript
.83 1 0 r
.78502 1 m
.77992 .99087 L
.76462 .96358 L
.75016 .93782 L
.73647 .91351 L
.72352 .89056 L
.71128 .8689 L
.6997 .84845 L
.68875 .82914 L
.6784 .81091 L
.66861 .7937 L
.65935 .77745 L
.6506 .7621 L
.64233 .7476 L
.63451 .73391 L
.62711 .72098 L
.62012 .70877 L
.61352 .69723 L
.60728 .68634 L
.60137 .67604 L
.5958 .66632 L
.59053 .65714 L
.58554 .64846 L
.58084 .64027 L
.57639 .63253 L
.57218 .62521 L
.56821 .6183 L
.56445 .61178 L
.5609 .60561 L
.55755 .59978 L
.55438 .59428 L
.55138 .58908 L
.54855 .58416 L
.54588 .57952 L
.54335 .57514 L
.54096 .57099 L
.5387 .56708 L
.53657 .56338 L
.53456 .55988 L
.53265 .55658 L
.53085 .55346 L
.52915 .55051 L
.52755 .54773 L
.52603 .5451 L
.52459 .54261 L
.52324 .54026 L
.52196 .53804 L
.52075 .53594 L
.5196 .53396 L
.51852 .53209 L
Mistroke
.5175 .53032 L
.51654 .52865 L
.51563 .52707 L
.51477 .52558 L
.51395 .52417 L
.51318 .52284 L
.51246 .52158 L
.51177 .52039 L
.51112 .51926 L
.51051 .5182 L
.50993 .5172 L
.50938 .51625 L
.50886 .51535 L
.50838 .51451 L
.50791 .51371 L
.50748 .51295 L
.50707 .51224 L
.50668 .51156 L
.50631 .51093 L
.50596 .51032 L
.50563 .50976 L
.50532 .50922 L
.50503 .50871 L
.50475 .50823 L
.50449 .50778 L
.50424 .50735 L
.50401 .50694 L
.50379 .50656 L
.50358 .5062 L
.50338 .50586 L
.50319 .50553 L
.50302 .50523 L
.50285 .50494 L
.5027 .50467 L
.50255 .50441 L
.50241 .50417 L
.50227 .50394 L
.50215 .50372 L
.50203 .50352 L
.50192 .50332 L
.50181 .50314 L
.50171 .50297 L
.50162 .5028 L
.50153 .50265 L
.50144 .5025 L
.50136 .50236 L
.50129 .50223 L
.50122 .50211 L
.50115 .50199 L
.50109 .50188 L
Mistroke
.50103 .50178 L
.50097 .50168 L
.50092 .50159 L
.50087 .5015 L
.50082 .50142 L
.50077 .50134 L
.50073 .50127 L
.50069 .5012 L
.50065 .50113 L
.50062 .50107 L
.50058 .50101 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .5008 L
.50044 .50076 L
.50041 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .50061 L
.50033 .50057 L
.50031 .50054 L
.5003 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50039 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50018 L
.5001 .50017 L
.5001 .50016 L
.50009 .50016 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
Mfstroke
1 0 0 r
% Start of user PostScript
3.1149483 6.5808025 2.970075 6.1715948 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
2.8296057 5.7911466 2.6937759 5.4370445 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.8793723 3.5380284 1.7821794 3.3319216 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.2199774 2.2029489 1.1547646 2.0779966 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
0.78334466 1.3853563 0.74081201 1.3078742 MAarrowhead1
% End of user PostScript
.581 1 0 r
.75016 .93782 m
.73647 .91351 L
s
% Start of user PostScript
0.5003113 0.87564139 0.47293887 0.82701914 MAarrowhead1
% End of user PostScript
.266 1 0 r
.65935 .77745 m
.6506 .7621 L
s
% Start of user PostScript
0.31870152 0.55489162 0.30119955 0.52419222 MAarrowhead1
% End of user PostScript
0 1 .049 r
.60137 .67604 m
.5958 .66632 L
s
% Start of user PostScript
0.20274929 0.35208866 0.19159423 0.33264515 MAarrowhead1
% End of user PostScript
0 1 .364 r
.56445 .61178 m
.5609 .60561 L
s
% Start of user PostScript
0.12889943 0.22355162 0.12180091 0.21121775 MAarrowhead1
% End of user PostScript
0 1 .679 r
.54096 .57099 m
.5387 .56708 L
s
% Start of user PostScript
0.081922085 0.14198577 0.077408527 0.1341557 MAarrowhead1
% End of user PostScript
0 1 .995 r
.52603 .5451 m
.52459 .54261 L
s
% Start of user PostScript
0.052057131 0.090195008 0.049188339 0.085222188 MAarrowhead1
% End of user PostScript
0 .69 1 r
.51654 .52865 m
.51563 .52707 L
s
% Start of user PostScript
0.033076844 0.057300121 0.031253817 0.054141297 MAarrowhead1
% End of user PostScript
0 .375 1 r
.51051 .5182 m
.50993 .5172 L
s
% Start of user PostScript
0.021016007 0.036403762 0.019857645 0.034397023 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50668 .51156 m
.50631 .51093 L
s
% Start of user PostScript
0.013352651 0.023128414 0.012616657 0.021853509 MAarrowhead1
% End of user PostScript
.432 1 0 r
.22321 0 m
.23671 .02592 L
.25082 .05276 L
.2642 .07802 L
.27689 .10181 L
.28892 .12422 L
.30033 .14534 L
.31113 .16523 L
.32137 .18398 L
.33107 .20166 L
.34025 .21833 L
.34894 .23405 L
.35717 .24888 L
.36496 .26287 L
.37233 .27607 L
.3793 .28852 L
.3859 .30027 L
.39214 .31136 L
.39805 .32183 L
.40363 .33172 L
.40891 .34105 L
.41391 .34985 L
.41863 .35817 L
.42309 .36602 L
.42732 .37344 L
.43131 .38044 L
.43508 .38705 L
.43865 .3933 L
.44202 .3992 L
.44521 .40477 L
.44822 .41003 L
.45107 .415 L
.45376 .4197 L
.4563 .42413 L
.45871 .42832 L
.46098 .43228 L
.46313 .43602 L
.46516 .43955 L
.46708 .44288 L
.46889 .44604 L
.4706 .44901 L
.47222 .45183 L
.47375 .45448 L
.4752 .45699 L
.47656 .45937 L
.47785 .46161 L
.47907 .46373 L
.48023 .46573 L
.48132 .46762 L
.48235 .4694 L
Mistroke
.48332 .47109 L
.48424 .47268 L
.48511 .47419 L
.48593 .47561 L
.4867 .47696 L
.48743 .47823 L
.48813 .47943 L
.48878 .48056 L
.4894 .48163 L
.48998 .48265 L
.49054 .4836 L
.49106 .48451 L
.49155 .48536 L
.49202 .48617 L
.49246 .48693 L
.49287 .48765 L
.49326 .48833 L
.49364 .48898 L
.49399 .48958 L
.49432 .49016 L
.49463 .4907 L
.49493 .49121 L
.49521 .4917 L
.49547 .49215 L
.49572 .49259 L
.49596 .493 L
.49618 .49338 L
.49639 .49375 L
.49659 .49409 L
.49678 .49442 L
.49695 .49473 L
.49712 .49502 L
.49728 .49529 L
.49743 .49555 L
.49757 .4958 L
.49771 .49603 L
.49783 .49625 L
.49795 .49645 L
.49807 .49665 L
.49817 .49683 L
.49827 .49701 L
.49837 .49717 L
.49846 .49733 L
.49854 .49748 L
.49862 .49762 L
.4987 .49775 L
.49877 .49787 L
.49884 .49799 L
.4989 .4981 L
.49896 .4982 L
Mistroke
.49902 .4983 L
.49907 .4984 L
.49913 .49848 L
.49917 .49857 L
.49922 .49865 L
.49926 .49872 L
.4993 .49879 L
.49934 .49886 L
.49938 .49892 L
.49941 .49898 L
.49944 .49904 L
.49947 .49909 L
.4995 .49914 L
.49953 .49919 L
.49956 .49923 L
.49958 .49927 L
.4996 .49931 L
.49963 .49935 L
.49965 .49939 L
.49967 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49978 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
Mistroke
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
Mfstroke
1 0 0 r
% Start of user PostScript
-1.9828556 -5.1638712 -1.9126924 -4.8114492 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-1.8411719 -4.4875026 -1.7690665 -4.1892537 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.2888147 -2.6449238 -1.2271106 -2.48296 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.85666728 -1.6149154 -0.81241373 -1.52076 MAarrowhead1
% End of user PostScript
.897 1 0 r
.22321 0 m
.23671 .02592 L
s
% Start of user PostScript
-0.55629845 -1.0052052 -0.52657742 -0.94816389 MAarrowhead1
% End of user PostScript
.581 1 0 r
.32137 .18398 m
.33107 .20166 L
s
% Start of user PostScript
-0.35726035 -0.63203416 -0.33786731 -0.59667665 MAarrowhead1
% End of user PostScript
.266 1 0 r
.3859 .30027 m
.39214 .31136 L
s
% Start of user PostScript
-0.22819682 -0.39945618 -0.21571353 -0.37727272 MAarrowhead1
% End of user PostScript
0 1 .049 r
.42732 .37344 m
.43131 .38044 L
s
% Start of user PostScript
-0.14536905 -0.25312368 -0.13738638 -0.23911877 MAarrowhead1
% End of user PostScript
0 1 .364 r
.45376 .4197 m
.4563 .42413 L
s
% Start of user PostScript
-0.092481826 -0.16060812 -0.087393722 -0.15173854 MAarrowhead1
% End of user PostScript
0 1 .679 r
.4706 .44901 m
.47222 .45183 L
s
% Start of user PostScript
-0.058796658 -0.10197382 -0.055558765 -0.096347599 MAarrowhead1
% End of user PostScript
0 1 .995 r
.48132 .46762 m
.48235 .4694 L
s
% Start of user PostScript
-0.037368439 -0.064766942 -0.035309613 -0.061195222 MAarrowhead1
% End of user PostScript
0 .69 1 r
.48813 .47943 m
.48878 .48056 L
s
% Start of user PostScript
-0.02374572 -0.041142428 -0.022437133 -0.038874069 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49246 .48693 m
.49287 .48765 L
s
% Start of user PostScript
-0.015087933 -0.0261374 -0.014256365 -0.024696502 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49521 .4917 m
.49547 .49215 L
s
% Start of user PostScript
-0.0095864142 -0.016605533 -0.0090580297 -0.015690161 MAarrowhead1
% End of user PostScript
1 .237 0 r
1 .1627 m
.94895 .2241 L
.90037 .2806 L
.85764 .32847 L
.82003 .36893 L
.78688 .40301 L
.75763 .43163 L
.73178 .45557 L
.70892 .4755 L
.68866 .49199 L
.67068 .50555 L
.65471 .51661 L
.6405 .52555 L
.62782 .53268 L
.61651 .53827 L
.60639 .54257 L
.59732 .54578 L
.58917 .54807 L
.58185 .54959 L
.57525 .55047 L
.5693 .55082 L
.56391 .55073 L
.55903 .55028 L
.5546 .54955 L
.55057 .54858 L
.5469 .54743 L
.54355 .54614 L
.54049 .54475 L
.53768 .54327 L
.53511 .54175 L
.53274 .5402 L
.53056 .53863 L
.52855 .53706 L
.5267 .5355 L
.52499 .53397 L
.5234 .53246 L
.52193 .53099 L
.52056 .52955 L
.51929 .52816 L
.51811 .52681 L
.51701 .52551 L
.51598 .52426 L
.51502 .52306 L
.51413 .5219 L
.51329 .5208 L
.51251 .51974 L
.51177 .51873 L
.51109 .51776 L
.51044 .51684 L
.50984 .51596 L
Mistroke
.50927 .51512 L
.50874 .51432 L
.50824 .51357 L
.50777 .51285 L
.50733 .51216 L
.50691 .51151 L
.50652 .5109 L
.50615 .51031 L
.5058 .50976 L
.50548 .50923 L
.50517 .50873 L
.50488 .50826 L
.50461 .50781 L
.50435 .50739 L
.50411 .50699 L
.50388 .50661 L
.50366 .50625 L
.50346 .50591 L
.50326 .50558 L
.50308 .50528 L
.50291 .50499 L
.50275 .50472 L
.5026 .50446 L
.50245 .50421 L
.50232 .50398 L
.50219 .50376 L
.50207 .50356 L
.50195 .50336 L
.50184 .50318 L
.50174 .503 L
.50165 .50284 L
.50156 .50268 L
.50147 .50254 L
.50139 .5024 L
.50131 .50226 L
.50124 .50214 L
.50117 .50202 L
.50111 .50191 L
.50104 .50181 L
.50099 .50171 L
.50093 .50161 L
.50088 .50152 L
.50083 .50144 L
.50079 .50136 L
.50074 .50129 L
.5007 .50121 L
.50066 .50115 L
.50063 .50108 L
.50059 .50102 L
.50056 .50097 L
Mistroke
.50053 .50092 L
.5005 .50086 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50036 .50062 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
Mistroke
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
Mfstroke
1 0 0 r
% Start of user PostScript
5.8971935 -7.865475 5.1630246 -6.7233241 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
4.5239428 -5.7387326 3.9674149 -4.8903854 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.6298353 -1.4906641 1.442388 -1.2394336 MAarrowhead1
% End of user PostScript
1 .788 0 r
.82003 .36893 m
.78688 .40301 L
s
% Start of user PostScript
0.64005826 -0.26214977 0.57375977 -0.19397561 MAarrowhead1
% End of user PostScript
.897 1 0 r
.6405 .52555 m
.62782 .53268 L
s
% Start of user PostScript
0.28099347 0.051100025 0.2556481 0.065355534 MAarrowhead1
% End of user PostScript
.581 1 0 r
.5693 .55082 m
.56391 .55073 L
s
% Start of user PostScript
0.13859461 0.10163152 0.1278229 0.10145458 MAarrowhead1
% End of user PostScript
.266 1 0 r
.53768 .54327 m
.53511 .54175 L
s
% Start of user PostScript
0.075365523 0.086549989 0.07021594 0.083503213 MAarrowhead1
% End of user PostScript
0 1 .049 r
.52193 .53099 m
.52056 .52955 L
s
% Start of user PostScript
0.043850524 0.061973368 0.041117132 0.059105152 MAarrowhead1
% End of user PostScript
0 1 .364 r
.51329 .5208 m
.51251 .51974 L
s
% Start of user PostScript
0.02657872 0.041593839 0.025013156 0.039475221 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50824 .51357 m
.50777 .51285 L
s
% Start of user PostScript
0.016479409 0.027131661 0.015539103 0.025691449 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50517 .50873 m
.50488 .50826 L
s
% Start of user PostScript
0.010340683 0.017462044 0.009760541 0.016517093 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50326 .50558 m
.50308 .50528 L
s
% Start of user PostScript
0.0065287634 0.011165614 0.0061656641 0.010555737 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50207 .50356 m
.50195 .50336 L
s
% Start of user PostScript
0.004134939 0.0071166299 0.0039059908 0.0067261272 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50131 .50226 m
.50124 .50214 L
s
% Start of user PostScript
0.0026229534 0.004528695 0.002478047 0.0042796315 MAarrowhead1
% End of user PostScript
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -13.4688 -20 ]
[0 .4875 13.4688 0 ]
[.125 .4875 -25.9688 -20 ]
[.125 .4875 25.9688 0 ]
[.25 .4875 -20.9688 -20 ]
[.25 .4875 20.9688 0 ]
[.375 .4875 -25.9688 -20 ]
[.375 .4875 25.9688 0 ]
[.625 .4875 -19.5 -20 ]
[.625 .4875 19.5 0 ]
[.75 .4875 -14.5 -20 ]
[.75 .4875 14.5 0 ]
[.875 .4875 -19.5 -20 ]
[.875 .4875 19.5 0 ]
[1 .4875 -7 -20 ]
[1 .4875 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .125 -51.9375 -10 ]
[.4875 .125 0 10 ]
[.4875 .25 -41.9375 -10 ]
[.4875 .25 0 10 ]
[.4875 .375 -51.9375 -10 ]
[.4875 .375 0 10 ]
[.4875 .625 -39 -10 ]
[.4875 .625 0 10 ]
[.4875 .75 -29 -10 ]
[.4875 .75 0 10 ]
[.4875 .875 -39 -10 ]
[.4875 .875 0 10 ]
[.4875 1 -14 -10 ]
[.4875 1 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 .5 m
.125 .50625 L
s
gsave
.125 .4875 -86.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.25 .5 m
.25 .50625 L
s
gsave
.25 .4875 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.375 .5 m
.375 .50625 L
s
gsave
.375 .4875 -86.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.625 .5 m
.625 .50625 L
s
gsave
.625 .4875 -80.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.75 .5 m
.75 .50625 L
s
gsave
.75 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.875 .5 m
.875 .50625 L
s
gsave
.875 .4875 -80.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .125 m
.50625 .125 L
s
gsave
.4875 .125 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.5 .25 m
.50625 .25 L
s
gsave
.4875 .25 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .375 m
.50625 .375 L
s
gsave
.4875 .375 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.5 .625 m
.50625 .625 L
s
gsave
.4875 .625 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.5 .75 m
.50625 .75 L
s
gsave
.4875 .75 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .875 m
.50625 .875 L
s
gsave
.4875 .875 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.01 w
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 .147 1 r
.5 Mabswid
.11214 0 m
.12931 .01384 L
.15327 .03453 L
.17544 .05489 L
.19598 .07484 L
.21503 .0943 L
.23273 .11322 L
.24918 .13155 L
.2645 .14927 L
.27877 .16637 L
.29209 .18282 L
.30452 .19862 L
.31614 .21377 L
.327 .22829 L
.33717 .24217 L
.34669 .25543 L
.35562 .26809 L
.36399 .28016 L
.37184 .29166 L
.37921 .30261 L
.38614 .31303 L
.39265 .32293 L
.39877 .33235 L
.40452 .34129 L
.40993 .34977 L
.41503 .35783 L
.41983 .36547 L
.42434 .37271 L
.4286 .37958 L
.43261 .38609 L
.43639 .39226 L
.43995 .3981 L
.44331 .40364 L
.44647 .40888 L
.44946 .41384 L
.45228 .41853 L
.45493 .42298 L
.45744 .42718 L
.45981 .43116 L
.46204 .43492 L
.46415 .43849 L
.46614 .44185 L
.46802 .44504 L
.46979 .44805 L
.47146 .4509 L
.47304 .45359 L
.47454 .45614 L
.47594 .45855 L
.47728 .46082 L
.47853 .46298 L
Mistroke
.47972 .46501 L
.48084 .46693 L
.4819 .46875 L
.4829 .47047 L
.48384 .47209 L
.48474 .47363 L
.48558 .47508 L
.48638 .47645 L
.48713 .47775 L
.48784 .47897 L
.48851 .48013 L
.48914 .48122 L
.48974 .48226 L
.49031 .48324 L
.49084 .48416 L
.49135 .48503 L
.49183 .48586 L
.49228 .48663 L
.4927 .48737 L
.4931 .48807 L
.49349 .48872 L
.49384 .48935 L
.49418 .48993 L
.4945 .49049 L
.49481 .49101 L
.49509 .49151 L
.49536 .49197 L
.49562 .49242 L
.49586 .49283 L
.49609 .49323 L
.49631 .4936 L
.49651 .49396 L
.4967 .49429 L
.49688 .4946 L
.49706 .4949 L
.49722 .49518 L
.49737 .49545 L
.49752 .4957 L
.49765 .49594 L
.49778 .49616 L
.4979 .49637 L
.49802 .49657 L
.49813 .49676 L
.49823 .49694 L
.49833 .49711 L
.49842 .49727 L
.49851 .49742 L
.49859 .49756 L
.49867 .49769 L
.49874 .49782 L
Mistroke
.49881 .49794 L
.49888 .49805 L
.49894 .49816 L
.499 .49826 L
.49905 .49836 L
.4991 .49845 L
.49915 .49853 L
.4992 .49862 L
.49924 .49869 L
.49929 .49876 L
.49933 .49883 L
.49936 .4989 L
.4994 .49896 L
.49943 .49901 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49921 L
.49957 .49926 L
.4996 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.4997 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.4998 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
Mistroke
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
Mfstroke
0 .063 1 r
.20856 1 m
.24008 .94562 L
.27467 .88595 L
.30466 .83425 L
.33065 .78946 L
.35317 .75067 L
.37269 .71706 L
.38961 .68794 L
.40427 .66272 L
.41698 .64088 L
.428 .62196 L
.43755 .60557 L
.44583 .59137 L
.45301 .57908 L
.45923 .56843 L
.46462 .55921 L
.4693 .55122 L
.47335 .54431 L
.47687 .53832 L
.47992 .53313 L
.48256 .52865 L
.48485 .52476 L
.48684 .5214 L
.48857 .51849 L
.49006 .51597 L
.49136 .51379 L
.49249 .5119 L
.49347 .51027 L
.49432 .50885 L
.49505 .50763 L
.49569 .50658 L
.49625 .50567 L
.49673 .50488 L
.49715 .50419 L
.49751 .5036 L
.49783 .5031 L
.4981 .50266 L
.49834 .50228 L
.49855 .50195 L
.49873 .50167 L
.49889 .50142 L
.49903 .50121 L
.49914 .50103 L
.49925 .50088 L
.49934 .50074 L
.49942 .50063 L
.49949 .50053 L
.49955 .50045 L
.4996 .50037 L
.49965 .50031 L
Mistroke
.49969 .50026 L
.49972 .50021 L
.49975 .50017 L
.49978 .50014 L
.4998 .50011 L
.49983 .50009 L
.49984 .50007 L
.49986 .50005 L
.49987 .50004 L
.49989 .50002 L
.4999 .50001 L
.49991 .50001 L
.49992 .5 L
.49992 .49999 L
.49993 .49999 L
.49994 .49999 L
.49994 .49998 L
.49995 .49998 L
.49995 .49998 L
.49996 .49998 L
.49996 .49998 L
.49996 .49998 L
.49997 .49998 L
.49997 .49998 L
.49997 .49998 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49998 .49998 L
.49998 .49998 L
.49998 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
Mistroke
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 .719 0 r
.77306 1 m
.76242 .97884 L
.7485 .95149 L
.73528 .92578 L
.72273 .90159 L
.71081 .87884 L
.6995 .85742 L
.68877 .83725 L
.6786 .81826 L
.66895 .80037 L
.65982 .78351 L
.65116 .76762 L
.64296 .75264 L
.63519 .73851 L
.62784 .7252 L
.62088 .71264 L
.61429 .70079 L
.60805 .68961 L
.60215 .67906 L
.59657 .66911 L
.59129 .65971 L
.58629 .65085 L
.58157 .64248 L
.5771 .63458 L
.57287 .62712 L
.56888 .62008 L
.5651 .61343 L
.56152 .60715 L
.55815 .60122 L
.55495 .59562 L
.55193 .59033 L
.54908 .58534 L
.54638 .58062 L
.54383 .57617 L
.54142 .57196 L
.53914 .56798 L
.53699 .56423 L
.53495 .56068 L
.53303 .55733 L
.53121 .55417 L
.52949 .55118 L
.52787 .54835 L
.52634 .54568 L
.52489 .54316 L
.52352 .54078 L
.52222 .53853 L
.521 .53641 L
.51984 .5344 L
.51875 .5325 L
.51771 .53071 L
Mistroke
.51674 .52901 L
.51582 .52741 L
.51495 .5259 L
.51412 .52447 L
.51334 .52312 L
.51261 .52185 L
.51191 .52064 L
.51126 .51951 L
.51064 .51843 L
.51005 .51741 L
.5095 .51645 L
.50897 .51555 L
.50848 .51469 L
.50801 .51388 L
.50757 .51311 L
.50715 .51239 L
.50676 .51171 L
.50639 .51106 L
.50603 .51045 L
.5057 .50988 L
.50539 .50933 L
.50509 .50882 L
.50481 .50833 L
.50454 .50787 L
.50429 .50744 L
.50406 .50703 L
.50383 .50664 L
.50362 .50628 L
.50342 .50593 L
.50323 .5056 L
.50306 .50529 L
.50289 .505 L
.50273 .50473 L
.50258 .50447 L
.50244 .50422 L
.5023 .50399 L
.50217 .50377 L
.50205 .50356 L
.50194 .50336 L
.50183 .50318 L
.50173 .503 L
.50164 .50284 L
.50155 .50268 L
.50146 .50253 L
.50138 .50239 L
.50131 .50226 L
.50123 .50214 L
.50117 .50202 L
.5011 .50191 L
.50104 .5018 L
Mistroke
.50098 .5017 L
.50093 .50161 L
.50088 .50152 L
.50083 .50144 L
.50078 .50136 L
.50074 .50128 L
.5007 .50121 L
.50066 .50115 L
.50062 .50108 L
.50059 .50102 L
.50056 .50097 L
.50053 .50091 L
.5005 .50086 L
.50047 .50081 L
.50044 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50035 .50061 L
.50033 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
Mistroke
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
Mfstroke
0 1 .274 r
.4794 1 m
.48513 .97986 L
.49739 .93359 L
.50745 .89252 L
.51563 .856 L
.52221 .82349 L
.52743 .79449 L
.53151 .76857 L
.53461 .74538 L
.5369 .72459 L
.5385 .70591 L
.53953 .68911 L
.54008 .67395 L
.54024 .66027 L
.54007 .64788 L
.53964 .63666 L
.53899 .62646 L
.53818 .61718 L
.53723 .60872 L
.53618 .60099 L
.53505 .59392 L
.53387 .58744 L
.53265 .5815 L
.53142 .57603 L
.53017 .57099 L
.52893 .56634 L
.52771 .56205 L
.5265 .55808 L
.52531 .5544 L
.52416 .55099 L
.52303 .54782 L
.52194 .54487 L
.52089 .54213 L
.51987 .53957 L
.51889 .53719 L
.51795 .53497 L
.51705 .53289 L
.51619 .53094 L
.51536 .52912 L
.51457 .52742 L
.51382 .52582 L
.5131 .52432 L
.51241 .52292 L
.51176 .5216 L
.51114 .52036 L
.51055 .5192 L
.50999 .5181 L
.50946 .51707 L
.50895 .51611 L
.50847 .51519 L
Mistroke
.50802 .51434 L
.50758 .51353 L
.50718 .51277 L
.50679 .51205 L
.50642 .51137 L
.50607 .51074 L
.50574 .51014 L
.50543 .50957 L
.50513 .50904 L
.50485 .50853 L
.50459 .50806 L
.50434 .50761 L
.5041 .50719 L
.50388 .50679 L
.50367 .50641 L
.50347 .50605 L
.50328 .50572 L
.5031 .5054 L
.50293 .5051 L
.50277 .50482 L
.50261 .50455 L
.50247 .5043 L
.50233 .50406 L
.50221 .50384 L
.50209 .50363 L
.50197 .50343 L
.50186 .50324 L
.50176 .50306 L
.50166 .50289 L
.50157 .50273 L
.50149 .50258 L
.5014 .50244 L
.50133 .5023 L
.50125 .50217 L
.50118 .50205 L
.50112 .50194 L
.50106 .50183 L
.501 .50173 L
.50094 .50164 L
.50089 .50155 L
.50084 .50146 L
.5008 .50138 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50063 .5011 L
.5006 .50104 L
.50057 .50098 L
.50054 .50093 L
.50051 .50088 L
Mistroke
.50048 .50083 L
.50045 .50078 L
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50056 L
.5003 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .5004 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
Mistroke
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
Mfstroke
0 .472 1 r
1 .30166 m
.96801 .33487 L
.92013 .38222 L
.87784 .42184 L
.84044 .45487 L
.80731 .48223 L
.77792 .50477 L
.75182 .52319 L
.72859 .53809 L
.7079 .55002 L
.68942 .55941 L
.6729 .56667 L
.6581 .57212 L
.64482 .57605 L
.63288 .57871 L
.62213 .58031 L
.61243 .58102 L
.60366 .58101 L
.59572 .58041 L
.58851 .57932 L
.58196 .57785 L
.57599 .57607 L
.57054 .57406 L
.56557 .57186 L
.56101 .56953 L
.55683 .56712 L
.55299 .56464 L
.54945 .56214 L
.54619 .55964 L
.54319 .55715 L
.54041 .55469 L
.53783 .55228 L
.53545 .54992 L
.53323 .54761 L
.53118 .54538 L
.52926 .54322 L
.52748 .54113 L
.52582 .53911 L
.52427 .53718 L
.52282 .53532 L
.52147 .53354 L
.5202 .53183 L
.51902 .5302 L
.51791 .52864 L
.51687 .52716 L
.51589 .52574 L
.51497 .52439 L
.51411 .52311 L
.51331 .52189 L
.51255 .52073 L
Mistroke
.51183 .51962 L
.51116 .51858 L
.51053 .51758 L
.50993 .51664 L
.50937 .51574 L
.50884 .51489 L
.50835 .51409 L
.50788 .51333 L
.50744 .51261 L
.50702 .51192 L
.50663 .51127 L
.50626 .51066 L
.50591 .51008 L
.50558 .50953 L
.50527 .50901 L
.50498 .50852 L
.5047 .50805 L
.50444 .50761 L
.50419 .5072 L
.50396 .5068 L
.50374 .50643 L
.50353 .50608 L
.50334 .50574 L
.50315 .50543 L
.50298 .50513 L
.50281 .50485 L
.50266 .50458 L
.50251 .50433 L
.50237 .50409 L
.50224 .50387 L
.50212 .50365 L
.502 .50345 L
.50189 .50326 L
.50179 .50308 L
.50169 .50291 L
.50159 .50275 L
.50151 .5026 L
.50142 .50246 L
.50134 .50232 L
.50127 .5022 L
.5012 .50208 L
.50113 .50196 L
.50107 .50185 L
.50101 .50175 L
.50096 .50165 L
.5009 .50156 L
.50085 .50148 L
.50081 .5014 L
.50076 .50132 L
.50072 .50125 L
Mistroke
.50068 .50118 L
.50064 .50111 L
.50061 .50105 L
.50057 .50099 L
.50054 .50094 L
.50051 .50089 L
.50048 .50084 L
.50046 .50079 L
.50043 .50075 L
.50041 .50071 L
.50039 .50067 L
.50036 .50063 L
.50034 .5006 L
.50033 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50048 L
.50026 .50045 L
.50025 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50029 L
.50016 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
Mistroke
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
Mfstroke
1 0 .577 r
.28981 0 m
.29666 .02681 L
.30513 .05764 L
.3135 .08613 L
.32172 .1125 L
.32977 .13695 L
.33761 .15963 L
.34522 .18071 L
.35259 .20032 L
.35972 .21857 L
.36658 .23559 L
.37318 .25147 L
.37952 .2663 L
.38559 .28017 L
.39141 .29313 L
.39697 .30527 L
.40228 .31664 L
.40735 .3273 L
.41218 .3373 L
.41678 .34668 L
.42116 .35549 L
.42532 .36377 L
.42928 .37155 L
.43305 .37886 L
.43662 .38574 L
.44001 .39222 L
.44323 .39831 L
.44629 .40405 L
.44918 .40945 L
.45192 .41454 L
.45452 .41934 L
.45699 .42386 L
.45932 .42812 L
.46153 .43214 L
.46362 .43593 L
.46561 .4395 L
.46748 .44287 L
.46925 .44605 L
.47093 .44905 L
.47252 .45188 L
.47402 .45456 L
.47545 .45708 L
.47679 .45946 L
.47806 .46171 L
.47927 .46383 L
.4804 .46583 L
.48148 .46773 L
.48249 .46951 L
.48346 .4712 L
.48436 .47279 L
Mistroke
.48522 .4743 L
.48604 .47572 L
.4868 .47706 L
.48753 .47833 L
.48821 .47953 L
.48886 .48066 L
.48948 .48173 L
.49005 .48273 L
.4906 .48369 L
.49112 .48459 L
.49161 .48544 L
.49207 .48624 L
.49251 .487 L
.49292 .48772 L
.49331 .4884 L
.49368 .48904 L
.49403 .48964 L
.49435 .49021 L
.49467 .49075 L
.49496 .49126 L
.49524 .49174 L
.4955 .4922 L
.49575 .49263 L
.49598 .49304 L
.4962 .49342 L
.49641 .49378 L
.49661 .49413 L
.4968 .49445 L
.49697 .49476 L
.49714 .49505 L
.4973 .49532 L
.49745 .49558 L
.49759 .49582 L
.49772 .49605 L
.49785 .49627 L
.49796 .49647 L
.49808 .49667 L
.49818 .49685 L
.49828 .49703 L
.49838 .49719 L
.49847 .49734 L
.49855 .49749 L
.49863 .49763 L
.49871 .49776 L
.49878 .49788 L
.49885 .498 L
.49891 .49811 L
.49897 .49821 L
.49903 .49831 L
.49908 .49841 L
Mistroke
.49913 .49849 L
.49918 .49858 L
.49922 .49866 L
.49927 .49873 L
.49931 .4988 L
.49935 .49887 L
.49938 .49893 L
.49942 .49899 L
.49945 .49904 L
.49948 .4991 L
.49951 .49915 L
.49953 .49919 L
.49956 .49924 L
.49958 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .49939 L
.49967 .49943 L
.49969 .49946 L
.4997 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49976 .49959 L
.49978 .49961 L
.49979 .49964 L
.4998 .49966 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49982 L
.4999 .49983 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
Mistroke
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
0 .944 1 r
.81344 1 m
.80328 .9857 L
.78566 .96048 L
.76914 .93644 L
.75363 .91355 L
.73907 .89177 L
.72539 .87105 L
.71253 .85135 L
.70043 .83264 L
.68906 .81487 L
.67835 .79801 L
.66827 .78201 L
.65878 .76684 L
.64985 .75245 L
.64143 .73881 L
.63349 .72589 L
.62601 .71365 L
.61896 .70205 L
.61231 .69107 L
.60605 .68067 L
.60013 .67083 L
.59455 .66152 L
.58929 .6527 L
.58432 .64436 L
.57964 .63647 L
.57522 .62901 L
.57104 .62195 L
.5671 .61527 L
.56338 .60895 L
.55987 .60298 L
.55655 .59733 L
.55342 .59199 L
.55046 .58694 L
.54767 .58217 L
.54503 .57765 L
.54254 .57339 L
.54019 .56935 L
.53797 .56554 L
.53587 .56194 L
.53389 .55853 L
.53202 .55531 L
.53025 .55227 L
.52858 .54939 L
.527 .54667 L
.52551 .5441 L
.5241 .54168 L
.52277 .53938 L
.52152 .53721 L
.52033 .53516 L
.51921 .53323 L
Mistroke
.51815 .5314 L
.51715 .52967 L
.5162 .52803 L
.51531 .52649 L
.51446 .52503 L
.51367 .52365 L
.51291 .52235 L
.5122 .52112 L
.51153 .51995 L
.51089 .51885 L
.51029 .51782 L
.50972 .51683 L
.50919 .51591 L
.50868 .51503 L
.5082 .5142 L
.50775 .51342 L
.50732 .51268 L
.50692 .51198 L
.50654 .51132 L
.50618 .5107 L
.50584 .51011 L
.50551 .50955 L
.50521 .50902 L
.50492 .50853 L
.50465 .50806 L
.5044 .50761 L
.50415 .50719 L
.50392 .5068 L
.50371 .50642 L
.5035 .50607 L
.50331 .50573 L
.50313 .50542 L
.50296 .50512 L
.50279 .50484 L
.50264 .50457 L
.50249 .50432 L
.50236 .50408 L
.50223 .50386 L
.5021 .50364 L
.50199 .50344 L
.50188 .50325 L
.50177 .50307 L
.50168 .5029 L
.50158 .50274 L
.5015 .50259 L
.50141 .50245 L
.50134 .50231 L
.50126 .50219 L
.50119 .50207 L
.50113 .50195 L
Mistroke
.50107 .50184 L
.50101 .50174 L
.50095 .50165 L
.5009 .50156 L
.50085 .50147 L
.5008 .50139 L
.50076 .50131 L
.50072 .50124 L
.50068 .50117 L
.50064 .50111 L
.5006 .50105 L
.50057 .50099 L
.50054 .50093 L
.50051 .50088 L
.50048 .50083 L
.50046 .50079 L
.50043 .50074 L
.50041 .5007 L
.50038 .50066 L
.50036 .50063 L
.50034 .50059 L
.50032 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.50019 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
Mfstroke
0 1 .93 r
0 .49221 m
.03201 .46894 L
.07544 .4401 L
.11413 .41693 L
.14864 .39857 L
.17949 .38428 L
.2071 .37344 L
.23186 .36549 L
.2541 .35998 L
.27413 .35649 L
.29218 .35469 L
.30849 .35429 L
.32326 .35503 L
.33665 .35671 L
.34881 .35913 L
.35988 .36215 L
.36998 .36564 L
.3792 .36949 L
.38764 .3736 L
.39538 .37789 L
.40248 .38231 L
.40902 .38679 L
.41504 .39129 L
.42059 .39577 L
.42572 .40021 L
.43047 .40458 L
.43487 .40886 L
.43895 .41304 L
.44274 .41709 L
.44626 .42102 L
.44954 .42483 L
.4526 .42849 L
.45545 .43202 L
.45812 .4354 L
.46061 .43865 L
.46293 .44177 L
.46511 .44474 L
.46715 .44758 L
.46906 .4503 L
.47086 .45289 L
.47254 .45535 L
.47412 .4577 L
.4756 .45993 L
.477 .46205 L
.47831 .46407 L
.47954 .46599 L
.4807 .46781 L
.48179 .46953 L
.48282 .47117 L
.48379 .47272 L
Mistroke
.4847 .47419 L
.48556 .47559 L
.48637 .47691 L
.48713 .47816 L
.48785 .47935 L
.48853 .48047 L
.48917 .48154 L
.48977 .48254 L
.49034 .48349 L
.49088 .4844 L
.49139 .48525 L
.49187 .48605 L
.49232 .48682 L
.49274 .48754 L
.49315 .48822 L
.49353 .48887 L
.49388 .48948 L
.49422 .49006 L
.49454 .4906 L
.49485 .49112 L
.49513 .4916 L
.4954 .49207 L
.49565 .4925 L
.49589 .49291 L
.49612 .4933 L
.49634 .49367 L
.49654 .49402 L
.49673 .49435 L
.49691 .49466 L
.49708 .49495 L
.49724 .49523 L
.49739 .49549 L
.49754 .49574 L
.49767 .49598 L
.4978 .4962 L
.49792 .49641 L
.49804 .49661 L
.49815 .49679 L
.49825 .49697 L
.49834 .49714 L
.49844 .49729 L
.49852 .49744 L
.4986 .49758 L
.49868 .49772 L
.49875 .49784 L
.49882 .49796 L
.49889 .49807 L
.49895 .49818 L
.49901 .49828 L
.49906 .49837 L
Mistroke
.49911 .49846 L
.49916 .49855 L
.49921 .49863 L
.49925 .4987 L
.49929 .49878 L
.49933 .49884 L
.49937 .49891 L
.4994 .49897 L
.49944 .49902 L
.49947 .49908 L
.4995 .49913 L
.49952 .49918 L
.49955 .49922 L
.49958 .49927 L
.4996 .49931 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49945 L
.4997 .49948 L
.49971 .49951 L
.49973 .49953 L
.49975 .49956 L
.49976 .49958 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
Mistroke
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
Mfstroke
1 0 .968 r
.80966 1 m
.80813 .9978 L
.79034 .97177 L
.77363 .94699 L
.75794 .9234 L
.74319 .90098 L
.72933 .87967 L
.71629 .85943 L
.70402 .84021 L
.69248 .82198 L
.68161 .80468 L
.67138 .78827 L
.66174 .77271 L
.65265 .75797 L
.64409 .74401 L
.63602 .73077 L
.62842 .71824 L
.62124 .70638 L
.61448 .69514 L
.6081 .68451 L
.60208 .67445 L
.5964 .66492 L
.59104 .65591 L
.58598 .64739 L
.58121 .63932 L
.5767 .6317 L
.57245 .62448 L
.56843 .61766 L
.56464 .61121 L
.56106 .60511 L
.55768 .59934 L
.55449 .59389 L
.55147 .58873 L
.54862 .58385 L
.54594 .57925 L
.5434 .57489 L
.541 .57077 L
.53873 .56688 L
.53659 .5632 L
.53457 .55973 L
.53266 .55644 L
.53086 .55333 L
.52916 .5504 L
.52755 .54763 L
.52603 .545 L
.52459 .54253 L
.52323 .54018 L
.52195 .53797 L
.52074 .53588 L
.5196 .5339 L
Mistroke
.51852 .53204 L
.51749 .53027 L
.51653 .5286 L
.51562 .52703 L
.51476 .52554 L
.51394 .52413 L
.51317 .5228 L
.51245 .52155 L
.51176 .52036 L
.51111 .51924 L
.5105 .51818 L
.50992 .51718 L
.50937 .51623 L
.50886 .51534 L
.50837 .51449 L
.50791 .51369 L
.50747 .51294 L
.50706 .51222 L
.50667 .51155 L
.5063 .51091 L
.50595 .51031 L
.50563 .50974 L
.50532 .50921 L
.50502 .5087 L
.50475 .50822 L
.50448 .50777 L
.50424 .50734 L
.504 .50693 L
.50378 .50655 L
.50357 .50619 L
.50338 .50585 L
.50319 .50553 L
.50302 .50522 L
.50285 .50493 L
.50269 .50466 L
.50254 .50441 L
.5024 .50416 L
.50227 .50393 L
.50215 .50372 L
.50203 .50351 L
.50192 .50332 L
.50181 .50314 L
.50171 .50296 L
.50162 .5028 L
.50153 .50264 L
.50144 .5025 L
.50136 .50236 L
.50129 .50223 L
.50122 .50211 L
.50115 .50199 L
Mistroke
.50109 .50188 L
.50103 .50178 L
.50097 .50168 L
.50092 .50159 L
.50087 .5015 L
.50082 .50142 L
.50077 .50134 L
.50073 .50127 L
.50069 .5012 L
.50065 .50113 L
.50062 .50107 L
.50058 .50101 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .5008 L
.50044 .50076 L
.50041 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .50061 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50016 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
Mfstroke
1 .641 0 r
.23301 0 m
.23358 .00122 L
.24742 .03017 L
.26061 .05734 L
.27317 .08284 L
.28513 .10678 L
.29649 .12928 L
.3073 .15043 L
.31756 .17032 L
.32731 .18903 L
.33656 .20664 L
.34534 .22321 L
.35366 .23881 L
.36155 .25351 L
.36903 .26736 L
.37612 .28041 L
.38284 .29271 L
.38919 .30431 L
.39522 .31524 L
.40092 .32556 L
.40632 .33528 L
.41143 .34446 L
.41626 .35312 L
.42083 .36128 L
.42516 .36899 L
.42926 .37627 L
.43313 .38314 L
.43679 .38962 L
.44025 .39574 L
.44353 .40152 L
.44663 .40697 L
.44956 .41212 L
.45232 .41699 L
.45494 .42158 L
.45742 .42592 L
.45976 .43001 L
.46197 .43388 L
.46406 .43754 L
.46604 .44099 L
.4679 .44425 L
.46967 .44733 L
.47134 .45024 L
.47292 .45298 L
.47441 .45558 L
.47581 .45803 L
.47715 .46035 L
.4784 .46254 L
.47959 .4646 L
.48072 .46656 L
.48178 .4684 L
Mistroke
.48278 .47015 L
.48373 .47179 L
.48463 .47335 L
.48547 .47482 L
.48627 .47621 L
.48703 .47752 L
.48774 .47876 L
.48842 .47993 L
.48906 .48104 L
.48966 .48208 L
.49023 .48307 L
.49077 .484 L
.49128 .48489 L
.49176 .48572 L
.49221 .48651 L
.49264 .48725 L
.49305 .48795 L
.49343 .48862 L
.49379 .48925 L
.49413 .48984 L
.49446 .4904 L
.49476 .49093 L
.49505 .49143 L
.49532 .4919 L
.49558 .49235 L
.49583 .49277 L
.49606 .49317 L
.49627 .49354 L
.49648 .4939 L
.49667 .49424 L
.49686 .49455 L
.49703 .49485 L
.49719 .49514 L
.49735 .49541 L
.49749 .49566 L
.49763 .4959 L
.49776 .49612 L
.49789 .49634 L
.498 .49654 L
.49811 .49673 L
.49822 .49691 L
.49831 .49708 L
.49841 .49724 L
.4985 .49739 L
.49858 .49754 L
.49866 .49767 L
.49873 .4978 L
.4988 .49792 L
.49887 .49804 L
.49893 .49815 L
Mistroke
.49899 .49825 L
.49904 .49834 L
.4991 .49844 L
.49915 .49852 L
.49919 .4986 L
.49924 .49868 L
.49928 .49875 L
.49932 .49882 L
.49936 .49889 L
.49939 .49895 L
.49943 .49901 L
.49946 .49906 L
.49949 .49911 L
.49952 .49916 L
.49954 .49921 L
.49957 .49925 L
.49959 .49929 L
.49961 .49933 L
.49964 .49937 L
.49966 .4994 L
.49967 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49952 L
.49974 .49955 L
.49975 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49971 L
.49984 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49978 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
Mistroke
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
1 0 .882 r
.93722 1 m
.91913 .98991 L
.89069 .97216 L
.86452 .95415 L
.84042 .93606 L
.81818 .91804 L
.79763 .90021 L
.77862 .88267 L
.761 .86549 L
.74465 .84874 L
.72947 .83246 L
.71535 .81668 L
.7022 .80143 L
.68995 .78673 L
.67853 .77258 L
.66786 .75899 L
.65789 .74596 L
.64856 .73348 L
.63983 .72154 L
.63166 .71014 L
.624 .69926 L
.61681 .68888 L
.61007 .679 L
.60374 .66959 L
.59779 .66064 L
.5922 .65212 L
.58695 .64404 L
.58201 .63635 L
.57736 .62906 L
.57298 .62214 L
.56886 .61557 L
.56498 .60935 L
.56133 .60345 L
.55789 .59785 L
.55464 .59255 L
.55158 .58753 L
.5487 .58278 L
.54598 .57828 L
.54341 .57402 L
.54099 .56998 L
.53871 .56617 L
.53656 .56255 L
.53452 .55914 L
.53261 .5559 L
.5308 .55284 L
.52909 .54995 L
.52747 .54721 L
.52595 .54463 L
.52451 .54218 L
.52316 .53986 L
Mistroke
.52187 .53768 L
.52066 .53561 L
.51952 .53365 L
.51844 .5318 L
.51742 .53006 L
.51646 .5284 L
.51555 .52684 L
.51469 .52537 L
.51388 .52397 L
.51311 .52265 L
.51239 .52141 L
.5117 .52023 L
.51106 .51911 L
.51045 .51806 L
.50987 .51707 L
.50933 .51613 L
.50881 .51524 L
.50833 .5144 L
.50787 .51361 L
.50743 .51286 L
.50702 .51215 L
.50663 .51148 L
.50627 .51085 L
.50592 .51025 L
.5056 .50969 L
.50529 .50915 L
.505 .50865 L
.50472 .50817 L
.50446 .50772 L
.50421 .5073 L
.50398 .50689 L
.50376 .50651 L
.50355 .50616 L
.50336 .50582 L
.50317 .5055 L
.503 .50519 L
.50283 .50491 L
.50268 .50464 L
.50253 .50438 L
.50239 .50414 L
.50226 .50391 L
.50213 .5037 L
.50202 .50349 L
.50191 .5033 L
.5018 .50312 L
.5017 .50295 L
.50161 .50278 L
.50152 .50263 L
.50143 .50248 L
.50136 .50235 L
Mistroke
.50128 .50222 L
.50121 .5021 L
.50114 .50198 L
.50108 .50187 L
.50102 .50177 L
.50096 .50167 L
.50091 .50158 L
.50086 .50149 L
.50081 .50141 L
.50077 .50133 L
.50073 .50126 L
.50069 .50119 L
.50065 .50112 L
.50061 .50106 L
.50058 .501 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .5008 L
.50044 .50076 L
.50041 .50071 L
.50039 .50067 L
.50037 .50064 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .5003 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50015 L
.50008 .50014 L
Mistroke
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
Mfstroke
1 0 .675 r
0 .02604 m
.00272 .02666 L
.03891 .03755 L
.07193 .04986 L
.10212 .06326 L
.12976 .07744 L
.15512 .09216 L
.17842 .10721 L
.19986 .12243 L
.21962 .13766 L
.23787 .1528 L
.25473 .16776 L
.27035 .18244 L
.28482 .1968 L
.29826 .21079 L
.31074 .22437 L
.32235 .23752 L
.33317 .25022 L
.34325 .26245 L
.35266 .27421 L
.36145 .28551 L
.36966 .29633 L
.37734 .30669 L
.38454 .3166 L
.39128 .32606 L
.3976 .33508 L
.40352 .34368 L
.40908 .35188 L
.41431 .35968 L
.41921 .36709 L
.42383 .37414 L
.42816 .38084 L
.43224 .3872 L
.43608 .39324 L
.43969 .39897 L
.44309 .40441 L
.4463 .40956 L
.44932 .41444 L
.45216 .41907 L
.45484 .42346 L
.45737 .42761 L
.45975 .43154 L
.462 .43527 L
.46412 .43879 L
.46612 .44213 L
.468 .44529 L
.46978 .44828 L
.47146 .4511 L
.47305 .45378 L
.47454 .45631 L
Mistroke
.47596 .4587 L
.47729 .46096 L
.47855 .4631 L
.47974 .46513 L
.48086 .46704 L
.48192 .46885 L
.48292 .47056 L
.48386 .47218 L
.48476 .47371 L
.4856 .47515 L
.48639 .47652 L
.48715 .47781 L
.48786 .47903 L
.48853 .48018 L
.48916 .48127 L
.48976 .4823 L
.49032 .48328 L
.49086 .4842 L
.49136 .48507 L
.49184 .48589 L
.49229 .48667 L
.49272 .4874 L
.49312 .48809 L
.4935 .48875 L
.49386 .48937 L
.49419 .48995 L
.49452 .49051 L
.49482 .49103 L
.4951 .49153 L
.49537 .49199 L
.49563 .49243 L
.49587 .49285 L
.4961 .49324 L
.49631 .49362 L
.49652 .49397 L
.49671 .4943 L
.49689 .49461 L
.49706 .49491 L
.49722 .49519 L
.49738 .49546 L
.49752 .49571 L
.49766 .49594 L
.49779 .49617 L
.49791 .49638 L
.49802 .49658 L
.49813 .49677 L
.49824 .49694 L
.49833 .49711 L
.49842 .49727 L
.49851 .49742 L
Mistroke
.49859 .49756 L
.49867 .4977 L
.49874 .49783 L
.49881 .49795 L
.49888 .49806 L
.49894 .49817 L
.499 .49827 L
.49905 .49836 L
.49911 .49845 L
.49916 .49854 L
.4992 .49862 L
.49925 .49869 L
.49929 .49877 L
.49933 .49883 L
.49936 .4989 L
.4994 .49896 L
.49943 .49902 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49922 L
.49957 .49926 L
.4996 .4993 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49944 L
.4997 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49956 L
.49976 .49958 L
.49977 .4996 L
.49978 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
Mistroke
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
0 .704 1 r
.29499 0 m
.29591 .00412 L
.30394 .03703 L
.31195 .06739 L
.3199 .09542 L
.32773 .12135 L
.33541 .14537 L
.34291 .16765 L
.3502 .18833 L
.35728 .20755 L
.36412 .22545 L
.37072 .24212 L
.37708 .25766 L
.38319 .27217 L
.38905 .28573 L
.39467 .29841 L
.40004 .31027 L
.40518 .32138 L
.41008 .33179 L
.41475 .34155 L
.41921 .35071 L
.42345 .3593 L
.42748 .36738 L
.43132 .37496 L
.43497 .38209 L
.43844 .3888 L
.44173 .39511 L
.44485 .40104 L
.44781 .40663 L
.45062 .4119 L
.45328 .41685 L
.45581 .42152 L
.4582 .42593 L
.46047 .43007 L
.46261 .43399 L
.46465 .43767 L
.46657 .44115 L
.46839 .44443 L
.47011 .44753 L
.47175 .45045 L
.47329 .4532 L
.47475 .4558 L
.47613 .45826 L
.47744 .46057 L
.47867 .46276 L
.47984 .46483 L
.48095 .46677 L
.48199 .46861 L
.48298 .47035 L
.48392 .47199 L
Mistroke
.4848 .47354 L
.48563 .47501 L
.48642 .47639 L
.48717 .47769 L
.48787 .47893 L
.48854 .48009 L
.48917 .48119 L
.48977 .48223 L
.49033 .48321 L
.49086 .48414 L
.49137 .48501 L
.49184 .48584 L
.49229 .48662 L
.49271 .48736 L
.49312 .48806 L
.49349 .48872 L
.49385 .48934 L
.49419 .48993 L
.49451 .49048 L
.49481 .49101 L
.4951 .4915 L
.49537 .49197 L
.49562 .49242 L
.49587 .49283 L
.49609 .49323 L
.49631 .4936 L
.49651 .49396 L
.4967 .49429 L
.49689 .4946 L
.49706 .4949 L
.49722 .49518 L
.49737 .49545 L
.49752 .4957 L
.49765 .49594 L
.49778 .49616 L
.49791 .49637 L
.49802 .49657 L
.49813 .49676 L
.49823 .49694 L
.49833 .49711 L
.49842 .49727 L
.49851 .49742 L
.49859 .49756 L
.49867 .49769 L
.49874 .49782 L
.49881 .49794 L
.49888 .49806 L
.49894 .49816 L
.499 .49826 L
.49905 .49836 L
Mistroke
.49911 .49845 L
.49915 .49854 L
.4992 .49862 L
.49925 .49869 L
.49929 .49876 L
.49933 .49883 L
.49936 .4989 L
.4994 .49896 L
.49943 .49902 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49922 L
.49957 .49926 L
.4996 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.4997 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.4998 .49965 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
Mistroke
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
1 .108 0 r
0 .37718 m
.02843 .36216 L
.06979 .34314 L
.10681 .32873 L
.14002 .3182 L
.16986 .31091 L
.19672 .30633 L
.22094 .30401 L
.24282 .30355 L
.26263 .30462 L
.2806 .30693 L
.29692 .31025 L
.31178 .31436 L
.32533 .31909 L
.33771 .32429 L
.34904 .32985 L
.35943 .33565 L
.36897 .34161 L
.37774 .34765 L
.38583 .35372 L
.39328 .35977 L
.40018 .36575 L
.40655 .37163 L
.41246 .3774 L
.41794 .38302 L
.42304 .38848 L
.42777 .39377 L
.43218 .39889 L
.43629 .40382 L
.44012 .40857 L
.4437 .41313 L
.44704 .4175 L
.45017 .42168 L
.4531 .42569 L
.45584 .42951 L
.45841 .43316 L
.46082 .43664 L
.46308 .43996 L
.46521 .44312 L
.4672 .44612 L
.46907 .44897 L
.47084 .45169 L
.47249 .45426 L
.47405 .45671 L
.47552 .45903 L
.4769 .46123 L
.4782 .46332 L
.47943 .4653 L
.48058 .46718 L
.48167 .46895 L
Mistroke
.4827 .47064 L
.48367 .47223 L
.48458 .47374 L
.48544 .47517 L
.48625 .47653 L
.48702 .47781 L
.48774 .47902 L
.48842 .48016 L
.48906 .48125 L
.48967 .48228 L
.49024 .48325 L
.49078 .48416 L
.4913 .48503 L
.49178 .48585 L
.49223 .48663 L
.49266 .48736 L
.49307 .48806 L
.49345 .48871 L
.49381 .48933 L
.49416 .48992 L
.49448 .49047 L
.49478 .491 L
.49507 .49149 L
.49534 .49196 L
.4956 .4924 L
.49584 .49282 L
.49607 .49322 L
.49629 .49359 L
.4965 .49394 L
.49669 .49427 L
.49687 .49459 L
.49704 .49489 L
.49721 .49517 L
.49736 .49544 L
.49751 .49569 L
.49764 .49592 L
.49777 .49615 L
.4979 .49636 L
.49801 .49656 L
.49812 .49675 L
.49823 .49693 L
.49832 .4971 L
.49842 .49726 L
.4985 .49741 L
.49859 .49755 L
.49866 .49769 L
.49874 .49782 L
.49881 .49794 L
.49887 .49805 L
.49894 .49816 L
Mistroke
.49899 .49826 L
.49905 .49835 L
.4991 .49844 L
.49915 .49853 L
.4992 .49861 L
.49924 .49869 L
.49928 .49876 L
.49932 .49883 L
.49936 .49889 L
.4994 .49895 L
.49943 .49901 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49921 L
.49957 .49926 L
.49959 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
Mistroke
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
.263 0 1 r
.172 0 m
.18425 .01539 L
.20307 .03966 L
.22065 .06292 L
.23711 .08518 L
.25252 .10646 L
.26695 .12677 L
.28049 .14615 L
.29318 .16462 L
.3051 .18222 L
.31629 .19896 L
.32681 .21488 L
.33669 .23001 L
.34598 .24439 L
.35472 .25804 L
.36295 .271 L
.37069 .28329 L
.37799 .29496 L
.38485 .30601 L
.39132 .31649 L
.39742 .32642 L
.40317 .33583 L
.40859 .34474 L
.41369 .35318 L
.41851 .36117 L
.42306 .36873 L
.42734 .37589 L
.43139 .38266 L
.4352 .38907 L
.4388 .39513 L
.4422 .40087 L
.44541 .40629 L
.44844 .41143 L
.4513 .41628 L
.454 .42087 L
.45654 .42521 L
.45895 .42931 L
.46122 .43319 L
.46337 .43686 L
.46539 .44033 L
.46731 .44361 L
.46912 .44671 L
.47082 .44964 L
.47243 .45241 L
.47396 .45502 L
.4754 .4575 L
.47675 .45984 L
.47804 .46205 L
.47925 .46414 L
.4804 .46611 L
Mistroke
.48148 .46797 L
.4825 .46974 L
.48347 .4714 L
.48438 .47298 L
.48524 .47447 L
.48605 .47587 L
.48682 .4772 L
.48755 .47846 L
.48824 .47964 L
.48889 .48077 L
.4895 .48183 L
.49008 .48283 L
.49063 .48377 L
.49114 .48467 L
.49163 .48551 L
.49209 .48631 L
.49253 .48706 L
.49294 .48778 L
.49333 .48845 L
.4937 .48909 L
.49404 .48969 L
.49437 .49026 L
.49468 .49079 L
.49498 .4913 L
.49525 .49178 L
.49552 .49223 L
.49576 .49266 L
.496 .49307 L
.49622 .49345 L
.49643 .49381 L
.49662 .49415 L
.49681 .49447 L
.49698 .49478 L
.49715 .49507 L
.49731 .49534 L
.49746 .49559 L
.4976 .49584 L
.49773 .49607 L
.49785 .49628 L
.49797 .49649 L
.49808 .49668 L
.49819 .49686 L
.49829 .49704 L
.49838 .4972 L
.49847 .49736 L
.49856 .4975 L
.49864 .49764 L
.49871 .49777 L
.49878 .49789 L
.49885 .49801 L
Mistroke
.49891 .49812 L
.49897 .49822 L
.49903 .49832 L
.49908 .49841 L
.49913 .4985 L
.49918 .49858 L
.49923 .49866 L
.49927 .49873 L
.49931 .4988 L
.49935 .49887 L
.49938 .49893 L
.49942 .49899 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
.49956 .49924 L
.49959 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .49939 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49976 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
Mistroke
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
Mfstroke
0 1 .723 r
.18779 0 m
.19191 .00582 L
.20978 .03152 L
.22655 .056 L
.2423 .07931 L
.25708 .1015 L
.27098 .12259 L
.28404 .14264 L
.29632 .16168 L
.30787 .17976 L
.31875 .19692 L
.32898 .2132 L
.33862 .22864 L
.3477 .24328 L
.35626 .25715 L
.36432 .2703 L
.37192 .28275 L
.37908 .29455 L
.38584 .30572 L
.39221 .31629 L
.39822 .3263 L
.40389 .33577 L
.40924 .34474 L
.41428 .35322 L
.41905 .36124 L
.42354 .36884 L
.42778 .37602 L
.43179 .38281 L
.43557 .38923 L
.43914 .3953 L
.44251 .40105 L
.44569 .40648 L
.4487 .41161 L
.45154 .41646 L
.45422 .42105 L
.45675 .42539 L
.45914 .42949 L
.4614 .43337 L
.46353 .43703 L
.46555 .4405 L
.46745 .44377 L
.46925 .44686 L
.47095 .44979 L
.47255 .45255 L
.47406 .45516 L
.4755 .45763 L
.47685 .45996 L
.47813 .46217 L
.47933 .46425 L
.48047 .46622 L
Mistroke
.48155 .46808 L
.48257 .46984 L
.48353 .4715 L
.48444 .47307 L
.4853 .47455 L
.48611 .47595 L
.48687 .47728 L
.4876 .47853 L
.48828 .47971 L
.48893 .48083 L
.48954 .48189 L
.49011 .48289 L
.49066 .48383 L
.49118 .48472 L
.49166 .48556 L
.49212 .48636 L
.49256 .48711 L
.49297 .48782 L
.49335 .48849 L
.49372 .48913 L
.49407 .48972 L
.49439 .49029 L
.4947 .49083 L
.49499 .49133 L
.49527 .49181 L
.49553 .49226 L
.49578 .49269 L
.49601 .49309 L
.49623 .49347 L
.49644 .49383 L
.49663 .49417 L
.49682 .49449 L
.497 .4948 L
.49716 .49508 L
.49732 .49535 L
.49747 .49561 L
.49761 .49585 L
.49774 .49608 L
.49786 .4963 L
.49798 .4965 L
.49809 .49669 L
.4982 .49688 L
.4983 .49705 L
.49839 .49721 L
.49848 .49736 L
.49856 .49751 L
.49864 .49765 L
.49872 .49778 L
.49879 .4979 L
.49885 .49802 L
Mistroke
.49892 .49812 L
.49898 .49823 L
.49903 .49833 L
.49909 .49842 L
.49914 .49851 L
.49918 .49859 L
.49923 .49867 L
.49927 .49874 L
.49931 .49881 L
.49935 .49887 L
.49939 .49894 L
.49942 .49899 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
.49956 .49924 L
.49959 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
Mistroke
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
Mfstroke
.734 1 0 r
.20571 0 m
.21622 .01735 L
.23206 .0436 L
.247 .06846 L
.2611 .09198 L
.2744 .11425 L
.28695 .13532 L
.29879 .15525 L
.30996 .1741 L
.32051 .19194 L
.33047 .20881 L
.33987 .22476 L
.34874 .23985 L
.35712 .25412 L
.36504 .26761 L
.37251 .28037 L
.37956 .29243 L
.38622 .30383 L
.39251 .31461 L
.39846 .32479 L
.40407 .33443 L
.40937 .34353 L
.41438 .35213 L
.41911 .36027 L
.42357 .36796 L
.42779 .37522 L
.43178 .38209 L
.43555 .38858 L
.4391 .39471 L
.44247 .40051 L
.44564 .40599 L
.44864 .41116 L
.45147 .41605 L
.45415 .42068 L
.45668 .42505 L
.45907 .42917 L
.46133 .43308 L
.46346 .43676 L
.46548 .44025 L
.46738 .44354 L
.46918 .44665 L
.47088 .44959 L
.47248 .45237 L
.474 .45499 L
.47544 .45747 L
.47679 .45981 L
.47807 .46203 L
.47928 .46412 L
.48042 .4661 L
.4815 .46797 L
Mistroke
.48252 .46973 L
.48348 .4714 L
.48439 .47298 L
.48525 .47447 L
.48607 .47587 L
.48684 .4772 L
.48756 .47846 L
.48825 .47965 L
.4889 .48077 L
.48951 .48183 L
.49009 .48283 L
.49063 .48378 L
.49115 .48467 L
.49164 .48552 L
.4921 .48631 L
.49253 .48707 L
.49294 .48778 L
.49333 .48845 L
.4937 .48909 L
.49405 .48969 L
.49438 .49026 L
.49469 .4908 L
.49498 .4913 L
.49526 .49178 L
.49552 .49224 L
.49576 .49266 L
.496 .49307 L
.49622 .49345 L
.49643 .49381 L
.49662 .49415 L
.49681 .49448 L
.49699 .49478 L
.49715 .49507 L
.49731 .49534 L
.49746 .4956 L
.4976 .49584 L
.49773 .49607 L
.49786 .49629 L
.49797 .49649 L
.49809 .49668 L
.49819 .49687 L
.49829 .49704 L
.49838 .4972 L
.49847 .49736 L
.49856 .4975 L
.49864 .49764 L
.49871 .49777 L
.49878 .49789 L
.49885 .49801 L
.49891 .49812 L
Mistroke
.49897 .49822 L
.49903 .49832 L
.49908 .49841 L
.49913 .4985 L
.49918 .49858 L
.49923 .49866 L
.49927 .49873 L
.49931 .4988 L
.49935 .49887 L
.49938 .49893 L
.49942 .49899 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
.49956 .49924 L
.49959 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .49939 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49977 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
Mistroke
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
Mfstroke
0 .488 1 r
.84869 1 m
.84515 .99628 L
.82383 .9729 L
.80399 .95028 L
.78551 .92845 L
.76827 .90742 L
.75219 .88721 L
.73717 .86781 L
.72312 .84922 L
.70998 .83143 L
.69768 .81443 L
.68615 .79819 L
.67534 .7827 L
.6652 .76794 L
.65568 .75389 L
.64674 .74051 L
.63835 .72779 L
.63045 .7157 L
.62303 .70421 L
.61605 .6933 L
.60948 .68295 L
.60329 .67312 L
.59747 .66381 L
.59198 .65497 L
.58681 .6466 L
.58194 .63867 L
.57735 .63115 L
.57302 .62403 L
.56894 .61729 L
.5651 .61091 L
.56147 .60487 L
.55804 .59915 L
.55481 .59374 L
.55176 .58862 L
.54889 .58378 L
.54617 .57919 L
.54361 .57486 L
.54119 .57076 L
.53891 .56688 L
.53675 .56321 L
.53471 .55975 L
.53279 .55647 L
.53098 .55337 L
.52926 .55044 L
.52764 .54767 L
.52612 .54505 L
.52467 .54257 L
.52331 .54023 L
.52202 .53802 L
.5208 .53593 L
Mistroke
.51965 .53395 L
.51857 .53208 L
.51754 .53032 L
.51658 .52865 L
.51566 .52707 L
.5148 .52558 L
.51398 .52417 L
.51321 .52284 L
.51248 .52159 L
.51179 .5204 L
.51114 .51927 L
.51053 .51821 L
.50995 .51721 L
.5094 .51626 L
.50888 .51537 L
.50839 .51452 L
.50793 .51372 L
.50749 .51296 L
.50708 .51225 L
.50669 .51157 L
.50632 .51094 L
.50597 .51033 L
.50564 .50976 L
.50533 .50923 L
.50503 .50872 L
.50476 .50824 L
.5045 .50778 L
.50425 .50735 L
.50401 .50695 L
.50379 .50657 L
.50358 .5062 L
.50339 .50586 L
.5032 .50554 L
.50302 .50523 L
.50286 .50495 L
.5027 .50467 L
.50255 .50442 L
.50241 .50417 L
.50228 .50394 L
.50215 .50372 L
.50203 .50352 L
.50192 .50333 L
.50181 .50314 L
.50171 .50297 L
.50162 .50281 L
.50153 .50265 L
.50145 .5025 L
.50137 .50237 L
.50129 .50224 L
.50122 .50211 L
Mistroke
.50115 .502 L
.50109 .50189 L
.50103 .50178 L
.50097 .50168 L
.50092 .50159 L
.50087 .5015 L
.50082 .50142 L
.50078 .50134 L
.50073 .50127 L
.50069 .5012 L
.50065 .50113 L
.50062 .50107 L
.50058 .50101 L
.50055 .50096 L
.50052 .5009 L
.50049 .50085 L
.50047 .50081 L
.50044 .50076 L
.50042 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .50061 L
.50033 .50057 L
.50031 .50054 L
.5003 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50039 L
.50021 .50036 L
.5002 .50034 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50025 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50018 L
.5001 .50017 L
.5001 .50016 L
.50009 .50016 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
Mistroke
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
Mfstroke
1 0 .586 r
1 .768 m
.97678 .77364 L
.938 .7802 L
.90303 .78351 L
.87144 .78413 L
.84283 .78254 L
.81689 .77917 L
.79332 .77435 L
.77187 .76839 L
.7523 .76153 L
.73442 .75399 L
.71806 .74595 L
.70306 .73756 L
.68928 .72894 L
.67661 .72019 L
.66494 .71142 L
.65416 .70267 L
.64421 .69402 L
.635 .68551 L
.62647 .67718 L
.61855 .66906 L
.61119 .66116 L
.60435 .65351 L
.59798 .64611 L
.59205 .63898 L
.58651 .63212 L
.58134 .62554 L
.57651 .61922 L
.57199 .61317 L
.56776 .60738 L
.5638 .60185 L
.56009 .59658 L
.55661 .59155 L
.55334 .58676 L
.55027 .5822 L
.54739 .57786 L
.54468 .57373 L
.54214 .56981 L
.53974 .56609 L
.53749 .56255 L
.53537 .5592 L
.53337 .55602 L
.53149 .553 L
.52972 .55014 L
.52805 .54743 L
.52648 .54486 L
.525 .54242 L
.5236 .54012 L
.52228 .53794 L
.52104 .53587 L
Mistroke
.51987 .53392 L
.51876 .53207 L
.51772 .53032 L
.51673 .52866 L
.5158 .52709 L
.51493 .52561 L
.5141 .52421 L
.51332 .52288 L
.51258 .52163 L
.51188 .52044 L
.51122 .51932 L
.5106 .51826 L
.51001 .51726 L
.50946 .51631 L
.50894 .51541 L
.50844 .51457 L
.50798 .51377 L
.50754 .51301 L
.50712 .51229 L
.50673 .51162 L
.50635 .51098 L
.506 .51037 L
.50567 .5098 L
.50536 .50926 L
.50506 .50875 L
.50478 .50827 L
.50452 .50782 L
.50427 .50739 L
.50403 .50698 L
.50381 .5066 L
.5036 .50623 L
.5034 .50589 L
.50322 .50556 L
.50304 .50526 L
.50287 .50497 L
.50271 .50469 L
.50256 .50444 L
.50242 .50419 L
.50229 .50396 L
.50216 .50374 L
.50204 .50354 L
.50193 .50334 L
.50182 .50316 L
.50172 .50298 L
.50163 .50282 L
.50154 .50266 L
.50145 .50252 L
.50137 .50238 L
.5013 .50225 L
.50123 .50212 L
Mistroke
.50116 .50201 L
.50109 .5019 L
.50103 .50179 L
.50098 .50169 L
.50092 .5016 L
.50087 .50151 L
.50082 .50143 L
.50078 .50135 L
.50074 .50127 L
.5007 .5012 L
.50066 .50114 L
.50062 .50108 L
.50059 .50102 L
.50055 .50096 L
.50052 .50091 L
.50049 .50086 L
.50047 .50081 L
.50044 .50077 L
.50042 .50072 L
.50039 .50068 L
.50037 .50065 L
.50035 .50061 L
.50033 .50058 L
.50031 .50054 L
.5003 .50051 L
.50028 .50049 L
.50027 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
Mistroke
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
Mfstroke
1 .624 0 r
.06973 0 m
.07191 .0012 L
.101 .01918 L
.12775 .03745 L
.15239 .0558 L
.17512 .0741 L
.19613 .09221 L
.21556 .11005 L
.23356 .12751 L
.25026 .14456 L
.26577 .16113 L
.2802 .17719 L
.29362 .19271 L
.30613 .20768 L
.3178 .22209 L
.3287 .23594 L
.33888 .24921 L
.3484 .26193 L
.35731 .27409 L
.36566 .28571 L
.37348 .2968 L
.38081 .30738 L
.3877 .31745 L
.39416 .32705 L
.40023 .33617 L
.40593 .34485 L
.41129 .3531 L
.41633 .36093 L
.42108 .36837 L
.42554 .37542 L
.42975 .38212 L
.4337 .38847 L
.43743 .39449 L
.44095 .40019 L
.44426 .4056 L
.44738 .41072 L
.45032 .41556 L
.4531 .42015 L
.45571 .4245 L
.45818 .42862 L
.46051 .43251 L
.46271 .43619 L
.46478 .43968 L
.46674 .44298 L
.46858 .4461 L
.47033 .44905 L
.47197 .45184 L
.47353 .45448 L
.47499 .45698 L
.47638 .45934 L
Mistroke
.47769 .46157 L
.47892 .46368 L
.48009 .46567 L
.48119 .46756 L
.48223 .46934 L
.48321 .47103 L
.48414 .47262 L
.48502 .47412 L
.48584 .47555 L
.48662 .47689 L
.48736 .47816 L
.48806 .47937 L
.48872 .4805 L
.48934 .48158 L
.48993 .48259 L
.49049 .48355 L
.49101 .48445 L
.49151 .48531 L
.49198 .48612 L
.49242 .48688 L
.49284 .48761 L
.49323 .48829 L
.49361 .48893 L
.49396 .48954 L
.49429 .49012 L
.49461 .49066 L
.4949 .49118 L
.49518 .49166 L
.49545 .49212 L
.4957 .49256 L
.49594 .49297 L
.49616 .49336 L
.49637 .49372 L
.49657 .49407 L
.49676 .49439 L
.49694 .4947 L
.49711 .495 L
.49727 .49527 L
.49742 .49553 L
.49756 .49578 L
.4977 .49601 L
.49782 .49623 L
.49794 .49644 L
.49806 .49663 L
.49816 .49682 L
.49826 .497 L
.49836 .49716 L
.49845 .49732 L
.49854 .49747 L
.49862 .4976 L
Mistroke
.49869 .49774 L
.49877 .49786 L
.49883 .49798 L
.4989 .49809 L
.49896 .4982 L
.49902 .4983 L
.49907 .49839 L
.49912 .49848 L
.49917 .49856 L
.49922 .49864 L
.49926 .49872 L
.4993 .49879 L
.49934 .49885 L
.49937 .49892 L
.49941 .49898 L
.49944 .49903 L
.49947 .49909 L
.4995 .49914 L
.49953 .49918 L
.49956 .49923 L
.49958 .49927 L
.4996 .49931 L
.49962 .49935 L
.49965 .49939 L
.49966 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
Mistroke
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
Mfstroke
1 .118 0 r
.79542 1 m
.78534 .98353 L
.76937 .9573 L
.75432 .93246 L
.74012 .90893 L
.72672 .88667 L
.71409 .86559 L
.70217 .84564 L
.69092 .82677 L
.68031 .80891 L
.67029 .79201 L
.66084 .77603 L
.65192 .76092 L
.64349 .74662 L
.63554 .7331 L
.62803 .72032 L
.62094 .70823 L
.61425 .6968 L
.60793 .686 L
.60196 .67578 L
.59632 .66612 L
.59099 .65699 L
.58596 .64836 L
.58121 .64021 L
.57673 .6325 L
.57249 .62521 L
.56848 .61832 L
.5647 .61181 L
.56113 .60566 L
.55776 .59984 L
.55457 .59435 L
.55156 .58915 L
.54871 .58424 L
.54602 .57961 L
.54348 .57522 L
.54108 .57108 L
.53882 .56716 L
.53668 .56346 L
.53465 .55997 L
.53274 .55667 L
.53094 .55354 L
.52923 .55059 L
.52762 .54781 L
.5261 .54517 L
.52466 .54268 L
.5233 .54033 L
.52201 .53811 L
.5208 .53601 L
.51965 .53402 L
.51857 .53215 L
Mistroke
.51754 .53038 L
.51658 .5287 L
.51566 .52712 L
.5148 .52563 L
.51398 .52422 L
.51321 .52288 L
.51248 .52162 L
.5118 .52043 L
.51115 .5193 L
.51053 .51824 L
.50995 .51723 L
.5094 .51628 L
.50888 .51539 L
.50839 .51454 L
.50793 .51374 L
.50749 .51298 L
.50708 .51226 L
.50669 .51159 L
.50632 .51095 L
.50597 .51035 L
.50564 .50978 L
.50533 .50924 L
.50504 .50873 L
.50476 .50825 L
.5045 .50779 L
.50425 .50736 L
.50402 .50696 L
.5038 .50657 L
.50359 .50621 L
.50339 .50587 L
.5032 .50555 L
.50303 .50524 L
.50286 .50495 L
.5027 .50468 L
.50255 .50442 L
.50241 .50418 L
.50228 .50395 L
.50215 .50373 L
.50203 .50352 L
.50192 .50333 L
.50182 .50315 L
.50172 .50297 L
.50162 .50281 L
.50153 .50265 L
.50145 .50251 L
.50137 .50237 L
.50129 .50224 L
.50122 .50211 L
.50115 .502 L
.50109 .50189 L
Mistroke
.50103 .50178 L
.50097 .50169 L
.50092 .50159 L
.50087 .50151 L
.50082 .50142 L
.50078 .50134 L
.50073 .50127 L
.50069 .5012 L
.50065 .50113 L
.50062 .50107 L
.50058 .50101 L
.50055 .50096 L
.50052 .5009 L
.50049 .50085 L
.50047 .50081 L
.50044 .50076 L
.50042 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .50061 L
.50033 .50057 L
.50031 .50054 L
.5003 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50039 L
.50021 .50036 L
.5002 .50034 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50025 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50018 L
.5001 .50017 L
.5001 .50016 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
Mfstroke
.805 0 1 r
1 .80314 m
.97514 .80715 L
.93728 .81044 L
.90306 .81084 L
.87208 .80889 L
.84398 .80501 L
.81844 .7996 L
.79518 .79296 L
.77397 .78536 L
.75459 .77705 L
.73685 .7682 L
.72058 .75899 L
.70564 .74953 L
.69189 .73996 L
.67922 .73035 L
.66753 .72079 L
.65672 .71134 L
.64673 .70205 L
.63746 .69295 L
.62886 .68409 L
.62087 .67547 L
.61344 .66713 L
.60653 .65907 L
.60008 .6513 L
.59406 .64382 L
.58845 .63664 L
.5832 .62976 L
.57829 .62317 L
.57369 .61687 L
.56938 .61085 L
.56535 .6051 L
.56156 .59962 L
.55801 .59441 L
.55468 .58944 L
.55154 .58472 L
.5486 .58023 L
.54583 .57596 L
.54323 .57191 L
.54078 .56806 L
.53847 .56441 L
.5363 .56095 L
.53426 .55766 L
.53233 .55455 L
.53052 .5516 L
.5288 .5488 L
.52719 .54616 L
.52567 .54365 L
.52424 .54127 L
.52289 .53903 L
.52161 .5369 L
Mistroke
.52041 .53489 L
.51927 .53298 L
.5182 .53118 L
.51719 .52947 L
.51624 .52786 L
.51533 .52634 L
.51448 .52489 L
.51368 .52353 L
.51292 .52224 L
.51221 .52102 L
.51153 .51986 L
.51089 .51877 L
.51029 .51774 L
.50972 .51677 L
.50918 .51585 L
.50868 .51498 L
.5082 .51415 L
.50774 .51337 L
.50732 .51264 L
.50691 .51194 L
.50653 .51129 L
.50617 .51066 L
.50583 .51008 L
.50551 .50952 L
.5052 .509 L
.50492 .5085 L
.50465 .50804 L
.50439 .50759 L
.50415 .50717 L
.50392 .50678 L
.5037 .50641 L
.5035 .50605 L
.5033 .50572 L
.50312 .5054 L
.50295 .50511 L
.50279 .50483 L
.50263 .50456 L
.50249 .50431 L
.50235 .50407 L
.50222 .50385 L
.5021 .50363 L
.50198 .50343 L
.50187 .50325 L
.50177 .50307 L
.50167 .5029 L
.50158 .50274 L
.50149 .50259 L
.50141 .50244 L
.50133 .50231 L
.50126 .50218 L
Mistroke
.50119 .50206 L
.50113 .50195 L
.50106 .50184 L
.501 .50174 L
.50095 .50164 L
.5009 .50155 L
.50085 .50147 L
.5008 .50139 L
.50076 .50131 L
.50071 .50124 L
.50068 .50117 L
.50064 .50111 L
.5006 .50104 L
.50057 .50099 L
.50054 .50093 L
.50051 .50088 L
.50048 .50083 L
.50045 .50079 L
.50043 .50074 L
.50041 .5007 L
.50038 .50066 L
.50036 .50063 L
.50034 .50059 L
.50032 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.50019 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
Mistroke
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
Mfstroke
1 .225 0 r
.80083 1 m
.79084 .9844 L
.77437 .95845 L
.75887 .93384 L
.74427 .9105 L
.73052 .88836 L
.71757 .86738 L
.70536 .8475 L
.69386 .82867 L
.68301 .81083 L
.67278 .79394 L
.66314 .77795 L
.65404 .76281 L
.64546 .74848 L
.63736 .73492 L
.62972 .72208 L
.62251 .70995 L
.61571 .69846 L
.60929 .6876 L
.60323 .67732 L
.5975 .66761 L
.5921 .65842 L
.587 .64973 L
.58218 .64151 L
.57763 .63375 L
.57334 .6264 L
.56928 .61946 L
.56545 .61289 L
.56183 .60669 L
.55841 .60083 L
.55519 .59528 L
.55214 .59004 L
.54926 .58509 L
.54654 .58041 L
.54397 .57598 L
.54154 .5718 L
.53925 .56785 L
.53708 .56411 L
.53503 .56058 L
.5331 .55725 L
.53127 .5541 L
.52955 .55112 L
.52792 .5483 L
.52638 .54564 L
.52492 .54313 L
.52355 .54075 L
.52225 .53851 L
.52102 .53639 L
.51986 .53438 L
.51877 .53249 L
Mistroke
.51773 .5307 L
.51676 .52901 L
.51583 .52741 L
.51496 .5259 L
.51413 .52447 L
.51335 .52312 L
.51262 .52185 L
.51192 .52064 L
.51126 .51951 L
.51064 .51843 L
.51006 .51742 L
.5095 .51646 L
.50898 .51555 L
.50848 .51469 L
.50802 .51388 L
.50757 .51312 L
.50716 .51239 L
.50676 .51171 L
.50639 .51107 L
.50604 .51046 L
.5057 .50988 L
.50539 .50933 L
.50509 .50882 L
.50481 .50833 L
.50455 .50787 L
.5043 .50744 L
.50406 .50703 L
.50384 .50664 L
.50362 .50628 L
.50342 .50593 L
.50324 .5056 L
.50306 .5053 L
.50289 .505 L
.50273 .50473 L
.50258 .50447 L
.50244 .50422 L
.5023 .50399 L
.50218 .50377 L
.50206 .50356 L
.50194 .50336 L
.50184 .50318 L
.50173 .503 L
.50164 .50284 L
.50155 .50268 L
.50146 .50253 L
.50138 .50239 L
.50131 .50226 L
.50123 .50214 L
.50117 .50202 L
.5011 .50191 L
Mistroke
.50104 .5018 L
.50098 .5017 L
.50093 .50161 L
.50088 .50152 L
.50083 .50144 L
.50078 .50136 L
.50074 .50128 L
.5007 .50121 L
.50066 .50115 L
.50062 .50108 L
.50059 .50102 L
.50056 .50097 L
.50053 .50091 L
.5005 .50086 L
.50047 .50082 L
.50044 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50035 .50061 L
.50033 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
Mfstroke
1 .528 0 r
1 .96458 m
.96743 .95607 L
.93366 .94478 L
.90283 .93227 L
.87462 .91885 L
.84876 .90478 L
.82503 .89028 L
.80321 .87553 L
.78311 .8607 L
.76457 .8459 L
.74744 .83123 L
.7316 .81679 L
.71692 .80263 L
.70331 .78882 L
.69067 .77538 L
.67892 .76235 L
.66798 .74975 L
.65779 .7376 L
.64829 .7259 L
.63941 .71466 L
.63112 .70388 L
.62337 .69355 L
.61611 .68367 L
.60932 .67423 L
.60295 .66522 L
.59698 .65663 L
.59138 .64844 L
.58612 .64064 L
.58118 .63322 L
.57654 .62617 L
.57217 .61947 L
.56807 .6131 L
.56421 .60705 L
.56057 .60131 L
.55715 .59587 L
.55393 .59071 L
.5509 .58581 L
.54804 .58118 L
.54535 .57678 L
.54281 .57262 L
.54041 .56868 L
.53816 .56494 L
.53603 .56141 L
.53402 .55806 L
.53212 .55489 L
.53034 .5519 L
.52865 .54906 L
.52706 .54638 L
.52555 .54384 L
.52414 .54144 L
Mistroke
.5228 .53917 L
.52153 .53703 L
.52034 .53499 L
.51921 .53308 L
.51815 .53126 L
.51715 .52954 L
.5162 .52792 L
.5153 .52639 L
.51446 .52494 L
.51366 .52357 L
.5129 .52227 L
.51219 .52105 L
.51152 .51989 L
.51088 .5188 L
.51028 .51776 L
.50971 .51678 L
.50918 .51586 L
.50867 .51499 L
.50819 .51416 L
.50774 .51338 L
.50731 .51265 L
.50691 .51195 L
.50653 .51129 L
.50617 .51067 L
.50583 .51008 L
.50551 .50953 L
.5052 .509 L
.50491 .50851 L
.50464 .50804 L
.50439 .50759 L
.50415 .50718 L
.50392 .50678 L
.5037 .50641 L
.5035 .50605 L
.5033 .50572 L
.50312 .50541 L
.50295 .50511 L
.50279 .50483 L
.50263 .50456 L
.50249 .50431 L
.50235 .50407 L
.50222 .50385 L
.5021 .50363 L
.50198 .50343 L
.50187 .50325 L
.50177 .50307 L
.50167 .5029 L
.50158 .50274 L
.50149 .50259 L
.50141 .50244 L
Mistroke
.50133 .50231 L
.50126 .50218 L
.50119 .50206 L
.50112 .50195 L
.50106 .50184 L
.501 .50174 L
.50095 .50164 L
.5009 .50155 L
.50085 .50147 L
.5008 .50139 L
.50076 .50131 L
.50071 .50124 L
.50068 .50117 L
.50064 .50111 L
.5006 .50104 L
.50057 .50099 L
.50054 .50093 L
.50051 .50088 L
.50048 .50083 L
.50045 .50079 L
.50043 .50074 L
.50041 .5007 L
.50038 .50066 L
.50036 .50063 L
.50034 .50059 L
.50032 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.50019 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
Mistroke
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
Mfstroke
1 0 .326 r
1 .07387 m
.94321 .14799 L
.89344 .21127 L
.8498 .26521 L
.8115 .3111 L
.77785 .35007 L
.74825 .38307 L
.72219 .41095 L
.69922 .43443 L
.67895 .45414 L
.66103 .47061 L
.64518 .48431 L
.63113 .49565 L
.61867 .50496 L
.60759 .51255 L
.59772 .51867 L
.58893 .52354 L
.58107 .52736 L
.57405 .53028 L
.56775 .53245 L
.56209 .53399 L
.55701 .535 L
.55242 .53557 L
.54828 .53577 L
.54454 .53568 L
.54114 .53533 L
.53806 .5348 L
.53526 .5341 L
.53271 .53328 L
.53038 .53236 L
.52824 .53137 L
.52629 .53033 L
.5245 .52925 L
.52285 .52815 L
.52133 .52705 L
.51993 .52595 L
.51864 .52485 L
.51744 .52377 L
.51633 .52272 L
.51531 .52168 L
.51436 .52068 L
.51347 .5197 L
.51264 .51876 L
.51188 .51785 L
.51116 .51697 L
.51049 .51613 L
.50987 .51532 L
.50928 .51454 L
.50874 .5138 L
.50822 .51309 L
Mistroke
.50775 .51242 L
.5073 .51177 L
.50687 .51116 L
.50648 .51057 L
.50611 .51001 L
.50576 .50948 L
.50543 .50898 L
.50512 .5085 L
.50483 .50805 L
.50456 .50762 L
.5043 .50721 L
.50406 .50682 L
.50383 .50645 L
.50361 .5061 L
.50341 .50577 L
.50322 .50546 L
.50304 .50516 L
.50287 .50488 L
.50271 .50462 L
.50256 .50437 L
.50242 .50413 L
.50228 .5039 L
.50215 .50369 L
.50203 .50349 L
.50192 .5033 L
.50182 .50312 L
.50171 .50295 L
.50162 .50278 L
.50153 .50263 L
.50144 .50249 L
.50136 .50235 L
.50129 .50222 L
.50122 .5021 L
.50115 .50198 L
.50109 .50188 L
.50103 .50177 L
.50097 .50167 L
.50092 .50158 L
.50087 .5015 L
.50082 .50141 L
.50077 .50134 L
.50073 .50126 L
.50069 .50119 L
.50065 .50113 L
.50062 .50106 L
.50058 .50101 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .5008 L
Mistroke
.50044 .50076 L
.50041 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50023 .50041 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50016 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
Mistroke
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
Mfstroke
.514 1 0 r
.80847 1 m
.79508 .98032 L
.77812 .95505 L
.76219 .93102 L
.74721 .90816 L
.73313 .88645 L
.71989 .86583 L
.70743 .84625 L
.6957 .82768 L
.68466 .81006 L
.67426 .79335 L
.66446 .77751 L
.65523 .7625 L
.64653 .74828 L
.63833 .73481 L
.6306 .72206 L
.6233 .70998 L
.61643 .69855 L
.60994 .68772 L
.60382 .67748 L
.59804 .66779 L
.59259 .65862 L
.58745 .64995 L
.58259 .64174 L
.57801 .63398 L
.57368 .62664 L
.5696 .6197 L
.56575 .61313 L
.5621 .60693 L
.55867 .60106 L
.55542 .59551 L
.55235 .59026 L
.54946 .5853 L
.54672 .58062 L
.54414 .57618 L
.5417 .572 L
.5394 .56804 L
.53722 .56429 L
.53517 .56076 L
.53322 .55741 L
.53139 .55425 L
.52966 .55127 L
.52802 .54845 L
.52647 .54578 L
.52501 .54326 L
.52363 .54088 L
.52233 .53863 L
.5211 .5365 L
.51993 .53449 L
.51883 .53259 L
Mistroke
.51779 .53079 L
.51681 .5291 L
.51589 .52749 L
.51501 .52598 L
.51418 .52455 L
.5134 .5232 L
.51266 .52192 L
.51196 .52071 L
.5113 .51957 L
.51068 .51849 L
.51009 .51747 L
.50953 .51651 L
.50901 .5156 L
.50851 .51474 L
.50804 .51393 L
.5076 .51316 L
.50718 .51243 L
.50678 .51175 L
.50641 .5111 L
.50606 .51049 L
.50572 .50991 L
.50541 .50937 L
.50511 .50885 L
.50483 .50836 L
.50456 .5079 L
.50431 .50747 L
.50407 .50705 L
.50385 .50666 L
.50364 .5063 L
.50344 .50595 L
.50325 .50562 L
.50307 .50531 L
.5029 .50502 L
.50274 .50474 L
.50259 .50448 L
.50244 .50423 L
.50231 .504 L
.50218 .50378 L
.50206 .50357 L
.50195 .50338 L
.50184 .50319 L
.50174 .50301 L
.50164 .50285 L
.50155 .50269 L
.50147 .50254 L
.50139 .5024 L
.50131 .50227 L
.50124 .50214 L
.50117 .50203 L
.50111 .50191 L
Mistroke
.50104 .50181 L
.50099 .50171 L
.50093 .50162 L
.50088 .50153 L
.50083 .50144 L
.50079 .50136 L
.50074 .50129 L
.5007 .50122 L
.50066 .50115 L
.50063 .50109 L
.50059 .50103 L
.50056 .50097 L
.50053 .50092 L
.5005 .50087 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50036 .50062 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
Mfstroke
0 1 .337 r
0 .13265 m
.03262 .13285 L
.06839 .13575 L
.10086 .14081 L
.13038 .14759 L
.15726 .15574 L
.1818 .16494 L
.20423 .17494 L
.22477 .18552 L
.24361 .19649 L
.26092 .20771 L
.27686 .21905 L
.29155 .2304 L
.3051 .24168 L
.31764 .25281 L
.32925 .26374 L
.34 .27444 L
.34999 .28485 L
.35927 .29496 L
.3679 .30474 L
.37594 .31419 L
.38344 .32329 L
.39043 .33205 L
.39697 .34045 L
.40307 .3485 L
.40879 .35621 L
.41414 .36358 L
.41915 .37062 L
.42385 .37733 L
.42825 .38373 L
.43239 .38983 L
.43627 .39563 L
.43992 .40115 L
.44335 .40639 L
.44658 .41137 L
.44961 .41611 L
.45246 .4206 L
.45515 .42486 L
.45768 .4289 L
.46006 .43273 L
.46231 .43637 L
.46442 .43981 L
.46642 .44307 L
.46829 .44616 L
.47007 .44909 L
.47174 .45186 L
.47331 .45448 L
.4748 .45696 L
.4762 .45931 L
.47753 .46153 L
Mistroke
.47878 .46363 L
.47995 .46562 L
.48107 .4675 L
.48212 .46928 L
.48311 .47097 L
.48405 .47256 L
.48493 .47406 L
.48576 .47549 L
.48655 .47683 L
.4873 .4781 L
.488 .47931 L
.48866 .48044 L
.48929 .48152 L
.48988 .48253 L
.49044 .48349 L
.49097 .4844 L
.49147 .48526 L
.49194 .48607 L
.49238 .48684 L
.4928 .48756 L
.4932 .48825 L
.49358 .48889 L
.49393 .48951 L
.49427 .49008 L
.49458 .49063 L
.49488 .49115 L
.49516 .49163 L
.49543 .49209 L
.49568 .49253 L
.49592 .49294 L
.49615 .49333 L
.49636 .4937 L
.49656 .49404 L
.49675 .49437 L
.49693 .49468 L
.4971 .49498 L
.49726 .49525 L
.49741 .49551 L
.49755 .49576 L
.49769 .49599 L
.49781 .49622 L
.49793 .49642 L
.49805 .49662 L
.49816 .49681 L
.49826 .49698 L
.49835 .49715 L
.49844 .49731 L
.49853 .49746 L
.49861 .4976 L
.49869 .49773 L
Mistroke
.49876 .49785 L
.49883 .49797 L
.49889 .49808 L
.49895 .49819 L
.49901 .49829 L
.49907 .49838 L
.49912 .49847 L
.49917 .49856 L
.49921 .49864 L
.49926 .49871 L
.4993 .49878 L
.49934 .49885 L
.49937 .49891 L
.49941 .49897 L
.49944 .49903 L
.49947 .49908 L
.4995 .49913 L
.49953 .49918 L
.49955 .49923 L
.49958 .49927 L
.4996 .49931 L
.49962 .49935 L
.49964 .49938 L
.49966 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
Mistroke
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
1 .656 0 r
.76958 0 m
.73548 .06075 L
.70333 .11816 L
.67552 .16798 L
.65145 .21121 L
.63063 .24872 L
.61262 .28129 L
.59705 .30956 L
.58359 .33411 L
.57195 .35543 L
.5619 .37395 L
.55321 .39004 L
.5457 .40402 L
.53922 .41618 L
.53362 .42675 L
.52879 .43594 L
.52463 .44393 L
.52104 .45089 L
.51794 .45695 L
.51528 .46223 L
.51298 .46683 L
.51101 .47084 L
.50931 .47434 L
.50785 .47739 L
.5066 .48005 L
.50552 .48238 L
.5046 .48442 L
.50382 .4862 L
.50315 .48776 L
.50257 .48913 L
.50208 .49033 L
.50167 .49138 L
.50132 .49231 L
.50102 .49312 L
.50077 .49384 L
.50055 .49447 L
.50038 .49503 L
.50023 .49553 L
.50011 .49596 L
.5 .49635 L
.49992 .4967 L
.49985 .497 L
.4998 .49728 L
.49976 .49752 L
.49972 .49774 L
.4997 .49793 L
.49968 .49811 L
.49967 .49826 L
.49966 .4984 L
.49966 .49853 L
Mistroke
.49966 .49865 L
.49966 .49875 L
.49966 .49885 L
.49967 .49893 L
.49967 .49901 L
.49968 .49908 L
.49969 .49915 L
.4997 .49921 L
.49971 .49926 L
.49972 .49931 L
.49973 .49936 L
.49974 .4994 L
.49975 .49944 L
.49976 .49947 L
.49977 .49951 L
.49978 .49954 L
.49979 .49957 L
.4998 .49959 L
.49981 .49962 L
.49982 .49964 L
.49983 .49966 L
.49984 .49968 L
.49985 .4997 L
.49986 .49972 L
.49986 .49974 L
.49987 .49975 L
.49988 .49977 L
.49988 .49978 L
.49989 .49979 L
.49989 .49981 L
.4999 .49982 L
.49991 .49983 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
Mistroke
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.496 1 0 r
.79055 1 m
.78917 .99765 L
.77315 .97034 L
.75803 .94452 L
.74376 .92012 L
.73027 .89704 L
.71754 .87523 L
.70551 .8546 L
.69415 .83511 L
.68343 .81668 L
.67329 .79927 L
.66372 .78281 L
.65468 .76725 L
.64614 .75254 L
.63807 .73865 L
.63045 .72551 L
.62325 .7131 L
.61644 .70137 L
.61002 .69028 L
.60395 .6798 L
.59821 .6699 L
.59279 .66054 L
.58768 .6517 L
.58284 .64334 L
.57827 .63545 L
.57395 .62799 L
.56987 .62094 L
.56602 .61427 L
.56238 .60798 L
.55894 .60203 L
.55569 .59641 L
.55262 .59109 L
.54972 .58608 L
.54698 .58133 L
.54439 .57685 L
.54194 .57262 L
.53963 .56861 L
.53744 .56483 L
.53538 .56126 L
.53343 .55788 L
.53158 .55469 L
.52984 .55168 L
.5282 .54883 L
.52664 .54614 L
.52517 .5436 L
.52379 .54119 L
.52248 .53892 L
.52124 .53678 L
.52007 .53475 L
.51896 .53284 L
Mistroke
.51791 .53103 L
.51693 .52932 L
.51599 .5277 L
.51511 .52617 L
.51428 .52473 L
.51349 .52337 L
.51275 .52208 L
.51205 .52086 L
.51138 .51971 L
.51075 .51863 L
.51016 .5176 L
.5096 .51663 L
.50907 .51571 L
.50857 .51485 L
.5081 .51403 L
.50765 .51325 L
.50723 .51252 L
.50683 .51183 L
.50646 .51118 L
.5061 .51057 L
.50576 .50998 L
.50545 .50943 L
.50515 .50891 L
.50486 .50842 L
.50459 .50796 L
.50434 .50752 L
.5041 .5071 L
.50388 .50671 L
.50366 .50634 L
.50346 .50599 L
.50327 .50566 L
.50309 .50535 L
.50292 .50506 L
.50276 .50478 L
.50261 .50451 L
.50246 .50426 L
.50233 .50403 L
.5022 .50381 L
.50208 .5036 L
.50196 .5034 L
.50185 .50321 L
.50175 .50304 L
.50166 .50287 L
.50156 .50271 L
.50148 .50256 L
.5014 .50242 L
.50132 .50229 L
.50125 .50216 L
.50118 .50204 L
.50111 .50193 L
Mistroke
.50105 .50182 L
.50099 .50172 L
.50094 .50163 L
.50089 .50154 L
.50084 .50145 L
.50079 .50137 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50063 .50109 L
.5006 .50103 L
.50056 .50098 L
.50053 .50092 L
.5005 .50087 L
.50048 .50082 L
.50045 .50078 L
.50042 .50074 L
.5004 .50069 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50055 L
.5003 .50052 L
.50029 .50049 L
.50027 .50047 L
.50025 .50044 L
.50024 .50042 L
.50023 .50039 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
Mfstroke
.782 1 0 r
.20028 0 m
.21697 .0264 L
.23295 .05185 L
.248 .07599 L
.26217 .09888 L
.27552 .12056 L
.28811 .14111 L
.29997 .16057 L
.31116 .17901 L
.3217 .19646 L
.33165 .21299 L
.34104 .22863 L
.34989 .24343 L
.35824 .25744 L
.36612 .27069 L
.37356 .28323 L
.38058 .29509 L
.38721 .30631 L
.39346 .31692 L
.39937 .32696 L
.40494 .33645 L
.41021 .34542 L
.41518 .3539 L
.41987 .36192 L
.4243 .36951 L
.42849 .37668 L
.43244 .38345 L
.43618 .38986 L
.43971 .39591 L
.44304 .40164 L
.44618 .40705 L
.44916 .41216 L
.45196 .41699 L
.45462 .42156 L
.45712 .42588 L
.45949 .42996 L
.46172 .43381 L
.46384 .43746 L
.46583 .4409 L
.46772 .44416 L
.4695 .44723 L
.47118 .45014 L
.47277 .45288 L
.47427 .45548 L
.47569 .45793 L
.47703 .46025 L
.4783 .46244 L
.4795 .46451 L
.48063 .46646 L
.48169 .46831 L
Mistroke
.4827 .47006 L
.48366 .47171 L
.48456 .47327 L
.48541 .47474 L
.48621 .47613 L
.48697 .47745 L
.48769 .47869 L
.48837 .47986 L
.48901 .48097 L
.48962 .48202 L
.49019 .48301 L
.49073 .48395 L
.49124 .48483 L
.49173 .48567 L
.49218 .48646 L
.49261 .48721 L
.49302 .48791 L
.4934 .48858 L
.49377 .48921 L
.49411 .4898 L
.49444 .49036 L
.49474 .4909 L
.49503 .4914 L
.49531 .49187 L
.49557 .49232 L
.49581 .49274 L
.49604 .49314 L
.49626 .49352 L
.49647 .49388 L
.49666 .49422 L
.49684 .49453 L
.49702 .49484 L
.49718 .49512 L
.49734 .49539 L
.49748 .49564 L
.49762 .49588 L
.49775 .49611 L
.49788 .49632 L
.49799 .49653 L
.49811 .49672 L
.49821 .4969 L
.49831 .49707 L
.4984 .49723 L
.49849 .49738 L
.49857 .49753 L
.49865 .49766 L
.49873 .49779 L
.4988 .49792 L
.49886 .49803 L
.49893 .49814 L
Mistroke
.49898 .49824 L
.49904 .49834 L
.49909 .49843 L
.49914 .49852 L
.49919 .4986 L
.49924 .49868 L
.49928 .49875 L
.49932 .49882 L
.49935 .49888 L
.49939 .49894 L
.49942 .499 L
.49946 .49906 L
.49949 .49911 L
.49951 .49916 L
.49954 .4992 L
.49957 .49925 L
.49959 .49929 L
.49961 .49933 L
.49963 .49937 L
.49965 .4994 L
.49967 .49943 L
.49969 .49947 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .4997 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49988 .49978 L
.49988 .4998 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
Mistroke
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
Mfstroke
0 1 .062 r
.79713 1 m
.78123 .97432 L
.76543 .94868 L
.75055 .92438 L
.73653 .90136 L
.7233 .87956 L
.71083 .85892 L
.69907 .83938 L
.68797 .82089 L
.6775 .80338 L
.66763 .78682 L
.65831 .77115 L
.64951 .75632 L
.64121 .7423 L
.63338 .72903 L
.62598 .71648 L
.619 .70462 L
.6124 .6934 L
.60618 .68279 L
.6003 .67276 L
.59475 .66327 L
.58951 .65431 L
.58456 .64583 L
.57988 .63781 L
.57547 .63024 L
.5713 .62308 L
.56736 .61631 L
.56364 .60991 L
.56012 .60387 L
.5568 .59815 L
.55367 .59275 L
.5507 .58765 L
.5479 .58282 L
.54526 .57826 L
.54276 .57395 L
.5404 .56988 L
.53817 .56603 L
.53607 .5624 L
.53408 .55896 L
.5322 .55571 L
.53042 .55264 L
.52874 .54974 L
.52716 .547 L
.52566 .54441 L
.52425 .54197 L
.52291 .53966 L
.52165 .53747 L
.52045 .53541 L
.51932 .53345 L
.51826 .53161 L
Mistroke
.51725 .52987 L
.5163 .52822 L
.5154 .52667 L
.51455 .5252 L
.51375 .52381 L
.51299 .5225 L
.51228 .52126 L
.5116 .52009 L
.51096 .51898 L
.51036 .51793 L
.50978 .51694 L
.50925 .51601 L
.50874 .51513 L
.50825 .51429 L
.5078 .51351 L
.50737 .51276 L
.50696 .51206 L
.50658 .51139 L
.50622 .51077 L
.50587 .51017 L
.50555 .50961 L
.50524 .50908 L
.50495 .50858 L
.50468 .50811 L
.50442 .50766 L
.50418 .50724 L
.50395 .50684 L
.50373 .50646 L
.50353 .50611 L
.50333 .50577 L
.50315 .50545 L
.50297 .50515 L
.50281 .50487 L
.50266 .5046 L
.50251 .50435 L
.50237 .50411 L
.50224 .50388 L
.50212 .50367 L
.502 .50346 L
.50189 .50327 L
.50179 .50309 L
.50169 .50292 L
.50159 .50276 L
.50151 .50261 L
.50142 .50247 L
.50134 .50233 L
.50127 .5022 L
.5012 .50208 L
.50113 .50196 L
.50107 .50186 L
Mistroke
.50101 .50175 L
.50096 .50166 L
.5009 .50157 L
.50085 .50148 L
.50081 .5014 L
.50076 .50132 L
.50072 .50125 L
.50068 .50118 L
.50064 .50111 L
.50061 .50105 L
.50057 .501 L
.50054 .50094 L
.50051 .50089 L
.50048 .50084 L
.50046 .50079 L
.50043 .50075 L
.50041 .50071 L
.50039 .50067 L
.50037 .50063 L
.50034 .5006 L
.50033 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50018 .50032 L
.50017 .5003 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50012 .50022 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
Mfstroke
0 1 .395 r
.8499 1 m
.83951 .98904 L
.81855 .96596 L
.79905 .94364 L
.78089 .9221 L
.76395 .90136 L
.74814 .88142 L
.73336 .86229 L
.71955 .84396 L
.70663 .82643 L
.69453 .80967 L
.68319 .79367 L
.67256 .7784 L
.66258 .76386 L
.65322 .75001 L
.64442 .73683 L
.63616 .7243 L
.6284 .71239 L
.62109 .70107 L
.61422 .69033 L
.60776 .68013 L
.60167 .67046 L
.59594 .66128 L
.59054 .65258 L
.58545 .64434 L
.58066 .63653 L
.57614 .62913 L
.57188 .62212 L
.56787 .61548 L
.56408 .60919 L
.56051 .60325 L
.55713 .59762 L
.55396 .59229 L
.55095 .58725 L
.54812 .58248 L
.54545 .57796 L
.54293 .5737 L
.54055 .56966 L
.5383 .56584 L
.53618 .56223 L
.53417 .55882 L
.53228 .55559 L
.53049 .55254 L
.52881 .54965 L
.52721 .54693 L
.52571 .54435 L
.52429 .54191 L
.52295 .53961 L
.52168 .53743 L
.52048 .53537 L
Mistroke
.51935 .53343 L
.51828 .53159 L
.51727 .52985 L
.51632 .52821 L
.51542 .52665 L
.51457 .52519 L
.51376 .5238 L
.513 .52249 L
.51229 .52125 L
.51161 .52008 L
.51097 .51897 L
.51036 .51793 L
.50979 .51694 L
.50925 .51601 L
.50874 .51513 L
.50826 .51429 L
.5078 .51351 L
.50737 .51276 L
.50697 .51206 L
.50658 .51139 L
.50622 .51077 L
.50588 .51017 L
.50555 .50961 L
.50525 .50908 L
.50496 .50858 L
.50468 .50811 L
.50443 .50766 L
.50418 .50724 L
.50395 .50684 L
.50373 .50646 L
.50353 .50611 L
.50333 .50577 L
.50315 .50545 L
.50298 .50515 L
.50281 .50487 L
.50266 .5046 L
.50251 .50435 L
.50237 .50411 L
.50224 .50388 L
.50212 .50367 L
.502 .50346 L
.50189 .50327 L
.50179 .50309 L
.50169 .50292 L
.50159 .50276 L
.50151 .50261 L
.50142 .50247 L
.50135 .50233 L
.50127 .5022 L
.5012 .50208 L
Mistroke
.50113 .50197 L
.50107 .50186 L
.50101 .50175 L
.50096 .50166 L
.5009 .50157 L
.50085 .50148 L
.50081 .5014 L
.50076 .50132 L
.50072 .50125 L
.50068 .50118 L
.50064 .50111 L
.50061 .50105 L
.50057 .501 L
.50054 .50094 L
.50051 .50089 L
.50048 .50084 L
.50046 .50079 L
.50043 .50075 L
.50041 .50071 L
.50039 .50067 L
.50037 .50063 L
.50034 .5006 L
.50033 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50018 .50032 L
.50017 .5003 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50012 .50022 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
Mistroke
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
Mfstroke
.264 0 1 r
.79151 1 m
.78852 .99496 L
.77251 .96787 L
.7574 .94224 L
.74313 .918 L
.72966 .89509 L
.71694 .87341 L
.70493 .85292 L
.69358 .83355 L
.68287 .81523 L
.67276 .79791 L
.66321 .78154 L
.65419 .76607 L
.64566 .75144 L
.63762 .73762 L
.63001 .72455 L
.62283 .7122 L
.61605 .70052 L
.60964 .68949 L
.60359 .67906 L
.59787 .6692 L
.59247 .65989 L
.58737 .65109 L
.58254 .64277 L
.57799 .63491 L
.57369 .62748 L
.56962 .62046 L
.56578 .61382 L
.56215 .60755 L
.55872 .60163 L
.55549 .59603 L
.55243 .59074 L
.54953 .58574 L
.5468 .58102 L
.54422 .57655 L
.54178 .57233 L
.53948 .56835 L
.5373 .56458 L
.53525 .56102 L
.5333 .55766 L
.53147 .55448 L
.52973 .55148 L
.52809 .54864 L
.52654 .54596 L
.52508 .54343 L
.5237 .54104 L
.52239 .53877 L
.52116 .53664 L
.51999 .53462 L
.51889 .53271 L
Mistroke
.51785 .53091 L
.51686 .5292 L
.51593 .52759 L
.51505 .52607 L
.51423 .52464 L
.51344 .52328 L
.5127 .522 L
.512 .52078 L
.51134 .51964 L
.51071 .51855 L
.51012 .51753 L
.50956 .51657 L
.50904 .51565 L
.50854 .51479 L
.50807 .51397 L
.50762 .5132 L
.5072 .51248 L
.50681 .51179 L
.50643 .51114 L
.50608 .51053 L
.50574 .50995 L
.50543 .5094 L
.50513 .50888 L
.50484 .50839 L
.50458 .50793 L
.50432 .50749 L
.50409 .50708 L
.50386 .50669 L
.50365 .50632 L
.50345 .50597 L
.50326 .50564 L
.50308 .50533 L
.50291 .50504 L
.50275 .50476 L
.5026 .5045 L
.50245 .50425 L
.50232 .50401 L
.50219 .50379 L
.50207 .50358 L
.50196 .50339 L
.50185 .5032 L
.50175 .50302 L
.50165 .50286 L
.50156 .5027 L
.50147 .50255 L
.50139 .50241 L
.50131 .50228 L
.50124 .50215 L
.50117 .50203 L
.50111 .50192 L
Mistroke
.50105 .50182 L
.50099 .50172 L
.50094 .50162 L
.50088 .50153 L
.50084 .50145 L
.50079 .50137 L
.50075 .50129 L
.5007 .50122 L
.50067 .50115 L
.50063 .50109 L
.50059 .50103 L
.50056 .50097 L
.50053 .50092 L
.5005 .50087 L
.50047 .50082 L
.50045 .50078 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50036 .50062 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50047 L
.50025 .50044 L
.50024 .50042 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .5003 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50005 .5001 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
Mfstroke
1 0 .533 r
1 .86771 m
.96358 .86719 L
.92817 .86402 L
.89602 .85876 L
.86679 .8518 L
.84016 .84352 L
.81585 .83422 L
.79362 .82414 L
.77326 .8135 L
.75458 .80248 L
.73742 .79123 L
.72162 .77988 L
.70705 .76853 L
.6936 .75726 L
.68116 .74614 L
.66964 .73522 L
.65897 .72455 L
.64905 .71417 L
.63984 .70409 L
.63127 .69433 L
.62329 .68491 L
.61584 .67584 L
.6089 .66712 L
.60241 .65875 L
.59634 .65073 L
.59067 .64306 L
.58535 .63572 L
.58037 .62871 L
.57571 .62203 L
.57133 .61566 L
.56722 .60959 L
.56336 .60382 L
.55973 .59833 L
.55632 .59311 L
.55312 .58815 L
.5501 .58344 L
.54727 .57897 L
.54459 .57473 L
.54208 .57071 L
.53971 .5669 L
.53748 .56329 L
.53538 .55986 L
.53339 .55662 L
.53153 .55355 L
.52976 .55064 L
.5281 .54788 L
.52654 .54527 L
.52506 .5428 L
.52366 .54047 L
.52235 .53826 L
Mistroke
.5211 .53617 L
.51993 .53419 L
.51883 .53232 L
.51778 .53055 L
.5168 .52887 L
.51587 .52729 L
.51499 .52579 L
.51416 .52438 L
.51337 .52304 L
.51263 .52177 L
.51193 .52058 L
.51127 .51945 L
.51065 .51838 L
.51006 .51737 L
.50951 .51641 L
.50898 .51551 L
.50849 .51466 L
.50802 .51385 L
.50757 .51309 L
.50716 .51237 L
.50676 .51169 L
.50639 .51104 L
.50604 .51044 L
.5057 .50986 L
.50539 .50932 L
.50509 .50881 L
.50481 .50832 L
.50454 .50786 L
.50429 .50743 L
.50406 .50702 L
.50383 .50663 L
.50362 .50627 L
.50342 .50592 L
.50323 .5056 L
.50305 .50529 L
.50289 .505 L
.50273 .50472 L
.50258 .50446 L
.50243 .50422 L
.5023 .50398 L
.50217 .50376 L
.50205 .50356 L
.50194 .50336 L
.50183 .50318 L
.50173 .503 L
.50164 .50283 L
.50155 .50268 L
.50146 .50253 L
.50138 .50239 L
.5013 .50226 L
Mistroke
.50123 .50214 L
.50116 .50202 L
.5011 .50191 L
.50104 .5018 L
.50098 .5017 L
.50093 .50161 L
.50088 .50152 L
.50083 .50144 L
.50078 .50136 L
.50074 .50128 L
.5007 .50121 L
.50066 .50114 L
.50062 .50108 L
.50059 .50102 L
.50056 .50097 L
.50053 .50091 L
.5005 .50086 L
.50047 .50081 L
.50044 .50077 L
.50042 .50073 L
.5004 .50069 L
.50037 .50065 L
.50035 .50061 L
.50033 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50022 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
Mistroke
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
Mfstroke
1 0 .855 r
.79811 1 m
.79625 .99703 L
.77955 .97027 L
.76383 .94489 L
.74901 .92084 L
.73505 .89805 L
.72189 .87647 L
.70948 .85602 L
.69778 .83667 L
.68674 .81834 L
.67634 .80099 L
.66652 .78458 L
.65725 .76904 L
.64851 .75434 L
.64026 .74043 L
.63247 .72728 L
.62512 .71484 L
.61818 .70307 L
.61163 .69194 L
.60544 .68141 L
.5996 .67146 L
.59409 .66205 L
.58888 .65315 L
.58396 .64474 L
.57932 .63679 L
.57493 .62927 L
.57079 .62217 L
.56688 .61545 L
.56319 .6091 L
.55969 .6031 L
.5564 .59743 L
.55328 .59207 L
.55034 .587 L
.54756 .58222 L
.54494 .57769 L
.54246 .57341 L
.54011 .56937 L
.5379 .56555 L
.53581 .56194 L
.53383 .55853 L
.53197 .55531 L
.5302 .55226 L
.52854 .54938 L
.52696 .54666 L
.52548 .54409 L
.52407 .54166 L
.52274 .53937 L
.52149 .5372 L
.5203 .53515 L
.51918 .53321 L
Mistroke
.51813 .53138 L
.51713 .52965 L
.51618 .52802 L
.51529 .52647 L
.51445 .52502 L
.51365 .52364 L
.5129 .52233 L
.51219 .5211 L
.51152 .51994 L
.51088 .51884 L
.51028 .5178 L
.50971 .51682 L
.50918 .51589 L
.50867 .51502 L
.50819 .51419 L
.50774 .51341 L
.50732 .51267 L
.50691 .51197 L
.50653 .51131 L
.50617 .51069 L
.50583 .5101 L
.50551 .50954 L
.50521 .50902 L
.50492 .50852 L
.50465 .50805 L
.50439 .50761 L
.50415 .50719 L
.50392 .50679 L
.5037 .50642 L
.5035 .50606 L
.50331 .50573 L
.50313 .50541 L
.50295 .50511 L
.50279 .50483 L
.50264 .50457 L
.50249 .50431 L
.50235 .50408 L
.50222 .50385 L
.5021 .50364 L
.50199 .50344 L
.50188 .50325 L
.50177 .50307 L
.50168 .5029 L
.50158 .50274 L
.5015 .50259 L
.50141 .50245 L
.50134 .50231 L
.50126 .50219 L
.50119 .50206 L
.50113 .50195 L
Mistroke
.50106 .50184 L
.50101 .50174 L
.50095 .50165 L
.5009 .50155 L
.50085 .50147 L
.5008 .50139 L
.50076 .50131 L
.50072 .50124 L
.50068 .50117 L
.50064 .50111 L
.5006 .50105 L
.50057 .50099 L
.50054 .50093 L
.50051 .50088 L
.50048 .50083 L
.50045 .50079 L
.50043 .50074 L
.50041 .5007 L
.50038 .50066 L
.50036 .50063 L
.50034 .50059 L
.50032 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.50019 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
Mfstroke
0 .602 1 r
.20339 0 m
.21941 .02598 L
.23515 .05164 L
.24998 .07595 L
.26397 .09897 L
.27715 .12077 L
.28959 .14141 L
.30132 .16094 L
.31239 .17943 L
.32283 .19693 L
.33268 .21349 L
.34198 .22915 L
.35075 .24397 L
.35903 .25799 L
.36685 .27124 L
.37423 .28378 L
.3812 .29563 L
.38778 .30684 L
.394 .31744 L
.39986 .32747 L
.4054 .33694 L
.41063 .3459 L
.41558 .35436 L
.42024 .36237 L
.42465 .36994 L
.42881 .37709 L
.43275 .38385 L
.43646 .39024 L
.43997 .39628 L
.44329 .40198 L
.44642 .40738 L
.44937 .41248 L
.45217 .41729 L
.45481 .42185 L
.4573 .42615 L
.45966 .43022 L
.46188 .43406 L
.46399 .43769 L
.46597 .44112 L
.46785 .44437 L
.46962 .44743 L
.4713 .45033 L
.47288 .45306 L
.47438 .45565 L
.47579 .45809 L
.47713 .4604 L
.47839 .46258 L
.47958 .46465 L
.4807 .46659 L
.48177 .46843 L
Mistroke
.48277 .47017 L
.48372 .47182 L
.48462 .47337 L
.48547 .47484 L
.48627 .47622 L
.48703 .47754 L
.48774 .47877 L
.48842 .47994 L
.48906 .48105 L
.48966 .48209 L
.49023 .48308 L
.49077 .48401 L
.49128 .48489 L
.49176 .48573 L
.49221 .48651 L
.49264 .48726 L
.49305 .48796 L
.49343 .48862 L
.49379 .48925 L
.49413 .48984 L
.49446 .4904 L
.49476 .49093 L
.49505 .49143 L
.49533 .4919 L
.49558 .49235 L
.49583 .49277 L
.49606 .49317 L
.49627 .49355 L
.49648 .4939 L
.49667 .49424 L
.49686 .49456 L
.49703 .49486 L
.49719 .49514 L
.49735 .49541 L
.49749 .49566 L
.49763 .4959 L
.49776 .49613 L
.49789 .49634 L
.498 .49654 L
.49811 .49673 L
.49822 .49691 L
.49832 .49708 L
.49841 .49724 L
.4985 .49739 L
.49858 .49754 L
.49866 .49767 L
.49873 .4978 L
.4988 .49792 L
.49887 .49804 L
.49893 .49815 L
Mistroke
.49899 .49825 L
.49904 .49834 L
.4991 .49844 L
.49915 .49852 L
.49919 .4986 L
.49924 .49868 L
.49928 .49875 L
.49932 .49882 L
.49936 .49889 L
.49939 .49895 L
.49943 .49901 L
.49946 .49906 L
.49949 .49911 L
.49952 .49916 L
.49954 .49921 L
.49957 .49925 L
.49959 .49929 L
.49961 .49933 L
.49964 .49937 L
.49966 .4994 L
.49967 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49952 L
.49974 .49955 L
.49975 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49971 L
.49984 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
Mistroke
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
Mfstroke
0 .03 1 r
.65487 0 m
.63318 .04807 L
.61039 .09974 L
.59093 .14498 L
.57432 .18464 L
.56017 .21942 L
.54815 .24997 L
.53795 .27682 L
.52932 .30045 L
.52204 .32126 L
.51592 .33961 L
.51079 .35582 L
.50651 .37015 L
.50295 .38284 L
.50002 .39409 L
.49763 .40408 L
.49568 .41296 L
.49412 .42088 L
.49288 .42794 L
.49192 .43426 L
.4912 .43991 L
.49067 .44498 L
.4903 .44953 L
.49007 .45363 L
.48996 .45733 L
.48994 .46068 L
.49 .4637 L
.49012 .46645 L
.4903 .46894 L
.49051 .47121 L
.49075 .47328 L
.49102 .47517 L
.4913 .47691 L
.4916 .47849 L
.49191 .47995 L
.49222 .48129 L
.49253 .48253 L
.49284 .48367 L
.49314 .48472 L
.49344 .4857 L
.49374 .4866 L
.49403 .48744 L
.49431 .48822 L
.49458 .48894 L
.49484 .48962 L
.49509 .49025 L
.49533 .49083 L
.49556 .49138 L
.49579 .49189 L
.496 .49237 L
Mistroke
.49621 .49282 L
.4964 .49324 L
.49659 .49363 L
.49677 .494 L
.49694 .49435 L
.4971 .49467 L
.49725 .49498 L
.4974 .49527 L
.49753 .49554 L
.49767 .49579 L
.49779 .49603 L
.49791 .49625 L
.49802 .49646 L
.49813 .49666 L
.49823 .49685 L
.49832 .49703 L
.49842 .49719 L
.4985 .49735 L
.49858 .4975 L
.49866 .49764 L
.49873 .49777 L
.4988 .49789 L
.49887 .49801 L
.49893 .49812 L
.49899 .49823 L
.49904 .49833 L
.4991 .49842 L
.49914 .49851 L
.49919 .49859 L
.49924 .49867 L
.49928 .49874 L
.49932 .49881 L
.49936 .49888 L
.49939 .49894 L
.49942 .499 L
.49946 .49905 L
.49949 .49911 L
.49951 .49915 L
.49954 .4992 L
.49957 .49925 L
.49959 .49929 L
.49961 .49933 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
Mistroke
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .4997 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49988 .49978 L
.49988 .4998 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 .596 1 r
.87463 1 m
.85144 .97906 L
.82913 .95774 L
.80845 .93691 L
.78925 .91664 L
.77139 .89698 L
.75478 .87796 L
.7393 .85961 L
.72487 .84194 L
.7114 .82496 L
.69881 .80866 L
.68705 .79304 L
.67604 .7781 L
.66573 .76382 L
.65607 .75019 L
.64701 .73719 L
.63851 .7248 L
.63053 .713 L
.62304 .70177 L
.616 .6911 L
.60939 .68095 L
.60316 .67131 L
.59731 .66215 L
.5918 .65347 L
.58662 .64522 L
.58173 .63741 L
.57713 .63 L
.5728 .62297 L
.56872 .61632 L
.56487 .61001 L
.56124 .60404 L
.55782 .59838 L
.55459 .59303 L
.55155 .58796 L
.54868 .58316 L
.54597 .57863 L
.54341 .57433 L
.541 .57027 L
.53872 .56642 L
.53657 .56279 L
.53454 .55935 L
.53263 .5561 L
.53082 .55302 L
.52911 .55011 L
.5275 .54736 L
.52598 .54476 L
.52454 .5423 L
.52319 .53998 L
.5219 .53778 L
.52069 .53571 L
Mistroke
.51955 .53374 L
.51847 .53189 L
.51745 .53013 L
.51648 .52848 L
.51557 .52691 L
.51471 .52543 L
.5139 .52403 L
.51313 .52271 L
.51241 .52146 L
.51172 .52028 L
.51108 .51916 L
.51047 .5181 L
.50989 .51711 L
.50934 .51617 L
.50883 .51527 L
.50834 .51443 L
.50788 .51364 L
.50745 .51289 L
.50704 .51218 L
.50665 .51151 L
.50628 .51087 L
.50593 .51027 L
.50561 .50971 L
.5053 .50917 L
.50501 .50867 L
.50473 .50819 L
.50447 .50774 L
.50422 .50731 L
.50399 .50691 L
.50377 .50653 L
.50356 .50617 L
.50337 .50583 L
.50318 .50551 L
.503 .5052 L
.50284 .50492 L
.50268 .50465 L
.50253 .50439 L
.5024 .50415 L
.50226 .50392 L
.50214 .5037 L
.50202 .5035 L
.50191 .50331 L
.5018 .50312 L
.5017 .50295 L
.50161 .50279 L
.50152 .50264 L
.50144 .50249 L
.50136 .50235 L
.50128 .50222 L
.50121 .5021 L
Mistroke
.50115 .50198 L
.50108 .50188 L
.50102 .50177 L
.50097 .50167 L
.50091 .50158 L
.50086 .50149 L
.50082 .50141 L
.50077 .50133 L
.50073 .50126 L
.50069 .50119 L
.50065 .50113 L
.50061 .50106 L
.50058 .50101 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .5008 L
.50044 .50076 L
.50041 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .50041 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
Mistroke
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
Mfstroke
.849 1 0 r
.30446 0 m
.30953 .02475 L
.31674 .05664 L
.32399 .08602 L
.33122 .11311 L
.33839 .13815 L
.34544 .1613 L
.35235 .18275 L
.3591 .20265 L
.36566 .22113 L
.37202 .23831 L
.37817 .25431 L
.3841 .26921 L
.38981 .28311 L
.39529 .29608 L
.40055 .30821 L
.40559 .31955 L
.41041 .33016 L
.41502 .34009 L
.41942 .34941 L
.42361 .35814 L
.4276 .36633 L
.43141 .37403 L
.43503 .38125 L
.43847 .38804 L
.44174 .39442 L
.44484 .40042 L
.44779 .40607 L
.45059 .41139 L
.45325 .41639 L
.45576 .4211 L
.45815 .42554 L
.46041 .42972 L
.46256 .43366 L
.46459 .43738 L
.46651 .44088 L
.46833 .44418 L
.47005 .4473 L
.47169 .45023 L
.47323 .45301 L
.47469 .45562 L
.47607 .45809 L
.47738 .46042 L
.47862 .46261 L
.47979 .46469 L
.4809 .46665 L
.48194 .4685 L
.48293 .47024 L
.48387 .47189 L
.48476 .47345 L
Mistroke
.48559 .47492 L
.48638 .4763 L
.48713 .47761 L
.48784 .47885 L
.48851 .48002 L
.48914 .48113 L
.48974 .48217 L
.4903 .48315 L
.49083 .48408 L
.49134 .48496 L
.49182 .48579 L
.49227 .48658 L
.49269 .48732 L
.49309 .48802 L
.49347 .48868 L
.49383 .4893 L
.49417 .48989 L
.49449 .49045 L
.4948 .49098 L
.49508 .49148 L
.49535 .49195 L
.49561 .49239 L
.49585 .49281 L
.49608 .49321 L
.4963 .49358 L
.4965 .49394 L
.49669 .49427 L
.49688 .49459 L
.49705 .49488 L
.49721 .49517 L
.49736 .49543 L
.49751 .49568 L
.49765 .49592 L
.49778 .49615 L
.4979 .49636 L
.49801 .49656 L
.49812 .49675 L
.49823 .49693 L
.49833 .4971 L
.49842 .49726 L
.4985 .49741 L
.49859 .49755 L
.49867 .49769 L
.49874 .49781 L
.49881 .49794 L
.49887 .49805 L
.49894 .49816 L
.49899 .49826 L
.49905 .49835 L
.4991 .49845 L
Mistroke
.49915 .49853 L
.4992 .49861 L
.49924 .49869 L
.49928 .49876 L
.49932 .49883 L
.49936 .49889 L
.4994 .49895 L
.49943 .49901 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49921 L
.49957 .49926 L
.49959 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
Mistroke
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
0 .099 1 r
.23261 0 m
.23776 .01086 L
.25142 .03919 L
.26444 .06577 L
.27683 .09074 L
.28862 .11419 L
.29983 .13622 L
.31047 .15695 L
.32059 .17643 L
.33019 .19477 L
.33929 .21203 L
.34794 .22828 L
.35613 .24359 L
.3639 .258 L
.37126 .27159 L
.37823 .28439 L
.38484 .29646 L
.39109 .30784 L
.39702 .31857 L
.40262 .32869 L
.40793 .33824 L
.41295 .34724 L
.41771 .35574 L
.4222 .36376 L
.42646 .37133 L
.43048 .37847 L
.43429 .38521 L
.43789 .39158 L
.44129 .39759 L
.44451 .40326 L
.44756 .40862 L
.45044 .41368 L
.45316 .41845 L
.45573 .42297 L
.45816 .42723 L
.46046 .43125 L
.46263 .43505 L
.46469 .43864 L
.46663 .44203 L
.46847 .44523 L
.4702 .44826 L
.47184 .45111 L
.47339 .45381 L
.47485 .45636 L
.47624 .45877 L
.47755 .46105 L
.47878 .4632 L
.47995 .46523 L
.48106 .46715 L
.4821 .46896 L
Mistroke
.48308 .47067 L
.48402 .47229 L
.4849 .47382 L
.48573 .47526 L
.48651 .47663 L
.48726 .47791 L
.48796 .47913 L
.48862 .48028 L
.48925 .48137 L
.48984 .4824 L
.4904 .48337 L
.49093 .48429 L
.49143 .48515 L
.4919 .48597 L
.49235 .48674 L
.49277 .48748 L
.49317 .48817 L
.49355 .48882 L
.4939 .48943 L
.49424 .49002 L
.49456 .49057 L
.49486 .49109 L
.49514 .49158 L
.49541 .49204 L
.49566 .49248 L
.4959 .4929 L
.49613 .49329 L
.49634 .49366 L
.49654 .49401 L
.49673 .49434 L
.49691 .49465 L
.49708 .49494 L
.49724 .49522 L
.49739 .49549 L
.49754 .49574 L
.49767 .49597 L
.4978 .49619 L
.49792 .4964 L
.49804 .4966 L
.49815 .49679 L
.49825 .49697 L
.49834 .49713 L
.49844 .49729 L
.49852 .49744 L
.4986 .49758 L
.49868 .49771 L
.49875 .49784 L
.49882 .49796 L
.49889 .49807 L
.49895 .49818 L
Mistroke
.49901 .49828 L
.49906 .49837 L
.49911 .49846 L
.49916 .49855 L
.49921 .49863 L
.49925 .4987 L
.49929 .49878 L
.49933 .49884 L
.49937 .49891 L
.4994 .49897 L
.49944 .49902 L
.49947 .49908 L
.4995 .49913 L
.49952 .49918 L
.49955 .49922 L
.49958 .49926 L
.4996 .49931 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49945 L
.4997 .49948 L
.49971 .49951 L
.49973 .49953 L
.49975 .49956 L
.49976 .49958 L
.49977 .49961 L
.49978 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
Mistroke
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
.852 0 1 r
.02787 1 m
.0393 .98357 L
.09369 .90669 L
.14122 .84075 L
.18276 .78426 L
.21912 .73591 L
.25095 .6946 L
.27884 .65934 L
.3033 .62929 L
.32478 .60375 L
.34365 .58207 L
.36026 .56371 L
.37488 .54822 L
.38777 .53518 L
.39915 .52424 L
.40921 .51511 L
.41812 .50752 L
.42601 .50125 L
.43301 .49611 L
.43924 .49193 L
.44479 .48857 L
.44974 .4859 L
.45416 .48382 L
.45812 .48223 L
.46167 .48106 L
.46485 .48025 L
.46772 .47972 L
.47031 .47945 L
.47264 .47937 L
.47476 .47946 L
.47667 .47968 L
.47841 .48001 L
.48 .48043 L
.48144 .48092 L
.48276 .48146 L
.48397 .48204 L
.48507 .48264 L
.48609 .48327 L
.48702 .4839 L
.48788 .48454 L
.48867 .48517 L
.48941 .4858 L
.49008 .48642 L
.49071 .48703 L
.49129 .48762 L
.49184 .4882 L
.49234 .48876 L
.49281 .4893 L
.49324 .48982 L
.49365 .49032 L
Mistroke
.49403 .4908 L
.49438 .49126 L
.49472 .49171 L
.49503 .49213 L
.49532 .49254 L
.49559 .49292 L
.49585 .49329 L
.49609 .49364 L
.49631 .49397 L
.49652 .49429 L
.49672 .4946 L
.49691 .49488 L
.49708 .49516 L
.49725 .49541 L
.49741 .49566 L
.49755 .49589 L
.49769 .49611 L
.49782 .49632 L
.49794 .49652 L
.49806 .49671 L
.49817 .49689 L
.49827 .49706 L
.49837 .49722 L
.49846 .49737 L
.49854 .49751 L
.49862 .49765 L
.4987 .49778 L
.49877 .4979 L
.49884 .49801 L
.49891 .49812 L
.49897 .49822 L
.49902 .49832 L
.49908 .49841 L
.49913 .4985 L
.49918 .49858 L
.49922 .49866 L
.49927 .49873 L
.49931 .4988 L
.49934 .49887 L
.49938 .49893 L
.49942 .49899 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49953 .49919 L
.49956 .49924 L
.49958 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .49939 L
Mistroke
.49967 .49943 L
.49969 .49946 L
.4997 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49976 .49959 L
.49978 .49961 L
.49979 .49964 L
.4998 .49966 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49982 L
.4999 .49983 L
.4999 .49984 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
Mistroke
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.707 1 0 r
.54452 0 m
.53855 .01862 L
.52402 .06664 L
.51195 .10914 L
.50198 .14682 L
.4938 .18026 L
.48715 .21 L
.4818 .23648 L
.47755 .2601 L
.47424 .2812 L
.47172 .30009 L
.46986 .31702 L
.46857 .33223 L
.46773 .34592 L
.46729 .35826 L
.46717 .36941 L
.46731 .3795 L
.46767 .38864 L
.4682 .39695 L
.46886 .40451 L
.46964 .4114 L
.4705 .4177 L
.47142 .42346 L
.47238 .42874 L
.47337 .43358 L
.47438 .43804 L
.4754 .44214 L
.47641 .44593 L
.47741 .44943 L
.4784 .45267 L
.47936 .45566 L
.48031 .45844 L
.48122 .46103 L
.48211 .46343 L
.48297 .46566 L
.4838 .46774 L
.4846 .46969 L
.48537 .4715 L
.4861 .4732 L
.4868 .47478 L
.48748 .47626 L
.48812 .47765 L
.48874 .47895 L
.48932 .48017 L
.48988 .48132 L
.49041 .48239 L
.49092 .4834 L
.4914 .48435 L
.49186 .48524 L
.49229 .48608 L
Mistroke
.4927 .48687 L
.49309 .48761 L
.49347 .48831 L
.49382 .48897 L
.49415 .48959 L
.49447 .49018 L
.49477 .49073 L
.49505 .49125 L
.49532 .49174 L
.49557 .4922 L
.49581 .49263 L
.49604 .49304 L
.49626 .49343 L
.49646 .4938 L
.49666 .49414 L
.49684 .49447 L
.49701 .49477 L
.49718 .49506 L
.49733 .49534 L
.49748 .4956 L
.49761 .49584 L
.49775 .49607 L
.49787 .49629 L
.49799 .49649 L
.4981 .49669 L
.4982 .49687 L
.4983 .49704 L
.49839 .49721 L
.49848 .49736 L
.49857 .49751 L
.49864 .49765 L
.49872 .49778 L
.49879 .4979 L
.49886 .49801 L
.49892 .49812 L
.49898 .49823 L
.49903 .49833 L
.49909 .49842 L
.49914 .49851 L
.49919 .49859 L
.49923 .49867 L
.49927 .49874 L
.49931 .49881 L
.49935 .49887 L
.49939 .49894 L
.49942 .499 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
Mistroke
.49956 .49924 L
.49959 .49929 L
.49961 .49932 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
Mistroke
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
Mfstroke
1 .811 0 r
1 .64584 m
.98306 .65436 L
.941 .67259 L
.90331 .68625 L
.86949 .69606 L
.83908 .70265 L
.81168 .70656 L
.78696 .70824 L
.76461 .70808 L
.74436 .70641 L
.72598 .70353 L
.70928 .69968 L
.69406 .69505 L
.68017 .68983 L
.66747 .68416 L
.65584 .67816 L
.64518 .67193 L
.63537 .66557 L
.62635 .65915 L
.61804 .65271 L
.61036 .64632 L
.60326 .64002 L
.59669 .63382 L
.5906 .62776 L
.58495 .62186 L
.57969 .61614 L
.5748 .61059 L
.57025 .60524 L
.56601 .60008 L
.56205 .59513 L
.55835 .59037 L
.55489 .5858 L
.55165 .58144 L
.54862 .57726 L
.54579 .57328 L
.54313 .56947 L
.54063 .56585 L
.53829 .5624 L
.53609 .55911 L
.53402 .55599 L
.53208 .55302 L
.53026 .55019 L
.52854 .54751 L
.52692 .54497 L
.5254 .54256 L
.52397 .54027 L
.52262 .5381 L
.52135 .53604 L
.52015 .53409 L
.51902 .53224 L
Mistroke
.51796 .53049 L
.51695 .52883 L
.51601 .52727 L
.51511 .52578 L
.51427 .52438 L
.51348 .52305 L
.51273 .52179 L
.51202 .5206 L
.51135 .51947 L
.51072 .5184 L
.51013 .5174 L
.50957 .51644 L
.50904 .51554 L
.50854 .51469 L
.50806 .51388 L
.50762 .51312 L
.50719 .5124 L
.5068 .51172 L
.50642 .51108 L
.50607 .51047 L
.50573 .50989 L
.50541 .50935 L
.50511 .50883 L
.50483 .50835 L
.50457 .50789 L
.50431 .50745 L
.50408 .50704 L
.50385 .50666 L
.50364 .50629 L
.50344 .50594 L
.50325 .50562 L
.50307 .50531 L
.5029 .50501 L
.50274 .50474 L
.50259 .50448 L
.50245 .50423 L
.50231 .504 L
.50218 .50378 L
.50206 .50357 L
.50195 .50337 L
.50184 .50319 L
.50174 .50301 L
.50164 .50285 L
.50155 .50269 L
.50147 .50254 L
.50139 .5024 L
.50131 .50227 L
.50124 .50214 L
.50117 .50203 L
.50111 .50191 L
Mistroke
.50104 .50181 L
.50099 .50171 L
.50093 .50161 L
.50088 .50153 L
.50083 .50144 L
.50079 .50136 L
.50074 .50129 L
.5007 .50122 L
.50066 .50115 L
.50063 .50109 L
.50059 .50103 L
.50056 .50097 L
.50053 .50092 L
.5005 .50087 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50036 .50062 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
Mfstroke
1 0 .097 r
.03868 0 m
.0594 .00969 L
.08986 .02602 L
.11781 .04288 L
.14352 .06005 L
.16718 .07734 L
.18901 .09461 L
.20917 .11173 L
.22781 .12861 L
.24508 .14516 L
.26109 .16132 L
.27596 .17705 L
.28978 .1923 L
.30265 .20705 L
.31463 .22128 L
.32581 .23498 L
.33624 .24815 L
.34598 .26079 L
.3551 .27289 L
.36362 .28448 L
.37161 .29555 L
.37909 .30611 L
.38611 .31619 L
.39269 .3258 L
.39887 .33494 L
.40467 .34364 L
.41013 .35192 L
.41525 .35978 L
.42007 .36726 L
.42461 .37435 L
.42887 .38108 L
.43289 .38747 L
.43667 .39353 L
.44024 .39927 L
.44359 .40471 L
.44676 .40987 L
.44974 .41476 L
.45255 .41939 L
.4552 .42377 L
.4577 .42792 L
.46006 .43184 L
.46229 .43556 L
.46438 .43908 L
.46636 .44241 L
.46823 .44555 L
.47 .44853 L
.47166 .45135 L
.47323 .45401 L
.47472 .45654 L
.47612 .45892 L
Mistroke
.47744 .46117 L
.47869 .4633 L
.47987 .46532 L
.48098 .46722 L
.48204 .46902 L
.48303 .47072 L
.48397 .47233 L
.48485 .47385 L
.48569 .47529 L
.48648 .47665 L
.48723 .47794 L
.48793 .47915 L
.4886 .4803 L
.48923 .48138 L
.48982 .48241 L
.49038 .48337 L
.49092 .48429 L
.49142 .48515 L
.49189 .48597 L
.49234 .48674 L
.49276 .48747 L
.49316 .48816 L
.49354 .48882 L
.49389 .48943 L
.49423 .49001 L
.49455 .49056 L
.49485 .49108 L
.49513 .49158 L
.4954 .49204 L
.49566 .49248 L
.49589 .49289 L
.49612 .49328 L
.49634 .49365 L
.49654 .494 L
.49673 .49433 L
.49691 .49465 L
.49708 .49494 L
.49724 .49522 L
.49739 .49548 L
.49754 .49573 L
.49767 .49597 L
.4978 .49619 L
.49792 .4964 L
.49804 .4966 L
.49814 .49679 L
.49825 .49696 L
.49834 .49713 L
.49843 .49729 L
.49852 .49744 L
.4986 .49758 L
Mistroke
.49868 .49771 L
.49875 .49784 L
.49882 .49796 L
.49889 .49807 L
.49895 .49818 L
.49901 .49828 L
.49906 .49837 L
.49911 .49846 L
.49916 .49855 L
.49921 .49863 L
.49925 .4987 L
.49929 .49877 L
.49933 .49884 L
.49937 .49891 L
.4994 .49897 L
.49944 .49902 L
.49947 .49908 L
.4995 .49913 L
.49952 .49918 L
.49955 .49922 L
.49958 .49926 L
.4996 .4993 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49945 L
.4997 .49948 L
.49971 .49951 L
.49973 .49953 L
.49974 .49956 L
.49976 .49958 L
.49977 .49961 L
.49978 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
Mistroke
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
Mfstroke
1 0 .444 r
0 .16324 m
.02771 .16109 L
.06459 .16099 L
.09798 .16341 L
.12828 .16787 L
.15583 .17396 L
.18091 .18134 L
.20379 .18974 L
.22471 .19889 L
.24386 .2086 L
.26142 .2187 L
.27756 .22903 L
.29241 .23949 L
.30609 .24997 L
.31872 .26038 L
.3304 .27068 L
.3412 .28079 L
.35122 .29069 L
.36052 .30033 L
.36915 .30969 L
.37719 .31876 L
.38467 .32751 L
.39164 .33595 L
.39815 .34407 L
.40423 .35186 L
.40991 .35933 L
.41522 .36648 L
.4202 .37332 L
.42486 .37985 L
.42923 .38608 L
.43332 .39202 L
.43717 .39768 L
.44078 .40306 L
.44417 .40819 L
.44736 .41306 L
.45036 .41768 L
.45318 .42208 L
.45583 .42625 L
.45833 .4302 L
.46068 .43396 L
.46289 .43752 L
.46498 .44089 L
.46694 .44409 L
.4688 .44712 L
.47054 .44999 L
.47219 .4527 L
.47374 .45528 L
.47521 .45771 L
.47659 .46002 L
.47789 .4622 L
Mistroke
.47912 .46426 L
.48028 .46622 L
.48138 .46806 L
.48241 .46981 L
.48339 .47146 L
.48431 .47303 L
.48518 .47451 L
.486 .47591 L
.48677 .47723 L
.48751 .47848 L
.4882 .47966 L
.48885 .48078 L
.48947 .48183 L
.49005 .48283 L
.4906 .48377 L
.49112 .48467 L
.49161 .48551 L
.49207 .48631 L
.49251 .48706 L
.49292 .48777 L
.49331 .48845 L
.49368 .48908 L
.49403 .48968 L
.49436 .49025 L
.49467 .49079 L
.49497 .49129 L
.49524 .49177 L
.49551 .49223 L
.49575 .49265 L
.49599 .49306 L
.49621 .49344 L
.49642 .4938 L
.49662 .49414 L
.4968 .49447 L
.49698 .49477 L
.49715 .49506 L
.4973 .49533 L
.49745 .49559 L
.49759 .49583 L
.49773 .49606 L
.49785 .49628 L
.49797 .49648 L
.49808 .49668 L
.49819 .49686 L
.49829 .49703 L
.49838 .4972 L
.49847 .49735 L
.49856 .4975 L
.49863 .49764 L
.49871 .49777 L
Mistroke
.49878 .49789 L
.49885 .49801 L
.49891 .49812 L
.49897 .49822 L
.49903 .49832 L
.49908 .49841 L
.49913 .4985 L
.49918 .49858 L
.49923 .49866 L
.49927 .49873 L
.49931 .4988 L
.49935 .49887 L
.49938 .49893 L
.49942 .49899 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .49919 L
.49956 .49924 L
.49958 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .49939 L
.49967 .49943 L
.49969 .49946 L
.4997 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49976 .49959 L
.49978 .49961 L
.49979 .49964 L
.4998 .49966 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49982 L
.4999 .49983 L
.4999 .49984 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
Mistroke
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
Mfstroke
0 1 .681 r
.20813 0 m
.2183 .01715 L
.23395 .04357 L
.24871 .06855 L
.26265 .09219 L
.27581 .11454 L
.28823 .13567 L
.29996 .15566 L
.31103 .17455 L
.32149 .19242 L
.33137 .20931 L
.34069 .22528 L
.3495 .24038 L
.35782 .25465 L
.36568 .26813 L
.3731 .28088 L
.38011 .29294 L
.38673 .30433 L
.39299 .31509 L
.3989 .32527 L
.40448 .33488 L
.40975 .34397 L
.41473 .35256 L
.41944 .36068 L
.42388 .36835 L
.42808 .3756 L
.43205 .38245 L
.4358 .38892 L
.43934 .39504 L
.44269 .40082 L
.44585 .40629 L
.44884 .41145 L
.45166 .41633 L
.45432 .42094 L
.45684 .42529 L
.45922 .42941 L
.46147 .4333 L
.4636 .43697 L
.4656 .44045 L
.4675 .44373 L
.46929 .44683 L
.47098 .44976 L
.47258 .45253 L
.4741 .45514 L
.47552 .45762 L
.47687 .45995 L
.47815 .46216 L
.47935 .46424 L
.48049 .46622 L
.48157 .46808 L
Mistroke
.48258 .46984 L
.48354 .4715 L
.48445 .47307 L
.48531 .47455 L
.48612 .47596 L
.48688 .47728 L
.48761 .47853 L
.48829 .47972 L
.48893 .48084 L
.48954 .48189 L
.49012 .48289 L
.49067 .48383 L
.49118 .48472 L
.49167 .48557 L
.49213 .48636 L
.49256 .48711 L
.49297 .48782 L
.49336 .48849 L
.49372 .48913 L
.49407 .48973 L
.4944 .49029 L
.49471 .49083 L
.495 .49133 L
.49527 .49181 L
.49553 .49226 L
.49578 .49269 L
.49601 .49309 L
.49623 .49347 L
.49644 .49383 L
.49664 .49417 L
.49682 .49449 L
.497 .4948 L
.49716 .49508 L
.49732 .49536 L
.49747 .49561 L
.49761 .49585 L
.49774 .49608 L
.49786 .4963 L
.49798 .4965 L
.49809 .49669 L
.4982 .49688 L
.4983 .49705 L
.49839 .49721 L
.49848 .49737 L
.49856 .49751 L
.49864 .49765 L
.49872 .49778 L
.49879 .4979 L
.49885 .49802 L
.49892 .49813 L
Mistroke
.49898 .49823 L
.49903 .49833 L
.49909 .49842 L
.49914 .49851 L
.49918 .49859 L
.49923 .49867 L
.49927 .49874 L
.49931 .49881 L
.49935 .49887 L
.49939 .49894 L
.49942 .499 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
.49956 .49924 L
.49959 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
Mistroke
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
Mfstroke
0 1 .111 r
.86616 1 m
.8486 .98336 L
.82666 .96144 L
.8063 .94009 L
.78737 .91938 L
.76975 .89933 L
.75335 .87998 L
.73805 .86134 L
.72378 .84342 L
.71044 .82622 L
.69798 .80974 L
.68631 .79397 L
.67539 .77889 L
.66516 .76449 L
.65557 .75076 L
.64657 .73767 L
.63813 .7252 L
.63019 .71334 L
.62274 .70206 L
.61574 .69133 L
.60915 .68114 L
.60296 .67147 L
.59713 .66229 L
.59164 .65357 L
.58647 .64531 L
.5816 .63748 L
.57702 .63005 L
.5727 .62301 L
.56862 .61635 L
.56478 .61003 L
.56116 .60405 L
.55775 .59839 L
.55453 .59303 L
.55149 .58796 L
.54863 .58316 L
.54592 .57862 L
.54337 .57432 L
.54096 .57025 L
.53869 .56641 L
.53654 .56277 L
.53451 .55933 L
.5326 .55608 L
.5308 .553 L
.52909 .55009 L
.52748 .54734 L
.52596 .54474 L
.52452 .54229 L
.52317 .53996 L
.52189 .53777 L
.52068 .53569 L
Mistroke
.51954 .53373 L
.51846 .53187 L
.51744 .53012 L
.51647 .52846 L
.51556 .5269 L
.5147 .52542 L
.51389 .52402 L
.51313 .5227 L
.5124 .52145 L
.51172 .52027 L
.51107 .51915 L
.51046 .5181 L
.50988 .5171 L
.50934 .51616 L
.50882 .51527 L
.50834 .51443 L
.50788 .51363 L
.50744 .51288 L
.50703 .51217 L
.50664 .5115 L
.50628 .51087 L
.50593 .51027 L
.5056 .5097 L
.5053 .50917 L
.505 .50866 L
.50473 .50818 L
.50447 .50773 L
.50422 .50731 L
.50399 .5069 L
.50377 .50652 L
.50356 .50616 L
.50336 .50583 L
.50318 .5055 L
.503 .5052 L
.50284 .50491 L
.50268 .50464 L
.50253 .50439 L
.50239 .50415 L
.50226 .50392 L
.50214 .5037 L
.50202 .5035 L
.50191 .5033 L
.5018 .50312 L
.5017 .50295 L
.50161 .50279 L
.50152 .50263 L
.50144 .50249 L
.50136 .50235 L
.50128 .50222 L
.50121 .5021 L
Mistroke
.50115 .50198 L
.50108 .50187 L
.50102 .50177 L
.50097 .50167 L
.50091 .50158 L
.50086 .50149 L
.50082 .50141 L
.50077 .50133 L
.50073 .50126 L
.50069 .50119 L
.50065 .50113 L
.50061 .50106 L
.50058 .501 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .5008 L
.50044 .50076 L
.50041 .50071 L
.50039 .50068 L
.50037 .50064 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .50041 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
Mistroke
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
Mfstroke
1 .128 0 r
.9904 0 m
.97196 .02609 L
.91673 .10283 L
.86844 .16857 L
.82619 .22484 L
.7892 .27294 L
.75678 .31398 L
.72836 .34896 L
.7034 .37871 L
.68147 .40395 L
.66218 .42533 L
.6452 .44338 L
.63022 .45858 L
.617 .47133 L
.60532 .48197 L
.59498 .49082 L
.58581 .49814 L
.57768 .50414 L
.57045 .50902 L
.56401 .51295 L
.55826 .51608 L
.55313 .51851 L
.54854 .52037 L
.54442 .52175 L
.54072 .52271 L
.5374 .52333 L
.5344 .52367 L
.53169 .52378 L
.52924 .52368 L
.52702 .52344 L
.525 .52306 L
.52316 .52258 L
.52149 .52202 L
.51996 .52141 L
.51856 .52074 L
.51728 .52005 L
.51611 .51933 L
.51502 .5186 L
.51403 .51786 L
.51311 .51713 L
.51226 .51641 L
.51148 .51569 L
.51075 .51499 L
.51007 .51431 L
.50945 .51364 L
.50886 .513 L
.50832 .51237 L
.50782 .51177 L
.50735 .51119 L
.50691 .51063 L
Mistroke
.5065 .5101 L
.50611 .50959 L
.50575 .5091 L
.50542 .50863 L
.5051 .50818 L
.5048 .50776 L
.50453 .50735 L
.50427 .50697 L
.50402 .5066 L
.50379 .50625 L
.50358 .50592 L
.50337 .5056 L
.50318 .5053 L
.503 .50502 L
.50283 .50475 L
.50267 .50449 L
.50252 .50425 L
.50238 .50402 L
.50225 .5038 L
.50212 .5036 L
.502 .5034 L
.50189 .50322 L
.50178 .50304 L
.50169 .50288 L
.50159 .50272 L
.5015 .50257 L
.50142 .50243 L
.50134 .5023 L
.50127 .50217 L
.5012 .50205 L
.50113 .50194 L
.50107 .50183 L
.50101 .50173 L
.50095 .50164 L
.5009 .50155 L
.50085 .50146 L
.5008 .50138 L
.50076 .50131 L
.50072 .50124 L
.50068 .50117 L
.50064 .5011 L
.5006 .50104 L
.50057 .50099 L
.50054 .50093 L
.50051 .50088 L
.50048 .50083 L
.50045 .50079 L
.50043 .50074 L
.50041 .5007 L
.50038 .50066 L
Mistroke
.50036 .50063 L
.50034 .50059 L
.50032 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.50019 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
Mistroke
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.17 1 0 r
.79392 1 m
.7792 .97559 L
.76363 .94969 L
.74894 .92517 L
.73508 .90197 L
.72201 .88002 L
.70967 .85925 L
.69802 .8396 L
.68703 .82101 L
.67665 .80343 L
.66686 .78681 L
.65761 .77108 L
.64888 .75622 L
.64064 .74216 L
.63285 .72887 L
.6255 .7163 L
.61856 .70442 L
.612 .69319 L
.60581 .68257 L
.59996 .67253 L
.59444 .66305 L
.58922 .65408 L
.58429 .64561 L
.57964 .6376 L
.57524 .63002 L
.57109 .62287 L
.56716 .61611 L
.56345 .60971 L
.55995 .60367 L
.55664 .59797 L
.55352 .59257 L
.55057 .58747 L
.54778 .58266 L
.54514 .5781 L
.54265 .5738 L
.5403 .56974 L
.53808 .5659 L
.53598 .56227 L
.53399 .55883 L
.53212 .55559 L
.53035 .55253 L
.52867 .54964 L
.52709 .5469 L
.5256 .54432 L
.52419 .54187 L
.52285 .53957 L
.52159 .53739 L
.5204 .53533 L
.51928 .53338 L
.51821 .53154 L
Mistroke
.51721 .5298 L
.51626 .52816 L
.51536 .52661 L
.51452 .52514 L
.51372 .52376 L
.51296 .52245 L
.51225 .52121 L
.51157 .52004 L
.51093 .51894 L
.51033 .51789 L
.50976 .51691 L
.50922 .51597 L
.50871 .51509 L
.50823 .51426 L
.50778 .51348 L
.50735 .51273 L
.50695 .51203 L
.50656 .51137 L
.5062 .51074 L
.50586 .51015 L
.50554 .50959 L
.50523 .50906 L
.50494 .50856 L
.50467 .50809 L
.50441 .50764 L
.50417 .50722 L
.50394 .50682 L
.50372 .50645 L
.50352 .50609 L
.50332 .50576 L
.50314 .50544 L
.50297 .50514 L
.5028 .50486 L
.50265 .50459 L
.5025 .50434 L
.50237 .5041 L
.50223 .50387 L
.50211 .50366 L
.502 .50346 L
.50189 .50327 L
.50178 .50309 L
.50168 .50292 L
.50159 .50275 L
.5015 .5026 L
.50142 .50246 L
.50134 .50232 L
.50127 .5022 L
.5012 .50207 L
.50113 .50196 L
.50107 .50185 L
Mistroke
.50101 .50175 L
.50095 .50165 L
.5009 .50156 L
.50085 .50148 L
.50081 .5014 L
.50076 .50132 L
.50072 .50125 L
.50068 .50118 L
.50064 .50111 L
.50061 .50105 L
.50057 .50099 L
.50054 .50094 L
.50051 .50089 L
.50048 .50084 L
.50046 .50079 L
.50043 .50075 L
.50041 .50071 L
.50039 .50067 L
.50036 .50063 L
.50034 .5006 L
.50033 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50048 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50029 L
.50016 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
Mfstroke
1 0 .268 r
.77476 1 m
.76962 .9899 L
.75528 .962 L
.74165 .93576 L
.72872 .91106 L
.71645 .88782 L
.70481 .86594 L
.69378 .84533 L
.68332 .82591 L
.6734 .80762 L
.66401 .79038 L
.65511 .77412 L
.64668 .7588 L
.63871 .74435 L
.63115 .73072 L
.624 .71786 L
.61724 .70573 L
.61084 .69429 L
.60478 .68349 L
.59905 .67329 L
.59363 .66367 L
.5885 .65459 L
.58365 .64602 L
.57907 .63793 L
.57473 .63029 L
.57063 .62307 L
.56675 .61626 L
.56309 .60983 L
.55962 .60375 L
.55635 .59801 L
.55325 .59259 L
.55032 .58748 L
.54756 .58264 L
.54494 .57808 L
.54247 .57376 L
.54013 .56969 L
.53793 .56584 L
.53584 .56221 L
.53387 .55877 L
.532 .55553 L
.53024 .55246 L
.52858 .54957 L
.527 .54683 L
.52551 .54425 L
.52411 .54181 L
.52278 .5395 L
.52153 .53732 L
.52034 .53526 L
.51922 .53332 L
.51816 .53148 L
Mistroke
.51716 .52974 L
.51622 .5281 L
.51532 .52655 L
.51448 .52509 L
.51368 .52371 L
.51293 .5224 L
.51221 .52116 L
.51154 .52 L
.51091 .51889 L
.5103 .51785 L
.50974 .51687 L
.5092 .51594 L
.50869 .51506 L
.50821 .51423 L
.50776 .51345 L
.50733 .5127 L
.50693 .512 L
.50655 .51134 L
.50619 .51072 L
.50585 .51013 L
.50552 .50957 L
.50522 .50904 L
.50493 .50854 L
.50466 .50807 L
.5044 .50763 L
.50416 .50721 L
.50393 .50681 L
.50371 .50643 L
.50351 .50608 L
.50332 .50574 L
.50313 .50543 L
.50296 .50513 L
.5028 .50485 L
.50264 .50458 L
.5025 .50433 L
.50236 .50409 L
.50223 .50386 L
.50211 .50365 L
.50199 .50345 L
.50188 .50326 L
.50178 .50308 L
.50168 .50291 L
.50159 .50275 L
.5015 .5026 L
.50142 .50245 L
.50134 .50232 L
.50126 .50219 L
.5012 .50207 L
.50113 .50196 L
.50107 .50185 L
Mistroke
.50101 .50175 L
.50095 .50165 L
.5009 .50156 L
.50085 .50147 L
.5008 .50139 L
.50076 .50132 L
.50072 .50124 L
.50068 .50117 L
.50064 .50111 L
.50061 .50105 L
.50057 .50099 L
.50054 .50094 L
.50051 .50088 L
.50048 .50084 L
.50046 .50079 L
.50043 .50075 L
.50041 .5007 L
.50038 .50067 L
.50036 .50063 L
.50034 .50059 L
.50032 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.50019 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50016 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
Mistroke
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
Mfstroke
1 0 .274 r
.78633 1 m
.78596 .99936 L
.77029 .97167 L
.75547 .94554 L
.74146 .92086 L
.72821 .89756 L
.71568 .87555 L
.70384 .85477 L
.69264 .83515 L
.68206 .81662 L
.67205 .79912 L
.66259 .78258 L
.65365 .76697 L
.6452 .75222 L
.63721 .73829 L
.62966 .72513 L
.62253 .7127 L
.61579 .70096 L
.60941 .68986 L
.60339 .67938 L
.5977 .66948 L
.59232 .66013 L
.58724 .6513 L
.58243 .64295 L
.57789 .63506 L
.5736 .62761 L
.56955 .62057 L
.56572 .61392 L
.5621 .60764 L
.55868 .6017 L
.55544 .59609 L
.55239 .59079 L
.5495 .58579 L
.54677 .58106 L
.5442 .57659 L
.54176 .57236 L
.53946 .56837 L
.53729 .5646 L
.53523 .56104 L
.53329 .55768 L
.53145 .5545 L
.52972 .55149 L
.52808 .54865 L
.52654 .54597 L
.52507 .54344 L
.52369 .54104 L
.52239 .53878 L
.52115 .53664 L
.51999 .53462 L
.51888 .53271 L
Mistroke
.51784 .53091 L
.51686 .52921 L
.51593 .5276 L
.51505 .52607 L
.51422 .52464 L
.51344 .52328 L
.5127 .522 L
.512 .52078 L
.51134 .51964 L
.51071 .51856 L
.51012 .51753 L
.50956 .51657 L
.50904 .51565 L
.50854 .51479 L
.50807 .51397 L
.50762 .5132 L
.5072 .51248 L
.50681 .51179 L
.50643 .51114 L
.50608 .51052 L
.50574 .50994 L
.50543 .5094 L
.50513 .50888 L
.50484 .50839 L
.50458 .50793 L
.50432 .50749 L
.50409 .50708 L
.50386 .50669 L
.50365 .50632 L
.50345 .50597 L
.50326 .50564 L
.50308 .50533 L
.50291 .50504 L
.50275 .50476 L
.5026 .5045 L
.50245 .50425 L
.50232 .50401 L
.50219 .50379 L
.50207 .50358 L
.50196 .50339 L
.50185 .5032 L
.50175 .50302 L
.50165 .50286 L
.50156 .5027 L
.50147 .50255 L
.50139 .50241 L
.50131 .50228 L
.50124 .50215 L
.50117 .50203 L
.50111 .50192 L
Mistroke
.50105 .50181 L
.50099 .50171 L
.50094 .50162 L
.50088 .50153 L
.50084 .50145 L
.50079 .50137 L
.50075 .50129 L
.5007 .50122 L
.50067 .50115 L
.50063 .50109 L
.50059 .50103 L
.50056 .50097 L
.50053 .50092 L
.5005 .50087 L
.50047 .50082 L
.50045 .50078 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50036 .50062 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50047 L
.50025 .50044 L
.50024 .50042 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .5003 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50005 .5001 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
Mfstroke
.261 1 0 r
0 .94118 m
.0446 .8819 L
.09619 .81497 L
.1414 .75785 L
.18106 .70919 L
.21587 .66781 L
.24647 .63269 L
.27338 .60297 L
.29708 .57787 L
.31798 .55675 L
.33644 .53904 L
.35275 .52426 L
.36718 .51197 L
.37998 .50183 L
.39134 .49351 L
.40144 .48675 L
.41044 .4813 L
.41846 .47699 L
.42563 .47362 L
.43205 .47106 L
.4378 .46918 L
.44297 .46786 L
.44762 .46702 L
.45182 .46658 L
.4556 .46646 L
.45903 .46661 L
.46214 .46698 L
.46496 .46752 L
.46753 .46821 L
.46988 .469 L
.47202 .46988 L
.47397 .47082 L
.47577 .47181 L
.47742 .47282 L
.47893 .47385 L
.48033 .47489 L
.48161 .47592 L
.4828 .47694 L
.4839 .47795 L
.48492 .47894 L
.48587 .4799 L
.48675 .48084 L
.48756 .48174 L
.48832 .48262 L
.48903 .48347 L
.48969 .48428 L
.49031 .48506 L
.49088 .48582 L
.49142 .48653 L
.49193 .48722 L
Mistroke
.4924 .48788 L
.49284 .48851 L
.49326 .4891 L
.49365 .48967 L
.49401 .49022 L
.49436 .49073 L
.49468 .49122 L
.49498 .49169 L
.49527 .49213 L
.49553 .49255 L
.49579 .49295 L
.49603 .49333 L
.49625 .49369 L
.49646 .49403 L
.49666 .49435 L
.49685 .49466 L
.49702 .49495 L
.49719 .49522 L
.49735 .49548 L
.49749 .49573 L
.49763 .49596 L
.49777 .49618 L
.49789 .49639 L
.49801 .49659 L
.49812 .49677 L
.49822 .49695 L
.49832 .49712 L
.49841 .49728 L
.4985 .49742 L
.49859 .49757 L
.49866 .4977 L
.49874 .49783 L
.49881 .49795 L
.49887 .49806 L
.49894 .49816 L
.49899 .49827 L
.49905 .49836 L
.4991 .49845 L
.49915 .49854 L
.4992 .49862 L
.49924 .49869 L
.49929 .49876 L
.49932 .49883 L
.49936 .4989 L
.4994 .49896 L
.49943 .49902 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49921 L
Mistroke
.49957 .49926 L
.49959 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
Mistroke
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
Mfstroke
0 1 .76 r
.77359 0 m
.77271 .00155 L
.73571 .06708 L
.70369 .12391 L
.67597 .17321 L
.65198 .21597 L
.63122 .25308 L
.61325 .28527 L
.59771 .31321 L
.58427 .33746 L
.57264 .35851 L
.56259 .37679 L
.5539 .39266 L
.54639 .40644 L
.5399 .41841 L
.53429 .42882 L
.52944 .43786 L
.52526 .44572 L
.52165 .45255 L
.51853 .4585 L
.51585 .46367 L
.51353 .46817 L
.51153 .47209 L
.50981 .47551 L
.50833 .47848 L
.50706 .48108 L
.50597 .48334 L
.50503 .48532 L
.50422 .48704 L
.50353 .48855 L
.50294 .48987 L
.50243 .49103 L
.502 .49204 L
.50163 .49292 L
.50132 .4937 L
.50105 .49439 L
.50082 .49499 L
.50063 .49552 L
.50047 .49598 L
.50034 .49639 L
.50022 .49676 L
.50013 .49708 L
.50005 .49736 L
.49999 .49761 L
.49993 .49784 L
.49989 .49804 L
.49986 .49821 L
.49983 .49837 L
.49981 .49851 L
.49979 .49864 L
Mistroke
.49978 .49876 L
.49977 .49886 L
.49977 .49895 L
.49977 .49903 L
.49977 .49911 L
.49977 .49918 L
.49977 .49924 L
.49978 .4993 L
.49978 .49935 L
.49979 .49939 L
.49979 .49944 L
.4998 .49948 L
.49981 .49951 L
.49981 .49954 L
.49982 .49958 L
.49983 .4996 L
.49984 .49963 L
.49984 .49965 L
.49985 .49967 L
.49986 .4997 L
.49986 .49971 L
.49987 .49973 L
.49988 .49975 L
.49988 .49976 L
.49989 .49978 L
.49989 .49979 L
.4999 .4998 L
.4999 .49982 L
.49991 .49983 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49993 .49986 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
Mistroke
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.249 0 1 r
.79478 0 m
.76157 .05703 L
.72688 .11656 L
.6968 .16813 L
.67073 .21279 L
.64813 .25147 L
.62854 .28496 L
.61155 .31397 L
.59682 .33909 L
.58405 .36083 L
.57297 .37967 L
.56336 .39597 L
.55503 .41008 L
.54781 .4223 L
.54154 .43287 L
.5361 .44202 L
.53139 .44994 L
.52729 .45679 L
.52374 .46272 L
.52066 .46785 L
.51798 .47228 L
.51566 .47612 L
.51364 .47943 L
.51189 .4823 L
.51037 .48478 L
.50905 .48692 L
.5079 .48876 L
.5069 .49036 L
.50603 .49174 L
.50527 .49293 L
.50462 .49395 L
.50404 .49484 L
.50355 .4956 L
.50311 .49625 L
.50273 .49682 L
.5024 .4973 L
.50212 .49772 L
.50186 .49808 L
.50165 .49839 L
.50145 .49865 L
.50129 .49888 L
.50114 .49907 L
.50101 .49924 L
.5009 .49938 L
.5008 .4995 L
.50071 .4996 L
.50064 .49968 L
.50057 .49976 L
.50051 .49982 L
.50046 .49987 L
Mistroke
.50041 .49991 L
.50037 .49995 L
.50033 .49998 L
.5003 .5 L
.50027 .50002 L
.50025 .50004 L
.50023 .50005 L
.50021 .50006 L
.50019 .50007 L
.50017 .50008 L
.50016 .50008 L
.50014 .50009 L
.50013 .50009 L
.50012 .50009 L
.50011 .50009 L
.5001 .50009 L
.5001 .50009 L
.50009 .50008 L
.50008 .50008 L
.50008 .50008 L
.50007 .50008 L
.50007 .50008 L
.50006 .50007 L
.50006 .50007 L
.50005 .50007 L
.50005 .50006 L
.50005 .50006 L
.50004 .50006 L
.50004 .50006 L
.50004 .50005 L
.50004 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50003 .50004 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
Mistroke
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 .918 1 r
0 .20758 m
.0273 .20263 L
.06516 .19859 L
.09935 .1975 L
.13029 .19883 L
.15834 .20214 L
.18383 .20704 L
.20702 .21321 L
.22816 .22037 L
.24747 .22829 L
.26514 .23677 L
.28133 .24565 L
.2962 .2548 L
.30987 .26409 L
.32247 .27343 L
.33408 .28275 L
.34482 .29198 L
.35475 .30106 L
.36394 .30996 L
.37248 .31865 L
.3804 .3271 L
.38777 .33529 L
.39463 .3432 L
.40102 .35084 L
.40698 .35819 L
.41254 .36525 L
.41774 .37202 L
.4226 .3785 L
.42715 .38471 L
.43141 .39064 L
.43541 .3963 L
.43915 .40169 L
.44267 .40683 L
.44597 .41173 L
.44907 .41639 L
.45198 .42081 L
.45471 .42502 L
.45729 .42902 L
.45971 .43281 L
.46199 .43642 L
.46414 .43983 L
.46616 .44307 L
.46806 .44614 L
.46986 .44906 L
.47155 .45181 L
.47314 .45443 L
.47464 .4569 L
.47606 .45925 L
.47739 .46146 L
.47865 .46356 L
Mistroke
.47984 .46555 L
.48096 .46743 L
.48202 .46921 L
.48302 .47089 L
.48396 .47249 L
.48485 .47399 L
.48569 .47542 L
.48649 .47677 L
.48724 .47804 L
.48794 .47924 L
.48861 .48038 L
.48924 .48146 L
.48984 .48248 L
.4904 .48344 L
.49093 .48435 L
.49143 .48521 L
.4919 .48602 L
.49235 .48679 L
.49277 .48752 L
.49317 .48821 L
.49355 .48885 L
.49391 .48947 L
.49424 .49005 L
.49456 .4906 L
.49486 .49111 L
.49514 .4916 L
.49541 .49206 L
.49567 .4925 L
.4959 .49291 L
.49613 .4933 L
.49634 .49367 L
.49655 .49402 L
.49674 .49435 L
.49692 .49466 L
.49709 .49496 L
.49725 .49523 L
.4974 .4955 L
.49754 .49575 L
.49768 .49598 L
.49781 .4962 L
.49793 .49641 L
.49804 .49661 L
.49815 .4968 L
.49825 .49697 L
.49835 .49714 L
.49844 .4973 L
.49852 .49745 L
.49861 .49759 L
.49868 .49772 L
.49876 .49784 L
Mistroke
.49882 .49796 L
.49889 .49808 L
.49895 .49818 L
.49901 .49828 L
.49906 .49838 L
.49911 .49847 L
.49916 .49855 L
.49921 .49863 L
.49925 .49871 L
.49929 .49878 L
.49933 .49884 L
.49937 .49891 L
.4994 .49897 L
.49944 .49903 L
.49947 .49908 L
.4995 .49913 L
.49953 .49918 L
.49955 .49922 L
.49958 .49927 L
.4996 .49931 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49953 L
.49975 .49956 L
.49976 .49958 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
Mistroke
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
.997 1 0 r
.19139 0 m
.20767 .02395 L
.22447 .049 L
.24025 .07283 L
.25508 .09549 L
.26903 .11701 L
.28215 .13745 L
.29449 .15686 L
.30611 .17527 L
.31705 .19274 L
.32735 .20929 L
.33705 .22499 L
.3462 .23987 L
.35482 .25396 L
.36294 .26731 L
.3706 .27995 L
.37783 .29192 L
.38464 .30325 L
.39107 .31398 L
.39714 .32413 L
.40286 .33373 L
.40826 .34282 L
.41335 .35142 L
.41816 .35955 L
.4227 .36724 L
.42699 .37451 L
.43104 .38139 L
.43486 .3879 L
.43846 .39405 L
.44187 .39986 L
.44509 .40536 L
.44812 .41056 L
.45099 .41547 L
.4537 .42012 L
.45626 .42451 L
.45868 .42866 L
.46096 .43258 L
.46312 .43629 L
.46515 .4398 L
.46708 .44311 L
.4689 .44624 L
.47061 .4492 L
.47224 .452 L
.47377 .45464 L
.47522 .45714 L
.47658 .4595 L
.47787 .46173 L
.4791 .46383 L
.48025 .46583 L
.48134 .46771 L
Mistroke
.48237 .46949 L
.48334 .47117 L
.48426 .47276 L
.48513 .47426 L
.48595 .47568 L
.48672 .47702 L
.48745 .47828 L
.48815 .47948 L
.4888 .48061 L
.48942 .48168 L
.49 .48269 L
.49055 .48364 L
.49107 .48454 L
.49157 .48539 L
.49203 .4862 L
.49247 .48696 L
.49288 .48768 L
.49328 .48836 L
.49365 .489 L
.494 .48961 L
.49433 .49018 L
.49464 .49072 L
.49494 .49123 L
.49522 .49171 L
.49548 .49217 L
.49573 .4926 L
.49596 .49301 L
.49619 .4934 L
.4964 .49376 L
.4966 .4941 L
.49678 .49443 L
.49696 .49474 L
.49713 .49503 L
.49729 .4953 L
.49744 .49556 L
.49758 .4958 L
.49771 .49604 L
.49784 .49625 L
.49796 .49646 L
.49807 .49666 L
.49818 .49684 L
.49828 .49701 L
.49837 .49718 L
.49846 .49733 L
.49855 .49748 L
.49863 .49762 L
.4987 .49775 L
.49877 .49788 L
.49884 .49799 L
.4989 .4981 L
Mistroke
.49897 .49821 L
.49902 .49831 L
.49908 .4984 L
.49913 .49849 L
.49918 .49857 L
.49922 .49865 L
.49926 .49872 L
.4993 .49879 L
.49934 .49886 L
.49938 .49892 L
.49941 .49898 L
.49945 .49904 L
.49948 .49909 L
.4995 .49914 L
.49953 .49919 L
.49956 .49923 L
.49958 .49928 L
.49961 .49932 L
.49963 .49935 L
.49965 .49939 L
.49967 .49942 L
.49969 .49946 L
.4997 .49949 L
.49972 .49951 L
.49973 .49954 L
.49975 .49957 L
.49976 .49959 L
.49978 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
Mistroke
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
Mfstroke
1 0 .294 r
.81073 1 m
.79624 .97907 L
.77914 .954 L
.76309 .93013 L
.74801 .90742 L
.73384 .88583 L
.72051 .86532 L
.70798 .84583 L
.69619 .82733 L
.6851 .80978 L
.67465 .79313 L
.66481 .77734 L
.65554 .76237 L
.64681 .74818 L
.63858 .73474 L
.63082 .72201 L
.62351 .70995 L
.61661 .69853 L
.6101 .68773 L
.60397 .67749 L
.59818 .66781 L
.59271 .65865 L
.58756 .64998 L
.5827 .64178 L
.5781 .63402 L
.57377 .62668 L
.56968 .61974 L
.56582 .61318 L
.56217 .60697 L
.55873 .6011 L
.55548 .59556 L
.55241 .59031 L
.54951 .58535 L
.54677 .58066 L
.54418 .57623 L
.54174 .57204 L
.53943 .56808 L
.53726 .56433 L
.5352 .5608 L
.53325 .55745 L
.53142 .55429 L
.52968 .5513 L
.52804 .54848 L
.5265 .54581 L
.52503 .54329 L
.52365 .54091 L
.52235 .53865 L
.52111 .53652 L
.51995 .53451 L
.51885 .53261 L
Mistroke
.51781 .53082 L
.51683 .52912 L
.5159 .52751 L
.51502 .526 L
.51419 .52457 L
.51341 .52321 L
.51267 .52193 L
.51197 .52073 L
.51131 .51958 L
.51069 .5185 L
.5101 .51748 L
.50954 .51652 L
.50902 .51561 L
.50852 .51475 L
.50805 .51394 L
.50761 .51317 L
.50719 .51244 L
.50679 .51176 L
.50642 .51111 L
.50606 .5105 L
.50573 .50992 L
.50541 .50937 L
.50511 .50886 L
.50483 .50837 L
.50457 .50791 L
.50431 .50747 L
.50408 .50706 L
.50385 .50667 L
.50364 .5063 L
.50344 .50595 L
.50325 .50563 L
.50307 .50532 L
.5029 .50502 L
.50274 .50475 L
.50259 .50448 L
.50245 .50424 L
.50231 .504 L
.50218 .50378 L
.50206 .50357 L
.50195 .50338 L
.50184 .50319 L
.50174 .50302 L
.50165 .50285 L
.50155 .50269 L
.50147 .50254 L
.50139 .5024 L
.50131 .50227 L
.50124 .50215 L
.50117 .50203 L
.50111 .50192 L
Mistroke
.50105 .50181 L
.50099 .50171 L
.50093 .50162 L
.50088 .50153 L
.50083 .50144 L
.50079 .50136 L
.50074 .50129 L
.5007 .50122 L
.50066 .50115 L
.50063 .50109 L
.50059 .50103 L
.50056 .50097 L
.50053 .50092 L
.5005 .50087 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50036 .50062 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .5003 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
Mfstroke
0 .063 1 r
.30468 0 m
.31151 .03269 L
.31872 .06397 L
.32595 .09279 L
.33315 .11938 L
.34027 .14395 L
.34728 .16669 L
.35414 .18776 L
.36083 .2073 L
.36734 .22546 L
.37364 .24235 L
.37972 .25807 L
.38559 .27272 L
.39124 .28639 L
.39666 .29916 L
.40187 .31108 L
.40685 .32224 L
.41161 .33268 L
.41616 .34246 L
.4205 .35163 L
.42464 .36022 L
.42859 .36829 L
.43234 .37587 L
.43591 .38298 L
.43931 .38967 L
.44254 .39595 L
.4456 .40187 L
.44851 .40743 L
.45127 .41266 L
.45389 .41759 L
.45638 .42224 L
.45873 .42661 L
.46096 .43073 L
.46308 .43461 L
.46508 .43827 L
.46698 .44172 L
.46877 .44498 L
.47047 .44805 L
.47208 .45094 L
.47361 .45367 L
.47505 .45625 L
.47641 .45868 L
.4777 .46098 L
.47892 .46315 L
.48007 .46519 L
.48117 .46712 L
.4822 .46894 L
.48317 .47066 L
.4841 .47229 L
.48497 .47382 L
Mistroke
.4858 .47527 L
.48658 .47664 L
.48731 .47793 L
.48801 .47915 L
.48867 .4803 L
.48929 .48139 L
.48988 .48242 L
.49044 .48339 L
.49096 .48431 L
.49146 .48518 L
.49193 .48599 L
.49237 .48677 L
.49279 .4875 L
.49319 .48819 L
.49357 .48884 L
.49392 .48946 L
.49426 .49004 L
.49457 .49059 L
.49487 .49111 L
.49515 .4916 L
.49542 .49206 L
.49567 .4925 L
.49591 .49291 L
.49614 .4933 L
.49635 .49367 L
.49655 .49402 L
.49674 .49435 L
.49692 .49466 L
.49709 .49496 L
.49725 .49523 L
.4974 .4955 L
.49754 .49575 L
.49768 .49598 L
.49781 .4962 L
.49793 .49641 L
.49804 .49661 L
.49815 .4968 L
.49825 .49697 L
.49835 .49714 L
.49844 .4973 L
.49853 .49745 L
.49861 .49759 L
.49868 .49772 L
.49876 .49785 L
.49882 .49796 L
.49889 .49808 L
.49895 .49818 L
.49901 .49828 L
.49906 .49838 L
.49911 .49847 L
Mistroke
.49916 .49855 L
.49921 .49863 L
.49925 .49871 L
.49929 .49878 L
.49933 .49885 L
.49937 .49891 L
.4994 .49897 L
.49944 .49903 L
.49947 .49908 L
.4995 .49913 L
.49953 .49918 L
.49955 .49922 L
.49958 .49927 L
.4996 .49931 L
.49962 .49935 L
.49964 .49938 L
.49966 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49953 L
.49975 .49956 L
.49976 .49958 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
Mistroke
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
0 1 .007 r
.19322 0 m
.20771 .02161 L
.22445 .04688 L
.24019 .07091 L
.25498 .09375 L
.2689 .11543 L
.28199 .13601 L
.29432 .15554 L
.30592 .17407 L
.31685 .19163 L
.32715 .20828 L
.33685 .22406 L
.34599 .23901 L
.35461 .25317 L
.36274 .26658 L
.3704 .27928 L
.37763 .2913 L
.38445 .30267 L
.39088 .31344 L
.39695 .32363 L
.40268 .33327 L
.40809 .34239 L
.41319 .35101 L
.418 .35917 L
.42255 .36689 L
.42684 .37418 L
.4309 .38108 L
.43472 .38761 L
.43834 .39378 L
.44175 .39961 L
.44497 .40512 L
.44801 .41034 L
.45089 .41526 L
.4536 .41992 L
.45617 .42432 L
.45859 .42849 L
.46088 .43242 L
.46304 .43614 L
.46508 .43965 L
.46701 .44297 L
.46883 .44611 L
.47055 .44908 L
.47217 .45188 L
.47371 .45453 L
.47516 .45703 L
.47653 .4594 L
.47783 .46164 L
.47905 .46375 L
.4802 .46575 L
.4813 .46763 L
Mistroke
.48233 .46942 L
.4833 .4711 L
.48422 .47269 L
.48509 .4742 L
.48592 .47562 L
.48669 .47696 L
.48743 .47823 L
.48812 .47943 L
.48877 .48056 L
.48939 .48164 L
.48998 .48265 L
.49053 .4836 L
.49105 .48451 L
.49155 .48536 L
.49201 .48617 L
.49245 .48693 L
.49287 .48765 L
.49326 .48833 L
.49363 .48897 L
.49398 .48958 L
.49432 .49016 L
.49463 .4907 L
.49493 .49121 L
.4952 .4917 L
.49547 .49215 L
.49572 .49259 L
.49596 .49299 L
.49618 .49338 L
.49639 .49375 L
.49659 .49409 L
.49678 .49442 L
.49695 .49472 L
.49712 .49501 L
.49728 .49529 L
.49743 .49555 L
.49757 .49579 L
.49771 .49603 L
.49783 .49625 L
.49795 .49645 L
.49806 .49665 L
.49817 .49683 L
.49827 .49701 L
.49837 .49717 L
.49846 .49733 L
.49854 .49748 L
.49862 .49761 L
.4987 .49775 L
.49877 .49787 L
.49884 .49799 L
.4989 .4981 L
Mistroke
.49896 .4982 L
.49902 .4983 L
.49907 .4984 L
.49912 .49848 L
.49917 .49857 L
.49922 .49865 L
.49926 .49872 L
.4993 .49879 L
.49934 .49886 L
.49938 .49892 L
.49941 .49898 L
.49944 .49904 L
.49947 .49909 L
.4995 .49914 L
.49953 .49919 L
.49956 .49923 L
.49958 .49927 L
.4996 .49931 L
.49963 .49935 L
.49965 .49939 L
.49967 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49978 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
Mistroke
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
Mfstroke
1 .503 0 r
.80836 1 m
.79102 .97442 L
.77431 .94943 L
.75861 .92566 L
.74385 .90307 L
.72997 .88161 L
.71692 .86123 L
.70463 .84188 L
.69307 .82353 L
.68218 .80612 L
.67193 .78962 L
.66226 .77398 L
.65316 .75915 L
.64458 .74511 L
.63649 .7318 L
.62886 .71921 L
.62167 .70728 L
.61488 .69599 L
.60848 .6853 L
.60244 .67519 L
.59675 .66562 L
.59137 .65657 L
.5863 .64801 L
.58151 .6399 L
.57698 .63224 L
.57272 .625 L
.56869 .61814 L
.56488 .61166 L
.56129 .60554 L
.5579 .59974 L
.55469 .59427 L
.55167 .58909 L
.54881 .58419 L
.54611 .57957 L
.54356 .57519 L
.54116 .57106 L
.53888 .56715 L
.53674 .56346 L
.53471 .55997 L
.53279 .55667 L
.53098 .55355 L
.52927 .5506 L
.52765 .54781 L
.52613 .54518 L
.52469 .54269 L
.52332 .54034 L
.52204 .53812 L
.52082 .53602 L
.51967 .53404 L
.51859 .53216 L
Mistroke
.51756 .53039 L
.51659 .52872 L
.51568 .52714 L
.51481 .52564 L
.514 .52423 L
.51322 .52289 L
.5125 .52163 L
.51181 .52044 L
.51116 .51931 L
.51054 .51825 L
.50996 .51724 L
.50941 .51629 L
.50889 .5154 L
.5084 .51455 L
.50794 .51375 L
.5075 .51299 L
.50709 .51227 L
.5067 .5116 L
.50633 .51096 L
.50598 .51035 L
.50565 .50978 L
.50534 .50924 L
.50504 .50873 L
.50476 .50825 L
.5045 .5078 L
.50425 .50737 L
.50402 .50696 L
.5038 .50658 L
.50359 .50622 L
.50339 .50587 L
.5032 .50555 L
.50303 .50524 L
.50286 .50495 L
.5027 .50468 L
.50255 .50442 L
.50241 .50418 L
.50228 .50395 L
.50215 .50373 L
.50204 .50353 L
.50192 .50333 L
.50182 .50315 L
.50172 .50297 L
.50162 .50281 L
.50153 .50266 L
.50145 .50251 L
.50137 .50237 L
.50129 .50224 L
.50122 .50212 L
.50115 .502 L
.50109 .50189 L
Mistroke
.50103 .50179 L
.50097 .50169 L
.50092 .50159 L
.50087 .50151 L
.50082 .50142 L
.50078 .50134 L
.50073 .50127 L
.50069 .5012 L
.50065 .50113 L
.50062 .50107 L
.50058 .50101 L
.50055 .50096 L
.50052 .5009 L
.50049 .50085 L
.50047 .50081 L
.50044 .50076 L
.50042 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .50061 L
.50033 .50057 L
.50031 .50054 L
.5003 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50039 L
.50021 .50036 L
.5002 .50034 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50025 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50018 L
.5001 .50017 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
Mfstroke
1 .883 0 r
.78742 1 m
.77717 .98205 L
.76194 .9554 L
.74754 .93023 L
.73393 .90646 L
.72106 .88401 L
.7089 .86279 L
.69741 .84276 L
.68655 .82383 L
.67628 .80595 L
.66658 .78907 L
.65741 .77311 L
.64874 .75804 L
.64055 .7438 L
.63281 .73035 L
.6255 .71764 L
.61859 .70563 L
.61206 .69429 L
.60588 .68357 L
.60005 .67344 L
.59454 .66388 L
.58933 .65484 L
.58441 .6463 L
.57976 .63823 L
.57536 .63061 L
.57121 .62341 L
.56729 .6166 L
.56358 .61017 L
.56008 .6041 L
.55677 .59836 L
.55364 .59294 L
.55068 .58781 L
.54789 .58297 L
.54525 .5784 L
.54276 .57407 L
.5404 .56999 L
.53817 .56613 L
.53607 .56249 L
.53408 .55904 L
.5322 .55579 L
.53043 .55271 L
.52875 .5498 L
.52717 .54706 L
.52567 .54447 L
.52425 .54201 L
.52292 .5397 L
.52165 .53751 L
.52046 .53544 L
.51933 .53349 L
.51827 .53164 L
Mistroke
.51726 .5299 L
.51631 .52825 L
.51541 .52669 L
.51456 .52522 L
.51376 .52383 L
.513 .52252 L
.51228 .52128 L
.51161 .5201 L
.51097 .519 L
.51036 .51795 L
.50979 .51696 L
.50925 .51602 L
.50874 .51514 L
.50826 .51431 L
.5078 .51352 L
.50737 .51277 L
.50697 .51207 L
.50658 .5114 L
.50622 .51077 L
.50588 .51018 L
.50555 .50962 L
.50525 .50909 L
.50496 .50859 L
.50469 .50811 L
.50443 .50767 L
.50418 .50724 L
.50395 .50685 L
.50373 .50647 L
.50353 .50611 L
.50333 .50577 L
.50315 .50546 L
.50298 .50516 L
.50281 .50487 L
.50266 .5046 L
.50251 .50435 L
.50237 .50411 L
.50224 .50388 L
.50212 .50367 L
.502 .50347 L
.50189 .50328 L
.50179 .5031 L
.50169 .50292 L
.5016 .50276 L
.50151 .50261 L
.50142 .50247 L
.50135 .50233 L
.50127 .5022 L
.5012 .50208 L
.50114 .50197 L
.50107 .50186 L
Mistroke
.50101 .50176 L
.50096 .50166 L
.5009 .50157 L
.50086 .50148 L
.50081 .5014 L
.50076 .50132 L
.50072 .50125 L
.50068 .50118 L
.50064 .50112 L
.50061 .50105 L
.50057 .501 L
.50054 .50094 L
.50051 .50089 L
.50049 .50084 L
.50046 .50079 L
.50043 .50075 L
.50041 .50071 L
.50039 .50067 L
.50037 .50063 L
.50035 .5006 L
.50033 .50056 L
.50031 .50053 L
.50029 .5005 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50018 .50032 L
.50017 .5003 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50012 .50022 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
Mfstroke
0 .11 1 r
.37484 0 m
.37515 .03336 L
.37637 .0689 L
.37827 .10117 L
.38073 .13052 L
.38362 .15727 L
.38684 .18169 L
.39031 .20403 L
.39396 .2245 L
.39772 .24328 L
.40156 .26055 L
.40543 .27645 L
.40929 .29112 L
.41312 .30466 L
.41689 .31719 L
.42059 .32879 L
.42421 .33954 L
.42773 .34953 L
.43114 .35882 L
.43444 .36746 L
.43762 .37551 L
.44069 .38301 L
.44363 .39002 L
.44646 .39657 L
.44917 .40269 L
.45176 .40842 L
.45424 .41378 L
.4566 .4188 L
.45886 .42352 L
.46101 .42794 L
.46306 .43209 L
.465 .43598 L
.46686 .43965 L
.46862 .44309 L
.47029 .44633 L
.47188 .44937 L
.47338 .45224 L
.47481 .45493 L
.47617 .45748 L
.47745 .45987 L
.47867 .46212 L
.47983 .46425 L
.48092 .46625 L
.48196 .46814 L
.48294 .46992 L
.48387 .4716 L
.48474 .47318 L
.48558 .47467 L
.48636 .47608 L
.48711 .47741 L
Mistroke
.48781 .47867 L
.48848 .47985 L
.48911 .48097 L
.48971 .48203 L
.49027 .48302 L
.4908 .48396 L
.49131 .48485 L
.49179 .48569 L
.49224 .48648 L
.49266 .48723 L
.49307 .48794 L
.49345 .4886 L
.49381 .48923 L
.49415 .48983 L
.49447 .49039 L
.49477 .49092 L
.49506 .49142 L
.49533 .4919 L
.49559 .49234 L
.49583 .49277 L
.49606 .49317 L
.49628 .49354 L
.49648 .4939 L
.49668 .49424 L
.49686 .49455 L
.49703 .49485 L
.4972 .49514 L
.49735 .49541 L
.4975 .49566 L
.49763 .4959 L
.49776 .49613 L
.49789 .49634 L
.498 .49654 L
.49811 .49673 L
.49822 .49691 L
.49832 .49708 L
.49841 .49724 L
.4985 .4974 L
.49858 .49754 L
.49866 .49767 L
.49873 .4978 L
.4988 .49792 L
.49887 .49804 L
.49893 .49815 L
.49899 .49825 L
.49904 .49835 L
.4991 .49844 L
.49915 .49852 L
.49919 .4986 L
.49924 .49868 L
Mistroke
.49928 .49875 L
.49932 .49882 L
.49936 .49889 L
.49939 .49895 L
.49943 .49901 L
.49946 .49906 L
.49949 .49911 L
.49952 .49916 L
.49954 .49921 L
.49957 .49925 L
.49959 .49929 L
.49961 .49933 L
.49964 .49937 L
.49966 .4994 L
.49967 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49952 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49971 L
.49984 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
Mistroke
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
Mfstroke
1 0 .34 r
.19799 0 m
.2 .00309 L
.21705 .02959 L
.23309 .05475 L
.24819 .07863 L
.2624 .10127 L
.27579 .12275 L
.2884 .14311 L
.30028 .16241 L
.31148 .18069 L
.32203 .19801 L
.33198 .21441 L
.34137 .22994 L
.35022 .24464 L
.35857 .25856 L
.36644 .27173 L
.37387 .28419 L
.38089 .29598 L
.3875 .30714 L
.39375 .31769 L
.39965 .32767 L
.40521 .33711 L
.41046 .34604 L
.41543 .35448 L
.42011 .36247 L
.42453 .37001 L
.42871 .37715 L
.43265 .3839 L
.43638 .39028 L
.43989 .39631 L
.44322 .40201 L
.44636 .40739 L
.44932 .41249 L
.45212 .4173 L
.45476 .42185 L
.45726 .42615 L
.45962 .43021 L
.46185 .43405 L
.46396 .43768 L
.46595 .44111 L
.46782 .44436 L
.4696 .44742 L
.47128 .45031 L
.47286 .45305 L
.47436 .45564 L
.47577 .45808 L
.47711 .46039 L
.47837 .46257 L
.47957 .46463 L
.48069 .46658 L
Mistroke
.48176 .46842 L
.48276 .47016 L
.48371 .47181 L
.48461 .47336 L
.48546 .47483 L
.48626 .47622 L
.48702 .47753 L
.48774 .47876 L
.48841 .47993 L
.48905 .48104 L
.48965 .48209 L
.49022 .48307 L
.49076 .48401 L
.49127 .48489 L
.49175 .48572 L
.49221 .48651 L
.49264 .48725 L
.49304 .48795 L
.49343 .48862 L
.49379 .48924 L
.49413 .48984 L
.49446 .4904 L
.49476 .49093 L
.49505 .49143 L
.49532 .4919 L
.49558 .49235 L
.49582 .49277 L
.49605 .49317 L
.49627 .49354 L
.49648 .4939 L
.49667 .49424 L
.49686 .49455 L
.49703 .49485 L
.49719 .49514 L
.49735 .4954 L
.49749 .49566 L
.49763 .4959 L
.49776 .49612 L
.49789 .49634 L
.498 .49654 L
.49811 .49673 L
.49822 .49691 L
.49831 .49708 L
.49841 .49724 L
.4985 .49739 L
.49858 .49754 L
.49866 .49767 L
.49873 .4978 L
.4988 .49792 L
.49887 .49804 L
Mistroke
.49893 .49815 L
.49899 .49825 L
.49904 .49834 L
.4991 .49844 L
.49915 .49852 L
.49919 .4986 L
.49924 .49868 L
.49928 .49875 L
.49932 .49882 L
.49936 .49889 L
.49939 .49895 L
.49943 .49901 L
.49946 .49906 L
.49949 .49911 L
.49952 .49916 L
.49954 .49921 L
.49957 .49925 L
.49959 .49929 L
.49961 .49933 L
.49964 .49937 L
.49966 .4994 L
.49967 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49952 L
.49974 .49955 L
.49975 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49971 L
.49984 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49978 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
Mistroke
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
Mfstroke
0 1 .002 r
.00401 0 m
.03695 .01236 L
.06958 .02692 L
.09947 .04232 L
.12689 .05829 L
.15209 .07462 L
.17527 .09113 L
.19665 .10764 L
.21638 .12406 L
.23462 .14026 L
.25151 .15617 L
.26717 .17173 L
.2817 .18689 L
.2952 .2016 L
.30777 .21584 L
.31947 .22959 L
.33037 .24284 L
.34055 .25558 L
.35006 .26781 L
.35895 .27953 L
.36726 .29075 L
.37505 .30147 L
.38234 .31171 L
.38918 .32148 L
.39559 .3308 L
.40161 .33967 L
.40726 .34811 L
.41257 .35614 L
.41756 .36377 L
.42225 .37102 L
.42667 .37791 L
.43082 .38445 L
.43473 .39065 L
.43841 .39653 L
.44188 .40211 L
.44515 .4074 L
.44822 .41241 L
.45112 .41715 L
.45386 .42165 L
.45644 .42591 L
.45887 .42994 L
.46116 .43375 L
.46333 .43736 L
.46537 .44078 L
.4673 .44402 L
.46911 .44708 L
.47083 .44997 L
.47245 .45271 L
.47398 .4553 L
.47542 .45775 L
Mistroke
.47678 .46006 L
.47807 .46226 L
.47928 .46433 L
.48043 .46628 L
.48151 .46814 L
.48253 .46989 L
.4835 .47154 L
.48441 .4731 L
.48527 .47458 L
.48609 .47598 L
.48686 .4773 L
.48758 .47855 L
.48827 .47973 L
.48892 .48085 L
.48953 .4819 L
.49011 .4829 L
.49065 .48384 L
.49117 .48473 L
.49166 .48557 L
.49212 .48636 L
.49255 .48711 L
.49296 .48782 L
.49335 .48849 L
.49372 .48913 L
.49406 .48973 L
.49439 .49029 L
.4947 .49083 L
.49499 .49133 L
.49527 .49181 L
.49553 .49226 L
.49578 .49269 L
.49601 .49309 L
.49623 .49347 L
.49644 .49383 L
.49663 .49417 L
.49682 .49449 L
.49699 .4948 L
.49716 .49508 L
.49732 .49535 L
.49746 .49561 L
.4976 .49585 L
.49774 .49608 L
.49786 .4963 L
.49798 .4965 L
.49809 .49669 L
.4982 .49688 L
.4983 .49705 L
.49839 .49721 L
.49848 .49736 L
.49856 .49751 L
Mistroke
.49864 .49765 L
.49872 .49778 L
.49879 .4979 L
.49885 .49801 L
.49892 .49812 L
.49898 .49823 L
.49903 .49833 L
.49909 .49842 L
.49914 .4985 L
.49918 .49859 L
.49923 .49867 L
.49927 .49874 L
.49931 .49881 L
.49935 .49887 L
.49939 .49894 L
.49942 .49899 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
.49956 .49924 L
.49959 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
Mistroke
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
1 .704 0 r
.47312 .98373 m
.4866 .93628 L
.49774 .89422 L
.50687 .85689 L
.5143 .82369 L
.52027 .79414 L
.52502 .76777 L
.52872 .74421 L
.53153 .72313 L
.53361 .70423 L
.53506 .68725 L
.53599 .67197 L
.53649 .65819 L
.53663 .64575 L
.53647 .63449 L
.53607 .62428 L
.53548 .61501 L
.53474 .60657 L
.53387 .59888 L
.53292 .59185 L
.53189 .58542 L
.53082 .57953 L
.52971 .57412 L
.52858 .56915 L
.52745 .56457 L
.52632 .56034 L
.52521 .55644 L
.52411 .55283 L
.52303 .54948 L
.52198 .54638 L
.52095 .54349 L
.51996 .54081 L
.519 .53832 L
.51808 .536 L
.51719 .53383 L
.51633 .5318 L
.51551 .52991 L
.51472 .52815 L
.51397 .52649 L
.51325 .52494 L
.51257 .52349 L
.51191 .52213 L
.51129 .52085 L
.5107 .51965 L
.51013 .51852 L
.5096 .51746 L
.50909 .51647 L
.5086 .51553 L
.50814 .51465 L
.50771 .51382 L
Mistroke
.50729 .51304 L
.5069 .51231 L
.50653 .51161 L
.50617 .51096 L
.50584 .51035 L
.50552 .50977 L
.50522 .50922 L
.50494 .50871 L
.50467 .50822 L
.50442 .50776 L
.50418 .50733 L
.50395 .50692 L
.50373 .50654 L
.50353 .50617 L
.50333 .50583 L
.50315 .50551 L
.50298 .5052 L
.50282 .50491 L
.50266 .50464 L
.50252 .50438 L
.50238 .50414 L
.50225 .50391 L
.50212 .5037 L
.50201 .50349 L
.5019 .5033 L
.50179 .50312 L
.50169 .50294 L
.5016 .50278 L
.50151 .50263 L
.50143 .50248 L
.50135 .50235 L
.50128 .50222 L
.50121 .50209 L
.50114 .50198 L
.50108 .50187 L
.50102 .50177 L
.50096 .50167 L
.50091 .50158 L
.50086 .50149 L
.50081 .50141 L
.50077 .50133 L
.50072 .50126 L
.50068 .50119 L
.50065 .50112 L
.50061 .50106 L
.50058 .501 L
.50055 .50095 L
.50052 .50089 L
.50049 .50084 L
.50046 .5008 L
Mistroke
.50044 .50075 L
.50041 .50071 L
.50039 .50067 L
.50037 .50064 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .5003 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .5002 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
Mistroke
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.612 1 0 r
.2408 0 m
.24873 .01801 L
.26152 .04641 L
.27375 .073 L
.28543 .09791 L
.29657 .12127 L
.30718 .14318 L
.31729 .16374 L
.32692 .18306 L
.33607 .2012 L
.34477 .21825 L
.35303 .23429 L
.36088 .24937 L
.36833 .26356 L
.3754 .27693 L
.3821 .28951 L
.38846 .30136 L
.39448 .31252 L
.40019 .32304 L
.4056 .33295 L
.41073 .3423 L
.41558 .35111 L
.42017 .35942 L
.42452 .36726 L
.42863 .37466 L
.43253 .38163 L
.43621 .38822 L
.4397 .39443 L
.443 .40029 L
.44612 .40583 L
.44907 .41105 L
.45186 .41598 L
.4545 .42064 L
.45699 .42504 L
.45935 .42919 L
.46159 .43311 L
.46369 .43681 L
.46569 .4403 L
.46757 .4436 L
.46936 .44672 L
.47104 .44967 L
.47263 .45245 L
.47414 .45507 L
.47556 .45756 L
.47691 .4599 L
.47818 .46211 L
.47938 .46421 L
.48051 .46618 L
.48159 .46805 L
.4826 .46981 L
Mistroke
.48356 .47148 L
.48446 .47305 L
.48532 .47454 L
.48613 .47594 L
.48689 .47727 L
.48761 .47852 L
.4883 .47971 L
.48894 .48083 L
.48955 .48189 L
.49012 .48288 L
.49067 .48383 L
.49118 .48472 L
.49167 .48556 L
.49213 .48636 L
.49256 .48711 L
.49297 .48782 L
.49336 .48849 L
.49372 .48913 L
.49407 .48973 L
.4944 .49029 L
.49471 .49083 L
.495 .49133 L
.49527 .49181 L
.49553 .49226 L
.49578 .49269 L
.49601 .49309 L
.49623 .49347 L
.49644 .49383 L
.49664 .49417 L
.49682 .49449 L
.497 .4948 L
.49716 .49508 L
.49732 .49536 L
.49747 .49561 L
.49761 .49585 L
.49774 .49608 L
.49786 .4963 L
.49798 .4965 L
.49809 .4967 L
.4982 .49688 L
.4983 .49705 L
.49839 .49721 L
.49848 .49737 L
.49856 .49751 L
.49864 .49765 L
.49872 .49778 L
.49879 .4979 L
.49885 .49802 L
.49892 .49813 L
.49898 .49823 L
Mistroke
.49903 .49833 L
.49909 .49842 L
.49914 .49851 L
.49918 .49859 L
.49923 .49867 L
.49927 .49874 L
.49931 .49881 L
.49935 .49887 L
.49939 .49894 L
.49942 .499 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
.49956 .49924 L
.49959 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
Mistroke
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
Mfstroke
.699 1 0 r
.74695 1 m
.74377 .99174 L
.73191 .96191 L
.72049 .93409 L
.70951 .90811 L
.69899 .88384 L
.68891 .86115 L
.67926 .83991 L
.67005 .82002 L
.66125 .80138 L
.65286 .78391 L
.64487 .76751 L
.63726 .75211 L
.63002 .73765 L
.62313 .72406 L
.61659 .71129 L
.61038 .69928 L
.60447 .68798 L
.59887 .67734 L
.59356 .66733 L
.58852 .6579 L
.58375 .64901 L
.57922 .64064 L
.57493 .63276 L
.57087 .62532 L
.56702 .61831 L
.56338 .61171 L
.55993 .60547 L
.55666 .59959 L
.55357 .59405 L
.55065 .58881 L
.54788 .58387 L
.54526 .57921 L
.54279 .57482 L
.54044 .57066 L
.53823 .56674 L
.53613 .56305 L
.53415 .55955 L
.53228 .55625 L
.53051 .55314 L
.52883 .5502 L
.52725 .54742 L
.52575 .5448 L
.52434 .54232 L
.523 .53998 L
.52173 .53777 L
.52054 .53569 L
.51941 .53371 L
.51834 .53185 L
.51733 .53009 L
Mistroke
.51638 .52843 L
.51548 .52686 L
.51463 .52538 L
.51382 .52398 L
.51306 .52265 L
.51234 .5214 L
.51166 .52022 L
.51102 .51911 L
.51041 .51805 L
.50984 .51706 L
.5093 .51612 L
.50878 .51523 L
.5083 .51439 L
.50784 .51359 L
.50741 .51284 L
.507 .51214 L
.50662 .51147 L
.50625 .51083 L
.50591 .51024 L
.50558 .50967 L
.50527 .50914 L
.50498 .50864 L
.50471 .50816 L
.50445 .50771 L
.5042 .50728 L
.50397 .50688 L
.50375 .5065 L
.50355 .50615 L
.50335 .50581 L
.50317 .50549 L
.50299 .50518 L
.50283 .5049 L
.50267 .50463 L
.50252 .50437 L
.50239 .50413 L
.50225 .5039 L
.50213 .50369 L
.50201 .50349 L
.5019 .50329 L
.5018 .50311 L
.5017 .50294 L
.5016 .50278 L
.50152 .50263 L
.50143 .50248 L
.50135 .50234 L
.50128 .50221 L
.50121 .50209 L
.50114 .50198 L
.50108 .50187 L
.50102 .50177 L
Mistroke
.50096 .50167 L
.50091 .50158 L
.50086 .50149 L
.50081 .50141 L
.50077 .50133 L
.50073 .50126 L
.50069 .50119 L
.50065 .50112 L
.50061 .50106 L
.50058 .501 L
.50055 .50095 L
.50052 .50089 L
.50049 .50084 L
.50046 .5008 L
.50044 .50075 L
.50041 .50071 L
.50039 .50067 L
.50037 .50064 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .5003 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .5002 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
Mistroke
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
Mfstroke
1 .225 0 r
.72172 1 m
.71375 .97307 L
.70429 .94297 L
.69505 .91506 L
.68605 .88915 L
.67731 .86508 L
.66884 .84268 L
.66067 .82182 L
.6528 .80238 L
.64523 .78423 L
.63797 .76729 L
.631 .75144 L
.62434 .73662 L
.61796 .72274 L
.61188 .70974 L
.60607 .69756 L
.60054 .68613 L
.59527 .6754 L
.59025 .66532 L
.58548 .65586 L
.58095 .64696 L
.57664 .63859 L
.57255 .63072 L
.56866 .62332 L
.56498 .61635 L
.56148 .60979 L
.55817 .60361 L
.55502 .59778 L
.55205 .5923 L
.54923 .58713 L
.54656 .58225 L
.54403 .57765 L
.54163 .57332 L
.53936 .56923 L
.53722 .56537 L
.53519 .56173 L
.53327 .5583 L
.53145 .55506 L
.52973 .552 L
.5281 .54911 L
.52656 .54639 L
.52511 .54382 L
.52373 .54139 L
.52243 .5391 L
.5212 .53693 L
.52003 .53489 L
.51893 .53296 L
.51789 .53113 L
.51691 .52941 L
.51598 .52779 L
Mistroke
.5151 .52625 L
.51427 .5248 L
.51349 .52343 L
.51275 .52214 L
.51204 .52091 L
.51138 .51976 L
.51076 .51867 L
.51016 .51764 L
.5096 .51666 L
.50908 .51574 L
.50858 .51488 L
.5081 .51405 L
.50766 .51328 L
.50724 .51255 L
.50684 .51185 L
.50646 .5112 L
.5061 .51058 L
.50577 .51 L
.50545 .50945 L
.50515 .50893 L
.50487 .50843 L
.5046 .50797 L
.50434 .50753 L
.50411 .50711 L
.50388 .50672 L
.50367 .50635 L
.50346 .506 L
.50327 .50567 L
.50309 .50536 L
.50292 .50506 L
.50276 .50478 L
.50261 .50452 L
.50246 .50427 L
.50233 .50403 L
.5022 .50381 L
.50208 .5036 L
.50196 .5034 L
.50186 .50322 L
.50175 .50304 L
.50166 .50287 L
.50157 .50271 L
.50148 .50256 L
.5014 .50242 L
.50132 .50229 L
.50125 .50216 L
.50118 .50204 L
.50111 .50193 L
.50105 .50182 L
.501 .50172 L
.50094 .50163 L
Mistroke
.50089 .50154 L
.50084 .50145 L
.50079 .50137 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50063 .5011 L
.5006 .50103 L
.50056 .50098 L
.50053 .50092 L
.5005 .50087 L
.50048 .50082 L
.50045 .50078 L
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50055 L
.5003 .50052 L
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .50039 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
Mistroke
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
Mfstroke
0 1 .273 r
.62107 1 m
.62121 .99208 L
.62091 .9539 L
.61978 .9193 L
.61797 .88788 L
.61562 .85931 L
.61285 .83327 L
.60974 .8095 L
.6064 .78776 L
.60287 .76784 L
.59923 .74956 L
.59552 .73276 L
.59178 .71729 L
.58804 .70303 L
.58433 .68986 L
.58067 .67768 L
.57708 .6664 L
.57358 .65593 L
.57017 .64622 L
.56686 .6372 L
.56366 .62879 L
.56057 .62097 L
.55759 .61367 L
.55473 .60686 L
.55199 .6005 L
.54936 .59455 L
.54684 .58898 L
.54444 .58377 L
.54214 .57889 L
.53995 .57431 L
.53787 .57001 L
.53588 .56598 L
.53399 .56219 L
.53219 .55863 L
.53048 .55529 L
.52886 .55214 L
.52732 .54918 L
.52585 .5464 L
.52446 .54378 L
.52315 .54131 L
.5219 .53899 L
.52072 .5368 L
.51959 .53473 L
.51853 .53279 L
.51753 .53095 L
.51657 .52922 L
.51567 .52759 L
.51482 .52605 L
.51401 .5246 L
.51325 .52323 L
Mistroke
.51252 .52194 L
.51184 .52072 L
.51119 .51957 L
.51058 .51848 L
.51 .51746 L
.50945 .51649 L
.50893 .51558 L
.50844 .51471 L
.50798 .5139 L
.50754 .51313 L
.50713 .5124 L
.50674 .51172 L
.50637 .51107 L
.50602 .51046 L
.50568 .50988 L
.50537 .50933 L
.50508 .50882 L
.5048 .50833 L
.50453 .50787 L
.50428 .50744 L
.50405 .50703 L
.50383 .50664 L
.50361 .50627 L
.50342 .50593 L
.50323 .5056 L
.50305 .50529 L
.50288 .505 L
.50272 .50472 L
.50257 .50446 L
.50243 .50422 L
.5023 .50398 L
.50217 .50376 L
.50205 .50356 L
.50194 .50336 L
.50183 .50317 L
.50173 .503 L
.50164 .50283 L
.50155 .50268 L
.50146 .50253 L
.50138 .50239 L
.5013 .50226 L
.50123 .50213 L
.50116 .50202 L
.5011 .50191 L
.50104 .5018 L
.50098 .5017 L
.50093 .50161 L
.50088 .50152 L
.50083 .50143 L
.50078 .50136 L
Mistroke
.50074 .50128 L
.5007 .50121 L
.50066 .50114 L
.50062 .50108 L
.50059 .50102 L
.50056 .50096 L
.50053 .50091 L
.5005 .50086 L
.50047 .50081 L
.50044 .50077 L
.50042 .50073 L
.5004 .50069 L
.50037 .50065 L
.50035 .50061 L
.50033 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50022 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
Mistroke
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
Mfstroke
0 .949 1 r
0 .02847 m
.01265 .03152 L
.04802 .04262 L
.0803 .05508 L
.10981 .06855 L
.13685 .08275 L
.16166 .09745 L
.18446 .11245 L
.20545 .12758 L
.2248 .14271 L
.24267 .15773 L
.2592 .17254 L
.2745 .18708 L
.28869 .20128 L
.30186 .21511 L
.3141 .22853 L
.32549 .24151 L
.3361 .25405 L
.34599 .26612 L
.35522 .27772 L
.36385 .28886 L
.37191 .29953 L
.37946 .30974 L
.38652 .3195 L
.39314 .32882 L
.39934 .33771 L
.40516 .34618 L
.41063 .35425 L
.41576 .36193 L
.42058 .36924 L
.42511 .37618 L
.42937 .38277 L
.43338 .38903 L
.43715 .39498 L
.4407 .40062 L
.44405 .40596 L
.4472 .41103 L
.45016 .41584 L
.45296 .4204 L
.4556 .42471 L
.45808 .4288 L
.46042 .43267 L
.46263 .43633 L
.46471 .4398 L
.46668 .44308 L
.46854 .44619 L
.47028 .44913 L
.47194 .45191 L
.47349 .45454 L
.47497 .45703 L
Mistroke
.47635 .45938 L
.47767 .46161 L
.4789 .46371 L
.48007 .4657 L
.48118 .46758 L
.48222 .46936 L
.4832 .47105 L
.48413 .47264 L
.48501 .47414 L
.48584 .47556 L
.48662 .4769 L
.48736 .47817 L
.48806 .47937 L
.48872 .48051 L
.48934 .48158 L
.48993 .48259 L
.49048 .48355 L
.49101 .48446 L
.49151 .48531 L
.49197 .48612 L
.49242 .48689 L
.49284 .48761 L
.49323 .48829 L
.4936 .48894 L
.49396 .48954 L
.49429 .49012 L
.49461 .49066 L
.4949 .49118 L
.49518 .49167 L
.49545 .49212 L
.4957 .49256 L
.49594 .49297 L
.49616 .49336 L
.49637 .49372 L
.49657 .49407 L
.49676 .49439 L
.49694 .4947 L
.49711 .495 L
.49727 .49527 L
.49742 .49553 L
.49756 .49578 L
.4977 .49601 L
.49782 .49623 L
.49794 .49644 L
.49806 .49663 L
.49816 .49682 L
.49827 .497 L
.49836 .49716 L
.49845 .49732 L
.49854 .49747 L
Mistroke
.49862 .49761 L
.49869 .49774 L
.49877 .49786 L
.49883 .49798 L
.4989 .49809 L
.49896 .4982 L
.49902 .4983 L
.49907 .49839 L
.49912 .49848 L
.49917 .49856 L
.49922 .49864 L
.49926 .49872 L
.4993 .49879 L
.49934 .49885 L
.49937 .49892 L
.49941 .49898 L
.49944 .49903 L
.49947 .49909 L
.4995 .49914 L
.49953 .49918 L
.49956 .49923 L
.49958 .49927 L
.4996 .49931 L
.49962 .49935 L
.49965 .49939 L
.49966 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
Mistroke
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
0 .386 1 r
.78945 1 m
.78211 .98738 L
.76653 .96056 L
.75182 .93522 L
.73791 .91126 L
.72478 .88863 L
.71238 .86723 L
.70065 .84701 L
.68958 .82791 L
.67912 .80985 L
.66924 .79279 L
.6599 .77666 L
.65108 .76142 L
.64275 .74702 L
.63487 .73342 L
.62744 .72056 L
.62041 .70841 L
.61377 .69692 L
.60749 .68607 L
.60157 .67582 L
.59597 .66613 L
.59067 .65698 L
.58567 .64833 L
.58095 .64016 L
.57649 .63243 L
.57227 .62513 L
.56829 .61824 L
.56452 .61172 L
.56096 .60557 L
.5576 .59975 L
.55443 .59425 L
.55143 .58906 L
.54859 .58415 L
.54591 .57951 L
.54338 .57513 L
.54099 .57099 L
.53873 .56707 L
.5366 .56338 L
.53458 .55988 L
.53267 .55658 L
.53087 .55346 L
.52917 .55052 L
.52756 .54773 L
.52604 .5451 L
.52461 .54262 L
.52325 .54027 L
.52197 .53805 L
.52076 .53595 L
.51961 .53397 L
.51853 .5321 L
Mistroke
.51751 .53033 L
.51655 .52866 L
.51563 .52708 L
.51477 .52558 L
.51396 .52417 L
.51319 .52284 L
.51246 .52158 L
.51177 .52039 L
.51113 .51927 L
.51051 .51821 L
.50993 .5172 L
.50938 .51625 L
.50887 .51536 L
.50838 .51451 L
.50792 .51371 L
.50748 .51296 L
.50707 .51224 L
.50668 .51157 L
.50631 .51093 L
.50596 .51033 L
.50563 .50976 L
.50532 .50922 L
.50503 .50871 L
.50475 .50823 L
.50449 .50778 L
.50424 .50735 L
.50401 .50694 L
.50379 .50656 L
.50358 .5062 L
.50338 .50586 L
.5032 .50554 L
.50302 .50523 L
.50285 .50494 L
.5027 .50467 L
.50255 .50441 L
.50241 .50417 L
.50227 .50394 L
.50215 .50372 L
.50203 .50352 L
.50192 .50332 L
.50181 .50314 L
.50171 .50297 L
.50162 .5028 L
.50153 .50265 L
.50144 .5025 L
.50137 .50236 L
.50129 .50223 L
.50122 .50211 L
.50115 .50199 L
.50109 .50188 L
Mistroke
.50103 .50178 L
.50097 .50168 L
.50092 .50159 L
.50087 .5015 L
.50082 .50142 L
.50077 .50134 L
.50073 .50127 L
.50069 .5012 L
.50065 .50113 L
.50062 .50107 L
.50058 .50101 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .50081 L
.50044 .50076 L
.50042 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .50061 L
.50033 .50057 L
.50031 .50054 L
.5003 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50039 L
.50021 .50036 L
.5002 .50034 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50018 L
.5001 .50017 L
.5001 .50016 L
.50009 .50016 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
Mfstroke
.389 1 0 r
.89884 1 m
.89103 .99437 L
.86534 .97429 L
.84162 .95436 L
.81968 .9347 L
.79936 .9154 L
.78053 .89654 L
.76304 .87819 L
.74679 .86038 L
.73167 .84314 L
.71759 .8265 L
.70445 .81048 L
.6922 .79508 L
.68075 .78029 L
.67004 .76613 L
.66003 .75257 L
.65065 .73961 L
.64186 .72724 L
.63362 .71544 L
.6259 .70419 L
.61864 .69348 L
.61183 .68329 L
.60543 .67359 L
.59942 .66438 L
.59376 .65562 L
.58844 .64731 L
.58343 .63942 L
.57872 .63193 L
.57428 .62483 L
.5701 .6181 L
.56616 .61172 L
.56245 .60568 L
.55895 .59995 L
.55565 .59452 L
.55254 .58939 L
.54961 .58452 L
.54684 .57992 L
.54423 .57556 L
.54177 .57144 L
.53945 .56754 L
.53726 .56384 L
.53519 .56035 L
.53323 .55705 L
.53139 .55392 L
.52965 .55097 L
.52801 .54817 L
.52646 .54553 L
.52499 .54303 L
.52361 .54067 L
.5223 .53844 L
Mistroke
.52107 .53633 L
.5199 .53433 L
.5188 .53244 L
.51776 .53066 L
.51678 .52897 L
.51585 .52738 L
.51498 .52587 L
.51415 .52445 L
.51337 .52311 L
.51263 .52183 L
.51193 .52063 L
.51128 .5195 L
.51065 .51842 L
.51007 .51741 L
.50951 .51645 L
.50899 .51554 L
.50849 .51469 L
.50802 .51388 L
.50758 .51311 L
.50716 .51239 L
.50677 .51171 L
.50639 .51106 L
.50604 .51046 L
.50571 .50988 L
.50539 .50933 L
.5051 .50882 L
.50481 .50833 L
.50455 .50788 L
.5043 .50744 L
.50406 .50703 L
.50384 .50664 L
.50363 .50628 L
.50343 .50593 L
.50324 .5056 L
.50306 .5053 L
.50289 .505 L
.50273 .50473 L
.50258 .50447 L
.50244 .50422 L
.5023 .50399 L
.50218 .50377 L
.50206 .50356 L
.50194 .50336 L
.50184 .50318 L
.50173 .503 L
.50164 .50284 L
.50155 .50268 L
.50146 .50253 L
.50138 .50239 L
.50131 .50226 L
Mistroke
.50123 .50214 L
.50117 .50202 L
.5011 .50191 L
.50104 .5018 L
.50098 .5017 L
.50093 .50161 L
.50088 .50152 L
.50083 .50144 L
.50078 .50136 L
.50074 .50128 L
.5007 .50121 L
.50066 .50115 L
.50063 .50108 L
.50059 .50102 L
.50056 .50097 L
.50053 .50091 L
.5005 .50086 L
.50047 .50082 L
.50044 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50035 .50061 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
Mistroke
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
Mfstroke
1 .93 0 r
.17823 0 m
.19374 .02054 L
.21177 .04497 L
.22866 .06832 L
.24448 .09061 L
.25932 .11188 L
.27324 .13215 L
.2863 .15145 L
.29857 .16981 L
.31009 .18728 L
.32093 .20388 L
.33112 .21965 L
.3407 .23463 L
.34972 .24885 L
.35821 .26233 L
.36621 .27512 L
.37374 .28725 L
.38083 .29874 L
.38752 .30963 L
.39382 .31995 L
.39976 .32973 L
.40536 .33898 L
.41064 .34774 L
.41562 .35604 L
.42032 .36389 L
.42476 .37131 L
.42894 .37834 L
.43289 .38499 L
.43662 .39129 L
.44014 .39724 L
.44346 .40286 L
.44659 .40819 L
.44955 .41322 L
.45235 .41798 L
.45498 .42248 L
.45748 .42674 L
.45983 .43076 L
.46205 .43456 L
.46415 .43816 L
.46613 .44156 L
.468 .44477 L
.46977 .44781 L
.47144 .45068 L
.47302 .45339 L
.47451 .45595 L
.47592 .45838 L
.47725 .46067 L
.4785 .46283 L
.47969 .46488 L
.48081 .46681 L
Mistroke
.48187 .46864 L
.48287 .47037 L
.48381 .472 L
.48471 .47354 L
.48555 .475 L
.48635 .47638 L
.4871 .47768 L
.48781 .47891 L
.48848 .48007 L
.48912 .48117 L
.48972 .4822 L
.49029 .48318 L
.49082 .48411 L
.49133 .48499 L
.49181 .48581 L
.49226 .4866 L
.49268 .48733 L
.49309 .48803 L
.49347 .48869 L
.49383 .48932 L
.49417 .4899 L
.49449 .49046 L
.49479 .49099 L
.49508 .49148 L
.49535 .49195 L
.49561 .4924 L
.49585 .49281 L
.49608 .49321 L
.4963 .49359 L
.4965 .49394 L
.49669 .49427 L
.49688 .49459 L
.49705 .49489 L
.49721 .49517 L
.49736 .49543 L
.49751 .49569 L
.49765 .49592 L
.49778 .49615 L
.4979 .49636 L
.49801 .49656 L
.49812 .49675 L
.49823 .49693 L
.49833 .4971 L
.49842 .49726 L
.4985 .49741 L
.49859 .49755 L
.49867 .49769 L
.49874 .49782 L
.49881 .49794 L
.49887 .49805 L
Mistroke
.49894 .49816 L
.49899 .49826 L
.49905 .49835 L
.4991 .49845 L
.49915 .49853 L
.4992 .49861 L
.49924 .49869 L
.49928 .49876 L
.49932 .49883 L
.49936 .49889 L
.4994 .49895 L
.49943 .49901 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49921 L
.49957 .49926 L
.49959 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
Mistroke
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
Mfstroke
.517 0 1 r
1 .82758 m
.97762 .83002 L
.94004 .83132 L
.90604 .82994 L
.87521 .82639 L
.84721 .82108 L
.82173 .81436 L
.7985 .80656 L
.77728 .79791 L
.75787 .78863 L
.74008 .77892 L
.72375 .76891 L
.70873 .75873 L
.6949 .7485 L
.68214 .73829 L
.67035 .72818 L
.65945 .71823 L
.64935 .70847 L
.63998 .69895 L
.63128 .68969 L
.62319 .68071 L
.61566 .67203 L
.60865 .66365 L
.6021 .65559 L
.59599 .64785 L
.59029 .64042 L
.58495 .63331 L
.57995 .6265 L
.57527 .62 L
.57089 .61379 L
.56678 .60787 L
.56292 .60223 L
.5593 .59686 L
.5559 .59175 L
.5527 .58689 L
.5497 .58227 L
.54687 .57789 L
.54422 .57372 L
.54171 .56977 L
.53936 .56602 L
.53714 .56247 L
.53505 .5591 L
.53308 .5559 L
.53123 .55288 L
.52948 .55001 L
.52783 .54729 L
.52628 .54472 L
.52481 .54229 L
.52343 .53998 L
.52212 .5378 L
Mistroke
.52089 .53574 L
.51973 .53379 L
.51863 .53194 L
.5176 .53019 L
.51662 .52854 L
.5157 .52698 L
.51483 .5255 L
.51401 .5241 L
.51323 .52278 L
.5125 .52153 L
.51181 .52035 L
.51115 .51923 L
.51054 .51817 L
.50995 .51717 L
.5094 .51623 L
.50888 .51534 L
.50839 .51449 L
.50793 .5137 L
.50749 .51294 L
.50708 .51223 L
.50669 .51156 L
.50632 .51092 L
.50597 .51032 L
.50564 .50975 L
.50533 .50922 L
.50503 .50871 L
.50476 .50823 L
.50449 .50778 L
.50425 .50735 L
.50401 .50694 L
.50379 .50656 L
.50358 .5062 L
.50338 .50586 L
.5032 .50553 L
.50302 .50523 L
.50285 .50494 L
.5027 .50467 L
.50255 .50441 L
.50241 .50417 L
.50228 .50394 L
.50215 .50372 L
.50203 .50352 L
.50192 .50332 L
.50181 .50314 L
.50171 .50297 L
.50162 .5028 L
.50153 .50265 L
.50145 .5025 L
.50137 .50237 L
.50129 .50223 L
Mistroke
.50122 .50211 L
.50115 .502 L
.50109 .50189 L
.50103 .50178 L
.50097 .50168 L
.50092 .50159 L
.50087 .5015 L
.50082 .50142 L
.50077 .50134 L
.50073 .50127 L
.50069 .5012 L
.50065 .50113 L
.50062 .50107 L
.50058 .50101 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50047 .50081 L
.50044 .50076 L
.50042 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .50061 L
.50033 .50057 L
.50031 .50054 L
.5003 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50039 L
.50021 .50036 L
.5002 .50034 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50018 L
.5001 .50017 L
.5001 .50016 L
.50009 .50016 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
Mistroke
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
Mfstroke
0 .643 1 r
.26807 0 m
.27409 .01829 L
.2845 .04839 L
.29461 .07635 L
.30439 .10237 L
.31384 .12659 L
.32295 .14917 L
.33171 .17024 L
.34012 .18992 L
.34818 .20831 L
.3559 .22551 L
.36328 .24162 L
.37033 .25671 L
.37705 .27085 L
.38346 .28412 L
.38957 .29657 L
.39538 .30826 L
.40091 .31924 L
.40617 .32956 L
.41116 .33927 L
.4159 .34839 L
.4204 .35698 L
.42467 .36507 L
.42872 .37268 L
.43257 .37985 L
.43621 .3866 L
.43966 .39297 L
.44293 .39897 L
.44602 .40462 L
.44896 .40995 L
.45173 .41498 L
.45436 .41972 L
.45685 .4242 L
.4592 .42842 L
.46143 .4324 L
.46354 .43616 L
.46553 .4397 L
.46742 .44305 L
.4692 .44621 L
.47089 .44919 L
.47249 .45201 L
.474 .45467 L
.47542 .45718 L
.47677 .45955 L
.47805 .46179 L
.47925 .4639 L
.48039 .4659 L
.48147 .46778 L
.48249 .46956 L
.48345 .47124 L
Mistroke
.48436 .47283 L
.48522 .47433 L
.48603 .47575 L
.4868 .47709 L
.48753 .47835 L
.48822 .47955 L
.48886 .48068 L
.48948 .48174 L
.49006 .48275 L
.4906 .4837 L
.49112 .4846 L
.49161 .48545 L
.49207 .48626 L
.49251 .48701 L
.49292 .48773 L
.49331 .48841 L
.49368 .48905 L
.49403 .48965 L
.49436 .49022 L
.49467 .49076 L
.49496 .49127 L
.49524 .49175 L
.4955 .49221 L
.49575 .49264 L
.49598 .49304 L
.49621 .49343 L
.49641 .49379 L
.49661 .49413 L
.4968 .49445 L
.49698 .49476 L
.49714 .49505 L
.4973 .49532 L
.49745 .49558 L
.49759 .49582 L
.49772 .49605 L
.49785 .49627 L
.49797 .49648 L
.49808 .49667 L
.49818 .49685 L
.49828 .49703 L
.49838 .49719 L
.49847 .49735 L
.49855 .49749 L
.49863 .49763 L
.49871 .49776 L
.49878 .49788 L
.49885 .498 L
.49891 .49811 L
.49897 .49822 L
.49903 .49831 L
Mistroke
.49908 .49841 L
.49913 .49849 L
.49918 .49858 L
.49922 .49866 L
.49927 .49873 L
.49931 .4988 L
.49935 .49887 L
.49938 .49893 L
.49942 .49899 L
.49945 .49904 L
.49948 .4991 L
.49951 .49915 L
.49953 .49919 L
.49956 .49924 L
.49958 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .49939 L
.49967 .49943 L
.49969 .49946 L
.4997 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49976 .49959 L
.49978 .49961 L
.49979 .49964 L
.4998 .49966 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49982 L
.4999 .49983 L
.4999 .49984 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
Mistroke
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
1 0 .736 r
.15822 0 m
.16116 .00326 L
.18188 .02711 L
.20118 .05011 L
.21918 .07226 L
.23599 .09354 L
.25169 .11395 L
.26638 .1335 L
.28012 .15221 L
.29299 .17009 L
.30504 .18715 L
.31635 .20342 L
.32696 .21893 L
.33692 .23369 L
.34628 .24773 L
.35507 .26109 L
.36333 .27379 L
.3711 .28584 L
.37841 .29729 L
.38529 .30816 L
.39177 .31846 L
.39787 .32824 L
.40362 .3375 L
.40903 .34629 L
.41413 .35461 L
.41894 .36249 L
.42347 .36996 L
.42775 .37703 L
.43178 .38372 L
.43558 .39006 L
.43917 .39605 L
.44256 .40173 L
.44575 .4071 L
.44876 .41218 L
.45161 .41698 L
.45429 .42153 L
.45683 .42582 L
.45922 .42989 L
.46148 .43373 L
.46362 .43737 L
.46563 .44081 L
.46753 .44406 L
.46933 .44713 L
.47102 .45003 L
.47263 .45278 L
.47414 .45537 L
.47557 .45783 L
.47692 .46015 L
.47819 .46234 L
.4794 .46441 L
Mistroke
.48054 .46637 L
.48161 .46822 L
.48263 .46997 L
.48358 .47162 L
.48449 .47318 L
.48535 .47466 L
.48616 .47605 L
.48692 .47737 L
.48764 .47862 L
.48832 .4798 L
.48897 .48091 L
.48958 .48196 L
.49015 .48295 L
.49069 .48389 L
.49121 .48478 L
.49169 .48562 L
.49215 .48641 L
.49258 .48716 L
.49299 .48787 L
.49338 .48854 L
.49374 .48917 L
.49409 .48976 L
.49441 .49033 L
.49472 .49086 L
.49501 .49137 L
.49529 .49184 L
.49555 .49229 L
.49579 .49272 L
.49603 .49312 L
.49624 .4935 L
.49645 .49386 L
.49665 .49419 L
.49683 .49451 L
.49701 .49482 L
.49717 .4951 L
.49733 .49537 L
.49747 .49563 L
.49761 .49587 L
.49775 .4961 L
.49787 .49631 L
.49799 .49651 L
.4981 .49671 L
.4982 .49689 L
.4983 .49706 L
.4984 .49722 L
.49848 .49737 L
.49857 .49752 L
.49865 .49766 L
.49872 .49779 L
.49879 .49791 L
Mistroke
.49886 .49802 L
.49892 .49813 L
.49898 .49823 L
.49904 .49833 L
.49909 .49842 L
.49914 .49851 L
.49919 .49859 L
.49923 .49867 L
.49927 .49874 L
.49931 .49881 L
.49935 .49888 L
.49939 .49894 L
.49942 .499 L
.49945 .49905 L
.49948 .49911 L
.49951 .49916 L
.49954 .4992 L
.49956 .49925 L
.49959 .49929 L
.49961 .49933 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .4997 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .4998 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
Mistroke
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
Mfstroke
0 1 .946 r
.19732 0 m
.20579 .01301 L
.22252 .03897 L
.23826 .06361 L
.25307 .087 L
.26701 .10919 L
.28014 .13023 L
.29251 .15018 L
.30417 .16909 L
.31515 .18701 L
.3255 .20398 L
.33526 .22005 L
.34446 .23527 L
.35314 .24968 L
.36133 .26332 L
.36905 .27623 L
.37634 .28844 L
.38321 .3 L
.3897 .31094 L
.39583 .32128 L
.40161 .33106 L
.40707 .34032 L
.41222 .34907 L
.41708 .35735 L
.42167 .36517 L
.42601 .37257 L
.4301 .37957 L
.43397 .38618 L
.43762 .39243 L
.44107 .39834 L
.44433 .40393 L
.44741 .40921 L
.45031 .4142 L
.45306 .41892 L
.45565 .42338 L
.4581 .4276 L
.46041 .43158 L
.4626 .43535 L
.46466 .43891 L
.46661 .44227 L
.46846 .44545 L
.4702 .44845 L
.47184 .45129 L
.47339 .45397 L
.47486 .45651 L
.47625 .4589 L
.47756 .46117 L
.4788 .46331 L
.47997 .46533 L
.48107 .46724 L
Mistroke
.48212 .46904 L
.4831 .47075 L
.48403 .47236 L
.48491 .47388 L
.48575 .47532 L
.48653 .47668 L
.48727 .47797 L
.48798 .47918 L
.48864 .48033 L
.48927 .48141 L
.48986 .48244 L
.49042 .4834 L
.49094 .48432 L
.49144 .48518 L
.49192 .486 L
.49236 .48677 L
.49278 .4875 L
.49318 .48819 L
.49356 .48884 L
.49391 .48946 L
.49425 .49004 L
.49456 .49059 L
.49486 .4911 L
.49515 .4916 L
.49541 .49206 L
.49567 .4925 L
.49591 .49291 L
.49613 .4933 L
.49634 .49367 L
.49655 .49402 L
.49674 .49435 L
.49692 .49466 L
.49709 .49495 L
.49725 .49523 L
.4974 .4955 L
.49754 .49574 L
.49768 .49598 L
.49781 .4962 L
.49793 .49641 L
.49804 .49661 L
.49815 .49679 L
.49825 .49697 L
.49835 .49714 L
.49844 .4973 L
.49852 .49744 L
.49861 .49759 L
.49868 .49772 L
.49876 .49784 L
.49882 .49796 L
.49889 .49808 L
Mistroke
.49895 .49818 L
.49901 .49828 L
.49906 .49838 L
.49911 .49847 L
.49916 .49855 L
.49921 .49863 L
.49925 .49871 L
.49929 .49878 L
.49933 .49884 L
.49937 .49891 L
.4994 .49897 L
.49944 .49903 L
.49947 .49908 L
.4995 .49913 L
.49953 .49918 L
.49955 .49922 L
.49958 .49927 L
.4996 .49931 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49953 L
.49975 .49956 L
.49976 .49958 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
Mistroke
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
Mfstroke
1 0 .313 r
.14206 0 m
.14247 .0004 L
.16488 .02325 L
.1857 .04546 L
.20506 .06699 L
.22308 .08781 L
.23987 .10789 L
.25553 .12721 L
.27015 .14577 L
.28381 .16358 L
.29659 .18063 L
.30855 .19695 L
.31975 .21253 L
.33024 .22741 L
.34009 .24159 L
.34932 .25511 L
.35799 .26798 L
.36613 .28022 L
.37379 .29186 L
.38098 .30292 L
.38775 .31343 L
.39411 .32341 L
.4001 .33287 L
.40574 .34185 L
.41105 .35037 L
.41606 .35845 L
.42077 .3661 L
.42521 .37335 L
.4294 .38022 L
.43335 .38672 L
.43707 .39288 L
.44058 .39871 L
.44389 .40423 L
.44702 .40945 L
.44997 .4144 L
.45275 .41907 L
.45537 .4235 L
.45785 .42769 L
.46019 .43164 L
.4624 .43539 L
.46448 .43893 L
.46645 .44228 L
.46831 .44545 L
.47006 .44844 L
.47172 .45127 L
.47328 .45395 L
.47476 .45648 L
.47616 .45887 L
.47748 .46113 L
.47872 .46327 L
Mistroke
.4799 .46529 L
.48101 .4672 L
.48206 .469 L
.48305 .47071 L
.48398 .47232 L
.48487 .47384 L
.4857 .47528 L
.48649 .47664 L
.48724 .47793 L
.48794 .47914 L
.48861 .48029 L
.48924 .48138 L
.48983 .4824 L
.49039 .48337 L
.49092 .48429 L
.49142 .48515 L
.49189 .48597 L
.49234 .48674 L
.49276 .48747 L
.49316 .48816 L
.49354 .48882 L
.4939 .48943 L
.49423 .49001 L
.49455 .49057 L
.49485 .49109 L
.49513 .49158 L
.4954 .49204 L
.49566 .49248 L
.4959 .49289 L
.49612 .49329 L
.49634 .49366 L
.49654 .49401 L
.49673 .49434 L
.49691 .49465 L
.49708 .49494 L
.49724 .49522 L
.49739 .49548 L
.49754 .49573 L
.49767 .49597 L
.4978 .49619 L
.49792 .4964 L
.49804 .4966 L
.49814 .49679 L
.49825 .49696 L
.49834 .49713 L
.49843 .49729 L
.49852 .49744 L
.4986 .49758 L
.49868 .49771 L
.49875 .49784 L
Mistroke
.49882 .49796 L
.49889 .49807 L
.49895 .49818 L
.49901 .49828 L
.49906 .49837 L
.49911 .49846 L
.49916 .49855 L
.49921 .49863 L
.49925 .4987 L
.49929 .49877 L
.49933 .49884 L
.49937 .49891 L
.4994 .49897 L
.49944 .49902 L
.49947 .49908 L
.4995 .49913 L
.49952 .49918 L
.49955 .49922 L
.49958 .49926 L
.4996 .4993 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49945 L
.4997 .49948 L
.49971 .49951 L
.49973 .49953 L
.49974 .49956 L
.49976 .49958 L
.49977 .49961 L
.49978 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
Mistroke
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
Mfstroke
.924 0 1 r
.79603 1 m
.79259 .99442 L
.77619 .96766 L
.76072 .9423 L
.74614 .91828 L
.73239 .89554 L
.71942 .87401 L
.70719 .85363 L
.69565 .83434 L
.68476 .81609 L
.67449 .79882 L
.6648 .78248 L
.65565 .76703 L
.64701 .75241 L
.63885 .73858 L
.63116 .72551 L
.62389 .71314 L
.61703 .70145 L
.61055 .6904 L
.60443 .67994 L
.59865 .67006 L
.5932 .66072 L
.58804 .65189 L
.58318 .64354 L
.57858 .63565 L
.57424 .62819 L
.57014 .62114 L
.56626 .61447 L
.5626 .60818 L
.55915 .60222 L
.55588 .5966 L
.5528 .59128 L
.54988 .58626 L
.54713 .58151 L
.54453 .57702 L
.54207 .57278 L
.53975 .56877 L
.53756 .56498 L
.53549 .5614 L
.53353 .55802 L
.53168 .55483 L
.52993 .5518 L
.52828 .54895 L
.52672 .54625 L
.52525 .54371 L
.52386 .5413 L
.52254 .53902 L
.5213 .53687 L
.52012 .53484 L
.51901 .53292 L
Mistroke
.51797 .53111 L
.51697 .52939 L
.51604 .52777 L
.51515 .52624 L
.51432 .5248 L
.51353 .52343 L
.51278 .52214 L
.51208 .52092 L
.51141 .51976 L
.51078 .51868 L
.51019 .51765 L
.50963 .51667 L
.5091 .51575 L
.5086 .51489 L
.50812 .51407 L
.50767 .51329 L
.50725 .51256 L
.50685 .51187 L
.50647 .51121 L
.50612 .51059 L
.50578 .51001 L
.50546 .50946 L
.50516 .50894 L
.50488 .50844 L
.50461 .50798 L
.50435 .50754 L
.50411 .50712 L
.50389 .50673 L
.50367 .50636 L
.50347 .50601 L
.50328 .50568 L
.5031 .50537 L
.50293 .50507 L
.50277 .50479 L
.50261 .50453 L
.50247 .50428 L
.50233 .50404 L
.5022 .50382 L
.50208 .50361 L
.50197 .50341 L
.50186 .50322 L
.50176 .50304 L
.50166 .50288 L
.50157 .50272 L
.50148 .50257 L
.5014 .50243 L
.50132 .50229 L
.50125 .50217 L
.50118 .50205 L
.50112 .50193 L
Mistroke
.50105 .50183 L
.501 .50173 L
.50094 .50163 L
.50089 .50154 L
.50084 .50146 L
.50079 .50138 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50063 .5011 L
.5006 .50104 L
.50057 .50098 L
.50053 .50093 L
.5005 .50087 L
.50048 .50083 L
.50045 .50078 L
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50056 L
.5003 .50052 L
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .5004 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
Mfstroke
1 0 .499 r
.79525 1 m
.7831 .9801 L
.76726 .95404 L
.75233 .92936 L
.73825 .90599 L
.72496 .88388 L
.71243 .86294 L
.70061 .84313 L
.68945 .82439 L
.67893 .80666 L
.66899 .78988 L
.65961 .77401 L
.65076 .759 L
.6424 .74481 L
.63451 .73139 L
.62706 .7187 L
.62002 .70669 L
.61338 .69535 L
.60711 .68462 L
.60118 .67448 L
.59559 .66489 L
.5903 .65583 L
.58531 .64726 L
.5806 .63917 L
.57615 .63151 L
.57194 .62428 L
.56797 .61744 L
.56422 .61098 L
.56067 .60487 L
.55732 .5991 L
.55416 .59364 L
.55117 .58849 L
.54834 .58362 L
.54568 .57901 L
.54316 .57466 L
.54078 .57055 L
.53853 .56666 L
.5364 .56299 L
.53439 .55952 L
.5325 .55624 L
.5307 .55314 L
.52901 .55022 L
.52741 .54745 L
.5259 .54483 L
.52447 .54236 L
.52312 .54003 L
.52185 .53782 L
.52064 .53574 L
.5195 .53377 L
.51843 .53191 L
Mistroke
.51741 .53015 L
.51645 .52849 L
.51555 .52692 L
.51469 .52544 L
.51388 .52403 L
.51311 .52271 L
.51239 .52146 L
.51171 .52028 L
.51106 .51916 L
.51045 .5181 L
.50988 .5171 L
.50933 .51616 L
.50882 .51527 L
.50833 .51443 L
.50787 .51363 L
.50744 .51288 L
.50703 .51217 L
.50664 .5115 L
.50627 .51087 L
.50593 .51027 L
.5056 .5097 L
.50529 .50917 L
.505 .50866 L
.50473 .50818 L
.50447 .50773 L
.50422 .50731 L
.50399 .5069 L
.50377 .50652 L
.50356 .50616 L
.50336 .50582 L
.50318 .5055 L
.503 .5052 L
.50284 .50491 L
.50268 .50464 L
.50253 .50439 L
.50239 .50415 L
.50226 .50392 L
.50214 .5037 L
.50202 .5035 L
.50191 .5033 L
.5018 .50312 L
.5017 .50295 L
.50161 .50279 L
.50152 .50263 L
.50144 .50249 L
.50136 .50235 L
.50128 .50222 L
.50121 .5021 L
.50115 .50198 L
.50108 .50187 L
Mistroke
.50102 .50177 L
.50097 .50167 L
.50091 .50158 L
.50086 .50149 L
.50081 .50141 L
.50077 .50133 L
.50073 .50126 L
.50069 .50119 L
.50065 .50113 L
.50061 .50106 L
.50058 .501 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .5008 L
.50044 .50076 L
.50041 .50071 L
.50039 .50068 L
.50037 .50064 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .50041 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
Mfstroke
.823 1 0 r
0 .3503 m
.03508 .33392 L
.07517 .31802 L
.11112 .30635 L
.14342 .29821 L
.17248 .29304 L
.19869 .29032 L
.22236 .28964 L
.24379 .29064 L
.26321 .29299 L
.28086 .29644 L
.29692 .30076 L
.31157 .30577 L
.32494 .31129 L
.33719 .31721 L
.3484 .3234 L
.35871 .32976 L
.36818 .33623 L
.37691 .34272 L
.38496 .3492 L
.3924 .35561 L
.39928 .36193 L
.40565 .36811 L
.41157 .37415 L
.41706 .38001 L
.42217 .3857 L
.42692 .3912 L
.43135 .3965 L
.43548 .4016 L
.43934 .4065 L
.44295 .4112 L
.44632 .4157 L
.44947 .42001 L
.45243 .42412 L
.4552 .42805 L
.4578 .43179 L
.46023 .43536 L
.46252 .43876 L
.46467 .44199 L
.46669 .44506 L
.46859 .44798 L
.47037 .45076 L
.47205 .45339 L
.47363 .45589 L
.47512 .45826 L
.47652 .46051 L
.47785 .46264 L
.47909 .46466 L
.48026 .46657 L
.48137 .46838 L
Mistroke
.48241 .4701 L
.48339 .47173 L
.48432 .47327 L
.48519 .47472 L
.48602 .4761 L
.48679 .47741 L
.48753 .47864 L
.48822 .47981 L
.48888 .48091 L
.48949 .48196 L
.49008 .48295 L
.49063 .48388 L
.49115 .48477 L
.49164 .4856 L
.4921 .48639 L
.49254 .48714 L
.49295 .48784 L
.49334 .48851 L
.49371 .48914 L
.49406 .48974 L
.49438 .4903 L
.49469 .49084 L
.49499 .49134 L
.49526 .49182 L
.49553 .49227 L
.49577 .49269 L
.49601 .4931 L
.49623 .49348 L
.49643 .49383 L
.49663 .49417 L
.49682 .4945 L
.49699 .4948 L
.49716 .49508 L
.49732 .49536 L
.49746 .49561 L
.4976 .49585 L
.49774 .49608 L
.49786 .4963 L
.49798 .4965 L
.49809 .49669 L
.4982 .49688 L
.49829 .49705 L
.49839 .49721 L
.49848 .49736 L
.49856 .49751 L
.49864 .49765 L
.49872 .49778 L
.49879 .4979 L
.49885 .49802 L
.49892 .49812 L
Mistroke
.49898 .49823 L
.49903 .49833 L
.49909 .49842 L
.49914 .4985 L
.49918 .49859 L
.49923 .49867 L
.49927 .49874 L
.49931 .49881 L
.49935 .49887 L
.49939 .49894 L
.49942 .49899 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
.49956 .49924 L
.49959 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
Mistroke
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
1 0 .047 r
.2154 0 m
.21605 .00116 L
.23154 .02893 L
.2462 .05514 L
.26007 .07986 L
.27319 .1032 L
.2856 .12523 L
.29735 .14602 L
.30845 .16565 L
.31895 .18418 L
.32888 .20168 L
.33827 .2182 L
.34714 .23379 L
.35554 .24852 L
.36347 .26244 L
.37097 .27557 L
.37806 .28798 L
.38477 .2997 L
.3911 .31077 L
.39709 .32122 L
.40275 .3311 L
.4081 .34043 L
.41316 .34924 L
.41794 .35756 L
.42245 .36543 L
.42672 .37285 L
.43076 .37987 L
.43457 .3865 L
.43817 .39276 L
.44158 .39868 L
.44479 .40427 L
.44783 .40955 L
.45071 .41454 L
.45342 .41925 L
.45599 .42371 L
.45841 .42792 L
.4607 .43189 L
.46287 .43565 L
.46491 .4392 L
.46685 .44255 L
.46867 .44572 L
.4704 .44871 L
.47203 .45154 L
.47357 .45421 L
.47503 .45673 L
.47641 .45912 L
.47771 .46137 L
.47893 .4635 L
.4801 .46552 L
.48119 .46742 L
Mistroke
.48223 .46921 L
.48321 .47091 L
.48413 .47251 L
.48501 .47403 L
.48583 .47546 L
.48662 .47681 L
.48735 .47809 L
.48805 .4793 L
.48871 .48044 L
.48933 .48152 L
.48992 .48254 L
.49047 .4835 L
.491 .48441 L
.4915 .48527 L
.49196 .48608 L
.49241 .48685 L
.49283 .48757 L
.49322 .48826 L
.49359 .48891 L
.49395 .48952 L
.49428 .4901 L
.4946 .49064 L
.49489 .49116 L
.49518 .49164 L
.49544 .4921 L
.49569 .49254 L
.49593 .49295 L
.49615 .49334 L
.49637 .49371 L
.49657 .49405 L
.49676 .49438 L
.49694 .49469 L
.4971 .49498 L
.49726 .49526 L
.49741 .49552 L
.49756 .49577 L
.49769 .496 L
.49782 .49622 L
.49794 .49643 L
.49805 .49663 L
.49816 .49681 L
.49826 .49699 L
.49836 .49715 L
.49845 .49731 L
.49853 .49746 L
.49861 .4976 L
.49869 .49773 L
.49876 .49786 L
.49883 .49798 L
.4989 .49809 L
Mistroke
.49896 .49819 L
.49901 .49829 L
.49907 .49839 L
.49912 .49848 L
.49917 .49856 L
.49921 .49864 L
.49926 .49871 L
.4993 .49878 L
.49934 .49885 L
.49937 .49891 L
.49941 .49897 L
.49944 .49903 L
.49947 .49908 L
.4995 .49914 L
.49953 .49918 L
.49955 .49923 L
.49958 .49927 L
.4996 .49931 L
.49962 .49935 L
.49964 .49938 L
.49966 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
Mistroke
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
Mfstroke
0 .347 1 r
.7931 1 m
.78813 .99172 L
.77208 .96491 L
.75694 .93953 L
.74265 .91552 L
.72917 .8928 L
.71645 .87131 L
.70443 .85099 L
.69309 .83176 L
.68239 .81358 L
.67228 .79638 L
.66274 .78013 L
.65373 .76475 L
.64522 .75022 L
.63719 .73648 L
.6296 .72349 L
.62243 .71121 L
.61567 .6996 L
.60927 .68863 L
.60324 .67825 L
.59753 .66845 L
.59215 .65918 L
.58706 .65043 L
.58225 .64215 L
.57771 .63433 L
.57342 .62693 L
.56937 .61994 L
.56554 .61334 L
.56192 .6071 L
.55851 .6012 L
.55528 .59563 L
.55223 .59036 L
.54935 .58539 L
.54663 .58068 L
.54405 .57624 L
.54162 .57204 L
.53933 .56807 L
.53716 .56432 L
.53511 .56078 L
.53317 .55743 L
.53134 .55426 L
.52962 .55127 L
.52798 .54845 L
.52644 .54578 L
.52498 .54326 L
.52361 .54087 L
.5223 .53862 L
.52107 .53649 L
.51991 .53448 L
.51881 .53258 L
Mistroke
.51778 .53078 L
.5168 .52909 L
.51587 .52748 L
.515 .52597 L
.51417 .52454 L
.51339 .52319 L
.51265 .52191 L
.51195 .5207 L
.51129 .51956 L
.51067 .51848 L
.51008 .51746 L
.50953 .5165 L
.509 .51559 L
.50851 .51473 L
.50804 .51392 L
.50759 .51315 L
.50718 .51243 L
.50678 .51174 L
.50641 .5111 L
.50605 .51048 L
.50572 .50991 L
.5054 .50936 L
.50511 .50884 L
.50482 .50836 L
.50456 .5079 L
.50431 .50746 L
.50407 .50705 L
.50385 .50666 L
.50363 .50629 L
.50343 .50595 L
.50324 .50562 L
.50307 .50531 L
.5029 .50502 L
.50274 .50474 L
.50259 .50448 L
.50244 .50423 L
.50231 .504 L
.50218 .50378 L
.50206 .50357 L
.50195 .50337 L
.50184 .50319 L
.50174 .50301 L
.50164 .50285 L
.50155 .50269 L
.50147 .50254 L
.50139 .5024 L
.50131 .50227 L
.50124 .50214 L
.50117 .50203 L
.5011 .50191 L
Mistroke
.50104 .50181 L
.50099 .50171 L
.50093 .50161 L
.50088 .50153 L
.50083 .50144 L
.50079 .50136 L
.50074 .50129 L
.5007 .50122 L
.50066 .50115 L
.50063 .50109 L
.50059 .50103 L
.50056 .50097 L
.50053 .50092 L
.5005 .50087 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50036 .50062 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
Mfstroke
.501 1 0 r
0 .15386 m
.01786 .15254 L
.05547 .15258 L
.08953 .15517 L
.12044 .15983 L
.14854 .16614 L
.17413 .17377 L
.19749 .18242 L
.21883 .19184 L
.23838 .20181 L
.2563 .21218 L
.27277 .22278 L
.28793 .2335 L
.3019 .24424 L
.3148 .25491 L
.32672 .26546 L
.33776 .27581 L
.34798 .28594 L
.35748 .29581 L
.3663 .3054 L
.37451 .31467 L
.38215 .32363 L
.38927 .33227 L
.39592 .34057 L
.40213 .34854 L
.40793 .35618 L
.41336 .3635 L
.41844 .37049 L
.42321 .37717 L
.42767 .38354 L
.43186 .38961 L
.43578 .3954 L
.43947 .4009 L
.44294 .40614 L
.4462 .41112 L
.44926 .41585 L
.45214 .42034 L
.45485 .42461 L
.45741 .42865 L
.45981 .43249 L
.46207 .43613 L
.4642 .43958 L
.46621 .44285 L
.46811 .44594 L
.46989 .44888 L
.47157 .45165 L
.47316 .45428 L
.47466 .45677 L
.47607 .45913 L
.4774 .46136 L
Mistroke
.47866 .46347 L
.47984 .46547 L
.48096 .46736 L
.48202 .46914 L
.48302 .47083 L
.48396 .47243 L
.48485 .47394 L
.48569 .47537 L
.48648 .47672 L
.48723 .478 L
.48794 .47921 L
.4886 .48035 L
.48923 .48143 L
.48983 .48245 L
.49039 .48341 L
.49092 .48433 L
.49142 .48519 L
.4919 .486 L
.49234 .48677 L
.49277 .4875 L
.49317 .48819 L
.49354 .48884 L
.4939 .48945 L
.49424 .49003 L
.49455 .49058 L
.49486 .4911 L
.49514 .49159 L
.49541 .49205 L
.49566 .49249 L
.4959 .49291 L
.49613 .4933 L
.49634 .49367 L
.49654 .49401 L
.49673 .49434 L
.49691 .49466 L
.49708 .49495 L
.49724 .49523 L
.4974 .49549 L
.49754 .49574 L
.49768 .49597 L
.4978 .4962 L
.49792 .49641 L
.49804 .4966 L
.49815 .49679 L
.49825 .49697 L
.49835 .49714 L
.49844 .49729 L
.49852 .49744 L
.4986 .49758 L
.49868 .49772 L
Mistroke
.49875 .49784 L
.49882 .49796 L
.49889 .49807 L
.49895 .49818 L
.49901 .49828 L
.49906 .49837 L
.49911 .49846 L
.49916 .49855 L
.49921 .49863 L
.49925 .4987 L
.49929 .49878 L
.49933 .49884 L
.49937 .49891 L
.4994 .49897 L
.49944 .49902 L
.49947 .49908 L
.4995 .49913 L
.49952 .49918 L
.49955 .49922 L
.49958 .49927 L
.4996 .49931 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49945 L
.4997 .49948 L
.49971 .49951 L
.49973 .49953 L
.49975 .49956 L
.49976 .49958 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
Mistroke
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
1 0 .179 r
0 .49024 m
.01864 .47643 L
.0635 .44597 L
.10345 .42144 L
.13907 .40193 L
.17089 .38668 L
.19937 .37502 L
.22489 .3664 L
.24782 .36033 L
.26844 .35638 L
.28703 .35421 L
.30382 .3535 L
.31901 .354 L
.33277 .35548 L
.34527 .35776 L
.35665 .36067 L
.36702 .36408 L
.37648 .36787 L
.38514 .37195 L
.39308 .37623 L
.40036 .38065 L
.40706 .38514 L
.41322 .38966 L
.41891 .39418 L
.42417 .39865 L
.42902 .40306 L
.43352 .40739 L
.4377 .41161 L
.44157 .41572 L
.44518 .4197 L
.44853 .42355 L
.45166 .42727 L
.45457 .43085 L
.45729 .43428 L
.45983 .43758 L
.46221 .44074 L
.46443 .44377 L
.46651 .44666 L
.46846 .44941 L
.47029 .45204 L
.47201 .45455 L
.47362 .45694 L
.47513 .45921 L
.47656 .46137 L
.47789 .46342 L
.47915 .46537 L
.48033 .46722 L
.48145 .46898 L
.48249 .47064 L
.48348 .47222 L
Mistroke
.48441 .47372 L
.48529 .47514 L
.48611 .47649 L
.48689 .47776 L
.48762 .47897 L
.48831 .48011 L
.48897 .48119 L
.48958 .48222 L
.49016 .48319 L
.49071 .48411 L
.49123 .48498 L
.49171 .4858 L
.49217 .48657 L
.49261 .48731 L
.49302 .488 L
.4934 .48866 L
.49377 .48928 L
.49412 .48987 L
.49444 .49043 L
.49475 .49095 L
.49504 .49145 L
.49531 .49192 L
.49557 .49236 L
.49582 .49278 L
.49605 .49318 L
.49627 .49355 L
.49647 .49391 L
.49667 .49424 L
.49685 .49456 L
.49703 .49486 L
.49719 .49514 L
.49735 .49541 L
.49749 .49566 L
.49763 .4959 L
.49776 .49613 L
.49788 .49634 L
.498 .49654 L
.49811 .49673 L
.49822 .49691 L
.49831 .49708 L
.49841 .49724 L
.49849 .4974 L
.49858 .49754 L
.49866 .49767 L
.49873 .4978 L
.4988 .49792 L
.49887 .49804 L
.49893 .49815 L
.49899 .49825 L
.49904 .49834 L
Mistroke
.4991 .49844 L
.49915 .49852 L
.49919 .4986 L
.49924 .49868 L
.49928 .49875 L
.49932 .49882 L
.49936 .49889 L
.49939 .49895 L
.49943 .49901 L
.49946 .49906 L
.49949 .49911 L
.49952 .49916 L
.49954 .49921 L
.49957 .49925 L
.49959 .49929 L
.49961 .49933 L
.49964 .49937 L
.49966 .4994 L
.49967 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49952 L
.49974 .49955 L
.49975 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49971 L
.49984 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49978 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
Mistroke
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
Mfstroke
0 .501 1 r
.20753 0 m
.20764 .00019 L
.22391 .02748 L
.23925 .0533 L
.25374 .07773 L
.26741 .10084 L
.28031 .1227 L
.29249 .14337 L
.304 .16292 L
.31485 .1814 L
.32511 .19888 L
.33479 .21541 L
.34393 .23104 L
.35256 .24581 L
.36072 .25977 L
.36842 .27298 L
.37569 .28546 L
.38256 .29725 L
.38905 .3084 L
.39518 .31894 L
.40097 .3289 L
.40644 .33831 L
.4116 .34721 L
.41648 .35562 L
.42109 .36357 L
.42545 .37108 L
.42956 .37818 L
.43345 .38489 L
.43712 .39122 L
.44059 .39721 L
.44387 .40288 L
.44696 .40823 L
.44989 .41328 L
.45265 .41806 L
.45526 .42257 L
.45773 .42684 L
.46006 .43087 L
.46226 .43468 L
.46435 .43828 L
.46631 .44168 L
.46817 .44489 L
.46992 .44793 L
.47158 .4508 L
.47315 .45351 L
.47463 .45607 L
.47603 .45849 L
.47735 .46078 L
.4786 .46294 L
.47978 .46498 L
.48089 .46691 L
Mistroke
.48195 .46874 L
.48294 .47046 L
.48388 .47209 L
.48477 .47363 L
.48561 .47508 L
.4864 .47645 L
.48715 .47775 L
.48786 .47898 L
.48853 .48014 L
.48916 .48123 L
.48976 .48227 L
.49032 .48324 L
.49086 .48417 L
.49136 .48504 L
.49184 .48586 L
.49229 .48664 L
.49271 .48738 L
.49311 .48807 L
.49349 .48873 L
.49385 .48935 L
.49419 .48994 L
.49451 .49049 L
.49481 .49102 L
.4951 .49151 L
.49537 .49198 L
.49563 .49242 L
.49587 .49284 L
.49609 .49324 L
.49631 .49361 L
.49651 .49396 L
.49671 .49429 L
.49689 .49461 L
.49706 .49491 L
.49722 .49519 L
.49737 .49545 L
.49752 .4957 L
.49766 .49594 L
.49778 .49616 L
.49791 .49637 L
.49802 .49657 L
.49813 .49676 L
.49823 .49694 L
.49833 .49711 L
.49842 .49727 L
.49851 .49742 L
.49859 .49756 L
.49867 .4977 L
.49874 .49782 L
.49881 .49794 L
.49888 .49806 L
Mistroke
.49894 .49816 L
.499 .49827 L
.49905 .49836 L
.49911 .49845 L
.49916 .49854 L
.4992 .49862 L
.49925 .49869 L
.49929 .49877 L
.49933 .49883 L
.49936 .4989 L
.4994 .49896 L
.49943 .49902 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49922 L
.49957 .49926 L
.4996 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.4997 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49956 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.4998 .49965 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
Mistroke
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
Mfstroke
.359 1 0 r
.32836 0 m
.33023 .01508 L
.33526 .04929 L
.3406 .08061 L
.34615 .10935 L
.35182 .13575 L
.35755 .16004 L
.36329 .18243 L
.369 .20311 L
.37464 .22221 L
.38018 .2399 L
.38559 .2563 L
.39087 .27152 L
.39599 .28566 L
.40095 .29881 L
.40574 .31106 L
.41035 .32248 L
.41479 .33314 L
.41905 .34309 L
.42314 .3524 L
.42705 .3611 L
.43078 .36925 L
.43435 .37688 L
.43776 .38404 L
.441 .39075 L
.4441 .39705 L
.44704 .40296 L
.44984 .40852 L
.4525 .41374 L
.45503 .41865 L
.45743 .42327 L
.45971 .42762 L
.46187 .43171 L
.46392 .43556 L
.46587 .43919 L
.46771 .44261 L
.46946 .44583 L
.47111 .44886 L
.47268 .45173 L
.47416 .45442 L
.47557 .45697 L
.4769 .45937 L
.47816 .46163 L
.47935 .46377 L
.48048 .46578 L
.48154 .46769 L
.48255 .46948 L
.48351 .47117 L
.48441 .47277 L
.48527 .47428 L
Mistroke
.48607 .47571 L
.48684 .47705 L
.48756 .47833 L
.48824 .47952 L
.48889 .48066 L
.4895 .48173 L
.49008 .48274 L
.49062 .48369 L
.49114 .48459 L
.49162 .48545 L
.49208 .48625 L
.49252 .48701 L
.49293 .48773 L
.49332 .4884 L
.49369 .48904 L
.49404 .48965 L
.49436 .49022 L
.49467 .49076 L
.49497 .49127 L
.49524 .49175 L
.49551 .49221 L
.49575 .49264 L
.49599 .49304 L
.49621 .49343 L
.49642 .49379 L
.49661 .49413 L
.4968 .49446 L
.49698 .49476 L
.49714 .49505 L
.4973 .49532 L
.49745 .49558 L
.49759 .49582 L
.49772 .49605 L
.49785 .49627 L
.49797 .49648 L
.49808 .49667 L
.49819 .49686 L
.49829 .49703 L
.49838 .49719 L
.49847 .49735 L
.49855 .49749 L
.49863 .49763 L
.49871 .49776 L
.49878 .49789 L
.49885 .498 L
.49891 .49811 L
.49897 .49822 L
.49903 .49831 L
.49908 .49841 L
.49913 .4985 L
Mistroke
.49918 .49858 L
.49922 .49866 L
.49927 .49873 L
.49931 .4988 L
.49935 .49887 L
.49938 .49893 L
.49942 .49899 L
.49945 .49904 L
.49948 .4991 L
.49951 .49915 L
.49953 .49919 L
.49956 .49924 L
.49958 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .49939 L
.49967 .49943 L
.49969 .49946 L
.4997 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49976 .49959 L
.49978 .49961 L
.49979 .49964 L
.4998 .49966 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49982 L
.4999 .49983 L
.4999 .49984 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
Mistroke
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
.222 0 1 r
1 .77397 m
.97057 .78041 L
.93254 .7859 L
.89821 .7883 L
.86718 .78814 L
.83907 .78589 L
.81356 .78195 L
.79037 .77664 L
.76924 .77026 L
.74996 .76305 L
.73234 .75521 L
.7162 .74691 L
.7014 .7383 L
.6878 .7295 L
.67528 .7206 L
.66374 .71169 L
.65308 .70284 L
.64324 .6941 L
.63412 .68552 L
.62567 .67713 L
.61782 .66895 L
.61053 .66102 L
.60375 .65333 L
.59744 .64592 L
.59155 .63877 L
.58605 .63189 L
.58092 .6253 L
.57613 .61897 L
.57164 .61292 L
.56744 .60713 L
.5635 .60161 L
.55981 .59633 L
.55635 .59131 L
.5531 .58652 L
.55005 .58197 L
.54719 .57763 L
.54449 .57352 L
.54196 .5696 L
.53958 .56589 L
.53734 .56236 L
.53522 .55901 L
.53324 .55584 L
.53137 .55283 L
.5296 .54997 L
.52794 .54727 L
.52638 .54471 L
.5249 .54228 L
.52351 .53999 L
.5222 .53781 L
.52096 .53575 L
Mistroke
.51979 .5338 L
.51869 .53196 L
.51765 .53021 L
.51667 .52856 L
.51574 .527 L
.51487 .52552 L
.51404 .52412 L
.51327 .5228 L
.51253 .52155 L
.51184 .52037 L
.51118 .51925 L
.51056 .5182 L
.50998 .5172 L
.50943 .51625 L
.5089 .51536 L
.50841 .51451 L
.50795 .51372 L
.50751 .51296 L
.50709 .51225 L
.5067 .51158 L
.50633 .51094 L
.50598 .51034 L
.50565 .50977 L
.50534 .50923 L
.50504 .50872 L
.50477 .50824 L
.5045 .50779 L
.50425 .50736 L
.50402 .50695 L
.5038 .50657 L
.50359 .50621 L
.50339 .50587 L
.5032 .50554 L
.50303 .50524 L
.50286 .50495 L
.5027 .50468 L
.50255 .50442 L
.50241 .50418 L
.50228 .50395 L
.50215 .50373 L
.50204 .50352 L
.50192 .50333 L
.50182 .50315 L
.50172 .50297 L
.50162 .50281 L
.50153 .50265 L
.50145 .50251 L
.50137 .50237 L
.50129 .50224 L
.50122 .50212 L
Mistroke
.50115 .502 L
.50109 .50189 L
.50103 .50178 L
.50097 .50169 L
.50092 .50159 L
.50087 .50151 L
.50082 .50142 L
.50078 .50134 L
.50073 .50127 L
.50069 .5012 L
.50065 .50113 L
.50062 .50107 L
.50058 .50101 L
.50055 .50096 L
.50052 .5009 L
.50049 .50085 L
.50047 .50081 L
.50044 .50076 L
.50042 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .50061 L
.50033 .50057 L
.50031 .50054 L
.5003 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50039 L
.50021 .50036 L
.5002 .50034 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50025 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50018 L
.5001 .50017 L
.5001 .50016 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
Mistroke
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
Mfstroke
.431 1 0 r
.83514 1 m
.82358 .98629 L
.80407 .96239 L
.78585 .93942 L
.76884 .91738 L
.75293 .89627 L
.73804 .87606 L
.7241 .85675 L
.71103 .83832 L
.69879 .82074 L
.6873 .80398 L
.67651 .78803 L
.66638 .77284 L
.65686 .75841 L
.64791 .74468 L
.6395 .73165 L
.63159 .71927 L
.62414 .70752 L
.61712 .69638 L
.61052 .68581 L
.6043 .67578 L
.59844 .66629 L
.59292 .65729 L
.58772 .64876 L
.58281 .64068 L
.57818 .63304 L
.57382 .6258 L
.5697 .61894 L
.56582 .61246 L
.56216 .60632 L
.5587 .60051 L
.55544 .59502 L
.55236 .58982 L
.54945 .5849 L
.54671 .58025 L
.54412 .57585 L
.54168 .57169 L
.53937 .56776 L
.53719 .56404 L
.53513 .56053 L
.53319 .5572 L
.53135 .55406 L
.52962 .55109 L
.52798 .54828 L
.52643 .54563 L
.52497 .54312 L
.52359 .54075 L
.52229 .53851 L
.52106 .53639 L
.5199 .53439 L
Mistroke
.5188 .53249 L
.51776 .53071 L
.51678 .52901 L
.51585 .52742 L
.51498 .52591 L
.51415 .52448 L
.51337 .52313 L
.51263 .52186 L
.51194 .52066 L
.51128 .51952 L
.51066 .51844 L
.51007 .51743 L
.50951 .51647 L
.50899 .51556 L
.50849 .5147 L
.50802 .51389 L
.50758 .51313 L
.50716 .5124 L
.50677 .51172 L
.5064 .51107 L
.50604 .51046 L
.50571 .50989 L
.5054 .50934 L
.5051 .50883 L
.50482 .50834 L
.50455 .50788 L
.5043 .50745 L
.50406 .50704 L
.50384 .50665 L
.50363 .50628 L
.50343 .50594 L
.50324 .50561 L
.50306 .5053 L
.50289 .50501 L
.50273 .50473 L
.50258 .50447 L
.50244 .50422 L
.5023 .50399 L
.50218 .50377 L
.50206 .50356 L
.50194 .50337 L
.50184 .50318 L
.50174 .50301 L
.50164 .50284 L
.50155 .50268 L
.50146 .50254 L
.50138 .5024 L
.50131 .50226 L
.50124 .50214 L
.50117 .50202 L
Mistroke
.5011 .50191 L
.50104 .5018 L
.50098 .50171 L
.50093 .50161 L
.50088 .50152 L
.50083 .50144 L
.50078 .50136 L
.50074 .50128 L
.5007 .50121 L
.50066 .50115 L
.50063 .50108 L
.50059 .50102 L
.50056 .50097 L
.50053 .50091 L
.5005 .50086 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50035 .50061 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
Mistroke
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
Mfstroke
.337 1 0 r
1 .24672 m
.97958 .26961 L
.92914 .32389 L
.88468 .36963 L
.84545 .40804 L
.81079 .44016 L
.78012 .46691 L
.75295 .48904 L
.72885 .50725 L
.70743 .5221 L
.68837 .5341 L
.67137 .54367 L
.6562 .55118 L
.64262 .55696 L
.63046 .56127 L
.61954 .56435 L
.60972 .56639 L
.60088 .56758 L
.59289 .56805 L
.58567 .56794 L
.57913 .56735 L
.57319 .56637 L
.56779 .56508 L
.56287 .56354 L
.55838 .56182 L
.55427 .55995 L
.55051 .55798 L
.54706 .55594 L
.54388 .55386 L
.54096 .55176 L
.53827 .54966 L
.53579 .54757 L
.53349 .54551 L
.53136 .54349 L
.52939 .54152 L
.52755 .5396 L
.52585 .53774 L
.52427 .53593 L
.52279 .53419 L
.52141 .53251 L
.52013 .5309 L
.51893 .52935 L
.51781 .52787 L
.51676 .52645 L
.51578 .52509 L
.51486 .5238 L
.514 .52256 L
.51319 .52138 L
.51243 .52026 L
.51171 .51919 L
Mistroke
.51104 .51818 L
.51041 .51721 L
.50982 .5163 L
.50926 .51543 L
.50874 .5146 L
.50824 .51382 L
.50778 .51307 L
.50734 .51237 L
.50693 .5117 L
.50654 .51107 L
.50617 .51047 L
.50583 .5099 L
.5055 .50936 L
.5052 .50885 L
.50491 .50837 L
.50463 .50791 L
.50437 .50748 L
.50413 .50707 L
.5039 .50669 L
.50369 .50632 L
.50348 .50597 L
.50329 .50565 L
.50311 .50534 L
.50293 .50505 L
.50277 .50477 L
.50262 .50451 L
.50247 .50426 L
.50234 .50403 L
.50221 .5038 L
.50208 .5036 L
.50197 .5034 L
.50186 .50321 L
.50176 .50303 L
.50166 .50287 L
.50157 .50271 L
.50148 .50256 L
.5014 .50242 L
.50132 .50229 L
.50125 .50216 L
.50118 .50204 L
.50112 .50193 L
.50105 .50182 L
.501 .50172 L
.50094 .50163 L
.50089 .50154 L
.50084 .50145 L
.50079 .50137 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
Mistroke
.50063 .50109 L
.5006 .50103 L
.50056 .50098 L
.50053 .50092 L
.5005 .50087 L
.50048 .50082 L
.50045 .50078 L
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50055 L
.5003 .50052 L
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .50039 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
Mistroke
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
Mfstroke
0 1 .314 r
.20691 0 m
.21008 .00528 L
.22622 .03226 L
.24146 .05779 L
.25584 .08194 L
.26941 .1048 L
.28221 .12642 L
.2943 .14687 L
.30571 .16621 L
.31648 .1845 L
.32665 .2018 L
.33625 .21815 L
.34532 .23362 L
.35388 .24824 L
.36196 .26207 L
.3696 .27514 L
.37681 .28749 L
.38362 .29917 L
.39005 .31021 L
.39613 .32065 L
.40186 .33051 L
.40729 .33984 L
.41241 .34865 L
.41724 .35698 L
.42181 .36485 L
.42613 .37229 L
.4302 .37932 L
.43406 .38596 L
.4377 .39224 L
.44113 .39817 L
.44438 .40378 L
.44745 .40908 L
.45035 .41409 L
.45309 .41882 L
.45567 .42329 L
.45812 .42752 L
.46043 .43151 L
.46261 .43528 L
.46467 .43885 L
.46662 .44222 L
.46846 .4454 L
.4702 .44841 L
.47184 .45125 L
.4734 .45394 L
.47486 .45648 L
.47625 .45888 L
.47756 .46114 L
.4788 .46328 L
.47997 .46531 L
.48107 .46722 L
Mistroke
.48211 .46903 L
.4831 .47073 L
.48403 .47235 L
.48491 .47387 L
.48574 .47531 L
.48653 .47667 L
.48727 .47796 L
.48797 .47917 L
.48864 .48032 L
.48926 .4814 L
.48985 .48243 L
.49041 .4834 L
.49094 .48431 L
.49144 .48518 L
.49191 .48599 L
.49236 .48677 L
.49278 .4875 L
.49318 .48819 L
.49355 .48884 L
.49391 .48945 L
.49425 .49003 L
.49456 .49058 L
.49486 .4911 L
.49515 .49159 L
.49541 .49206 L
.49567 .49249 L
.4959 .49291 L
.49613 .4933 L
.49634 .49367 L
.49655 .49402 L
.49674 .49435 L
.49692 .49466 L
.49709 .49495 L
.49725 .49523 L
.4974 .49549 L
.49754 .49574 L
.49768 .49598 L
.49781 .4962 L
.49793 .49641 L
.49804 .49661 L
.49815 .49679 L
.49825 .49697 L
.49835 .49714 L
.49844 .49729 L
.49852 .49744 L
.49861 .49758 L
.49868 .49772 L
.49876 .49784 L
.49882 .49796 L
.49889 .49807 L
Mistroke
.49895 .49818 L
.49901 .49828 L
.49906 .49838 L
.49911 .49847 L
.49916 .49855 L
.49921 .49863 L
.49925 .49871 L
.49929 .49878 L
.49933 .49884 L
.49937 .49891 L
.4994 .49897 L
.49944 .49903 L
.49947 .49908 L
.4995 .49913 L
.49953 .49918 L
.49955 .49922 L
.49958 .49927 L
.4996 .49931 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49945 L
.4997 .49948 L
.49971 .49951 L
.49973 .49953 L
.49975 .49956 L
.49976 .49958 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
Mistroke
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
Mfstroke
.614 1 0 r
.27737 0 m
.2826 .01778 L
.2922 .04851 L
.30158 .07698 L
.31072 .10341 L
.3196 .12796 L
.32819 .15081 L
.3365 .17208 L
.3445 .19191 L
.35219 .21041 L
.35958 .22769 L
.36666 .24384 L
.37344 .25894 L
.37992 .27309 L
.38611 .28634 L
.39202 .29876 L
.39765 .31041 L
.40301 .32134 L
.40812 .33161 L
.41297 .34125 L
.41759 .35032 L
.42197 .35884 L
.42614 .36686 L
.43009 .3744 L
.43384 .3815 L
.4374 .38818 L
.44078 .39448 L
.44397 .40041 L
.447 .406 L
.44988 .41127 L
.45259 .41624 L
.45517 .42092 L
.45761 .42533 L
.45992 .4295 L
.4621 .43343 L
.46417 .43713 L
.46613 .44063 L
.46798 .44393 L
.46973 .44704 L
.47139 .44998 L
.47295 .45276 L
.47444 .45538 L
.47584 .45785 L
.47716 .46019 L
.47841 .46239 L
.4796 .46447 L
.48072 .46644 L
.48178 .46829 L
.48278 .47005 L
.48373 .4717 L
Mistroke
.48462 .47327 L
.48547 .47475 L
.48627 .47614 L
.48702 .47746 L
.48774 .4787 L
.48841 .47988 L
.48905 .48099 L
.48965 .48204 L
.49022 .48303 L
.49076 .48397 L
.49127 .48485 L
.49175 .48569 L
.4922 .48648 L
.49263 .48722 L
.49304 .48793 L
.49342 .48859 L
.49378 .48922 L
.49413 .48982 L
.49445 .49038 L
.49476 .49091 L
.49504 .49141 L
.49532 .49189 L
.49558 .49233 L
.49582 .49276 L
.49605 .49315 L
.49627 .49353 L
.49647 .49389 L
.49667 .49423 L
.49685 .49454 L
.49702 .49484 L
.49719 .49513 L
.49734 .4954 L
.49749 .49565 L
.49763 .49589 L
.49776 .49612 L
.49788 .49633 L
.498 .49653 L
.49811 .49672 L
.49821 .49691 L
.49831 .49708 L
.49841 .49724 L
.49849 .49739 L
.49858 .49753 L
.49865 .49767 L
.49873 .4978 L
.4988 .49792 L
.49887 .49803 L
.49893 .49814 L
.49899 .49824 L
.49904 .49834 L
Mistroke
.4991 .49843 L
.49915 .49852 L
.49919 .4986 L
.49924 .49868 L
.49928 .49875 L
.49932 .49882 L
.49936 .49888 L
.49939 .49895 L
.49943 .499 L
.49946 .49906 L
.49949 .49911 L
.49952 .49916 L
.49954 .49921 L
.49957 .49925 L
.49959 .49929 L
.49961 .49933 L
.49963 .49937 L
.49965 .4994 L
.49967 .49944 L
.49969 .49947 L
.49971 .4995 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49982 .49968 L
.49983 .4997 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49988 .49978 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
Mistroke
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mfstroke
.656 0 1 r
.77825 1 m
.76782 .98021 L
.75343 .9531 L
.73978 .92757 L
.72684 .90352 L
.71457 .88086 L
.70295 .85951 L
.69195 .83938 L
.68152 .8204 L
.67165 .8025 L
.66231 .78563 L
.65346 .7697 L
.64509 .75469 L
.63717 .74051 L
.62968 .72714 L
.62259 .71452 L
.61588 .70261 L
.60953 .69137 L
.60353 .68076 L
.59786 .67074 L
.59249 .66128 L
.58742 .65234 L
.58262 .64391 L
.57809 .63595 L
.5738 .62843 L
.56974 .62132 L
.56591 .61462 L
.56229 .60828 L
.55886 .6023 L
.55563 .59664 L
.55257 .59131 L
.54968 .58626 L
.54694 .5815 L
.54436 .577 L
.54192 .57275 L
.53961 .56873 L
.53743 .56494 L
.53537 .56136 L
.53342 .55797 L
.53158 .55477 L
.52984 .55175 L
.5282 .54889 L
.52665 .5462 L
.52518 .54365 L
.52379 .54124 L
.52248 .53897 L
.52124 .53682 L
.52007 .53479 L
.51897 .53287 L
.51792 .53106 L
Mistroke
.51693 .52934 L
.516 .52773 L
.51512 .5262 L
.51429 .52475 L
.5135 .52339 L
.51275 .5221 L
.51205 .52088 L
.51139 .51973 L
.51076 .51864 L
.51017 .51761 L
.50961 .51664 L
.50908 .51572 L
.50858 .51486 L
.5081 .51404 L
.50766 .51326 L
.50724 .51253 L
.50684 .51184 L
.50646 .51119 L
.5061 .51057 L
.50577 .50999 L
.50545 .50944 L
.50515 .50892 L
.50487 .50843 L
.5046 .50796 L
.50434 .50752 L
.5041 .50711 L
.50388 .50672 L
.50366 .50635 L
.50346 .506 L
.50327 .50567 L
.50309 .50535 L
.50292 .50506 L
.50276 .50478 L
.50261 .50452 L
.50246 .50427 L
.50233 .50403 L
.5022 .50381 L
.50208 .5036 L
.50196 .5034 L
.50186 .50321 L
.50175 .50304 L
.50166 .50287 L
.50157 .50271 L
.50148 .50256 L
.5014 .50242 L
.50132 .50229 L
.50125 .50216 L
.50118 .50204 L
.50111 .50193 L
.50105 .50182 L
Mistroke
.50099 .50172 L
.50094 .50163 L
.50089 .50154 L
.50084 .50145 L
.50079 .50137 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50063 .50109 L
.5006 .50103 L
.50056 .50098 L
.50053 .50092 L
.5005 .50087 L
.50048 .50082 L
.50045 .50078 L
.50042 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50055 L
.5003 .50052 L
.50029 .50049 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .50039 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
Mistroke
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
Mfstroke
.534 1 0 r
.79845 1 m
.79844 .99998 L
.78161 .97309 L
.76575 .94758 L
.75082 .92341 L
.73674 .9005 L
.72348 .8788 L
.71097 .85825 L
.69918 .83878 L
.68806 .82035 L
.67757 .8029 L
.66768 .78639 L
.65835 .77076 L
.64954 .75597 L
.64123 .74198 L
.63338 .72875 L
.62598 .71623 L
.61899 .70439 L
.61239 .69319 L
.60616 .6826 L
.60028 .67258 L
.59473 .66311 L
.58949 .65416 L
.58453 .64569 L
.57986 .63769 L
.57544 .63013 L
.57127 .62298 L
.56733 .61622 L
.56361 .60983 L
.5601 .60379 L
.55678 .59808 L
.55364 .59268 L
.55068 .58758 L
.54788 .58276 L
.54524 .57821 L
.54274 .5739 L
.54038 .56983 L
.53815 .56599 L
.53605 .56235 L
.53406 .55892 L
.53218 .55568 L
.53041 .55261 L
.52873 .54971 L
.52714 .54697 L
.52565 .54439 L
.52423 .54194 L
.5229 .53963 L
.52163 .53745 L
.52044 .53538 L
.51931 .53343 L
Mistroke
.51825 .53159 L
.51724 .52985 L
.51629 .52821 L
.51539 .52665 L
.51454 .52518 L
.51374 .5238 L
.51298 .52248 L
.51227 .52124 L
.51159 .52007 L
.51095 .51897 L
.51035 .51792 L
.50978 .51693 L
.50924 .516 L
.50873 .51512 L
.50825 .51429 L
.50779 .5135 L
.50736 .51275 L
.50696 .51205 L
.50658 .51139 L
.50621 .51076 L
.50587 .51017 L
.50555 .50961 L
.50524 .50908 L
.50495 .50858 L
.50468 .5081 L
.50442 .50766 L
.50418 .50724 L
.50395 .50684 L
.50373 .50646 L
.50352 .5061 L
.50333 .50577 L
.50315 .50545 L
.50297 .50515 L
.50281 .50486 L
.50265 .5046 L
.50251 .50434 L
.50237 .5041 L
.50224 .50388 L
.50212 .50366 L
.502 .50346 L
.50189 .50327 L
.50178 .50309 L
.50169 .50292 L
.50159 .50276 L
.50151 .50261 L
.50142 .50246 L
.50134 .50233 L
.50127 .5022 L
.5012 .50208 L
.50113 .50196 L
Mistroke
.50107 .50186 L
.50101 .50175 L
.50096 .50166 L
.5009 .50157 L
.50085 .50148 L
.50081 .5014 L
.50076 .50132 L
.50072 .50125 L
.50068 .50118 L
.50064 .50111 L
.50061 .50105 L
.50057 .50099 L
.50054 .50094 L
.50051 .50089 L
.50048 .50084 L
.50046 .50079 L
.50043 .50075 L
.50041 .50071 L
.50039 .50067 L
.50036 .50063 L
.50034 .5006 L
.50033 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50048 L
.50026 .50045 L
.50025 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50012 .50022 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50012 L
Mistroke
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
Mfstroke
1 0 .258 r
.25281 0 m
.26075 .02031 L
.27246 .04931 L
.28372 .07637 L
.29453 .10164 L
.3049 .12527 L
.31482 .14737 L
.3243 .16805 L
.33336 .18743 L
.34201 .2056 L
.35025 .22264 L
.35809 .23863 L
.36556 .25365 L
.37267 .26776 L
.37942 .28102 L
.38584 .29349 L
.39193 .30521 L
.39772 .31625 L
.40321 .32664 L
.40841 .33642 L
.41335 .34563 L
.41803 .3543 L
.42246 .36248 L
.42666 .37019 L
.43064 .37745 L
.43441 .3843 L
.43798 .39076 L
.44136 .39685 L
.44455 .4026 L
.44758 .40802 L
.45044 .41314 L
.45315 .41797 L
.45571 .42252 L
.45814 .42682 L
.46043 .43088 L
.4626 .43472 L
.46465 .43833 L
.46659 .44175 L
.46842 .44498 L
.47015 .44802 L
.47179 .4509 L
.47334 .45361 L
.47481 .45618 L
.47619 .4586 L
.4775 .46089 L
.47874 .46305 L
.47991 .46509 L
.48101 .46702 L
.48206 .46884 L
.48304 .47056 L
Mistroke
.48398 .47219 L
.48486 .47372 L
.48569 .47517 L
.48648 .47654 L
.48722 .47784 L
.48793 .47906 L
.48859 .48022 L
.48922 .48131 L
.48981 .48234 L
.49038 .48331 L
.49091 .48423 L
.49141 .4851 L
.49188 .48592 L
.49233 .4867 L
.49275 .48743 L
.49315 .48813 L
.49353 .48878 L
.49388 .4894 L
.49422 .48999 L
.49454 .49054 L
.49484 .49106 L
.49512 .49155 L
.49539 .49202 L
.49565 .49246 L
.49589 .49287 L
.49611 .49327 L
.49633 .49364 L
.49653 .49399 L
.49672 .49432 L
.4969 .49463 L
.49707 .49493 L
.49723 .49521 L
.49739 .49547 L
.49753 .49572 L
.49767 .49596 L
.4978 .49618 L
.49792 .49639 L
.49803 .49659 L
.49814 .49678 L
.49824 .49696 L
.49834 .49712 L
.49843 .49728 L
.49852 .49743 L
.4986 .49757 L
.49868 .49771 L
.49875 .49783 L
.49882 .49795 L
.49888 .49807 L
.49894 .49817 L
.499 .49827 L
Mistroke
.49906 .49837 L
.49911 .49846 L
.49916 .49854 L
.49921 .49862 L
.49925 .4987 L
.49929 .49877 L
.49933 .49884 L
.49937 .4989 L
.4994 .49896 L
.49943 .49902 L
.49947 .49907 L
.4995 .49913 L
.49952 .49917 L
.49955 .49922 L
.49957 .49926 L
.4996 .4993 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49944 L
.4997 .49948 L
.49971 .4995 L
.49973 .49953 L
.49974 .49956 L
.49976 .49958 L
.49977 .4996 L
.49978 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
Mistroke
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
Mfstroke
0 .347 1 r
.17365 0 m
.1877 .01792 L
.20625 .04219 L
.22359 .06542 L
.23983 .08765 L
.25504 .10888 L
.26929 .12914 L
.28266 .14845 L
.2952 .16685 L
.30698 .18437 L
.31804 .20104 L
.32844 .21688 L
.33821 .23194 L
.3474 .24624 L
.35605 .25981 L
.36419 .27269 L
.37186 .28491 L
.37908 .2965 L
.38588 .30748 L
.39229 .31789 L
.39832 .32776 L
.40402 .3371 L
.40938 .34595 L
.41444 .35432 L
.41922 .36226 L
.42372 .36976 L
.42797 .37687 L
.43197 .38359 L
.43575 .38995 L
.43932 .39597 L
.44269 .40166 L
.44587 .40705 L
.44887 .41214 L
.45171 .41696 L
.45438 .42151 L
.45691 .42582 L
.45929 .42989 L
.46155 .43374 L
.46367 .43738 L
.46568 .44082 L
.46758 .44407 L
.46937 .44714 L
.47107 .45005 L
.47266 .4528 L
.47417 .45539 L
.4756 .45785 L
.47695 .46017 L
.47822 .46236 L
.47942 .46443 L
.48056 .46639 L
Mistroke
.48163 .46824 L
.48265 .46999 L
.4836 .47164 L
.48451 .4732 L
.48536 .47468 L
.48617 .47607 L
.48693 .47739 L
.48765 .47863 L
.48833 .47981 L
.48898 .48092 L
.48959 .48197 L
.49016 .48297 L
.4907 .48391 L
.49122 .48479 L
.4917 .48563 L
.49216 .48642 L
.49259 .48717 L
.493 .48788 L
.49338 .48855 L
.49375 .48918 L
.49409 .48977 L
.49442 .49034 L
.49473 .49087 L
.49502 .49137 L
.49529 .49185 L
.49555 .4923 L
.4958 .49272 L
.49603 .49312 L
.49625 .4935 L
.49645 .49386 L
.49665 .4942 L
.49683 .49452 L
.49701 .49482 L
.49717 .49511 L
.49733 .49538 L
.49748 .49563 L
.49762 .49587 L
.49775 .4961 L
.49787 .49631 L
.49799 .49652 L
.4981 .49671 L
.4982 .49689 L
.4983 .49706 L
.4984 .49722 L
.49849 .49738 L
.49857 .49752 L
.49865 .49766 L
.49872 .49779 L
.49879 .49791 L
.49886 .49802 L
Mistroke
.49892 .49813 L
.49898 .49824 L
.49904 .49833 L
.49909 .49843 L
.49914 .49851 L
.49919 .49859 L
.49923 .49867 L
.49928 .49874 L
.49932 .49881 L
.49935 .49888 L
.49939 .49894 L
.49942 .499 L
.49945 .49905 L
.49948 .49911 L
.49951 .49916 L
.49954 .4992 L
.49956 .49925 L
.49959 .49929 L
.49961 .49933 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .4997 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49988 .49978 L
.49988 .4998 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
Mistroke
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
Mfstroke
0 1 .016 r
.17804 0 m
.18018 .00278 L
.19909 .02796 L
.21679 .05206 L
.23336 .07508 L
.2489 .09705 L
.26346 .11801 L
.27713 .13798 L
.28996 .157 L
.302 .17509 L
.31333 .19229 L
.32397 .20864 L
.33398 .22417 L
.34339 .23891 L
.35226 .25291 L
.3606 .26618 L
.36846 .27877 L
.37586 .29071 L
.38283 .30202 L
.3894 .31274 L
.39559 .32289 L
.40143 .33251 L
.40694 .34161 L
.41213 .35023 L
.41703 .35839 L
.42165 .36612 L
.42601 .37343 L
.43013 .38034 L
.43401 .38688 L
.43767 .39307 L
.44113 .39893 L
.4444 .40446 L
.44748 .4097 L
.45039 .41465 L
.45314 .41933 L
.45573 .42376 L
.45818 .42794 L
.46049 .4319 L
.46268 .43564 L
.46474 .43918 L
.46669 .44252 L
.46853 .44568 L
.47027 .44867 L
.47191 .45149 L
.47347 .45416 L
.47493 .45668 L
.47631 .45907 L
.47762 .46132 L
.47886 .46345 L
.48002 .46546 L
Mistroke
.48113 .46736 L
.48217 .46916 L
.48315 .47086 L
.48408 .47246 L
.48496 .47398 L
.48579 .47541 L
.48657 .47677 L
.48731 .47805 L
.48801 .47926 L
.48867 .4804 L
.4893 .48148 L
.48989 .4825 L
.49045 .48346 L
.49097 .48437 L
.49147 .48524 L
.49194 .48605 L
.49239 .48682 L
.49281 .48754 L
.4932 .48823 L
.49358 .48888 L
.49393 .48949 L
.49427 .49007 L
.49458 .49062 L
.49488 .49114 L
.49516 .49162 L
.49543 .49209 L
.49568 .49252 L
.49592 .49293 L
.49614 .49332 L
.49636 .49369 L
.49656 .49404 L
.49675 .49437 L
.49693 .49468 L
.4971 .49497 L
.49726 .49525 L
.49741 .49551 L
.49755 .49576 L
.49769 .49599 L
.49781 .49621 L
.49793 .49642 L
.49805 .49662 L
.49816 .4968 L
.49826 .49698 L
.49835 .49715 L
.49844 .4973 L
.49853 .49745 L
.49861 .49759 L
.49869 .49773 L
.49876 .49785 L
.49883 .49797 L
Mistroke
.49889 .49808 L
.49895 .49819 L
.49901 .49829 L
.49907 .49838 L
.49912 .49847 L
.49917 .49856 L
.49921 .49864 L
.49926 .49871 L
.4993 .49878 L
.49934 .49885 L
.49937 .49891 L
.49941 .49897 L
.49944 .49903 L
.49947 .49908 L
.4995 .49913 L
.49953 .49918 L
.49955 .49923 L
.49958 .49927 L
.4996 .49931 L
.49962 .49935 L
.49964 .49938 L
.49966 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
Mistroke
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .4999 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
Mfstroke
.83 1 0 r
.78502 1 m
.77992 .99087 L
.76462 .96358 L
.75016 .93782 L
.73647 .91351 L
.72352 .89056 L
.71128 .8689 L
.6997 .84845 L
.68875 .82914 L
.6784 .81091 L
.66861 .7937 L
.65935 .77745 L
.6506 .7621 L
.64233 .7476 L
.63451 .73391 L
.62711 .72098 L
.62012 .70877 L
.61352 .69723 L
.60728 .68634 L
.60137 .67604 L
.5958 .66632 L
.59053 .65714 L
.58554 .64846 L
.58084 .64027 L
.57639 .63253 L
.57218 .62521 L
.56821 .6183 L
.56445 .61178 L
.5609 .60561 L
.55755 .59978 L
.55438 .59428 L
.55138 .58908 L
.54855 .58416 L
.54588 .57952 L
.54335 .57514 L
.54096 .57099 L
.5387 .56708 L
.53657 .56338 L
.53456 .55988 L
.53265 .55658 L
.53085 .55346 L
.52915 .55051 L
.52755 .54773 L
.52603 .5451 L
.52459 .54261 L
.52324 .54026 L
.52196 .53804 L
.52075 .53594 L
.5196 .53396 L
.51852 .53209 L
Mistroke
.5175 .53032 L
.51654 .52865 L
.51563 .52707 L
.51477 .52558 L
.51395 .52417 L
.51318 .52284 L
.51246 .52158 L
.51177 .52039 L
.51112 .51926 L
.51051 .5182 L
.50993 .5172 L
.50938 .51625 L
.50886 .51535 L
.50838 .51451 L
.50791 .51371 L
.50748 .51295 L
.50707 .51224 L
.50668 .51156 L
.50631 .51093 L
.50596 .51032 L
.50563 .50976 L
.50532 .50922 L
.50503 .50871 L
.50475 .50823 L
.50449 .50778 L
.50424 .50735 L
.50401 .50694 L
.50379 .50656 L
.50358 .5062 L
.50338 .50586 L
.50319 .50553 L
.50302 .50523 L
.50285 .50494 L
.5027 .50467 L
.50255 .50441 L
.50241 .50417 L
.50227 .50394 L
.50215 .50372 L
.50203 .50352 L
.50192 .50332 L
.50181 .50314 L
.50171 .50297 L
.50162 .5028 L
.50153 .50265 L
.50144 .5025 L
.50136 .50236 L
.50129 .50223 L
.50122 .50211 L
.50115 .50199 L
.50109 .50188 L
Mistroke
.50103 .50178 L
.50097 .50168 L
.50092 .50159 L
.50087 .5015 L
.50082 .50142 L
.50077 .50134 L
.50073 .50127 L
.50069 .5012 L
.50065 .50113 L
.50062 .50107 L
.50058 .50101 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .5008 L
.50044 .50076 L
.50041 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .50061 L
.50033 .50057 L
.50031 .50054 L
.5003 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50039 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50018 L
.5001 .50017 L
.5001 .50016 L
.50009 .50016 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
Mistroke
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
Mfstroke
.432 1 0 r
.22321 0 m
.23671 .02592 L
.25082 .05276 L
.2642 .07802 L
.27689 .10181 L
.28892 .12422 L
.30033 .14534 L
.31113 .16523 L
.32137 .18398 L
.33107 .20166 L
.34025 .21833 L
.34894 .23405 L
.35717 .24888 L
.36496 .26287 L
.37233 .27607 L
.3793 .28852 L
.3859 .30027 L
.39214 .31136 L
.39805 .32183 L
.40363 .33172 L
.40891 .34105 L
.41391 .34985 L
.41863 .35817 L
.42309 .36602 L
.42732 .37344 L
.43131 .38044 L
.43508 .38705 L
.43865 .3933 L
.44202 .3992 L
.44521 .40477 L
.44822 .41003 L
.45107 .415 L
.45376 .4197 L
.4563 .42413 L
.45871 .42832 L
.46098 .43228 L
.46313 .43602 L
.46516 .43955 L
.46708 .44288 L
.46889 .44604 L
.4706 .44901 L
.47222 .45183 L
.47375 .45448 L
.4752 .45699 L
.47656 .45937 L
.47785 .46161 L
.47907 .46373 L
.48023 .46573 L
.48132 .46762 L
.48235 .4694 L
Mistroke
.48332 .47109 L
.48424 .47268 L
.48511 .47419 L
.48593 .47561 L
.4867 .47696 L
.48743 .47823 L
.48813 .47943 L
.48878 .48056 L
.4894 .48163 L
.48998 .48265 L
.49054 .4836 L
.49106 .48451 L
.49155 .48536 L
.49202 .48617 L
.49246 .48693 L
.49287 .48765 L
.49326 .48833 L
.49364 .48898 L
.49399 .48958 L
.49432 .49016 L
.49463 .4907 L
.49493 .49121 L
.49521 .4917 L
.49547 .49215 L
.49572 .49259 L
.49596 .493 L
.49618 .49338 L
.49639 .49375 L
.49659 .49409 L
.49678 .49442 L
.49695 .49473 L
.49712 .49502 L
.49728 .49529 L
.49743 .49555 L
.49757 .4958 L
.49771 .49603 L
.49783 .49625 L
.49795 .49645 L
.49807 .49665 L
.49817 .49683 L
.49827 .49701 L
.49837 .49717 L
.49846 .49733 L
.49854 .49748 L
.49862 .49762 L
.4987 .49775 L
.49877 .49787 L
.49884 .49799 L
.4989 .4981 L
.49896 .4982 L
Mistroke
.49902 .4983 L
.49907 .4984 L
.49913 .49848 L
.49917 .49857 L
.49922 .49865 L
.49926 .49872 L
.4993 .49879 L
.49934 .49886 L
.49938 .49892 L
.49941 .49898 L
.49944 .49904 L
.49947 .49909 L
.4995 .49914 L
.49953 .49919 L
.49956 .49923 L
.49958 .49927 L
.4996 .49931 L
.49963 .49935 L
.49965 .49939 L
.49967 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49978 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
Mistroke
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
Mfstroke
1 .237 0 r
1 .1627 m
.94895 .2241 L
.90037 .2806 L
.85764 .32847 L
.82003 .36893 L
.78688 .40301 L
.75763 .43163 L
.73178 .45557 L
.70892 .4755 L
.68866 .49199 L
.67068 .50555 L
.65471 .51661 L
.6405 .52555 L
.62782 .53268 L
.61651 .53827 L
.60639 .54257 L
.59732 .54578 L
.58917 .54807 L
.58185 .54959 L
.57525 .55047 L
.5693 .55082 L
.56391 .55073 L
.55903 .55028 L
.5546 .54955 L
.55057 .54858 L
.5469 .54743 L
.54355 .54614 L
.54049 .54475 L
.53768 .54327 L
.53511 .54175 L
.53274 .5402 L
.53056 .53863 L
.52855 .53706 L
.5267 .5355 L
.52499 .53397 L
.5234 .53246 L
.52193 .53099 L
.52056 .52955 L
.51929 .52816 L
.51811 .52681 L
.51701 .52551 L
.51598 .52426 L
.51502 .52306 L
.51413 .5219 L
.51329 .5208 L
.51251 .51974 L
.51177 .51873 L
.51109 .51776 L
.51044 .51684 L
.50984 .51596 L
Mistroke
.50927 .51512 L
.50874 .51432 L
.50824 .51357 L
.50777 .51285 L
.50733 .51216 L
.50691 .51151 L
.50652 .5109 L
.50615 .51031 L
.5058 .50976 L
.50548 .50923 L
.50517 .50873 L
.50488 .50826 L
.50461 .50781 L
.50435 .50739 L
.50411 .50699 L
.50388 .50661 L
.50366 .50625 L
.50346 .50591 L
.50326 .50558 L
.50308 .50528 L
.50291 .50499 L
.50275 .50472 L
.5026 .50446 L
.50245 .50421 L
.50232 .50398 L
.50219 .50376 L
.50207 .50356 L
.50195 .50336 L
.50184 .50318 L
.50174 .503 L
.50165 .50284 L
.50156 .50268 L
.50147 .50254 L
.50139 .5024 L
.50131 .50226 L
.50124 .50214 L
.50117 .50202 L
.50111 .50191 L
.50104 .50181 L
.50099 .50171 L
.50093 .50161 L
.50088 .50152 L
.50083 .50144 L
.50079 .50136 L
.50074 .50129 L
.5007 .50121 L
.50066 .50115 L
.50063 .50108 L
.50059 .50102 L
.50056 .50097 L
Mistroke
.50053 .50092 L
.5005 .50086 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50036 .50062 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
Mistroke
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0333333 0.5 0.0333333 [
[0 .4875 -18.4688 -20 ]
[0 .4875 18.4688 0 ]
[.16667 .4875 -18.4688 -20 ]
[.16667 .4875 18.4688 0 ]
[.33333 .4875 -13.4688 -20 ]
[.33333 .4875 13.4688 0 ]
[.66667 .4875 -7 -20 ]
[.66667 .4875 7 0 ]
[.83333 .4875 -12 -20 ]
[.83333 .4875 12 0 ]
[1 .4875 -12 -20 ]
[1 .4875 12 0 ]
[.4875 0 -36.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .16667 -36.9375 -10 ]
[.4875 .16667 0 10 ]
[.4875 .33333 -26.9375 -10 ]
[.4875 .33333 0 10 ]
[.4875 .66667 -14 -10 ]
[.4875 .66667 0 10 ]
[.4875 .83333 -24 -10 ]
[.4875 .83333 0 10 ]
[.4875 1 -24 -10 ]
[.4875 1 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.16667 .5 m
.16667 .50625 L
s
gsave
.16667 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.33333 .5 m
.33333 .50625 L
s
gsave
.33333 .4875 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.66667 .5 m
.66667 .50625 L
s
gsave
.66667 .4875 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.83333 .5 m
.83333 .50625 L
s
gsave
.83333 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.5 .16667 m
.50625 .16667 L
s
gsave
.4875 .16667 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 .33333 m
.50625 .33333 L
s
gsave
.4875 .33333 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .66667 m
.50625 .66667 L
s
gsave
.4875 .66667 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .83333 m
.50625 .83333 L
s
gsave
.4875 .83333 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.01 w
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 .147 1 r
.5 Mabswid
.19618 .63683 m
.22793 .6033 L
.25593 .57509 L
.28065 .55144 L
.3025 .5317 L
.32184 .5153 L
.33899 .50176 L
.35422 .49067 L
.36776 .48165 L
.37981 .4744 L
.39057 .46866 L
.40018 .46419 L
.40878 .46079 L
.4165 .45829 L
.42343 .45656 L
.42967 .45546 L
.4353 .45489 L
.44038 .45475 L
.44498 .45497 L
.44915 .45548 L
.45294 .45623 L
.45638 .45716 L
.45953 .45824 L
.4624 .45943 L
.46503 .46071 L
.46744 .46204 L
.46965 .46341 L
.47168 .4648 L
.47356 .4662 L
.47529 .46759 L
.47688 .46897 L
.47836 .47033 L
.47973 .47166 L
.481 .47295 L
.48218 .47421 L
.48328 .47544 L
.4843 .47662 L
.48525 .47776 L
.48614 .47885 L
.48697 .47991 L
.48774 .48092 L
.48847 .48189 L
.48914 .48281 L
.48978 .4837 L
.49037 .48454 L
.49093 .48534 L
.49146 .48611 L
.49195 .48684 L
.49241 .48754 L
.49284 .4882 L
Mistroke
.49325 .48882 L
.49363 .48942 L
.494 .48998 L
.49434 .49052 L
.49466 .49103 L
.49496 .49151 L
.49524 .49197 L
.49551 .49241 L
.49576 .49282 L
.496 .49321 L
.49622 .49358 L
.49643 .49393 L
.49663 .49426 L
.49682 .49457 L
.497 .49487 L
.49716 .49515 L
.49732 .49541 L
.49747 .49566 L
.49761 .4959 L
.49774 .49612 L
.49787 .49634 L
.49799 .49654 L
.4981 .49673 L
.4982 .49691 L
.4983 .49708 L
.4984 .49724 L
.49849 .49739 L
.49857 .49753 L
.49865 .49767 L
.49872 .4978 L
.49879 .49792 L
.49886 .49803 L
.49892 .49814 L
.49898 .49824 L
.49904 .49834 L
.49909 .49843 L
.49914 .49852 L
.49919 .4986 L
.49923 .49868 L
.49928 .49875 L
.49932 .49882 L
.49935 .49888 L
.49939 .49894 L
.49942 .499 L
.49946 .49906 L
.49949 .49911 L
.49951 .49916 L
.49954 .4992 L
.49957 .49925 L
.49959 .49929 L
Mistroke
.49961 .49933 L
.49963 .49937 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .4997 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49988 .49978 L
.49988 .4998 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
Mistroke
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.19618 .63683 m
.22793 .6033 L
s
% Start of user PostScript
-9.1146369 4.1049912 -8.1621098 3.0990942 MAarrowhead1
% End of user PostScript
1 .158 0 r
.25593 .57509 m
.28065 .55144 L
s
% Start of user PostScript
-7.3221809 2.2527289 -6.5806208 1.5432056 MAarrowhead1
% End of user PostScript
1 .473 0 r
.39057 .46866 m
.40018 .46419 L
s
% Start of user PostScript
-3.2829375 -0.94020005 -2.9945848 -1.0743848 MAarrowhead1
% End of user PostScript
1 .788 0 r
.44498 .45497 m
.44915 .45548 L
s
% Start of user PostScript
-1.6507065 -1.3509404 -1.5255906 -1.3355842 MAarrowhead1
% End of user PostScript
.897 1 0 r
.46965 .46341 m
.47168 .4648 L
s
% Start of user PostScript
-0.91050567 -1.0977836 -0.84947274 -1.0560558 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48218 .47421 m
.48328 .47544 L
s
% Start of user PostScript
-0.53454814 -0.77356793 -0.50163698 -0.73689679 MAarrowhead1
% End of user PostScript
.266 1 0 r
.48914 .48281 m
.48978 .4837 L
s
% Start of user PostScript
-0.32565994 -0.51566343 -0.30661403 -0.48913617 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49325 .48882 m
.49363 .48942 L
s
% Start of user PostScript
-0.20246919 -0.33530782 -0.19096082 -0.31742796 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49576 .49282 m
.496 .49321 L
s
% Start of user PostScript
-0.12722757 -0.21547752 -0.12010404 -0.20379166 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49732 .49541 m
.49747 .49566 L
s
% Start of user PostScript
-0.080385163 -0.13767819 -0.075919087 -0.13015005 MAarrowhead1
% End of user PostScript
0 1 .995 r
.4983 .49708 m
.4984 .49724 L
s
% Start of user PostScript
-0.050929803 -0.087719501 -0.048111319 -0.082903629 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49892 .49814 m
.49898 .49824 L
s
% Start of user PostScript
-0.032312666 -0.055810356 -0.030528001 -0.052740162 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49932 .49882 m
.49935 .49888 L
s
% Start of user PostScript
-0.020515258 -0.035483635 -0.019383303 -0.033529684 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49957 .49925 m
.49959 .49929 L
s
% Start of user PostScript
-0.013029663 -0.022552202 -0.012311092 -0.021309716 MAarrowhead1
% End of user PostScript
0 .063 1 r
.38875 .69206 m
.40359 .66639 L
.41644 .64415 L
.42759 .62489 L
.43724 .60819 L
.44561 .59373 L
.45286 .5812 L
.45914 .57034 L
.46459 .56093 L
.46931 .55278 L
.4734 .54572 L
.47694 .5396 L
.48001 .5343 L
.48267 .52971 L
.48498 .52573 L
.48698 .52228 L
.48871 .5193 L
.49021 .51671 L
.49151 .51447 L
.49264 .51253 L
.49362 .51085 L
.49447 .50939 L
.4952 .50813 L
.49584 .50704 L
.49639 .50609 L
.49687 .50527 L
.49728 .50456 L
.49764 .50395 L
.49795 .50341 L
.49822 .50295 L
.49846 .50255 L
.49866 .50221 L
.49884 .50191 L
.49899 .50165 L
.49912 .50143 L
.49924 .50123 L
.49934 .50106 L
.49942 .50092 L
.4995 .50079 L
.49956 .50068 L
.49962 .50059 L
.49967 .50051 L
.49971 .50044 L
.49975 .50038 L
.49978 .50033 L
.49981 .50028 L
.49983 .50024 L
.49986 .50021 L
.49987 .50018 L
.49989 .50015 L
Mistroke
.4999 .50013 L
.49992 .50011 L
.49993 .50009 L
.49994 .50008 L
.49994 .50007 L
.49995 .50006 L
.49996 .50005 L
.49996 .50004 L
.49997 .50004 L
.49997 .50003 L
.49997 .50002 L
.49998 .50002 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.38875 .69206 m
.40359 .66639 L
s
% Start of user PostScript
-3.3376028 5.7617385 -2.892443 4.991755 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41644 .64415 m
.42759 .62489 L
s
% Start of user PostScript
-2.5066912 4.3246112 -2.1724174 3.7465748 MAarrowhead1
% End of user PostScript
1 .473 0 r
.4734 .54572 m
.47694 .5396 L
s
% Start of user PostScript
-0.79813312 1.3715394 -0.69182266 1.1880033 MAarrowhead1
% End of user PostScript
1 .788 0 r
.49151 .51447 m
.49264 .51253 L
s
% Start of user PostScript
-0.25462343 0.43411597 -0.22078565 0.37588783 MAarrowhead1
% End of user PostScript
.897 1 0 r
.49728 .50456 m
.49764 .50395 L
s
% Start of user PostScript
-0.081546069 0.13685505 -0.070758363 0.11841201 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49912 .50143 m
.49924 .50123 L
s
% Start of user PostScript
-0.026315504 0.042792615 -0.022865268 0.036970263 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49971 .50044 m
.49975 .50038 L
s
% Start of user PostScript
-0.0086179335 0.013155885 -0.0075074489 0.011330079 MAarrowhead1
% End of user PostScript
0 1 .049 r
.4999 .50013 m
.49992 .50011 L
s
% Start of user PostScript
-0.0029009054 0.0038994412 -0.0025390724 0.0033347436 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49997 .50004 m
.49997 .50003 L
s
% Start of user PostScript
-0.0010249766 0.0010605031 -0.00090430974 0.00089090315 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49999 .50001 m
.49999 .50001 L
s
% Start of user PostScript
-0.00039124174 0.00022350184 -0.0003492847 0.00017586339 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49999 .5 m
.49999 .5 L
s
% Start of user PostScript
-0.00016596063 -0.0000010880981 -0.00015033281 -0.000012251549 MAarrowhead1
% End of user PostScript
0 .69 1 r
.5 .5 m
.5 .5 L
s
% Start of user PostScript
-0.000079189845 -0.00004616133 -0.00007276566 -0.000047183387 MAarrowhead1
% End of user PostScript
0 .375 1 r
.5 .5 m
.5 .5 L
s
% Start of user PostScript
-0.000041970454 -0.000043777546 -0.000039002644 -0.000042497826 MAarrowhead1
% End of user PostScript
0 .06 1 r
.5 .5 m
.5 .5 L
s
% Start of user PostScript
-0.000024014673 -0.000032405389 -0.000022483018 -0.000030979314 MAarrowhead1
% End of user PostScript
1 .719 0 r
.5606 .68264 m
.55902 .66953 L
.55729 .65755 L
.55545 .64658 L
.55354 .63652 L
.55158 .62728 L
.54959 .61877 L
.5476 .61094 L
.54563 .60371 L
.54367 .59702 L
.54175 .59084 L
.53986 .5851 L
.53803 .57978 L
.53625 .57484 L
.53452 .57024 L
.53286 .56596 L
.53125 .56197 L
.52971 .55825 L
.52822 .55477 L
.5268 .55152 L
.52544 .54848 L
.52414 .54563 L
.52289 .54297 L
.5217 .54047 L
.52057 .53813 L
.5195 .53593 L
.51847 .53386 L
.51749 .53192 L
.51657 .5301 L
.51569 .52839 L
.51485 .52677 L
.51405 .52526 L
.5133 .52383 L
.51258 .52248 L
.51191 .52122 L
.51126 .52002 L
.51065 .5189 L
.51008 .51784 L
.50953 .51684 L
.50901 .5159 L
.50852 .51501 L
.50806 .51418 L
.50762 .51339 L
.5072 .51264 L
.50681 .51194 L
.50644 .51127 L
.50609 .51065 L
.50575 .51006 L
.50544 .5095 L
.50514 .50897 L
Mistroke
.50486 .50847 L
.50459 .50801 L
.50434 .50756 L
.5041 .50714 L
.50388 .50675 L
.50366 .50637 L
.50346 .50602 L
.50327 .50569 L
.50309 .50537 L
.50292 .50508 L
.50276 .5048 L
.50261 .50453 L
.50247 .50428 L
.50233 .50405 L
.5022 .50382 L
.50208 .50361 L
.50197 .50341 L
.50186 .50322 L
.50176 .50305 L
.50166 .50288 L
.50157 .50272 L
.50148 .50257 L
.5014 .50243 L
.50132 .50229 L
.50125 .50217 L
.50118 .50205 L
.50112 .50193 L
.50105 .50183 L
.501 .50173 L
.50094 .50163 L
.50089 .50154 L
.50084 .50146 L
.50079 .50138 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50063 .5011 L
.5006 .50104 L
.50057 .50098 L
.50053 .50093 L
.5005 .50087 L
.50048 .50083 L
.50045 .50078 L
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50056 L
.5003 .50052 L
Mistroke
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .5004 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
Mistroke
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.5606 .68264 m
.55902 .66953 L
s
% Start of user PostScript
1.8181448 5.4791687 1.7706507 5.0858285 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55729 .65755 m
.55545 .64658 L
s
% Start of user PostScript
1.7187354 4.7263617 1.6635824 4.3972735 MAarrowhead1
% End of user PostScript
1 .473 0 r
.54175 .59084 m
.53986 .5851 L
s
% Start of user PostScript
1.2523636 2.7250816 1.1959111 2.5530833 MAarrowhead1
% End of user PostScript
1 .788 0 r
.52822 .55477 m
.5268 .55152 L
s
% Start of user PostScript
0.84664454 1.6430905 0.80397383 1.5455974 MAarrowhead1
% End of user PostScript
.897 1 0 r
.51847 .53386 m
.51749 .53192 L
s
% Start of user PostScript
0.55410495 1.0158759 0.52483225 0.95767924 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51191 .52122 m
.51126 .52002 L
s
% Start of user PostScript
0.35719324 0.63651609 0.33790794 0.60073132 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50762 .51339 m
.5072 .51264 L
s
% Start of user PostScript
0.22857571 0.40157363 0.2161046 0.37921619 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50486 .50847 m
.50459 .50801 L
s
% Start of user PostScript
0.14574373 0.25423698 0.13775091 0.2401525 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50309 .50537 m
.50292 .50508 L
s
% Start of user PostScript
0.092762443 0.16124172 0.087662209 0.15233142 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50197 .50341 m
.50186 .50322 L
s
% Start of user PostScript
0.058988473 0.10235294 0.055741068 0.096703985 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50125 .50217 m
.50118 .50205 L
s
% Start of user PostScript
0.037494606 0.06500037 0.035429162 0.061415198 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50079 .50138 m
.50075 .5013 L
s
% Start of user PostScript
0.023827245 0.041288369 0.022514272 0.03901178 MAarrowhead1
% End of user PostScript
0 .375 1 r
.5005 .50087 m
.50048 .50083 L
s
% Start of user PostScript
0.015140164 0.026229371 0.01430575 0.024783344 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50032 .50056 m
.5003 .50052 L
s
% Start of user PostScript
0.0096197364 0.016663727 0.0090895259 0.015745128 MAarrowhead1
% End of user PostScript
0 1 .274 r
.46924 .60977 m
.47462 .59732 L
.47922 .58642 L
.48313 .57686 L
.48646 .56847 L
.48929 .56109 L
.49168 .5546 L
.4937 .54889 L
.4954 .54385 L
.49683 .5394 L
.49802 .53547 L
.49901 .53199 L
.49983 .52891 L
.5005 .52617 L
.50104 .52373 L
.50148 .52157 L
.50183 .51963 L
.5021 .5179 L
.50231 .51636 L
.50246 .51497 L
.50257 .51373 L
.50264 .51261 L
.50267 .5116 L
.50268 .51068 L
.50267 .50986 L
.50264 .50911 L
.5026 .50843 L
.50255 .50781 L
.50248 .50725 L
.50241 .50673 L
.50234 .50626 L
.50226 .50583 L
.50218 .50543 L
.50209 .50507 L
.50201 .50473 L
.50193 .50442 L
.50185 .50414 L
.50177 .50387 L
.50169 .50363 L
.50161 .5034 L
.50154 .50319 L
.50146 .50299 L
.50139 .50281 L
.50132 .50264 L
.50126 .50248 L
.5012 .50233 L
.50114 .50219 L
.50108 .50206 L
.50102 .50194 L
.50097 .50183 L
Mistroke
.50092 .50172 L
.50087 .50162 L
.50083 .50153 L
.50078 .50144 L
.50074 .50136 L
.5007 .50128 L
.50067 .50121 L
.50063 .50114 L
.5006 .50107 L
.50056 .50101 L
.50053 .50096 L
.50051 .5009 L
.50048 .50085 L
.50045 .5008 L
.50043 .50076 L
.5004 .50072 L
.50038 .50068 L
.50036 .50064 L
.50034 .5006 L
.50032 .50057 L
.50031 .50054 L
.50029 .50051 L
.50027 .50048 L
.50026 .50045 L
.50024 .50043 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50012 .50022 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
Mistroke
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
Mistroke
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.46924 .60977 m
.47462 .59732 L
s
% Start of user PostScript
-0.92287751 3.292964 -0.76132389 2.9197422 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47922 .58642 m
.48313 .57686 L
s
% Start of user PostScript
-0.62345232 2.5926874 -0.50598459 2.3058379 MAarrowhead1
% End of user PostScript
1 .473 0 r
.49802 .53547 m
.49901 .53199 L
s
% Start of user PostScript
-0.05943022 1.0641066 -0.029746499 0.95971188 MAarrowhead1
% End of user PostScript
1 .788 0 r
.50231 .51636 m
.50246 .51497 L
s
% Start of user PostScript
0.069228795 0.49076536 0.07380458 0.44917876 MAarrowhead1
% End of user PostScript
.897 1 0 r
.5026 .50843 m
.50255 .50781 L
s
% Start of user PostScript
0.077982018 0.25291826 0.076350244 0.23435822 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50201 .50473 m
.50193 .50442 L
s
% Start of user PostScript
0.060349071 0.14197732 0.057869963 0.13268359 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50139 .50281 m
.50132 .50264 L
s
% Start of user PostScript
0.041775534 0.084257933 0.039742098 0.079147108 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50092 .50172 m
.50087 .50162 L
s
% Start of user PostScript
0.027632778 0.05164309 0.026195196 0.048648239 MAarrowhead1
% End of user PostScript
0 1 .364 r
.5006 .50107 m
.50056 .50101 L
s
% Start of user PostScript
0.017902984 0.032210614 0.016943341 0.030388024 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50038 .50068 m
.50036 .50064 L
s
% Start of user PostScript
0.011484708 0.020273981 0.010860297 0.019141485 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50024 .50043 m
.50023 .5004 L
s
% Start of user PostScript
0.0073317409 0.012820301 0.0069303517 0.012108873 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50016 .50027 m
.50015 .50026 L
s
% Start of user PostScript
0.0046692971 0.0081260228 0.004412792 0.0076765944 MAarrowhead1
% End of user PostScript
0 .375 1 r
.5001 .50017 m
.50009 .50016 L
s
% Start of user PostScript
0.0029701418 0.0051566908 0.0028067009 0.0048719669 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50006 .50011 m
.50006 .5001 L
s
% Start of user PostScript
0.001888183 0.003274323 0.001784192 0.0030936854 MAarrowhead1
% End of user PostScript
0 .472 1 r
.62936 .36092 m
.61401 .38282 L
.60061 .40161 L
.58889 .41772 L
.57865 .43151 L
.56968 .44331 L
.56182 .45339 L
.55494 .46198 L
.5489 .4693 L
.54359 .47551 L
.53892 .48078 L
.53482 .48524 L
.5312 .48899 L
.52801 .49215 L
.52519 .49479 L
.5227 .49699 L
.52049 .49882 L
.51853 .50032 L
.51679 .50155 L
.51524 .50254 L
.51386 .50333 L
.51263 .50396 L
.51153 .50444 L
.51054 .50481 L
.50965 .50507 L
.50886 .50525 L
.50814 .50535 L
.5075 .5054 L
.50691 .5054 L
.50638 .50536 L
.5059 .50529 L
.50546 .50519 L
.50507 .50507 L
.5047 .50494 L
.50437 .50479 L
.50407 .50464 L
.50379 .50447 L
.50353 .50431 L
.5033 .50414 L
.50308 .50398 L
.50288 .50381 L
.50269 .50365 L
.50252 .50349 L
.50236 .50333 L
.50222 .50317 L
.50208 .50303 L
.50195 .50288 L
.50183 .50274 L
.50172 .50261 L
.50162 .50248 L
Mistroke
.50152 .50235 L
.50143 .50224 L
.50135 .50212 L
.50127 .50201 L
.50119 .50191 L
.50112 .50181 L
.50106 .50172 L
.501 .50163 L
.50094 .50154 L
.50089 .50146 L
.50084 .50138 L
.50079 .50131 L
.50074 .50124 L
.5007 .50117 L
.50066 .50111 L
.50062 .50105 L
.50059 .50099 L
.50056 .50094 L
.50053 .50089 L
.5005 .50084 L
.50047 .50079 L
.50044 .50075 L
.50042 .50071 L
.50039 .50067 L
.50037 .50064 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.5003 .50051 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50024 .50041 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
Mistroke
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
Mistroke
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.62936 .36092 m
.61401 .38282 L
s
% Start of user PostScript
3.8807153 -4.1723819 3.4202962 -3.5154286 MAarrowhead1
% End of user PostScript
1 .158 0 r
.60061 .40161 m
.58889 .41772 L
s
% Start of user PostScript
3.0181667 -2.9516905 2.6667199 -2.468419 MAarrowhead1
% End of user PostScript
1 .473 0 r
.53892 .48078 m
.53482 .48524 L
s
% Start of user PostScript
1.1677426 -0.57659425 1.0445607 -0.44294219 MAarrowhead1
% End of user PostScript
1 .788 0 r
.51679 .50155 m
.51524 .50254 L
s
% Start of user PostScript
0.50364003 0.046373235 0.45718897 0.076188689 MAarrowhead1
% End of user PostScript
.897 1 0 r
.50814 .50535 m
.5075 .5054 L
s
% Start of user PostScript
0.24426559 0.16061157 0.22486221 0.16204535 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50437 .50479 m
.50407 .50464 L
s
% Start of user PostScript
0.13113095 0.14371931 0.12201553 0.13906624 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50252 .50349 m
.50236 .50333 L
s
% Start of user PostScript
0.075666999 0.10455465 0.070896392 0.099830246 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50152 .50235 m
.50143 .50224 L
s
% Start of user PostScript
0.045644753 0.070636572 0.042938171 0.067073091 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50094 .50154 m
.50089 .50146 L
s
% Start of user PostScript
0.028227967 0.046215822 0.026611442 0.043773243 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50059 .50099 m
.50056 .50094 L
s
% Start of user PostScript
0.017689088 0.029787889 0.016694797 0.028179275 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50037 .50064 m
.50035 .5006 L
s
% Start of user PostScript
0.011160673 0.019060582 0.010539367 0.018020531 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50024 .50041 m
.50022 .50038 L
s
% Start of user PostScript
0.007066082 0.012152927 0.0066746469 0.011486408 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50015 .50026 m
.50014 .50024 L
s
% Start of user PostScript
0.0044815142 0.0077349179 0.0042338697 0.0073096288 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50009 .50016 m
.50009 .50015 L
s
% Start of user PostScript
0.0028447979 0.0049186616 0.0026877927 0.0046478785 MAarrowhead1
% End of user PostScript
1 0 .577 r
.51819 .24143 m
.51062 .26705 L
.50435 .28974 L
.49918 .30987 L
.49495 .32774 L
.49153 .34365 L
.48879 .35782 L
.48663 .37047 L
.48496 .38178 L
.48371 .39191 L
.4828 .40099 L
.48218 .40916 L
.4818 .41652 L
.48163 .42316 L
.48162 .42916 L
.48175 .43459 L
.482 .43952 L
.48233 .44401 L
.48273 .44809 L
.48318 .45181 L
.48368 .45521 L
.4842 .45833 L
.48475 .46119 L
.48531 .46381 L
.48588 .46623 L
.48644 .46845 L
.48701 .47051 L
.48757 .47241 L
.48811 .47417 L
.48865 .4758 L
.48917 .47731 L
.48968 .47871 L
.49017 .48002 L
.49065 .48124 L
.49111 .48237 L
.49155 .48343 L
.49197 .48442 L
.49237 .48534 L
.49276 .48621 L
.49313 .48702 L
.49349 .48778 L
.49382 .48849 L
.49415 .48915 L
.49445 .48978 L
.49474 .49037 L
.49502 .49092 L
.49529 .49144 L
.49554 .49192 L
.49577 .49238 L
.496 .49281 L
Mistroke
.49622 .49322 L
.49642 .4936 L
.49661 .49396 L
.49679 .4943 L
.49697 .49462 L
.49713 .49492 L
.49729 .49521 L
.49744 .49548 L
.49757 .49573 L
.49771 .49597 L
.49783 .49619 L
.49795 .4964 L
.49806 .4966 L
.49817 .49679 L
.49827 .49697 L
.49836 .49714 L
.49845 .4973 L
.49854 .49745 L
.49862 .49759 L
.49869 .49772 L
.49877 .49785 L
.49883 .49797 L
.4989 .49808 L
.49896 .49819 L
.49901 .49829 L
.49907 .49838 L
.49912 .49847 L
.49917 .49856 L
.49921 .49864 L
.49926 .49871 L
.4993 .49878 L
.49934 .49885 L
.49937 .49891 L
.49941 .49897 L
.49944 .49903 L
.49947 .49908 L
.4995 .49913 L
.49953 .49918 L
.49955 .49923 L
.49958 .49927 L
.4996 .49931 L
.49962 .49935 L
.49964 .49938 L
.49966 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
Mistroke
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.51819 .24143 m
.51062 .26705 L
s
% Start of user PostScript
0.54556408 -7.7571472 0.31858089 -6.9885032 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50435 .28974 m
.49918 .30987 L
s
% Start of user PostScript
0.13039831 -6.3077618 -0.024632162 -5.7039986 MAarrowhead1
% End of user PostScript
1 .473 0 r
.4828 .40099 m
.48218 .40916 L
s
% Start of user PostScript
-0.51611474 -2.9701607 -0.53464662 -2.7250684 MAarrowhead1
% End of user PostScript
1 .788 0 r
.48273 .44809 m
.48318 .45181 L
s
% Start of user PostScript
-0.5182456 -1.5574007 -0.50460857 -1.4456964 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48701 .47051 m
.48757 .47241 L
s
% Start of user PostScript
-0.38974784 -0.88472275 -0.37300861 -0.82773851 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49111 .48237 m
.49155 .48343 L
s
% Start of user PostScript
-0.26684399 -0.52881206 -0.25364279 -0.49705204 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49415 .48915 m
.49445 .48978 L
s
% Start of user PostScript
-0.17564528 -0.32539826 -0.16644256 -0.3066321 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49622 .49322 m
.49642 .4936 L
s
% Start of user PostScript
-0.11353594 -0.20337787 -0.10742993 -0.19190373 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49757 .49573 m
.49771 .49597 L
s
% Start of user PostScript
-0.072751066 -0.12814649 -0.068789309 -0.12099909 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49845 .4973 m
.49854 .49745 L
s
% Start of user PostScript
-0.046417894 -0.081077537 -0.043874652 -0.07658181 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49901 .49829 m
.49907 .49838 L
s
% Start of user PostScript
-0.029553579 -0.051404192 -0.027929432 -0.048562265 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49937 .49891 m
.49941 .49897 L
s
% Start of user PostScript
-0.018796459 -0.032625028 -0.017761926 -0.030824005 MAarrowhead1
% End of user PostScript
0 .375 1 r
.4996 .49931 m
.49962 .49935 L
s
% Start of user PostScript
-0.011948493 -0.020717198 -0.01129037 -0.019574385 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49975 .49956 m
.49976 .49959 L
s
% Start of user PostScript
-0.0075933934 -0.013159071 -0.0071749924 -0.012433454 MAarrowhead1
% End of user PostScript
0 .944 1 r
.8115 .50968 m
.78234 .52991 L
.75639 .54626 L
.73326 .5593 L
.7126 .56954 L
.69412 .57741 L
.67756 .58329 L
.6627 .58749 L
.64934 .59028 L
.6373 .5919 L
.62643 .59256 L
.6166 .59241 L
.60769 .59161 L
.59961 .59028 L
.59226 .58853 L
.58556 .58644 L
.57944 .5841 L
.57385 .58156 L
.56873 .57888 L
.56404 .57611 L
.55972 .57327 L
.55575 .57042 L
.55208 .56756 L
.5487 .56472 L
.54557 .56193 L
.54267 .55918 L
.53999 .55649 L
.53749 .55388 L
.53518 .55134 L
.53302 .54889 L
.53101 .54652 L
.52914 .54424 L
.52739 .54204 L
.52576 .53994 L
.52424 .53792 L
.52281 .53599 L
.52147 .53414 L
.52022 .53238 L
.51904 .5307 L
.51794 .5291 L
.51691 .52757 L
.51594 .52612 L
.51503 .52474 L
.51417 .52342 L
.51336 .52218 L
.5126 .52099 L
.51189 .51987 L
.51122 .5188 L
.51059 .51779 L
.50999 .51683 L
Mistroke
.50943 .51592 L
.5089 .51506 L
.5084 .51424 L
.50793 .51347 L
.50749 .51274 L
.50707 .51204 L
.50668 .51139 L
.5063 .51077 L
.50595 .51018 L
.50562 .50962 L
.50531 .5091 L
.50501 .5086 L
.50474 .50813 L
.50447 .50768 L
.50423 .50726 L
.50399 .50687 L
.50377 .50649 L
.50356 .50613 L
.50336 .5058 L
.50318 .50548 L
.503 .50518 L
.50284 .50489 L
.50268 .50462 L
.50253 .50437 L
.50239 .50413 L
.50226 .5039 L
.50213 .50369 L
.50202 .50348 L
.50191 .50329 L
.5018 .50311 L
.5017 .50294 L
.50161 .50278 L
.50152 .50263 L
.50143 .50248 L
.50136 .50234 L
.50128 .50222 L
.50121 .50209 L
.50114 .50198 L
.50108 .50187 L
.50102 .50177 L
.50096 .50167 L
.50091 .50158 L
.50086 .50149 L
.50081 .50141 L
.50077 .50133 L
.50073 .50126 L
.50069 .50119 L
.50065 .50112 L
.50061 .50106 L
.50058 .501 L
Mistroke
.50055 .50095 L
.50052 .50089 L
.50049 .50085 L
.50046 .5008 L
.50044 .50075 L
.50041 .50071 L
.50039 .50067 L
.50037 .50064 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .5003 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .5002 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
Mistroke
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.8115 .50968 m
.78234 .52991 L
s
% Start of user PostScript
9.3451264 0.29027207 8.4703168 0.89728001 MAarrowhead1
% End of user PostScript
1 .158 0 r
.75639 .54626 m
.73326 .5593 L
s
% Start of user PostScript
7.6917496 1.3876529 6.9977085 1.7789244 MAarrowhead1
% End of user PostScript
1 .473 0 r
.62643 .59256 m
.6166 .59241 L
s
% Start of user PostScript
3.792787 2.7766976 3.4979046 2.7722853 MAarrowhead1
% End of user PostScript
1 .788 0 r
.56873 .57888 m
.56404 .57611 L
s
% Start of user PostScript
2.062039 2.3663603 1.9211055 2.2831585 MAarrowhead1
% End of user PostScript
.897 1 0 r
.53999 .55649 m
.53749 .55388 L
s
% Start of user PostScript
1.1996176 1.6948168 1.124827 1.6164064 MAarrowhead1
% End of user PostScript
.581 1 0 r
.52424 .53792 m
.52281 .53599 L
s
% Start of user PostScript
0.72705951 1.1376018 0.68422916 1.0796656 MAarrowhead1
% End of user PostScript
.266 1 0 r
.51503 .52474 m
.51417 .52342 L
s
% Start of user PostScript
0.45077545 0.742092 0.425053 0.70270266 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50943 .51592 m
.5089 .51506 L
s
% Start of user PostScript
0.28285175 0.47762396 0.2669825 0.45177837 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50595 .51018 m
.50562 .50962 L
s
% Start of user PostScript
0.17858132 0.30540657 0.16864931 0.28872522 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50377 .50649 m
.50356 .50613 L
s
% Start of user PostScript
0.11310242 0.19465812 0.10683999 0.18397695 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50239 .50413 m
.50226 .5039 L
s
% Start of user PostScript
0.071745093 0.12387178 0.067781486 0.11705926 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50152 .50263 m
.50143 .50248 L
s
% Start of user PostScript
0.045546609 0.078763721 0.043033185 0.074427073 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50096 .50167 m
.50091 .50158 L
s
% Start of user PostScript
0.028926243 0.050061899 0.02733089 0.047303982 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50061 .50106 m
.50058 .501 L
s
% Start of user PostScript
0.018374443 0.031812814 0.017361333 0.030059746 MAarrowhead1
% End of user PostScript
0 1 .93 r
.41854 .54764 m
.4273 .53761 L
.435 .52913 L
.44179 .52197 L
.44778 .51595 L
.45307 .5109 L
.45774 .50668 L
.46188 .50318 L
.46554 .5003 L
.4688 .49793 L
.4717 .49601 L
.47428 .49446 L
.47658 .49324 L
.47863 .49229 L
.48047 .49156 L
.48212 .49103 L
.48361 .49067 L
.48494 .49043 L
.48615 .49031 L
.48723 .49029 L
.48822 .49034 L
.48911 .49045 L
.48992 .49061 L
.49066 .49081 L
.49133 .49104 L
.49195 .4913 L
.49251 .49157 L
.49303 .49186 L
.4935 .49215 L
.49393 .49245 L
.49434 .49275 L
.49471 .49305 L
.49505 .49335 L
.49536 .49364 L
.49566 .49392 L
.49593 .4942 L
.49618 .49447 L
.49642 .49473 L
.49664 .49499 L
.49684 .49523 L
.49703 .49547 L
.49721 .49569 L
.49737 .49591 L
.49753 .49612 L
.49767 .49632 L
.49781 .49651 L
.49794 .49669 L
.49806 .49686 L
.49817 .49702 L
.49827 .49718 L
Mistroke
.49837 .49733 L
.49847 .49747 L
.49855 .4976 L
.49864 .49773 L
.49871 .49785 L
.49879 .49797 L
.49885 .49808 L
.49892 .49818 L
.49898 .49828 L
.49904 .49837 L
.49909 .49846 L
.49914 .49854 L
.49919 .49862 L
.49924 .4987 L
.49928 .49877 L
.49932 .49884 L
.49936 .4989 L
.49939 .49896 L
.49943 .49902 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49954 .49921 L
.49957 .49926 L
.49959 .4993 L
.49961 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49984 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
Mistroke
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
Mistroke
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.41854 .54764 m
.4273 .53761 L
s
% Start of user PostScript
-2.4439428 1.4290535 -2.1811078 1.1283688 MAarrowhead1
% End of user PostScript
1 .158 0 r
.435 .52913 m
.44179 .52197 L
s
% Start of user PostScript
-1.9498657 0.87388532 -1.7461915 0.65910085 MAarrowhead1
% End of user PostScript
1 .473 0 r
.4717 .49601 m
.47428 .49446 L
s
% Start of user PostScript
-0.84911429 -0.11979727 -0.77174156 -0.16613997 MAarrowhead1
% End of user PostScript
1 .788 0 r
.48615 .49031 m
.48723 .49029 L
s
% Start of user PostScript
-0.41563566 -0.29061543 -0.38301138 -0.29142129 MAarrowhead1
% End of user PostScript
.897 1 0 r
.49251 .49157 m
.49303 .49186 L
s
% Start of user PostScript
-0.22471693 -0.25280436 -0.2092434 -0.24421602 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49566 .49392 m
.49593 .4942 L
s
% Start of user PostScript
-0.13026653 -0.18227834 -0.12210515 -0.17392992 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49737 .49591 m
.49753 .49612 L
s
% Start of user PostScript
-0.078789907 -0.12269258 -0.074135191 -0.11646951 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49837 .49733 m
.49847 .49747 L
s
% Start of user PostScript
-0.04879578 -0.080139241 -0.046007038 -0.075893429 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49898 .49828 m
.49904 .49837 L
s
% Start of user PostScript
-0.030600765 -0.051611009 -0.028882534 -0.048820662 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49936 .4989 m
.49939 .49896 L
s
% Start of user PostScript
-0.019314465 -0.033011587 -0.018239824 -0.03120927 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49959 .4993 m
.49961 .49934 L
s
% Start of user PostScript
-0.012230791 -0.02104388 -0.011553435 -0.019889419 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49974 .49955 m
.49976 .49958 L
s
% Start of user PostScript
-0.0077578733 -0.013392392 -0.0073292391 -0.012655936 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49984 .49972 m
.49984 .49973 L
s
% Start of user PostScript
-0.0049248205 -0.0085158542 -0.0046530369 -0.0080470051 MAarrowhead1
% End of user PostScript
0 .06 1 r
.4999 .49982 m
.4999 .49983 L
s
% Start of user PostScript
-0.0031276511 -0.005412743 -0.0029551489 -0.0051145622 MAarrowhead1
% End of user PostScript
1 0 .968 r
.80046 .53995 m
.77303 .55658 L
.74856 .56977 L
.72669 .58007 L
.70712 .5879 L
.68958 .59367 L
.67382 .59771 L
.65964 .60029 L
.64685 .60167 L
.6353 .60205 L
.62485 .60161 L
.61537 .6005 L
.60677 .59885 L
.59893 .59678 L
.59179 .59437 L
.58527 .5917 L
.5793 .58884 L
.57383 .58584 L
.56881 .58276 L
.5642 .57962 L
.55994 .57647 L
.55602 .57333 L
.5524 .57022 L
.54904 .56715 L
.54594 .56415 L
.54306 .56122 L
.54038 .55836 L
.53789 .5556 L
.53558 .55293 L
.53342 .55035 L
.53141 .54787 L
.52953 .54549 L
.52777 .5432 L
.52613 .54101 L
.52459 .53892 L
.52316 .53692 L
.52181 .53501 L
.52054 .53319 L
.51936 .53145 L
.51824 .5298 L
.5172 .52823 L
.51621 .52673 L
.51529 .52531 L
.51442 .52396 L
.5136 .52268 L
.51283 .52147 L
.51211 .52031 L
.51143 .51922 L
.51078 .51818 L
.51018 .5172 L
Mistroke
.50961 .51627 L
.50907 .51538 L
.50856 .51455 L
.50808 .51376 L
.50763 .51301 L
.50721 .5123 L
.50681 .51163 L
.50643 .51099 L
.50607 .51039 L
.50573 .50983 L
.50541 .50929 L
.50511 .50878 L
.50483 .5083 L
.50456 .50784 L
.50431 .50741 L
.50407 .50701 L
.50385 .50662 L
.50363 .50626 L
.50343 .50592 L
.50324 .50559 L
.50306 .50528 L
.50289 .50499 L
.50273 .50472 L
.50258 .50446 L
.50244 .50421 L
.5023 .50398 L
.50218 .50376 L
.50206 .50356 L
.50194 .50336 L
.50184 .50318 L
.50174 .503 L
.50164 .50284 L
.50155 .50268 L
.50146 .50253 L
.50138 .50239 L
.50131 .50226 L
.50123 .50214 L
.50117 .50202 L
.5011 .50191 L
.50104 .5018 L
.50098 .5017 L
.50093 .50161 L
.50088 .50152 L
.50083 .50144 L
.50078 .50136 L
.50074 .50128 L
.5007 .50121 L
.50066 .50115 L
.50062 .50108 L
.50059 .50102 L
Mistroke
.50056 .50097 L
.50053 .50091 L
.5005 .50086 L
.50047 .50081 L
.50044 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50035 .50061 L
.50033 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
Mistroke
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.80046 .53995 m
.77303 .55658 L
s
% Start of user PostScript
9.013786 1.1984082 8.1907759 1.6972733 MAarrowhead1
% End of user PostScript
1 .158 0 r
.74856 .56977 m
.72669 .58007 L
s
% Start of user PostScript
7.4566756 2.0932191 6.8007709 2.401988 MAarrowhead1
% End of user PostScript
1 .473 0 r
.62485 .60161 m
.61537 .6005 L
s
% Start of user PostScript
3.7454423 3.0482913 3.4611708 3.01505 MAarrowhead1
% End of user PostScript
1 .788 0 r
.56881 .58276 m
.5642 .57962 L
s
% Start of user PostScript
2.0643745 2.48277 1.9258549 2.3887477 MAarrowhead1
% End of user PostScript
.897 1 0 r
.54038 .55836 m
.53789 .5556 L
s
% Start of user PostScript
1.2114023 1.7509353 1.1367701 1.6680321 MAarrowhead1
% End of user PostScript
.581 1 0 r
.52459 .53892 m
.52316 .53692 L
s
% Start of user PostScript
0.73782023 1.1675866 0.69465349 1.1075529 MAarrowhead1
% End of user PostScript
.266 1 0 r
.51529 .52531 m
.51442 .52396 L
s
% Start of user PostScript
0.4586524 0.75934099 0.43257735 0.71885954 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50961 .51627 m
.50907 .51538 L
s
% Start of user PostScript
0.28818687 0.48801047 0.27204947 0.46154745 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50607 .51039 m
.50573 .50983 L
s
% Start of user PostScript
0.18207599 0.31182363 0.17195959 0.29477429 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50385 .50662 m
.50363 .50626 L
s
% Start of user PostScript
0.11535612 0.19867734 0.10897207 0.18777009 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50244 .50421 m
.5023 .50398 L
s
% Start of user PostScript
0.07318757 0.12640699 0.069145284 0.11945329 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50155 .50268 m
.50146 .50253 L
s
% Start of user PostScript
0.046466448 0.080368613 0.043902585 0.075943043 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50098 .5017 m
.50093 .50161 L
s
% Start of user PostScript
0.029511728 0.051079701 0.027884186 0.048265536 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50062 .50108 m
.50059 .50102 L
s
% Start of user PostScript
0.018746767 0.032458878 0.017713161 0.030670152 MAarrowhead1
% End of user PostScript
1 .641 0 r
.45378 .36949 m
.45519 .37866 L
.45667 .38706 L
.4582 .39477 L
.45976 .40186 L
.46133 .40838 L
.46291 .4144 L
.46447 .41995 L
.46601 .42509 L
.46752 .42985 L
.469 .43426 L
.47043 .43836 L
.47183 .44216 L
.47317 .44571 L
.47448 .44901 L
.47573 .45208 L
.47693 .45495 L
.47809 .45764 L
.4792 .46014 L
.48026 .46249 L
.48127 .46469 L
.48224 .46675 L
.48316 .46868 L
.48404 .47049 L
.48488 .47219 L
.48568 .47379 L
.48643 .47529 L
.48715 .4767 L
.48784 .47802 L
.48849 .47927 L
.4891 .48044 L
.48969 .48155 L
.49024 .48259 L
.49077 .48357 L
.49127 .48449 L
.49174 .48536 L
.49219 .48618 L
.49261 .48695 L
.49301 .48768 L
.49339 .48837 L
.49375 .48902 L
.4941 .48963 L
.49442 .49021 L
.49472 .49075 L
.49501 .49127 L
.49528 .49175 L
.49554 .49221 L
.49579 .49264 L
.49602 .49305 L
.49624 .49343 L
Mistroke
.49644 .4938 L
.49664 .49414 L
.49682 .49447 L
.497 .49477 L
.49716 .49506 L
.49732 .49533 L
.49746 .49559 L
.4976 .49584 L
.49774 .49607 L
.49786 .49628 L
.49798 .49649 L
.49809 .49668 L
.49819 .49687 L
.49829 .49704 L
.49839 .4972 L
.49848 .49736 L
.49856 .4975 L
.49864 .49764 L
.49871 .49777 L
.49879 .49789 L
.49885 .49801 L
.49892 .49812 L
.49898 .49822 L
.49903 .49832 L
.49908 .49841 L
.49914 .4985 L
.49918 .49858 L
.49923 .49866 L
.49927 .49874 L
.49931 .49881 L
.49935 .49887 L
.49938 .49893 L
.49942 .49899 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
.49956 .49924 L
.49959 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49977 .49959 L
.49978 .49962 L
Mistroke
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.45378 .36949 m
.45519 .37866 L
s
% Start of user PostScript
-1.3866054 -3.9153263 -1.3444249 -3.6401839 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45667 .38706 m
.4582 .39477 L
s
% Start of user PostScript
-1.2999967 -3.388128 -1.2540552 -3.1568285 MAarrowhead1
% End of user PostScript
1 .473 0 r
.469 .43426 m
.47043 .43836 L
s
% Start of user PostScript
-0.9301286 -1.9721716 -0.88703061 -1.8493087 MAarrowhead1
% End of user PostScript
1 .788 0 r
.4792 .46014 m
.48026 .46249 L
s
% Start of user PostScript
-0.62405821 -1.1956625 -0.59225614 -1.1252581 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48643 .47529 m
.48715 .4767 L
s
% Start of user PostScript
-0.40701186 -0.74143376 -0.38540205 -0.69913565 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49127 .48449 m
.49174 .48536 L
s
% Start of user PostScript
-0.26193546 -0.46527434 -0.24775947 -0.43917361 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49442 .49021 m
.49472 .49075 L
s
% Start of user PostScript
-0.16748133 -0.2937688 -0.15833287 -0.27743155 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49644 .4938 m
.49664 .49414 L
s
% Start of user PostScript
-0.10674574 -0.18605929 -0.10088825 -0.17575759 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49774 .49607 m
.49786 .49628 L
s
% Start of user PostScript
-0.067927467 -0.1180257 -0.064191631 -0.11150539 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49856 .4975 m
.49864 .49764 L
s
% Start of user PostScript
-0.043191351 -0.074927787 -0.040813261 -0.070793038 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49908 .49841 m
.49914 .4985 L
s
% Start of user PostScript
-0.027452167 -0.047586101 -0.025939818 -0.044961621 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49942 .49899 m
.49945 .49905 L
s
% Start of user PostScript
-0.017444993 -0.030227547 -0.016483672 -0.028560897 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49963 .49936 m
.49965 .4994 L
s
% Start of user PostScript
-0.011084653 -0.019202974 -0.010473738 -0.018144332 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49977 .49959 m
.49978 .49962 L
s
% Start of user PostScript
-0.0070429071 -0.012199878 -0.0066547201 -0.011527358 MAarrowhead1
% End of user PostScript
1 0 .882 r
.7328 .41283 m
.70887 .43686 L
.68774 .45699 L
.66906 .47379 L
.65253 .48774 L
.63786 .49925 L
.62484 .50868 L
.61327 .51634 L
.60295 .52249 L
.59375 .52735 L
.58553 .53114 L
.57817 .53401 L
.57156 .53611 L
.56563 .53756 L
.56029 .53847 L
.55548 .53894 L
.55112 .53903 L
.54719 .53882 L
.54361 .53836 L
.54037 .5377 L
.53741 .53689 L
.53472 .53595 L
.53226 .53492 L
.53001 .53381 L
.52794 .53266 L
.52605 .53148 L
.5243 .53028 L
.52269 .52907 L
.52121 .52787 L
.51984 .52668 L
.51857 .52551 L
.5174 .52437 L
.51631 .52325 L
.5153 .52216 L
.51436 .52111 L
.51348 .5201 L
.51266 .51912 L
.5119 .51817 L
.51119 .51727 L
.51053 .5164 L
.5099 .51557 L
.50932 .51477 L
.50878 .51401 L
.50827 .51328 L
.50779 .51259 L
.50734 .51193 L
.50692 .51131 L
.50652 .51071 L
.50615 .51014 L
.5058 .5096 L
Mistroke
.50547 .50909 L
.50516 .5086 L
.50487 .50814 L
.50459 .5077 L
.50433 .50729 L
.50409 .5069 L
.50386 .50652 L
.50364 .50617 L
.50344 .50584 L
.50325 .50552 L
.50307 .50522 L
.50289 .50493 L
.50273 .50467 L
.50258 .50441 L
.50244 .50417 L
.5023 .50394 L
.50217 .50373 L
.50205 .50352 L
.50194 .50333 L
.50183 .50315 L
.50173 .50298 L
.50163 .50281 L
.50154 .50266 L
.50146 .50251 L
.50138 .50237 L
.5013 .50224 L
.50123 .50212 L
.50116 .502 L
.5011 .50189 L
.50104 .50179 L
.50098 .50169 L
.50093 .5016 L
.50087 .50151 L
.50083 .50143 L
.50078 .50135 L
.50074 .50127 L
.5007 .5012 L
.50066 .50114 L
.50062 .50108 L
.50059 .50102 L
.50056 .50096 L
.50052 .50091 L
.5005 .50086 L
.50047 .50081 L
.50044 .50077 L
.50042 .50072 L
.50039 .50068 L
.50037 .50065 L
.50035 .50061 L
.50033 .50058 L
Mistroke
.50031 .50054 L
.5003 .50051 L
.50028 .50049 L
.50027 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
Mistroke
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.7328 .41283 m
.70887 .43686 L
s
% Start of user PostScript
6.9840519 -2.6149771 6.2661852 -1.8942423 MAarrowhead1
% End of user PostScript
1 .158 0 r
.68774 .45699 m
.66906 .47379 L
s
% Start of user PostScript
5.6323322 -1.2902146 5.0719285 -0.78618374 MAarrowhead1
% End of user PostScript
1 .473 0 r
.58553 .53114 m
.57817 .53401 L
s
% Start of user PostScript
2.5658617 0.93415012 2.3450026 1.0202275 MAarrowhead1
% End of user PostScript
1 .788 0 r
.54361 .53836 m
.54037 .5377 L
s
% Start of user PostScript
1.3084227 1.1508458 1.2110612 1.1311258 MAarrowhead1
% End of user PostScript
.897 1 0 r
.5243 .53028 m
.52269 .52907 L
s
% Start of user PostScript
0.72904365 0.9082911 0.68083732 0.87211679 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51436 .52111 m
.51348 .5201 L
s
% Start of user PostScript
0.4306992 0.63335752 0.40440978 0.60286052 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50878 .51401 m
.50827 .51328 L
s
% Start of user PostScript
0.26331611 0.42028412 0.24799186 0.39852033 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50547 .50909 m
.50516 .5086 L
s
% Start of user PostScript
0.16401486 0.272708 0.15471677 0.25812176 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50344 .50584 m
.50325 .50552 L
s
% Start of user PostScript
0.10316303 0.17506921 0.097394763 0.16556083 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50217 .50373 m
.50205 .50352 L
s
% Start of user PostScript
0.065212592 0.11180296 0.061591999 0.10568525 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50138 .50237 m
.5013 .50224 L
s
% Start of user PostScript
0.041327088 0.07121563 0.039040826 0.067304436 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50087 .50151 m
.50083 .50143 L
s
% Start of user PostScript
0.026223428 0.045304325 0.024775333 0.042811637 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50056 .50096 m
.50052 .50091 L
s
% Start of user PostScript
0.016650246 0.028802215 0.015731628 0.027216043 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50035 .50061 m
.50033 .50058 L
s
% Start of user PostScript
0.010575243 0.018305146 0.0099920565 0.017296601 MAarrowhead1
% End of user PostScript
1 0 .675 r
.36243 .51786 m
.37581 .50683 L
.38768 .49776 L
.39822 .49034 L
.4076 .48435 L
.41596 .47955 L
.42342 .47577 L
.4301 .47286 L
.43608 .47067 L
.44144 .4691 L
.44627 .46804 L
.45061 .46741 L
.45453 .46713 L
.45808 .46714 L
.46129 .46739 L
.4642 .46784 L
.46685 .46844 L
.46926 .46917 L
.47146 .46999 L
.47347 .47088 L
.47532 .47183 L
.47701 .47281 L
.47856 .47381 L
.47999 .47483 L
.48131 .47584 L
.48252 .47685 L
.48365 .47785 L
.48469 .47883 L
.48565 .47979 L
.48655 .48072 L
.48738 .48162 L
.48816 .4825 L
.48888 .48335 L
.48955 .48416 L
.49018 .48495 L
.49076 .4857 L
.49131 .48642 L
.49182 .48711 L
.4923 .48777 L
.49275 .4884 L
.49317 .48901 L
.49357 .48958 L
.49394 .49013 L
.49429 .49065 L
.49461 .49114 L
.49492 .49161 L
.49521 .49206 L
.49548 .49248 L
.49574 .49288 L
.49598 .49326 L
Mistroke
.49621 .49363 L
.49642 .49397 L
.49662 .4943 L
.49681 .4946 L
.49699 .4949 L
.49716 .49517 L
.49732 .49544 L
.49747 .49568 L
.49761 .49592 L
.49774 .49614 L
.49787 .49635 L
.49799 .49655 L
.4981 .49674 L
.4982 .49692 L
.4983 .49709 L
.4984 .49725 L
.49849 .4974 L
.49857 .49754 L
.49865 .49768 L
.49872 .4978 L
.49879 .49792 L
.49886 .49804 L
.49892 .49815 L
.49898 .49825 L
.49904 .49834 L
.49909 .49843 L
.49914 .49852 L
.49919 .4986 L
.49924 .49868 L
.49928 .49875 L
.49932 .49882 L
.49935 .49889 L
.49939 .49895 L
.49942 .499 L
.49946 .49906 L
.49949 .49911 L
.49951 .49916 L
.49954 .49921 L
.49957 .49925 L
.49959 .49929 L
.49961 .49933 L
.49963 .49937 L
.49965 .4994 L
.49967 .49944 L
.49969 .49947 L
.49971 .4995 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .4996 L
Mistroke
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49983 .4997 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49988 .49978 L
.49988 .4998 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.36243 .51786 m
.37581 .50683 L
s
% Start of user PostScript
-4.1271437 0.53569059 -3.725774 0.2050003 MAarrowhead1
% End of user PostScript
1 .158 0 r
.38768 .49776 m
.39822 .49034 L
s
% Start of user PostScript
-3.369742 -0.067254634 -3.0534494 -0.28966319 MAarrowhead1
% End of user PostScript
1 .473 0 r
.44627 .46804 m
.45061 .46741 L
s
% Start of user PostScript
-1.6120476 -0.95880323 -1.4817045 -0.97780677 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47146 .46999 m
.47347 .47088 L
s
% Start of user PostScript
-0.85613368 -0.90027487 -0.79575957 -0.87348399 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48365 .47785 m
.48469 .47883 L
s
% Start of user PostScript
-0.49053026 -0.66448983 -0.45930239 -0.63511819 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49018 .48495 m
.49076 .4857 L
s
% Start of user PostScript
-0.29468319 -0.45157536 -0.27710864 -0.42898969 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49394 .49013 m
.49429 .49065 L
s
% Start of user PostScript
-0.18183172 -0.29624677 -0.17138589 -0.28064997 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49621 .49363 m
.49642 .49397 L
s
% Start of user PostScript
-0.11381172 -0.19118686 -0.10740384 -0.18088123 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49761 .49592 m
.49774 .49614 L
s
% Start of user PostScript
-0.071764891 -0.12241259 -0.067766398 -0.11573904 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49849 .4974 m
.49857 .49754 L
s
% Start of user PostScript
-0.045422274 -0.078073775 -0.042904964 -0.073793759 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49904 .49834 m
.49909 .49843 L
s
% Start of user PostScript
-0.02880374 -0.049698904 -0.027211727 -0.046966907 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49939 .49895 m
.49942 .499 L
s
% Start of user PostScript
-0.018282786 -0.031606135 -0.017273644 -0.029866337 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49961 .49933 m
.49963 .49937 L
s
% Start of user PostScript
-0.011610292 -0.020090364 -0.010969881 -0.018983711 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49975 .49957 m
.49977 .4996 L
s
% Start of user PostScript
-0.0073747559 -0.012767334 -0.0069681112 -0.012063822 MAarrowhead1
% End of user PostScript
0 .704 1 r
.53109 .21247 m
.52165 .2417 L
.51377 .26753 L
.50721 .29039 L
.50179 .31065 L
.49733 .32863 L
.49371 .34461 L
.49078 .35884 L
.48846 .37153 L
.48664 .38286 L
.48525 .393 L
.48422 .40209 L
.48349 .41025 L
.48302 .4176 L
.48276 .42422 L
.48267 .43019 L
.48272 .4356 L
.48289 .4405 L
.48316 .44495 L
.4835 .449 L
.48391 .45269 L
.48435 .45606 L
.48483 .45914 L
.48534 .46197 L
.48586 .46456 L
.48639 .46694 L
.48693 .46914 L
.48746 .47116 L
.48799 .47303 L
.48852 .47476 L
.48903 .47636 L
.48953 .47784 L
.49001 .47922 L
.49049 .4805 L
.49094 .4817 L
.49138 .48281 L
.49181 .48384 L
.49221 .48481 L
.4926 .48572 L
.49298 .48656 L
.49334 .48735 L
.49368 .48809 L
.49401 .48879 L
.49432 .48944 L
.49461 .49005 L
.4949 .49062 L
.49517 .49116 L
.49542 .49166 L
.49566 .49214 L
.4959 .49259 L
Mistroke
.49612 .49301 L
.49632 .4934 L
.49652 .49378 L
.49671 .49413 L
.49689 .49446 L
.49705 .49477 L
.49721 .49506 L
.49736 .49534 L
.49751 .4956 L
.49764 .49584 L
.49777 .49608 L
.49789 .4963 L
.49801 .4965 L
.49812 .4967 L
.49822 .49688 L
.49832 .49705 L
.49841 .49722 L
.4985 .49737 L
.49858 .49752 L
.49866 .49766 L
.49873 .49778 L
.4988 .49791 L
.49887 .49802 L
.49893 .49813 L
.49899 .49824 L
.49904 .49833 L
.49909 .49843 L
.49914 .49851 L
.49919 .4986 L
.49924 .49867 L
.49928 .49875 L
.49932 .49882 L
.49936 .49888 L
.49939 .49894 L
.49942 .499 L
.49946 .49906 L
.49949 .49911 L
.49951 .49916 L
.49954 .4992 L
.49957 .49925 L
.49959 .49929 L
.49961 .49933 L
.49963 .49937 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
Mistroke
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .4997 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49988 .49978 L
.49988 .4998 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.53109 .21247 m
.52165 .2417 L
s
% Start of user PostScript
0.93278171 -8.6258224 0.64962203 -7.7489642 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51377 .26753 m
.50721 .29039 L
s
% Start of user PostScript
0.41300987 -6.9740282 0.21624884 -6.2882418 MAarrowhead1
% End of user PostScript
1 .473 0 r
.48525 .393 m
.48422 .40209 L
s
% Start of user PostScript
-0.4425128 -3.2099518 -0.47341238 -2.9372475 MAarrowhead1
% End of user PostScript
1 .788 0 r
.48316 .44495 m
.4835 .449 L
s
% Start of user PostScript
-0.50515251 -1.6514333 -0.49487811 -1.5299715 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48693 .46914 m
.48746 .47116 L
s
% Start of user PostScript
-0.39212854 -0.92593397 -0.3760973 -0.86522454 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49094 .4817 m
.49138 .48281 L
s
% Start of user PostScript
-0.27175653 -0.5491064 -0.25855122 -0.51576582 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49401 .48879 m
.49432 .48944 L
s
% Start of user PostScript
-0.17984686 -0.33642077 -0.17049729 -0.31690025 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49612 .49301 m
.49632 .4934 L
s
% Start of user PostScript
-0.11654872 -0.20978628 -0.11030357 -0.19791225 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49751 .4956 m
.49764 .49584 L
s
% Start of user PostScript
-0.074774317 -0.13202905 -0.070709594 -0.12465282 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49841 .49722 m
.4985 .49737 L
s
% Start of user PostScript
-0.047738024 -0.083484249 -0.045124734 -0.078851151 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49899 .49824 m
.49904 .49833 L
s
% Start of user PostScript
-0.030403332 -0.052914198 -0.02873321 -0.04998754 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49936 .49888 m
.49939 .49894 L
s
% Start of user PostScript
-0.019339845 -0.033578335 -0.018275634 -0.031724289 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49959 .49929 m
.49961 .49933 L
s
% Start of user PostScript
-0.012294842 -0.021320949 -0.011617715 -0.020144705 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49974 .49955 m
.49975 .49957 L
s
% Start of user PostScript
-0.0078137975 -0.013542048 -0.0073832752 -0.012795273 MAarrowhead1
% End of user PostScript
1 .108 0 r
.24716 .75104 m
.27668 .7102 L
.3025 .67522 L
.32509 .64528 L
.34488 .61971 L
.36222 .59789 L
.37743 .5793 L
.39078 .5635 L
.40252 .5501 L
.41285 .53876 L
.42194 .52918 L
.42997 .52113 L
.43705 .51439 L
.44331 .50876 L
.44886 .50408 L
.45377 .50023 L
.45814 .49707 L
.46202 .4945 L
.46548 .49244 L
.46856 .49081 L
.47132 .48954 L
.47379 .48858 L
.476 .48788 L
.47799 .48739 L
.47978 .48709 L
.4814 .48693 L
.48285 .4869 L
.48418 .48697 L
.48537 .48713 L
.48646 .48735 L
.48745 .48762 L
.48836 .48794 L
.48918 .48829 L
.48994 .48866 L
.49063 .48904 L
.49126 .48944 L
.49185 .48984 L
.49239 .49025 L
.49289 .49065 L
.49335 .49105 L
.49377 .49144 L
.49416 .49183 L
.49453 .4922 L
.49487 .49257 L
.49518 .49292 L
.49548 .49326 L
.49575 .49359 L
.49601 .4939 L
.49625 .49421 L
.49647 .4945 L
Mistroke
.49668 .49478 L
.49687 .49505 L
.49706 .4953 L
.49723 .49554 L
.49739 .49578 L
.49754 .496 L
.49768 .49621 L
.49781 .49641 L
.49794 .4966 L
.49806 .49678 L
.49817 .49695 L
.49827 .49711 L
.49837 .49727 L
.49846 .49742 L
.49855 .49755 L
.49863 .49769 L
.49871 .49781 L
.49878 .49793 L
.49885 .49804 L
.49891 .49815 L
.49897 .49825 L
.49903 .49834 L
.49908 .49844 L
.49913 .49852 L
.49918 .4986 L
.49923 .49868 L
.49927 .49875 L
.49931 .49882 L
.49935 .49888 L
.49939 .49894 L
.49942 .499 L
.49945 .49906 L
.49948 .49911 L
.49951 .49916 L
.49954 .4992 L
.49956 .49925 L
.49959 .49929 L
.49961 .49933 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
Mistroke
.49981 .49968 L
.49982 .4997 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .4998 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.24716 .75104 m
.27668 .7102 L
s
% Start of user PostScript
-7.5852747 7.5312255 -6.6994592 6.3060054 MAarrowhead1
% End of user PostScript
1 .158 0 r
.3025 .67522 m
.32509 .64528 L
s
% Start of user PostScript
-5.924913 5.2564736 -5.2471663 4.3585068 MAarrowhead1
% End of user PostScript
1 .473 0 r
.42194 .52918 m
.42997 .52113 L
s
% Start of user PostScript
-2.3416913 0.87554173 -2.1010249 0.63400233 MAarrowhead1
% End of user PostScript
1 .788 0 r
.46548 .49244 m
.46856 .49081 L
s
% Start of user PostScript
-1.0356906 -0.22676847 -0.94314164 -0.27568783 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48285 .4869 m
.48418 .48697 L
s
% Start of user PostScript
-0.51435683 -0.39290611 -0.47473638 -0.3907661 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49063 .48904 m
.49126 .48944 L
s
% Start of user PostScript
-0.28114082 -0.32870242 -0.26206314 -0.31678609 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49453 .4922 m
.49487 .49257 L
s
% Start of user PostScript
-0.16411373 -0.23396607 -0.15392967 -0.22304045 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49668 .49478 m
.49687 .49505 L
s
% Start of user PostScript
-0.099658526 -0.15663357 -0.093803621 -0.14862603 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49794 .4966 m
.49806 .49678 L
s
% Start of user PostScript
-0.06185242 -0.10205346 -0.058328127 -0.096627166 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49871 .49781 m
.49878 .49793 L
s
% Start of user PostScript
-0.038831992 -0.065645297 -0.036655007 -0.062090087 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49918 .4986 m
.49923 .49868 L
s
% Start of user PostScript
-0.024523712 -0.041963525 -0.023160329 -0.039670538 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49948 .49911 m
.49951 .49916 L
s
% Start of user PostScript
-0.015533966 -0.026742666 -0.014674026 -0.025274962 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49967 .49943 m
.49969 .49946 L
s
% Start of user PostScript
-0.0098544623 -0.017016647 -0.0093100997 -0.016080697 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49979 .49964 m
.4998 .49966 L
s
% Start of user PostScript
-0.0062562193 -0.010819635 -0.0059109959 -0.010223887 MAarrowhead1
% End of user PostScript
.263 0 1 r
.23542 .51161 m
.26064 .49256 L
.28304 .47701 L
.30298 .46445 L
.32076 .45443 L
.33664 .44656 L
.35083 .44051 L
.36356 .436 L
.37498 .43277 L
.38525 .43062 L
.3945 .42938 L
.40285 .42888 L
.4104 .42899 L
.41725 .4296 L
.42346 .43063 L
.42911 .43197 L
.43426 .43358 L
.43895 .43538 L
.44325 .43733 L
.44718 .43939 L
.45079 .44152 L
.45411 .44369 L
.45716 .44589 L
.45998 .44808 L
.46258 .45026 L
.46498 .45241 L
.46721 .45453 L
.46927 .45659 L
.47119 .4586 L
.47297 .46055 L
.47463 .46243 L
.47617 .46425 L
.47761 .46601 L
.47895 .46769 L
.4802 .46931 L
.48138 .47086 L
.48247 .47235 L
.4835 .47376 L
.48446 .47512 L
.48537 .47641 L
.48621 .47764 L
.48701 .47881 L
.48775 .47993 L
.48845 .48099 L
.48911 .482 L
.48973 .48296 L
.49031 .48387 L
.49086 .48473 L
.49138 .48555 L
.49187 .48633 L
Mistroke
.49232 .48707 L
.49275 .48777 L
.49316 .48843 L
.49354 .48906 L
.49391 .48965 L
.49425 .49021 L
.49457 .49074 L
.49487 .49125 L
.49516 .49173 L
.49543 .49218 L
.49568 .4926 L
.49592 .49301 L
.49615 .49339 L
.49636 .49375 L
.49656 .4941 L
.49675 .49442 L
.49693 .49472 L
.4971 .49501 L
.49726 .49529 L
.49741 .49555 L
.49756 .49579 L
.49769 .49602 L
.49782 .49624 L
.49794 .49645 L
.49805 .49664 L
.49816 .49683 L
.49826 .497 L
.49836 .49717 L
.49845 .49732 L
.49854 .49747 L
.49862 .49761 L
.49869 .49774 L
.49877 .49786 L
.49883 .49798 L
.4989 .49809 L
.49896 .4982 L
.49902 .4983 L
.49907 .49839 L
.49912 .49848 L
.49917 .49856 L
.49922 .49864 L
.49926 .49872 L
.4993 .49879 L
.49934 .49886 L
.49938 .49892 L
.49941 .49898 L
.49944 .49903 L
.49947 .49909 L
.4995 .49914 L
.49953 .49919 L
Mistroke
.49956 .49923 L
.49958 .49927 L
.4996 .49931 L
.49962 .49935 L
.49965 .49939 L
.49967 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
Mistroke
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.23542 .51161 m
.26064 .49256 L
s
% Start of user PostScript
-7.9374295 0.34844938 -7.1809328 -0.22323892 MAarrowhead1
% End of user PostScript
1 .158 0 r
.28304 .47701 m
.30298 .46445 L
s
% Start of user PostScript
-6.5087206 -0.68965488 -5.9104615 -1.0664487 MAarrowhead1
% End of user PostScript
1 .473 0 r
.3945 .42938 m
.40285 .42888 L
s
% Start of user PostScript
-3.1650152 -2.1187014 -2.9144514 -2.1337317 MAarrowhead1
% End of user PostScript
1 .788 0 r
.44325 .43733 m
.44718 .43939 L
s
% Start of user PostScript
-1.7025474 -1.8801351 -1.5845167 -1.8183875 MAarrowhead1
% End of user PostScript
.897 1 0 r
.46721 .45453 m
.46927 .45659 L
s
% Start of user PostScript
-0.98372427 -1.3642336 -0.92181502 -1.3023462 MAarrowhead1
% End of user PostScript
.581 1 0 r
.4802 .46931 m
.48138 .47086 L
s
% Start of user PostScript
-0.59386767 -0.92068391 -0.55869078 -0.8741645 MAarrowhead1
% End of user PostScript
.266 1 0 r
.48775 .47993 m
.48845 .48099 L
s
% Start of user PostScript
-0.36741592 -0.60208709 -0.34638742 -0.57024342 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49232 .48707 m
.49275 .48777 L
s
% Start of user PostScript
-0.23029119 -0.38797763 -0.21735063 -0.36701893 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49516 .49173 m
.49543 .49218 L
s
% Start of user PostScript
-0.14531486 -0.24822947 -0.13722655 -0.23468247 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49693 .49472 m
.4971 .49501 L
s
% Start of user PostScript
-0.092007327 -0.15826083 -0.08691086 -0.14958042 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49805 .49664 m
.49816 .49683 L
s
% Start of user PostScript
-0.058355346 -0.1007247 -0.055130809 -0.09518633 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49877 .49786 m
.49883 .49798 L
s
% Start of user PostScript
-0.037043616 -0.064050292 -0.034999209 -0.060524111 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49922 .49864 m
.49926 .49872 L
s
% Start of user PostScript
-0.023525224 -0.040711568 -0.022227684 -0.038468877 MAarrowhead1
% End of user PostScript
0 .06 1 r
.4995 .49914 m
.49953 .49919 L
s
% Start of user PostScript
-0.014943355 -0.025871429 -0.014119404 -0.024445801 MAarrowhead1
% End of user PostScript
0 1 .723 r
.21561 .465 m
.24164 .44899 L
.26486 .43626 L
.28559 .42631 L
.30415 .41871 L
.32078 .41308 L
.33571 .40911 L
.34915 .40653 L
.36126 .40511 L
.3722 .40464 L
.3821 .40496 L
.39107 .40592 L
.39921 .4074 L
.40662 .40929 L
.41338 .4115 L
.41954 .41397 L
.42519 .41662 L
.43035 .41941 L
.4351 .42228 L
.43946 .4252 L
.44348 .42815 L
.44718 .43109 L
.45061 .434 L
.45377 .43687 L
.4567 .43969 L
.45942 .44244 L
.46195 .44511 L
.46429 .44771 L
.46648 .45021 L
.46851 .45263 L
.47041 .45496 L
.47218 .4572 L
.47384 .45935 L
.47539 .46141 L
.47683 .46338 L
.47819 .46526 L
.47946 .46705 L
.48065 .46877 L
.48177 .4704 L
.48282 .47195 L
.48381 .47343 L
.48473 .47484 L
.4856 .47618 L
.48642 .47745 L
.48719 .47865 L
.48792 .47979 L
.4886 .48088 L
.48924 .48191 L
.48985 .48289 L
.49042 .48381 L
Mistroke
.49095 .48469 L
.49146 .48552 L
.49194 .4863 L
.49239 .48705 L
.49281 .48775 L
.49321 .48842 L
.49359 .48905 L
.49395 .48965 L
.49429 .49021 L
.4946 .49075 L
.4949 .49126 L
.49519 .49173 L
.49545 .49219 L
.4957 .49262 L
.49594 .49302 L
.49617 .4934 L
.49638 .49377 L
.49658 .49411 L
.49677 .49443 L
.49695 .49474 L
.49712 .49503 L
.49728 .4953 L
.49743 .49556 L
.49757 .4958 L
.4977 .49603 L
.49783 .49625 L
.49795 .49646 L
.49806 .49665 L
.49817 .49684 L
.49827 .49701 L
.49837 .49718 L
.49846 .49733 L
.49854 .49748 L
.49862 .49762 L
.4987 .49775 L
.49877 .49787 L
.49884 .49799 L
.4989 .4981 L
.49896 .4982 L
.49902 .4983 L
.49907 .4984 L
.49912 .49849 L
.49917 .49857 L
.49922 .49865 L
.49926 .49872 L
.4993 .49879 L
.49934 .49886 L
.49938 .49892 L
.49941 .49898 L
.49944 .49904 L
Mistroke
.49947 .49909 L
.4995 .49914 L
.49953 .49919 L
.49956 .49923 L
.49958 .49928 L
.4996 .49931 L
.49963 .49935 L
.49965 .49939 L
.49967 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49978 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
Mistroke
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.21561 .465 m
.24164 .44899 L
s
% Start of user PostScript
-8.5315584 -1.0501112 -7.7506735 -1.5302272 MAarrowhead1
% End of user PostScript
1 .158 0 r
.26486 .43626 m
.28559 .42631 L
s
% Start of user PostScript
-7.0543012 -1.912052 -6.4322466 -2.2105927 MAarrowhead1
% End of user PostScript
1 .473 0 r
.3821 .40496 m
.39107 .40592 L
s
% Start of user PostScript
-3.5370787 -2.8512927 -3.2680012 -2.8224865 MAarrowhead1
% End of user PostScript
1 .788 0 r
.4351 .42228 m
.43946 .4252 L
s
% Start of user PostScript
-1.9470172 -2.3315839 -1.816145 -2.2438539 MAarrowhead1
% End of user PostScript
.897 1 0 r
.46195 .44511 m
.46429 .44771 L
s
% Start of user PostScript
-1.1416148 -1.6466103 -1.0712038 -1.568809 MAarrowhead1
% End of user PostScript
.581 1 0 r
.47683 .46338 m
.47819 .46526 L
s
% Start of user PostScript
-0.69499846 -1.0986765 -0.65431112 -1.042235 MAarrowhead1
% End of user PostScript
.266 1 0 r
.4856 .47618 m
.48642 .47745 L
s
% Start of user PostScript
-0.43192802 -0.7147243 -0.40736388 -0.67663669 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49095 .48469 m
.49146 .48552 L
s
% Start of user PostScript
-0.27136093 -0.45939818 -0.25616302 -0.43449149 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49429 .49021 m
.4946 .49075 L
s
% Start of user PostScript
-0.17143443 -0.29356068 -0.16190843 -0.2775114 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49638 .49377 m
.49658 .49411 L
s
% Start of user PostScript
-0.10861054 -0.18704729 -0.10259954 -0.176779 MAarrowhead1
% End of user PostScript
0 1 .995 r
.4977 .49603 m
.49783 .49625 L
s
% Start of user PostScript
-0.068906733 -0.11900941 -0.065100798 -0.1124628 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49854 .49748 m
.49862 .49762 L
s
% Start of user PostScript
-0.043748209 -0.075665901 -0.041334302 -0.071499339 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49907 .4984 m
.49912 .49849 L
s
% Start of user PostScript
-0.027785209 -0.048091005 -0.026252874 -0.045441513 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49941 .49898 m
.49944 .49904 L
s
% Start of user PostScript
-0.017649993 -0.030559757 -0.016676855 -0.028875691 MAarrowhead1
% End of user PostScript
.734 1 0 r
.34881 .31542 m
.3589 .32257 L
.36819 .32972 L
.37677 .33683 L
.3847 .34386 L
.39204 .35076 L
.39884 .3575 L
.40516 .36408 L
.41103 .37046 L
.41649 .37664 L
.42157 .3826 L
.42631 .38835 L
.43074 .39388 L
.43487 .39919 L
.43873 .40427 L
.44234 .40914 L
.44572 .4138 L
.44889 .41824 L
.45186 .42248 L
.45465 .42653 L
.45726 .43038 L
.45972 .43404 L
.46203 .43753 L
.46419 .44084 L
.46623 .44399 L
.46815 .44698 L
.46995 .44982 L
.47165 .45251 L
.47325 .45507 L
.47476 .45749 L
.47618 .45979 L
.47751 .46196 L
.47877 .46402 L
.47996 .46597 L
.48108 .46782 L
.48214 .46957 L
.48313 .47123 L
.48407 .4728 L
.48496 .47428 L
.4858 .47569 L
.48659 .47702 L
.48733 .47827 L
.48803 .47946 L
.4887 .48059 L
.48932 .48165 L
.48992 .48266 L
.49047 .48361 L
.491 .48451 L
.4915 .48536 L
.49197 .48616 L
Mistroke
.49241 .48692 L
.49283 .48764 L
.49323 .48832 L
.4936 .48896 L
.49396 .48957 L
.49429 .49014 L
.49461 .49068 L
.4949 .4912 L
.49519 .49168 L
.49545 .49214 L
.4957 .49257 L
.49594 .49298 L
.49616 .49337 L
.49638 .49373 L
.49658 .49408 L
.49676 .4944 L
.49694 .49471 L
.49711 .495 L
.49727 .49528 L
.49742 .49554 L
.49756 .49578 L
.4977 .49602 L
.49783 .49624 L
.49795 .49644 L
.49806 .49664 L
.49817 .49682 L
.49827 .497 L
.49836 .49716 L
.49845 .49732 L
.49854 .49747 L
.49862 .49761 L
.49869 .49774 L
.49877 .49786 L
.49883 .49798 L
.4989 .49809 L
.49896 .4982 L
.49902 .4983 L
.49907 .49839 L
.49912 .49848 L
.49917 .49856 L
.49922 .49864 L
.49926 .49872 L
.4993 .49879 L
.49934 .49886 L
.49938 .49892 L
.49941 .49898 L
.49944 .49903 L
.49947 .49909 L
.4995 .49914 L
.49953 .49919 L
Mistroke
.49956 .49923 L
.49958 .49927 L
.4996 .49931 L
.49963 .49935 L
.49965 .49939 L
.49967 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
Mistroke
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.34881 .31542 m
.3589 .32257 L
s
% Start of user PostScript
-4.5355889 -5.537346 -4.2331177 -5.3229899 MAarrowhead1
% End of user PostScript
1 .158 0 r
.36819 .32972 m
.37677 .33683 L
s
% Start of user PostScript
-3.9543234 -5.1083176 -3.6969657 -4.8949662 MAarrowhead1
% End of user PostScript
1 .473 0 r
.42157 .3826 m
.42631 .38835 L
s
% Start of user PostScript
-2.3527694 -3.5219417 -2.2105645 -3.3494881 MAarrowhead1
% End of user PostScript
1 .788 0 r
.45186 .42248 m
.45465 .42653 L
s
% Start of user PostScript
-1.4441046 -2.3254772 -1.3605259 -2.2041833 MAarrowhead1
% End of user PostScript
.897 1 0 r
.46995 .44982 m
.47165 .45251 L
s
% Start of user PostScript
-0.90138718 -1.5053881 -0.85043754 -1.4245985 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48108 .46782 m
.48214 .46957 L
s
% Start of user PostScript
-0.56756935 -0.96530794 -0.53588252 -0.91279461 MAarrowhead1
% End of user PostScript
.266 1 0 r
.48803 .47946 m
.4887 .48059 L
s
% Start of user PostScript
-0.35897407 -0.61612048 -0.3390593 -0.58238019 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49241 .48692 m
.49283 .48764 L
s
% Start of user PostScript
-0.22755464 -0.39234368 -0.21497097 -0.37078743 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49519 .49168 m
.49545 .49214 L
s
% Start of user PostScript
-0.14441098 -0.24955754 -0.13643797 -0.23582393 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49694 .49471 m
.49711 .495 L
s
% Start of user PostScript
-0.091698327 -0.15864515 -0.086639699 -0.14990752 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49806 .49664 m
.49817 .49682 L
s
% Start of user PostScript
-0.058243321 -0.10082287 -0.055031572 -0.095267637 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49877 .49786 m
.49883 .49798 L
s
% Start of user PostScript
-0.036999229 -0.064066266 -0.03495937 -0.060535566 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49922 .49864 m
.49926 .49872 L
s
% Start of user PostScript
-0.023505536 -0.040706974 -0.022209748 -0.03846338 MAarrowhead1
% End of user PostScript
0 .06 1 r
.4995 .49914 m
.49953 .49919 L
s
% Start of user PostScript
-0.014933552 -0.025863824 -0.014110353 -0.024438249 MAarrowhead1
% End of user PostScript
0 .488 1 r
.73368 .47287 m
.71103 .4913 L
.69093 .50644 L
.67307 .5188 L
.65717 .52877 L
.643 .53673 L
.63034 .54297 L
.61902 .54777 L
.60888 .55134 L
.59977 .55389 L
.59158 .55558 L
.5842 .55655 L
.57754 .55694 L
.57151 .55683 L
.56606 .55632 L
.5611 .5555 L
.55659 .55441 L
.55249 .55312 L
.54874 .55167 L
.54531 .55011 L
.54217 .54846 L
.53929 .54675 L
.53664 .54501 L
.53421 .54325 L
.53196 .54149 L
.52988 .53975 L
.52796 .53803 L
.52619 .53634 L
.52454 .53469 L
.52301 .53309 L
.52159 .53153 L
.52027 .53002 L
.51903 .52856 L
.51788 .52716 L
.51681 .52581 L
.51581 .52452 L
.51487 .52328 L
.514 .5221 L
.51318 .52096 L
.51241 .51988 L
.51169 .51885 L
.51101 .51786 L
.51038 .51693 L
.50978 .51603 L
.50922 .51519 L
.5087 .51438 L
.5082 .51361 L
.50774 .51289 L
.5073 .5122 L
.50689 .51154 L
Mistroke
.5065 .51092 L
.50613 .51033 L
.50579 .50977 L
.50546 .50924 L
.50516 .50874 L
.50487 .50827 L
.5046 .50782 L
.50434 .50739 L
.5041 .50699 L
.50387 .50661 L
.50365 .50625 L
.50345 .50591 L
.50326 .50559 L
.50308 .50528 L
.50291 .50499 L
.50275 .50472 L
.50259 .50446 L
.50245 .50421 L
.50231 .50398 L
.50219 .50376 L
.50207 .50356 L
.50195 .50336 L
.50184 .50318 L
.50174 .503 L
.50164 .50284 L
.50155 .50268 L
.50147 .50253 L
.50139 .5024 L
.50131 .50226 L
.50124 .50214 L
.50117 .50202 L
.50111 .50191 L
.50104 .5018 L
.50099 .50171 L
.50093 .50161 L
.50088 .50152 L
.50083 .50144 L
.50079 .50136 L
.50074 .50128 L
.5007 .50121 L
.50066 .50115 L
.50063 .50108 L
.50059 .50102 L
.50056 .50097 L
.50053 .50091 L
.5005 .50086 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
Mistroke
.50038 .50065 L
.50036 .50062 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
Mistroke
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.73368 .47287 m
.71103 .4913 L
s
% Start of user PostScript
7.0104931 -0.81379936 6.3308896 -0.26114614 MAarrowhead1
% End of user PostScript
1 .158 0 r
.69093 .50644 m
.67307 .5188 L
s
% Start of user PostScript
5.7278879 0.19324985 5.1920398 0.56385568 MAarrowhead1
% End of user PostScript
1 .473 0 r
.59158 .55558 m
.5842 .55655 L
s
% Start of user PostScript
2.7473947 1.6673889 2.5260061 1.6966347 MAarrowhead1
% End of user PostScript
1 .788 0 r
.54874 .55167 m
.54531 .55011 L
s
% Start of user PostScript
1.4621528 1.5502032 1.3593291 1.5032538 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52796 .53803 m
.52619 .53634 L
s
% Start of user PostScript
0.83891583 1.1408877 0.78561019 1.0902348 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51681 .52581 m
.51581 .52452 L
s
% Start of user PostScript
0.50438286 0.77442085 0.47433601 0.73562153 MAarrowhead1
% End of user PostScript
.266 1 0 r
.51038 .51693 m
.50978 .51603 L
s
% Start of user PostScript
0.31136258 0.50777379 0.29348659 0.48102007 MAarrowhead1
% End of user PostScript
0 1 .049 r
.5065 .51092 m
.50613 .51033 L
s
% Start of user PostScript
0.19493237 0.32761585 0.18396078 0.30994983 MAarrowhead1
% End of user PostScript
0 1 .364 r
.5041 .50699 m
.50387 .50661 L
s
% Start of user PostScript
0.12293068 0.20973905 0.11608255 0.19830272 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50259 .50446 m
.50245 .50421 L
s
% Start of user PostScript
0.077811371 0.13376173 0.073499418 0.12642825 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50164 .50284 m
.50155 .50268 L
s
% Start of user PostScript
0.049344201 0.085145226 0.046617011 0.080464508 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50104 .5018 m
.50099 .50171 L
s
% Start of user PostScript
0.031321039 0.054147486 0.029592271 0.051166809 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50066 .50115 m
.50063 .50108 L
s
% Start of user PostScript
0.019890247 0.03441846 0.018793136 0.032522541 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50042 .50073 m
.5004 .50069 L
s
% Start of user PostScript
0.012634159 0.021872691 0.011937514 0.020667444 MAarrowhead1
% End of user PostScript
1 0 .586 r
.82229 .19694 m
.78503 .2474 L
.75244 .29057 L
.72389 .32746 L
.69887 .35893 L
.67692 .38574 L
.65765 .40852 L
.64071 .42785 L
.62581 .44421 L
.61268 .45801 L
.6011 .46962 L
.59088 .47935 L
.58184 .48747 L
.57384 .4942 L
.56674 .49976 L
.56044 .50432 L
.55484 .50801 L
.54985 .51098 L
.5454 .51333 L
.54142 .51515 L
.53785 .51653 L
.53466 .51754 L
.53179 .51824 L
.5292 .51868 L
.52687 .5189 L
.52476 .51894 L
.52286 .51884 L
.52113 .51861 L
.51955 .51829 L
.51812 .51789 L
.51682 .51744 L
.51563 .51693 L
.51454 .5164 L
.51354 .51584 L
.51262 .51526 L
.51177 .51468 L
.511 .51409 L
.51028 .51351 L
.50961 .51293 L
.509 .51237 L
.50843 .51181 L
.5079 .51127 L
.50741 .51074 L
.50696 .51023 L
.50653 .50974 L
.50614 .50927 L
.50577 .50881 L
.50542 .50837 L
.5051 .50795 L
.5048 .50754 L
Mistroke
.50452 .50716 L
.50425 .50679 L
.50401 .50644 L
.50377 .5061 L
.50356 .50578 L
.50335 .50548 L
.50316 .50519 L
.50298 .50492 L
.50281 .50465 L
.50265 .50441 L
.5025 .50417 L
.50236 .50395 L
.50222 .50373 L
.5021 .50353 L
.50198 .50334 L
.50187 .50316 L
.50177 .50299 L
.50167 .50283 L
.50157 .50267 L
.50149 .50253 L
.5014 .50239 L
.50132 .50226 L
.50125 .50214 L
.50118 .50202 L
.50112 .50191 L
.50105 .50181 L
.501 .50171 L
.50094 .50161 L
.50089 .50153 L
.50084 .50144 L
.50079 .50136 L
.50075 .50129 L
.50071 .50122 L
.50067 .50115 L
.50063 .50109 L
.5006 .50103 L
.50056 .50097 L
.50053 .50092 L
.5005 .50087 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50036 .50062 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50047 L
Mistroke
.50025 .50044 L
.50024 .50042 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .5003 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .5001 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
Mistroke
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.82229 .19694 m
.78503 .2474 L
s
% Start of user PostScript
9.6686597 -9.0918639 8.5510374 -7.5780249 MAarrowhead1
% End of user PostScript
1 .158 0 r
.75244 .29057 m
.72389 .32746 L
s
% Start of user PostScript
7.5730778 -6.2828311 6.7166614 -5.1761802 MAarrowhead1
% End of user PostScript
1 .473 0 r
.6011 .46962 m
.59088 .47935 L
s
% Start of user PostScript
3.0330495 -0.91138082 2.7263672 -0.61952912 MAarrowhead1
% End of user PostScript
1 .788 0 r
.5454 .51333 m
.54142 .51515 L
s
% Start of user PostScript
1.3618783 0.39982757 1.2424812 0.45456793 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52286 .51884 m
.52113 .51861 L
s
% Start of user PostScript
0.68566966 0.56508777 0.6337881 0.558338 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51262 .51526 m
.51177 .51468 L
s
% Start of user PostScript
0.37856612 0.45787196 0.3532227 0.44038674 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50741 .51074 m
.50696 .51023 L
s
% Start of user PostScript
0.22238415 0.3223171 0.20870357 0.30701436 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50452 .50716 m
.50425 .50679 L
s
% Start of user PostScript
0.13552733 0.21476372 0.12760486 0.2037086 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50281 .50465 m
.50265 .50441 L
s
% Start of user PostScript
0.084275052 0.13962063 0.079486058 0.13217336 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50177 .50299 m
.50167 .50283 L
s
% Start of user PostScript
0.052961638 0.089714996 0.049996677 0.084848849 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50112 .50191 m
.50105 .50181 L
s
% Start of user PostScript
0.033463891 0.057320126 0.031604812 0.05418569 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50071 .50122 m
.50067 .50115 L
s
% Start of user PostScript
0.021202292 0.036519742 0.020028984 0.03451471 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50045 .50077 m
.50042 .50073 L
s
% Start of user PostScript
0.013452059 0.023234918 0.012709099 0.021956716 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50028 .50049 m
.50027 .50047 L
s
% Start of user PostScript
0.008540741 0.014772427 0.0080694987 0.013958958 MAarrowhead1
% End of user PostScript
1 .624 0 r
.20191 .65519 m
.23354 .62032 L
.26139 .59088 L
.28595 .56611 L
.30764 .54534 L
.3268 .52801 L
.34377 .51361 L
.35881 .50172 L
.37217 .49198 L
.38404 .48405 L
.39462 .47769 L
.40405 .47264 L
.41248 .4687 L
.42003 .46572 L
.4268 .46352 L
.43287 .46199 L
.43835 .46102 L
.44328 .46051 L
.44773 .46038 L
.45177 .46057 L
.45542 .46102 L
.45875 .46167 L
.46177 .46248 L
.46453 .46343 L
.46704 .46447 L
.46935 .46558 L
.47146 .46675 L
.4734 .46795 L
.47518 .46916 L
.47683 .47039 L
.47834 .47161 L
.47974 .47281 L
.48104 .474 L
.48224 .47517 L
.48335 .4763 L
.48438 .47741 L
.48535 .47848 L
.48624 .47951 L
.48708 .48051 L
.48785 .48147 L
.48858 .4824 L
.48926 .48328 L
.48989 .48413 L
.49049 .48494 L
.49104 .48571 L
.49157 .48645 L
.49205 .48716 L
.49251 .48783 L
.49294 .48847 L
.49335 .48908 L
Mistroke
.49373 .48966 L
.49409 .49021 L
.49442 .49073 L
.49474 .49122 L
.49504 .49169 L
.49532 .49214 L
.49558 .49256 L
.49583 .49297 L
.49606 .49335 L
.49628 .49371 L
.49649 .49405 L
.49669 .49437 L
.49687 .49468 L
.49705 .49497 L
.49721 .49524 L
.49737 .4955 L
.49751 .49575 L
.49765 .49598 L
.49778 .4962 L
.49791 .49641 L
.49802 .4966 L
.49813 .49679 L
.49824 .49697 L
.49833 .49713 L
.49843 .49729 L
.49851 .49744 L
.49859 .49758 L
.49867 .49771 L
.49875 .49784 L
.49882 .49796 L
.49888 .49807 L
.49894 .49817 L
.499 .49827 L
.49906 .49837 L
.49911 .49846 L
.49916 .49854 L
.4992 .49862 L
.49925 .4987 L
.49929 .49877 L
.49933 .49884 L
.49937 .4989 L
.4994 .49896 L
.49943 .49902 L
.49947 .49907 L
.49949 .49913 L
.49952 .49917 L
.49955 .49922 L
.49957 .49926 L
.4996 .4993 L
.49962 .49934 L
Mistroke
.49964 .49938 L
.49966 .49941 L
.49968 .49944 L
.4997 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49956 L
.49976 .49958 L
.49977 .4996 L
.49978 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
Mistroke
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.20191 .65519 m
.23354 .62032 L
s
% Start of user PostScript
-8.9426626 4.6556202 -7.9938954 3.6094655 MAarrowhead1
% End of user PostScript
1 .158 0 r
.26139 .59088 m
.28595 .56611 L
s
% Start of user PostScript
-7.1582829 2.726384 -6.4214628 1.9833144 MAarrowhead1
% End of user PostScript
1 .473 0 r
.39462 .47769 m
.40405 .47264 L
s
% Start of user PostScript
-3.1614085 -0.66939975 -2.8783901 -0.82087498 MAarrowhead1
% End of user PostScript
1 .788 0 r
.44773 .46038 m
.45177 .46057 L
s
% Start of user PostScript
-1.5679654 -1.1884649 -1.4469766 -1.1828156 MAarrowhead1
% End of user PostScript
.897 1 0 r
.47146 .46675 m
.4734 .46795 L
s
% Start of user PostScript
-0.85617985 -0.99759871 -0.79800363 -0.96163195 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48335 .4763 m
.48438 .47741 L
s
% Start of user PostScript
-0.49947433 -0.71088312 -0.46845269 -0.6777431 MAarrowhead1
% End of user PostScript
.266 1 0 r
.48989 .48413 m
.49049 .48494 L
s
% Start of user PostScript
-0.30319862 -0.47614433 -0.28537689 -0.45181952 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49373 .48966 m
.49409 .49021 L
s
% Start of user PostScript
-0.18814217 -0.31029727 -0.1774191 -0.29380369 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49606 .49335 m
.49628 .49371 L
s
% Start of user PostScript
-0.11810708 -0.19961827 -0.11148487 -0.18880902 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49751 .49575 m
.49765 .49598 L
s
% Start of user PostScript
-0.074584827 -0.12761198 -0.070438026 -0.12063948 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49843 .49729 m
.49851 .49744 L
s
% Start of user PostScript
-0.04724279 -0.081327135 -0.044627396 -0.076863865 MAarrowhead1
% End of user PostScript
0 .69 1 r
.499 .49827 m
.49906 .49837 L
s
% Start of user PostScript
-0.029969572 -0.051750005 -0.028314016 -0.048903701 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49937 .4989 m
.4994 .49896 L
s
% Start of user PostScript
-0.019026407 -0.032904235 -0.017976504 -0.031092488 MAarrowhead1
% End of user PostScript
0 .06 1 r
.4996 .4993 m
.49962 .49934 L
s
% Start of user PostScript
-0.012083673 -0.020913498 -0.011417242 -0.019761347 MAarrowhead1
% End of user PostScript
1 .118 0 r
.76568 .70622 m
.74528 .70481 L
.72679 .70214 L
.70997 .69847 L
.69466 .69401 L
.68069 .68892 L
.66792 .68337 L
.65623 .67748 L
.64552 .67134 L
.63567 .66506 L
.62661 .6587 L
.61826 .65233 L
.61055 .64599 L
.60343 .63973 L
.59684 .63357 L
.59072 .62755 L
.58505 .62167 L
.57979 .61597 L
.57489 .61045 L
.57032 .60512 L
.56607 .59998 L
.5621 .59503 L
.55839 .59029 L
.55493 .58573 L
.55169 .58138 L
.54865 .57721 L
.54581 .57323 L
.54315 .56943 L
.54065 .56582 L
.53831 .56237 L
.5361 .55909 L
.53404 .55596 L
.53209 .553 L
.53026 .55018 L
.52855 .5475 L
.52693 .54496 L
.52541 .54254 L
.52397 .54026 L
.52262 .53809 L
.52135 .53603 L
.52015 .53408 L
.51902 .53224 L
.51796 .53049 L
.51695 .52883 L
.51601 .52726 L
.51511 .52578 L
.51427 .52437 L
.51348 .52304 L
.51273 .52178 L
.51202 .52059 L
Mistroke
.51135 .51947 L
.51072 .5184 L
.51013 .51739 L
.50957 .51644 L
.50904 .51554 L
.50854 .51469 L
.50806 .51388 L
.50762 .51312 L
.5072 .5124 L
.5068 .51172 L
.50642 .51107 L
.50607 .51047 L
.50573 .50989 L
.50541 .50935 L
.50512 .50883 L
.50483 .50835 L
.50457 .50789 L
.50431 .50745 L
.50408 .50704 L
.50385 .50666 L
.50364 .50629 L
.50344 .50594 L
.50325 .50562 L
.50307 .50531 L
.5029 .50501 L
.50274 .50474 L
.50259 .50448 L
.50245 .50423 L
.50231 .504 L
.50218 .50378 L
.50206 .50357 L
.50195 .50337 L
.50184 .50319 L
.50174 .50301 L
.50164 .50285 L
.50155 .50269 L
.50147 .50254 L
.50139 .5024 L
.50131 .50227 L
.50124 .50214 L
.50117 .50203 L
.50111 .50191 L
.50104 .50181 L
.50099 .50171 L
.50093 .50161 L
.50088 .50153 L
.50083 .50144 L
.50079 .50136 L
.50074 .50129 L
.5007 .50122 L
Mistroke
.50066 .50115 L
.50063 .50109 L
.50059 .50103 L
.50056 .50097 L
.50053 .50092 L
.5005 .50087 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50036 .50062 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
Mistroke
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.76568 .70622 m
.74528 .70481 L
s
% Start of user PostScript
7.9702659 6.1866147 7.3585477 6.144183 MAarrowhead1
% End of user PostScript
1 .158 0 r
.72679 .70214 m
.70997 .69847 L
s
% Start of user PostScript
6.803563 6.0642273 6.299112 5.9541379 MAarrowhead1
% End of user PostScript
1 .473 0 r
.62661 .6587 m
.61826 .65233 L
s
% Start of user PostScript
3.7982333 4.7610923 3.5477401 4.5698932 MAarrowhead1
% End of user PostScript
1 .788 0 r
.57489 .61045 m
.57032 .60512 L
s
% Start of user PostScript
2.2465517 3.31354 2.1096489 3.1535312 MAarrowhead1
% End of user PostScript
.897 1 0 r
.54581 .57323 m
.54315 .56943 L
s
% Start of user PostScript
1.3743805 2.1969492 1.2944695 2.0830443 MAarrowhead1
% End of user PostScript
.581 1 0 r
.52855 .5475 m
.52693 .54496 L
s
% Start of user PostScript
0.85637687 1.4249613 0.80785244 1.3487016 MAarrowhead1
% End of user PostScript
.266 1 0 r
.51796 .53049 m
.51695 .52883 L
s
% Start of user PostScript
0.53874623 0.91460096 0.50863042 0.8649134 MAarrowhead1
% End of user PostScript
0 1 .049 r
.51135 .51947 m
.51072 .5184 L
s
% Start of user PostScript
0.34058963 0.58402861 0.3216826 0.55206703 MAarrowhead1
% End of user PostScript
0 1 .364 r
.5072 .5124 m
.5068 .51172 L
s
% Start of user PostScript
0.21585138 0.37199387 0.20391101 0.35156244 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50457 .50789 m
.50431 .50745 L
s
% Start of user PostScript
0.13696814 0.236641 0.12940481 0.22362035 MAarrowhead1
% End of user PostScript
0 1 .995 r
.5029 .50501 m
.50274 .50474 L
s
% Start of user PostScript
0.086967258 0.15044271 0.082169232 0.14215751 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50184 .50319 m
.50174 .50301 L
s
% Start of user PostScript
0.055236736 0.095612772 0.052190656 0.090344825 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50117 .50203 m
.50111 .50191 L
s
% Start of user PostScript
0.035088783 0.060756468 0.033154211 0.05740824 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50074 .50129 m
.5007 .50122 L
s
% Start of user PostScript
0.022291672 0.038604244 0.021062789 0.036476565 MAarrowhead1
% End of user PostScript
.805 0 1 r
.74198 .31503 m
.71497 .34891 L
.69128 .37775 L
.67047 .40226 L
.65218 .42305 L
.63609 .44064 L
.62191 .45548 L
.60941 .46795 L
.59836 .4784 L
.5886 .48712 L
.57995 .49435 L
.57228 .50031 L
.56547 .50518 L
.55941 .50914 L
.55402 .51231 L
.5492 .51482 L
.5449 .51676 L
.54104 .51823 L
.53758 .51929 L
.53447 .52003 L
.53168 .52048 L
.52915 .5207 L
.52687 .52072 L
.52481 .52059 L
.52293 .52033 L
.52123 .51997 L
.51968 .51953 L
.51826 .51902 L
.51697 .51847 L
.51579 .51788 L
.51471 .51727 L
.51371 .51664 L
.51279 .516 L
.51195 .51536 L
.51117 .51472 L
.51045 .51409 L
.50978 .51347 L
.50916 .51286 L
.50859 .51227 L
.50806 .5117 L
.50756 .51114 L
.5071 .5106 L
.50667 .51009 L
.50627 .50959 L
.5059 .50911 L
.50555 .50865 L
.50522 .50821 L
.50491 .50779 L
.50463 .50739 L
.50436 .50701 L
Mistroke
.5041 .50664 L
.50387 .50629 L
.50365 .50596 L
.50344 .50565 L
.50324 .50535 L
.50306 .50506 L
.50288 .50479 L
.50272 .50454 L
.50256 .50429 L
.50242 .50406 L
.50228 .50384 L
.50216 .50364 L
.50203 .50344 L
.50192 .50325 L
.50181 .50308 L
.50171 .50291 L
.50162 .50275 L
.50153 .5026 L
.50144 .50246 L
.50136 .50233 L
.50128 .5022 L
.50121 .50208 L
.50115 .50196 L
.50108 .50186 L
.50102 .50176 L
.50097 .50166 L
.50091 .50157 L
.50086 .50148 L
.50081 .5014 L
.50077 .50132 L
.50073 .50125 L
.50069 .50118 L
.50065 .50112 L
.50061 .50106 L
.50058 .501 L
.50055 .50094 L
.50052 .50089 L
.50049 .50084 L
.50046 .5008 L
.50044 .50075 L
.50041 .50071 L
.50039 .50067 L
.50037 .50063 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
Mistroke
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .5003 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50012 .50022 L
.50012 .5002 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
Mistroke
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.74198 .31503 m
.71497 .34891 L
s
% Start of user PostScript
7.2594617 -5.5489831 6.4492292 -4.532834 MAarrowhead1
% End of user PostScript
1 .158 0 r
.69128 .37775 m
.67047 .40226 L
s
% Start of user PostScript
5.7384066 -3.667524 5.1142048 -2.9320784 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57995 .49435 m
.57228 .50031 L
s
% Start of user PostScript
2.3984752 -0.16960621 2.1684271 0.0092081794 MAarrowhead1
% End of user PostScript
1 .788 0 r
.53758 .51929 m
.53447 .52003 L
s
% Start of user PostScript
1.1274674 0.57880545 1.0342284 0.60075291 MAarrowhead1
% End of user PostScript
.897 1 0 r
.51968 .51953 m
.51826 .51902 L
s
% Start of user PostScript
0.59036652 0.58591324 0.54794464 0.57072977 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51117 .51472 m
.51045 .51409 L
s
% Start of user PostScript
0.33505767 0.4415861 0.3134492 0.42268333 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50667 .51009 m
.50627 .50959 L
s
% Start of user PostScript
0.2001568 0.30259015 0.18812619 0.28763906 MAarrowhead1
% End of user PostScript
0 1 .049 r
.5041 .50664 m
.50387 .50629 L
s
% Start of user PostScript
0.12312623 0.19924965 0.1160223 0.18881589 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50256 .50429 m
.50242 .50406 L
s
% Start of user PostScript
0.076942957 0.12881668 0.072601011 0.12189064 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50162 .50275 m
.50153 .5026 L
s
% Start of user PostScript
0.048477019 0.082549787 0.045772886 0.078054988 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50102 .50176 m
.50097 .50166 L
s
% Start of user PostScript
0.030669841 0.052672111 0.028969105 0.049786377 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50065 .50112 m
.50061 .50106 L
s
% Start of user PostScript
0.019444659 0.033536262 0.018369611 0.031693299 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50041 .50071 m
.50039 .50067 L
s
% Start of user PostScript
0.012340936 0.021329725 0.01165966 0.020155782 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50026 .50045 m
.50025 .50043 L
s
% Start of user PostScript
0.0078365682 0.013558907 0.0074042798 0.012812087 MAarrowhead1
% End of user PostScript
1 .225 0 r
.63162 .63297 m
.62222 .62937 L
.61362 .62546 L
.60574 .62134 L
.59852 .61708 L
.59187 .61272 L
.58576 .60833 L
.58012 .60393 L
.57492 .59957 L
.5701 .59526 L
.56565 .59104 L
.56152 .58691 L
.55768 .58289 L
.55412 .57899 L
.5508 .57521 L
.54771 .57156 L
.54483 .56805 L
.54214 .56468 L
.53963 .56144 L
.53728 .55834 L
.53509 .55536 L
.53303 .55252 L
.5311 .54981 L
.5293 .54723 L
.5276 .54476 L
.52601 .54241 L
.52452 .54018 L
.52312 .53805 L
.5218 .53603 L
.52056 .53412 L
.51939 .53229 L
.51829 .53056 L
.51726 .52892 L
.51628 .52737 L
.51537 .52589 L
.5145 .52449 L
.51369 .52317 L
.51292 .52191 L
.5122 .52072 L
.51152 .5196 L
.51088 .51853 L
.51027 .51752 L
.5097 .51657 L
.50916 .51566 L
.50865 .51481 L
.50817 .514 L
.50771 .51323 L
.50729 .51251 L
.50688 .51182 L
.5065 .51117 L
Mistroke
.50614 .51056 L
.5058 .50998 L
.50548 .50943 L
.50518 .50892 L
.50489 .50843 L
.50462 .50796 L
.50436 .50753 L
.50412 .50711 L
.50389 .50672 L
.50368 .50635 L
.50348 .506 L
.50328 .50567 L
.5031 .50536 L
.50293 .50507 L
.50277 .50479 L
.50262 .50452 L
.50247 .50427 L
.50234 .50404 L
.50221 .50382 L
.50208 .50361 L
.50197 .50341 L
.50186 .50322 L
.50176 .50304 L
.50166 .50288 L
.50157 .50272 L
.50148 .50257 L
.5014 .50243 L
.50132 .50229 L
.50125 .50217 L
.50118 .50205 L
.50112 .50193 L
.50106 .50183 L
.501 .50173 L
.50094 .50163 L
.50089 .50154 L
.50084 .50146 L
.50079 .50138 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50063 .5011 L
.5006 .50104 L
.50057 .50098 L
.50053 .50093 L
.5005 .50087 L
.50048 .50083 L
.50045 .50078 L
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
Mistroke
.50036 .50062 L
.50034 .50059 L
.50032 .50056 L
.5003 .50052 L
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .5004 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
Mistroke
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.63162 .63297 m
.62222 .62937 L
s
% Start of user PostScript
3.9487298 3.9891547 3.6665753 3.8809766 MAarrowhead1
% End of user PostScript
1 .158 0 r
.61362 .62546 m
.60574 .62134 L
s
% Start of user PostScript
3.4085841 3.7638473 3.1722747 3.6402516 MAarrowhead1
% End of user PostScript
1 .473 0 r
.56565 .59104 m
.56152 .58691 L
s
% Start of user PostScript
1.9694394 2.7311316 1.8454934 2.6072406 MAarrowhead1
% End of user PostScript
1 .788 0 r
.53963 .56144 m
.53728 .55834 L
s
% Start of user PostScript
1.1889283 1.8431851 1.1185032 1.7500558 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52452 .54018 m
.52312 .53805 L
s
% Start of user PostScript
0.73556696 1.2053683 0.69346766 1.1416182 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51537 .52589 m
.5145 .52449 L
s
% Start of user PostScript
0.46104218 0.7767265 0.43513514 0.73476759 MAarrowhead1
% End of user PostScript
.266 1 0 r
.5097 .51657 m
.50916 .51566 L
s
% Start of user PostScript
0.29091954 0.49695294 0.27472676 0.46983202 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50614 .51056 m
.5058 .50998 L
s
% Start of user PostScript
0.18419806 0.31683679 0.17399496 0.2994587 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50389 .50672 m
.50368 .50635 L
s
% Start of user PostScript
0.11682699 0.20165002 0.11037148 0.19056225 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50247 .50427 m
.50234 .50404 L
s
% Start of user PostScript
0.074161044 0.12822817 0.070068155 0.12116879 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50157 .50272 m
.50148 .50257 L
s
% Start of user PostScript
0.047097321 0.081504241 0.044499655 0.077014392 MAarrowhead1
% End of user PostScript
0 .69 1 r
.501 .50173 m
.50094 .50163 L
s
% Start of user PostScript
0.029916484 0.051794399 0.028266939 0.048940305 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50063 .5011 m
.5006 .50104 L
s
% Start of user PostScript
0.019005177 0.032910791 0.017957425 0.031096985 MAarrowhead1
% End of user PostScript
0 .06 1 r
.5004 .5007 m
.50038 .50066 L
s
% Start of user PostScript
0.012074157 0.020910784 0.011408562 0.019758243 MAarrowhead1
% End of user PostScript
1 .528 0 r
.71806 .39985 m
.69523 .4241 L
.6751 .44451 L
.65733 .46163 L
.64162 .47593 L
.62772 .48781 L
.6154 .49763 L
.60446 .50569 L
.59474 .51225 L
.58608 .51752 L
.57836 .52171 L
.57146 .52498 L
.56529 .52748 L
.55975 .52932 L
.55478 .53061 L
.5503 .53144 L
.54627 .53189 L
.54263 .53202 L
.53933 .5319 L
.53634 .53156 L
.53363 .53105 L
.53116 .5304 L
.52891 .52965 L
.52686 .52882 L
.52497 .52792 L
.52325 .52699 L
.52167 .52602 L
.52021 .52504 L
.51887 .52405 L
.51764 .52306 L
.5165 .52208 L
.51544 .52112 L
.51446 .52018 L
.51355 .51925 L
.51271 .51836 L
.51193 .51749 L
.5112 .51665 L
.51052 .51584 L
.50989 .51506 L
.50929 .51431 L
.50874 .51359 L
.50822 .5129 L
.50774 .51224 L
.50729 .51162 L
.50686 .51101 L
.50647 .51044 L
.50609 .5099 L
.50574 .50938 L
.50541 .50888 L
.5051 .50841 L
Mistroke
.50481 .50796 L
.50454 .50754 L
.50428 .50714 L
.50404 .50675 L
.50381 .50639 L
.5036 .50605 L
.50339 .50572 L
.5032 .50541 L
.50302 .50512 L
.50285 .50484 L
.50269 .50458 L
.50254 .50433 L
.5024 .50409 L
.50227 .50387 L
.50214 .50366 L
.50202 .50346 L
.50191 .50327 L
.5018 .50309 L
.5017 .50292 L
.50161 .50276 L
.50152 .50261 L
.50144 .50247 L
.50136 .50233 L
.50128 .50221 L
.50121 .50208 L
.50114 .50197 L
.50108 .50186 L
.50102 .50176 L
.50096 .50166 L
.50091 .50157 L
.50086 .50148 L
.50081 .5014 L
.50077 .50133 L
.50073 .50125 L
.50069 .50118 L
.50065 .50112 L
.50061 .50106 L
.50058 .501 L
.50055 .50094 L
.50052 .50089 L
.50049 .50084 L
.50046 .5008 L
.50044 .50075 L
.50041 .50071 L
.50039 .50067 L
.50037 .50064 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
Mistroke
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .5003 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50012 .50022 L
.50012 .5002 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50015 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
Mistroke
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.71806 .39985 m
.69523 .4241 L
s
% Start of user PostScript
6.541869 -3.004465 5.8568931 -2.2770131 MAarrowhead1
% End of user PostScript
1 .158 0 r
.6751 .44451 m
.65733 .46163 L
s
% Start of user PostScript
5.2529808 -1.6646691 4.7198822 -1.1510738 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57836 .52171 m
.57146 .52498 L
s
% Start of user PostScript
2.3507505 0.65137041 2.1437807 0.74951534 MAarrowhead1
% End of user PostScript
1 .788 0 r
.53933 .5319 m
.53634 .53156 L
s
% Start of user PostScript
1.1799859 0.95692426 1.0903498 0.94677492 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52167 .52602 m
.52021 .52504 L
s
% Start of user PostScript
0.65005835 0.78055304 0.606411 0.7510644 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51271 .51836 m
.51193 .51749 L
s
% Start of user PostScript
0.38134776 0.55076007 0.35784387 0.52470301 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50774 .51224 m
.50729 .51162 L
s
% Start of user PostScript
0.23222519 0.36734882 0.21863544 0.348467 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50481 .50796 m
.50454 .50754 L
s
% Start of user PostScript
0.1443454 0.23893051 0.13613811 0.22619472 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50302 .50512 m
.50285 .50484 L
s
% Start of user PostScript
0.090692851 0.1535627 0.085614048 0.14523616 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50191 .50327 m
.5018 .50309 L
s
% Start of user PostScript
0.057298224 0.098124254 0.054114546 0.092759381 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50121 .50208 m
.50114 .50197 L
s
% Start of user PostScript
0.036301442 0.062520293 0.034292411 0.059088031 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50077 .50133 m
.50073 .50125 L
s
% Start of user PostScript
0.023031273 0.039778319 0.021759202 0.037590115 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50049 .50084 m
.50046 .5008 L
s
% Start of user PostScript
0.014622404 0.025290832 0.013815585 0.023898176 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50031 .50054 m
.50029 .50051 L
s
% Start of user PostScript
0.0092869535 0.016074063 0.0087747862 0.015188487 MAarrowhead1
% End of user PostScript
1 0 .326 r
.53766 .46581 m
.53333 .47159 L
.52955 .47653 L
.52623 .48075 L
.52332 .48435 L
.52077 .48741 L
.51852 .49 L
.51655 .4922 L
.51481 .49406 L
.51328 .49563 L
.51193 .49694 L
.51074 .49804 L
.50968 .49895 L
.50874 .49971 L
.50791 .50033 L
.50717 .50084 L
.50651 .50124 L
.50593 .50157 L
.5054 .50182 L
.50494 .50202 L
.50452 .50216 L
.50414 .50227 L
.5038 .50233 L
.50349 .50237 L
.50322 .50238 L
.50297 .50238 L
.50274 .50236 L
.50254 .50232 L
.50235 .50227 L
.50218 .50222 L
.50203 .50216 L
.50188 .50209 L
.50175 .50202 L
.50163 .50195 L
.50152 .50188 L
.50142 .5018 L
.50133 .50173 L
.50124 .50166 L
.50116 .50158 L
.50109 .50151 L
.50102 .50145 L
.50096 .50138 L
.5009 .50131 L
.50084 .50125 L
.50079 .50119 L
.50074 .50113 L
.5007 .50108 L
.50066 .50102 L
.50062 .50097 L
.50058 .50092 L
Mistroke
.50055 .50087 L
.50052 .50083 L
.50049 .50078 L
.50046 .50074 L
.50043 .5007 L
.50041 .50067 L
.50038 .50063 L
.50036 .5006 L
.50034 .50057 L
.50032 .50054 L
.5003 .50051 L
.50029 .50048 L
.50027 .50045 L
.50026 .50043 L
.50024 .50041 L
.50023 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
Mistroke
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.53766 .46581 m
.53333 .47159 L
s
% Start of user PostScript
1.1297888 -1.0257282 1.0000235 -0.8522929 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52955 .47653 m
.52623 .48075 L
s
% Start of user PostScript
0.88642142 -0.704024 0.78688867 -0.57745072 MAarrowhead1
% End of user PostScript
1 .473 0 r
.51193 .49694 m
.51074 .49804 L
s
% Start of user PostScript
0.3578918 -0.091724052 0.322062 -0.058778042 MAarrowhead1
% End of user PostScript
1 .788 0 r
.5054 .50182 m
.50494 .50202 L
s
% Start of user PostScript
0.16214799 0.054716079 0.14809325 0.060562835 MAarrowhead1
% End of user PostScript
.897 1 0 r
.50274 .50236 m
.50254 .50232 L
s
% Start of user PostScript
0.082289184 0.070669688 0.076127262 0.069590656 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50152 .50188 m
.50142 .5018 L
s
% Start of user PostScript
0.04569425 0.05630962 0.042658809 0.054100734 MAarrowhead1
% End of user PostScript
.266 1 0 r
.5009 .50131 m
.50084 .50125 L
s
% Start of user PostScript
0.026938147 0.039401791 0.025289082 0.037514314 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50055 .50087 m
.50052 .50083 L
s
% Start of user PostScript
0.016449744 0.02618587 0.015490834 0.024832846 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50034 .50057 m
.50032 .50054 L
s
% Start of user PostScript
0.010239841 0.01700316 0.0096588265 0.016094642 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50021 .50036 m
.5002 .50034 L
s
% Start of user PostScript
0.0064386386 0.010919194 0.0060784634 0.01032644 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50014 .50023 m
.50013 .50022 L
s
% Start of user PostScript
0.004069399 0.0069744103 0.0038434141 0.0065928718 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50009 .50015 m
.50008 .50014 L
s
% Start of user PostScript
0.0025786818 0.004442894 0.0024360094 0.0041989174 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50005 .50009 m
.50005 .50009 L
s
% Start of user PostScript
0.0016361925 0.0028264964 0.0015458344 0.0026709891 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50003 .50006 m
.50003 .50006 L
s
% Start of user PostScript
0.0010388589 0.001796982 0.00098154193 0.001698023 MAarrowhead1
% End of user PostScript
.514 1 0 r
.80179 .54729 m
.7744 .56332 L
.74995 .57597 L
.7281 .58577 L
.70852 .59317 L
.69097 .59854 L
.67518 .60221 L
.66097 .60446 L
.64816 .60553 L
.63657 .60564 L
.62608 .60495 L
.61656 .60361 L
.60792 .60175 L
.60004 .59948 L
.59286 .59689 L
.58629 .59405 L
.58028 .59104 L
.57477 .5879 L
.56971 .58469 L
.56505 .58143 L
.56076 .57817 L
.55679 .57492 L
.55313 .57171 L
.54974 .56855 L
.5466 .56546 L
.54369 .56245 L
.54098 .55953 L
.53846 .5567 L
.53612 .55396 L
.53393 .55132 L
.5319 .54879 L
.52999 .54635 L
.52821 .54401 L
.52655 .54178 L
.52499 .53964 L
.52353 .5376 L
.52216 .53565 L
.52088 .53379 L
.51967 .53202 L
.51854 .53034 L
.51748 .52873 L
.51648 .52721 L
.51554 .52576 L
.51466 .52439 L
.51383 .52308 L
.51305 .52185 L
.51231 .52067 L
.51162 .51956 L
.51096 .5185 L
.51035 .5175 L
Mistroke
.50977 .51655 L
.50922 .51565 L
.50871 .5148 L
.50822 .514 L
.50776 .51324 L
.50733 .51251 L
.50692 .51183 L
.50654 .51119 L
.50617 .51057 L
.50583 .51 L
.50551 .50945 L
.5052 .50893 L
.50491 .50844 L
.50464 .50798 L
.50438 .50754 L
.50414 .50713 L
.50391 .50674 L
.50369 .50637 L
.50349 .50602 L
.5033 .50569 L
.50311 .50537 L
.50294 .50508 L
.50278 .5048 L
.50263 .50454 L
.50248 .50429 L
.50234 .50405 L
.50221 .50383 L
.50209 .50362 L
.50198 .50342 L
.50187 .50323 L
.50176 .50305 L
.50167 .50288 L
.50158 .50273 L
.50149 .50258 L
.50141 .50243 L
.50133 .5023 L
.50126 .50217 L
.50119 .50205 L
.50112 .50194 L
.50106 .50183 L
.501 .50173 L
.50095 .50164 L
.50089 .50155 L
.50084 .50146 L
.5008 .50138 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50064 .5011 L
.5006 .50104 L
Mistroke
.50057 .50098 L
.50054 .50093 L
.50051 .50088 L
.50048 .50083 L
.50045 .50078 L
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50056 L
.5003 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .5004 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
Mistroke
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.80179 .54729 m
.7744 .56332 L
s
% Start of user PostScript
9.0537163 1.4186633 8.2319241 1.8994659 MAarrowhead1
% End of user PostScript
1 .158 0 r
.74995 .57597 m
.7281 .58577 L
s
% Start of user PostScript
7.4985182 2.2791354 6.842874 2.5732102 MAarrowhead1
% End of user PostScript
1 .473 0 r
.62608 .60495 m
.61656 .60361 L
s
% Start of user PostScript
3.7824265 3.1483991 3.4969321 3.1082268 MAarrowhead1
% End of user PostScript
1 .788 0 r
.56971 .58469 m
.56505 .58143 L
s
% Start of user PostScript
2.0911769 2.5406487 1.9514391 2.4429871 MAarrowhead1
% End of user PostScript
.897 1 0 r
.54098 .55953 m
.53846 .5567 L
s
% Start of user PostScript
1.2294812 1.7858892 1.1539348 1.7009166 MAarrowhead1
% End of user PostScript
.581 1 0 r
.52499 .53964 m
.52353 .5376 L
s
% Start of user PostScript
0.74964027 1.1892163 0.70584817 1.127945 MAarrowhead1
% End of user PostScript
.266 1 0 r
.51554 .52576 m
.51466 .52439 L
s
% Start of user PostScript
0.46626823 0.77289959 0.43978171 0.73165637 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50977 .51655 m
.50922 .51565 L
s
% Start of user PostScript
0.29305924 0.49656646 0.27665591 0.46962725 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50617 .51057 m
.50583 .51 L
s
% Start of user PostScript
0.18518232 0.31724108 0.17489554 0.29989167 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50391 .50674 m
.50369 .50637 L
s
% Start of user PostScript
0.11733311 0.20211338 0.11084036 0.19101627 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50248 .50429 m
.50234 .50405 L
s
% Start of user PostScript
0.07444472 0.12858819 0.070333222 0.12151411 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50158 .50273 m
.50149 .50258 L
s
% Start of user PostScript
0.047265513 0.081753825 0.044657632 0.077251854 MAarrowhead1
% End of user PostScript
0 .375 1 r
.501 .50173 m
.50095 .50164 L
s
% Start of user PostScript
0.030019517 0.051959597 0.028363994 0.049096917 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50064 .5011 m
.5006 .50104 L
s
% Start of user PostScript
0.019069423 0.033017854 0.018018034 0.031198312 MAarrowhead1
% End of user PostScript
0 1 .337 r
.28006 .63714 m
.30391 .60928 L
.32487 .58566 L
.34333 .56569 L
.35959 .54886 L
.37394 .53472 L
.38662 .52289 L
.39783 .51303 L
.40776 .50487 L
.41657 .49815 L
.4244 .49266 L
.43136 .48822 L
.43757 .48467 L
.44311 .48188 L
.44806 .47972 L
.4525 .47811 L
.45649 .47695 L
.46007 .47617 L
.4633 .47571 L
.46621 .47551 L
.46884 .47552 L
.47123 .47572 L
.47339 .47605 L
.47536 .47651 L
.47715 .47705 L
.47879 .47766 L
.48028 .47833 L
.48165 .47903 L
.48291 .47977 L
.48406 .48051 L
.48512 .48127 L
.4861 .48203 L
.48701 .48278 L
.48784 .48352 L
.48862 .48425 L
.48933 .48496 L
.49 .48566 L
.49062 .48633 L
.49119 .48698 L
.49173 .48761 L
.49223 .48822 L
.4927 .4888 L
.49313 .48936 L
.49354 .4899 L
.49392 .49041 L
.49428 .49091 L
.49461 .49137 L
.49492 .49182 L
.49522 .49225 L
.49549 .49266 L
Mistroke
.49575 .49304 L
.49599 .49341 L
.49622 .49376 L
.49644 .49409 L
.49664 .49441 L
.49683 .49471 L
.49701 .49499 L
.49718 .49526 L
.49734 .49552 L
.49749 .49576 L
.49763 .49599 L
.49776 .4962 L
.49789 .49641 L
.498 .49661 L
.49812 .49679 L
.49822 .49697 L
.49832 .49713 L
.49841 .49729 L
.4985 .49744 L
.49859 .49758 L
.49866 .49771 L
.49874 .49783 L
.49881 .49795 L
.49887 .49806 L
.49894 .49817 L
.499 .49827 L
.49905 .49837 L
.4991 .49846 L
.49915 .49854 L
.4992 .49862 L
.49924 .4987 L
.49929 .49877 L
.49933 .49884 L
.49936 .4989 L
.4994 .49896 L
.49943 .49902 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49922 L
.49957 .49926 L
.4996 .4993 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49944 L
.4997 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49956 L
Mistroke
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.4998 .49965 L
.49981 .49967 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.28006 .63714 m
.30391 .60928 L
s
% Start of user PostScript
-6.5981594 4.1142046 -5.8827633 3.2782673 MAarrowhead1
% End of user PostScript
1 .158 0 r
.32487 .58566 m
.34333 .56569 L
s
% Start of user PostScript
-5.2537547 2.5697346 -4.7001033 1.9707263 MAarrowhead1
% End of user PostScript
1 .473 0 r
.4244 .49266 m
.43136 .48822 L
s
% Start of user PostScript
-2.2681484 -0.22026578 -2.0592141 -0.35346262 MAarrowhead1
% End of user PostScript
1 .788 0 r
.4633 .47571 m
.46621 .47551 L
s
% Start of user PostScript
-1.1011 -0.72875992 -1.0137411 -0.73477463 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48028 .47833 m
.48165 .47903 L
s
% Start of user PostScript
-0.59154783 -0.65012386 -0.5504675 -0.62896461 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48862 .48425 m
.48933 .48496 L
s
% Start of user PostScript
-0.34150707 -0.47251115 -0.3199901 -0.45112953 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49313 .48936 m
.49354 .4899 L
s
% Start of user PostScript
-0.20606535 -0.3191015 -0.1938511 -0.30299425 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49575 .49304 m
.49599 .49341 L
s
% Start of user PostScript
-0.12745566 -0.20874327 -0.12015823 -0.19770803 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49734 .49552 m
.49749 .49576 L
s
% Start of user PostScript
-0.079876506 -0.13453165 -0.075387203 -0.12726574 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49832 .49713 m
.49841 .49729 L
s
% Start of user PostScript
-0.050398942 -0.086080096 -0.047593429 -0.081382806 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49894 .49817 m
.499 .49827 L
s
% Start of user PostScript
-0.031909389 -0.054883083 -0.030141776 -0.051872969 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49933 .49884 m
.49936 .4989 L
s
% Start of user PostScript
-0.020238066 -0.034930825 -0.019119745 -0.033010194 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49957 .49926 m
.4996 .4993 L
s
% Start of user PostScript
-0.012846886 -0.022212521 -0.012137868 -0.020989664 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49973 .49953 m
.49974 .49956 L
s
% Start of user PostScript
-0.008158613 -0.014118759 -0.0077086195 -0.013340999 MAarrowhead1
% End of user PostScript
1 .656 0 r
.68474 .17454 m
.65995 .21778 L
.63848 .25525 L
.61988 .28774 L
.60377 .3159 L
.58982 .3403 L
.57773 .36146 L
.56727 .3798 L
.5582 .39571 L
.55035 .40949 L
.54356 .42145 L
.53767 .43181 L
.53257 .4408 L
.52816 .4486 L
.52434 .45536 L
.52104 .46122 L
.51818 .4663 L
.5157 .47072 L
.51356 .47454 L
.5117 .47787 L
.5101 .48075 L
.50871 .48325 L
.50751 .48542 L
.50647 .4873 L
.50557 .48894 L
.5048 .49036 L
.50413 .4916 L
.50355 .49267 L
.50305 .4936 L
.50261 .49441 L
.50224 .49512 L
.50192 .49573 L
.50164 .49626 L
.5014 .49673 L
.5012 .49713 L
.50102 .49748 L
.50087 .49779 L
.50073 .49806 L
.50062 .49829 L
.50052 .49849 L
.50044 .49867 L
.50037 .49883 L
.50031 .49896 L
.50025 .49908 L
.50021 .49918 L
.50017 .49928 L
.50014 .49936 L
.50011 .49943 L
.50009 .49949 L
.50007 .49954 L
Mistroke
.50005 .49959 L
.50004 .49963 L
.50003 .49967 L
.50002 .4997 L
.50001 .49973 L
.5 .49976 L
.49999 .49978 L
.49999 .4998 L
.49999 .49982 L
.49998 .49983 L
.49998 .49985 L
.49998 .49986 L
.49998 .49987 L
.49998 .49988 L
.49998 .49989 L
.49998 .4999 L
.49998 .49991 L
.49998 .49992 L
.49998 .49992 L
.49998 .49993 L
.49998 .49993 L
.49998 .49994 L
.49998 .49994 L
.49998 .49995 L
.49998 .49995 L
.49998 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.49999 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
Mistroke
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.68474 .17454 m
.65995 .21778 L
s
% Start of user PostScript
5.5420515 -9.7636882 4.7984248 -8.4666174 MAarrowhead1
% End of user PostScript
1 .158 0 r
.63848 .25525 m
.61988 .28774 L
s
% Start of user PostScript
4.1542827 -7.3423591 3.596332 -6.3678613 MAarrowhead1
% End of user PostScript
1 .473 0 r
.54356 .42145 m
.53767 .43181 L
s
% Start of user PostScript
1.3066595 -2.3565519 1.1300989 -2.0455944 MAarrowhead1
% End of user PostScript
1 .788 0 r
.51356 .47454 m
.5117 .47787 L
s
% Start of user PostScript
0.40666648 -0.76367712 0.35103158 -0.6640454 MAarrowhead1
% End of user PostScript
.897 1 0 r
.50413 .4916 m
.50355 .49267 L
s
% Start of user PostScript
0.12379145 -0.25209536 0.10641175 -0.21991574 MAarrowhead1
% End of user PostScript
.581 1 0 r
.5012 .49713 m
.50102 .49748 L
s
% Start of user PostScript
0.035883405 -0.086093065 0.030550978 -0.075537359 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50031 .49896 m
.50025 .49908 L
s
% Start of user PostScript
0.0092080845 -0.03115974 0.0076345489 -0.027595853 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50005 .49959 m
.50004 .49963 L
s
% Start of user PostScript
0.0015316634 -0.012317043 0.0011084958 -0.011051396 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49999 .49982 m
.49998 .49983 L
s
% Start of user PostScript
-0.00039922304 -0.0054485614 -0.00048486073 -0.0049617857 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49998 .49991 m
.49998 .49992 L
s
% Start of user PostScript
-0.00068974449 -0.0027063581 -0.00068593129 -0.0024979328 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49998 .49995 m
.49998 .49995 L
s
% Start of user PostScript
-0.00057680667 -0.0014794351 -0.00055588229 -0.0013790593 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49999 .49997 m
.49999 .49997 L
s
% Start of user PostScript
-0.00041050824 -0.00086367305 -0.0003913347 -0.0008100834 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49999 .49998 m
.49999 .49998 L
s
% Start of user PostScript
-0.00027480785 -0.0005244902 -0.00026075775 -0.0004936784 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49999 .49999 m
.49999 .49999 L
s
% Start of user PostScript
-0.00017904433 -0.00032552887 -0.00016952399 -0.00030698113 MAarrowhead1
% End of user PostScript
.496 1 0 r
.64014 .71485 m
.63179 .7041 L
.62397 .6938 L
.61667 .68393 L
.60983 .67451 L
.60342 .6655 L
.59741 .65691 L
.59177 .64873 L
.58648 .64093 L
.58151 .63351 L
.57685 .62645 L
.57246 .61974 L
.56834 .61337 L
.56446 .60731 L
.56081 .60157 L
.55737 .59612 L
.55413 .59095 L
.55109 .58604 L
.54821 .5814 L
.54551 .57699 L
.54296 .57282 L
.54056 .56887 L
.53829 .56513 L
.53615 .56158 L
.53414 .55823 L
.53223 .55505 L
.53044 .55205 L
.52875 .54921 L
.52715 .54652 L
.52564 .54397 L
.52422 .54157 L
.52287 .53929 L
.52161 .53714 L
.52041 .5351 L
.51928 .53318 L
.51821 .53136 L
.5172 .52963 L
.51625 .52801 L
.51535 .52647 L
.5145 .52502 L
.5137 .52364 L
.51294 .52234 L
.51223 .52111 L
.51155 .51995 L
.51091 .51885 L
.51031 .51782 L
.50974 .51684 L
.5092 .51591 L
.5087 .51503 L
.50822 .51421 L
Mistroke
.50776 .51342 L
.50733 .51269 L
.50693 .51199 L
.50655 .51133 L
.50619 .5107 L
.50585 .51011 L
.50552 .50956 L
.50522 .50903 L
.50493 .50853 L
.50466 .50806 L
.5044 .50762 L
.50416 .5072 L
.50393 .5068 L
.50371 .50643 L
.50351 .50607 L
.50331 .50574 L
.50313 .50542 L
.50296 .50512 L
.5028 .50484 L
.50264 .50457 L
.5025 .50432 L
.50236 .50408 L
.50223 .50386 L
.50211 .50365 L
.50199 .50345 L
.50188 .50326 L
.50178 .50308 L
.50168 .50291 L
.50159 .50275 L
.5015 .50259 L
.50142 .50245 L
.50134 .50232 L
.50126 .50219 L
.50119 .50207 L
.50113 .50195 L
.50107 .50185 L
.50101 .50174 L
.50095 .50165 L
.5009 .50156 L
.50085 .50147 L
.5008 .50139 L
.50076 .50131 L
.50072 .50124 L
.50068 .50117 L
.50064 .50111 L
.5006 .50105 L
.50057 .50099 L
.50054 .50094 L
.50051 .50088 L
.50048 .50083 L
Mistroke
.50046 .50079 L
.50043 .50075 L
.50041 .5007 L
.50038 .50067 L
.50036 .50063 L
.50034 .50059 L
.50032 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.50019 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50016 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
Mistroke
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.64014 .71485 m
.63179 .7041 L
s
% Start of user PostScript
4.2042486 6.4454821 3.9535768 6.1229831 MAarrowhead1
% End of user PostScript
1 .158 0 r
.62397 .6938 m
.61667 .68393 L
s
% Start of user PostScript
3.7192494 5.8138838 3.5000281 5.5180298 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57685 .62645 m
.57246 .61974 L
s
% Start of user PostScript
2.3054247 3.7935354 2.1738307 3.5922528 MAarrowhead1
% End of user PostScript
1 .788 0 r
.54821 .5814 m
.54551 .57699 L
s
% Start of user PostScript
1.44644 2.4418869 1.3652753 2.3097725 MAarrowhead1
% End of user PostScript
.897 1 0 r
.53044 .55205 m
.52875 .54921 L
s
% Start of user PostScript
0.91317192 1.5615066 0.86238066 1.4762242 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51928 .53318 m
.51821 .53136 L
s
% Start of user PostScript
0.57833008 0.99529277 0.54630685 0.94068194 MAarrowhead1
% End of user PostScript
.266 1 0 r
.51223 .52111 m
.51155 .51995 L
s
% Start of user PostScript
0.36685102 0.63336947 0.34658366 0.59853708 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50776 .51342 m
.50733 .51269 L
s
% Start of user PostScript
0.23288976 0.40273018 0.22003794 0.38055651 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50493 .50853 m
.50466 .50806 L
s
% Start of user PostScript
0.14790565 0.2559746 0.13974825 0.241873 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50313 .50542 m
.50296 .50512 L
s
% Start of user PostScript
0.093952023 0.16266437 0.088771786 0.15370066 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50199 .50345 m
.50188 .50326 L
s
% Start of user PostScript
0.059685799 0.10335808 0.05639537 0.097661664 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50126 .50219 m
.50119 .50207 L
s
% Start of user PostScript
0.037919068 0.065671158 0.03582877 0.062051536 MAarrowhead1
% End of user PostScript
0 .375 1 r
.5008 .50139 m
.50076 .50131 L
s
% Start of user PostScript
0.02409102 0.041724776 0.022763044 0.039424933 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50051 .50088 m
.50048 .50083 L
s
% Start of user PostScript
0.015305876 0.026509888 0.014462181 0.025048655 MAarrowhead1
% End of user PostScript
.782 1 0 r
.30156 .34898 m
.31686 .34975 L
.33073 .35149 L
.34334 .35401 L
.35481 .35714 L
.36527 .36076 L
.37483 .36475 L
.38357 .369 L
.39159 .37346 L
.39895 .37803 L
.40572 .38267 L
.41196 .38734 L
.41771 .39199 L
.42303 .39659 L
.42795 .40112 L
.43251 .40555 L
.43673 .40988 L
.44066 .41408 L
.44431 .41816 L
.44771 .4221 L
.45088 .42589 L
.45384 .42955 L
.4566 .43306 L
.45918 .43643 L
.46159 .43965 L
.46385 .44274 L
.46596 .44568 L
.46794 .44849 L
.4698 .45118 L
.47154 .45373 L
.47318 .45616 L
.47472 .45848 L
.47616 .46068 L
.47752 .46277 L
.4788 .46475 L
.48 .46664 L
.48113 .46843 L
.4822 .47012 L
.4832 .47173 L
.48414 .47326 L
.48503 .4747 L
.48587 .47607 L
.48666 .47737 L
.48741 .4786 L
.48811 .47976 L
.48878 .48087 L
.4894 .48191 L
.48999 .4829 L
.49055 .48383 L
.49107 .48471 L
Mistroke
.49157 .48555 L
.49204 .48634 L
.49248 .48709 L
.4929 .48779 L
.49329 .48846 L
.49366 .4891 L
.49401 .48969 L
.49435 .49026 L
.49466 .49079 L
.49495 .4913 L
.49523 .49178 L
.4955 .49223 L
.49575 .49266 L
.49598 .49306 L
.4962 .49344 L
.49641 .4938 L
.49661 .49414 L
.4968 .49447 L
.49697 .49477 L
.49714 .49506 L
.4973 .49533 L
.49745 .49559 L
.49759 .49583 L
.49772 .49606 L
.49785 .49628 L
.49797 .49648 L
.49808 .49668 L
.49818 .49686 L
.49828 .49703 L
.49838 .4972 L
.49847 .49735 L
.49855 .4975 L
.49863 .49763 L
.49871 .49776 L
.49878 .49789 L
.49885 .498 L
.49891 .49811 L
.49897 .49822 L
.49903 .49832 L
.49908 .49841 L
.49913 .4985 L
.49918 .49858 L
.49922 .49866 L
.49927 .49873 L
.49931 .4988 L
.49935 .49887 L
.49938 .49893 L
.49942 .49899 L
.49945 .49904 L
.49948 .4991 L
Mistroke
.49951 .49915 L
.49953 .49919 L
.49956 .49924 L
.49958 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .49939 L
.49967 .49943 L
.49969 .49946 L
.4997 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49976 .49959 L
.49978 .49961 L
.49979 .49964 L
.4998 .49966 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49982 L
.4999 .49983 L
.4999 .49984 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
Mistroke
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.30156 .34898 m
.31686 .34975 L
s
% Start of user PostScript
-5.9531557 -4.5305804 -5.4942068 -4.5074066 MAarrowhead1
% End of user PostScript
1 .158 0 r
.33073 .35149 m
.34334 .35401 L
s
% Start of user PostScript
-5.0780189 -4.4552631 -4.6999035 -4.379785 MAarrowhead1
% End of user PostScript
1 .473 0 r
.40572 .38267 m
.41196 .38734 L
s
% Start of user PostScript
-2.828409 -3.5197632 -2.6412952 -3.3798034 MAarrowhead1
% End of user PostScript
1 .788 0 r
.44431 .41816 m
.44771 .4221 L
s
% Start of user PostScript
-1.6705753 -2.4552502 -1.5685738 -2.3370907 MAarrowhead1
% End of user PostScript
.897 1 0 r
.46596 .44568 m
.46794 .44849 L
s
% Start of user PostScript
-1.0212108 -1.6295171 -0.96176884 -1.5451544 MAarrowhead1
% End of user PostScript
.581 1 0 r
.4788 .46475 m
.48 .46664 L
s
% Start of user PostScript
-0.63605179 -1.0574168 -0.59999033 -1.0008652 MAarrowhead1
% End of user PostScript
.266 1 0 r
.48666 .47737 m
.48741 .4786 L
s
% Start of user PostScript
-0.400054 -0.67885001 -0.37768426 -0.64198211 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49157 .48555 m
.49204 .48634 L
s
% Start of user PostScript
-0.25288233 -0.4335359 -0.238842 -0.40981399 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49466 .49079 m
.49495 .4913 L
s
% Start of user PostScript
-0.16025738 -0.27615374 -0.15139165 -0.26098745 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49661 .49414 m
.4968 .49447 L
s
% Start of user PostScript
-0.10168826 -0.17567793 -0.096072854 -0.16601202 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49785 .49628 m
.49797 .49648 L
s
% Start of user PostScript
-0.064565577 -0.11168745 -0.061003393 -0.10553671 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49863 .49763 m
.49871 .49776 L
s
% Start of user PostScript
-0.041008158 -0.07098264 -0.038746703 -0.06707177 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49913 .4985 m
.49918 .49858 L
s
% Start of user PostScript
-0.026050079 -0.045105579 -0.024613837 -0.042619868 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49945 .49904 m
.49948 .4991 L
s
% Start of user PostScript
-0.016549415 -0.028659826 -0.015637086 -0.027080239 MAarrowhead1
% End of user PostScript
0 1 .062 r
.77672 .67595 m
.7546 .67814 L
.73462 .67862 L
.71653 .6777 L
.70013 .67564 L
.68523 .67266 L
.67167 .66895 L
.6593 .66467 L
.648 .65995 L
.63766 .65492 L
.62819 .64965 L
.61948 .64424 L
.61148 .63874 L
.6041 .63323 L
.5973 .62773 L
.59101 .62229 L
.5852 .61693 L
.57981 .61169 L
.57481 .60657 L
.57016 .6016 L
.56584 .59678 L
.56182 .59212 L
.55808 .58763 L
.55458 .58331 L
.55132 .57916 L
.54827 .57517 L
.54542 .57136 L
.54275 .56771 L
.54025 .56423 L
.53791 .5609 L
.53571 .55773 L
.53365 .55471 L
.53171 .55184 L
.5299 .5491 L
.52819 .5465 L
.52658 .54403 L
.52507 .54168 L
.52365 .53945 L
.52231 .53733 L
.52105 .53533 L
.51987 .53343 L
.51875 .53162 L
.5177 .52991 L
.5167 .52829 L
.51577 .52676 L
.51489 .5253 L
.51406 .52393 L
.51327 .52263 L
.51253 .52139 L
.51183 .52023 L
Mistroke
.51118 .51912 L
.51055 .51808 L
.50997 .51709 L
.50941 .51615 L
.50889 .51527 L
.5084 .51443 L
.50793 .51364 L
.50749 .51289 L
.50708 .51219 L
.50669 .51152 L
.50632 .51088 L
.50597 .51029 L
.50564 .50972 L
.50533 .50919 L
.50503 .50868 L
.50475 .50821 L
.50449 .50775 L
.50424 .50733 L
.50401 .50692 L
.50379 .50654 L
.50358 .50618 L
.50338 .50584 L
.50319 .50552 L
.50302 .50522 L
.50285 .50493 L
.50269 .50466 L
.50254 .5044 L
.5024 .50416 L
.50227 .50393 L
.50215 .50371 L
.50203 .50351 L
.50192 .50332 L
.50181 .50313 L
.50171 .50296 L
.50162 .5028 L
.50153 .50264 L
.50144 .5025 L
.50136 .50236 L
.50129 .50223 L
.50122 .50211 L
.50115 .50199 L
.50109 .50188 L
.50103 .50178 L
.50097 .50168 L
.50092 .50159 L
.50087 .5015 L
.50082 .50142 L
.50077 .50134 L
.50073 .50127 L
.50069 .5012 L
Mistroke
.50065 .50113 L
.50062 .50107 L
.50058 .50101 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .5008 L
.50044 .50076 L
.50041 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .50061 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50016 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
Mistroke
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.77672 .67595 m
.7546 .67814 L
s
% Start of user PostScript
8.3016062 5.2784786 7.6380886 5.3441897 MAarrowhead1
% End of user PostScript
1 .158 0 r
.73462 .67862 m
.71653 .6777 L
s
% Start of user PostScript
7.038637 5.358661 6.4960497 5.3310743 MAarrowhead1
% End of user PostScript
1 .473 0 r
.62819 .64965 m
.61948 .64424 L
s
% Start of user PostScript
3.845578 4.4894986 3.5844739 4.3271286 MAarrowhead1
% End of user PostScript
1 .788 0 r
.57481 .60657 m
.57016 .6016 L
s
% Start of user PostScript
2.2442162 3.1971303 2.1048995 3.0479421 MAarrowhead1
% End of user PostScript
.897 1 0 r
.54542 .57136 m
.54275 .56771 L
s
% Start of user PostScript
1.3625958 2.1408308 1.2825264 2.0314186 MAarrowhead1
% End of user PostScript
.581 1 0 r
.52819 .5465 m
.52658 .54403 L
s
% Start of user PostScript
0.84561615 1.3949765 0.7974281 1.3208143 MAarrowhead1
% End of user PostScript
.266 1 0 r
.5177 .52991 m
.5167 .52829 L
s
% Start of user PostScript
0.53086927 0.89735198 0.50110607 0.84875651 MAarrowhead1
% End of user PostScript
0 1 .049 r
.51118 .51912 m
.51055 .51808 L
s
% Start of user PostScript
0.33525451 0.57364211 0.31661564 0.54229796 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50708 .51219 m
.50669 .51152 L
s
% Start of user PostScript
0.2123567 0.36557682 0.20060073 0.34551337 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50449 .50775 m
.50424 .50733 L
s
% Start of user PostScript
0.13471444 0.23262178 0.12727273 0.21982721 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50285 .50493 m
.50269 .50466 L
s
% Start of user PostScript
0.085524781 0.14790749 0.080805434 0.13976349 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50181 .50313 m
.50171 .50296 L
s
% Start of user PostScript
0.054316897 0.09400788 0.051321255 0.088828855 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50115 .50199 m
.50109 .50188 L
s
% Start of user PostScript
0.034503298 0.059738666 0.032600915 0.056446686 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50073 .50127 m
.50069 .5012 L
s
% Start of user PostScript
0.021919348 0.03795818 0.020710961 0.035866159 MAarrowhead1
% End of user PostScript
0 1 .395 r
.70674 .49318 m
.68708 .50786 L
.66962 .51982 L
.65407 .52946 L
.6402 .53714 L
.62782 .54316 L
.61674 .54776 L
.60681 .55118 L
.5979 .55361 L
.58988 .5552 L
.58265 .55609 L
.57612 .55641 L
.57022 .55626 L
.56487 .55572 L
.56001 .55487 L
.5556 .55377 L
.55157 .55247 L
.54789 .55102 L
.54453 .54946 L
.54145 .54782 L
.53862 .54612 L
.53602 .5444 L
.53363 .54265 L
.53142 .54091 L
.52939 .53919 L
.5275 .53749 L
.52576 .53582 L
.52414 .53419 L
.52263 .5326 L
.52124 .53106 L
.51994 .52958 L
.51873 .52814 L
.5176 .52676 L
.51654 .52543 L
.51556 .52415 L
.51464 .52293 L
.51378 .52176 L
.51297 .52064 L
.51221 .51958 L
.5115 .51856 L
.51084 .51759 L
.51021 .51667 L
.50963 .51579 L
.50908 .51495 L
.50856 .51416 L
.50807 .5134 L
.50761 .51269 L
.50718 .51201 L
.50678 .51136 L
.5064 .51075 L
Mistroke
.50604 .51017 L
.5057 .50962 L
.50538 .5091 L
.50508 .50861 L
.50479 .50814 L
.50452 .5077 L
.50427 .50728 L
.50403 .50688 L
.50381 .50651 L
.5036 .50615 L
.5034 .50582 L
.50321 .5055 L
.50303 .5052 L
.50286 .50491 L
.5027 .50464 L
.50255 .50439 L
.50241 .50415 L
.50228 .50392 L
.50215 .50371 L
.50203 .5035 L
.50192 .50331 L
.50181 .50313 L
.50171 .50296 L
.50162 .50279 L
.50153 .50264 L
.50145 .5025 L
.50137 .50236 L
.50129 .50223 L
.50122 .50211 L
.50115 .50199 L
.50109 .50188 L
.50103 .50178 L
.50097 .50168 L
.50092 .50159 L
.50087 .5015 L
.50082 .50142 L
.50077 .50134 L
.50073 .50126 L
.50069 .5012 L
.50065 .50113 L
.50062 .50107 L
.50058 .50101 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .5008 L
.50044 .50076 L
.50041 .50072 L
.50039 .50068 L
.50037 .50064 L
Mistroke
.50035 .50061 L
.50033 .50057 L
.50031 .50054 L
.5003 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50016 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
Mistroke
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.70674 .49318 m
.68708 .50786 L
s
% Start of user PostScript
6.2021243 -0.20460334 5.6125463 0.23571876 MAarrowhead1
% End of user PostScript
1 .158 0 r
.66962 .51982 m
.65407 .52946 L
s
% Start of user PostScript
5.0885376 0.59448932 4.6220685 0.88385092 MAarrowhead1
% End of user PostScript
1 .473 0 r
.58265 .55609 m
.57612 .55641 L
s
% Start of user PostScript
2.4794895 1.6827681 2.2837162 1.6923769 MAarrowhead1
% End of user PostScript
1 .788 0 r
.54453 .54946 m
.54145 .54782 L
s
% Start of user PostScript
1.3358899 1.4838525 1.2434732 1.4345898 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52576 .53582 m
.52414 .53419 L
s
% Start of user PostScript
0.77266145 1.0745426 0.72410329 1.0256494 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51556 .52415 m
.51464 .52293 L
s
% Start of user PostScript
0.4667266 0.72458209 0.43910352 0.68792701 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50963 .51579 m
.50908 .51495 L
s
% Start of user PostScript
0.28884822 0.47366637 0.27232387 0.4486011 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50604 .51017 m
.5057 .50962 L
s
% Start of user PostScript
0.18107618 0.3051697 0.17090352 0.28868005 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50381 .50651 m
.5036 .50615 L
s
% Start of user PostScript
0.11426966 0.19523138 0.10791011 0.18457538 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50241 .50415 m
.50228 .50392 L
s
% Start of user PostScript
0.072353904 0.12446599 0.068346323 0.11763876 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50153 .50264 m
.50145 .5025 L
s
% Start of user PostScript
0.045891217 0.079214333 0.043355487 0.074858579 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50097 .50168 m
.50092 .50159 L
s
% Start of user PostScript
0.029131779 0.050371417 0.027524044 0.047598261 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50062 .50107 m
.50058 .50101 L
s
% Start of user PostScript
0.018500768 0.032016845 0.017480361 0.030253109 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50039 .50068 m
.50037 .50064 L
s
% Start of user PostScript
0.011751824 0.020346041 0.011103851 0.019224883 MAarrowhead1
% End of user PostScript
.264 0 1 r
.69928 .76008 m
.68637 .74908 L
.67443 .73824 L
.66337 .72761 L
.65311 .71724 L
.64359 .70714 L
.63473 .69735 L
.62649 .68789 L
.61881 .67875 L
.61165 .66996 L
.60497 .66151 L
.59872 .6534 L
.59288 .64564 L
.58742 .63821 L
.5823 .63111 L
.5775 .62433 L
.57301 .61786 L
.56879 .6117 L
.56483 .60584 L
.56111 .60026 L
.55761 .59495 L
.55433 .5899 L
.55124 .58511 L
.54833 .58056 L
.5456 .57625 L
.54302 .57215 L
.5406 .56827 L
.53831 .56458 L
.53616 .56109 L
.53413 .55779 L
.53222 .55465 L
.53042 .55169 L
.52872 .54888 L
.52712 .54622 L
.52561 .5437 L
.52418 .54132 L
.52283 .53906 L
.52156 .53693 L
.52037 .53491 L
.51923 .533 L
.51817 .53119 L
.51716 .52948 L
.51621 .52787 L
.51531 .52634 L
.51446 .52489 L
.51366 .52353 L
.51291 .52224 L
.51219 .52102 L
.51152 .51986 L
.51088 .51877 L
Mistroke
.51028 .51774 L
.50971 .51676 L
.50917 .51584 L
.50867 .51497 L
.50819 .51415 L
.50774 .51337 L
.50731 .51263 L
.50691 .51194 L
.50652 .51128 L
.50616 .51066 L
.50582 .51007 L
.5055 .50952 L
.5052 .50899 L
.50491 .5085 L
.50464 .50803 L
.50439 .50759 L
.50414 .50717 L
.50391 .50678 L
.5037 .5064 L
.5035 .50605 L
.5033 .50572 L
.50312 .5054 L
.50295 .5051 L
.50279 .50482 L
.50263 .50456 L
.50249 .50431 L
.50235 .50407 L
.50222 .50384 L
.5021 .50363 L
.50198 .50343 L
.50187 .50324 L
.50177 .50306 L
.50167 .5029 L
.50158 .50274 L
.50149 .50258 L
.50141 .50244 L
.50133 .50231 L
.50126 .50218 L
.50119 .50206 L
.50112 .50195 L
.50106 .50184 L
.501 .50174 L
.50095 .50164 L
.5009 .50155 L
.50085 .50147 L
.5008 .50139 L
.50076 .50131 L
.50071 .50124 L
.50067 .50117 L
.50064 .5011 L
Mistroke
.5006 .50104 L
.50057 .50099 L
.50054 .50093 L
.50051 .50088 L
.50048 .50083 L
.50045 .50079 L
.50043 .50074 L
.50041 .5007 L
.50038 .50066 L
.50036 .50063 L
.50034 .50059 L
.50032 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.50019 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
Mistroke
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.69928 .76008 m
.68637 .74908 L
s
% Start of user PostScript
5.9784639 7.80254 5.591166 7.4724921 MAarrowhead1
% End of user PostScript
1 .158 0 r
.67443 .73824 m
.66337 .72761 L
s
% Start of user PostScript
5.2329275 7.147281 4.901117 6.8284233 MAarrowhead1
% End of user PostScript
1 .473 0 r
.60497 .66151 m
.59872 .6534 L
s
% Start of user PostScript
3.14902 4.8452728 2.9616616 4.6020631 MAarrowhead1
% End of user PostScript
1 .788 0 r
.56483 .60584 m
.56111 .60026 L
s
% Start of user PostScript
1.9448802 3.1751092 1.8332968 3.0076777 MAarrowhead1
% End of user PostScript
.897 1 0 r
.5406 .56827 m
.53831 .56458 L
s
% Start of user PostScript
1.2179256 2.0480125 1.1494004 1.9375336 MAarrowhead1
% End of user PostScript
.581 1 0 r
.52561 .5437 m
.52418 .54132 L
s
% Start of user PostScript
0.76816321 1.3109556 0.72537885 1.2394599 MAarrowhead1
% End of user PostScript
.266 1 0 r
.51621 .52787 m
.51531 .52634 L
s
% Start of user PostScript
0.48625583 0.8360098 0.45931225 0.79017123 MAarrowhead1
% End of user PostScript
0 1 .049 r
.51028 .51774 m
.50971 .51676 L
s
% Start of user PostScript
0.30837008 0.53213925 0.29132766 0.50288438 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50652 .51128 m
.50616 .51066 L
s
% Start of user PostScript
0.19573994 0.33840444 0.18493631 0.31977572 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50414 .50717 m
.50391 .50678 L
s
% Start of user PostScript
0.12430457 0.21510255 0.11744823 0.20325363 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50263 .50456 m
.50249 .50431 L
s
% Start of user PostScript
0.078957804 0.1366956 0.074604113 0.12916324 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50167 .5029 m
.50158 .50274 L
s
% Start of user PostScript
0.050159504 0.086858687 0.047394191 0.082071711 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50106 .50184 m
.501 .50174 L
s
% Start of user PostScript
0.031866659 0.055188277 0.030109982 0.052146478 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50067 .50117 m
.50064 .5011 L
s
% Start of user PostScript
0.020245681 0.035064516 0.019129667 0.033131794 MAarrowhead1
% End of user PostScript
1 0 .533 r
.80941 .25148 m
.77461 .29593 L
.74409 .33382 L
.71731 .36606 L
.69378 .39344 L
.6731 .41665 L
.65488 .43626 L
.63883 .45279 L
.62467 .46666 L
.61216 .47827 L
.60109 .48793 L
.59128 .49593 L
.58258 .50251 L
.57485 .50788 L
.56797 .51222 L
.56183 .51568 L
.55636 .5184 L
.55146 .52049 L
.54707 .52205 L
.54313 .52317 L
.53959 .52391 L
.53639 .52434 L
.53351 .52452 L
.53091 .52448 L
.52854 .52427 L
.5264 .52392 L
.52445 .52345 L
.52268 .5229 L
.52106 .52228 L
.51957 .52161 L
.51822 .5209 L
.51697 .52017 L
.51583 .51942 L
.51477 .51866 L
.5138 .5179 L
.51291 .51715 L
.51208 .51641 L
.51131 .51568 L
.5106 .51497 L
.50994 .51428 L
.50932 .51361 L
.50875 .51296 L
.50822 .51233 L
.50772 .51172 L
.50726 .51114 L
.50683 .51058 L
.50642 .51005 L
.50604 .50954 L
.50569 .50905 L
.50536 .50858 L
Mistroke
.50505 .50814 L
.50476 .50771 L
.50448 .50731 L
.50422 .50692 L
.50398 .50656 L
.50375 .50621 L
.50354 .50588 L
.50334 .50556 L
.50315 .50526 L
.50297 .50498 L
.50281 .50471 L
.50265 .50446 L
.5025 .50422 L
.50236 .50399 L
.50223 .50377 L
.5021 .50357 L
.50198 .50338 L
.50187 .50319 L
.50177 .50302 L
.50167 .50285 L
.50158 .5027 L
.50149 .50255 L
.50141 .50241 L
.50133 .50228 L
.50126 .50215 L
.50119 .50204 L
.50112 .50192 L
.50106 .50182 L
.501 .50172 L
.50094 .50163 L
.50089 .50154 L
.50084 .50145 L
.5008 .50137 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50063 .50109 L
.5006 .50103 L
.50057 .50098 L
.50053 .50092 L
.5005 .50087 L
.50048 .50082 L
.50045 .50078 L
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50055 L
.5003 .50052 L
Mistroke
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .50039 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
Mistroke
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.80941 .25148 m
.77461 .29593 L
s
% Start of user PostScript
9.2824073 -7.4554819 8.2382421 -6.1221973 MAarrowhead1
% End of user PostScript
1 .158 0 r
.74409 .33382 m
.71731 .36606 L
s
% Start of user PostScript
7.3227261 -4.9855424 6.5192764 -4.0182391 MAarrowhead1
% End of user PostScript
1 .473 0 r
.60109 .48793 m
.59128 .49593 L
s
% Start of user PostScript
3.0326696 -0.36199791 2.7384546 -0.12198659 MAarrowhead1
% End of user PostScript
1 .788 0 r
.54707 .52205 m
.54313 .52317 L
s
% Start of user PostScript
1.4120614 0.66153666 1.2938532 0.69500077 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52445 .52345 m
.52268 .5229 L
s
% Start of user PostScript
0.73357675 0.70360911 0.68031134 0.68704694 MAarrowhead1
% End of user PostScript
.581 1 0 r
.5138 .5179 m
.51291 .51715 L
s
% Start of user PostScript
0.41409549 0.5370611 0.38719304 0.5145191 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50822 .51233 m
.50772 .51172 L
s
% Start of user PostScript
0.24657559 0.36982678 0.23168846 0.35168542 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50505 .50814 m
.50476 .50771 L
s
% Start of user PostScript
0.15141138 0.24405808 0.14265369 0.23131835 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50315 .50526 m
.50297 .50498 L
s
% Start of user PostScript
0.094530275 0.15794959 0.089188815 0.1494698 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50198 .50338 m
.50187 .50319 L
s
% Start of user PostScript
0.059529148 0.10127024 0.05620625 0.095760102 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50126 .50215 m
.50119 .50204 L
s
% Start of user PostScript
0.037653014 0.064633096 0.03556432 0.061093317 MAarrowhead1
% End of user PostScript
0 .69 1 r
.5008 .50137 m
.50075 .5013 L
s
% Start of user PostScript
0.023869067 0.041156907 0.022549174 0.038895556 MAarrowhead1
% End of user PostScript
0 .375 1 r
.5005 .50087 m
.50048 .50082 L
s
% Start of user PostScript
0.015148043 0.026178223 0.014311729 0.024737556 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50032 .50055 m
.5003 .50052 L
s
% Start of user PostScript
0.0096188023 0.016641519 0.0090881773 0.015724951 MAarrowhead1
% End of user PostScript
1 0 .855 r
.73937 .66617 m
.72055 .66675 L
.70352 .66599 L
.68809 .66415 L
.67406 .66144 L
.6613 .65803 L
.64966 .65407 L
.63903 .6497 L
.62931 .64502 L
.62039 .64012 L
.61221 .63508 L
.60468 .62996 L
.59775 .62481 L
.59136 .61967 L
.58545 .61459 L
.57998 .60958 L
.57492 .60467 L
.57022 .59989 L
.56586 .59523 L
.5618 .59072 L
.55803 .58636 L
.55451 .58215 L
.55123 .57811 L
.54816 .57422 L
.5453 .57049 L
.54262 .56691 L
.54012 .5635 L
.53777 .56023 L
.53557 .55711 L
.53351 .55414 L
.53157 .55131 L
.52976 .54861 L
.52805 .54605 L
.52645 .54361 L
.52494 .54129 L
.52352 .53909 L
.52219 .537 L
.52093 .53502 L
.51975 .53314 L
.51864 .53135 L
.51759 .52966 L
.5166 .52806 L
.51567 .52654 L
.51479 .5251 L
.51397 .52373 L
.51319 .52244 L
.51245 .52122 L
.51176 .52007 L
.5111 .51897 L
.51048 .51794 L
Mistroke
.5099 .51696 L
.50935 .51603 L
.50883 .51515 L
.50834 .51432 L
.50788 .51354 L
.50744 .5128 L
.50703 .51209 L
.50664 .51143 L
.50627 .5108 L
.50593 .51021 L
.5056 .50965 L
.50529 .50912 L
.505 .50862 L
.50472 .50814 L
.50446 .5077 L
.50421 .50727 L
.50398 .50687 L
.50376 .5065 L
.50355 .50614 L
.50336 .5058 L
.50317 .50548 L
.503 .50518 L
.50283 .50489 L
.50267 .50462 L
.50253 .50437 L
.50239 .50413 L
.50226 .5039 L
.50213 .50369 L
.50201 .50348 L
.5019 .50329 L
.5018 .50311 L
.5017 .50294 L
.5016 .50278 L
.50152 .50262 L
.50143 .50248 L
.50135 .50234 L
.50128 .50221 L
.50121 .50209 L
.50114 .50198 L
.50108 .50187 L
.50102 .50176 L
.50096 .50167 L
.50091 .50158 L
.50086 .50149 L
.50081 .50141 L
.50077 .50133 L
.50073 .50126 L
.50069 .50119 L
.50065 .50112 L
.50061 .50106 L
Mistroke
.50058 .501 L
.50055 .50095 L
.50052 .50089 L
.50049 .50084 L
.50046 .5008 L
.50044 .50075 L
.50041 .50071 L
.50039 .50067 L
.50037 .50064 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .5003 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .5002 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
Mistroke
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.73937 .66617 m
.72055 .66675 L
s
% Start of user PostScript
7.1810589 4.9851171 6.6165866 5.0024291 MAarrowhead1
% End of user PostScript
1 .158 0 r
.70352 .66599 m
.68809 .66415 L
s
% Start of user PostScript
6.1057438 4.9797896 5.6425684 4.9246073 MAarrowhead1
% End of user PostScript
1 .473 0 r
.61221 .63508 m
.60468 .62996 L
s
% Start of user PostScript
3.3662663 4.0523779 3.140477 3.8986969 MAarrowhead1
% End of user PostScript
1 .788 0 r
.56586 .59523 m
.5618 .59072 L
s
% Start of user PostScript
1.9757232 2.8569952 1.8540326 2.7216601 MAarrowhead1
% End of user PostScript
.897 1 0 r
.54012 .5635 m
.53777 .56023 L
s
% Start of user PostScript
1.2034614 1.9048948 1.1330619 1.806932 MAarrowhead1
% End of user PostScript
.581 1 0 r
.52494 .54129 m
.52352 .53909 L
s
% Start of user PostScript
0.74814998 1.2387735 0.70561982 1.1727271 MAarrowhead1
% End of user PostScript
.266 1 0 r
.51567 .52654 m
.51479 .5251 L
s
% Start of user PostScript
0.47010112 0.79610668 0.44377823 0.7529349 MAarrowhead1
% End of user PostScript
0 1 .049 r
.5099 .51696 m
.50935 .51603 L
s
% Start of user PostScript
0.29701332 0.50868015 0.28051118 0.48086686 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50627 .5108 m
.50593 .51021 L
s
% Start of user PostScript
0.18817719 0.32410143 0.17776318 0.30630829 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50398 .50687 m
.50376 .5065 L
s
% Start of user PostScript
0.11938925 0.2062064 0.1127952 0.19486284 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50253 .50437 m
.50239 .50413 L
s
% Start of user PostScript
0.075799819 0.13110424 0.07161745 0.12388485 MAarrowhead1
% End of user PostScript
0 .69 1 r
.5016 .50278 m
.50152 .50262 L
s
% Start of user PostScript
0.048141954 0.083325555 0.045486977 0.078734844 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50102 .50176 m
.50096 .50167 L
s
% Start of user PostScript
0.03058128 0.05294966 0.028895178 0.050031737 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50065 .50112 m
.50061 .50106 L
s
% Start of user PostScript
0.019427899 0.033644175 0.018356874 0.031789897 MAarrowhead1
% End of user PostScript
0 .602 1 r
.25039 .3141 m
.26973 .31469 L
.28725 .31654 L
.30317 .3194 L
.31765 .32307 L
.33084 .32738 L
.34289 .33218 L
.35391 .33734 L
.36401 .34276 L
.37327 .34836 L
.3818 .35406 L
.38964 .3598 L
.39688 .36553 L
.40356 .37121 L
.40974 .37681 L
.41547 .3823 L
.42078 .38767 L
.42571 .39288 L
.43029 .39794 L
.43455 .40284 L
.43853 .40756 L
.44223 .4121 L
.44569 .41647 L
.44893 .42066 L
.45195 .42468 L
.45477 .42852 L
.45742 .43219 L
.4599 .4357 L
.46223 .43904 L
.46441 .44222 L
.46646 .44526 L
.46839 .44814 L
.47019 .45089 L
.47189 .4535 L
.47349 .45598 L
.475 .45833 L
.47641 .46056 L
.47774 .46268 L
.479 .46469 L
.48018 .46659 L
.48129 .4684 L
.48234 .47011 L
.48333 .47173 L
.48426 .47326 L
.48514 .47472 L
.48597 .47609 L
.48675 .4774 L
.48749 .47863 L
.48819 .4798 L
.48885 .4809 L
Mistroke
.48947 .48194 L
.49005 .48293 L
.4906 .48387 L
.49112 .48475 L
.49162 .48559 L
.49208 .48638 L
.49252 .48712 L
.49293 .48783 L
.49332 .4885 L
.49369 .48913 L
.49404 .48973 L
.49437 .49029 L
.49468 .49082 L
.49498 .49133 L
.49525 .49181 L
.49552 .49226 L
.49576 .49268 L
.496 .49309 L
.49622 .49347 L
.49643 .49383 L
.49662 .49417 L
.49681 .49449 L
.49699 .49479 L
.49715 .49508 L
.49731 .49535 L
.49746 .4956 L
.4976 .49585 L
.49773 .49607 L
.49786 .49629 L
.49797 .4965 L
.49809 .49669 L
.49819 .49687 L
.49829 .49704 L
.49839 .49721 L
.49848 .49736 L
.49856 .49751 L
.49864 .49764 L
.49871 .49777 L
.49878 .4979 L
.49885 .49801 L
.49891 .49812 L
.49897 .49822 L
.49903 .49832 L
.49908 .49841 L
.49914 .4985 L
.49918 .49858 L
.49923 .49866 L
.49927 .49874 L
.49931 .49881 L
.49935 .49887 L
Mistroke
.49938 .49893 L
.49942 .49899 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
.49956 .49924 L
.49959 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49977 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
Mistroke
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.25039 .3141 m
.26973 .31469 L
s
% Start of user PostScript
-7.4881528 -5.5768717 -6.9081074 -5.5592195 MAarrowhead1
% End of user PostScript
1 .158 0 r
.28725 .31654 m
.30317 .3194 L
s
% Start of user PostScript
-6.382369 -5.5038565 -5.9049625 -5.4180257 MAarrowhead1
% End of user PostScript
1 .473 0 r
.3818 .35406 m
.38964 .3598 L
s
% Start of user PostScript
-3.546138 -4.3782049 -3.310757 -4.2060042 MAarrowhead1
% End of user PostScript
1 .788 0 r
.43029 .39794 m
.43455 .40284 L
s
% Start of user PostScript
-2.0913125 -3.0617397 -1.9633532 -2.914941 MAarrowhead1
% End of user PostScript
.897 1 0 r
.45742 .43219 m
.4599 .4357 L
s
% Start of user PostScript
-1.2773163 -2.0342573 -1.2028785 -1.9291073 MAarrowhead1
% End of user PostScript
.581 1 0 r
.47349 .45598 m
.475 .45833 L
s
% Start of user PostScript
-0.7952054 -1.3207342 -0.75009185 -1.250152 MAarrowhead1
% End of user PostScript
.266 1 0 r
.48333 .47173 m
.48426 .47326 L
s
% Start of user PostScript
-0.50003948 -0.84810705 -0.47206964 -0.80206323 MAarrowhead1
% End of user PostScript
0 1 .049 r
.48947 .48194 m
.49005 .48293 L
s
% Start of user PostScript
-0.3160478 -0.54169511 -0.2984975 -0.51206019 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49332 .4885 m
.49369 .48913 L
s
% Start of user PostScript
-0.20027486 -0.34506991 -0.18919435 -0.3261204 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49576 .49268 m
.496 .49309 L
s
% Start of user PostScript
-0.12707678 -0.21952625 -0.12005908 -0.2074483 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49731 .49535 m
.49746 .4956 L
s
% Start of user PostScript
-0.080684463 -0.13956617 -0.076232879 -0.13188029 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49829 .49704 m
.49839 .49721 L
s
% Start of user PostScript
-0.051245516 -0.088701553 -0.048419478 -0.083814492 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49891 .49812 m
.49897 .49822 L
s
% Start of user PostScript
-0.032553151 -0.05636519 -0.03075836 -0.053258993 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49931 .49881 m
.49935 .49887 L
s
% Start of user PostScript
-0.020680728 -0.035814185 -0.019540646 -0.033840291 MAarrowhead1
% End of user PostScript
0 .03 1 r
.57574 .338 m
.56493 .35842 L
.5556 .37618 L
.54755 .39163 L
.54062 .40508 L
.53464 .41679 L
.52949 .42699 L
.52505 .43588 L
.52124 .44363 L
.51796 .45038 L
.51515 .45628 L
.51273 .46143 L
.51065 .46594 L
.50888 .46987 L
.50736 .47332 L
.50606 .47633 L
.50495 .47898 L
.50401 .48129 L
.50321 .48333 L
.50253 .48512 L
.50195 .4867 L
.50147 .48808 L
.50106 .48931 L
.50072 .49039 L
.50043 .49134 L
.5002 .49219 L
.5 .49294 L
.49984 .49361 L
.49971 .4942 L
.49961 .49473 L
.49953 .4952 L
.49946 .49562 L
.49941 .49599 L
.49938 .49633 L
.49935 .49664 L
.49934 .49691 L
.49933 .49716 L
.49933 .49738 L
.49933 .49758 L
.49934 .49776 L
.49935 .49793 L
.49937 .49808 L
.49938 .49822 L
.4994 .49834 L
.49942 .49846 L
.49944 .49857 L
.49946 .49866 L
.49948 .49875 L
.4995 .49884 L
.49952 .49891 L
Mistroke
.49954 .49898 L
.49956 .49905 L
.49958 .49911 L
.4996 .49916 L
.49962 .49921 L
.49964 .49926 L
.49966 .49931 L
.49967 .49935 L
.49969 .49939 L
.4997 .49943 L
.49972 .49946 L
.49973 .49949 L
.49975 .49952 L
.49976 .49955 L
.49977 .49958 L
.49978 .4996 L
.4998 .49962 L
.49981 .49964 L
.49982 .49967 L
.49983 .49968 L
.49984 .4997 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49987 .49976 L
.49988 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.49991 .49983 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
Mistroke
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.57574 .338 m
.56493 .35842 L
s
% Start of user PostScript
2.2720519 -4.8600672 1.9477916 -4.247458 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5556 .37618 m
.54755 .39163 L
s
% Start of user PostScript
1.6679757 -3.7146387 1.4266071 -3.2510667 MAarrowhead1
% End of user PostScript
1 .473 0 r
.51515 .45628 m
.51273 .46143 L
s
% Start of user PostScript
0.45435398 -1.3115163 0.38182496 -1.1569783 MAarrowhead1
% End of user PostScript
1 .788 0 r
.50321 .48333 m
.50253 .48512 L
s
% Start of user PostScript
0.096294808 -0.50005814 0.075897525 -0.4463587 MAarrowhead1
% End of user PostScript
.897 1 0 r
.5 .49294 m
.49984 .49361 L
s
% Start of user PostScript
0.000047901918 -0.21182423 -0.0047497757 -0.19184295 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49935 .49664 m
.49934 .49691 L
s
% Start of user PostScript
-0.01939593 -0.10093365 -0.019850546 -0.092730851 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49938 .49822 m
.4994 .49834 L
s
% Start of user PostScript
-0.018496296 -0.053435181 -0.017960965 -0.049651089 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49954 .49898 m
.49956 .49905 L
s
% Start of user PostScript
-0.013713196 -0.030551921 -0.013111176 -0.028601349 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49969 .49939 m
.4997 .49943 L
s
% Start of user PostScript
-0.0093359667 -0.018331232 -0.008870252 -0.0172361 MAarrowhead1
% End of user PostScript
0 1 .679 r
.4998 .49962 m
.49981 .49964 L
s
% Start of user PostScript
-0.0061296384 -0.011303515 -0.0058073027 -0.010653537 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49987 .49976 m
.49988 .49978 L
s
% Start of user PostScript
-0.0039573742 -0.0070725799 -0.0037441761 -0.0066741779 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49992 .49985 m
.49992 .49986 L
s
% Start of user PostScript
-0.002534295 -0.0044588684 -0.0023961703 -0.004210372 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49995 .49991 m
.49995 .49991 L
s
% Start of user PostScript
-0.001616504 -0.0028219018 -0.0015278988 -0.0026654913 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49997 .49994 m
.49997 .49994 L
s
% Start of user PostScript
-0.0010290549 -0.0017893776 -0.00097249054 -0.0016904703 MAarrowhead1
% End of user PostScript
0 .596 1 r
.71628 .46059 m
.69499 .47899 L
.67612 .49421 L
.65938 .50671 L
.6445 .51689 L
.63125 .52511 L
.61944 .53165 L
.60889 .53678 L
.59946 .5407 L
.591 .54361 L
.5834 .54568 L
.57657 .54703 L
.57041 .54779 L
.56485 .54806 L
.55982 .54793 L
.55527 .54747 L
.55113 .54675 L
.54736 .54581 L
.54393 .5447 L
.5408 .54347 L
.53794 .54214 L
.53531 .54074 L
.5329 .5393 L
.53069 .53782 L
.52865 .53634 L
.52677 .53486 L
.52503 .53339 L
.52343 .53194 L
.52194 .53052 L
.52056 .52913 L
.51928 .52778 L
.51809 .52647 L
.51699 .5252 L
.51595 .52397 L
.51499 .5228 L
.51409 .52166 L
.51325 .52058 L
.51247 .51954 L
.51174 .51854 L
.51105 .51759 L
.5104 .51668 L
.5098 .51581 L
.50923 .51499 L
.5087 .5142 L
.5082 .51345 L
.50773 .51274 L
.50729 .51206 L
.50688 .51142 L
.50649 .51081 L
.50612 .51023 L
Mistroke
.50577 .50968 L
.50545 .50916 L
.50514 .50867 L
.50485 .5082 L
.50458 .50775 L
.50432 .50733 L
.50408 .50694 L
.50385 .50656 L
.50364 .5062 L
.50344 .50586 L
.50325 .50554 L
.50306 .50524 L
.50289 .50496 L
.50273 .50468 L
.50258 .50443 L
.50244 .50419 L
.5023 .50396 L
.50218 .50374 L
.50205 .50353 L
.50194 .50334 L
.50183 .50316 L
.50173 .50298 L
.50164 .50282 L
.50155 .50267 L
.50146 .50252 L
.50138 .50238 L
.5013 .50225 L
.50123 .50213 L
.50116 .50201 L
.5011 .5019 L
.50104 .50179 L
.50098 .5017 L
.50093 .5016 L
.50088 .50151 L
.50083 .50143 L
.50078 .50135 L
.50074 .50128 L
.5007 .50121 L
.50066 .50114 L
.50062 .50108 L
.50059 .50102 L
.50056 .50096 L
.50053 .50091 L
.5005 .50086 L
.50047 .50081 L
.50044 .50077 L
.50042 .50072 L
.5004 .50068 L
.50037 .50065 L
.50035 .50061 L
Mistroke
.50033 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50022 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
Mistroke
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.71628 .46059 m
.69499 .47899 L
s
% Start of user PostScript
6.4883352 -1.1823515 5.8496391 -0.63038477 MAarrowhead1
% End of user PostScript
1 .158 0 r
.67612 .49421 m
.65938 .50671 L
s
% Start of user PostScript
5.2836709 -0.17383357 4.7814124 0.2012382 MAarrowhead1
% End of user PostScript
1 .473 0 r
.5834 .54568 m
.57657 .54703 L
s
% Start of user PostScript
2.5020469 1.3702825 2.2970752 1.4108944 MAarrowhead1
% End of user PostScript
1 .788 0 r
.54393 .5447 m
.5408 .54347 L
s
% Start of user PostScript
1.3179931 1.3411384 1.224035 1.3041207 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52503 .53339 m
.52343 .53194 L
s
% Start of user PostScript
0.75104939 1.0016089 0.70287921 0.9581272 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51499 .5228 m
.51409 .52166 L
s
% Start of user PostScript
0.44974105 0.68388103 0.42279896 0.64991159 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50923 .51499 m
.5087 .5142 L
s
% Start of user PostScript
0.27702237 0.4495985 0.26106875 0.42600038 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50577 .50968 m
.50545 .50916 L
s
% Start of user PostScript
0.17323407 0.29044756 0.16346789 0.27481407 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50364 .5062 m
.50344 .50586 L
s
% Start of user PostScript
0.10918279 0.18605865 0.10309544 0.17592245 MAarrowhead1
% End of user PostScript
0 1 .679 r
.5023 .50396 m
.50218 .50374 L
s
% Start of user PostScript
0.069088808 0.11869564 0.065258601 0.11219098 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50146 .50252 m
.50138 .50238 L
s
% Start of user PostScript
0.043806215 0.075566447 0.041384586 0.071413202 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50093 .5016 m
.50088 .50151 L
s
% Start of user PostScript
0.027803735 0.048059562 0.026268941 0.045414293 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50059 .50102 m
.50056 .50096 L
s
% Start of user PostScript
0.017655939 0.030549867 0.016682017 0.028867138 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50037 .50065 m
.50035 .50061 L
s
% Start of user PostScript
0.01121473 0.019414594 0.010596335 0.018344823 MAarrowhead1
% End of user PostScript
.849 1 0 r
.52675 .24438 m
.51844 .2703 L
.5115 .29322 L
.50574 .3135 L
.50098 .33148 L
.49707 .34744 L
.4939 .36163 L
.49134 .37427 L
.48931 .38554 L
.48773 .39561 L
.48653 .40462 L
.48564 .4127 L
.48502 .41996 L
.48462 .42649 L
.48441 .43238 L
.48435 .4377 L
.48441 .44251 L
.48458 .44688 L
.48483 .45084 L
.48515 .45445 L
.48552 .45773 L
.48593 .46074 L
.48637 .46349 L
.48683 .466 L
.4873 .46832 L
.48778 .47044 L
.48827 .4724 L
.48875 .47421 L
.48923 .47588 L
.4897 .47742 L
.49016 .47885 L
.49061 .48018 L
.49104 .48141 L
.49147 .48255 L
.49188 .48362 L
.49227 .48461 L
.49265 .48554 L
.49302 .48641 L
.49337 .48721 L
.49371 .48797 L
.49403 .48868 L
.49433 .48934 L
.49463 .48996 L
.49491 .49054 L
.49517 .49109 L
.49543 .4916 L
.49567 .49208 L
.4959 .49254 L
.49612 .49296 L
.49632 .49336 L
Mistroke
.49652 .49374 L
.49671 .49409 L
.49688 .49443 L
.49705 .49474 L
.49721 .49504 L
.49736 .49531 L
.4975 .49558 L
.49764 .49583 L
.49777 .49606 L
.49789 .49628 L
.498 .49649 L
.49811 .49668 L
.49822 .49687 L
.49831 .49704 L
.4984 .49721 L
.49849 .49736 L
.49857 .49751 L
.49865 .49765 L
.49873 .49778 L
.4988 .4979 L
.49886 .49802 L
.49892 .49813 L
.49898 .49823 L
.49904 .49833 L
.49909 .49842 L
.49914 .49851 L
.49919 .49859 L
.49923 .49867 L
.49928 .49874 L
.49932 .49881 L
.49935 .49888 L
.49939 .49894 L
.49942 .499 L
.49945 .49905 L
.49948 .49911 L
.49951 .49915 L
.49954 .4992 L
.49956 .49925 L
.49959 .49929 L
.49961 .49933 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .4996 L
.49978 .49962 L
Mistroke
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .4997 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .4998 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.52675 .24438 m
.51844 .2703 L
s
% Start of user PostScript
0.80240797 -7.6687225 0.55320164 -6.8909826 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5115 .29322 m
.50574 .3135 L
s
% Start of user PostScript
0.3450977 -6.2035118 0.172177 -5.5950062 MAarrowhead1
% End of user PostScript
1 .473 0 r
.48653 .40462 m
.48564 .4127 L
s
% Start of user PostScript
-0.40424072 -2.8614324 -0.4308636 -2.6190002 MAarrowhead1
% End of user PostScript
1 .788 0 r
.48483 .45084 m
.48515 .45445 L
s
% Start of user PostScript
-0.45496344 -1.4748174 -0.44542612 -1.366606 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48827 .4724 m
.48875 .47421 L
s
% Start of user PostScript
-0.3520194 -0.82796293 -0.33755413 -0.77377079 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49188 .48362 m
.49227 .48461 L
s
% Start of user PostScript
-0.24366076 -0.4913865 -0.23179919 -0.46158246 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49463 .48996 m
.49491 .49054 L
s
% Start of user PostScript
-0.16116615 -0.30118686 -0.15278115 -0.28372128 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49652 .49374 m
.49671 .49409 L
s
% Start of user PostScript
-0.10441622 -0.18785762 -0.098819135 -0.17722818 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49777 .49606 m
.49789 .49628 L
s
% Start of user PostScript
-0.066982174 -0.11824205 -0.063340388 -0.11163716 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49857 .49751 m
.49865 .49765 L
s
% Start of user PostScript
-0.042760696 -0.074770912 -0.040419673 -0.070621723 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49909 .49842 m
.49914 .49851 L
s
% Start of user PostScript
-0.027232553 -0.047392902 -0.025736545 -0.044771735 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49942 .499 m
.49945 .49905 L
s
% Start of user PostScript
-0.017322622 -0.030075077 -0.016369392 -0.0284145 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49963 .49936 m
.49965 .4994 L
s
% Start of user PostScript
-0.011012358 -0.019096658 -0.010405856 -0.018043136 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49977 .4996 m
.49978 .49962 L
s
% Start of user PostScript
-0.0069987082 -0.01212933 -0.0066130934 -0.011460463 MAarrowhead1
% End of user PostScript
0 .099 1 r
.45016 .3411 m
.45126 .35271 L
.45253 .36329 L
.45391 .37296 L
.45538 .38181 L
.45692 .38993 L
.45849 .39739 L
.46008 .40425 L
.46168 .41057 L
.46327 .4164 L
.46484 .42179 L
.46639 .42678 L
.4679 .43141 L
.46938 .4357 L
.47081 .43968 L
.4722 .44339 L
.47354 .44684 L
.47483 .45006 L
.47608 .45306 L
.47727 .45586 L
.47842 .45848 L
.47951 .46093 L
.48056 .46323 L
.48156 .46538 L
.48252 .46739 L
.48343 .46928 L
.4843 .47105 L
.48512 .47272 L
.48591 .47428 L
.48666 .47575 L
.48736 .47713 L
.48804 .47843 L
.48868 .47965 L
.48929 .4808 L
.48986 .48189 L
.49041 .48291 L
.49093 .48387 L
.49142 .48477 L
.49188 .48563 L
.49232 .48643 L
.49274 .48719 L
.49313 .4879 L
.49351 .48858 L
.49386 .48922 L
.4942 .48982 L
.49451 .49038 L
.49481 .49092 L
.4951 .49142 L
.49537 .4919 L
.49562 .49235 L
Mistroke
.49586 .49277 L
.49609 .49317 L
.4963 .49355 L
.4965 .49391 L
.4967 .49425 L
.49688 .49456 L
.49705 .49486 L
.49721 .49515 L
.49736 .49542 L
.49751 .49567 L
.49765 .49591 L
.49778 .49614 L
.4979 .49635 L
.49801 .49655 L
.49812 .49674 L
.49823 .49692 L
.49832 .49709 L
.49842 .49725 L
.4985 .4974 L
.49859 .49755 L
.49866 .49768 L
.49874 .49781 L
.49881 .49793 L
.49887 .49804 L
.49893 .49815 L
.49899 .49825 L
.49905 .49835 L
.4991 .49844 L
.49915 .49853 L
.4992 .49861 L
.49924 .49869 L
.49928 .49876 L
.49932 .49883 L
.49936 .49889 L
.4994 .49895 L
.49943 .49901 L
.49946 .49906 L
.49949 .49912 L
.49952 .49917 L
.49954 .49921 L
.49957 .49925 L
.49959 .4993 L
.49962 .49933 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
Mistroke
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49984 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.45016 .3411 m
.45126 .35271 L
s
% Start of user PostScript
-1.4952072 -4.7668922 -1.4620532 -4.4188074 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45253 .36329 m
.45391 .37296 L
s
% Start of user PostScript
-1.4241497 -4.1013013 -1.3826365 -3.8111675 MAarrowhead1
% End of user PostScript
1 .473 0 r
.46484 .42179 m
.46639 .42678 L
s
% Start of user PostScript
-1.0546743 -2.3461858 -1.008293 -2.1965028 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47608 .45306 m
.47727 .45586 L
s
% Start of user PostScript
-0.71769897 -1.4081552 -0.68187354 -1.3240665 MAarrowhead1
% End of user PostScript
.897 1 0 r
.4843 .47105 m
.48512 .47272 L
s
% Start of user PostScript
-0.47111729 -0.86845242 -0.4463356 -0.81852639 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48986 .48189 m
.49041 .48291 L
s
% Start of user PostScript
-0.3041298 -0.54343666 -0.28774294 -0.51282844 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49351 .48858 m
.49386 .48922 L
s
% Start of user PostScript
-0.19475488 -0.34262215 -0.18413959 -0.32352878 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49586 .49277 m
.49609 .49317 L
s
% Start of user PostScript
-0.12422178 -0.21684163 -0.1174126 -0.20482307 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49736 .49542 m
.49751 .49567 L
s
% Start of user PostScript
-0.079077779 -0.13750161 -0.074731012 -0.12990138 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49832 .49709 m
.49842 .49725 L
s
% Start of user PostScript
-0.050290569 -0.087275793 -0.047522334 -0.082458375 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49893 .49815 m
.49899 .49825 L
s
% Start of user PostScript
-0.031967357 -0.055423099 -0.030206497 -0.052365988 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49932 .49883 m
.49936 .49889 L
s
% Start of user PostScript
-0.020315197 -0.035204117 -0.019195785 -0.033262947 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49957 .49925 m
.49959 .4993 L
s
% Start of user PostScript
-0.012908697 -0.022363973 -0.012197276 -0.021131028 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49973 .49953 m
.49974 .49955 L
s
% Start of user PostScript
-0.0082019539 -0.014207934 -0.0077498906 -0.013424706 MAarrowhead1
% End of user PostScript
.852 0 1 r
.30325 .79443 m
.32846 .75331 L
.35037 .71777 L
.36941 .68708 L
.38596 .66057 L
.40035 .63768 L
.41287 .61793 L
.42375 .60089 L
.43323 .5862 L
.44147 .57354 L
.44866 .56263 L
.45492 .55324 L
.46037 .54516 L
.46513 .53821 L
.46929 .53224 L
.47291 .52711 L
.47608 .52272 L
.47885 .51895 L
.48127 .51573 L
.4834 .51297 L
.48526 .51062 L
.48689 .50862 L
.48832 .50692 L
.48958 .50547 L
.49068 .50425 L
.49166 .50321 L
.49252 .50235 L
.49328 .50162 L
.49395 .50101 L
.49454 .5005 L
.49507 .50008 L
.49553 .49974 L
.49595 .49946 L
.49632 .49924 L
.49665 .49906 L
.49694 .49892 L
.49721 .49882 L
.49744 .49874 L
.49766 .49868 L
.49785 .49865 L
.49802 .49863 L
.49818 .49862 L
.49832 .49863 L
.49844 .49865 L
.49856 .49867 L
.49867 .4987 L
.49876 .49873 L
.49885 .49876 L
.49893 .4988 L
.499 .49884 L
Mistroke
.49907 .49888 L
.49913 .49893 L
.49919 .49897 L
.49924 .49901 L
.49929 .49905 L
.49934 .49909 L
.49938 .49914 L
.49942 .49917 L
.49946 .49921 L
.49949 .49925 L
.49952 .49929 L
.49955 .49932 L
.49958 .49935 L
.4996 .49939 L
.49963 .49942 L
.49965 .49945 L
.49967 .49948 L
.49969 .4995 L
.49971 .49953 L
.49972 .49955 L
.49974 .49958 L
.49975 .4996 L
.49977 .49962 L
.49978 .49964 L
.49979 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49985 .49975 L
.49986 .49977 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
Mistroke
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.30325 .79443 m
.32846 .75331 L
s
% Start of user PostScript
-5.9026424 8.8329965 -5.1460665 7.5992248 MAarrowhead1
% End of user PostScript
1 .158 0 r
.35037 .71777 m
.36941 .68708 L
s
% Start of user PostScript
-4.4887642 6.5331746 -3.9175775 5.6122883 MAarrowhead1
% End of user PostScript
1 .473 0 r
.44866 .56263 m
.45492 .55324 L
s
% Start of user PostScript
-1.540241 1.8789377 -1.3524578 1.5971696 MAarrowhead1
% End of user PostScript
1 .788 0 r
.48127 .51573 m
.4834 .51297 L
s
% Start of user PostScript
-0.56176668 0.47182561 -0.49810765 0.38919079 MAarrowhead1
% End of user PostScript
.897 1 0 r
.49252 .50235 m
.49328 .50162 L
s
% Start of user PostScript
-0.22446108 0.070354853 -0.20169923 0.048482074 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49665 .49906 m
.49694 .49892 L
s
% Start of user PostScript
-0.10051933 -0.028203418 -0.091677117 -0.032367091 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49832 .49863 m
.49844 .49865 L
s
% Start of user PostScript
-0.050488946 -0.041085606 -0.046656808 -0.040638044 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49907 .49888 m
.49913 .49893 L
s
% Start of user PostScript
-0.027827459 -0.03346529 -0.025960189 -0.032198079 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49946 .49921 m
.49949 .49925 L
s
% Start of user PostScript
-0.016329331 -0.023601355 -0.015323296 -0.022483914 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49967 .49948 m
.49969 .4995 L
s
% Start of user PostScript
-0.0099455248 -0.015738369 -0.0093636488 -0.01492916 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49979 .49966 m
.49981 .49968 L
s
% Start of user PostScript
-0.0061824311 -0.010235503 -0.0058309493 -0.0096898384 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49987 .49978 m
.49988 .49979 L
s
% Start of user PostScript
-0.0038846243 -0.0065781282 -0.0036670991 -0.0062214214 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49992 .49986 m
.49992 .49987 L
s
% Start of user PostScript
-0.002454297 -0.0042032249 -0.0023179326 -0.0039734088 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49995 .49991 m
.49995 .49992 L
s
% Start of user PostScript
-0.0015549444 -0.0026780714 -0.0014688905 -0.0025310472 MAarrowhead1
% End of user PostScript
.707 1 0 r
.57184 .31087 m
.56079 .33358 L
.55129 .3534 L
.54313 .37071 L
.53614 .38583 L
.53015 .39905 L
.52502 .41062 L
.52064 .42075 L
.5169 .42962 L
.51371 .43741 L
.511 .44424 L
.5087 .45025 L
.50676 .45553 L
.50511 .46018 L
.50373 .46429 L
.50257 .46791 L
.5016 .47111 L
.5008 .47394 L
.50013 .47645 L
.49959 .47868 L
.49914 .48067 L
.49879 .48243 L
.4985 .48401 L
.49828 .48541 L
.49811 .48667 L
.49799 .4878 L
.4979 .48882 L
.49785 .48973 L
.49782 .49055 L
.49781 .49129 L
.49782 .49197 L
.49784 .49258 L
.49788 .49313 L
.49792 .49363 L
.49798 .49409 L
.49803 .49451 L
.49809 .4949 L
.49816 .49525 L
.49822 .49557 L
.49829 .49587 L
.49836 .49614 L
.49843 .4964 L
.49849 .49663 L
.49856 .49684 L
.49862 .49704 L
.49869 .49723 L
.49875 .4974 L
.49881 .49756 L
.49886 .49771 L
.49892 .49785 L
Mistroke
.49897 .49798 L
.49902 .4981 L
.49907 .49821 L
.49912 .49832 L
.49917 .49842 L
.49921 .49851 L
.49925 .4986 L
.49929 .49868 L
.49933 .49875 L
.49936 .49883 L
.49939 .49889 L
.49943 .49896 L
.49946 .49902 L
.49949 .49907 L
.49951 .49912 L
.49954 .49917 L
.49956 .49922 L
.49959 .49926 L
.49961 .49931 L
.49963 .49935 L
.49965 .49938 L
.49967 .49942 L
.49969 .49945 L
.4997 .49948 L
.49972 .49951 L
.49974 .49954 L
.49975 .49956 L
.49976 .49959 L
.49978 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
Mistroke
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
Mistroke
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.57184 .31087 m
.56079 .33358 L
s
% Start of user PostScript
2.1552799 -5.6740229 1.8236147 -4.9925731 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55129 .3534 m
.54313 .37071 L
s
% Start of user PostScript
1.53865 -4.3979085 1.2940176 -3.8786737 MAarrowhead1
% End of user PostScript
1 .473 0 r
.511 .44424 m
.5087 .45025 L
s
% Start of user PostScript
0.33008458 -1.6727023 0.26110301 -1.4925353 MAarrowhead1
% End of user PostScript
1 .788 0 r
.50013 .47645 m
.49959 .47868 L
s
% Start of user PostScript
0.0039617191 -0.70636152 -0.012395479 -0.63947269 MAarrowhead1
% End of user PostScript
.897 1 0 r
.4979 .48882 m
.49785 .48973 L
s
% Start of user PostScript
-0.062866938 -0.33553365 -0.064530152 -0.30815573 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49798 .49409 m
.49803 .49451 L
s
% Start of user PostScript
-0.060719515 -0.17719148 -0.059002294 -0.1646017 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49849 .49663 m
.49856 .49684 L
s
% Start of user PostScript
-0.045180293 -0.10114145 -0.043207781 -0.094669401 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49897 .49798 m
.49902 .4981 L
s
% Start of user PostScript
-0.030803126 -0.060625472 -0.029269789 -0.056998671 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49933 .49875 m
.49936 .49883 L
s
% Start of user PostScript
-0.020237294 -0.037363168 -0.019174084 -0.035213081 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49956 .49922 m
.49959 .49926 L
s
% Start of user PostScript
-0.0130695 -0.023371464 -0.012365711 -0.022054414 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49972 .49951 m
.49974 .49954 L
s
% Start of user PostScript
-0.0083709468 -0.014732288 -0.0079148102 -0.013911078 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49982 .49969 m
.49983 .49971 L
s
% Start of user PostScript
-0.0053398198 -0.0093230025 -0.0050471601 -0.0088061997 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49989 .4998 m
.49989 .49981 L
s
% Start of user PostScript
-0.0033994174 -0.005911531 -0.0032125704 -0.005584756 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49993 .49987 m
.49993 .49988 L
s
% Start of user PostScript
-0.0021619575 -0.0037521093 -0.002042957 -0.0035449946 MAarrowhead1
% End of user PostScript
1 .811 0 r
.7559 .2508 m
.72612 .29168 L
.70008 .32667 L
.67729 .3566 L
.65732 .38216 L
.63982 .40396 L
.62446 .42251 L
.61097 .43826 L
.5991 .45162 L
.58866 .46291 L
.57946 .47243 L
.57134 .48042 L
.56417 .48711 L
.55783 .49268 L
.55221 .4973 L
.54722 .5011 L
.54279 .5042 L
.53885 .50671 L
.53534 .50871 L
.5322 .51029 L
.5294 .51151 L
.52689 .51242 L
.52463 .51307 L
.52261 .51351 L
.52078 .51377 L
.51913 .51388 L
.51764 .51387 L
.51629 .51376 L
.51507 .51357 L
.51395 .51331 L
.51294 .513 L
.51201 .51266 L
.51116 .51228 L
.51039 .51188 L
.50968 .51146 L
.50902 .51104 L
.50842 .51061 L
.50787 .51018 L
.50736 .50975 L
.50688 .50933 L
.50645 .50892 L
.50604 .50852 L
.50566 .50812 L
.50531 .50774 L
.50499 .50737 L
.50468 .50702 L
.5044 .50667 L
.50414 .50634 L
.50389 .50602 L
.50366 .50572 L
Mistroke
.50344 .50543 L
.50324 .50515 L
.50305 .50489 L
.50288 .50463 L
.50271 .50439 L
.50255 .50416 L
.50241 .50394 L
.50227 .50373 L
.50214 .50353 L
.50202 .50335 L
.5019 .50317 L
.50179 .503 L
.50169 .50284 L
.5016 .50268 L
.50151 .50254 L
.50142 .5024 L
.50134 .50227 L
.50127 .50215 L
.5012 .50203 L
.50113 .50192 L
.50107 .50182 L
.50101 .50172 L
.50095 .50163 L
.5009 .50154 L
.50085 .50145 L
.5008 .50137 L
.50076 .5013 L
.50071 .50123 L
.50068 .50116 L
.50064 .5011 L
.5006 .50104 L
.50057 .50098 L
.50054 .50093 L
.50051 .50087 L
.50048 .50083 L
.50045 .50078 L
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50056 L
.5003 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .5004 L
.50022 .50037 L
.5002 .50035 L
Mistroke
.50019 .50033 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
Mistroke
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.7559 .2508 m
.72612 .29168 L
s
% Start of user PostScript
7.6768577 -7.4759386 6.7836557 -6.2497158 MAarrowhead1
% End of user PostScript
1 .158 0 r
.70008 .32667 m
.67729 .3566 L
s
% Start of user PostScript
6.0024423 -5.1997773 5.3186664 -4.3018948 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57946 .47243 m
.57134 .48042 L
s
% Start of user PostScript
2.3838362 -0.82720033 2.1402888 -0.58735925 MAarrowhead1
% End of user PostScript
1 .788 0 r
.53534 .50871 m
.5322 .51029 L
s
% Start of user PostScript
1.0602068 0.26139677 0.96612917 0.30871445 MAarrowhead1
% End of user PostScript
.897 1 0 r
.51764 .51387 m
.51629 .51376 L
s
% Start of user PostScript
0.52921476 0.41615103 0.48871898 0.41282732 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50968 .51146 m
.50902 .51104 L
s
% Start of user PostScript
0.29035246 0.34386626 0.27074912 0.33114509 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50566 .50812 m
.50531 .50774 L
s
% Start of user PostScript
0.16989376 0.24372594 0.1593854 0.2322722 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50344 .50543 m
.50324 .50515 L
s
% Start of user PostScript
0.10330778 0.16287436 0.097249912 0.15452595 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50214 .50353 m
.50202 .50335 L
s
% Start of user PostScript
0.064163622 0.10603119 0.060511358 0.10038663 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50134 .50227 m
.50127 .50215 L
s
% Start of user PostScript
0.040298071 0.068176553 0.038040092 0.064482133 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50085 .50145 m
.5008 .50137 L
s
% Start of user PostScript
0.025454436 0.043573023 0.024039693 0.041191419 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50054 .50093 m
.50051 .50087 L
s
% Start of user PostScript
0.01612506 0.027765657 0.01523252 0.026241596 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50034 .50059 m
.50032 .50056 L
s
% Start of user PostScript
0.010229935 0.017666727 0.0096648703 0.016694953 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50022 .50037 m
.5002 .50035 L
s
% Start of user PostScript
0.0064947498 0.011232699 0.0061363765 0.010614186 MAarrowhead1
% End of user PostScript
1 0 .097 r
.26934 .59164 m
.29317 .56734 L
.3142 .54695 L
.33279 .52991 L
.34923 .51573 L
.36381 .50402 L
.37675 .49439 L
.38824 .48655 L
.39848 .48023 L
.40761 .47521 L
.41576 .47127 L
.42305 .46826 L
.42959 .46603 L
.43547 .46446 L
.44075 .46343 L
.44551 .46286 L
.44981 .46266 L
.4537 .46277 L
.45722 .46314 L
.46042 .46371 L
.46333 .46445 L
.46599 .46531 L
.46841 .46628 L
.47063 .46731 L
.47266 .4684 L
.47452 .46953 L
.47623 .47067 L
.47781 .47182 L
.47927 .47297 L
.48061 .47412 L
.48185 .47524 L
.48301 .47634 L
.48407 .47742 L
.48506 .47847 L
.48599 .47949 L
.48684 .48047 L
.48764 .48142 L
.48839 .48233 L
.48908 .48321 L
.48973 .48405 L
.49034 .48486 L
.49091 .48563 L
.49144 .48637 L
.49194 .48707 L
.49241 .48775 L
.49285 .48839 L
.49326 .489 L
.49364 .48958 L
.49401 .49013 L
.49435 .49065 L
Mistroke
.49467 .49115 L
.49497 .49162 L
.49526 .49207 L
.49553 .4925 L
.49578 .4929 L
.49602 .49328 L
.49624 .49365 L
.49645 .49399 L
.49665 .49432 L
.49684 .49463 L
.49701 .49492 L
.49718 .49519 L
.49734 .49546 L
.49749 .4957 L
.49763 .49594 L
.49776 .49616 L
.49788 .49637 L
.498 .49657 L
.49811 .49676 L
.49822 .49693 L
.49831 .4971 L
.49841 .49726 L
.4985 .49741 L
.49858 .49755 L
.49866 .49769 L
.49873 .49781 L
.4988 .49793 L
.49887 .49805 L
.49893 .49816 L
.49899 .49826 L
.49905 .49835 L
.4991 .49844 L
.49915 .49853 L
.4992 .49861 L
.49924 .49869 L
.49928 .49876 L
.49932 .49883 L
.49936 .49889 L
.49939 .49895 L
.49943 .49901 L
.49946 .49906 L
.49949 .49912 L
.49952 .49916 L
.49954 .49921 L
.49957 .49925 L
.49959 .4993 L
.49962 .49933 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
Mistroke
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49984 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
Mistroke
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.26934 .59164 m
.29317 .56734 L
s
% Start of user PostScript
-6.919717 2.7491214 -6.2048825 2.0201021 MAarrowhead1
% End of user PostScript
1 .158 0 r
.3142 .54695 m
.33279 .52991 L
s
% Start of user PostScript
-5.5739633 1.4083656 -5.0163911 0.89715372 MAarrowhead1
% End of user PostScript
1 .473 0 r
.41576 .47127 m
.42305 .46826 L
s
% Start of user PostScript
-2.5272141 -0.86179145 -2.3083626 -0.95206975 MAarrowhead1
% End of user PostScript
1 .788 0 r
.45722 .46314 m
.46042 .46371 L
s
% Start of user PostScript
-1.2833714 -1.1057337 -1.1873518 -1.0885677 MAarrowhead1
% End of user PostScript
.897 1 0 r
.47623 .47067 m
.47781 .47182 L
s
% Start of user PostScript
-0.71296962 -0.87990284 -0.66563693 -0.84531478 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48599 .47949 m
.48684 .48047 L
s
% Start of user PostScript
-0.42043651 -0.61540812 -0.39470885 -0.58590733 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49144 .48637 m
.49194 .48707 L
s
% Start of user PostScript
-0.25677984 -0.4089077 -0.24181463 -0.38777316 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49467 .49115 m
.49497 .49162 L
s
% Start of user PostScript
-0.15985701 -0.26548885 -0.15078772 -0.25130122 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49665 .49432 m
.49684 .49463 L
s
% Start of user PostScript
-0.10051976 -0.17048536 -0.09489707 -0.16122986 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49788 .49637 m
.498 .49657 L
s
% Start of user PostScript
-0.063532698 -0.10889152 -0.060004663 -0.10293436 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49866 .49769 m
.49873 .49781 L
s
% Start of user PostScript
-0.040259616 -0.069366151 -0.038032182 -0.065556924 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49915 .49853 m
.4992 .49861 L
s
% Start of user PostScript
-0.025545165 -0.044129361 -0.024134453 -0.041701445 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49946 .49906 m
.49949 .49912 L
s
% Start of user PostScript
-0.0162193 -0.028055737 -0.015324435 -0.026510715 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49966 .49941 m
.49968 .49944 L
s
% Start of user PostScript
-0.010301439 -0.017830885 -0.0097333446 -0.016848483 MAarrowhead1
% End of user PostScript
1 0 .444 r
.20675 .73942 m
.23983 .69693 L
.26882 .6607 L
.29426 .62985 L
.3166 .60363 L
.33625 .58141 L
.35353 .56262 L
.36876 .54677 L
.3822 .53345 L
.39407 .5223 L
.40456 .513 L
.41386 .5053 L
.4221 .49895 L
.42942 .49376 L
.43594 .48956 L
.44175 .48619 L
.44693 .48354 L
.45156 .48149 L
.45571 .47995 L
.45943 .47883 L
.46278 .47808 L
.46579 .47762 L
.46851 .47741 L
.47097 .4774 L
.4732 .47756 L
.47522 .47786 L
.47706 .47826 L
.47873 .47876 L
.48025 .47932 L
.48165 .47993 L
.48292 .48057 L
.48409 .48125 L
.48517 .48194 L
.48616 .48263 L
.48707 .48333 L
.48791 .48403 L
.48869 .48471 L
.48941 .48539 L
.49008 .48605 L
.4907 .48669 L
.49128 .48731 L
.49181 .48792 L
.49231 .4885 L
.49278 .48906 L
.49321 .4896 L
.49362 .49012 L
.49399 .49062 L
.49435 .4911 L
.49468 .49155 L
.49499 .49199 L
Mistroke
.49528 .49241 L
.49555 .4928 L
.49581 .49318 L
.49605 .49354 L
.49628 .49388 L
.49649 .4942 L
.49669 .49451 L
.49688 .49481 L
.49706 .49508 L
.49722 .49535 L
.49738 .4956 L
.49753 .49583 L
.49767 .49606 L
.4978 .49627 L
.49792 .49647 L
.49804 .49667 L
.49815 .49685 L
.49825 .49702 L
.49835 .49718 L
.49844 .49733 L
.49853 .49748 L
.49861 .49762 L
.49869 .49775 L
.49876 .49787 L
.49883 .49799 L
.49889 .4981 L
.49895 .4982 L
.49901 .4983 L
.49907 .49839 L
.49912 .49848 L
.49917 .49857 L
.49921 .49864 L
.49926 .49872 L
.4993 .49879 L
.49934 .49886 L
.49937 .49892 L
.49941 .49898 L
.49944 .49903 L
.49947 .49909 L
.4995 .49914 L
.49953 .49918 L
.49955 .49923 L
.49958 .49927 L
.4996 .49931 L
.49962 .49935 L
.49964 .49939 L
.49966 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
Mistroke
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
Mistroke
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.20675 .73942 m
.23983 .69693 L
s
% Start of user PostScript
-8.797405 7.1825771 -7.8051577 5.9079552 MAarrowhead1
% End of user PostScript
1 .158 0 r
.26882 .6607 m
.29426 .62985 L
s
% Start of user PostScript
-6.9353355 4.8209059 -6.1721477 3.8954277 MAarrowhead1
% End of user PostScript
1 .473 0 r
.40456 .513 m
.41386 .5053 L
s
% Start of user PostScript
-2.8631479 0.39007965 -2.5842857 0.15892764 MAarrowhead1
% End of user PostScript
1 .788 0 r
.45571 .47995 m
.45943 .47883 L
s
% Start of user PostScript
-1.3286998 -0.60153187 -1.2169961 -0.63499638 MAarrowhead1
% End of user PostScript
.897 1 0 r
.47706 .47826 m
.47873 .47876 L
s
% Start of user PostScript
-0.68834916 -0.65208704 -0.63818351 -0.6373139 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48707 .48333 m
.48791 .48403 L
s
% Start of user PostScript
-0.38781862 -0.5000692 -0.3625574 -0.47923227 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49231 .4885 m
.49278 .48906 L
s
% Start of user PostScript
-0.23066191 -0.34497123 -0.21671323 -0.32809381 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49528 .49241 m
.49555 .4928 L
s
% Start of user PostScript
-0.14154896 -0.22783632 -0.13335437 -0.21595704 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49706 .49508 m
.49722 .49535 L
s
% Start of user PostScript
-0.088343135 -0.14750658 -0.083348906 -0.13959171 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49815 .49685 m
.49825 .49702 L
s
% Start of user PostScript
-0.055623257 -0.094591931 -0.052517623 -0.089446502 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49883 .49799 m
.49889 .4981 L
s
% Start of user PostScript
-0.035179398 -0.060376279 -0.033227678 -0.057070059 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49926 .49872 m
.4993 .49879 L
s
% Start of user PostScript
-0.022300003 -0.038447982 -0.021066798 -0.036335607 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49953 .49918 m
.49955 .49923 L
s
% Start of user PostScript
-0.014151953 -0.024455733 -0.013370608 -0.023109902 MAarrowhead1
% End of user PostScript
0 .06 1 r
.4997 .49948 m
.49972 .49951 L
s
% Start of user PostScript
-0.0089861988 -0.015546704 -0.0084904639 -0.014690449 MAarrowhead1
% End of user PostScript
0 1 .681 r
.27431 .22929 m
.28947 .2395 L
.30344 .24978 L
.31631 .26003 L
.32821 .2702 L
.33921 .28021 L
.3494 .29002 L
.35885 .2996 L
.36763 .30892 L
.37579 .31796 L
.38339 .32669 L
.39046 .33512 L
.39706 .34324 L
.40322 .35103 L
.40898 .35851 L
.41436 .36568 L
.4194 .37253 L
.42412 .37909 L
.42854 .38534 L
.43268 .3913 L
.43657 .39698 L
.44022 .40239 L
.44365 .40754 L
.44688 .41244 L
.4499 .41709 L
.45275 .42151 L
.45543 .4257 L
.45796 .42969 L
.46033 .43346 L
.46257 .43705 L
.46467 .44044 L
.46666 .44366 L
.46853 .44671 L
.47029 .4496 L
.47195 .45234 L
.47352 .45493 L
.47499 .45738 L
.47639 .4597 L
.4777 .4619 L
.47894 .46398 L
.48012 .46595 L
.48122 .46781 L
.48226 .46957 L
.48325 .47124 L
.48418 .47281 L
.48505 .4743 L
.48588 .47571 L
.48666 .47704 L
.4874 .4783 L
.4881 .47949 L
Mistroke
.48876 .48062 L
.48938 .48169 L
.48997 .48269 L
.49052 .48364 L
.49105 .48454 L
.49154 .48539 L
.49201 .4862 L
.49245 .48696 L
.49287 .48767 L
.49326 .48835 L
.49363 .48899 L
.49398 .4896 L
.49432 .49017 L
.49463 .49071 L
.49493 .49122 L
.49521 .49171 L
.49547 .49216 L
.49572 .49259 L
.49596 .493 L
.49618 .49339 L
.49639 .49375 L
.49659 .4941 L
.49678 .49442 L
.49695 .49473 L
.49712 .49502 L
.49728 .49529 L
.49743 .49555 L
.49757 .4958 L
.49771 .49603 L
.49783 .49625 L
.49795 .49646 L
.49807 .49665 L
.49817 .49684 L
.49827 .49701 L
.49837 .49717 L
.49846 .49733 L
.49854 .49748 L
.49862 .49762 L
.4987 .49775 L
.49877 .49787 L
.49884 .49799 L
.4989 .4981 L
.49896 .4982 L
.49902 .4983 L
.49907 .4984 L
.49913 .49849 L
.49917 .49857 L
.49922 .49865 L
.49926 .49872 L
.4993 .49879 L
Mistroke
.49934 .49886 L
.49938 .49892 L
.49941 .49898 L
.49944 .49904 L
.49948 .49909 L
.4995 .49914 L
.49953 .49919 L
.49956 .49923 L
.49958 .49928 L
.4996 .49932 L
.49963 .49935 L
.49965 .49939 L
.49967 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49978 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
Mistroke
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.27431 .22929 m
.28947 .2395 L
s
% Start of user PostScript
-6.7705601 -8.1213897 -6.3157712 -7.8150404 MAarrowhead1
% End of user PostScript
1 .158 0 r
.30344 .24978 m
.31631 .26003 L
s
% Start of user PostScript
-5.8969433 -7.5067113 -5.5106399 -7.1990303 MAarrowhead1
% End of user PostScript
1 .473 0 r
.38339 .32669 m
.39046 .33512 L
s
% Start of user PostScript
-3.4984133 -5.1991815 -3.2861105 -4.9463114 MAarrowhead1
% End of user PostScript
1 .788 0 r
.42854 .38534 m
.43268 .3913 L
s
% Start of user PostScript
-2.143831 -3.4398585 -2.0194746 -3.260963 MAarrowhead1
% End of user PostScript
.897 1 0 r
.45543 .4257 m
.45796 .42969 L
s
% Start of user PostScript
-1.3370081 -2.2288971 -1.2613448 -2.109442 MAarrowhead1
% End of user PostScript
.581 1 0 r
.47195 .45234 m
.47352 .45493 L
s
% Start of user PostScript
-0.8414955 -1.4299081 -0.79448652 -1.3521716 MAarrowhead1
% End of user PostScript
.266 1 0 r
.48226 .46957 m
.48325 .47124 L
s
% Start of user PostScript
-0.53210786 -0.91286572 -0.50257889 -0.86289117 MAarrowhead1
% End of user PostScript
0 1 .049 r
.48876 .48062 m
.48938 .48169 L
s
% Start of user PostScript
-0.33726698 -0.58137597 -0.3186133 -0.54943902 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49287 .48767 m
.49326 .48835 L
s
% Start of user PostScript
-0.21402476 -0.36981593 -0.20220739 -0.34946591 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49547 .49216 m
.49572 .49259 L
s
% Start of user PostScript
-0.13589798 -0.23510072 -0.12840074 -0.22215269 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49712 .49502 m
.49728 .49529 L
s
% Start of user PostScript
-0.086316064 -0.14941436 -0.081556185 -0.14118195 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49817 .49684 m
.49827 .49701 L
s
% Start of user PostScript
-0.05483213 -0.09494361 -0.051809068 -0.089711308 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49884 .49799 m
.4989 .4981 L
s
% Start of user PostScript
-0.034834619 -0.060326297 -0.032914285 -0.057001387 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49926 .49872 m
.4993 .49879 L
s
% Start of user PostScript
-0.022131113 -0.038329341 -0.020911152 -0.03621669 MAarrowhead1
% End of user PostScript
0 1 .111 r
.6697 .50516 m
.65381 .51619 L
.63967 .52511 L
.62707 .53222 L
.61581 .53781 L
.60574 .5421 L
.59672 .54531 L
.58863 .5476 L
.58135 .54913 L
.57478 .55002 L
.56886 .55038 L
.56351 .5503 L
.55866 .54987 L
.55425 .54915 L
.55025 .54819 L
.5466 .54706 L
.54327 .54579 L
.54022 .5444 L
.53744 .54295 L
.53488 .54144 L
.53253 .5399 L
.53036 .53834 L
.52836 .53679 L
.52652 .53524 L
.52482 .53372 L
.52324 .53222 L
.52178 .53076 L
.52042 .52934 L
.51916 .52796 L
.51798 .52662 L
.51689 .52533 L
.51587 .52409 L
.51492 .52289 L
.51403 .52175 L
.5132 .52065 L
.51242 .5196 L
.51169 .51859 L
.51101 .51763 L
.51037 .51672 L
.50977 .51584 L
.50921 .51501 L
.50868 .51422 L
.50818 .51347 L
.50772 .51276 L
.50728 .51208 L
.50686 .51143 L
.50648 .51082 L
.50611 .51024 L
.50576 .50969 L
.50544 .50917 L
Mistroke
.50513 .50867 L
.50485 .5082 L
.50457 .50776 L
.50432 .50734 L
.50408 .50694 L
.50385 .50656 L
.50364 .5062 L
.50343 .50586 L
.50324 .50554 L
.50306 .50524 L
.50289 .50495 L
.50273 .50468 L
.50258 .50443 L
.50244 .50418 L
.5023 .50396 L
.50217 .50374 L
.50205 .50353 L
.50194 .50334 L
.50183 .50316 L
.50173 .50298 L
.50163 .50282 L
.50154 .50266 L
.50146 .50252 L
.50138 .50238 L
.5013 .50225 L
.50123 .50212 L
.50116 .50201 L
.5011 .5019 L
.50104 .50179 L
.50098 .50169 L
.50093 .5016 L
.50088 .50151 L
.50083 .50143 L
.50078 .50135 L
.50074 .50128 L
.5007 .50121 L
.50066 .50114 L
.50062 .50108 L
.50059 .50102 L
.50056 .50096 L
.50053 .50091 L
.5005 .50086 L
.50047 .50081 L
.50044 .50077 L
.50042 .50072 L
.5004 .50068 L
.50037 .50065 L
.50035 .50061 L
.50033 .50058 L
.50032 .50055 L
Mistroke
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
Mistroke
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.6697 .50516 m
.65381 .51619 L
s
% Start of user PostScript
5.0909929 0.15481568 4.6143434 0.48581141 MAarrowhead1
% End of user PostScript
1 .158 0 r
.63967 .52511 m
.62707 .53222 L
s
% Start of user PostScript
4.1901384 0.75323267 3.8119931 0.96663558 MAarrowhead1
% End of user PostScript
1 .473 0 r
.56886 .55038 m
.56351 .5503 L
s
% Start of user PostScript
2.0659015 1.5113394 1.9052564 1.5090403 MAarrowhead1
% End of user PostScript
1 .788 0 r
.53744 .54295 m
.53488 .54144 L
s
% Start of user PostScript
1.1230752 1.2884108 1.0463074 1.2431343 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52178 .53076 m
.52042 .52934 L
s
% Start of user PostScript
0.65332568 0.92287439 0.61259062 0.88018464 MAarrowhead1
% End of user PostScript
.581 1 0 r
.5132 .52065 m
.51242 .5196 L
s
% Start of user PostScript
0.395952 0.61948323 0.37262579 0.587936 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50818 .51347 m
.50772 .51276 L
s
% Start of user PostScript
0.2454851 0.40411597 0.23147671 0.38266662 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50513 .50867 m
.50485 .5082 L
s
% Start of user PostScript
0.15403512 0.260099 0.14539295 0.2460245 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50324 .50554 m
.50306 .50524 L
s
% Start of user PostScript
0.097251178 0.16631563 0.091842405 0.15723151 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50205 .50353 m
.50194 .50334 L
s
% Start of user PostScript
0.061592767 0.10600546 0.058182389 0.10018881 MAarrowhead1
% End of user PostScript
0 1 .995 r
.5013 .50225 m
.50123 .50212 L
s
% Start of user PostScript
0.039070548 0.06745725 0.036912065 0.063747342 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50083 .50143 m
.50078 .50135 L
s
% Start of user PostScript
0.024803507 0.042892637 0.02343476 0.040531015 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50053 .50091 m
.5005 .50086 L
s
% Start of user PostScript
0.01575248 0.027262393 0.014883692 0.025760505 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50033 .50058 m
.50032 .50055 L
s
% Start of user PostScript
0.010006243 0.017324424 0.0094545294 0.016369749 MAarrowhead1
% End of user PostScript
1 .128 0 r
.63255 .31315 m
.61582 .33977 L
.60127 .36275 L
.58861 .38257 L
.5776 .39966 L
.56801 .41439 L
.55966 .42708 L
.55238 .43801 L
.54604 .44741 L
.54051 .45549 L
.53568 .46244 L
.53146 .46841 L
.52778 .47352 L
.52456 .4779 L
.52175 .48166 L
.51928 .48486 L
.51712 .4876 L
.51522 .48993 L
.51356 .49191 L
.5121 .4936 L
.51081 .49502 L
.50968 .49623 L
.50868 .49724 L
.5078 .49809 L
.50702 .4988 L
.50633 .49939 L
.50572 .49988 L
.50518 .50028 L
.5047 .5006 L
.50427 .50086 L
.50388 .50107 L
.50354 .50123 L
.50324 .50136 L
.50296 .50145 L
.50271 .50151 L
.50249 .50156 L
.50229 .50158 L
.50211 .50159 L
.50195 .50158 L
.5018 .50156 L
.50167 .50154 L
.50154 .50151 L
.50143 .50147 L
.50133 .50143 L
.50124 .50138 L
.50115 .50134 L
.50107 .50129 L
.501 .50124 L
.50094 .50119 L
.50087 .50114 L
Mistroke
.50082 .50109 L
.50077 .50105 L
.50072 .501 L
.50067 .50095 L
.50063 .50091 L
.50059 .50087 L
.50055 .50082 L
.50052 .50078 L
.50049 .50075 L
.50046 .50071 L
.50043 .50067 L
.50041 .50064 L
.50038 .50061 L
.50036 .50058 L
.50034 .50055 L
.50032 .50052 L
.5003 .50049 L
.50028 .50046 L
.50027 .50044 L
.50025 .50042 L
.50024 .50039 L
.50022 .50037 L
.50021 .50035 L
.5002 .50033 L
.50019 .50032 L
.50018 .5003 L
.50017 .50028 L
.50016 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50013 .50021 L
.50012 .5002 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
Mistroke
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.63255 .31315 m
.61582 .33977 L
s
% Start of user PostScript
3.976488 -5.6054799 3.474608 -4.8068637 MAarrowhead1
% End of user PostScript
1 .158 0 r
.60127 .36275 m
.58861 .38257 L
s
% Start of user PostScript
3.0381335 -4.1176381 2.6584206 -3.5230458 MAarrowhead1
% End of user PostScript
1 .473 0 r
.53568 .46244 m
.53146 .46841 L
s
% Start of user PostScript
1.070371 -1.1267462 0.94392383 -0.94781697 MAarrowhead1
% End of user PostScript
1 .788 0 r
.51356 .49191 m
.5121 .4936 L
s
% Start of user PostScript
0.4068021 -0.24258613 0.36294566 -0.19209146 MAarrowhead1
% End of user PostScript
.897 1 0 r
.50572 .49988 m
.50518 .50028 L
s
% Start of user PostScript
0.17162653 -0.0037272645 0.15535538 0.0082749675 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50271 .50151 m
.50249 .50156 L
s
% Start of user PostScript
0.081448541 0.04542477 0.074794662 0.046669625 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50143 .50147 m
.50133 .50143 L
s
% Start of user PostScript
0.042979333 0.044047722 0.039922485 0.042811008 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50082 .50109 m
.50077 .50105 L
s
% Start of user PostScript
0.024520232 0.032811607 0.022950088 0.03138154 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50049 .50075 m
.50046 .50071 L
s
% Start of user PostScript
0.014693315 0.022380277 0.013813949 0.021266941 MAarrowhead1
% End of user PostScript
0 1 .679 r
.5003 .50049 m
.50028 .50046 L
s
% Start of user PostScript
0.009053925 0.014706512 0.0085327907 0.013934097 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50019 .50032 m
.50018 .5003 L
s
% Start of user PostScript
0.0056629366 0.0094985529 0.0053437747 0.0089871277 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50012 .5002 m
.50011 .50019 L
s
% Start of user PostScript
0.0035694952 0.0060840553 0.0033705112 0.0057525544 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50008 .50013 m
.50007 .50012 L
s
% Start of user PostScript
0.0022588256 0.0038811025 0.002133608 0.0036683977 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50005 .50008 m
.50005 .50008 L
s
% Start of user PostScript
0.0014322604 0.002470802 0.0013530873 0.002334998 MAarrowhead1
% End of user PostScript
.17 1 0 r
.78435 .73971 m
.76295 .73641 L
.7435 .73196 L
.72578 .72661 L
.70962 .72057 L
.69484 .71399 L
.6813 .70704 L
.66889 .69982 L
.65748 .69244 L
.64698 .68498 L
.63731 .67751 L
.62837 .67009 L
.62012 .66276 L
.61247 .65557 L
.60538 .64853 L
.5988 .64167 L
.59269 .63502 L
.587 .62858 L
.58171 .62236 L
.57677 .61636 L
.57216 .6106 L
.56786 .60507 L
.56384 .59977 L
.56007 .59469 L
.55655 .58984 L
.55325 .5852 L
.55016 .58078 L
.54725 .57657 L
.54453 .57255 L
.54197 .56873 L
.53957 .5651 L
.53731 .56165 L
.53519 .55837 L
.53319 .55525 L
.53131 .55229 L
.52954 .54948 L
.52787 .54682 L
.5263 .5443 L
.52482 .54191 L
.52343 .53964 L
.52212 .53749 L
.52088 .53546 L
.51971 .53353 L
.51861 .53171 L
.51758 .52998 L
.5166 .52834 L
.51567 .5268 L
.5148 .52533 L
.51398 .52395 L
.5132 .52264 L
Mistroke
.51247 .5214 L
.51178 .52023 L
.51112 .51912 L
.51051 .51807 L
.50993 .51708 L
.50938 .51614 L
.50886 .51526 L
.50837 .51442 L
.5079 .51363 L
.50747 .51288 L
.50705 .51217 L
.50666 .5115 L
.5063 .51087 L
.50595 .51027 L
.50562 .50971 L
.50531 .50917 L
.50502 .50867 L
.50474 .50819 L
.50448 .50774 L
.50423 .50731 L
.504 .50691 L
.50378 .50653 L
.50357 .50617 L
.50337 .50583 L
.50319 .50551 L
.50301 .50521 L
.50284 .50492 L
.50269 .50465 L
.50254 .50439 L
.5024 .50415 L
.50227 .50392 L
.50214 .50371 L
.50202 .5035 L
.50191 .50331 L
.50181 .50313 L
.50171 .50295 L
.50161 .50279 L
.50152 .50264 L
.50144 .50249 L
.50136 .50236 L
.50129 .50223 L
.50121 .5021 L
.50115 .50199 L
.50108 .50188 L
.50102 .50177 L
.50097 .50168 L
.50091 .50158 L
.50086 .5015 L
.50082 .50141 L
.50077 .50134 L
Mistroke
.50073 .50126 L
.50069 .50119 L
.50065 .50113 L
.50061 .50106 L
.50058 .50101 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .5008 L
.50044 .50076 L
.50041 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .50041 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
Mistroke
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.78435 .73971 m
.76295 .73641 L
s
% Start of user PostScript
8.5303561 7.1913448 7.8885485 7.0921739 MAarrowhead1
% End of user PostScript
1 .158 0 r
.7435 .73196 m
.72578 .72661 L
s
% Start of user PostScript
7.3050284 6.9587878 6.7735242 6.7983702 MAarrowhead1
% End of user PostScript
1 .473 0 r
.63731 .67751 m
.62837 .67009 L
s
% Start of user PostScript
4.1192192 5.3253174 3.8512198 5.1026937 MAarrowhead1
% End of user PostScript
1 .788 0 r
.58171 .62236 m
.57677 .61636 L
s
% Start of user PostScript
2.4512453 3.6707049 2.3031189 3.4909058 MAarrowhead1
% End of user PostScript
.897 1 0 r
.55016 .58078 m
.54725 .57657 L
s
% Start of user PostScript
1.5046719 2.4234547 1.4175979 2.2970317 MAarrowhead1
% End of user PostScript
.581 1 0 r
.53131 .55229 m
.52954 .54948 L
s
% Start of user PostScript
0.93923308 1.5687376 0.8861475 1.4845423 MAarrowhead1
% End of user PostScript
.266 1 0 r
.51971 .53353 m
.51861 .53171 L
s
% Start of user PostScript
0.59141266 1.0059062 0.55839572 0.95118242 MAarrowhead1
% End of user PostScript
0 1 .049 r
.51247 .5214 m
.51178 .52023 L
s
% Start of user PostScript
0.37405862 0.64202537 0.35330734 0.60686589 MAarrowhead1
% End of user PostScript
0 1 .364 r
.5079 .51363 m
.50747 .51288 L
s
% Start of user PostScript
0.23711813 0.40883748 0.22400571 0.38637484 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50502 .50867 m
.50474 .50819 L
s
% Start of user PostScript
0.1504806 0.26004798 0.14217252 0.245737 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50319 .50551 m
.50301 .50521 L
s
% Start of user PostScript
0.095552562 0.16531375 0.090281322 0.15620881 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50202 .5035 m
.50191 .50331 L
s
% Start of user PostScript
0.060691429 0.10506085 0.057344685 0.099272103 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50129 .50223 m
.50121 .5021 L
s
% Start of user PostScript
0.03855441 0.066759198 0.036428811 0.063080089 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50082 .50141 m
.50077 .50134 L
s
% Start of user PostScript
0.024493544 0.042418024 0.023143291 0.040080124 MAarrowhead1
% End of user PostScript
1 0 .268 r
.56722 .71385 m
.56571 .69824 L
.564 .68401 L
.56213 .671 L
.56014 .65909 L
.55807 .64817 L
.55594 .63813 L
.55379 .6289 L
.55164 .6204 L
.54949 .61255 L
.54737 .60529 L
.54528 .59858 L
.54324 .59235 L
.54126 .58658 L
.53932 .58121 L
.53745 .57622 L
.53565 .57158 L
.5339 .56725 L
.53223 .56321 L
.53062 .55943 L
.52907 .55591 L
.5276 .55261 L
.52619 .54952 L
.52484 .54663 L
.52355 .54391 L
.52232 .54137 L
.52115 .53898 L
.52004 .53674 L
.51898 .53464 L
.51797 .53266 L
.51702 .5308 L
.51611 .52905 L
.51525 .5274 L
.51443 .52585 L
.51365 .5244 L
.51292 .52302 L
.51222 .52173 L
.51156 .52051 L
.51093 .51936 L
.51034 .51827 L
.50978 .51725 L
.50925 .51629 L
.50874 .51538 L
.50827 .51452 L
.50782 .51372 L
.50739 .51295 L
.50699 .51223 L
.5066 .51155 L
.50624 .51091 L
.5059 .51031 L
Mistroke
.50558 .50973 L
.50527 .5092 L
.50498 .50869 L
.50471 .5082 L
.50445 .50775 L
.50421 .50732 L
.50397 .50692 L
.50376 .50653 L
.50355 .50617 L
.50335 .50583 L
.50317 .50551 L
.503 .50521 L
.50283 .50492 L
.50268 .50465 L
.50253 .50439 L
.50239 .50415 L
.50226 .50392 L
.50213 .5037 L
.50202 .5035 L
.50191 .5033 L
.5018 .50312 L
.5017 .50295 L
.50161 .50279 L
.50152 .50263 L
.50144 .50249 L
.50136 .50235 L
.50128 .50222 L
.50121 .5021 L
.50114 .50198 L
.50108 .50187 L
.50102 .50177 L
.50097 .50167 L
.50091 .50158 L
.50086 .50149 L
.50081 .50141 L
.50077 .50133 L
.50073 .50126 L
.50069 .50119 L
.50065 .50112 L
.50061 .50106 L
.50058 .501 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .5008 L
.50044 .50076 L
.50041 .50071 L
.50039 .50068 L
.50037 .50064 L
.50035 .5006 L
Mistroke
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .50041 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
Mistroke
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.56722 .71385 m
.56571 .69824 L
s
% Start of user PostScript
2.0164576 6.4154593 1.9714461 5.9472759 MAarrowhead1
% End of user PostScript
1 .158 0 r
.564 .68401 m
.56213 .671 L
s
% Start of user PostScript
1.9200858 5.5201932 1.8639055 5.1299039 MAarrowhead1
% End of user PostScript
1 .473 0 r
.54737 .60529 m
.54528 .59858 L
s
% Start of user PostScript
1.4210927 3.1587653 1.3585401 2.9573184 MAarrowhead1
% End of user PostScript
1 .788 0 r
.53223 .56321 m
.53062 .55943 L
s
% Start of user PostScript
0.96681145 1.8961706 0.918534 1.7829659 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52115 .53898 m
.52004 .53674 L
s
% Start of user PostScript
0.63457247 1.1695321 0.60118748 1.102306 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51365 .5244 m
.51292 .52302 L
s
% Start of user PostScript
0.40962706 0.73187274 0.38755424 0.6906539 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50874 .51538 m
.50827 .51452 L
s
% Start of user PostScript
0.26230526 0.46143718 0.24800756 0.43572345 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50558 .50973 m
.50527 .5092 L
s
% Start of user PostScript
0.16730579 0.29204187 0.15813481 0.27585558 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50355 .50617 m
.50335 .50583 L
s
% Start of user PostScript
0.10650377 0.18518803 0.10064939 0.17495208 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50226 .50392 m
.50213 .5037 L
s
% Start of user PostScript
0.067732283 0.11754395 0.064003954 0.11105583 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50144 .50249 m
.50136 .50235 L
s
% Start of user PostScript
0.043054169 0.074644523 0.040682608 0.070527177 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50091 .50158 m
.50086 .50149 L
s
% Start of user PostScript
0.027360825 0.047413381 0.025853181 0.04479899 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50058 .501 m
.50055 .50095 L
s
% Start of user PostScript
0.017385628 0.030120114 0.016427475 0.028459567 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50037 .50064 m
.50035 .5006 L
s
% Start of user PostScript
0.011046513 0.019135449 0.010437668 0.018080587 MAarrowhead1
% End of user PostScript
1 0 .274 r
.60983 .71672 m
.60438 .70374 L
.59914 .69161 L
.59413 .68027 L
.58933 .66966 L
.58474 .65972 L
.58037 .65041 L
.57619 .64168 L
.57221 .63349 L
.56842 .6258 L
.56481 .61858 L
.56138 .6118 L
.55812 .60542 L
.55503 .59942 L
.55209 .59378 L
.5493 .58847 L
.54665 .58347 L
.54414 .57877 L
.54176 .57434 L
.5395 .57016 L
.53736 .56622 L
.53534 .56251 L
.53342 .55902 L
.5316 .55572 L
.52988 .55261 L
.52826 .54968 L
.52671 .54691 L
.52526 .5443 L
.52388 .54184 L
.52257 .53951 L
.52134 .53732 L
.52017 .53525 L
.51906 .53329 L
.51802 .53144 L
.51703 .5297 L
.5161 .52806 L
.51521 .5265 L
.51438 .52504 L
.51359 .52365 L
.51284 .52234 L
.51214 .52111 L
.51147 .51994 L
.51084 .51884 L
.51024 .5178 L
.50968 .51681 L
.50915 .51589 L
.50864 .51501 L
.50817 .51418 L
.50772 .5134 L
.50729 .51266 L
Mistroke
.50689 .51196 L
.50651 .5113 L
.50615 .51068 L
.50582 .51009 L
.5055 .50953 L
.50519 .509 L
.50491 .50851 L
.50464 .50804 L
.50438 .50759 L
.50414 .50718 L
.50391 .50678 L
.5037 .50641 L
.50349 .50605 L
.5033 .50572 L
.50312 .5054 L
.50295 .50511 L
.50278 .50482 L
.50263 .50456 L
.50249 .50431 L
.50235 .50407 L
.50222 .50385 L
.5021 .50363 L
.50198 .50343 L
.50187 .50324 L
.50177 .50306 L
.50167 .5029 L
.50158 .50274 L
.50149 .50259 L
.50141 .50244 L
.50133 .50231 L
.50126 .50218 L
.50119 .50206 L
.50112 .50195 L
.50106 .50184 L
.501 .50174 L
.50095 .50164 L
.5009 .50155 L
.50085 .50147 L
.5008 .50139 L
.50076 .50131 L
.50071 .50124 L
.50067 .50117 L
.50064 .5011 L
.5006 .50104 L
.50057 .50099 L
.50054 .50093 L
.50051 .50088 L
.50048 .50083 L
.50045 .50079 L
.50043 .50074 L
Mistroke
.50041 .5007 L
.50038 .50066 L
.50036 .50063 L
.50034 .50059 L
.50032 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.50019 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
Mistroke
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.60983 .71672 m
.60438 .70374 L
s
% Start of user PostScript
3.2949497 6.501719 3.1313102 6.1121892 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59914 .69161 m
.59413 .68027 L
s
% Start of user PostScript
2.9742899 5.7482891 2.8238446 5.4080507 MAarrowhead1
% End of user PostScript
1 .473 0 r
.56481 .61858 m
.56138 .6118 L
s
% Start of user PostScript
1.944394 3.5573956 1.8415068 3.353876 MAarrowhead1
% End of user PostScript
1 .788 0 r
.54176 .57434 m
.5395 .57016 L
s
% Start of user PostScript
1.2527396 2.2300609 1.1850503 2.1047756 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52671 .54691 m
.52526 .5443 L
s
% Start of user PostScript
0.80144324 1.4072871 0.75769989 1.3289652 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51703 .5297 m
.5161 .52806 L
s
% Start of user PostScript
0.51094682 0.89107021 0.48292044 0.84171479 MAarrowhead1
% End of user PostScript
.266 1 0 r
.51084 .51884 m
.51024 .5178 L
s
% Start of user PostScript
0.3251844 0.56516936 0.30730356 0.53394071 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50689 .51196 m
.50651 .5113 L
s
% Start of user PostScript
0.20678097 0.35876955 0.19539684 0.33896962 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50438 .50759 m
.50414 .50718 L
s
% Start of user PostScript
0.13143322 0.22784426 0.12419287 0.21527754 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50278 .50482 m
.50263 .50456 L
s
% Start of user PostScript
0.083523113 0.14472832 0.078920614 0.13674827 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50177 .50306 m
.50167 .5029 L
s
% Start of user PostScript
0.053071536 0.091942312 0.050146609 0.086873559 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50112 .50195 m
.50106 .50184 L
s
% Start of user PostScript
0.033720451 0.058411799 0.031861877 0.055191819 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50071 .50124 m
.50067 .50117 L
s
% Start of user PostScript
0.021424636 0.037110549 0.020243727 0.035064889 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50045 .50079 m
.50043 .50074 L
s
% Start of user PostScript
0.013612181 0.023577621 0.012861874 0.022277967 MAarrowhead1
% End of user PostScript
.261 1 0 r
.28835 .8031 m
.31517 .76014 L
.33849 .72306 L
.35877 .69106 L
.37641 .66345 L
.39177 .63965 L
.40513 .61913 L
.41678 .60145 L
.42692 .58623 L
.43577 .57314 L
.44348 .56188 L
.45021 .55221 L
.45609 .5439 L
.46122 .53678 L
.46571 .53068 L
.46964 .52546 L
.47308 .521 L
.47609 .51719 L
.47874 .51395 L
.48106 .51119 L
.4831 .50885 L
.48489 .50686 L
.48647 .50519 L
.48787 .50378 L
.4891 .5026 L
.49018 .50162 L
.49115 .5008 L
.492 .50012 L
.49276 .49957 L
.49343 .49912 L
.49403 .49875 L
.49456 .49847 L
.49504 .49824 L
.49547 .49807 L
.49585 .49795 L
.4962 .49786 L
.49651 .4978 L
.49679 .49777 L
.49704 .49776 L
.49727 .49777 L
.49748 .4978 L
.49766 .49783 L
.49784 .49788 L
.49799 .49793 L
.49813 .49799 L
.49826 .49805 L
.49838 .49812 L
.49849 .49819 L
.4986 .49826 L
.49869 .49833 L
Mistroke
.49877 .49839 L
.49885 .49846 L
.49893 .49853 L
.49899 .4986 L
.49906 .49866 L
.49912 .49872 L
.49917 .49878 L
.49922 .49884 L
.49927 .4989 L
.49931 .49895 L
.49935 .499 L
.49939 .49905 L
.49943 .4991 L
.49946 .49915 L
.49949 .49919 L
.49952 .49923 L
.49955 .49927 L
.49958 .49931 L
.4996 .49935 L
.49962 .49938 L
.49965 .49941 L
.49967 .49945 L
.49968 .49948 L
.4997 .4995 L
.49972 .49953 L
.49974 .49956 L
.49975 .49958 L
.49976 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .4997 L
.49983 .49972 L
.49984 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .4998 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
Mistroke
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
Mistroke
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.28835 .8031 m
.31517 .76014 L
s
% Start of user PostScript
-6.3495129 9.0928693 -5.5449104 7.8042525 MAarrowhead1
% End of user PostScript
1 .158 0 r
.33849 .72306 m
.35877 .69106 L
s
% Start of user PostScript
-4.8453522 6.6917901 -4.236945 5.7317376 MAarrowhead1
% End of user PostScript
1 .473 0 r
.44348 .56188 m
.45021 .55221 L
s
% Start of user PostScript
-1.6956354 1.856458 -1.493705 1.5662612 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47874 .51395 m
.48106 .51119 L
s
% Start of user PostScript
-0.63788215 0.41837585 -0.56825381 0.33561508 MAarrowhead1
% End of user PostScript
.897 1 0 r
.49115 .5008 m
.492 .50012 L
s
% Start of user PostScript
-0.26563456 0.023949458 -0.24003953 0.003658344 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49585 .49795 m
.4962 .49786 L
s
% Start of user PostScript
-0.1243951 -0.061641949 -0.11405772 -0.064272679 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49784 .49788 m
.49799 .49793 L
s
% Start of user PostScript
-0.064932612 -0.063587411 -0.060247404 -0.061998104 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49877 .49839 m
.49885 .49846 L
s
% Start of user PostScript
-0.036773553 -0.048161059 -0.034395075 -0.046115125 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49927 .4989 m
.49931 .49895 L
s
% Start of user PostScript
-0.021939895 -0.033065132 -0.02061885 -0.03143599 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49955 .49927 m
.49958 .49931 L
s
% Start of user PostScript
-0.013486873 -0.021791448 -0.012707967 -0.020651748 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49972 .49953 m
.49974 .49956 L
s
% Start of user PostScript
-0.0084250033 -0.014094102 -0.0079493276 -0.013336752 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49982 .4997 m
.49983 .49972 L
s
% Start of user PostScript
-0.005307076 -0.009033736 -0.005010959 -0.0085419924 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49989 .49981 m
.49989 .49982 L
s
% Start of user PostScript
-0.0033572949 -0.0057646731 -0.0031710975 -0.0054488894 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49993 .49988 m
.49993 .49988 L
s
% Start of user PostScript
-0.0021284206 -0.0036705382 -0.0020107373 -0.0034688402 MAarrowhead1
% End of user PostScript
0 1 .76 r
.61932 .2897 m
.6033 .31764 L
.58944 .34185 L
.57742 .36284 L
.56702 .38103 L
.558 .3968 L
.5502 .41047 L
.54344 .42232 L
.53758 .4326 L
.53251 .4415 L
.52812 .44923 L
.52432 .45593 L
.52103 .46173 L
.51818 .46677 L
.51571 .47114 L
.51358 .47493 L
.51173 .47821 L
.51013 .48106 L
.50875 .48354 L
.50755 .48568 L
.50651 .48755 L
.50562 .48916 L
.50484 .49057 L
.50417 .49179 L
.50359 .49284 L
.50309 .49376 L
.50266 .49456 L
.50229 .49525 L
.50196 .49586 L
.50168 .49638 L
.50144 .49684 L
.50124 .49723 L
.50106 .49758 L
.5009 .49788 L
.50077 .49814 L
.50065 .49837 L
.50056 .49857 L
.50047 .49874 L
.5004 .49889 L
.50034 .49902 L
.50028 .49914 L
.50024 .49924 L
.5002 .49932 L
.50016 .4994 L
.50013 .49947 L
.50011 .49953 L
.50009 .49958 L
.50007 .49963 L
.50005 .49967 L
.50004 .4997 L
Mistroke
.50003 .49973 L
.50002 .49976 L
.50001 .49978 L
.50001 .49981 L
.5 .49982 L
.5 .49984 L
.5 .49986 L
.49999 .49987 L
.49999 .49988 L
.49999 .49989 L
.49999 .4999 L
.49999 .49991 L
.49999 .49992 L
.49998 .49992 L
.49998 .49993 L
.49998 .49994 L
.49998 .49994 L
.49998 .49995 L
.49998 .49995 L
.49999 .49995 L
.49999 .49996 L
.49999 .49996 L
.49999 .49996 L
.49999 .49997 L
.49999 .49997 L
.49999 .49997 L
.49999 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
Mistroke
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.61932 .2897 m
.6033 .31764 L
s
% Start of user PostScript
3.5795001 -6.3089351 3.0991439 -5.4709224 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58944 .34185 m
.57742 .36284 L
s
% Start of user PostScript
2.6830547 -4.7445546 2.3226448 -4.1149393 MAarrowhead1
% End of user PostScript
1 .473 0 r
.52812 .44923 m
.52432 .45593 L
s
% Start of user PostScript
0.84368294 -1.5231635 0.72964554 -1.322235 MAarrowhead1
% End of user PostScript
1 .788 0 r
.50875 .48354 m
.50755 .48568 L
s
% Start of user PostScript
0.26243064 -0.49384669 0.22650495 -0.42945511 MAarrowhead1
% End of user PostScript
.897 1 0 r
.50266 .49456 m
.50229 .49525 L
s
% Start of user PostScript
0.079790921 -0.16317313 0.068573225 -0.14236707 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50077 .49814 m
.50065 .49837 L
s
% Start of user PostScript
0.023066391 -0.055817446 0.019627866 -0.048987231 MAarrowhead1
% End of user PostScript
.266 1 0 r
.5002 .49932 m
.50016 .4994 L
s
% Start of user PostScript
0.0058755006 -0.020256568 0.0048629919 -0.017947234 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50003 .49973 m
.50002 .49976 L
s
% Start of user PostScript
0.00094302586 -0.0080375669 0.00067221106 -0.0072154941 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49999 .49988 m
.49999 .49989 L
s
% Start of user PostScript
-0.00028742747 -0.0035710253 -0.00034112417 -0.0032537387 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49998 .49994 m
.49998 .49995 L
s
% Start of user PostScript
-0.00046434615 -0.0017808544 -0.00046084892 -0.0016444163 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49999 .49997 m
.49999 .49997 L
s
% Start of user PostScript
-0.00038454643 -0.00097638817 -0.00037037197 -0.00091040549 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49999 .49998 m
.49999 .49998 L
s
% Start of user PostScript
-0.00027276854 -0.00057106558 -0.00025996468 -0.00053572263 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49999 .49999 m
.49999 .49999 L
s
% Start of user PostScript
-0.00018234223 -0.00034716395 -0.0001730004 -0.00032679959 MAarrowhead1
% End of user PostScript
0 .06 1 r
.5 .49999 m
.5 .49999 L
s
% Start of user PostScript
-0.00011872278 -0.00021559232 -0.00011240396 -0.00020331829 MAarrowhead1
% End of user PostScript
.249 0 1 r
.53083 .44744 m
.52674 .45449 L
.52318 .4606 L
.52011 .46589 L
.51744 .47047 L
.51513 .47444 L
.51312 .47788 L
.51138 .48085 L
.50988 .48343 L
.50857 .48566 L
.50744 .4876 L
.50645 .48927 L
.5056 .49072 L
.50486 .49198 L
.50422 .49306 L
.50367 .49401 L
.50319 .49482 L
.50277 .49552 L
.50241 .49613 L
.50209 .49666 L
.50182 .49712 L
.50158 .49751 L
.50138 .49786 L
.5012 .49815 L
.50104 .49841 L
.50091 .49863 L
.50079 .49882 L
.50069 .49899 L
.5006 .49913 L
.50053 .49925 L
.50046 .49936 L
.5004 .49945 L
.50035 .49953 L
.50031 .4996 L
.50027 .49966 L
.50024 .49971 L
.50021 .49975 L
.50018 .49979 L
.50016 .49982 L
.50014 .49985 L
.50012 .49987 L
.50011 .49989 L
.5001 .49991 L
.50009 .49993 L
.50008 .49994 L
.50007 .49995 L
.50006 .49996 L
.50005 .49997 L
.50005 .49997 L
.50004 .49998 L
Mistroke
.50004 .49998 L
.50003 .49999 L
.50003 .49999 L
.50003 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.53083 .44744 m
.52674 .45449 L
s
% Start of user PostScript
0.92500309 -1.5768557 0.8020811 -1.3653429 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52318 .4606 m
.52011 .46589 L
s
% Start of user PostScript
0.69553851 -1.1821233 0.60319028 -1.0234163 MAarrowhead1
% End of user PostScript
1 .473 0 r
.50744 .4876 m
.50645 .48927 L
s
% Start of user PostScript
0.22309552 -0.3720637 0.19363539 -0.3218282 MAarrowhead1
% End of user PostScript
1 .788 0 r
.50241 .49613 m
.50209 .49666 L
s
% Start of user PostScript
0.072209725 -0.11595432 0.06277551 -0.1001163 MAarrowhead1
% End of user PostScript
.897 1 0 r
.50079 .49882 m
.50069 .49899 L
s
% Start of user PostScript
0.023782234 -0.035399872 0.020738204 -0.030446729 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50027 .49966 m
.50024 .49971 L
s
% Start of user PostScript
0.0080884017 -0.010329509 0.0070918146 -0.0088062167 MAarrowhead1
% End of user PostScript
.266 1 0 r
.5001 .49991 m
.50009 .49993 L
s
% Start of user PostScript
0.0029076571 -0.0026981378 0.0025723704 -0.0022462818 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50004 .49998 m
.50003 .49999 L
s
% Start of user PostScript
0.0011383224 -0.00048615389 0.0010199618 -0.0003630288 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50002 .5 m
.50002 .5 L
s
% Start of user PostScript
0.00049791057 0.000081382236 0.00045279207 0.00010750691 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50001 .50001 m
.50001 .50001 L
s
% Start of user PostScript
0.00024474458 0.00017571971 0.00022563789 0.0001757611 MAarrowhead1
% End of user PostScript
0 1 .995 r
.5 .50001 m
.5 .5 L
s
% Start of user PostScript
0.00013274424 0.00015105097 0.00012364256 0.00014581593 MAarrowhead1
% End of user PostScript
0 .69 1 r
.5 .5 m
.5 .5 L
s
% Start of user PostScript
0.000077107948 0.00010849231 0.000072290541 0.00010349435 MAarrowhead1
% End of user PostScript
0 .375 1 r
.5 .5 m
.5 .5 L
s
% Start of user PostScript
0.000046692432 0.000072909393 0.000043938468 0.000069202674 MAarrowhead1
% End of user PostScript
0 .06 1 r
.5 .5 m
.5 .5 L
s
% Start of user PostScript
0.000028935606 0.00004758709 0.00002728337 0.000045063219 MAarrowhead1
% End of user PostScript
0 .918 1 r
.28419 .65528 m
.30806 .62599 L
.32901 .60108 L
.34743 .57994 L
.36362 .56204 L
.37789 .54693 L
.39047 .53422 L
.40157 .52355 L
.41139 .51465 L
.42008 .50725 L
.42778 .50114 L
.43462 .49613 L
.4407 .49206 L
.44611 .48878 L
.45094 .48618 L
.45525 .48415 L
.45911 .48261 L
.46258 .48148 L
.46569 .48068 L
.46849 .48018 L
.47101 .47991 L
.47329 .47983 L
.47535 .47992 L
.47722 .48014 L
.47892 .48047 L
.48047 .48088 L
.48188 .48136 L
.48316 .48189 L
.48434 .48245 L
.48542 .48304 L
.48641 .48365 L
.48732 .48427 L
.48816 .4849 L
.48894 .48552 L
.48965 .48613 L
.49032 .48674 L
.49093 .48733 L
.4915 .48791 L
.49203 .48847 L
.49252 .48902 L
.49298 .48955 L
.4934 .49006 L
.4938 .49055 L
.49417 .49102 L
.49452 .49147 L
.49484 .4919 L
.49514 .49231 L
.49543 .49271 L
.49569 .49309 L
.49594 .49345 L
Mistroke
.49618 .49379 L
.4964 .49412 L
.4966 .49443 L
.4968 .49472 L
.49698 .495 L
.49715 .49527 L
.49731 .49552 L
.49747 .49576 L
.49761 .49599 L
.49774 .4962 L
.49787 .49641 L
.49799 .4966 L
.4981 .49679 L
.49821 .49696 L
.49831 .49713 L
.4984 .49728 L
.49849 .49743 L
.49858 .49757 L
.49866 .4977 L
.49873 .49783 L
.4988 .49795 L
.49887 .49806 L
.49893 .49817 L
.49899 .49827 L
.49905 .49836 L
.4991 .49845 L
.49915 .49854 L
.4992 .49862 L
.49924 .49869 L
.49928 .49876 L
.49932 .49883 L
.49936 .4989 L
.4994 .49896 L
.49943 .49901 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49954 .49921 L
.49957 .49926 L
.49959 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
Mistroke
.49978 .49962 L
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.28419 .65528 m
.30806 .62599 L
s
% Start of user PostScript
-6.4742627 4.6585157 -5.7582351 3.7796528 MAarrowhead1
% End of user PostScript
1 .158 0 r
.32901 .60108 m
.34743 .57994 L
s
% Start of user PostScript
-5.129626 3.0322859 -4.577215 2.3980787 MAarrowhead1
% End of user PostScript
1 .473 0 r
.42778 .50114 m
.43462 .49613 L
s
% Start of user PostScript
-2.1665898 0.034305445 -1.9614735 -0.11600686 MAarrowhead1
% End of user PostScript
1 .788 0 r
.46569 .48068 m
.46849 .48018 L
s
% Start of user PostScript
-1.0293638 -0.57951079 -0.94539338 -0.59473206 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48188 .48136 m
.48316 .48189 L
s
% Start of user PostScript
-0.543679 -0.55926876 -0.50505751 -0.54342891 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48965 .48613 m
.49032 .48674 L
s
% Start of user PostScript
-0.31036569 -0.41604833 -0.29050815 -0.39787795 MAarrowhead1
% End of user PostScript
.266 1 0 r
.4938 .49055 m
.49417 .49102 L
s
% Start of user PostScript
-0.18604846 -0.28362906 -0.17491942 -0.26950854 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49618 .49379 m
.4964 .49412 L
s
% Start of user PostScript
-0.11466453 -0.18633347 -0.10806639 -0.17654347 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49761 .49599 m
.49774 .4962 L
s
% Start of user PostScript
-0.071726377 -0.1203342 -0.067684486 -0.11385406 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49849 .49743 m
.49858 .49757 L
s
% Start of user PostScript
-0.045213386 -0.077072708 -0.042693125 -0.072872926 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49905 .49836 m
.4991 .49845 L
s
% Start of user PostScript
-0.028612421 -0.049164387 -0.027026356 -0.046469815 MAarrowhead1
% End of user PostScript
0 .69 1 r
.4994 .49896 m
.49943 .49901 L
s
% Start of user PostScript
-0.01814261 -0.031298789 -0.017139734 -0.029578463 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49962 .49934 m
.49964 .49937 L
s
% Start of user PostScript
-0.011515314 -0.019905344 -0.010879675 -0.018809694 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49976 .49958 m
.49977 .4996 L
s
% Start of user PostScript
-0.0073125317 -0.01265304 -0.0069091694 -0.011956083 MAarrowhead1
% End of user PostScript
.997 1 0 r
.17164 .47098 m
.20195 .45143 L
.22896 .43578 L
.25307 .42344 L
.27463 .41389 L
.29394 .40672 L
.31126 .40153 L
.32683 .398 L
.34086 .39587 L
.35351 .39488 L
.36495 .39485 L
.37531 .3956 L
.3847 .39698 L
.39325 .39887 L
.40103 .40116 L
.40812 .40377 L
.41461 .40661 L
.42055 .40962 L
.426 .41275 L
.431 .41595 L
.43561 .4192 L
.43985 .42245 L
.44377 .42568 L
.44739 .42887 L
.45075 .43201 L
.45385 .43508 L
.45674 .43807 L
.45941 .44097 L
.46191 .44378 L
.46423 .4465 L
.46639 .44912 L
.46841 .45163 L
.47029 .45405 L
.47206 .45637 L
.4737 .45859 L
.47525 .46071 L
.47669 .46273 L
.47805 .46467 L
.47932 .46651 L
.48051 .46826 L
.48163 .46993 L
.48268 .47152 L
.48367 .47303 L
.4846 .47447 L
.48548 .47583 L
.4863 .47712 L
.48707 .47835 L
.4878 .47952 L
.48849 .48062 L
.48914 .48167 L
Mistroke
.48975 .48266 L
.49032 .4836 L
.49086 .48449 L
.49137 .48533 L
.49186 .48613 L
.49231 .48688 L
.49274 .4876 L
.49314 .48828 L
.49352 .48892 L
.49388 .48952 L
.49422 .49009 L
.49454 .49064 L
.49485 .49115 L
.49513 .49163 L
.4954 .49209 L
.49566 .49253 L
.4959 .49294 L
.49612 .49332 L
.49634 .49369 L
.49654 .49404 L
.49673 .49436 L
.49691 .49467 L
.49708 .49497 L
.49725 .49524 L
.4974 .49551 L
.49754 .49575 L
.49768 .49599 L
.49781 .49621 L
.49793 .49642 L
.49804 .49661 L
.49815 .4968 L
.49825 .49698 L
.49835 .49714 L
.49844 .4973 L
.49852 .49745 L
.49861 .49759 L
.49868 .49772 L
.49876 .49785 L
.49882 .49797 L
.49889 .49808 L
.49895 .49818 L
.49901 .49828 L
.49906 .49838 L
.49911 .49847 L
.49916 .49855 L
.49921 .49863 L
.49925 .49871 L
.49929 .49878 L
.49933 .49885 L
.49937 .49891 L
Mistroke
.4994 .49897 L
.49944 .49903 L
.49947 .49908 L
.4995 .49913 L
.49953 .49918 L
.49955 .49922 L
.49958 .49927 L
.4996 .49931 L
.49962 .49935 L
.49964 .49938 L
.49966 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49953 L
.49975 .49956 L
.49976 .49958 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
Mistroke
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.17164 .47098 m
.20195 .45143 L
s
% Start of user PostScript
-9.8508431 -0.87051112 -8.941467 -1.4571244 MAarrowhead1
% End of user PostScript
1 .158 0 r
.22896 .43578 m
.25307 .42344 L
s
% Start of user PostScript
-8.1311318 -1.9266796 -7.4078478 -2.2969403 MAarrowhead1
% End of user PostScript
1 .473 0 r
.36495 .39485 m
.37531 .3956 L
s
% Start of user PostScript
-4.0515934 -3.1544155 -3.7408489 -3.1319479 MAarrowhead1
% End of user PostScript
1 .788 0 r
.426 .41275 m
.431 .41595 L
s
% Start of user PostScript
-2.2200025 -2.6175427 -2.0698546 -2.521374 MAarrowhead1
% End of user PostScript
.897 1 0 r
.45674 .43807 m
.45941 .44097 L
s
% Start of user PostScript
-1.2979234 -1.8579635 -1.2175529 -1.7708395 MAarrowhead1
% End of user PostScript
.581 1 0 r
.4737 .45859 m
.47525 .46071 L
s
% Start of user PostScript
-0.78886439 -1.2423871 -0.74257604 -1.1787637 MAarrowhead1
% End of user PostScript
.266 1 0 r
.48367 .47303 m
.4846 .47447 L
s
% Start of user PostScript
-0.48983523 -0.80902613 -0.46194347 -0.76597549 MAarrowhead1
% End of user PostScript
0 1 .049 r
.48975 .48266 m
.49032 .4836 L
s
% Start of user PostScript
-0.30760217 -0.52026434 -0.29036347 -0.49207732 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49352 .48892 m
.49388 .48952 L
s
% Start of user PostScript
-0.19428537 -0.33253415 -0.1834861 -0.31436034 MAarrowhead1
% End of user PostScript
0 1 .679 r
.4959 .49294 m
.49612 .49332 L
s
% Start of user PostScript
-0.12307323 -0.21190497 -0.11626067 -0.20027404 MAarrowhead1
% End of user PostScript
0 1 .995 r
.4974 .49551 m
.49754 .49575 L
s
% Start of user PostScript
-0.078077861 -0.13483312 -0.073765018 -0.12741669 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49835 .49714 m
.49844 .4973 L
s
% Start of user PostScript
-0.049569418 -0.0857291 -0.046834198 -0.081008602 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49895 .49818 m
.49901 .49828 L
s
% Start of user PostScript
-0.031481894 -0.054487676 -0.029745653 -0.051485834 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49933 .49885 m
.49937 .49891 L
s
% Start of user PostScript
-0.019998091 -0.034624819 -0.018895478 -0.032716759 MAarrowhead1
% End of user PostScript
1 0 .294 r
.62961 .59907 m
.61963 .59853 L
.61058 .59736 L
.60235 .59568 L
.59486 .59361 L
.58803 .59122 L
.5818 .58859 L
.57609 .58579 L
.57085 .58286 L
.56604 .57986 L
.56162 .57681 L
.55755 .57375 L
.55379 .5707 L
.55032 .56768 L
.5471 .56471 L
.54412 .56181 L
.54136 .55897 L
.53879 .55622 L
.53641 .55355 L
.53419 .55097 L
.53211 .54849 L
.53018 .54609 L
.52838 .54379 L
.52669 .54159 L
.52512 .53948 L
.52364 .53746 L
.52226 .53553 L
.52096 .53369 L
.51975 .53194 L
.51861 .53027 L
.51754 .52868 L
.51653 .52716 L
.51559 .52572 L
.5147 .52435 L
.51387 .52306 L
.51308 .52182 L
.51234 .52065 L
.51164 .51954 L
.51099 .51849 L
.51037 .51749 L
.50979 .51655 L
.50924 .51565 L
.50872 .5148 L
.50823 .514 L
.50777 .51324 L
.50734 .51252 L
.50693 .51183 L
.50655 .51119 L
.50618 .51058 L
.50584 .51 L
Mistroke
.50551 .50945 L
.50521 .50893 L
.50492 .50845 L
.50465 .50798 L
.50439 .50755 L
.50414 .50713 L
.50392 .50674 L
.5037 .50637 L
.50349 .50602 L
.5033 .50569 L
.50312 .50538 L
.50295 .50508 L
.50278 .5048 L
.50263 .50454 L
.50248 .50429 L
.50235 .50405 L
.50222 .50383 L
.50209 .50362 L
.50198 .50342 L
.50187 .50323 L
.50177 .50305 L
.50167 .50289 L
.50158 .50273 L
.50149 .50258 L
.50141 .50243 L
.50133 .5023 L
.50126 .50217 L
.50119 .50205 L
.50112 .50194 L
.50106 .50183 L
.501 .50173 L
.50095 .50164 L
.50089 .50155 L
.50084 .50146 L
.5008 .50138 L
.50075 .50131 L
.50071 .50123 L
.50067 .50117 L
.50064 .5011 L
.5006 .50104 L
.50057 .50098 L
.50054 .50093 L
.50051 .50088 L
.50048 .50083 L
.50045 .50078 L
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
Mistroke
.50032 .50056 L
.5003 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.5002 .50035 L
.50019 .50033 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
Mistroke
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.62961 .59907 m
.61963 .59853 L
s
% Start of user PostScript
3.8883979 2.9722386 3.5889228 2.9558744 MAarrowhead1
% End of user PostScript
1 .158 0 r
.61058 .59736 m
.60235 .59568 L
s
% Start of user PostScript
3.3173221 2.9207241 3.0705418 2.8704516 MAarrowhead1
% End of user PostScript
1 .473 0 r
.56162 .57681 m
.55755 .57375 L
s
% Start of user PostScript
1.8486552 2.3042343 1.726441 2.2124065 MAarrowhead1
% End of user PostScript
1 .788 0 r
.53641 .55355 m
.53419 .55097 L
s
% Start of user PostScript
1.0922322 1.6065249 1.0255717 1.5291519 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52226 .53553 m
.52096 .53369 L
s
% Start of user PostScript
0.66778992 1.0659921 0.62892915 1.0107862 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51387 .52306 m
.51308 .52182 L
s
% Start of user PostScript
0.41596523 0.69166531 0.39238482 0.65466886 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50872 .5148 m
.50823 .514 L
s
% Start of user PostScript
0.2616398 0.44401908 0.24701073 0.41990296 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50551 .50945 m
.50521 .50893 L
s
% Start of user PostScript
0.16539187 0.2835581 0.15620943 0.26804202 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50349 .50602 m
.5033 .50569 L
s
% Start of user PostScript
0.10481393 0.18061864 0.099015534 0.17069893 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50222 .50383 m
.50209 .50362 L
s
% Start of user PostScript
0.066508082 0.11490162 0.062835422 0.10857961 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50141 .50243 m
.50133 .5023 L
s
% Start of user PostScript
0.042228533 0.073048615 0.039898728 0.069025739 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50089 .50155 m
.50084 .50146 L
s
% Start of user PostScript
0.026821057 0.046425769 0.025341974 0.043867882 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50057 .50098 m
.50054 .50093 L
s
% Start of user PostScript
0.017037858 0.02950101 0.016098496 0.027875245 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50036 .50062 m
.50034 .50059 L
s
% Start of user PostScript
0.010824025 0.018744765 0.010227322 0.017711646 MAarrowhead1
% End of user PostScript
0 .063 1 r
.5249 .25053 m
.51691 .27575 L
.51024 .29805 L
.5047 .31779 L
.50014 .33529 L
.4964 .35084 L
.49336 .36466 L
.49093 .37697 L
.489 .38796 L
.4875 .39778 L
.48637 .40657 L
.48554 .41446 L
.48497 .42155 L
.48461 .42792 L
.48443 .43368 L
.4844 .43888 L
.48449 .44358 L
.48467 .44785 L
.48494 .45173 L
.48527 .45526 L
.48564 .45848 L
.48606 .46142 L
.4865 .46411 L
.48696 .46658 L
.48743 .46885 L
.48791 .47093 L
.4884 .47285 L
.48888 .47463 L
.48935 .47626 L
.48982 .47778 L
.49028 .47918 L
.49072 .48049 L
.49116 .4817 L
.49158 .48282 L
.49198 .48387 L
.49237 .48485 L
.49275 .48576 L
.49311 .48661 L
.49346 .48741 L
.49379 .48815 L
.49411 .48885 L
.49441 .4895 L
.4947 .49011 L
.49498 .49068 L
.49524 .49122 L
.49549 .49172 L
.49573 .4922 L
.49595 .49264 L
.49617 .49306 L
.49637 .49346 L
Mistroke
.49657 .49383 L
.49675 .49418 L
.49693 .49451 L
.49709 .49482 L
.49725 .49511 L
.4974 .49538 L
.49754 .49564 L
.49767 .49588 L
.4978 .49611 L
.49792 .49633 L
.49803 .49654 L
.49814 .49673 L
.49824 .49691 L
.49834 .49708 L
.49843 .49725 L
.49851 .4974 L
.49859 .49754 L
.49867 .49768 L
.49874 .49781 L
.49881 .49793 L
.49888 .49804 L
.49894 .49815 L
.499 .49825 L
.49905 .49835 L
.49911 .49844 L
.49915 .49853 L
.4992 .49861 L
.49924 .49869 L
.49929 .49876 L
.49933 .49883 L
.49936 .49889 L
.4994 .49895 L
.49943 .49901 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49921 L
.49957 .49926 L
.49959 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
Mistroke
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.5249 .25053 m
.51691 .27575 L
s
% Start of user PostScript
0.74704807 -7.4840901 0.50724082 -6.7275218 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51024 .29805 m
.5047 .31779 L
s
% Start of user PostScript
0.30717043 -6.0585877 0.14110615 -5.4663251 MAarrowhead1
% End of user PostScript
1 .473 0 r
.48637 .40657 m
.48554 .41446 L
s
% Start of user PostScript
-0.40902955 -2.8027982 -0.43387401 -2.5662212 MAarrowhead1
% End of user PostScript
1 .788 0 r
.48494 .45173 m
.48527 .45526 L
s
% Start of user PostScript
-0.45187038 -1.4481918 -0.4420223 -1.3422816 MAarrowhead1
% End of user PostScript
.897 1 0 r
.4884 .47285 m
.48888 .47463 L
s
% Start of user PostScript
-0.34810449 -0.81442359 -0.33370209 -0.76124264 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49198 .48387 m
.49237 .48485 L
s
% Start of user PostScript
-0.24055387 -0.48385751 -0.22881496 -0.45455266 MAarrowhead1
% End of user PostScript
.266 1 0 r
.4947 .49011 m
.49498 .49068 L
s
% Start of user PostScript
-0.15899532 -0.29674439 -0.15071454 -0.27955043 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49657 .49383 m
.49675 .49418 L
s
% Start of user PostScript
-0.10297443 -0.1851435 -0.097451913 -0.17467216 MAarrowhead1
% End of user PostScript
0 1 .364 r
.4978 .49611 m
.49792 .49633 L
s
% Start of user PostScript
-0.066046263 -0.11655208 -0.062454506 -0.11004305 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49859 .49754 m
.49867 .49768 L
s
% Start of user PostScript
-0.042159752 -0.073708147 -0.039851359 -0.069618398 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49911 .49844 m
.49915 .49853 L
s
% Start of user PostScript
-0.026848741 -0.046721159 -0.025373731 -0.044137292 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49943 .49901 m
.49946 .49907 L
s
% Start of user PostScript
-0.017078131 -0.029649395 -0.016138328 -0.028012369 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49964 .49937 m
.49966 .49941 L
s
% Start of user PostScript
-0.01085682 -0.018826555 -0.010258875 -0.017787949 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49977 .4996 m
.49978 .49962 L
s
% Start of user PostScript
-0.0068998235 -0.011957833 -0.0065196543 -0.011298428 MAarrowhead1
% End of user PostScript
0 1 .007 r
.28131 .40122 m
.2997 .39569 L
.31623 .39193 L
.33112 .38965 L
.34455 .38859 L
.35669 .38855 L
.36768 .38933 L
.37766 .39078 L
.38673 .39278 L
.39498 .3952 L
.40252 .39796 L
.4094 .40096 L
.41571 .40415 L
.42149 .40747 L
.4268 .41087 L
.43169 .41431 L
.43619 .41775 L
.44035 .42118 L
.44419 .42456 L
.44775 .42789 L
.45104 .43114 L
.4541 .43431 L
.45694 .43739 L
.45959 .44037 L
.46205 .44325 L
.46435 .44603 L
.46649 .4487 L
.46849 .45126 L
.47036 .45372 L
.4721 .45607 L
.47374 .45832 L
.47528 .46047 L
.47671 .46252 L
.47806 .46447 L
.47933 .46634 L
.48051 .46811 L
.48163 .46979 L
.48268 .47139 L
.48367 .47292 L
.48459 .47436 L
.48547 .47573 L
.48629 .47704 L
.48706 .47827 L
.48779 .47944 L
.48848 .48055 L
.48912 .4816 L
.48973 .4826 L
.49031 .48354 L
.49085 .48444 L
.49136 .48529 L
Mistroke
.49184 .48609 L
.4923 .48684 L
.49273 .48756 L
.49313 .48824 L
.49351 .48888 L
.49387 .48949 L
.49421 .49007 L
.49453 .49061 L
.49484 .49113 L
.49512 .49161 L
.49539 .49207 L
.49565 .49251 L
.49589 .49292 L
.49612 .49331 L
.49633 .49367 L
.49653 .49402 L
.49673 .49435 L
.49691 .49466 L
.49708 .49495 L
.49724 .49523 L
.49739 .49549 L
.49754 .49574 L
.49767 .49598 L
.4978 .4962 L
.49792 .49641 L
.49804 .49661 L
.49814 .49679 L
.49825 .49697 L
.49834 .49714 L
.49844 .49729 L
.49852 .49744 L
.4986 .49758 L
.49868 .49772 L
.49875 .49784 L
.49882 .49796 L
.49889 .49807 L
.49895 .49818 L
.49901 .49828 L
.49906 .49837 L
.49911 .49846 L
.49916 .49855 L
.49921 .49863 L
.49925 .4987 L
.49929 .49878 L
.49933 .49884 L
.49937 .49891 L
.4994 .49897 L
.49944 .49902 L
.49947 .49908 L
.4995 .49913 L
Mistroke
.49952 .49918 L
.49955 .49922 L
.49958 .49926 L
.4996 .49931 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49945 L
.4997 .49948 L
.49971 .49951 L
.49973 .49953 L
.49975 .49956 L
.49976 .49958 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
Mistroke
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.28131 .40122 m
.2997 .39569 L
s
% Start of user PostScript
-6.5606368 -2.9634709 -6.0089333 -3.129336 MAarrowhead1
% End of user PostScript
1 .158 0 r
.31623 .39193 m
.33112 .38965 L
s
% Start of user PostScript
-5.5130164 -3.2421058 -5.0664232 -3.310575 MAarrowhead1
% End of user PostScript
1 .473 0 r
.40252 .39796 m
.4094 .40096 L
s
% Start of user PostScript
-2.9244962 -3.0612555 -2.7179449 -2.9710623 MAarrowhead1
% End of user PostScript
1 .788 0 r
.44419 .42456 m
.44775 .42789 L
s
% Start of user PostScript
-1.6743334 -2.2631701 -1.5676311 -2.1633816 MAarrowhead1
% End of user PostScript
.897 1 0 r
.46649 .4487 m
.46849 .45126 L
s
% Start of user PostScript
-1.005393 -1.5390131 -0.94539498 -1.4621125 MAarrowhead1
% End of user PostScript
.581 1 0 r
.47933 .46634 m
.48051 .46811 L
s
% Start of user PostScript
-0.62021682 -1.0099361 -0.58457443 -0.95678761 MAarrowhead1
% End of user PostScript
.266 1 0 r
.48706 .47827 m
.48779 .47944 L
s
% Start of user PostScript
-0.38815495 -0.65186764 -0.3662969 -0.61673681 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49184 .48609 m
.4923 .48684 L
s
% Start of user PostScript
-0.24473815 -0.4174047 -0.23110091 -0.39465133 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49484 .49113 m
.49512 .49161 L
s
% Start of user PostScript
-0.15489739 -0.26622644 -0.14631254 -0.25163258 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49673 .49435 m
.49691 .49466 L
s
% Start of user PostScript
-0.098223825 -0.16947286 -0.092794759 -0.160157 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49792 .49641 m
.49804 .49661 L
s
% Start of user PostScript
-0.062345727 -0.10777757 -0.058904433 -0.1018449 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49868 .49772 m
.49875 .49784 L
s
% Start of user PostScript
-0.039591834 -0.068508845 -0.037407982 -0.064735143 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49916 .49855 m
.49921 .49863 L
s
% Start of user PostScript
-0.025148334 -0.043537149 -0.023761649 -0.041138149 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49947 .49908 m
.4995 .49913 L
s
% Start of user PostScript
-0.015975896 -0.027664376 -0.015095132 -0.026139742 MAarrowhead1
% End of user PostScript
1 .503 0 r
.768 .56736 m
.74425 .5792 L
.723 .58831 L
.70397 .59512 L
.68688 .6 L
.67152 .60325 L
.65768 .60516 L
.64519 .60594 L
.63389 .60581 L
.62366 .60492 L
.61437 .60342 L
.60592 .60143 L
.59823 .59905 L
.59121 .59638 L
.58478 .59348 L
.5789 .59042 L
.57351 .58725 L
.56855 .58401 L
.56399 .58074 L
.55978 .57747 L
.55589 .57422 L
.5523 .57101 L
.54897 .56787 L
.54589 .56479 L
.54303 .56179 L
.54037 .55889 L
.53789 .55607 L
.53559 .55336 L
.53344 .55074 L
.53143 .54823 L
.52956 .54581 L
.52781 .5435 L
.52617 .54128 L
.52464 .53917 L
.5232 .53714 L
.52185 .53522 L
.52059 .53338 L
.5194 .53163 L
.51829 .52996 L
.51724 .52838 L
.51626 .52687 L
.51533 .52544 L
.51446 .52408 L
.51364 .52279 L
.51287 .52157 L
.51215 .52041 L
.51146 .51931 L
.51082 .51827 L
.51021 .51728 L
.50964 .51634 L
Mistroke
.5091 .51545 L
.50859 .51461 L
.50811 .51382 L
.50766 .51307 L
.50723 .51235 L
.50683 .51168 L
.50645 .51104 L
.50609 .51044 L
.50575 .50987 L
.50543 .50933 L
.50513 .50882 L
.50485 .50833 L
.50458 .50788 L
.50433 .50744 L
.50409 .50704 L
.50386 .50665 L
.50365 .50628 L
.50344 .50594 L
.50325 .50561 L
.50307 .5053 L
.5029 .50501 L
.50274 .50474 L
.50259 .50448 L
.50245 .50423 L
.50231 .504 L
.50219 .50378 L
.50207 .50357 L
.50195 .50337 L
.50184 .50319 L
.50174 .50301 L
.50165 .50285 L
.50155 .50269 L
.50147 .50254 L
.50139 .5024 L
.50131 .50227 L
.50124 .50214 L
.50117 .50203 L
.50111 .50191 L
.50105 .50181 L
.50099 .50171 L
.50093 .50162 L
.50088 .50153 L
.50083 .50144 L
.50079 .50136 L
.50074 .50129 L
.5007 .50122 L
.50066 .50115 L
.50063 .50109 L
.50059 .50103 L
.50056 .50097 L
Mistroke
.50053 .50092 L
.5005 .50087 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50036 .50062 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
Mistroke
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.768 .56736 m
.74425 .5792 L
s
% Start of user PostScript
8.0399696 2.0209392 7.3274164 2.3761214 MAarrowhead1
% End of user PostScript
1 .158 0 r
.723 .58831 m
.70397 .59512 L
s
% Start of user PostScript
6.6901042 2.649434 6.119084 2.8537059 MAarrowhead1
% End of user PostScript
1 .473 0 r
.61437 .60342 m
.60592 .60143 L
s
% Start of user PostScript
3.4311159 3.1025369 3.1777173 3.0428416 MAarrowhead1
% End of user PostScript
1 .788 0 r
.56399 .58074 m
.55978 .57747 L
s
% Start of user PostScript
1.9195522 2.4221746 1.7933202 2.3240362 MAarrowhead1
% End of user PostScript
.897 1 0 r
.53789 .55607 m
.53559 .55336 L
s
% Start of user PostScript
1.1368309 1.6822287 1.0676771 1.6007433 MAarrowhead1
% End of user PostScript
.581 1 0 r
.5232 .53714 m
.52185 .53522 L
s
% Start of user PostScript
0.69598391 1.1143351 0.65555795 1.0564837 MAarrowhead1
% End of user PostScript
.266 1 0 r
.51446 .52408 m
.51364 .52279 L
s
% Start of user PostScript
0.43383313 0.72245757 0.4092643 0.68376992 MAarrowhead1
% End of user PostScript
0 1 .049 r
.5091 .51545 m
.50859 .51461 L
s
% Start of user PostScript
0.27297777 0.46360749 0.25772261 0.43841356 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50575 .50987 m
.50543 .50933 L
s
% Start of user PostScript
0.17259083 0.29601132 0.16301122 0.27980942 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50365 .50628 m
.50344 .50594 L
s
% Start of user PostScript
0.1093863 0.18853321 0.10333575 0.17817744 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50231 .504 m
.50219 .50378 L
s
% Start of user PostScript
0.069412646 0.11993088 0.065579847 0.11333171 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50147 .50254 m
.50139 .5024 L
s
% Start of user PostScript
0.044073782 0.076244176 0.041642254 0.072045176 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50093 .50162 m
.50088 .50153 L
s
% Start of user PostScript
0.027993377 0.048456127 0.026449671 0.045786331 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50059 .50103 m
.50056 .50097 L
s
% Start of user PostScript
0.01778267 0.03079101 0.016802251 0.029094141 MAarrowhead1
% End of user PostScript
1 .883 0 r
.65882 .81035 m
.65086 .79186 L
.64324 .77457 L
.63594 .7584 L
.62897 .74326 L
.62231 .72907 L
.61596 .71577 L
.6099 .70329 L
.60414 .69158 L
.59865 .68058 L
.59343 .67024 L
.58847 .66053 L
.58376 .6514 L
.57929 .6428 L
.57504 .63472 L
.57101 .62711 L
.56719 .61994 L
.56357 .61319 L
.56013 .60683 L
.55688 .60083 L
.5538 .59519 L
.55088 .58986 L
.54811 .58484 L
.54549 .5801 L
.54302 .57564 L
.54067 .57142 L
.53845 .56745 L
.53635 .5637 L
.53436 .56016 L
.53248 .55682 L
.53071 .55366 L
.52902 .55069 L
.52743 .54788 L
.52593 .54522 L
.52451 .54272 L
.52316 .54035 L
.52189 .53812 L
.52069 .53601 L
.51955 .53402 L
.51848 .53214 L
.51746 .53036 L
.5165 .52868 L
.5156 .5271 L
.51474 .5256 L
.51393 .52419 L
.51316 .52285 L
.51244 .52159 L
.51175 .5204 L
.51111 .51927 L
.51049 .51821 L
Mistroke
.50992 .5172 L
.50937 .51625 L
.50885 .51536 L
.50837 .51451 L
.50791 .51371 L
.50747 .51295 L
.50706 .51224 L
.50667 .51156 L
.5063 .51093 L
.50596 .51032 L
.50563 .50975 L
.50532 .50922 L
.50502 .50871 L
.50475 .50823 L
.50449 .50777 L
.50424 .50734 L
.50401 .50694 L
.50378 .50656 L
.50358 .5062 L
.50338 .50585 L
.50319 .50553 L
.50302 .50523 L
.50285 .50494 L
.50269 .50467 L
.50254 .50441 L
.5024 .50417 L
.50227 .50394 L
.50215 .50372 L
.50203 .50351 L
.50192 .50332 L
.50181 .50314 L
.50171 .50296 L
.50162 .5028 L
.50153 .50265 L
.50144 .5025 L
.50136 .50236 L
.50129 .50223 L
.50122 .50211 L
.50115 .50199 L
.50109 .50188 L
.50103 .50178 L
.50097 .50168 L
.50092 .50159 L
.50087 .5015 L
.50082 .50142 L
.50077 .50134 L
.50073 .50127 L
.50069 .5012 L
.50065 .50113 L
.50062 .50107 L
Mistroke
.50058 .50101 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .5008 L
.50044 .50076 L
.50041 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .50061 L
.50033 .50057 L
.50031 .50054 L
.5003 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50016 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
Mistroke
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.65882 .81035 m
.65086 .79186 L
s
% Start of user PostScript
4.7645936 9.3103742 4.5259001 8.7557138 MAarrowhead1
% End of user PostScript
1 .158 0 r
.64324 .77457 m
.63594 .7584 L
s
% Start of user PostScript
4.297168 8.2371622 4.0782747 7.7519902 MAarrowhead1
% End of user PostScript
1 .473 0 r
.59343 .67024 m
.58847 .66053 L
s
% Start of user PostScript
2.8029887 5.1073117 2.6541954 4.815898 MAarrowhead1
% End of user PostScript
1 .788 0 r
.56013 .60683 m
.55688 .60083 L
s
% Start of user PostScript
1.8039978 3.2048202 1.706374 3.0250229 MAarrowhead1
% End of user PostScript
.897 1 0 r
.53845 .56745 m
.53635 .5637 L
s
% Start of user PostScript
1.1535105 2.0234258 1.0905042 1.910893 MAarrowhead1
% End of user PostScript
.581 1 0 r
.52451 .54272 m
.52316 .54035 L
s
% Start of user PostScript
0.73521165 1.2815231 0.69486909 1.2105664 MAarrowhead1
% End of user PostScript
.266 1 0 r
.5156 .5271 m
.51474 .5256 L
s
% Start of user PostScript
0.46785425 0.81292104 0.44212375 0.7680109 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50992 .5172 m
.50937 .51625 L
s
% Start of user PostScript
0.29748399 0.51607525 0.28110479 0.48759645 MAarrowhead1
% End of user PostScript
0 1 .364 r
.5063 .51093 m
.50596 .51032 L
s
% Start of user PostScript
0.18907943 0.32775508 0.17866301 0.3096786 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50401 .50694 m
.50378 .50656 L
s
% Start of user PostScript
0.12015417 0.20819572 0.11353298 0.19671646 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50254 .50441 m
.5024 .50417 L
s
% Start of user PostScript
0.076346715 0.13226263 0.072138978 0.12497112 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50162 .5028 m
.50153 .50265 L
s
% Start of user PostScript
0.048508778 0.084028008 0.045835099 0.079395947 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50103 .50178 m
.50097 .50168 L
s
% Start of user PostScript
0.03082049 0.053385305 0.029121684 0.050442533 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50065 .50113 m
.50062 .50107 L
s
% Start of user PostScript
0.019581834 0.033917574 0.018502477 0.03204796 MAarrowhead1
% End of user PostScript
0 .11 1 r
.55447 .25591 m
.54381 .28263 L
.53476 .30611 L
.52709 .32675 L
.52062 .34493 L
.51516 .36096 L
.51059 .3751 L
.50676 .3876 L
.50358 .39866 L
.50095 .40846 L
.49879 .41716 L
.49703 .42489 L
.49561 .43177 L
.49448 .43791 L
.4936 .44339 L
.49292 .44829 L
.49242 .45269 L
.49206 .45664 L
.49183 .46019 L
.4917 .46339 L
.49165 .46628 L
.49168 .46889 L
.49176 .47126 L
.49188 .47341 L
.49205 .47537 L
.49224 .47715 L
.49246 .47878 L
.49269 .48027 L
.49293 .48163 L
.49318 .48289 L
.49344 .48404 L
.4937 .4851 L
.49395 .48607 L
.49421 .48698 L
.49446 .48781 L
.49471 .48859 L
.49495 .4893 L
.49518 .48997 L
.49541 .49059 L
.49563 .49116 L
.49584 .4917 L
.49605 .4922 L
.49624 .49267 L
.49643 .4931 L
.49661 .49351 L
.49678 .49389 L
.49695 .49425 L
.49711 .49459 L
.49726 .4949 L
.4974 .4952 L
Mistroke
.49754 .49547 L
.49767 .49573 L
.49779 .49598 L
.49791 .49621 L
.49802 .49642 L
.49813 .49662 L
.49823 .49682 L
.49832 .497 L
.49841 .49717 L
.4985 .49732 L
.49858 .49747 L
.49866 .49762 L
.49873 .49775 L
.4988 .49788 L
.49886 .49799 L
.49892 .49811 L
.49898 .49821 L
.49904 .49831 L
.49909 .49841 L
.49914 .49849 L
.49919 .49858 L
.49923 .49866 L
.49927 .49873 L
.49931 .4988 L
.49935 .49887 L
.49939 .49893 L
.49942 .49899 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
.49956 .49924 L
.49959 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .49939 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49977 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
Mistroke
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.55447 .25591 m
.54381 .28263 L
s
% Start of user PostScript
1.6340295 -7.32259 1.3142217 -6.5210416 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53476 .30611 m
.52709 .32675 L
s
% Start of user PostScript
1.0427139 -5.8168004 0.81274858 -5.1974101 MAarrowhead1
% End of user PostScript
1 .473 0 r
.49879 .41716 m
.49703 .42489 L
s
% Start of user PostScript
-0.036333842 -2.4852818 -0.089144015 -2.253351 MAarrowhead1
% End of user PostScript
1 .788 0 r
.49183 .46019 m
.4917 .46339 L
s
% Start of user PostScript
-0.24515076 -1.1943769 -0.24905594 -1.0983721 MAarrowhead1
% End of user PostScript
.897 1 0 r
.49246 .47878 m
.49269 .48027 L
s
% Start of user PostScript
-0.22632212 -0.63661333 -0.21938202 -0.59193533 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49446 .48781 m
.49471 .48859 L
s
% Start of user PostScript
-0.16621677 -0.36562756 -0.1588136 -0.34242717 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49624 .49267 m
.49643 .4931 L
s
% Start of user PostScript
-0.11273067 -0.21995647 -0.10707575 -0.20686407 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49754 .49547 m
.49767 .49573 L
s
% Start of user PostScript
-0.073887133 -0.13582571 -0.069991994 -0.12803118 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49841 .49717 m
.4985 .49732 L
s
% Start of user PostScript
-0.047663282 -0.085049586 -0.045092462 -0.080263781 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49898 .49821 m
.49904 .49831 L
s
% Start of user PostScript
-0.030511213 -0.053639618 -0.028847331 -0.050651866 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49935 .49887 m
.49939 .49893 L
s
% Start of user PostScript
-0.019457759 -0.033953711 -0.018390922 -0.032072266 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49959 .49928 m
.49961 .49932 L
s
% Start of user PostScript
-0.012385448 -0.021532267 -0.011704557 -0.020342243 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49974 .49954 m
.49975 .49957 L
s
% Start of user PostScript
-0.0078763486 -0.013667671 -0.0074427695 -0.012913295 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49983 .49971 m
.49984 .49973 L
s
% Start of user PostScript
-0.0050065169 -0.0086796244 -0.004730734 -0.0082008753 MAarrowhead1
% End of user PostScript
1 0 .34 r
.17615 .40631 m
.20458 .39316 L
.23002 .38319 L
.25284 .37588 L
.27334 .3708 L
.2918 .3676 L
.30844 .36596 L
.32347 .36559 L
.33708 .36629 L
.34942 .36784 L
.36063 .37008 L
.37083 .37287 L
.38014 .37609 L
.38864 .37964 L
.39642 .38344 L
.40355 .3874 L
.4101 .39147 L
.41612 .3956 L
.42167 .39976 L
.42679 .40389 L
.43152 .40799 L
.4359 .41202 L
.43995 .41596 L
.44371 .41981 L
.44721 .42355 L
.45046 .42718 L
.45348 .43069 L
.4563 .43407 L
.45893 .43732 L
.46139 .44044 L
.46368 .44344 L
.46583 .44631 L
.46783 .44905 L
.46971 .45167 L
.47148 .45417 L
.47313 .45656 L
.47468 .45883 L
.47614 .461 L
.47751 .46306 L
.47879 .46501 L
.48 .46687 L
.48114 .46864 L
.48221 .47032 L
.48321 .47191 L
.48416 .47342 L
.48505 .47485 L
.48589 .47621 L
.48669 .47749 L
.48743 .47871 L
.48814 .47987 L
Mistroke
.4888 .48096 L
.48942 .482 L
.49001 .48298 L
.49057 .4839 L
.4911 .48478 L
.49159 .48561 L
.49206 .4864 L
.4925 .48714 L
.49292 .48785 L
.49331 .48851 L
.49368 .48914 L
.49403 .48974 L
.49436 .4903 L
.49467 .49083 L
.49497 .49133 L
.49525 .49181 L
.49551 .49226 L
.49576 .49269 L
.49599 .49309 L
.49621 .49347 L
.49642 .49383 L
.49662 .49417 L
.49681 .49449 L
.49698 .49479 L
.49715 .49508 L
.49731 .49535 L
.49746 .4956 L
.4976 .49585 L
.49773 .49607 L
.49785 .49629 L
.49797 .49649 L
.49809 .49669 L
.49819 .49687 L
.49829 .49704 L
.49838 .49721 L
.49847 .49736 L
.49856 .4975 L
.49864 .49764 L
.49871 .49777 L
.49878 .49789 L
.49885 .49801 L
.49891 .49812 L
.49897 .49822 L
.49903 .49832 L
.49908 .49841 L
.49913 .4985 L
.49918 .49858 L
.49923 .49866 L
.49927 .49874 L
.49931 .49881 L
Mistroke
.49935 .49887 L
.49938 .49893 L
.49942 .49899 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
.49956 .49924 L
.49959 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49977 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
Mistroke
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.17615 .40631 m
.20458 .39316 L
s
% Start of user PostScript
-9.7154496 -2.8106541 -8.8627446 -3.2050933 MAarrowhead1
% End of user PostScript
1 .158 0 r
.23002 .38319 m
.25284 .37588 L
s
% Start of user PostScript
-8.0993871 -3.5044463 -7.4147988 -3.7237463 MAarrowhead1
% End of user PostScript
1 .473 0 r
.36063 .37008 m
.37083 .37287 L
s
% Start of user PostScript
-4.1811052 -3.8975846 -3.8749624 -3.8138173 MAarrowhead1
% End of user PostScript
1 .788 0 r
.42167 .39976 m
.42679 .40389 L
s
% Start of user PostScript
-2.3498518 -3.0073254 -2.1962773 -2.8832094 MAarrowhead1
% End of user PostScript
.897 1 0 r
.45348 .43069 m
.4563 .43407 L
s
% Start of user PostScript
-1.3955372 -2.0794295 -1.3109716 -1.9780446 MAarrowhead1
% End of user PostScript
.581 1 0 r
.47148 .45417 m
.47313 .45656 L
s
% Start of user PostScript
-0.85568582 -1.3747748 -0.80609094 -1.3032014 MAarrowhead1
% End of user PostScript
.266 1 0 r
.48221 .47032 m
.48321 .47191 L
s
% Start of user PostScript
-0.5338161 -0.89049404 -0.50361979 -0.84274542 MAarrowhead1
% End of user PostScript
0 1 .049 r
.4888 .48096 m
.48942 .482 L
s
% Start of user PostScript
-0.33603015 -0.57118434 -0.31726251 -0.54012464 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49292 .48785 m
.49331 .48851 L
s
% Start of user PostScript
-0.21250103 -0.36461886 -0.20070977 -0.34465556 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49551 .49226 m
.49576 .49269 L
s
% Start of user PostScript
-0.1346954 -0.23220495 -0.12724605 -0.2194484 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49715 .49508 m
.49731 .49535 L
s
% Start of user PostScript
-0.085477496 -0.14770361 -0.080757995 -0.13957563 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49819 .49687 m
.49829 .49704 L
s
% Start of user PostScript
-0.054275672 -0.093897715 -0.051281426 -0.088726281 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49885 .49801 m
.49891 .49812 L
s
% Start of user PostScript
-0.034473553 -0.059674828 -0.032572531 -0.05638685 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49927 .49874 m
.49931 .49881 L
s
% Start of user PostScript
-0.021899321 -0.037919577 -0.020691949 -0.035829837 MAarrowhead1
% End of user PostScript
0 1 .002 r
.40915 .47768 m
.41721 .47361 L
.42442 .47048 L
.43088 .46814 L
.43668 .46645 L
.44189 .46532 L
.44659 .46464 L
.45083 .46435 L
.45466 .46438 L
.45813 .46466 L
.46128 .46515 L
.46414 .46581 L
.46675 .4666 L
.46913 .46749 L
.47131 .46846 L
.4733 .46949 L
.47513 .47055 L
.47681 .47164 L
.47835 .47274 L
.47978 .47384 L
.48109 .47494 L
.48231 .47602 L
.48343 .47708 L
.48448 .47812 L
.48545 .47913 L
.48635 .48011 L
.48718 .48106 L
.48796 .48197 L
.48869 .48286 L
.48937 .48371 L
.49 .48452 L
.4906 .4853 L
.49115 .48605 L
.49167 .48676 L
.49216 .48745 L
.49261 .4881 L
.49304 .48872 L
.49344 .48931 L
.49382 .48987 L
.49417 .49041 L
.4945 .49092 L
.49482 .4914 L
.49511 .49186 L
.49539 .4923 L
.49565 .49271 L
.49589 .4931 L
.49613 .49347 L
.49634 .49383 L
.49655 .49416 L
.49674 .49448 L
Mistroke
.49692 .49478 L
.4971 .49506 L
.49726 .49533 L
.49741 .49558 L
.49756 .49582 L
.49769 .49605 L
.49782 .49627 L
.49794 .49647 L
.49806 .49666 L
.49816 .49685 L
.49827 .49702 L
.49836 .49718 L
.49845 .49734 L
.49854 .49748 L
.49862 .49762 L
.4987 .49775 L
.49877 .49788 L
.49884 .49799 L
.4989 .4981 L
.49896 .49821 L
.49902 .49831 L
.49907 .4984 L
.49912 .49849 L
.49917 .49857 L
.49922 .49865 L
.49926 .49872 L
.4993 .49879 L
.49934 .49886 L
.49938 .49892 L
.49941 .49898 L
.49944 .49904 L
.49947 .49909 L
.4995 .49914 L
.49953 .49919 L
.49956 .49923 L
.49958 .49928 L
.4996 .49932 L
.49963 .49935 L
.49965 .49939 L
.49967 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49978 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
Mistroke
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.40915 .47768 m
.41721 .47361 L
s
% Start of user PostScript
-2.725484 -0.66972494 -2.4835868 -0.79157719 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42442 .47048 m
.43088 .46814 L
s
% Start of user PostScript
-2.2672612 -0.88551609 -2.0734638 -0.95591018 MAarrowhead1
% End of user PostScript
1 .473 0 r
.46128 .46515 m
.46414 .46581 L
s
% Start of user PostScript
-1.1616633 -1.0455472 -1.0757607 -1.0257956 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47835 .47274 m
.47978 .47384 L
s
% Start of user PostScript
-0.64945097 -0.81774802 -0.60670255 -0.78471014 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48718 .48106 m
.48796 .48197 L
s
% Start of user PostScript
-0.38446812 -0.56831864 -0.36106725 -0.54081739 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49216 .48745 m
.49261 .4881 L
s
% Start of user PostScript
-0.23532189 -0.37657468 -0.22164883 -0.35703295 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49511 .49186 m
.49539 .4923 L
s
% Start of user PostScript
-0.14666693 -0.24417884 -0.13835944 -0.23110566 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49692 .49478 m
.4971 .49506 L
s
% Start of user PostScript
-0.092280334 -0.15670232 -0.087122853 -0.14818743 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49806 .49666 m
.49816 .49685 L
s
% Start of user PostScript
-0.058342575 -0.10005706 -0.055104136 -0.09458079 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49877 .49788 m
.49884 .49799 L
s
% Start of user PostScript
-0.036976325 -0.063728609 -0.034930985 -0.060228199 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49922 .49865 m
.49926 .49872 L
s
% Start of user PostScript
-0.023463666 -0.04053976 -0.022168044 -0.038309095 MAarrowhead1
% End of user PostScript
0 .69 1 r
.4995 .49914 m
.49953 .49919 L
s
% Start of user PostScript
-0.014898269 -0.025772622 -0.014076334 -0.024353253 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49968 .49945 m
.4997 .49948 L
s
% Start of user PostScript
-0.0094625872 -0.016379533 -0.0089407674 -0.01547707 MAarrowhead1
% End of user PostScript
0 .06 1 r
.4998 .49965 m
.49981 .49967 L
s
% Start of user PostScript
-0.0060110608 -0.010408238 -0.0056796502 -0.0098346483 MAarrowhead1
% End of user PostScript
1 .704 0 r
.49821 .53225 m
.49911 .52909 L
.49985 .52628 L
.50046 .52379 L
.50095 .52158 L
.50135 .51961 L
.50167 .51785 L
.50191 .51628 L
.5021 .51488 L
.50224 .51362 L
.50234 .51248 L
.5024 .51146 L
.50243 .51055 L
.50244 .50972 L
.50243 .50897 L
.5024 .50829 L
.50237 .50767 L
.50232 .5071 L
.50226 .50659 L
.50219 .50612 L
.50213 .50569 L
.50205 .5053 L
.50198 .50494 L
.50191 .50461 L
.50183 .5043 L
.50175 .50402 L
.50168 .50376 L
.50161 .50352 L
.50154 .5033 L
.50147 .50309 L
.5014 .5029 L
.50133 .50272 L
.50127 .50255 L
.50121 .5024 L
.50115 .50226 L
.50109 .50212 L
.50103 .50199 L
.50098 .50188 L
.50093 .50177 L
.50088 .50166 L
.50084 .50157 L
.50079 .50148 L
.50075 .50139 L
.50071 .50131 L
.50068 .50123 L
.50064 .50116 L
.50061 .5011 L
.50057 .50104 L
.50054 .50098 L
.50051 .50092 L
Mistroke
.50049 .50087 L
.50046 .50082 L
.50044 .50077 L
.50041 .50073 L
.50039 .50069 L
.50037 .50065 L
.50035 .50061 L
.50033 .50058 L
.50031 .50055 L
.50029 .50052 L
.50028 .50049 L
.50026 .50046 L
.50025 .50044 L
.50024 .50041 L
.50022 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
Mistroke
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.49821 .53225 m
.49911 .52909 L
s
% Start of user PostScript
-0.053762816 0.96745089 -0.026800737 0.87255693 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49985 .52628 m
.50046 .52379 L
s
% Start of user PostScript
-0.0045288255 0.78844311 0.013739202 0.71377432 MAarrowhead1
% End of user PostScript
1 .473 0 r
.50234 .51248 m
.5024 .51146 L
s
% Start of user PostScript
0.070121419 0.37449443 0.071982038 0.34393443 MAarrowhead1
% End of user PostScript
1 .788 0 r
.50226 .50659 m
.50219 .50612 L
s
% Start of user PostScript
0.067748394 0.19775375 0.065833534 0.18370181 MAarrowhead1
% End of user PostScript
.897 1 0 r
.50168 .50376 m
.50161 .50352 L
s
% Start of user PostScript
0.050414995 0.11287369 0.048214253 0.10565047 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50115 .50226 m
.50109 .50212 L
s
% Start of user PostScript
0.034373313 0.067656236 0.032662348 0.063608694 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50075 .50139 m
.50071 .50131 L
s
% Start of user PostScript
0.022583237 0.041695623 0.021396807 0.039296176 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50049 .50087 m
.50046 .50082 L
s
% Start of user PostScript
0.014584655 0.026081322 0.013799284 0.024611549 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50031 .50055 m
.50029 .50052 L
s
% Start of user PostScript
0.0093414313 0.016440396 0.0088324154 0.015523968 MAarrowhead1
% End of user PostScript
0 1 .679 r
.5002 .50035 m
.50019 .50033 L
s
% Start of user PostScript
0.0059589023 0.010403922 0.0056323134 0.0098271991 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50013 .50022 m
.50012 .50021 L
s
% Start of user PostScript
0.0037935392 0.0065969145 0.0035850297 0.0062322527 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50008 .50014 m
.50008 .50013 L
s
% Start of user PostScript
0.0024126117 0.0041871274 0.0022798146 0.0039559997 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50005 .50009 m
.50005 .50008 L
s
% Start of user PostScript
0.0015336031 0.0026589356 0.001449129 0.0025122674 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50003 .50006 m
.50003 .50005 L
s
% Start of user PostScript
0.00097460801 0.0016889149 0.00092090545 0.0015957866 MAarrowhead1
% End of user PostScript
.612 1 0 r
.47414 .19021 m
.46957 .21767 L
.46605 .24223 L
.46342 .26424 L
.46153 .28399 L
.46027 .30175 L
.45953 .31776 L
.45923 .3322 L
.45928 .34525 L
.45962 .35709 L
.46019 .36782 L
.46095 .37759 L
.46187 .38648 L
.46289 .3946 L
.46401 .40202 L
.46519 .40882 L
.46641 .41505 L
.46765 .42079 L
.46891 .42606 L
.47017 .43092 L
.47142 .43541 L
.47265 .43957 L
.47387 .44341 L
.47505 .44697 L
.4762 .45028 L
.47732 .45335 L
.47841 .45621 L
.47945 .45888 L
.48046 .46136 L
.48143 .46368 L
.48236 .46584 L
.48325 .46787 L
.4841 .46976 L
.48492 .47153 L
.4857 .47319 L
.48644 .47475 L
.48715 .47621 L
.48782 .47758 L
.48846 .47887 L
.48907 .48008 L
.48965 .48122 L
.4902 .48229 L
.49073 .48329 L
.49122 .48424 L
.49169 .48513 L
.49214 .48597 L
.49256 .48676 L
.49297 .4875 L
.49335 .4882 L
.49371 .48886 L
Mistroke
.49405 .48949 L
.49437 .49007 L
.49468 .49063 L
.49497 .49115 L
.49524 .49164 L
.4955 .49211 L
.49575 .49255 L
.49598 .49296 L
.4962 .49335 L
.49641 .49372 L
.4966 .49407 L
.49679 .4944 L
.49697 .49471 L
.49713 .495 L
.49729 .49528 L
.49744 .49554 L
.49758 .49579 L
.49771 .49602 L
.49784 .49624 L
.49796 .49645 L
.49807 .49664 L
.49818 .49683 L
.49828 .497 L
.49837 .49717 L
.49846 .49733 L
.49855 .49747 L
.49863 .49761 L
.4987 .49775 L
.49877 .49787 L
.49884 .49799 L
.4989 .4981 L
.49896 .4982 L
.49902 .4983 L
.49908 .4984 L
.49913 .49848 L
.49917 .49857 L
.49922 .49865 L
.49926 .49872 L
.4993 .49879 L
.49934 .49886 L
.49938 .49892 L
.49941 .49898 L
.49944 .49904 L
.49948 .49909 L
.4995 .49914 L
.49953 .49919 L
.49956 .49923 L
.49958 .49928 L
.4996 .49932 L
.49963 .49935 L
Mistroke
.49965 .49939 L
.49967 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49978 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
Mistroke
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.47414 .19021 m
.46957 .21767 L
s
% Start of user PostScript
-0.77584619 -9.2936554 -0.91296979 -8.4697997 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46605 .24223 m
.46342 .26424 L
s
% Start of user PostScript
-1.0185185 -7.7329536 -1.0974391 -7.0727677 MAarrowhead1
% End of user PostScript
1 .473 0 r
.46019 .36782 m
.46095 .37759 L
s
% Start of user PostScript
-1.1942947 -3.9653263 -1.1713832 -3.6724134 MAarrowhead1
% End of user PostScript
1 .788 0 r
.46891 .42606 m
.47017 .43092 L
s
% Start of user PostScript
-0.93266938 -2.2181705 -0.89489822 -2.072279 MAarrowhead1
% End of user PostScript
.897 1 0 r
.47841 .45621 m
.47945 .45888 L
s
% Start of user PostScript
-0.64782074 -1.3135944 -0.61644608 -1.2336805 MAarrowhead1
% End of user PostScript
.581 1 0 r
.4857 .47319 m
.48644 .47475 L
s
% Start of user PostScript
-0.4291474 -0.80417052 -0.40686949 -0.75745809 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49073 .48329 m
.49122 .48424 L
s
% Start of user PostScript
-0.27823568 -0.50125988 -0.26333663 -0.47287173 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49405 .48949 m
.49437 .49007 L
s
% Start of user PostScript
-0.17854828 -0.31540097 -0.16884555 -0.29777476 MAarrowhead1
% End of user PostScript
0 1 .364 r
.4962 .49335 m
.49641 .49372 L
s
% Start of user PostScript
-0.1140029 -0.19941195 -0.10776311 -0.18834356 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49758 .49579 m
.49771 .49602 L
s
% Start of user PostScript
-0.072610029 -0.12638492 -0.068621714 -0.11939409 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49846 .49733 m
.49855 .49747 L
s
% Start of user PostScript
-0.046189192 -0.080199257 -0.043647646 -0.075770839 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49902 .4983 m
.49908 .4984 L
s
% Start of user PostScript
-0.029364073 -0.050922742 -0.027746905 -0.048113357 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49938 .49892 m
.49941 .49898 L
s
% Start of user PostScript
-0.018662012 -0.03234347 -0.017633788 -0.030559875 MAarrowhead1
% End of user PostScript
0 .06 1 r
.4996 .49932 m
.49963 .49935 L
s
% Start of user PostScript
-0.01185861 -0.020546043 -0.011205091 -0.019413271 MAarrowhead1
% End of user PostScript
.699 1 0 r
.51209 .77712 m
.51722 .75181 L
.52129 .72923 L
.52447 .70905 L
.52689 .691 L
.52868 .67481 L
.52993 .66027 L
.53073 .64719 L
.53117 .63539 L
.53129 .62474 L
.53116 .6151 L
.53083 .60636 L
.53033 .59842 L
.52969 .5912 L
.52896 .58461 L
.52814 .5786 L
.52726 .57309 L
.52635 .56805 L
.5254 .56342 L
.52444 .55916 L
.52347 .55524 L
.52251 .55163 L
.52156 .54829 L
.52062 .54519 L
.51969 .54233 L
.51879 .53968 L
.51792 .53721 L
.51707 .53492 L
.51625 .53278 L
.51546 .53079 L
.5147 .52894 L
.51397 .52721 L
.51327 .52559 L
.51259 .52408 L
.51195 .52266 L
.51134 .52133 L
.51075 .52009 L
.51019 .51893 L
.50966 .51783 L
.50915 .51681 L
.50867 .51584 L
.50821 .51494 L
.50777 .51409 L
.50736 .51329 L
.50696 .51253 L
.50659 .51182 L
.50624 .51116 L
.5059 .51053 L
.50558 .50993 L
.50528 .50938 L
Mistroke
.505 .50885 L
.50472 .50835 L
.50447 .50789 L
.50423 .50745 L
.504 .50703 L
.50378 .50664 L
.50357 .50627 L
.50338 .50592 L
.50319 .50559 L
.50302 .50528 L
.50285 .50499 L
.5027 .50471 L
.50255 .50445 L
.50241 .5042 L
.50228 .50397 L
.50215 .50375 L
.50203 .50354 L
.50192 .50335 L
.50182 .50316 L
.50172 .50299 L
.50162 .50282 L
.50153 .50267 L
.50145 .50252 L
.50137 .50238 L
.50129 .50225 L
.50122 .50212 L
.50116 .50201 L
.50109 .5019 L
.50103 .50179 L
.50098 .50169 L
.50092 .5016 L
.50087 .50151 L
.50082 .50143 L
.50078 .50135 L
.50073 .50127 L
.50069 .5012 L
.50066 .50114 L
.50062 .50107 L
.50059 .50102 L
.50055 .50096 L
.50052 .50091 L
.50049 .50086 L
.50047 .50081 L
.50044 .50076 L
.50042 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .50061 L
.50033 .50058 L
.50031 .50054 L
Mistroke
.5003 .50051 L
.50028 .50049 L
.50026 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
Mistroke
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.51209 .77712 m
.51722 .75181 L
s
% Start of user PostScript
0.36266067 8.3137228 0.51657959 7.5542399 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52129 .72923 m
.52447 .70905 L
s
% Start of user PostScript
0.6387962 6.8768355 0.73415774 6.2716166 MAarrowhead1
% End of user PostScript
1 .473 0 r
.53116 .6151 m
.53083 .60636 L
s
% Start of user PostScript
0.93485082 3.4529033 0.92481346 3.1907071 MAarrowhead1
% End of user PostScript
1 .788 0 r
.5254 .56342 m
.52444 .55916 L
s
% Start of user PostScript
0.76205312 1.9026178 0.73323316 1.7749052 MAarrowhead1
% End of user PostScript
.897 1 0 r
.51792 .53721 m
.51707 .53492 L
s
% Start of user PostScript
0.537584 1.1162916 0.51214167 1.0475028 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51195 .52266 m
.51134 .52133 L
s
% Start of user PostScript
0.35852553 0.67982652 0.34009461 0.6400474 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50777 .51409 m
.50736 .51329 L
s
% Start of user PostScript
0.23318107 0.42258003 0.22075093 0.39855401 MAarrowhead1
% End of user PostScript
0 1 .049 r
.505 .50885 m
.50472 .50835 L
s
% Start of user PostScript
0.14986419 0.26551435 0.14173794 0.25064597 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50319 .50559 m
.50302 .50528 L
s
% Start of user PostScript
0.095759929 0.16774927 0.090524243 0.1584287 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50203 .50354 m
.50192 .50335 L
s
% Start of user PostScript
0.061013526 0.10627855 0.057663958 0.10039682 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50129 .50225 m
.50122 .50212 L
s
% Start of user PostScript
0.03881954 0.067428089 0.036684071 0.063703891 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50082 .50143 m
.50078 .50135 L
s
% Start of user PostScript
0.024681213 0.042809707 0.023322124 0.040447605 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50052 .50091 m
.50049 .50086 L
s
% Start of user PostScript
0.015686598 0.027189238 0.014822367 0.025689777 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50033 .50058 m
.50031 .50054 L
s
% Start of user PostScript
0.0099681394 0.017271442 0.0094188209 0.016319178 MAarrowhead1
% End of user PostScript
1 .225 0 r
.51993 .61288 m
.5206 .60359 L
.52101 .59522 L
.52118 .58766 L
.52116 .58083 L
.521 .57465 L
.52071 .56903 L
.52032 .56393 L
.51985 .55928 L
.51932 .55503 L
.51874 .55115 L
.51813 .5476 L
.5175 .54434 L
.51685 .54135 L
.5162 .53859 L
.51554 .53605 L
.51489 .53371 L
.51425 .53154 L
.51362 .52953 L
.513 .52767 L
.5124 .52594 L
.51182 .52434 L
.51126 .52285 L
.51071 .52145 L
.51019 .52016 L
.50968 .51895 L
.5092 .51782 L
.50873 .51676 L
.50829 .51577 L
.50786 .51485 L
.50746 .51398 L
.50707 .51317 L
.5067 .51241 L
.50635 .51169 L
.50602 .51102 L
.5057 .51039 L
.5054 .5098 L
.50511 .50924 L
.50484 .50871 L
.50458 .50822 L
.50433 .50776 L
.5041 .50732 L
.50388 .50691 L
.50367 .50652 L
.50347 .50615 L
.50328 .50581 L
.5031 .50548 L
.50294 .50518 L
.50278 .50489 L
.50262 .50462 L
Mistroke
.50248 .50436 L
.50235 .50412 L
.50222 .50389 L
.5021 .50367 L
.50198 .50347 L
.50187 .50327 L
.50177 .50309 L
.50167 .50292 L
.50158 .50276 L
.5015 .50261 L
.50141 .50246 L
.50134 .50233 L
.50126 .5022 L
.50119 .50208 L
.50113 .50196 L
.50107 .50185 L
.50101 .50175 L
.50095 .50165 L
.5009 .50156 L
.50085 .50148 L
.5008 .50139 L
.50076 .50132 L
.50072 .50124 L
.50068 .50118 L
.50064 .50111 L
.50061 .50105 L
.50057 .50099 L
.50054 .50094 L
.50051 .50089 L
.50048 .50084 L
.50046 .50079 L
.50043 .50075 L
.50041 .50071 L
.50038 .50067 L
.50036 .50063 L
.50034 .5006 L
.50032 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.50019 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50016 .50027 L
Mistroke
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
Mistroke
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.51993 .61288 m
.5206 .60359 L
s
% Start of user PostScript
0.59789117 3.386421 0.61812951 3.1076208 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52101 .59522 m
.52118 .58766 L
s
% Start of user PostScript
0.6301504 2.8564892 0.63535495 2.629859 MAarrowhead1
% End of user PostScript
1 .473 0 r
.51874 .55115 m
.51813 .5476 L
s
% Start of user PostScript
0.56216966 1.5345918 0.54387385 1.4280204 MAarrowhead1
% End of user PostScript
1 .788 0 r
.51362 .52953 m
.513 .52767 L
s
% Start of user PostScript
0.40858928 0.88593302 0.39010042 0.83011366 MAarrowhead1
% End of user PostScript
.897 1 0 r
.5092 .51782 m
.50873 .51676 L
s
% Start of user PostScript
0.27593401 0.53457063 0.26200579 0.50288456 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50602 .51102 m
.5057 .51039 L
s
% Start of user PostScript
0.18050513 0.33064251 0.17096272 0.31171165 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50388 .50691 m
.50367 .50652 L
s
% Start of user PostScript
0.11633271 0.20721363 0.11004972 0.19556758 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50248 .50436 m
.50235 .50412 L
s
% Start of user PostScript
0.074435529 0.13074363 0.070373672 0.12346563 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50158 .50276 m
.5015 .50261 L
s
% Start of user PostScript
0.047458731 0.082778492 0.044855812 0.078192997 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50101 .50175 m
.50095 .50165 L
s
% Start of user PostScript
0.030205533 0.052501051 0.028544717 0.049599931 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50064 .50111 m
.50061 .50105 L
s
% Start of user PostScript
0.019207707 0.033327047 0.018150273 0.031487731 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50041 .50071 m
.50038 .50067 L
s
% Start of user PostScript
0.012208834 0.021164855 0.011536287 0.019997494 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50026 .50045 m
.50024 .50042 L
s
% Start of user PostScript
0.0077584997 0.013444005 0.0073309743 0.012702723 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50016 .50028 m
.50016 .50027 L
s
% Start of user PostScript
0.0049298505 0.0085406231 0.0046581531 0.0080697794 MAarrowhead1
% End of user PostScript
0 1 .273 r
.48503 .63548 m
.48951 .62168 L
.49325 .60949 L
.49637 .59871 L
.49894 .58915 L
.50106 .58067 L
.50279 .57314 L
.50418 .56643 L
.50529 .56045 L
.50616 .5551 L
.50682 .55032 L
.50732 .54604 L
.50767 .5422 L
.5079 .53874 L
.50803 .53562 L
.50808 .53281 L
.50806 .53026 L
.50799 .52795 L
.50786 .52586 L
.50771 .52395 L
.50752 .52222 L
.50732 .52063 L
.50709 .51918 L
.50686 .51786 L
.50662 .51664 L
.50637 .51552 L
.50612 .51449 L
.50587 .51354 L
.50562 .51266 L
.50538 .51185 L
.50514 .51109 L
.50491 .5104 L
.50468 .50975 L
.50446 .50915 L
.50424 .50859 L
.50404 .50806 L
.50384 .50758 L
.50365 .50712 L
.50347 .5067 L
.50329 .5063 L
.50312 .50593 L
.50296 .50558 L
.50281 .50526 L
.50266 .50495 L
.50252 .50467 L
.50239 .5044 L
.50227 .50415 L
.50215 .50391 L
.50203 .50369 L
.50192 .50348 L
Mistroke
.50182 .50328 L
.50172 .50309 L
.50163 .50292 L
.50154 .50275 L
.50146 .5026 L
.50138 .50245 L
.50131 .50232 L
.50124 .50219 L
.50117 .50206 L
.5011 .50195 L
.50104 .50184 L
.50099 .50174 L
.50093 .50164 L
.50088 .50155 L
.50083 .50146 L
.50079 .50138 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50063 .5011 L
.5006 .50104 L
.50056 .50098 L
.50053 .50093 L
.5005 .50088 L
.50048 .50083 L
.50045 .50078 L
.50042 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50056 L
.5003 .50052 L
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .5004 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
Mistroke
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
Mistroke
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.48503 .63548 m
.48951 .62168 L
s
% Start of user PostScript
-0.44903476 4.0642905 -0.31471763 3.6504881 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49325 .60949 m
.49637 .59871 L
s
% Start of user PostScript
-0.20243204 3.284831 -0.10901066 2.961283 MAarrowhead1
% End of user PostScript
1 .473 0 r
.50682 .55032 m
.50732 .54604 L
s
% Start of user PostScript
0.20466246 1.5097438 0.21952238 1.3812469 MAarrowhead1
% End of user PostScript
1 .788 0 r
.50786 .52586 m
.50771 .52395 L
s
% Start of user PostScript
0.23593796 0.77576921 0.23123977 0.7186196 MAarrowhead1
% End of user PostScript
.897 1 0 r
.50612 .51449 m
.50587 .51354 L
s
% Start of user PostScript
0.18355625 0.43458817 0.17607816 0.40606089 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50424 .50859 m
.50404 .50806 L
s
% Start of user PostScript
0.12731586 0.25758903 0.12113689 0.24193745 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50281 .50526 m
.50266 .50495 L
s
% Start of user PostScript
0.084287763 0.1577711 0.079908279 0.14861285 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50182 .50328 m
.50172 .50309 L
s
% Start of user PostScript
0.05463162 0.098368269 0.051704962 0.092799362 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50117 .50206 m
.5011 .50195 L
s
% Start of user PostScript
0.035053016 0.061903206 0.033147766 0.058444397 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50075 .5013 m
.50071 .50123 L
s
% Start of user PostScript
0.022379753 0.039140896 0.021154706 0.036968583 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50048 .50083 m
.50045 .50078 L
s
% Start of user PostScript
0.014253481 0.024807881 0.013470529 0.02343573 MAarrowhead1
% End of user PostScript
0 .69 1 r
.5003 .50052 m
.50029 .5005 L
s
% Start of user PostScript
0.0090668658 0.015742446 0.0085679521 0.014873205 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50019 .50033 m
.50018 .50031 L
s
% Start of user PostScript
0.0057640717 0.0099957957 0.005446623 0.0094443389 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50012 .50021 m
.50012 .5002 L
s
% Start of user PostScript
0.0036632762 0.0063488354 0.0034614389 0.0059987282 MAarrowhead1
% End of user PostScript
0 .949 1 r
.40976 .4835 m
.4179 .47893 L
.42517 .47535 L
.43167 .47259 L
.43749 .47054 L
.44272 .46907 L
.44742 .4681 L
.45166 .46754 L
.45548 .46732 L
.45894 .46738 L
.46208 .46767 L
.46492 .46814 L
.46751 .46877 L
.46987 .46951 L
.47202 .47034 L
.47399 .47124 L
.47579 .47218 L
.47744 .47316 L
.47896 .47416 L
.48036 .47517 L
.48165 .47618 L
.48284 .47718 L
.48395 .47817 L
.48497 .47914 L
.48591 .48009 L
.48679 .48101 L
.48761 .4819 L
.48837 .48277 L
.48907 .4836 L
.48973 .48441 L
.49035 .48518 L
.49092 .48592 L
.49146 .48664 L
.49196 .48732 L
.49243 .48797 L
.49288 .48859 L
.49329 .48918 L
.49368 .48975 L
.49404 .49028 L
.49438 .4908 L
.49471 .49128 L
.49501 .49175 L
.49529 .49218 L
.49556 .4926 L
.49581 .493 L
.49605 .49337 L
.49627 .49373 L
.49648 .49407 L
.49668 .49439 L
.49686 .49469 L
Mistroke
.49704 .49498 L
.49721 .49525 L
.49736 .49551 L
.49751 .49576 L
.49765 .49599 L
.49778 .49621 L
.4979 .49641 L
.49802 .49661 L
.49813 .49679 L
.49823 .49697 L
.49833 .49714 L
.49842 .49729 L
.49851 .49744 L
.49859 .49758 L
.49867 .49771 L
.49875 .49784 L
.49881 .49796 L
.49888 .49807 L
.49894 .49818 L
.499 .49828 L
.49906 .49837 L
.49911 .49846 L
.49916 .49854 L
.4992 .49862 L
.49925 .4987 L
.49929 .49877 L
.49933 .49884 L
.49937 .4989 L
.4994 .49896 L
.49943 .49902 L
.49946 .49907 L
.49949 .49913 L
.49952 .49917 L
.49955 .49922 L
.49957 .49926 L
.4996 .4993 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49944 L
.4997 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49956 L
.49976 .49958 L
.49977 .4996 L
.49978 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49968 L
Mistroke
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.40976 .4835 m
.4179 .47893 L
s
% Start of user PostScript
-2.7070784 -0.49497067 -2.4629628 -0.63205528 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42517 .47535 m
.43167 .47259 L
s
% Start of user PostScript
-2.2449727 -0.73963932 -2.0499765 -0.82227862 MAarrowhead1
% End of user PostScript
1 .473 0 r
.46208 .46767 m
.46492 .46814 L
s
% Start of user PostScript
-1.1376684 -0.96989842 -1.052317 -0.95565276 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47896 .47416 m
.48036 .47517 L
s
% Start of user PostScript
-0.63108095 -0.77509777 -0.5891 -0.74483538 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48761 .4819 m
.48837 .48277 L
s
% Start of user PostScript
-0.3718038 -0.54294111 -0.34902311 -0.51697361 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49243 .48797 m
.49288 .48859 L
s
% Start of user PostScript
-0.22696013 -0.36099782 -0.21372324 -0.34235758 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49529 .49218 m
.49556 .4926 L
s
% Start of user PostScript
-0.14125407 -0.23445587 -0.13323708 -0.22193226 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49704 .49498 m
.49721 .49525 L
s
% Start of user PostScript
-0.08880944 -0.15058009 -0.083840779 -0.142407 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49813 .49679 m
.49823 .49697 L
s
% Start of user PostScript
-0.056127239 -0.096184884 -0.053010118 -0.090923429 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49881 .49796 m
.49888 .49807 L
s
% Start of user PostScript
-0.035565608 -0.061274021 -0.033597776 -0.057909349 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49925 .4987 m
.49929 .49877 L
s
% Start of user PostScript
-0.022566354 -0.038982026 -0.021320113 -0.036837364 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49952 .49917 m
.49955 .49922 L
s
% Start of user PostScript
-0.014327843 -0.024783489 -0.013537325 -0.023418686 MAarrowhead1
% End of user PostScript
0 .375 1 r
.4997 .49947 m
.49971 .4995 L
s
% Start of user PostScript
-0.0091000676 -0.015751273 -0.0085982222 -0.014883454 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49981 .49967 m
.49982 .49968 L
s
% Start of user PostScript
-0.0057807036 -0.010009133 -0.0054619881 -0.0094575478 MAarrowhead1
% End of user PostScript
0 .386 1 r
.54417 .57579 m
.54172 .57165 L
.53941 .56772 L
.53722 .56401 L
.53516 .5605 L
.53322 .55718 L
.53138 .55404 L
.52964 .55107 L
.528 .54827 L
.52645 .54562 L
.52499 .54311 L
.52361 .54074 L
.5223 .5385 L
.52107 .53638 L
.51991 .53438 L
.51881 .53249 L
.51777 .5307 L
.51679 .52901 L
.51586 .52742 L
.51499 .52591 L
.51416 .52448 L
.51338 .52313 L
.51264 .52186 L
.51194 .52066 L
.51128 .51952 L
.51066 .51844 L
.51007 .51743 L
.50952 .51647 L
.50899 .51556 L
.5085 .5147 L
.50803 .51389 L
.50758 .51313 L
.50717 .5124 L
.50677 .51172 L
.5064 .51108 L
.50604 .51047 L
.50571 .50989 L
.5054 .50934 L
.5051 .50883 L
.50482 .50834 L
.50455 .50788 L
.5043 .50745 L
.50406 .50704 L
.50384 .50665 L
.50363 .50628 L
.50343 .50594 L
.50324 .50561 L
.50306 .5053 L
.50289 .50501 L
.50273 .50473 L
Mistroke
.50258 .50447 L
.50244 .50423 L
.50231 .50399 L
.50218 .50377 L
.50206 .50356 L
.50194 .50337 L
.50184 .50318 L
.50174 .50301 L
.50164 .50284 L
.50155 .50268 L
.50146 .50254 L
.50138 .5024 L
.50131 .50226 L
.50124 .50214 L
.50117 .50202 L
.5011 .50191 L
.50104 .50181 L
.50098 .50171 L
.50093 .50161 L
.50088 .50152 L
.50083 .50144 L
.50078 .50136 L
.50074 .50128 L
.5007 .50121 L
.50066 .50115 L
.50063 .50108 L
.50059 .50102 L
.50056 .50097 L
.50053 .50091 L
.5005 .50086 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50035 .50061 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
Mistroke
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
Mistroke
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.54417 .57579 m
.54172 .57165 L
s
% Start of user PostScript
1.3252304 2.2738451 1.251695 2.1493513 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53941 .56772 m
.53722 .56401 L
s
% Start of user PostScript
1.1822779 2.0316071 1.1167436 1.9202555 MAarrowhead1
% End of user PostScript
1 .473 0 r
.52499 .54311 m
.52361 .54074 L
s
% Start of user PostScript
0.74967103 1.2933336 0.70823199 1.2222446 MAarrowhead1
% End of user PostScript
1 .788 0 r
.51586 .52742 m
.51499 .52591 L
s
% Start of user PostScript
0.47582773 0.8225261 0.44956256 0.77725134 MAarrowhead1
% End of user PostScript
.897 1 0 r
.51007 .51743 m
.50952 .51647 L
s
% Start of user PostScript
0.30216436 0.52284551 0.28549693 0.49404591 MAarrowhead1
% End of user PostScript
.581 1 0 r
.5064 .51108 m
.50604 .51047 L
s
% Start of user PostScript
0.19193056 0.33226871 0.18134737 0.31396008 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50406 .50704 m
.50384 .50665 L
s
% Start of user PostScript
0.12192669 0.21113085 0.11520474 0.1994951 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50258 .50447 m
.50244 .50423 L
s
% Start of user PostScript
0.077460499 0.13414888 0.073190399 0.12675507 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50164 .50284 m
.50155 .50268 L
s
% Start of user PostScript
0.049212482 0.085233232 0.046499706 0.080535271 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50104 .50181 m
.50098 .50171 L
s
% Start of user PostScript
0.031266335 0.0541532 0.029542855 0.05116827 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50066 .50115 m
.50063 .50108 L
s
% Start of user PostScript
0.019864701 0.034406138 0.018769721 0.032509648 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50042 .50073 m
.5004 .50069 L
s
% Start of user PostScript
0.012620855 0.021859793 0.011925173 0.020654859 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50027 .50046 m
.50025 .50044 L
s
% Start of user PostScript
0.00801856 0.013888499 0.0075765653 0.013122949 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50017 .50029 m
.50016 .50028 L
s
% Start of user PostScript
0.0050945332 0.0088239733 0.0048137155 0.008337585 MAarrowhead1
% End of user PostScript
.389 1 0 r
.6198 .52188 m
.609 .52795 L
.59935 .53271 L
.59072 .53637 L
.58299 .5391 L
.57605 .54105 L
.5698 .54234 L
.56418 .54308 L
.5591 .54338 L
.55451 .5433 L
.55035 .54291 L
.54657 .54228 L
.54313 .54146 L
.54 .54048 L
.53715 .53937 L
.53453 .53818 L
.53214 .53692 L
.52994 .53562 L
.52793 .5343 L
.52607 .53296 L
.52436 .53162 L
.52277 .53029 L
.52131 .52898 L
.51996 .52769 L
.5187 .52644 L
.51754 .52521 L
.51645 .52403 L
.51544 .52288 L
.51451 .52177 L
.51363 .5207 L
.51281 .51967 L
.51205 .51869 L
.51134 .51774 L
.51067 .51684 L
.51004 .51597 L
.50946 .51515 L
.50891 .51436 L
.50839 .51361 L
.50791 .5129 L
.50746 .51222 L
.50703 .51157 L
.50663 .51096 L
.50625 .51037 L
.5059 .50982 L
.50556 .50929 L
.50525 .5088 L
.50495 .50832 L
.50467 .50787 L
.50441 .50745 L
.50416 .50705 L
Mistroke
.50393 .50666 L
.50371 .5063 L
.5035 .50596 L
.50331 .50563 L
.50312 .50533 L
.50295 .50504 L
.50278 .50476 L
.50263 .5045 L
.50248 .50426 L
.50235 .50402 L
.50222 .5038 L
.50209 .50359 L
.50198 .5034 L
.50187 .50321 L
.50176 .50304 L
.50167 .50287 L
.50157 .50271 L
.50149 .50256 L
.5014 .50242 L
.50133 .50229 L
.50125 .50216 L
.50118 .50204 L
.50112 .50193 L
.50106 .50183 L
.501 .50172 L
.50094 .50163 L
.50089 .50154 L
.50084 .50146 L
.5008 .50138 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50063 .5011 L
.5006 .50104 L
.50057 .50098 L
.50053 .50093 L
.50051 .50087 L
.50048 .50083 L
.50045 .50078 L
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50056 L
.5003 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
Mistroke
.50023 .5004 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
Mistroke
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.6198 .52188 m
.609 .52795 L
s
% Start of user PostScript
3.5940599 0.65647078 3.2699437 0.8385355 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59935 .53271 m
.59072 .53637 L
s
% Start of user PostScript
2.9805161 0.98142663 2.7216189 1.0911936 MAarrowhead1
% End of user PostScript
1 .473 0 r
.55035 .54291 m
.54657 .54228 L
s
% Start of user PostScript
1.5103641 1.2874149 1.397047 1.268523 MAarrowhead1
% End of user PostScript
1 .788 0 r
.52793 .5343 m
.52607 .53296 L
s
% Start of user PostScript
0.83780057 1.0289127 0.78206635 0.98874489 MAarrowhead1
% End of user PostScript
.897 1 0 r
.51645 .52403 m
.51544 .52288 L
s
% Start of user PostScript
0.49358618 0.72075137 0.46334318 0.68628092 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51004 .51597 m
.50946 .51515 L
s
% Start of user PostScript
0.30129723 0.47922777 0.2837246 0.45448307 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50625 .51037 m
.5059 .50982 L
s
% Start of user PostScript
0.18751871 0.31124379 0.17687587 0.29461861 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50393 .50666 m
.50371 .5063 L
s
% Start of user PostScript
0.11789674 0.19989787 0.1113007 0.18904798 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50248 .50426 m
.50235 .50402 L
s
% Start of user PostScript
0.07451022 0.12768738 0.070372161 0.1207027 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50157 .50271 m
.50149 .50256 L
s
% Start of user PostScript
0.047214147 0.08134255 0.044601804 0.076875881 MAarrowhead1
% End of user PostScript
0 1 .995 r
.501 .50172 m
.50094 .50163 L
s
% Start of user PostScript
0.029957335 0.051749473 0.028302922 0.048902389 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50063 .5011 m
.5006 .50104 L
s
% Start of user PostScript
0.019020526 0.032900616 0.017971097 0.031088812 MAarrowhead1
% End of user PostScript
0 .375 1 r
.5004 .5007 m
.50038 .50066 L
s
% Start of user PostScript
0.012080539 0.020910156 0.011414328 0.019758108 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50026 .50044 m
.50024 .50042 L
s
% Start of user PostScript
0.0076740102 0.013287342 0.0072509084 0.0125551 MAarrowhead1
% End of user PostScript
1 .93 0 r
.35067 .4293 m
.36315 .42583 L
.37438 .42354 L
.3845 .42222 L
.39363 .42171 L
.40189 .42188 L
.40938 .42258 L
.41617 .42373 L
.42235 .42524 L
.42798 .42702 L
.43312 .42901 L
.43783 .43117 L
.44213 .43344 L
.44608 .43579 L
.44972 .43818 L
.45306 .4406 L
.45614 .44302 L
.45899 .44541 L
.46162 .44778 L
.46406 .4501 L
.46632 .45236 L
.46842 .45457 L
.47037 .45671 L
.47218 .45878 L
.47388 .46078 L
.47545 .46271 L
.47692 .46456 L
.4783 .46633 L
.47958 .46804 L
.48078 .46966 L
.48191 .47122 L
.48297 .47271 L
.48395 .47413 L
.48488 .47548 L
.48575 .47676 L
.48657 .47799 L
.48734 .47915 L
.48806 .48026 L
.48874 .48131 L
.48938 .48231 L
.48998 .48326 L
.49055 .48416 L
.49108 .48501 L
.49158 .48582 L
.49206 .48658 L
.4925 .48731 L
.49292 .488 L
.49332 .48865 L
.49369 .48927 L
.49404 .48985 L
Mistroke
.49437 .4904 L
.49469 .49093 L
.49498 .49142 L
.49526 .49189 L
.49553 .49233 L
.49577 .49275 L
.49601 .49315 L
.49623 .49352 L
.49644 .49388 L
.49664 .49421 L
.49682 .49453 L
.497 .49483 L
.49717 .49512 L
.49732 .49538 L
.49747 .49564 L
.49761 .49588 L
.49774 .4961 L
.49787 .49632 L
.49798 .49652 L
.4981 .49671 L
.4982 .49689 L
.4983 .49706 L
.49839 .49723 L
.49848 .49738 L
.49857 .49752 L
.49865 .49766 L
.49872 .49779 L
.49879 .49791 L
.49886 .49802 L
.49892 .49813 L
.49898 .49824 L
.49904 .49833 L
.49909 .49843 L
.49914 .49851 L
.49919 .49859 L
.49923 .49867 L
.49927 .49874 L
.49931 .49881 L
.49935 .49888 L
.49939 .49894 L
.49942 .499 L
.49945 .49905 L
.49948 .49911 L
.49951 .49916 L
.49954 .4992 L
.49956 .49925 L
.49959 .49929 L
.49961 .49933 L
.49963 .49936 L
.49965 .4994 L
Mistroke
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .4997 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .4998 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
Mistroke
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.35067 .4293 m
.36315 .42583 L
s
% Start of user PostScript
-4.4800432 -2.1210283 -4.1055063 -2.2251086 MAarrowhead1
% End of user PostScript
1 .158 0 r
.37438 .42354 m
.3845 .42222 L
s
% Start of user PostScript
-3.7686486 -2.2939476 -3.4651192 -2.3334269 MAarrowhead1
% End of user PostScript
1 .473 0 r
.43312 .42901 m
.43783 .43117 L
s
% Start of user PostScript
-2.00628 -2.1296627 -1.8652494 -2.0649997 MAarrowhead1
% End of user PostScript
1 .788 0 r
.46162 .44778 m
.46406 .4501 L
s
% Start of user PostScript
-1.1513461 -1.5666814 -1.0782087 -1.4970792 MAarrowhead1
% End of user PostScript
.897 1 0 r
.47692 .46456 m
.4783 .46633 L
s
% Start of user PostScript
-0.69230862 -1.063262 -0.65107361 -1.009978 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48575 .47676 m
.48657 .47799 L
s
% Start of user PostScript
-0.42739956 -0.6971074 -0.40286388 -0.6603739 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49108 .48501 m
.49158 .48582 L
s
% Start of user PostScript
-0.26758784 -0.44975726 -0.25252763 -0.42550371 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49437 .4904 m
.49469 .49093 L
s
% Start of user PostScript
-0.16875251 -0.28792852 -0.159352 -0.27222838 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49644 .49388 m
.49664 .49421 L
s
% Start of user PostScript
-0.10681613 -0.18362565 -0.10089694 -0.17355826 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49774 .4961 m
.49787 .49632 L
s
% Start of user PostScript
-0.067737911 -0.11688529 -0.063994148 -0.11045967 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49857 .49752 m
.49865 .49766 L
s
% Start of user PostScript
-0.04299647 -0.07433218 -0.040623283 -0.070240376 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49909 .49843 m
.49914 .49851 L
s
% Start of user PostScript
-0.027304694 -0.047248663 -0.025798617 -0.044645997 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49942 .499 m
.49945 .49905 L
s
% Start of user PostScript
-0.017343778 -0.030026179 -0.016387447 -0.02837165 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49963 .49936 m
.49965 .4994 L
s
% Start of user PostScript
-0.011017958 -0.019079174 -0.010410532 -0.018027681 MAarrowhead1
% End of user PostScript
.517 0 1 r
.68802 .38843 m
.66776 .41171 L
.64994 .43143 L
.63425 .44808 L
.62041 .46209 L
.6082 .47384 L
.5974 .48365 L
.58784 .4918 L
.57937 .49854 L
.57185 .50406 L
.56517 .50856 L
.55922 .51218 L
.55391 .51505 L
.54916 .51729 L
.54492 .51899 L
.54111 .52025 L
.53769 .52113 L
.53462 .5217 L
.53184 .522 L
.52934 .52209 L
.52707 .522 L
.52501 .52176 L
.52315 .52141 L
.52145 .52096 L
.5199 .52044 L
.51849 .51986 L
.51719 .51924 L
.51601 .51859 L
.51492 .51793 L
.51392 .51725 L
.51299 .51657 L
.51214 .51589 L
.51136 .51521 L
.51063 .51455 L
.50996 .5139 L
.50933 .51326 L
.50875 .51265 L
.50821 .51205 L
.50771 .51147 L
.50724 .51091 L
.50681 .51037 L
.5064 .50986 L
.50602 .50936 L
.50566 .50889 L
.50533 .50843 L
.50502 .508 L
.50473 .50759 L
.50445 .50719 L
.50419 .50682 L
.50395 .50646 L
Mistroke
.50373 .50612 L
.50351 .50579 L
.50331 .50548 L
.50312 .50519 L
.50295 .50491 L
.50278 .50465 L
.50262 .5044 L
.50248 .50416 L
.50234 .50394 L
.50221 .50373 L
.50208 .50353 L
.50197 .50333 L
.50186 .50315 L
.50175 .50298 L
.50165 .50282 L
.50156 .50267 L
.50147 .50252 L
.50139 .50238 L
.50132 .50225 L
.50124 .50213 L
.50117 .50201 L
.50111 .5019 L
.50105 .5018 L
.50099 .5017 L
.50093 .50161 L
.50088 .50152 L
.50083 .50144 L
.50079 .50136 L
.50074 .50128 L
.5007 .50121 L
.50066 .50114 L
.50063 .50108 L
.50059 .50102 L
.50056 .50097 L
.50053 .50091 L
.5005 .50086 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50036 .50061 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
Mistroke
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
Mistroke
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.68802 .38843 m
.66776 .41171 L
s
% Start of user PostScript
5.6404865 -3.3471349 5.0327698 -2.6485538 MAarrowhead1
% End of user PostScript
1 .158 0 r
.64994 .43143 m
.63425 .44808 L
s
% Start of user PostScript
4.4981768 -2.057113 4.0273867 -1.5577438 MAarrowhead1
% End of user PostScript
1 .473 0 r
.56517 .50856 m
.55922 .51218 L
s
% Start of user PostScript
1.9550647 0.25676004 1.7764844 0.36526157 MAarrowhead1
% End of user PostScript
1 .788 0 r
.53184 .522 m
.52934 .52209 L
s
% Start of user PostScript
0.95524263 0.66004677 0.88008527 0.66264071 MAarrowhead1
% End of user PostScript
.897 1 0 r
.51719 .51924 m
.51601 .51859 L
s
% Start of user PostScript
0.51573891 0.577264 0.48015976 0.55783026 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50996 .5139 m
.50933 .51326 L
s
% Start of user PostScript
0.29870027 0.41694 0.27996313 0.39789363 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50602 .50936 m
.50566 .50889 L
s
% Start of user PostScript
0.18057094 0.28084575 0.16989552 0.2666159 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50373 .50612 m
.50351 .50579 L
s
% Start of user PostScript
0.11179901 0.18350062 0.10540703 0.17378327 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50234 .50394 m
.50221 .50373 L
s
% Start of user PostScript
0.070101087 0.1181961 0.066164104 0.11180728 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50147 .50252 m
.50139 .50238 L
s
% Start of user PostScript
0.044242831 0.075606786 0.041780936 0.071479376 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50093 .50161 m
.50088 .50152 L
s
% Start of user PostScript
0.028015507 0.048198865 0.026463892 0.045554834 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50059 .50102 m
.50056 .50097 L
s
% Start of user PostScript
0.017769632 0.030674495 0.016787806 0.02898773 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50038 .50065 m
.50036 .50061 L
s
% Start of user PostScript
0.011280336 0.019505254 0.010657805 0.018431387 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50024 .50041 m
.50023 .50039 L
s
% Start of user PostScript
0.0071638731 0.01239775 0.0067687547 0.011714779 MAarrowhead1
% End of user PostScript
0 .643 1 r
.48872 .2926 m
.48509 .3114 L
.48223 .32817 L
.48002 .34317 L
.47836 .35661 L
.47715 .36866 L
.47633 .3795 L
.47584 .38926 L
.47561 .39806 L
.47561 .40602 L
.47578 .41323 L
.4761 .41977 L
.47654 .42571 L
.47707 .43113 L
.47768 .43607 L
.47833 .44058 L
.47903 .44471 L
.47976 .4485 L
.4805 .45199 L
.48126 .45519 L
.48201 .45815 L
.48276 .46087 L
.4835 .46339 L
.48423 .46572 L
.48494 .46789 L
.48563 .46989 L
.48631 .47176 L
.48696 .47349 L
.48759 .47511 L
.4882 .47661 L
.48878 .47802 L
.48934 .47933 L
.48988 .48055 L
.49039 .4817 L
.49089 .48277 L
.49136 .48378 L
.4918 .48472 L
.49223 .48561 L
.49264 .48644 L
.49303 .48722 L
.49339 .48795 L
.49374 .48864 L
.49408 .48928 L
.49439 .48989 L
.49469 .49047 L
.49498 .491 L
.49525 .49151 L
.4955 .49199 L
.49575 .49244 L
.49598 .49286 L
Mistroke
.4962 .49326 L
.4964 .49364 L
.4966 .494 L
.49678 .49433 L
.49696 .49465 L
.49712 .49495 L
.49728 .49523 L
.49743 .49549 L
.49757 .49574 L
.4977 .49598 L
.49783 .4962 L
.49795 .49641 L
.49806 .49661 L
.49817 .4968 L
.49827 .49698 L
.49836 .49715 L
.49845 .4973 L
.49854 .49745 L
.49862 .49759 L
.49869 .49773 L
.49876 .49785 L
.49883 .49797 L
.4989 .49808 L
.49896 .49819 L
.49901 .49829 L
.49907 .49838 L
.49912 .49847 L
.49917 .49856 L
.49921 .49864 L
.49926 .49871 L
.4993 .49878 L
.49934 .49885 L
.49937 .49891 L
.49941 .49897 L
.49944 .49903 L
.49947 .49908 L
.4995 .49913 L
.49953 .49918 L
.49955 .49923 L
.49958 .49927 L
.4996 .49931 L
.49962 .49935 L
.49964 .49938 L
.49966 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
Mistroke
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.48872 .2926 m
.48509 .3114 L
s
% Start of user PostScript
-0.33831323 -6.221895 -0.44719457 -5.6580482 MAarrowhead1
% End of user PostScript
1 .158 0 r
.48223 .32817 m
.48002 .34317 L
s
% Start of user PostScript
-0.53304814 -5.1547715 -0.59941634 -4.704789 MAarrowhead1
% End of user PostScript
1 .473 0 r
.47578 .41323 m
.4761 .41977 L
s
% Start of user PostScript
-0.72658722 -2.6031546 -0.71696395 -2.4069639 MAarrowhead1
% End of user PostScript
1 .788 0 r
.4805 .45199 m
.48126 .45519 L
s
% Start of user PostScript
-0.58490335 -1.440385 -0.56233171 -1.3442419 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48631 .47176 m
.48696 .47349 L
s
% Start of user PostScript
-0.41078692 -0.84729015 -0.39121638 -0.79526455 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49089 .48277 m
.49136 .48378 L
s
% Start of user PostScript
-0.27343877 -0.51675941 -0.25934286 -0.4865838 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49408 .48928 m
.49439 .48989 L
s
% Start of user PostScript
-0.17768318 -0.32146816 -0.16819932 -0.30321101 MAarrowhead1
% End of user PostScript
0 1 .049 r
.4962 .49326 m
.4964 .49364 L
s
% Start of user PostScript
-0.11414683 -0.20206541 -0.10795351 -0.19075652 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49757 .49574 m
.4977 .49598 L
s
% Start of user PostScript
-0.072921872 -0.12768903 -0.068933655 -0.12059638 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49845 .4973 m
.49854 .49745 L
s
% Start of user PostScript
-0.046457356 -0.080906507 -0.043906523 -0.076429589 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49901 .49829 m
.49907 .49838 L
s
% Start of user PostScript
-0.029556706 -0.051333539 -0.027930666 -0.048498487 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49937 .49891 m
.49941 .49897 L
s
% Start of user PostScript
-0.018791472 -0.032592217 -0.017756667 -0.03079395 MAarrowhead1
% End of user PostScript
0 .375 1 r
.4996 .49931 m
.49962 .49935 L
s
% Start of user PostScript
-0.011943109 -0.020700191 -0.011285109 -0.019558616 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49975 .49956 m
.49976 .49959 L
s
% Start of user PostScript
-0.0075892683 -0.013149485 -0.0071710394 -0.012424492 MAarrowhead1
% End of user PostScript
1 0 .736 r
.23165 .54587 m
.258 .52333 L
.28135 .5047 L
.30208 .48941 L
.32051 .47698 L
.33692 .46696 L
.35155 .45901 L
.36462 .4528 L
.37632 .44806 L
.38681 .44456 L
.39623 .44211 L
.40471 .44052 L
.41235 .43966 L
.41925 .4394 L
.4255 .43964 L
.43116 .44027 L
.4363 .44123 L
.44098 .44245 L
.44524 .44387 L
.44914 .44545 L
.4527 .44714 L
.45596 .44891 L
.45896 .45074 L
.46172 .4526 L
.46426 .45447 L
.4666 .45634 L
.46876 .45819 L
.47076 .46001 L
.47261 .4618 L
.47433 .46354 L
.47593 .46524 L
.47741 .46688 L
.47879 .46847 L
.48008 .47001 L
.48128 .47148 L
.4824 .4729 L
.48345 .47426 L
.48443 .47557 L
.48534 .47681 L
.4862 .47801 L
.487 .47914 L
.48776 .48023 L
.48846 .48126 L
.48913 .48225 L
.48975 .48318 L
.49034 .48407 L
.49089 .48492 L
.49141 .48572 L
.49189 .48649 L
.49235 .48721 L
Mistroke
.49278 .4879 L
.49319 .48855 L
.49357 .48917 L
.49394 .48975 L
.49428 .49031 L
.4946 .49083 L
.4949 .49133 L
.49518 .4918 L
.49545 .49225 L
.49571 .49267 L
.49594 .49307 L
.49617 .49345 L
.49638 .49381 L
.49658 .49415 L
.49677 .49447 L
.49695 .49477 L
.49712 .49505 L
.49728 .49533 L
.49743 .49558 L
.49757 .49582 L
.49771 .49605 L
.49784 .49627 L
.49796 .49648 L
.49807 .49667 L
.49818 .49685 L
.49828 .49702 L
.49837 .49719 L
.49846 .49734 L
.49855 .49749 L
.49863 .49763 L
.4987 .49776 L
.49877 .49788 L
.49884 .498 L
.49891 .49811 L
.49897 .49821 L
.49902 .49831 L
.49908 .4984 L
.49913 .49849 L
.49918 .49857 L
.49922 .49865 L
.49926 .49873 L
.49931 .4988 L
.49934 .49886 L
.49938 .49893 L
.49941 .49899 L
.49945 .49904 L
.49948 .49909 L
.49951 .49914 L
.49953 .49919 L
.49956 .49924 L
Mistroke
.49958 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .49939 L
.49967 .49942 L
.49969 .49946 L
.4997 .49949 L
.49972 .49951 L
.49974 .49954 L
.49975 .49957 L
.49976 .49959 L
.49978 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
Mistroke
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.23165 .54587 m
.258 .52333 L
s
% Start of user PostScript
-8.0503622 1.3760695 -7.2599613 0.69979574 MAarrowhead1
% End of user PostScript
1 .158 0 r
.28135 .5047 m
.30208 .48941 L
s
% Start of user PostScript
-6.5594091 0.14095976 -5.9375743 -0.31761377 MAarrowhead1
% End of user PostScript
1 .473 0 r
.39623 .44211 m
.40471 .44052 L
s
% Start of user PostScript
-3.1130256 -1.7368046 -2.8587236 -1.784324 MAarrowhead1
% End of user PostScript
1 .788 0 r
.44524 .44387 m
.44914 .44545 L
s
% Start of user PostScript
-1.6427613 -1.6838403 -1.5259275 -1.6365476 MAarrowhead1
% End of user PostScript
.897 1 0 r
.46876 .45819 m
.47076 .46001 L
s
% Start of user PostScript
-0.93723754 -1.254245 -0.87722382 -1.1995754 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48128 .47148 m
.4824 .4729 L
s
% Start of user PostScript
-0.5616309 -0.85548296 -0.52801902 -0.81292456 MAarrowhead1
% End of user PostScript
.266 1 0 r
.48846 .48126 m
.48913 .48225 L
s
% Start of user PostScript
-0.34607595 -0.56214915 -0.3261564 -0.53262355 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49278 .4879 m
.49319 .48855 L
s
% Start of user PostScript
-0.21646016 -0.36307587 -0.20426058 -0.34352686 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49545 .49225 m
.49571 .49267 L
s
% Start of user PostScript
-0.13644071 -0.23255847 -0.12883475 -0.21988705 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49712 .49505 m
.49728 .49533 L
s
% Start of user PostScript
-0.086341647 -0.14835209 -0.081555319 -0.1402216 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49818 .49685 m
.49828 .49702 L
s
% Start of user PostScript
-0.05474694 -0.09444441 -0.051720616 -0.089253407 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49884 .498 m
.49891 .49811 L
s
% Start of user PostScript
-0.034748257 -0.06006497 -0.032830155 -0.056758844 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49926 .49873 m
.49931 .4988 L
s
% Start of user PostScript
-0.022065999 -0.038181052 -0.020848824 -0.036077967 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49953 .49919 m
.49956 .49924 L
s
% Start of user PostScript
-0.014015966 -0.024264169 -0.013243111 -0.022927174 MAarrowhead1
% End of user PostScript
0 1 .946 r
.18055 .41154 m
.20867 .3982 L
.23385 .38802 L
.25642 .38052 L
.27669 .37525 L
.29492 .37186 L
.31137 .37002 L
.32622 .36948 L
.33965 .36999 L
.35183 .37137 L
.3629 .37344 L
.37296 .37607 L
.38214 .37913 L
.39052 .38253 L
.39819 .38618 L
.40522 .39 L
.41167 .39394 L
.4176 .39795 L
.42306 .40198 L
.4281 .406 L
.43275 .40999 L
.43706 .41391 L
.44105 .41776 L
.44475 .42151 L
.44818 .42516 L
.45137 .4287 L
.45435 .43213 L
.45712 .43543 L
.4597 .43861 L
.46211 .44166 L
.46437 .44459 L
.46647 .4474 L
.46844 .45008 L
.47029 .45265 L
.47202 .4551 L
.47364 .45743 L
.47517 .45966 L
.4766 .46178 L
.47794 .4638 L
.4792 .46571 L
.48039 .46753 L
.4815 .46926 L
.48255 .47091 L
.48354 .47247 L
.48447 .47395 L
.48534 .47535 L
.48617 .47668 L
.48694 .47794 L
.48768 .47913 L
.48837 .48027 L
Mistroke
.48902 .48134 L
.48963 .48235 L
.49021 .48331 L
.49076 .48422 L
.49127 .48508 L
.49176 .4859 L
.49221 .48667 L
.49265 .4874 L
.49306 .48809 L
.49344 .48874 L
.4938 .48935 L
.49415 .48994 L
.49447 .49049 L
.49478 .49101 L
.49507 .4915 L
.49534 .49197 L
.4956 .49241 L
.49584 .49283 L
.49607 .49322 L
.49629 .4936 L
.49649 .49395 L
.49669 .49428 L
.49687 .49459 L
.49704 .49489 L
.49721 .49517 L
.49736 .49544 L
.49751 .49569 L
.49764 .49593 L
.49777 .49615 L
.4979 .49636 L
.49801 .49656 L
.49812 .49675 L
.49823 .49693 L
.49832 .4971 L
.49842 .49726 L
.4985 .49741 L
.49859 .49755 L
.49866 .49769 L
.49874 .49782 L
.49881 .49794 L
.49887 .49805 L
.49894 .49816 L
.49899 .49826 L
.49905 .49835 L
.4991 .49845 L
.49915 .49853 L
.4992 .49861 L
.49924 .49869 L
.49928 .49876 L
.49932 .49883 L
Mistroke
.49936 .49889 L
.4994 .49895 L
.49943 .49901 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49921 L
.49957 .49926 L
.49959 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
Mistroke
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.18055 .41154 m
.20867 .3982 L
s
% Start of user PostScript
-9.5835765 -2.6537281 -8.7397581 -3.0540156 MAarrowhead1
% End of user PostScript
1 .158 0 r
.23385 .38802 m
.25642 .38052 L
s
% Start of user PostScript
-7.9845814 -3.3592685 -7.3075358 -3.5844674 MAarrowhead1
% End of user PostScript
1 .473 0 r
.3629 .37344 m
.37296 .37607 L
s
% Start of user PostScript
-4.1130845 -3.7968246 -3.8110769 -3.717943 MAarrowhead1
% End of user PostScript
1 .788 0 r
.42306 .40198 m
.4281 .406 L
s
% Start of user PostScript
-2.3081988 -2.9406002 -2.1570429 -2.8199497 MAarrowhead1
% End of user PostScript
.897 1 0 r
.45435 .43213 m
.45712 .43543 L
s
% Start of user PostScript
-1.3695701 -2.0361755 -1.2864749 -1.9371072 MAarrowhead1
% End of user PostScript
.581 1 0 r
.47202 .4551 m
.47364 .45743 L
s
% Start of user PostScript
-0.8393457 -1.3470201 -0.79066389 -1.2769552 MAarrowhead1
% End of user PostScript
.266 1 0 r
.48255 .47091 m
.48354 .47247 L
s
% Start of user PostScript
-0.52348469 -0.87277342 -0.49386179 -0.82599477 MAarrowhead1
% End of user PostScript
0 1 .049 r
.48902 .48134 m
.48963 .48235 L
s
% Start of user PostScript
-0.3294821 -0.55989805 -0.31107665 -0.5294583 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49306 .48809 m
.49344 .48874 L
s
% Start of user PostScript
-0.20834584 -0.35743942 -0.19678401 -0.33787117 MAarrowhead1
% End of user PostScript
0 1 .679 r
.4956 .49241 m
.49584 .49283 L
s
% Start of user PostScript
-0.13205704 -0.22764075 -0.12475324 -0.21513556 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49721 .49517 m
.49736 .49544 L
s
% Start of user PostScript
-0.08380174 -0.14480289 -0.07917465 -0.13683473 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49823 .49693 m
.49832 .4971 L
s
% Start of user PostScript
-0.053211155 -0.09205448 -0.050275598 -0.086984626 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49887 .49805 m
.49894 .49816 L
s
% Start of user PostScript
-0.03379727 -0.058503652 -0.03193353 -0.055280223 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49928 .49876 m
.49932 .49883 L
s
% Start of user PostScript
-0.021469665 -0.037175449 -0.020285978 -0.035126725 MAarrowhead1
% End of user PostScript
1 0 .313 r
.21246 .58934 m
.2416 .56139 L
.26736 .53806 L
.29016 .51868 L
.31037 .50267 L
.32832 .48955 L
.34427 .47888 L
.35848 .4703 L
.37116 .46349 L
.38248 .45819 L
.39262 .45416 L
.40171 .45119 L
.40988 .44912 L
.41723 .4478 L
.42385 .44711 L
.42984 .44693 L
.43525 .44717 L
.44016 .44776 L
.44463 .44862 L
.44869 .44971 L
.45239 .45097 L
.45577 .45236 L
.45886 .45385 L
.4617 .45541 L
.4643 .45702 L
.4667 .45865 L
.4689 .46029 L
.47093 .46192 L
.47281 .46354 L
.47455 .46513 L
.47616 .46669 L
.47766 .46822 L
.47905 .4697 L
.48034 .47113 L
.48154 .47252 L
.48266 .47386 L
.4837 .47515 L
.48468 .47638 L
.48559 .47757 L
.48644 .47871 L
.48724 .4798 L
.48798 .48084 L
.48868 .48183 L
.48934 .48277 L
.48995 .48367 L
.49053 .48453 L
.49108 .48535 L
.49159 .48612 L
.49207 .48686 L
.49252 .48756 L
Mistroke
.49294 .48823 L
.49334 .48886 L
.49372 .48946 L
.49407 .49002 L
.4944 .49056 L
.49472 .49107 L
.49501 .49156 L
.49529 .49201 L
.49556 .49245 L
.4958 .49286 L
.49604 .49325 L
.49626 .49362 L
.49647 .49396 L
.49666 .49429 L
.49685 .4946 L
.49702 .4949 L
.49719 .49518 L
.49735 .49544 L
.49749 .49569 L
.49763 .49593 L
.49776 .49615 L
.49789 .49636 L
.498 .49656 L
.49811 .49675 L
.49822 .49693 L
.49832 .4971 L
.49841 .49726 L
.4985 .49741 L
.49858 .49755 L
.49866 .49769 L
.49873 .49781 L
.4988 .49793 L
.49887 .49805 L
.49893 .49815 L
.49899 .49826 L
.49905 .49835 L
.4991 .49844 L
.49915 .49853 L
.4992 .49861 L
.49924 .49869 L
.49928 .49876 L
.49932 .49883 L
.49936 .49889 L
.49939 .49895 L
.49943 .49901 L
.49946 .49906 L
.49949 .49912 L
.49952 .49916 L
.49954 .49921 L
.49957 .49925 L
Mistroke
.49959 .4993 L
.49962 .49933 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49984 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
Mistroke
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.21246 .58934 m
.2416 .56139 L
s
% Start of user PostScript
-8.6262626 2.6800764 -7.7520391 1.8417219 MAarrowhead1
% End of user PostScript
1 .158 0 r
.26736 .53806 m
.29016 .51868 L
s
% Start of user PostScript
-6.9792375 1.1417819 -6.2951603 0.56031702 MAarrowhead1
% End of user PostScript
1 .473 0 r
.39262 .45416 m
.40171 .45119 L
s
% Start of user PostScript
-3.2213495 -1.3753154 -2.9486512 -1.4642818 MAarrowhead1
% End of user PostScript
1 .788 0 r
.44463 .44862 m
.44869 .44971 L
s
% Start of user PostScript
-1.6612449 -1.5413607 -1.5394439 -1.5087605 MAarrowhead1
% End of user PostScript
.897 1 0 r
.4689 .46029 m
.47093 .46192 L
s
% Start of user PostScript
-0.93298441 -1.1914284 -0.87195041 -1.1423946 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48154 .47252 m
.48266 .47386 L
s
% Start of user PostScript
-0.55384539 -0.8243774 -0.52026394 -0.78422418 MAarrowhead1
% End of user PostScript
.266 1 0 r
.48868 .48183 m
.48934 .48277 L
s
% Start of user PostScript
-0.33951412 -0.54518432 -0.31982957 -0.5168133 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49294 .48823 m
.49334 .48886 L
s
% Start of user PostScript
-0.21177783 -0.35318648 -0.19979608 -0.33425232 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49556 .49245 m
.4958 .49286 L
s
% Start of user PostScript
-0.1333027 -0.22655784 -0.12585692 -0.21423935 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49719 .49518 m
.49735 .49544 L
s
% Start of user PostScript
-0.084296098 -0.14462941 -0.079618457 -0.13671116 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49822 .49693 m
.49832 .4971 L
s
% Start of user PostScript
-0.053430842 -0.092107764 -0.050475771 -0.087047797 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49887 .49805 m
.49893 .49815 L
s
% Start of user PostScript
-0.033906849 -0.058589463 -0.032034715 -0.05536538 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49928 .49876 m
.49932 .49883 L
s
% Start of user PostScript
-0.021529753 -0.03724648 -0.020342006 -0.035195135 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49954 .49921 m
.49957 .49925 L
s
% Start of user PostScript
-0.013674737 -0.02367131 -0.01292065 -0.022367066 MAarrowhead1
% End of user PostScript
.924 0 1 r
.80628 .69169 m
.78173 .6944 L
.75956 .69519 L
.73949 .6944 L
.7213 .69232 L
.70478 .68921 L
.68975 .68526 L
.67605 .68067 L
.66353 .67558 L
.65208 .67012 L
.64159 .6644 L
.63195 .65851 L
.6231 .65252 L
.61494 .64649 L
.60741 .64047 L
.60046 .63452 L
.59403 .62865 L
.58807 .6229 L
.58255 .61729 L
.57741 .61183 L
.57264 .60654 L
.5682 .60142 L
.56407 .59649 L
.56021 .59173 L
.5566 .58717 L
.55324 .58279 L
.55009 .5786 L
.54714 .57458 L
.54439 .57075 L
.5418 .56709 L
.53938 .5636 L
.5371 .56027 L
.53497 .55711 L
.53296 .5541 L
.53108 .55123 L
.5293 .54851 L
.52764 .54592 L
.52607 .54347 L
.5246 .54114 L
.52321 .53893 L
.5219 .53683 L
.52067 .53485 L
.51951 .53296 L
.51841 .53118 L
.51738 .52949 L
.51641 .52789 L
.51549 .52637 L
.51463 .52493 L
.51381 .52358 L
.51304 .52229 L
Mistroke
.51232 .52107 L
.51163 .51992 L
.51099 .51883 L
.51038 .5178 L
.5098 .51683 L
.50926 .51591 L
.50874 .51503 L
.50826 .51421 L
.5078 .51343 L
.50737 .51269 L
.50696 .512 L
.50658 .51134 L
.50621 .51071 L
.50587 .51013 L
.50555 .50957 L
.50524 .50904 L
.50495 .50855 L
.50468 .50808 L
.50442 .50763 L
.50417 .50721 L
.50394 .50681 L
.50373 .50644 L
.50352 .50609 L
.50333 .50575 L
.50314 .50543 L
.50297 .50513 L
.5028 .50485 L
.50265 .50458 L
.5025 .50433 L
.50237 .50409 L
.50224 .50387 L
.50211 .50366 L
.502 .50345 L
.50189 .50326 L
.50178 .50308 L
.50168 .50291 L
.50159 .50275 L
.5015 .5026 L
.50142 .50246 L
.50134 .50232 L
.50127 .50219 L
.5012 .50207 L
.50113 .50196 L
.50107 .50185 L
.50101 .50175 L
.50095 .50165 L
.5009 .50156 L
.50085 .50148 L
.50081 .50139 L
.50076 .50132 L
Mistroke
.50072 .50125 L
.50068 .50118 L
.50064 .50111 L
.50061 .50105 L
.50057 .50099 L
.50054 .50094 L
.50051 .50089 L
.50048 .50084 L
.50046 .50079 L
.50043 .50075 L
.50041 .50071 L
.50039 .50067 L
.50036 .50063 L
.50034 .5006 L
.50033 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50029 L
.50016 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
Mistroke
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.80628 .69169 m
.78173 .6944 L
s
% Start of user PostScript
9.1883046 5.7505677 8.4518412 5.8319467 MAarrowhead1
% End of user PostScript
1 .158 0 r
.75956 .69519 m
.73949 .6944 L
s
% Start of user PostScript
7.7866782 5.8556564 7.1847859 5.8319761 MAarrowhead1
% End of user PostScript
1 .473 0 r
.64159 .6644 m
.63195 .65851 L
s
% Start of user PostScript
4.2476255 4.932074 3.9586173 4.7552555 MAarrowhead1
% End of user PostScript
1 .788 0 r
.58255 .61729 m
.57741 .61183 L
s
% Start of user PostScript
2.4763884 3.5186156 2.3224491 3.3548675 MAarrowhead1
% End of user PostScript
.897 1 0 r
.55009 .5786 m
.54714 .57458 L
s
% Start of user PostScript
1.5027114 2.35789 1.4143388 2.2375177 MAarrowhead1
% End of user PostScript
.581 1 0 r
.53108 .55123 m
.5293 .54851 L
s
% Start of user PostScript
0.93228824 1.5369529 0.87913843 1.455284 MAarrowhead1
% End of user PostScript
.266 1 0 r
.51951 .53296 m
.51841 .53118 L
s
% Start of user PostScript
0.58518921 0.9888489 0.55237326 0.93531144 MAarrowhead1
% End of user PostScript
0 1 .049 r
.51232 .52107 m
.51163 .51992 L
s
% Start of user PostScript
0.36952907 0.63218499 0.34898233 0.59764611 MAarrowhead1
% End of user PostScript
0 1 .364 r
.5078 .51343 m
.50737 .51269 L
s
% Start of user PostScript
0.23405742 0.40290223 0.22109937 0.3807916 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50495 .50855 m
.50468 .50808 L
s
% Start of user PostScript
0.14847789 0.25637772 0.14027564 0.24227695 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50314 .50543 m
.50297 .50513 L
s
% Start of user PostScript
0.094261682 0.16301386 0.089060148 0.15403821 MAarrowhead1
% End of user PostScript
0 .69 1 r
.502 .50345 m
.50189 .50326 L
s
% Start of user PostScript
0.059865409 0.1036098 0.056563736 0.097901831 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50127 .50219 m
.5012 .50207 L
s
% Start of user PostScript
0.038027739 0.065840512 0.035931024 0.062212295 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50081 .50139 m
.50076 .50132 L
s
% Start of user PostScript
0.024158334 0.04183537 0.022826512 0.039529666 MAarrowhead1
% End of user PostScript
1 0 .499 r
.72317 .70395 m
.70673 .69987 L
.69176 .69505 L
.67809 .68967 L
.66558 .68387 L
.65413 .67777 L
.64361 .67147 L
.63395 .66505 L
.62505 .65857 L
.61684 .65211 L
.60927 .64569 L
.60226 .63937 L
.59577 .63317 L
.58975 .62711 L
.58416 .62121 L
.57896 .61549 L
.57413 .60996 L
.56963 .60462 L
.56543 .59948 L
.56151 .59454 L
.55785 .5898 L
.55442 .58526 L
.55122 .58091 L
.54822 .57676 L
.54541 .57279 L
.54277 .56901 L
.5403 .5654 L
.53798 .56197 L
.5358 .5587 L
.53375 .5556 L
.53183 .55264 L
.53002 .54984 L
.52831 .54718 L
.52671 .54465 L
.5252 .54225 L
.52378 .53998 L
.52244 .53782 L
.52118 .53578 L
.51999 .53384 L
.51887 .53201 L
.51782 .53027 L
.51682 .52862 L
.51588 .52707 L
.515 .52559 L
.51416 .5242 L
.51337 .52288 L
.51263 .52163 L
.51193 .52044 L
.51127 .51933 L
.51064 .51827 L
Mistroke
.51005 .51727 L
.50949 .51632 L
.50897 .51543 L
.50847 .51458 L
.508 .51378 L
.50756 .51302 L
.50714 .51231 L
.50675 .51163 L
.50637 .51099 L
.50602 .51039 L
.50569 .50982 L
.50537 .50928 L
.50508 .50877 L
.5048 .50829 L
.50453 .50783 L
.50428 .5074 L
.50404 .50699 L
.50382 .50661 L
.50361 .50624 L
.50341 .5059 L
.50322 .50557 L
.50305 .50527 L
.50288 .50498 L
.50272 .5047 L
.50257 .50444 L
.50243 .5042 L
.50229 .50397 L
.50217 .50375 L
.50205 .50354 L
.50193 .50335 L
.50183 .50316 L
.50173 .50299 L
.50163 .50282 L
.50154 .50267 L
.50146 .50252 L
.50138 .50238 L
.5013 .50225 L
.50123 .50213 L
.50116 .50201 L
.5011 .5019 L
.50104 .50179 L
.50098 .5017 L
.50093 .5016 L
.50087 .50151 L
.50083 .50143 L
.50078 .50135 L
.50074 .50128 L
.5007 .50121 L
.50066 .50114 L
.50062 .50108 L
Mistroke
.50059 .50102 L
.50056 .50096 L
.50052 .50091 L
.5005 .50086 L
.50047 .50081 L
.50044 .50077 L
.50042 .50072 L
.5004 .50068 L
.50037 .50065 L
.50035 .50061 L
.50033 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
Mistroke
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.72317 .70395 m
.70673 .69987 L
s
% Start of user PostScript
6.6950304 6.1186084 6.2020461 5.9960225 MAarrowhead1
% End of user PostScript
1 .158 0 r
.69176 .69505 m
.67809 .68967 L
s
% Start of user PostScript
5.7527833 5.8515324 5.3426229 5.6901721 MAarrowhead1
% End of user PostScript
1 .473 0 r
.60927 .64569 m
.60226 .63937 L
s
% Start of user PostScript
3.2779758 4.3707433 3.0677174 4.1810425 MAarrowhead1
% End of user PostScript
1 .788 0 r
.56543 .59948 m
.56151 .59454 L
s
% Start of user PostScript
1.9628333 2.9844334 1.8452421 2.8362041 MAarrowhead1
% End of user PostScript
.897 1 0 r
.5403 .5654 m
.53798 .56197 L
s
% Start of user PostScript
1.2090013 1.9620816 1.1393734 1.8591014 MAarrowhead1
% End of user PostScript
.581 1 0 r
.5252 .54225 m
.52378 .53998 L
s
% Start of user PostScript
0.75603265 1.2675501 0.71341019 1.1993247 MAarrowhead1
% End of user PostScript
.266 1 0 r
.51588 .52707 m
.515 .52559 L
s
% Start of user PostScript
0.47649574 0.81198833 0.44992912 0.76775277 MAarrowhead1
% End of user PostScript
0 1 .049 r
.51005 .51727 m
.50949 .51632 L
s
% Start of user PostScript
0.30151667 0.51800736 0.28480085 0.48962009 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50637 .51099 m
.50602 .51039 L
s
% Start of user PostScript
0.19117836 0.32978491 0.18060991 0.31165948 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50404 .50699 m
.50382 .50661 L
s
% Start of user PostScript
0.12134052 0.20974031 0.11464239 0.19819591 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50257 .50444 m
.50243 .5042 L
s
% Start of user PostScript
0.07705368 0.13332499 0.072803305 0.12598127 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50163 .50282 m
.50154 .50267 L
s
% Start of user PostScript
0.048943079 0.084728716 0.046244295 0.080060051 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50104 .50179 m
.50098 .5017 L
s
% Start of user PostScript
0.031091697 0.053838677 0.029377572 0.050871556 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50066 .50114 m
.50062 .50108 L
s
% Start of user PostScript
0.019752643 0.03420822 0.018663753 0.032322789 MAarrowhead1
% End of user PostScript
.823 1 0 r
.22581 .77365 m
.25786 .72923 L
.28589 .69117 L
.31041 .65861 L
.33188 .63078 L
.35069 .60703 L
.3672 .5868 L
.38168 .5696 L
.39442 .555 L
.40562 .54265 L
.41549 .53222 L
.42419 .52344 L
.43187 .51609 L
.43866 .50994 L
.44467 .50484 L
.45 .50063 L
.45473 .49717 L
.45893 .49437 L
.46268 .49211 L
.46602 .49032 L
.46901 .48893 L
.47168 .48787 L
.47407 .48709 L
.47623 .48655 L
.47817 .4862 L
.47991 .48602 L
.48149 .48598 L
.48292 .48604 L
.48421 .4862 L
.48539 .48643 L
.48646 .48672 L
.48744 .48705 L
.48833 .48742 L
.48915 .48781 L
.48989 .48823 L
.49058 .48865 L
.49121 .48908 L
.49179 .48951 L
.49233 .48995 L
.49283 .49037 L
.49329 .4908 L
.49371 .49121 L
.4941 .49161 L
.49447 .492 L
.49481 .49238 L
.49513 .49275 L
.49542 .4931 L
.4957 .49344 L
.49596 .49377 L
.4962 .49408 L
Mistroke
.49642 .49438 L
.49663 .49467 L
.49683 .49494 L
.49701 .4952 L
.49719 .49545 L
.49735 .49569 L
.4975 .49592 L
.49764 .49613 L
.49778 .49634 L
.49791 .49653 L
.49802 .49672 L
.49814 .49689 L
.49824 .49706 L
.49834 .49722 L
.49843 .49737 L
.49852 .49751 L
.49861 .49764 L
.49868 .49777 L
.49876 .49789 L
.49883 .49801 L
.49889 .49812 L
.49895 .49822 L
.49901 .49831 L
.49907 .49841 L
.49912 .49849 L
.49917 .49858 L
.49921 .49865 L
.49926 .49873 L
.4993 .4988 L
.49934 .49886 L
.49938 .49893 L
.49941 .49898 L
.49944 .49904 L
.49947 .49909 L
.4995 .49914 L
.49953 .49919 L
.49956 .49923 L
.49958 .49928 L
.4996 .49932 L
.49963 .49935 L
.49965 .49939 L
.49967 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49957 L
.49976 .49959 L
.49978 .49961 L
.49979 .49963 L
Mistroke
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.22581 .77365 m
.25786 .72923 L
s
% Start of user PostScript
-8.2257349 8.2095546 -7.2641657 6.8768814 MAarrowhead1
% End of user PostScript
1 .158 0 r
.28589 .69117 m
.31041 .65861 L
s
% Start of user PostScript
-6.4234419 5.7351733 -5.6878448 4.7582162 MAarrowhead1
% End of user PostScript
1 .473 0 r
.41549 .53222 m
.42419 .52344 L
s
% Start of user PostScript
-2.5353856 0.9665643 -2.2743914 0.70329144 MAarrowhead1
% End of user PostScript
1 .788 0 r
.46268 .49211 m
.46602 .49032 L
s
% Start of user PostScript
-1.1196531 -0.23666096 -1.0194091 -0.29034703 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48149 .48598 m
.48292 .48604 L
s
% Start of user PostScript
-0.55527681 -0.42071197 -0.51242621 -0.41872729 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48989 .48823 m
.49058 .48865 L
s
% Start of user PostScript
-0.30319069 -0.35320745 -0.28258789 -0.34047678 MAarrowhead1
% End of user PostScript
.266 1 0 r
.4941 .49161 m
.49447 .492 L
s
% Start of user PostScript
-0.17686828 -0.25170836 -0.16588275 -0.23997523 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49642 .49438 m
.49663 .49467 L
s
% Start of user PostScript
-0.10736333 -0.16859661 -0.10105245 -0.15998381 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49778 .49634 m
.49791 .49653 L
s
% Start of user PostScript
-0.066620915 -0.10987355 -0.062823838 -0.10403341 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49861 .49764 m
.49868 .49777 L
s
% Start of user PostScript
-0.041821361 -0.070683472 -0.03947644 -0.066856021 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49912 .49849 m
.49917 .49858 L
s
% Start of user PostScript
-0.026410193 -0.045186656 -0.024941822 -0.042717745 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49944 .49904 m
.49947 .49909 L
s
% Start of user PostScript
-0.016728463 -0.028797503 -0.015802362 -0.027217086 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49965 .49939 m
.49967 .49942 L
s
% Start of user PostScript
-0.010612086 -0.018324412 -0.010025861 -0.017316551 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49978 .49961 m
.49979 .49963 L
s
% Start of user PostScript
-0.00673716 -0.011651225 -0.0063653943 -0.011009695 MAarrowhead1
% End of user PostScript
1 0 .047 r
.3767 .20505 m
.38166 .2245 L
.38659 .24245 L
.39145 .25904 L
.39624 .2744 L
.40092 .28863 L
.40548 .30184 L
.40991 .31411 L
.4142 .32553 L
.41835 .33616 L
.42234 .34607 L
.42618 .35532 L
.42987 .36395 L
.43341 .37202 L
.43679 .37957 L
.44003 .38664 L
.44312 .39326 L
.44607 .39946 L
.44888 .40528 L
.45156 .41075 L
.45411 .41588 L
.45653 .4207 L
.45884 .42522 L
.46103 .42948 L
.46311 .43349 L
.46508 .43726 L
.46696 .4408 L
.46873 .44414 L
.47042 .44729 L
.47201 .45025 L
.47353 .45304 L
.47496 .45568 L
.47632 .45816 L
.47761 .4605 L
.47883 .4627 L
.47998 .46478 L
.48107 .46674 L
.4821 .4686 L
.48308 .47034 L
.484 .47199 L
.48488 .47355 L
.48571 .47502 L
.48649 .4764 L
.48723 .47771 L
.48793 .47895 L
.48859 .48011 L
.48922 .48121 L
.48981 .48225 L
.49037 .48323 L
.4909 .48416 L
Mistroke
.4914 .48504 L
.49187 .48587 L
.49232 .48665 L
.49274 .48738 L
.49314 .48808 L
.49352 .48874 L
.49387 .48936 L
.49421 .48995 L
.49453 .4905 L
.49483 .49103 L
.49511 .49152 L
.49538 .49199 L
.49564 .49243 L
.49588 .49285 L
.49611 .49325 L
.49632 .49362 L
.49652 .49397 L
.49671 .4943 L
.49689 .49462 L
.49707 .49491 L
.49723 .49519 L
.49738 .49546 L
.49752 .49571 L
.49766 .49595 L
.49779 .49617 L
.49791 .49638 L
.49803 .49658 L
.49814 .49677 L
.49824 .49695 L
.49834 .49712 L
.49843 .49727 L
.49851 .49742 L
.4986 .49757 L
.49867 .4977 L
.49875 .49783 L
.49882 .49795 L
.49888 .49806 L
.49894 .49817 L
.499 .49827 L
.49906 .49836 L
.49911 .49845 L
.49916 .49854 L
.4992 .49862 L
.49925 .4987 L
.49929 .49877 L
.49933 .49884 L
.49936 .4989 L
.4994 .49896 L
.49943 .49902 L
.49946 .49907 L
Mistroke
.49949 .49912 L
.49952 .49917 L
.49955 .49922 L
.49957 .49926 L
.4996 .4993 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49944 L
.4997 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49956 L
.49976 .49958 L
.49977 .4996 L
.49978 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
Mistroke
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.3767 .20505 m
.38166 .2245 L
s
% Start of user PostScript
-3.6988617 -8.8485586 -3.5502319 -8.2651077 MAarrowhead1
% End of user PostScript
1 .158 0 r
.38659 .24245 m
.39145 .25904 L
s
% Start of user PostScript
-3.4024176 -7.726595 -3.2563589 -7.2288374 MAarrowhead1
% End of user PostScript
1 .473 0 r
.42234 .34607 m
.42618 .35532 L
s
% Start of user PostScript
-2.3297813 -4.6179202 -2.2145443 -4.3405399 MAarrowhead1
% End of user PostScript
1 .788 0 r
.44888 .40528 m
.45156 .41075 L
s
% Start of user PostScript
-1.533622 -2.8414538 -1.4532762 -2.6775729 MAarrowhead1
% End of user PostScript
.897 1 0 r
.46696 .4408 m
.46873 .44414 L
s
% Start of user PostScript
-0.99134917 -1.7759009 -0.93803599 -1.675705 MAarrowhead1
% End of user PostScript
.581 1 0 r
.47883 .4627 m
.47998 .46478 L
s
% Start of user PostScript
-0.63524055 -1.1189648 -0.60064831 -1.0565533 MAarrowhead1
% End of user PostScript
.266 1 0 r
.48649 .4764 m
.48723 .47771 L
s
% Start of user PostScript
-0.40530974 -0.70795817 -0.38310297 -0.66870174 MAarrowhead1
% End of user PostScript
0 1 .049 r
.4914 .48504 m
.49187 .48587 L
s
% Start of user PostScript
-0.25805546 -0.44885311 -0.24387383 -0.42403774 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49453 .4905 m
.49483 .49103 L
s
% Start of user PostScript
-0.16412688 -0.28487603 -0.15509356 -0.26914977 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49652 .49397 m
.49671 .4943 L
s
% Start of user PostScript
-0.10433191 -0.18089881 -0.098585308 -0.17091996 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49779 .49617 m
.49791 .49638 L
s
% Start of user PostScript
-0.066304051 -0.11490257 -0.062650656 -0.10856661 MAarrowhead1
% End of user PostScript
0 .69 1 r
.4986 .49757 m
.49867 .4977 L
s
% Start of user PostScript
-0.042131387 -0.072992954 -0.039809485 -0.068968733 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49911 .49845 m
.49916 .49854 L
s
% Start of user PostScript
-0.026769658 -0.046372526 -0.025294218 -0.043816172 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49943 .49902 m
.49946 .49907 L
s
% Start of user PostScript
-0.017008483 -0.029461501 -0.016070997 -0.027837468 MAarrowhead1
% End of user PostScript
0 .347 1 r
.63982 .68684 m
.63086 .67871 L
.62257 .67074 L
.61487 .66295 L
.60772 .65538 L
.60108 .64804 L
.5949 .64094 L
.58914 .63409 L
.58376 .62749 L
.57875 .62116 L
.57406 .61507 L
.56968 .60925 L
.56558 .60368 L
.56174 .59835 L
.55814 .59326 L
.55477 .58842 L
.55161 .58379 L
.54863 .5794 L
.54584 .57521 L
.54322 .57123 L
.54076 .56744 L
.53844 .56385 L
.53626 .56044 L
.53421 .5572 L
.53228 .55413 L
.53046 .55121 L
.52874 .54845 L
.52713 .54583 L
.52561 .54335 L
.52417 .541 L
.52282 .53877 L
.52155 .53667 L
.52034 .53467 L
.51921 .53278 L
.51814 .53099 L
.51713 .5293 L
.51618 .5277 L
.51528 .52619 L
.51443 .52475 L
.51363 .5234 L
.51287 .52212 L
.51216 .52091 L
.51149 .51976 L
.51085 .51868 L
.51025 .51765 L
.50968 .51668 L
.50915 .51577 L
.50864 .5149 L
.50816 .51408 L
.50771 .51331 L
Mistroke
.50728 .51258 L
.50688 .51188 L
.5065 .51123 L
.50614 .51061 L
.5058 .51003 L
.50548 .50948 L
.50518 .50896 L
.50489 .50846 L
.50462 .508 L
.50437 .50756 L
.50413 .50714 L
.5039 .50675 L
.50369 .50638 L
.50348 .50602 L
.50329 .50569 L
.50311 .50538 L
.50294 .50508 L
.50277 .5048 L
.50262 .50454 L
.50248 .50429 L
.50234 .50405 L
.50221 .50383 L
.50209 .50362 L
.50197 .50342 L
.50187 .50323 L
.50176 .50305 L
.50167 .50288 L
.50157 .50272 L
.50149 .50257 L
.5014 .50243 L
.50133 .5023 L
.50125 .50217 L
.50119 .50205 L
.50112 .50194 L
.50106 .50183 L
.501 .50173 L
.50094 .50164 L
.50089 .50155 L
.50084 .50146 L
.5008 .50138 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50064 .5011 L
.5006 .50104 L
.50057 .50098 L
.50054 .50093 L
.50051 .50088 L
.50048 .50083 L
.50045 .50078 L
Mistroke
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50056 L
.5003 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .5004 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
Mistroke
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.63982 .68684 m
.63086 .67871 L
s
% Start of user PostScript
4.1947265 5.6051266 3.9259372 5.3612386 MAarrowhead1
% End of user PostScript
1 .158 0 r
.62257 .67074 m
.61487 .66295 L
s
% Start of user PostScript
3.6769798 5.1221063 3.4460916 4.8886273 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57406 .61507 m
.56968 .60925 L
s
% Start of user PostScript
2.2218628 3.4522373 2.0904269 3.2774714 MAarrowhead1
% End of user PostScript
1 .788 0 r
.54584 .57521 m
.54322 .57123 L
s
% Start of user PostScript
1.3753297 2.2562567 1.2966712 2.1368226 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52874 .54845 m
.52713 .54583 L
s
% Start of user PostScript
0.86226617 1.4534859 0.81383174 1.3749357 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51814 .53099 m
.51713 .5293 L
s
% Start of user PostScript
0.54416779 0.92981431 0.5138849 0.87905994 MAarrowhead1
% End of user PostScript
.266 1 0 r
.51149 .51976 m
.51085 .51868 L
s
% Start of user PostScript
0.34456799 0.59276972 0.32548354 0.5602538 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50728 .51258 m
.50688 .51188 L
s
% Start of user PostScript
0.21854863 0.37725367 0.2064729 0.35650926 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50462 .508 m
.50437 .50756 L
s
% Start of user PostScript
0.13873573 0.23988941 0.1310792 0.22668238 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50294 .50508 m
.50277 .5048 L
s
% Start of user PostScript
0.088107414 0.15247689 0.083247885 0.14407725 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50187 .50323 m
.50176 .50305 L
s
% Start of user PostScript
0.05596657 0.09689575 0.052880687 0.091556344 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50119 .50205 m
.50112 .50194 L
s
% Start of user PostScript
0.035554207 0.061568604 0.033594117 0.058175375 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50075 .5013 m
.50071 .50123 L
s
% Start of user PostScript
0.022587926 0.039119277 0.021342756 0.036963134 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50048 .50083 m
.50045 .50078 L
s
% Start of user PostScript
0.014350706 0.02485483 0.013559646 0.023484851 MAarrowhead1
% End of user PostScript
.501 1 0 r
.23488 .69988 m
.26441 .66303 L
.29032 .63166 L
.31307 .60501 L
.33308 .58242 L
.35069 .56331 L
.3662 .54721 L
.37989 .53367 L
.39198 .52234 L
.40267 .5129 L
.41214 .50508 L
.42054 .49863 L
.42801 .49337 L
.43465 .48911 L
.44056 .4857 L
.44585 .48301 L
.45057 .48094 L
.4548 .47938 L
.4586 .47826 L
.46201 .4775 L
.46508 .47704 L
.46786 .47684 L
.47036 .47684 L
.47264 .47701 L
.4747 .47732 L
.47657 .47774 L
.47828 .47825 L
.47983 .47883 L
.48126 .47946 L
.48256 .48012 L
.48375 .48081 L
.48485 .48152 L
.48586 .48223 L
.48679 .48295 L
.48765 .48366 L
.48845 .48436 L
.48918 .48505 L
.48987 .48573 L
.4905 .48639 L
.49109 .48703 L
.49163 .48764 L
.49214 .48824 L
.49262 .48882 L
.49306 .48937 L
.49348 .4899 L
.49386 .49041 L
.49422 .4909 L
.49456 .49137 L
.49488 .49181 L
.49518 .49224 L
Mistroke
.49546 .49264 L
.49572 .49303 L
.49596 .49339 L
.4962 .49374 L
.49641 .49407 L
.49662 .49439 L
.49681 .49469 L
.49699 .49497 L
.49716 .49524 L
.49732 .4955 L
.49747 .49574 L
.49761 .49597 L
.49775 .49619 L
.49787 .4964 L
.49799 .49659 L
.4981 .49678 L
.49821 .49695 L
.49831 .49712 L
.4984 .49728 L
.49849 .49742 L
.49858 .49756 L
.49866 .4977 L
.49873 .49782 L
.4988 .49794 L
.49887 .49806 L
.49893 .49816 L
.49899 .49826 L
.49905 .49836 L
.4991 .49845 L
.49915 .49853 L
.4992 .49861 L
.49924 .49869 L
.49928 .49876 L
.49932 .49883 L
.49936 .49889 L
.49939 .49896 L
.49943 .49901 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49954 .49921 L
.49957 .49926 L
.49959 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
Mistroke
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
Mistroke
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.23488 .69988 m
.26441 .66303 L
s
% Start of user PostScript
-7.9535733 5.9963943 -7.0677523 4.8909289 MAarrowhead1
% End of user PostScript
1 .158 0 r
.29032 .63166 m
.31307 .60501 L
s
% Start of user PostScript
-6.2904911 3.9498576 -5.6078313 3.1503063 MAarrowhead1
% End of user PostScript
1 .473 0 r
.41214 .50508 m
.42054 .49863 L
s
% Start of user PostScript
-2.6356936 0.15231969 -2.3836637 -0.040967677 MAarrowhead1
% End of user PostScript
1 .788 0 r
.4586 .47826 m
.46201 .4775 L
s
% Start of user PostScript
-1.2421008 -0.65228375 -1.139713 -0.67508294 MAarrowhead1
% End of user PostScript
.897 1 0 r
.47828 .47825 m
.47983 .47883 L
s
% Start of user PostScript
-0.65173218 -0.65245669 -0.6050284 -0.63516298 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48765 .48366 m
.48845 .48436 L
s
% Start of user PostScript
-0.37040235 -0.49017489 -0.34655984 -0.46908886 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49262 .48882 m
.49306 .48937 L
s
% Start of user PostScript
-0.22145497 -0.33546615 -0.20815956 -0.3188602 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49546 .49264 m
.49572 .49303 L
s
% Start of user PostScript
-0.13628994 -0.22077448 -0.12843156 -0.20920423 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49716 .49524 m
.49732 .4955 L
s
% Start of user PostScript
-0.085189513 -0.14269485 -0.080383835 -0.13501971 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49821 .49695 m
.49831 .49712 L
s
% Start of user PostScript
-0.053679258 -0.09143154 -0.050685457 -0.086452214 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49887 .49806 m
.49893 .49816 L
s
% Start of user PostScript
-0.033963242 -0.058335523 -0.032080044 -0.055139218 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49928 .49876 m
.49932 .49883 L
s
% Start of user PostScript
-0.021533348 -0.037140972 -0.020342874 -0.035099822 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49954 .49921 m
.49957 .49926 L
s
% Start of user PostScript
-0.013666777 -0.023622018 -0.012912326 -0.022321883 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49971 .4995 m
.49973 .49953 L
s
% Start of user PostScript
-0.008678554 -0.015015955 -0.0081998246 -0.014188873 MAarrowhead1
% End of user PostScript
1 0 .179 r
.30472 .69664 m
.32759 .66484 L
.34758 .63759 L
.36507 .61426 L
.38038 .59433 L
.3938 .57731 L
.40556 .56281 L
.41589 .55047 L
.42497 .54 L
.43295 .53114 L
.43998 .52365 L
.44617 .51734 L
.45164 .51205 L
.45648 .50763 L
.46075 .50396 L
.46454 .50092 L
.46791 .49843 L
.4709 .4964 L
.47356 .49476 L
.47594 .49346 L
.47806 .49245 L
.47996 .49167 L
.48166 .49109 L
.48319 .49069 L
.48456 .49043 L
.4858 .49028 L
.48692 .49023 L
.48793 .49027 L
.48885 .49037 L
.48968 .49052 L
.49044 .49071 L
.49113 .49094 L
.49177 .49119 L
.49234 .49146 L
.49287 .49175 L
.49336 .49204 L
.4938 .49234 L
.49421 .49264 L
.49459 .49295 L
.49494 .49324 L
.49527 .49354 L
.49557 .49383 L
.49585 .49411 L
.4961 .49438 L
.49635 .49465 L
.49657 .4949 L
.49678 .49515 L
.49697 .49539 L
.49715 .49562 L
.49732 .49584 L
Mistroke
.49748 .49605 L
.49763 .49625 L
.49777 .49644 L
.4979 .49663 L
.49802 .4968 L
.49813 .49697 L
.49824 .49713 L
.49834 .49728 L
.49844 .49742 L
.49853 .49756 L
.49861 .49769 L
.49869 .49781 L
.49876 .49793 L
.49883 .49804 L
.4989 .49815 L
.49896 .49825 L
.49902 .49834 L
.49907 .49843 L
.49913 .49852 L
.49917 .4986 L
.49922 .49867 L
.49926 .49875 L
.49931 .49881 L
.49934 .49888 L
.49938 .49894 L
.49942 .499 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49953 .4992 L
.49956 .49924 L
.49958 .49929 L
.49961 .49932 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.4997 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49976 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
Mistroke
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.30472 .69664 m
.32759 .66484 L
s
% Start of user PostScript
-5.8582701 5.8991333 -5.1722666 4.9450786 MAarrowhead1
% End of user PostScript
1 .158 0 r
.34758 .63759 m
.36507 .61426 L
s
% Start of user PostScript
-4.5725513 4.1275734 -4.0478962 3.4278816 MAarrowhead1
% End of user PostScript
1 .473 0 r
.43998 .52365 m
.44617 .51734 L
s
% Start of user PostScript
-1.8007014 0.70948266 -1.6148156 0.52032955 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47356 .49476 m
.47594 .49346 L
s
% Start of user PostScript
-0.79310008 -0.15712147 -0.72185485 -0.19614151 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48692 .49023 m
.48793 .49027 L
s
% Start of user PostScript
-0.39236322 -0.2929975 -0.36198776 -0.29199887 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49287 .49175 m
.49336 .49204 L
s
% Start of user PostScript
-0.2138446 -0.24753913 -0.19927735 -0.23870932 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49585 .49411 m
.4961 .49438 L
s
% Start of user PostScript
-0.12460254 -0.17677902 -0.11685091 -0.16856477 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49748 .49605 m
.49763 .49625 L
s
% Start of user PostScript
-0.075586533 -0.11851411 -0.07113939 -0.11246767 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49844 .49742 m
.49853 .49756 L
s
% Start of user PostScript
-0.046886125 -0.077266953 -0.044212496 -0.073162403 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49902 .49834 m
.49907 .49843 L
s
% Start of user PostScript
-0.029427387 -0.049716996 -0.027776964 -0.047025628 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49938 .49894 m
.49942 .499 L
s
% Start of user PostScript
-0.01858165 -0.031786273 -0.017548397 -0.030049774 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49961 .49932 m
.49963 .49936 L
s
% Start of user PostScript
-0.011769232 -0.020258405 -0.011117634 -0.019146693 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49975 .49957 m
.49976 .49959 L
s
% Start of user PostScript
-0.0074659052 -0.012891128 -0.0070534651 -0.012182127 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49984 .49973 m
.49985 .49974 L
s
% Start of user PostScript
-0.0047397274 -0.0081966743 -0.0044781784 -0.0077453635 MAarrowhead1
% End of user PostScript
0 .501 1 r
.37697 .32411 m
.38459 .33234 L
.39169 .34032 L
.39829 .34803 L
.40444 .35546 L
.41018 .3626 L
.41555 .36946 L
.42056 .37604 L
.42524 .38234 L
.42963 .38836 L
.43374 .39412 L
.4376 .3996 L
.44121 .40484 L
.4446 .40982 L
.44779 .41457 L
.45078 .41908 L
.45359 .42337 L
.45623 .42745 L
.45872 .43132 L
.46106 .43499 L
.46326 .43848 L
.46533 .44179 L
.46728 .44493 L
.46912 .4479 L
.47086 .45072 L
.47249 .45339 L
.47403 .45592 L
.47548 .45831 L
.47685 .46058 L
.47814 .46272 L
.47936 .46476 L
.48051 .46668 L
.48159 .4685 L
.48262 .47022 L
.48358 .47185 L
.48449 .47339 L
.48535 .47485 L
.48617 .47622 L
.48693 .47753 L
.48766 .47876 L
.48834 .47993 L
.48899 .48103 L
.4896 .48207 L
.49017 .48305 L
.49071 .48398 L
.49123 .48487 L
.49171 .4857 L
.49217 .48648 L
.4926 .48723 L
.49301 .48793 L
Mistroke
.4934 .48859 L
.49376 .48922 L
.49411 .48981 L
.49443 .49037 L
.49474 .4909 L
.49503 .49141 L
.4953 .49188 L
.49556 .49233 L
.49581 .49275 L
.49604 .49315 L
.49626 .49353 L
.49646 .49388 L
.49666 .49422 L
.49684 .49454 L
.49702 .49484 L
.49718 .49512 L
.49734 .49539 L
.49748 .49565 L
.49762 .49589 L
.49775 .49611 L
.49788 .49633 L
.49799 .49653 L
.49811 .49672 L
.49821 .4969 L
.49831 .49707 L
.4984 .49723 L
.49849 .49739 L
.49857 .49753 L
.49865 .49767 L
.49873 .49779 L
.4988 .49792 L
.49886 .49803 L
.49893 .49814 L
.49898 .49824 L
.49904 .49834 L
.49909 .49843 L
.49914 .49852 L
.49919 .4986 L
.49924 .49868 L
.49928 .49875 L
.49932 .49882 L
.49935 .49888 L
.49939 .49894 L
.49942 .499 L
.49946 .49906 L
.49949 .49911 L
.49951 .49916 L
.49954 .4992 L
.49957 .49925 L
.49959 .49929 L
Mistroke
.49961 .49933 L
.49963 .49937 L
.49965 .4994 L
.49967 .49943 L
.49969 .49947 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .4997 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49988 .49978 L
.49988 .4998 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
Mistroke
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.37697 .32411 m
.38459 .33234 L
s
% Start of user PostScript
-3.6908487 -5.2767956 -3.4621528 -5.0296687 MAarrowhead1
% End of user PostScript
1 .158 0 r
.39169 .34032 m
.39829 .34803 L
s
% Start of user PostScript
-3.2494341 -4.7903245 -3.0513619 -4.5591137 MAarrowhead1
% End of user PostScript
1 .473 0 r
.43374 .39412 m
.4376 .3996 L
s
% Start of user PostScript
-1.9876961 -3.1765392 -1.872107 -3.0118793 MAarrowhead1
% End of user PostScript
1 .788 0 r
.45872 .43132 m
.46106 .43499 L
s
% Start of user PostScript
-1.2384611 -2.0604693 -1.1682809 -1.9502095 MAarrowhead1
% End of user PostScript
.897 1 0 r
.47403 .45592 m
.47548 .45831 L
s
% Start of user PostScript
-0.77909153 -1.3225397 -0.7355386 -1.2506933 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48358 .47185 m
.48449 .47339 L
s
% Start of user PostScript
-0.49252578 -0.84453583 -0.46518378 -0.79831877 MAarrowhead1
% End of user PostScript
.266 1 0 r
.4896 .48207 m
.49017 .48305 L
s
% Start of user PostScript
-0.31213969 -0.53792679 -0.29487271 -0.50838197 MAarrowhead1
% End of user PostScript
0 1 .049 r
.4934 .48859 m
.49376 .48922 L
s
% Start of user PostScript
-0.19806696 -0.34219927 -0.18712973 -0.32337061 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49581 .49275 m
.49604 .49315 L
s
% Start of user PostScript
-0.12576142 -0.217551 -0.11882308 -0.20557005 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49734 .49539 m
.49748 .49565 L
s
% Start of user PostScript
-0.079876536 -0.1382631 -0.075471665 -0.13064527 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49831 .49707 m
.4984 .49723 L
s
% Start of user PostScript
-0.050741033 -0.087858361 -0.047943494 -0.083016578 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49893 .49814 m
.49898 .49824 L
s
% Start of user PostScript
-0.032235436 -0.055824615 -0.030458377 -0.052747834 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49932 .49882 m
.49935 .49888 L
s
% Start of user PostScript
-0.020479761 -0.03546919 -0.019350826 -0.033514192 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49957 .49925 m
.49959 .49929 L
s
% Start of user PostScript
-0.013011422 -0.022535555 -0.012294195 -0.021293401 MAarrowhead1
% End of user PostScript
.359 1 0 r
.52516 .28561 m
.51793 .30753 L
.51189 .3269 L
.50685 .34404 L
.50267 .35921 L
.49924 .37267 L
.49643 .38463 L
.49415 .39527 L
.49233 .40475 L
.4909 .41321 L
.4898 .42078 L
.48897 .42756 L
.48837 .43364 L
.48796 .43911 L
.48772 .44404 L
.48761 .44848 L
.48761 .4525 L
.48771 .45614 L
.48787 .45944 L
.4881 .46244 L
.48837 .46518 L
.48868 .46767 L
.48902 .46995 L
.48937 .47204 L
.48974 .47396 L
.49012 .47572 L
.4905 .47734 L
.49089 .47883 L
.49127 .48021 L
.49164 .48148 L
.49201 .48266 L
.49237 .48375 L
.49272 .48477 L
.49307 .48571 L
.4934 .48659 L
.49372 .4874 L
.49402 .48817 L
.49432 .48888 L
.4946 .48954 L
.49488 .49016 L
.49514 .49074 L
.49539 .49128 L
.49562 .49179 L
.49585 .49227 L
.49607 .49272 L
.49627 .49314 L
.49647 .49353 L
.49666 .4939 L
.49683 .49425 L
.497 .49458 L
Mistroke
.49716 .49488 L
.49731 .49517 L
.49746 .49545 L
.49759 .4957 L
.49772 .49595 L
.49785 .49617 L
.49796 .49639 L
.49807 .49659 L
.49818 .49678 L
.49828 .49696 L
.49837 .49713 L
.49846 .49729 L
.49854 .49744 L
.49862 .49758 L
.4987 .49772 L
.49877 .49785 L
.49884 .49797 L
.4989 .49808 L
.49896 .49818 L
.49902 .49829 L
.49907 .49838 L
.49912 .49847 L
.49917 .49856 L
.49922 .49863 L
.49926 .49871 L
.4993 .49878 L
.49934 .49885 L
.49937 .49891 L
.49941 .49897 L
.49944 .49903 L
.49947 .49908 L
.4995 .49913 L
.49953 .49918 L
.49955 .49923 L
.49958 .49927 L
.4996 .49931 L
.49962 .49935 L
.49964 .49938 L
.49966 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
Mistroke
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.52516 .28561 m
.51793 .30753 L
s
% Start of user PostScript
0.75473671 -6.4318331 0.5380148 -5.7739855 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51189 .3269 m
.50685 .34404 L
s
% Start of user PostScript
0.35661861 -5.1928943 0.20547958 -4.6789221 MAarrowhead1
% End of user PostScript
1 .473 0 r
.4898 .42078 m
.48897 .42756 L
s
% Start of user PostScript
-0.30610305 -2.3766446 -0.33101193 -2.1732729 MAarrowhead1
% End of user PostScript
1 .788 0 r
.48787 .45944 m
.4881 .46244 L
s
% Start of user PostScript
-0.36375262 -1.2167973 -0.35697929 -1.1267291 MAarrowhead1
% End of user PostScript
.897 1 0 r
.4905 .47734 m
.49089 .47883 L
s
% Start of user PostScript
-0.2848983 -0.67991605 -0.2734135 -0.63513038 MAarrowhead1
% End of user PostScript
.581 1 0 r
.4934 .48659 m
.49372 .4874 L
s
% Start of user PostScript
-0.19810153 -0.40237361 -0.18852266 -0.377872 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49562 .49179 m
.49585 .49227 L
s
% Start of user PostScript
-0.13129431 -0.24623715 -0.12448325 -0.23192628 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49716 .49488 m
.49731 .49517 L
s
% Start of user PostScript
-0.085143061 -0.15345542 -0.080585254 -0.14476225 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49818 .49678 m
.49828 .49696 L
s
% Start of user PostScript
-0.054643584 -0.096546814 -0.051674582 -0.091150508 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49884 .49797 m
.4989 .49808 L
s
% Start of user PostScript
-0.034891738 -0.061038465 -0.032982131 -0.057650264 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49926 .49871 m
.4993 .49878 L
s
% Start of user PostScript
-0.022223621 -0.038684441 -0.02100297 -0.036544578 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49953 .49918 m
.49955 .49923 L
s
% Start of user PostScript
-0.014137229 -0.024547412 -0.013359347 -0.023191936 MAarrowhead1
% End of user PostScript
0 .375 1 r
.4997 .49948 m
.49972 .49951 L
s
% Start of user PostScript
-0.0089875868 -0.015586345 -0.008492618 -0.014726446 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49981 .49967 m
.49982 .49969 L
s
% Start of user PostScript
-0.0057119803 -0.0098996012 -0.0053972678 -0.0093536807 MAarrowhead1
% End of user PostScript
.222 0 1 r
.81414 .21013 m
.77795 .2588 L
.74628 .30041 L
.71853 .33596 L
.69421 .36626 L
.67287 .39206 L
.65412 .41398 L
.63764 .43255 L
.62313 .44826 L
.61035 .46149 L
.59907 .47262 L
.58911 .48192 L
.58029 .48968 L
.57249 .4961 L
.56556 .50139 L
.55941 .50571 L
.55394 .5092 L
.54906 .512 L
.5447 .5142 L
.54081 .51589 L
.53732 .51716 L
.53419 .51808 L
.53137 .51869 L
.52884 .51906 L
.52655 .51922 L
.52448 .51921 L
.5226 .51906 L
.5209 .5188 L
.51936 .51844 L
.51795 .51802 L
.51666 .51754 L
.51549 .51701 L
.51441 .51646 L
.51343 .51589 L
.51252 .5153 L
.51169 .51471 L
.51092 .51411 L
.51021 .51352 L
.50955 .51294 L
.50894 .51237 L
.50838 .51181 L
.50785 .51126 L
.50737 .51073 L
.50692 .51022 L
.5065 .50973 L
.5061 .50925 L
.50574 .50879 L
.50539 .50835 L
.50508 .50793 L
.50478 .50753 L
Mistroke
.5045 .50714 L
.50423 .50677 L
.50399 .50642 L
.50376 .50609 L
.50354 .50577 L
.50334 .50546 L
.50315 .50518 L
.50297 .5049 L
.5028 .50464 L
.50264 .50439 L
.50249 .50416 L
.50235 .50393 L
.50222 .50372 L
.50209 .50352 L
.50197 .50333 L
.50186 .50315 L
.50176 .50298 L
.50166 .50282 L
.50157 .50267 L
.50148 .50252 L
.5014 .50238 L
.50132 .50225 L
.50125 .50213 L
.50118 .50201 L
.50111 .5019 L
.50105 .5018 L
.50099 .5017 L
.50094 .50161 L
.50088 .50152 L
.50084 .50144 L
.50079 .50136 L
.50075 .50128 L
.5007 .50121 L
.50067 .50115 L
.50063 .50108 L
.50059 .50102 L
.50056 .50097 L
.50053 .50091 L
.5005 .50086 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50036 .50062 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
Mistroke
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
Mistroke
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.81414 .21013 m
.77795 .2588 L
s
% Start of user PostScript
9.4240996 -8.6959931 8.3385005 -7.236092 MAarrowhead1
% End of user PostScript
1 .158 0 r
.74628 .30041 m
.71853 .33596 L
s
% Start of user PostScript
7.3883235 -5.9875752 6.556013 -4.921313 MAarrowhead1
% End of user PostScript
1 .473 0 r
.59907 .47262 m
.58911 .48192 L
s
% Start of user PostScript
2.9720703 -0.82148531 2.6731734 -0.54225154 MAarrowhead1
% End of user PostScript
1 .788 0 r
.5447 .5142 m
.54081 .51589 L
s
% Start of user PostScript
1.3410592 0.42589752 1.2242156 0.47676583 MAarrowhead1
% End of user PostScript
.897 1 0 r
.5226 .51906 m
.5209 .5188 L
s
% Start of user PostScript
0.67813805 0.57178594 0.6271184 0.56389316 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51252 .5153 m
.51169 .51471 L
s
% Start of user PostScript
0.37559091 0.45899268 0.35055345 0.44119979 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50737 .51073 m
.50692 .51022 L
s
% Start of user PostScript
0.22106903 0.32203294 0.20750605 0.30666773 MAarrowhead1
% End of user PostScript
0 1 .049 r
.5045 .50714 m
.50423 .50677 L
s
% Start of user PostScript
0.13487454 0.21426662 0.12700239 0.20321406 MAarrowhead1
% End of user PostScript
0 1 .364 r
.5028 .50464 m
.50264 .50439 L
s
% Start of user PostScript
0.08391839 0.1392042 0.07915361 0.13177199 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50176 .50298 m
.50166 .50282 L
s
% Start of user PostScript
0.052753491 0.089418452 0.049801451 0.084566144 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50111 .5019 m
.50105 .5018 L
s
% Start of user PostScript
0.033337511 0.057121561 0.031485859 0.053997272 MAarrowhead1
% End of user PostScript
0 .69 1 r
.5007 .50121 m
.50067 .50115 L
s
% Start of user PostScript
0.021123861 0.036390357 0.019955023 0.034392203 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50045 .50077 m
.50042 .50073 L
s
% Start of user PostScript
0.013402821 0.023151688 0.012662622 0.021877993 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50028 .50049 m
.50027 .50046 L
s
% Start of user PostScript
0.0085096461 0.014719221 0.0080401326 0.013908659 MAarrowhead1
% End of user PostScript
.431 1 0 r
.7924 .44681 m
.76362 .47168 L
.73811 .49224 L
.71548 .50914 L
.69536 .5229 L
.67746 .53401 L
.66149 .54284 L
.64723 .54977 L
.63447 .55507 L
.62303 .559 L
.61276 .56179 L
.60353 .56362 L
.5952 .56464 L
.58769 .56501 L
.58089 .56483 L
.57472 .56421 L
.56913 .56322 L
.56404 .56195 L
.5594 .56046 L
.55517 .55879 L
.5513 .55699 L
.54775 .5551 L
.54449 .55314 L
.5415 .55115 L
.53874 .54914 L
.5362 .54714 L
.53385 .54515 L
.53168 .54319 L
.52967 .54127 L
.52781 .53939 L
.52607 .53756 L
.52446 .53579 L
.52297 .53407 L
.52157 .53242 L
.52027 .53083 L
.51906 .52929 L
.51792 .52783 L
.51686 .52642 L
.51587 .52507 L
.51494 .52378 L
.51407 .52255 L
.51325 .52138 L
.51249 .52027 L
.51177 .5192 L
.51109 .51819 L
.51046 .51723 L
.50986 .51631 L
.5093 .51544 L
.50877 .51462 L
.50828 .51383 L
Mistroke
.50781 .51309 L
.50737 .51239 L
.50695 .51172 L
.50656 .51109 L
.50619 .51049 L
.50585 .50992 L
.50552 .50938 L
.50521 .50887 L
.50492 .50839 L
.50465 .50793 L
.50439 .5075 L
.50414 .50709 L
.50391 .5067 L
.5037 .50633 L
.50349 .50599 L
.5033 .50566 L
.50311 .50535 L
.50294 .50506 L
.50278 .50478 L
.50262 .50452 L
.50248 .50427 L
.50234 .50404 L
.50221 .50381 L
.50209 .5036 L
.50197 .50341 L
.50187 .50322 L
.50176 .50304 L
.50166 .50287 L
.50157 .50272 L
.50149 .50257 L
.5014 .50243 L
.50133 .50229 L
.50125 .50217 L
.50118 .50205 L
.50112 .50193 L
.50106 .50183 L
.501 .50173 L
.50094 .50163 L
.50089 .50154 L
.50084 .50146 L
.5008 .50138 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50063 .5011 L
.5006 .50104 L
.50057 .50098 L
.50053 .50093 L
.50051 .50088 L
.50048 .50083 L
Mistroke
.50045 .50078 L
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50056 L
.5003 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .5004 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
Mistroke
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.7924 .44681 m
.76362 .47168 L
s
% Start of user PostScript
8.7718811 -1.5957043 7.9084609 -0.84973624 MAarrowhead1
% End of user PostScript
1 .158 0 r
.73811 .49224 m
.71548 .50914 L
s
% Start of user PostScript
7.1433531 -0.23273599 6.4643674 0.2741338 MAarrowhead1
% End of user PostScript
1 .473 0 r
.61276 .56179 m
.60353 .56362 L
s
% Start of user PostScript
3.3828961 1.8536651 3.1057858 1.9084828 MAarrowhead1
% End of user PostScript
1 .788 0 r
.5594 .56046 m
.55517 .55879 L
s
% Start of user PostScript
1.7820836 1.8137516 1.6550495 1.7636641 MAarrowhead1
% End of user PostScript
.897 1 0 r
.53385 .54515 m
.53168 .54319 L
s
% Start of user PostScript
1.0155424 1.3544721 0.95041136 1.2956653 MAarrowhead1
% End of user PostScript
.581 1 0 r
.52027 .53083 m
.51906 .52929 L
s
% Start of user PostScript
0.60813603 0.92478266 0.57170617 0.87884527 MAarrowhead1
% End of user PostScript
.266 1 0 r
.51249 .52027 m
.51177 .5192 L
s
% Start of user PostScript
0.37459138 0.6079645 0.35301913 0.5760536 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50781 .51309 m
.50737 .51239 L
s
% Start of user PostScript
0.23424953 0.39275197 0.22104367 0.37161169 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50492 .50839 m
.50465 .50793 L
s
% Start of user PostScript
0.14763892 0.25159336 0.13940754 0.23788686 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50311 .50535 m
.50294 .50506 L
s
% Start of user PostScript
0.093423264 0.16050309 0.088243992 0.15170732 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50197 .50341 m
.50187 .50322 L
s
% Start of user PostScript
0.059235681 0.10218269 0.055961108 0.096566567 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50125 .50217 m
.50118 .50205 L
s
% Start of user PostScript
0.037596807 0.064987219 0.035521427 0.061410226 MAarrowhead1
% End of user PostScript
0 .375 1 r
.5008 .50138 m
.50075 .5013 L
s
% Start of user PostScript
0.023874744 0.041310209 0.022557785 0.039034785 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50051 .50088 m
.50048 .50083 L
s
% Start of user PostScript
0.015164802 0.026252842 0.014328596 0.024806275 MAarrowhead1
% End of user PostScript
.337 1 0 r
.67738 .28128 m
.6557 .31395 L
.6368 .34207 L
.62033 .36625 L
.60595 .38703 L
.5934 .40488 L
.58244 .42019 L
.57286 .43332 L
.56448 .44455 L
.55714 .45416 L
.55072 .46236 L
.54508 .46935 L
.54014 .4753 L
.53579 .48036 L
.53197 .48464 L
.52861 .48826 L
.52565 .49131 L
.52303 .49387 L
.52072 .49601 L
.51867 .49779 L
.51686 .49927 L
.51526 .50048 L
.51383 .50147 L
.51256 .50227 L
.51142 .50291 L
.51041 .50341 L
.50951 .5038 L
.5087 .50408 L
.50797 .50429 L
.50731 .50443 L
.50673 .50451 L
.50619 .50454 L
.50571 .50453 L
.50528 .50449 L
.50488 .50442 L
.50452 .50434 L
.50419 .50424 L
.50389 .50412 L
.50362 .504 L
.50337 .50387 L
.50314 .50373 L
.50293 .50359 L
.50273 .50345 L
.50255 .50331 L
.50239 .50317 L
.50223 .50303 L
.50209 .5029 L
.50196 .50277 L
.50184 .50264 L
.50172 .50252 L
Mistroke
.50162 .5024 L
.50152 .50228 L
.50143 .50217 L
.50134 .50206 L
.50126 .50196 L
.50119 .50186 L
.50112 .50176 L
.50105 .50167 L
.50099 .50159 L
.50093 .5015 L
.50088 .50143 L
.50083 .50135 L
.50078 .50128 L
.50074 .50121 L
.50069 .50115 L
.50065 .50109 L
.50062 .50103 L
.50058 .50097 L
.50055 .50092 L
.50052 .50087 L
.50049 .50082 L
.50046 .50078 L
.50044 .50074 L
.50041 .5007 L
.50039 .50066 L
.50037 .50062 L
.50035 .50059 L
.50033 .50056 L
.50031 .50053 L
.50029 .5005 L
.50028 .50047 L
.50026 .50045 L
.50025 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50016 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
Mistroke
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
Mistroke
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.67738 .28128 m
.6557 .31395 L
s
% Start of user PostScript
5.321293 -6.561468 4.6709468 -5.5813979 MAarrowhead1
% End of user PostScript
1 .158 0 r
.6368 .34207 m
.62033 .36625 L
s
% Start of user PostScript
4.1041144 -4.7379104 3.6098289 -4.0124546 MAarrowhead1
% End of user PostScript
1 .473 0 r
.55072 .46236 m
.54508 .46935 L
s
% Start of user PostScript
1.5215114 -1.1291748 1.3524603 -0.91939135 MAarrowhead1
% End of user PostScript
1 .788 0 r
.52072 .49601 m
.51867 .49779 L
s
% Start of user PostScript
0.62157464 -0.1196701 0.56024345 -0.066188535 MAarrowhead1
% End of user PostScript
.897 1 0 r
.50951 .5038 m
.5087 .50408 L
s
% Start of user PostScript
0.2852466 0.11391665 0.26092151 0.12253638 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50488 .50442 m
.50452 .50434 L
s
% Start of user PostScript
0.14638013 0.13273707 0.13557798 0.13015496 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50273 .50345 m
.50255 .50331 L
s
% Start of user PostScript
0.081927351 0.10351482 0.076542775 0.099313462 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50162 .5024 m
.50152 .50228 L
s
% Start of user PostScript
0.048532857 0.071862763 0.045581632 0.068379692 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50099 .50159 m
.50093 .5015 L
s
% Start of user PostScript
0.02971673 0.047594466 0.027990989 0.045122925 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50062 .50103 m
.50058 .50097 L
s
% Start of user PostScript
0.018524958 0.030854337 0.017475964 0.029201884 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50039 .50066 m
.50037 .50062 L
s
% Start of user PostScript
0.01165678 0.01979869 0.011005386 0.018722702 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50025 .50042 m
.50023 .5004 L
s
% Start of user PostScript
0.0073701717 0.01264112 0.0069611034 0.0119492 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50016 .50027 m
.50015 .50025 L
s
% Start of user PostScript
0.0046711855 0.008051202 0.0044128092 0.0076089584 MAarrowhead1
% End of user PostScript
0 .06 1 r
.5001 .50017 m
.50009 .50016 L
s
% Start of user PostScript
0.0029641825 0.0051215535 0.0028005087 0.0048397391 MAarrowhead1
% End of user PostScript
0 1 .314 r
.25287 .24863 m
.27049 .25556 L
.2866 .26304 L
.30137 .2709 L
.31492 .27902 L
.32737 .2873 L
.33884 .29564 L
.34942 .30398 L
.35918 .31224 L
.36821 .32039 L
.37658 .32838 L
.38434 .33619 L
.39154 .34379 L
.39823 .35116 L
.40446 .35829 L
.41027 .36517 L
.41568 .37179 L
.42073 .37816 L
.42545 .38427 L
.42986 .39013 L
.43399 .39573 L
.43786 .40108 L
.44148 .40619 L
.44488 .41107 L
.44806 .41571 L
.45105 .42014 L
.45386 .42435 L
.4565 .42835 L
.45898 .43215 L
.46132 .43577 L
.46351 .4392 L
.46558 .44246 L
.46752 .44555 L
.46935 .44848 L
.47108 .45126 L
.4727 .45389 L
.47423 .45639 L
.47568 .45875 L
.47704 .46099 L
.47832 .46311 L
.47953 .46512 L
.48067 .46702 L
.48175 .46882 L
.48276 .47052 L
.48372 .47213 L
.48463 .47365 L
.48548 .47509 L
.48629 .47646 L
.48705 .47775 L
.48777 .47897 L
Mistroke
.48844 .48012 L
.48908 .48121 L
.48969 .48224 L
.49026 .48322 L
.4908 .48414 L
.49131 .48501 L
.49179 .48583 L
.49224 .48661 L
.49267 .48735 L
.49308 .48804 L
.49346 .4887 L
.49382 .48932 L
.49416 .48991 L
.49448 .49047 L
.49479 .49099 L
.49508 .49149 L
.49535 .49195 L
.4956 .4924 L
.49585 .49282 L
.49608 .49321 L
.49629 .49359 L
.4965 .49394 L
.49669 .49427 L
.49687 .49459 L
.49704 .49489 L
.49721 .49517 L
.49736 .49543 L
.49751 .49569 L
.49764 .49592 L
.49777 .49615 L
.4979 .49636 L
.49801 .49656 L
.49812 .49675 L
.49823 .49693 L
.49832 .4971 L
.49842 .49726 L
.4985 .49741 L
.49859 .49755 L
.49866 .49769 L
.49874 .49781 L
.49881 .49794 L
.49887 .49805 L
.49894 .49816 L
.49899 .49826 L
.49905 .49835 L
.4991 .49844 L
.49915 .49853 L
.4992 .49861 L
.49924 .49869 L
.49928 .49876 L
Mistroke
.49932 .49883 L
.49936 .49889 L
.4994 .49895 L
.49943 .49901 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49921 L
.49957 .49926 L
.49959 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
Mistroke
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.25287 .24863 m
.27049 .25556 L
s
% Start of user PostScript
-7.4140394 -7.5410131 -6.8854286 -7.3330835 MAarrowhead1
% End of user PostScript
1 .158 0 r
.2866 .26304 m
.30137 .2709 L
s
% Start of user PostScript
-6.4019682 -7.1088804 -5.9590317 -6.8730036 MAarrowhead1
% End of user PostScript
1 .473 0 r
.37658 .32838 m
.38434 .33619 L
s
% Start of user PostScript
-3.7026169 -5.1484843 -3.4699077 -4.9142578 MAarrowhead1
% End of user PostScript
1 .788 0 r
.42545 .38427 m
.42986 .39013 L
s
% Start of user PostScript
-2.2364986 -3.4718587 -2.1041263 -3.2962358 MAarrowhead1
% End of user PostScript
.897 1 0 r
.45386 .42435 m
.4565 .42835 L
s
% Start of user PostScript
-1.3841033 -2.2696326 -1.30492 -2.1495326 MAarrowhead1
% End of user PostScript
.581 1 0 r
.47108 .45126 m
.4727 .45389 L
s
% Start of user PostScript
-0.86767354 -1.4622733 -0.81892796 -1.3832613 MAarrowhead1
% End of user PostScript
.266 1 0 r
.48175 .46882 m
.48276 .47052 L
s
% Start of user PostScript
-0.54755029 -0.93548915 -0.5170768 -0.88442919 MAarrowhead1
% End of user PostScript
0 1 .049 r
.48844 .48012 m
.48908 .48121 L
s
% Start of user PostScript
-0.34670019 -0.59640438 -0.32749689 -0.5636904 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49267 .48735 m
.49308 .48804 L
s
% Start of user PostScript
-0.21989796 -0.3795722 -0.20774743 -0.35870072 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49535 .49195 m
.4956 .4924 L
s
% Start of user PostScript
-0.13959131 -0.24136542 -0.13188749 -0.22807726 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49704 .49489 m
.49721 .49517 L
s
% Start of user PostScript
-0.088650461 -0.1534156 -0.083760956 -0.14496429 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49812 .49675 m
.49823 .49693 L
s
% Start of user PostScript
-0.056311419 -0.097492451 -0.053206514 -0.092120177 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49881 .49794 m
.49887 .49805 L
s
% Start of user PostScript
-0.03577325 -0.061947808 -0.033801082 -0.058533684 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49924 .49869 m
.49928 .49876 L
s
% Start of user PostScript
-0.022727077 -0.039360232 -0.021474235 -0.03719081 MAarrowhead1
% End of user PostScript
.614 1 0 r
.48687 .33443 m
.48436 .34915 L
.48242 .36232 L
.48097 .37411 L
.47991 .38469 L
.4792 .3942 L
.47877 .40277 L
.47857 .4105 L
.47856 .41748 L
.47872 .42381 L
.479 .42955 L
.47939 .43477 L
.47986 .43952 L
.48039 .44386 L
.48097 .44782 L
.48158 .45145 L
.48222 .45478 L
.48287 .45784 L
.48353 .46065 L
.4842 .46325 L
.48486 .46564 L
.48551 .46785 L
.48615 .4699 L
.48677 .4718 L
.48738 .47356 L
.48797 .4752 L
.48855 .47672 L
.4891 .47814 L
.48963 .47946 L
.49015 .48069 L
.49064 .48185 L
.49111 .48292 L
.49156 .48393 L
.49199 .48487 L
.49241 .48576 L
.4928 .48658 L
.49318 .48736 L
.49353 .48809 L
.49387 .48877 L
.4942 .48942 L
.49451 .49002 L
.4948 .49059 L
.49508 .49112 L
.49534 .49163 L
.49559 .4921 L
.49583 .49255 L
.49605 .49297 L
.49626 .49336 L
.49647 .49373 L
.49666 .49408 L
Mistroke
.49684 .49442 L
.49701 .49473 L
.49717 .49502 L
.49733 .4953 L
.49747 .49556 L
.49761 .49581 L
.49774 .49604 L
.49787 .49626 L
.49798 .49647 L
.49809 .49667 L
.4982 .49685 L
.4983 .49703 L
.49839 .49719 L
.49848 .49735 L
.49856 .49749 L
.49864 .49763 L
.49871 .49776 L
.49879 .49789 L
.49885 .498 L
.49892 .49811 L
.49897 .49822 L
.49903 .49832 L
.49908 .49841 L
.49913 .4985 L
.49918 .49858 L
.49923 .49866 L
.49927 .49873 L
.49931 .4988 L
.49935 .49887 L
.49938 .49893 L
.49942 .49899 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
.49956 .49924 L
.49959 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .49939 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49976 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
Mistroke
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.48687 .33443 m
.48436 .34915 L
s
% Start of user PostScript
-0.39389208 -4.9671669 -0.46913956 -4.5254317 MAarrowhead1
% End of user PostScript
1 .158 0 r
.48242 .36232 m
.48097 .37411 L
s
% Start of user PostScript
-0.52729455 -4.1304665 -0.57102742 -3.7766998 MAarrowhead1
% End of user PostScript
1 .473 0 r
.479 .42955 m
.47939 .43477 L
s
% Start of user PostScript
-0.62994323 -2.11343 -0.61835336 -1.9568667 MAarrowhead1
% End of user PostScript
1 .788 0 r
.48353 .46065 m
.4842 .46325 L
s
% Start of user PostScript
-0.49395178 -1.180423 -0.47407574 -1.1026238 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48855 .47672 m
.4891 .47814 L
s
% Start of user PostScript
-0.34361136 -0.69838914 -0.32700709 -0.65584688 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49241 .48576 m
.4928 .48658 L
s
% Start of user PostScript
-0.22777529 -0.4273245 -0.21596235 -0.40248405 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49508 .49112 m
.49534 .49163 L
s
% Start of user PostScript
-0.14772296 -0.26628866 -0.13981618 -0.2512019 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49684 .49442 m
.49701 .49473 L
s
% Start of user PostScript
-0.094810491 -0.16752939 -0.089659375 -0.15816511 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49798 .49647 m
.49809 .49667 L
s
% Start of user PostScript
-0.060540905 -0.10591265 -0.057227633 -0.10003335 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49871 .49776 m
.49879 .49789 L
s
% Start of user PostScript
-0.038560765 -0.067123735 -0.036442815 -0.063410675 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49918 .49858 m
.49923 .49866 L
s
% Start of user PostScript
-0.02452999 -0.042593495 -0.023180271 -0.04024152 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49948 .4991 m
.49951 .49915 L
s
% Start of user PostScript
-0.01559471 -0.027044611 -0.014735873 -0.025552553 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49967 .49943 m
.49969 .49946 L
s
% Start of user PostScript
-0.0099110908 -0.017177248 -0.0093650214 -0.016229995 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49979 .49964 m
.4998 .49966 L
s
% Start of user PostScript
-0.006297929 -0.010911744 -0.0059508561 -0.010310141 MAarrowhead1
% End of user PostScript
.656 0 1 r
.58068 .74652 m
.57865 .72875 L
.57641 .71251 L
.57401 .69766 L
.5715 .68404 L
.56892 .67153 L
.56631 .66003 L
.56367 .64944 L
.56105 .63967 L
.55845 .63064 L
.5559 .62229 L
.55339 .61455 L
.55095 .60737 L
.54857 .6007 L
.54627 .5945 L
.54404 .58873 L
.5419 .58335 L
.53983 .57833 L
.53785 .57365 L
.53594 .56927 L
.53412 .56518 L
.53238 .56135 L
.53071 .55776 L
.52912 .5544 L
.52761 .55124 L
.52616 .54829 L
.52479 .54551 L
.52348 .5429 L
.52224 .54045 L
.52105 .53814 L
.51993 .53597 L
.51887 .53393 L
.51785 .53201 L
.5169 .53021 L
.51599 .5285 L
.51512 .5269 L
.5143 .52539 L
.51353 .52397 L
.5128 .52263 L
.5121 .52136 L
.51144 .52017 L
.51082 .51904 L
.51023 .51798 L
.50967 .51698 L
.50914 .51603 L
.50865 .51514 L
.50817 .5143 L
.50773 .51351 L
.5073 .51276 L
.5069 .51205 L
Mistroke
.50652 .51138 L
.50617 .51075 L
.50583 .51016 L
.50551 .50959 L
.50521 .50906 L
.50492 .50856 L
.50465 .50809 L
.50439 .50764 L
.50415 .50722 L
.50392 .50682 L
.50371 .50644 L
.5035 .50609 L
.50331 .50575 L
.50313 .50543 L
.50296 .50513 L
.50279 .50485 L
.50264 .50458 L
.5025 .50433 L
.50236 .50409 L
.50223 .50386 L
.50211 .50365 L
.50199 .50345 L
.50188 .50326 L
.50178 .50308 L
.50168 .50291 L
.50159 .50275 L
.5015 .5026 L
.50142 .50245 L
.50134 .50232 L
.50126 .50219 L
.50119 .50207 L
.50113 .50196 L
.50107 .50185 L
.50101 .50175 L
.50095 .50165 L
.5009 .50156 L
.50085 .50147 L
.5008 .50139 L
.50076 .50132 L
.50072 .50124 L
.50068 .50117 L
.50064 .50111 L
.50061 .50105 L
.50057 .50099 L
.50054 .50094 L
.50051 .50088 L
.50048 .50084 L
.50046 .50079 L
.50043 .50075 L
.50041 .5007 L
Mistroke
.50038 .50067 L
.50036 .50063 L
.50034 .50059 L
.50032 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.50019 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50016 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
Mistroke
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.58068 .74652 m
.57865 .72875 L
s
% Start of user PostScript
2.4204613 7.395572 2.3595246 6.8623754 MAarrowhead1
% End of user PostScript
1 .158 0 r
.57641 .71251 m
.57401 .69766 L
s
% Start of user PostScript
2.2922698 6.3753302 2.2203373 5.9296548 MAarrowhead1
% End of user PostScript
1 .473 0 r
.5559 .62229 m
.55339 .61455 L
s
% Start of user PostScript
1.6768542 3.6686475 1.6017173 3.4364737 MAarrowhead1
% End of user PostScript
1 .788 0 r
.53785 .57365 m
.53594 .56927 L
s
% Start of user PostScript
1.1354399 2.2094998 1.0783484 2.0781909 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52479 .54551 m
.52348 .5429 L
s
% Start of user PostScript
0.74365806 1.3652286 0.70441297 1.2869507 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51599 .5285 m
.51512 .5269 L
s
% Start of user PostScript
0.47955308 0.85513463 0.45367443 0.80703731 MAarrowhead1
% End of user PostScript
.266 1 0 r
.51023 .51798 m
.50967 .51698 L
s
% Start of user PostScript
0.30692907 0.53940997 0.29018708 0.50937155 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50652 .51138 m
.50617 .51075 L
s
% Start of user PostScript
0.19571975 0.34147306 0.18498746 0.32255355 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50415 .50722 m
.50392 .50682 L
s
% Start of user PostScript
0.12457626 0.21655938 0.11772726 0.2045915 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50264 .50458 m
.5025 .50433 L
s
% Start of user PostScript
0.079220833 0.13746459 0.074859736 0.12987756 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50168 .50291 m
.50159 .50275 L
s
% Start of user PostScript
0.050355349 0.087297493 0.047581495 0.082482426 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50107 .50185 m
.50101 .50175 L
s
% Start of user PostScript
0.032000218 0.055451256 0.030236895 0.052393721 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50068 .50117 m
.50064 .50111 L
s
% Start of user PostScript
0.020333438 0.035226573 0.019212814 0.033284523 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50043 .50075 m
.50041 .5007 L
s
% Start of user PostScript
0.012919449 0.022379692 0.01220737 0.021145994 MAarrowhead1
% End of user PostScript
.534 1 0 r
.69151 .6615 m
.6771 .65927 L
.664 .65627 L
.65207 .65266 L
.64118 .64859 L
.63123 .64416 L
.62211 .63947 L
.61375 .63461 L
.60607 .62963 L
.599 .62461 L
.59248 .61958 L
.58647 .61458 L
.5809 .60964 L
.57575 .60479 L
.57098 .60005 L
.56655 .59543 L
.56243 .59095 L
.5586 .58661 L
.55504 .58242 L
.55171 .57838 L
.54861 .5745 L
.54571 .57077 L
.543 .5672 L
.54046 .56378 L
.53809 .56051 L
.53587 .55739 L
.53378 .55441 L
.53183 .55158 L
.52999 .54887 L
.52827 .5463 L
.52665 .54385 L
.52513 .54152 L
.5237 .53931 L
.52235 .53721 L
.52109 .53522 L
.5199 .53333 L
.51877 .53154 L
.51772 .52984 L
.51672 .52823 L
.51578 .5267 L
.5149 .52525 L
.51406 .52388 L
.51328 .52259 L
.51254 .52136 L
.51184 .52019 L
.51118 .51909 L
.51056 .51805 L
.50997 .51706 L
.50942 .51613 L
.50889 .51525 L
Mistroke
.5084 .51442 L
.50793 .51363 L
.50749 .51288 L
.50708 .51217 L
.50669 .51151 L
.50632 .51087 L
.50597 .51028 L
.50564 .50971 L
.50532 .50918 L
.50503 .50868 L
.50475 .5082 L
.50449 .50775 L
.50424 .50732 L
.50401 .50692 L
.50379 .50654 L
.50358 .50618 L
.50338 .50584 L
.50319 .50552 L
.50302 .50521 L
.50285 .50493 L
.50269 .50466 L
.50254 .5044 L
.5024 .50416 L
.50227 .50393 L
.50215 .50371 L
.50203 .50351 L
.50192 .50331 L
.50181 .50313 L
.50171 .50296 L
.50162 .5028 L
.50153 .50264 L
.50144 .5025 L
.50136 .50236 L
.50129 .50223 L
.50122 .50211 L
.50115 .50199 L
.50109 .50188 L
.50103 .50178 L
.50097 .50168 L
.50092 .50159 L
.50087 .5015 L
.50082 .50142 L
.50077 .50134 L
.50073 .50126 L
.50069 .50119 L
.50065 .50113 L
.50062 .50107 L
.50058 .50101 L
.50055 .50095 L
.50052 .5009 L
Mistroke
.50049 .50085 L
.50046 .5008 L
.50044 .50076 L
.50041 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .50061 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50023 .50041 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50016 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
Mistroke
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.69151 .6615 m
.6771 .65927 L
s
% Start of user PostScript
5.7452884 4.8449529 5.3130579 4.7780184 MAarrowhead1
% End of user PostScript
1 .158 0 r
.664 .65627 m
.65207 .65266 L
s
% Start of user PostScript
4.9200783 4.6880553 4.5621266 4.5799 MAarrowhead1
% End of user PostScript
1 .473 0 r
.59248 .61958 m
.58647 .61458 L
s
% Start of user PostScript
2.7744819 3.5872654 2.5939816 3.4372784 MAarrowhead1
% End of user PostScript
1 .788 0 r
.55504 .58242 m
.55171 .57838 L
s
% Start of user PostScript
1.6510641 2.4725879 1.5512951 2.3514687 MAarrowhead1
% End of user PostScript
.897 1 0 r
.53378 .55441 m
.53183 .55158 L
s
% Start of user PostScript
1.0135019 1.6324135 0.95485258 1.5472544 MAarrowhead1
% End of user PostScript
.581 1 0 r
.52109 .53522 m
.5199 .53333 L
s
% Start of user PostScript
0.63264359 1.0566771 0.59688683 0.99996384 MAarrowhead1
% End of user PostScript
.266 1 0 r
.51328 .52259 m
.51254 .52136 L
s
% Start of user PostScript
0.39836197 0.67756013 0.37612263 0.64069902 MAarrowhead1
% End of user PostScript
0 1 .049 r
.5084 .51442 m
.50793 .51363 L
s
% Start of user PostScript
0.25195773 0.43245585 0.23798016 0.40877304 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50532 .50918 m
.50503 .50868 L
s
% Start of user PostScript
0.15971774 0.27538475 0.15088551 0.26025435 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50338 .50584 m
.50319 .50552 L
s
% Start of user PostScript
0.10136059 0.17516304 0.09576444 0.16552345 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50215 .50371 m
.50203 .50351 L
s
% Start of user PostScript
0.064362223 0.11135196 0.060811626 0.10521906 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50136 .50236 m
.50129 .50223 L
s
% Start of user PostScript
0.040880492 0.070766833 0.038626195 0.066867651 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50087 .5015 m
.50082 .50142 L
s
% Start of user PostScript
0.025969455 0.044967624 0.024537695 0.042489451 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50055 .50095 m
.50052 .5009 L
s
% Start of user PostScript
0.016498346 0.028571908 0.015588844 0.026997147 MAarrowhead1
% End of user PostScript
1 0 .258 r
.49823 .17647 m
.49108 .20686 L
.48529 .2339 L
.48065 .258 L
.477 .27951 L
.47418 .29875 L
.47206 .31597 L
.47053 .33143 L
.4695 .34533 L
.46888 .35785 L
.46859 .36914 L
.4686 .37935 L
.46883 .3886 L
.46925 .39699 L
.46982 .40462 L
.4705 .41156 L
.47129 .4179 L
.47214 .4237 L
.47304 .429 L
.47397 .43387 L
.47493 .43834 L
.4759 .44245 L
.47687 .44624 L
.47784 .44974 L
.47879 .45298 L
.47973 .45597 L
.48064 .45875 L
.48153 .46133 L
.4824 .46372 L
.48324 .46595 L
.48405 .46802 L
.48483 .46995 L
.48558 .47176 L
.4863 .47344 L
.48699 .47502 L
.48765 .47649 L
.48829 .47787 L
.48889 .47916 L
.48947 .48037 L
.49002 .48151 L
.49054 .48258 L
.49104 .48358 L
.49151 .48452 L
.49196 .4854 L
.49239 .48623 L
.4928 .48701 L
.49318 .48775 L
.49355 .48844 L
.49389 .48909 L
.49422 .48971 L
Mistroke
.49454 .49029 L
.49483 .49083 L
.49511 .49135 L
.49538 .49183 L
.49563 .49229 L
.49587 .49272 L
.49609 .49312 L
.4963 .49351 L
.49651 .49387 L
.4967 .49421 L
.49688 .49453 L
.49705 .49483 L
.49721 .49512 L
.49736 .49539 L
.49751 .49565 L
.49764 .49589 L
.49777 .49612 L
.49789 .49633 L
.49801 .49653 L
.49812 .49673 L
.49822 .49691 L
.49832 .49708 L
.49841 .49724 L
.4985 .49739 L
.49858 .49754 L
.49866 .49767 L
.49873 .4978 L
.4988 .49792 L
.49887 .49804 L
.49893 .49815 L
.49899 .49825 L
.49905 .49834 L
.4991 .49844 L
.49915 .49852 L
.4992 .4986 L
.49924 .49868 L
.49928 .49875 L
.49932 .49882 L
.49936 .49889 L
.49939 .49895 L
.49943 .49901 L
.49946 .49906 L
.49949 .49911 L
.49952 .49916 L
.49954 .49921 L
.49957 .49925 L
.49959 .49929 L
.49961 .49933 L
.49964 .49937 L
.49966 .4994 L
Mistroke
.49967 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49952 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49971 L
.49984 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
Mistroke
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.49823 .17647 m
.49108 .20686 L
s
% Start of user PostScript
-0.052996537 -9.7059933 -0.26762548 -8.7941782 MAarrowhead1
% End of user PostScript
1 .158 0 r
.48529 .2339 m
.48065 .258 L
s
% Start of user PostScript
-0.44137932 -7.9829302 -0.58038878 -7.2599894 MAarrowhead1
% End of user PostScript
1 .473 0 r
.46859 .36914 m
.4686 .37935 L
s
% Start of user PostScript
-0.94216998 -3.9257292 -0.94214143 -3.6194356 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47304 .429 m
.47397 .43387 L
s
% Start of user PostScript
-0.80888694 -2.1299603 -0.7807942 -1.9839854 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48064 .45875 m
.48153 .46133 L
s
% Start of user PostScript
-0.58074448 -1.2375141 -0.55397452 -1.1602222 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48699 .47502 m
.48765 .47649 L
s
% Start of user PostScript
-0.390207 -0.74946632 -0.37036388 -0.70526985 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49151 .48452 m
.49196 .4854 L
s
% Start of user PostScript
-0.25466332 -0.46448062 -0.24115524 -0.43796109 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49454 .49029 m
.49483 .49083 L
s
% Start of user PostScript
-0.16394296 -0.29139056 -0.1550744 -0.27503741 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49651 .49387 m
.4967 .49421 L
s
% Start of user PostScript
-0.10484147 -0.18395279 -0.099115918 -0.17372049 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49777 .49612 m
.49789 .49633 L
s
% Start of user PostScript
-0.066826859 -0.11649811 -0.06316026 -0.11004717 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49858 .49754 m
.49866 .49767 L
s
% Start of user PostScript
-0.042526806 -0.073897109 -0.04018807 -0.069814455 MAarrowhead1
% End of user PostScript
0 .69 1 r
.4991 .49844 m
.49915 .49852 L
s
% Start of user PostScript
-0.027040986 -0.046912158 -0.025552167 -0.044323328 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49943 .49901 m
.49946 .49906 L
s
% Start of user PostScript
-0.017187257 -0.029793289 -0.016240418 -0.0281501 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49964 .49937 m
.49966 .4994 L
s
% Start of user PostScript
-0.010922016 -0.018925141 -0.010320154 -0.017881663 MAarrowhead1
% End of user PostScript
0 .347 1 r
.30876 .45756 m
.32583 .44858 L
.3411 .44161 L
.35476 .43633 L
.36702 .43247 L
.37803 .42981 L
.38795 .42815 L
.39689 .42732 L
.40497 .42718 L
.41229 .4276 L
.41892 .42847 L
.42495 .42971 L
.43044 .43125 L
.43544 .43301 L
.44001 .43494 L
.4442 .43701 L
.44804 .43916 L
.45156 .44137 L
.4548 .44361 L
.45779 .44586 L
.46055 .4481 L
.46309 .45032 L
.46545 .4525 L
.46763 .45463 L
.46966 .45672 L
.47154 .45874 L
.47329 .4607 L
.47492 .46259 L
.47644 .46442 L
.47786 .46617 L
.47918 .46786 L
.48042 .46948 L
.48157 .47103 L
.48266 .47251 L
.48367 .47393 L
.48462 .47528 L
.48551 .47656 L
.48635 .47779 L
.48713 .47896 L
.48787 .48007 L
.48856 .48113 L
.48921 .48213 L
.48983 .48308 L
.4904 .48399 L
.49095 .48485 L
.49146 .48566 L
.49194 .48643 L
.49239 .48717 L
.49282 .48786 L
.49322 .48852 L
Mistroke
.4936 .48914 L
.49396 .48973 L
.4943 .49029 L
.49461 .49082 L
.49491 .49132 L
.4952 .49179 L
.49546 .49224 L
.49572 .49266 L
.49595 .49306 L
.49618 .49344 L
.49639 .4938 L
.49659 .49414 L
.49678 .49446 L
.49696 .49477 L
.49713 .49505 L
.49729 .49533 L
.49744 .49558 L
.49758 .49583 L
.49771 .49605 L
.49784 .49627 L
.49796 .49648 L
.49807 .49667 L
.49818 .49685 L
.49828 .49703 L
.49837 .49719 L
.49846 .49734 L
.49855 .49749 L
.49863 .49763 L
.4987 .49776 L
.49878 .49788 L
.49884 .498 L
.49891 .49811 L
.49897 .49821 L
.49902 .49831 L
.49908 .4984 L
.49913 .49849 L
.49918 .49858 L
.49922 .49865 L
.49927 .49873 L
.49931 .4988 L
.49934 .49886 L
.49938 .49893 L
.49941 .49899 L
.49945 .49904 L
.49948 .49909 L
.49951 .49914 L
.49953 .49919 L
.49956 .49924 L
.49958 .49928 L
.49961 .49932 L
Mistroke
.49963 .49936 L
.49965 .49939 L
.49967 .49942 L
.49969 .49946 L
.4997 .49949 L
.49972 .49951 L
.49974 .49954 L
.49975 .49957 L
.49976 .49959 L
.49978 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49983 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
Mistroke
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.30876 .45756 m
.32583 .44858 L
s
% Start of user PostScript
-5.7372754 -1.2731899 -5.2249788 -1.5425794 MAarrowhead1
% End of user PostScript
1 .158 0 r
.3411 .44161 m
.35476 .43633 L
s
% Start of user PostScript
-4.7670948 -1.7517848 -4.3571296 -1.9101763 MAarrowhead1
% End of user PostScript
1 .473 0 r
.41892 .42847 m
.42495 .42971 L
s
% Start of user PostScript
-2.4323967 -2.1458843 -2.2515443 -2.1086179 MAarrowhead1
% End of user PostScript
1 .788 0 r
.4548 .44361 m
.45779 .44586 L
s
% Start of user PostScript
-1.3559031 -1.6916034 -1.2662999 -1.6241054 MAarrowhead1
% End of user PostScript
.897 1 0 r
.47329 .4607 m
.47492 .46259 L
s
% Start of user PostScript
-0.80124427 -1.1790523 -0.75235519 -1.1222427 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48367 .47393 m
.48462 .47528 L
s
% Start of user PostScript
-0.48992882 -0.78224806 -0.46142231 -0.74172933 MAarrowhead1
% End of user PostScript
.266 1 0 r
.48983 .48308 m
.4904 .48399 L
s
% Start of user PostScript
-0.30519193 -0.50752874 -0.28789237 -0.48037925 MAarrowhead1
% End of user PostScript
0 1 .049 r
.4936 .48914 m
.49396 .48973 L
s
% Start of user PostScript
-0.19196923 -0.32580201 -0.18123606 -0.30810591 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49595 .49306 m
.49618 .49344 L
s
% Start of user PostScript
-0.12135228 -0.20805972 -0.11461502 -0.19667462 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49744 .49558 m
.49758 .49583 L
s
% Start of user PostScript
-0.07690522 -0.13252733 -0.072650797 -0.12524876 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49837 .49719 m
.49846 .49734 L
s
% Start of user PostScript
-0.048799204 -0.084307752 -0.046104464 -0.079669023 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49897 .49821 m
.49902 .49831 L
s
% Start of user PostScript
-0.030984541 -0.053598494 -0.029275087 -0.050646752 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49934 .49886 m
.49938 .49893 L
s
% Start of user PostScript
-0.019679558 -0.034064288 -0.018594304 -0.032187471 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49958 .49928 m
.49961 .49932 L
s
% Start of user PostScript
-0.012501285 -0.021645963 -0.011812042 -0.020453079 MAarrowhead1
% End of user PostScript
0 1 .016 r
.3871 .4223 m
.39599 .42197 L
.40403 .42226 L
.41133 .42308 L
.41795 .42432 L
.42397 .42588 L
.42947 .42771 L
.43448 .42974 L
.43907 .43192 L
.44328 .43421 L
.44714 .43656 L
.45069 .43896 L
.45396 .44137 L
.45697 .44377 L
.45976 .44615 L
.46234 .4485 L
.46472 .4508 L
.46694 .45305 L
.46899 .45523 L
.4709 .45735 L
.47268 .4594 L
.47434 .46137 L
.47589 .46327 L
.47733 .4651 L
.47868 .46685 L
.47994 .46853 L
.48112 .47014 L
.48222 .47167 L
.48326 .47314 L
.48423 .47453 L
.48514 .47587 L
.486 .47713 L
.4868 .47834 L
.48756 .47949 L
.48826 .48058 L
.48893 .48161 L
.48956 .48259 L
.49015 .48353 L
.49071 .48441 L
.49123 .48525 L
.49172 .48605 L
.49219 .4868 L
.49263 .48752 L
.49304 .48819 L
.49343 .48883 L
.4938 .48944 L
.49414 .49002 L
.49447 .49056 L
.49478 .49107 L
.49507 .49156 L
Mistroke
.49534 .49202 L
.4956 .49246 L
.49584 .49287 L
.49608 .49326 L
.49629 .49363 L
.4965 .49398 L
.49669 .49431 L
.49688 .49462 L
.49705 .49492 L
.49721 .4952 L
.49737 .49546 L
.49751 .49571 L
.49765 .49595 L
.49778 .49617 L
.4979 .49638 L
.49802 .49658 L
.49813 .49677 L
.49823 .49694 L
.49833 .49711 L
.49842 .49727 L
.49851 .49742 L
.49859 .49756 L
.49867 .4977 L
.49874 .49782 L
.49881 .49794 L
.49888 .49806 L
.49894 .49816 L
.499 .49827 L
.49905 .49836 L
.4991 .49845 L
.49915 .49854 L
.4992 .49862 L
.49924 .49869 L
.49929 .49877 L
.49933 .49883 L
.49936 .4989 L
.4994 .49896 L
.49943 .49902 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49922 L
.49957 .49926 L
.4996 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.4997 .49947 L
.49971 .4995 L
Mistroke
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.4998 .49965 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
Mistroke
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.3871 .4223 m
.39599 .42197 L
s
% Start of user PostScript
-3.3869932 -2.3309664 -3.1202969 -2.3410459 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40403 .42226 m
.41133 .42308 L
s
% Start of user PostScript
-2.8789819 -2.3320704 -2.6602232 -2.30756 MAarrowhead1
% End of user PostScript
1 .473 0 r
.44714 .43656 m
.45069 .43896 L
s
% Start of user PostScript
-1.5857959 -1.9031527 -1.4792974 -1.8313087 MAarrowhead1
% End of user PostScript
1 .788 0 r
.46899 .45523 m
.4709 .45735 L
s
% Start of user PostScript
-0.93019538 -1.3430937 -0.87285631 -1.2795663 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48112 .47014 m
.48222 .47167 L
s
% Start of user PostScript
-0.56642 -0.89588787 -0.53327072 -0.84984382 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48826 .48058 m
.48893 .48161 L
s
% Start of user PostScript
-0.35206232 -0.5827216 -0.33204368 -0.5516621 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49263 .48752 m
.49304 .48819 L
s
% Start of user PostScript
-0.22119898 -0.37452625 -0.20881156 -0.35421899 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49534 .49202 m
.4956 .49246 L
s
% Start of user PostScript
-0.13974874 -0.23931853 -0.13198375 -0.22623411 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49705 .49492 m
.49721 .4952 L
s
% Start of user PostScript
-0.08853784 -0.15248343 -0.083637864 -0.14411239 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49813 .49677 m
.49823 .49694 L
s
% Start of user PostScript
-0.056172293 -0.097017245 -0.053069757 -0.091680345 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49881 .49794 m
.49888 .49806 L
s
% Start of user PostScript
-0.035663385 -0.061683081 -0.033695587 -0.058286467 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49924 .49869 m
.49929 .49877 L
s
% Start of user PostScript
-0.022650451 -0.039203858 -0.021401297 -0.037043983 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49952 .49917 m
.49955 .49922 L
s
% Start of user PostScript
-0.014388256 -0.024912333 -0.013594956 -0.02353948 MAarrowhead1
% End of user PostScript
0 .06 1 r
.4997 .49947 m
.49971 .4995 L
s
% Start of user PostScript
-0.0091406698 -0.01582929 -0.0086367604 -0.014956869 MAarrowhead1
% End of user PostScript
.83 1 0 r
.60383 .71936 m
.599 .70572 L
.59432 .69304 L
.58979 .68123 L
.58542 .67024 L
.58122 .65998 L
.57718 .65041 L
.5733 .64146 L
.56959 .63309 L
.56604 .62527 L
.56265 .61793 L
.55941 .61106 L
.55632 .60462 L
.55337 .59858 L
.55057 .5929 L
.5479 .58757 L
.54537 .58257 L
.54296 .57786 L
.54067 .57343 L
.53849 .56927 L
.53643 .56535 L
.53447 .56166 L
.53262 .55818 L
.53086 .55491 L
.52919 .55182 L
.52761 .54892 L
.52611 .54618 L
.52469 .5436 L
.52335 .54116 L
.52208 .53886 L
.52088 .5367 L
.51974 .53465 L
.51866 .53272 L
.51764 .53091 L
.51668 .52919 L
.51576 .52757 L
.5149 .52604 L
.51409 .52459 L
.51331 .52323 L
.51258 .52194 L
.51189 .52073 L
.51124 .51958 L
.51062 .5185 L
.51004 .51747 L
.50949 .51651 L
.50897 .51559 L
.50847 .51473 L
.50801 .51392 L
.50757 .51315 L
.50715 .51242 L
Mistroke
.50676 .51174 L
.50639 .51109 L
.50604 .51048 L
.5057 .5099 L
.50539 .50935 L
.50509 .50884 L
.50481 .50835 L
.50455 .50789 L
.5043 .50745 L
.50406 .50704 L
.50384 .50665 L
.50363 .50629 L
.50343 .50594 L
.50324 .50561 L
.50306 .5053 L
.50289 .50501 L
.50273 .50473 L
.50258 .50447 L
.50244 .50423 L
.5023 .50399 L
.50218 .50377 L
.50206 .50356 L
.50194 .50337 L
.50184 .50318 L
.50174 .50301 L
.50164 .50284 L
.50155 .50268 L
.50146 .50254 L
.50138 .5024 L
.50131 .50226 L
.50123 .50214 L
.50117 .50202 L
.5011 .50191 L
.50104 .5018 L
.50098 .50171 L
.50093 .50161 L
.50088 .50152 L
.50083 .50144 L
.50078 .50136 L
.50074 .50128 L
.5007 .50121 L
.50066 .50115 L
.50063 .50108 L
.50059 .50102 L
.50056 .50097 L
.50053 .50091 L
.5005 .50086 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
Mistroke
.5004 .50069 L
.50038 .50065 L
.50035 .50061 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
Mistroke
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.60383 .71936 m
.599 .70572 L
s
% Start of user PostScript
3.1149483 6.5808025 2.970075 6.1715948 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59432 .69304 m
.58979 .68123 L
s
% Start of user PostScript
2.8296057 5.7911466 2.6937759 5.4370445 MAarrowhead1
% End of user PostScript
1 .473 0 r
.56265 .61793 m
.55941 .61106 L
s
% Start of user PostScript
1.8793723 3.5380284 1.7821794 3.3319216 MAarrowhead1
% End of user PostScript
1 .788 0 r
.54067 .57343 m
.53849 .56927 L
s
% Start of user PostScript
1.2199774 2.2029489 1.1547646 2.0779966 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52611 .54618 m
.52469 .5436 L
s
% Start of user PostScript
0.78334466 1.3853563 0.74081201 1.3078742 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51668 .52919 m
.51576 .52757 L
s
% Start of user PostScript
0.5003113 0.87564139 0.47293887 0.82701914 MAarrowhead1
% End of user PostScript
.266 1 0 r
.51062 .5185 m
.51004 .51747 L
s
% Start of user PostScript
0.31870152 0.55489162 0.30119955 0.52419222 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50676 .51174 m
.50639 .51109 L
s
% Start of user PostScript
0.20274929 0.35208866 0.19159423 0.33264515 MAarrowhead1
% End of user PostScript
0 1 .364 r
.5043 .50745 m
.50406 .50704 L
s
% Start of user PostScript
0.12889943 0.22355162 0.12180091 0.21121775 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50273 .50473 m
.50258 .50447 L
s
% Start of user PostScript
0.081922085 0.14198577 0.077408527 0.1341557 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50174 .50301 m
.50164 .50284 L
s
% Start of user PostScript
0.052057131 0.090195008 0.049188339 0.085222188 MAarrowhead1
% End of user PostScript
0 .69 1 r
.5011 .50191 m
.50104 .5018 L
s
% Start of user PostScript
0.033076844 0.057300121 0.031253817 0.054141297 MAarrowhead1
% End of user PostScript
0 .375 1 r
.5007 .50121 m
.50066 .50115 L
s
% Start of user PostScript
0.021016007 0.036403762 0.019857645 0.034397023 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50045 .50077 m
.50042 .50073 L
s
% Start of user PostScript
0.013352651 0.023128414 0.012616657 0.021853509 MAarrowhead1
% End of user PostScript
.432 1 0 r
.4339 .32787 m
.43624 .33962 L
.43863 .35042 L
.44103 .36036 L
.44343 .36953 L
.44582 .37799 L
.44817 .38582 L
.45047 .39307 L
.45272 .39979 L
.45491 .40603 L
.45704 .41184 L
.4591 .41723 L
.46108 .42226 L
.46299 .42695 L
.46483 .43133 L
.46659 .43542 L
.46828 .43924 L
.4699 .44282 L
.47144 .44617 L
.47292 .44931 L
.47433 .45225 L
.47567 .45501 L
.47694 .4576 L
.47816 .46004 L
.47932 .46232 L
.48041 .46447 L
.48146 .46649 L
.48245 .46839 L
.48339 .47018 L
.48428 .47187 L
.48513 .47345 L
.48593 .47495 L
.48669 .47636 L
.48741 .47768 L
.48809 .47893 L
.48874 .48011 L
.48935 .48122 L
.48993 .48227 L
.49048 .48326 L
.491 .48419 L
.49149 .48507 L
.49195 .4859 L
.49239 .48668 L
.49281 .48742 L
.4932 .48812 L
.49358 .48878 L
.49393 .4894 L
.49426 .48999 L
.49458 .49054 L
.49487 .49107 L
Mistroke
.49515 .49156 L
.49542 .49203 L
.49567 .49247 L
.49591 .49289 L
.49613 .49328 L
.49635 .49365 L
.49655 .494 L
.49674 .49433 L
.49692 .49465 L
.49709 .49494 L
.49725 .49522 L
.4974 .49549 L
.49754 .49573 L
.49768 .49597 L
.49781 .49619 L
.49793 .4964 L
.49804 .4966 L
.49815 .49679 L
.49825 .49697 L
.49835 .49713 L
.49844 .49729 L
.49852 .49744 L
.4986 .49758 L
.49868 .49772 L
.49875 .49784 L
.49882 .49796 L
.49889 .49807 L
.49895 .49818 L
.49901 .49828 L
.49906 .49837 L
.49911 .49846 L
.49916 .49855 L
.49921 .49863 L
.49925 .4987 L
.49929 .49878 L
.49933 .49884 L
.49937 .49891 L
.4994 .49897 L
.49944 .49902 L
.49947 .49908 L
.4995 .49913 L
.49952 .49918 L
.49955 .49922 L
.49958 .49927 L
.4996 .49931 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49945 L
.4997 .49948 L
Mistroke
.49971 .49951 L
.49973 .49953 L
.49975 .49956 L
.49976 .49958 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
Mistroke
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.4339 .32787 m
.43624 .33962 L
s
% Start of user PostScript
-1.9828556 -5.1638712 -1.9126924 -4.8114492 MAarrowhead1
% End of user PostScript
1 .158 0 r
.43863 .35042 m
.44103 .36036 L
s
% Start of user PostScript
-1.8411719 -4.4875026 -1.7690665 -4.1892537 MAarrowhead1
% End of user PostScript
1 .473 0 r
.45704 .41184 m
.4591 .41723 L
s
% Start of user PostScript
-1.2888147 -2.6449238 -1.2271106 -2.48296 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47144 .44617 m
.47292 .44931 L
s
% Start of user PostScript
-0.85666728 -1.6149154 -0.81241373 -1.52076 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48146 .46649 m
.48245 .46839 L
s
% Start of user PostScript
-0.55629845 -1.0052052 -0.52657742 -0.94816389 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48809 .47893 m
.48874 .48011 L
s
% Start of user PostScript
-0.35726035 -0.63203416 -0.33786731 -0.59667665 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49239 .48668 m
.49281 .48742 L
s
% Start of user PostScript
-0.22819682 -0.39945618 -0.21571353 -0.37727272 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49515 .49156 m
.49542 .49203 L
s
% Start of user PostScript
-0.14536905 -0.25312368 -0.13738638 -0.23911877 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49692 .49465 m
.49709 .49494 L
s
% Start of user PostScript
-0.092481826 -0.16060812 -0.087393722 -0.15173854 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49804 .4966 m
.49815 .49679 L
s
% Start of user PostScript
-0.058796658 -0.10197382 -0.055558765 -0.096347599 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49875 .49784 m
.49882 .49796 L
s
% Start of user PostScript
-0.037368439 -0.064766942 -0.035309613 -0.061195222 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49921 .49863 m
.49925 .4987 L
s
% Start of user PostScript
-0.02374572 -0.041142428 -0.022437133 -0.038874069 MAarrowhead1
% End of user PostScript
0 .375 1 r
.4995 .49913 m
.49952 .49918 L
s
% Start of user PostScript
-0.015087933 -0.0261374 -0.014256365 -0.024696502 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49968 .49945 m
.4997 .49948 L
s
% Start of user PostScript
-0.0095864142 -0.016605533 -0.0090580297 -0.015690161 MAarrowhead1
% End of user PostScript
1 .237 0 r
.69657 .23782 m
.6721 .27589 L
.6508 .30871 L
.63225 .33699 L
.61609 .36134 L
.602 .3823 L
.58972 .40032 L
.579 .41581 L
.56964 .42912 L
.56147 .44053 L
.55433 .45031 L
.54808 .45869 L
.54261 .46585 L
.53782 .47196 L
.53362 .47717 L
.52993 .48161 L
.52669 .48537 L
.52384 .48856 L
.52134 .49126 L
.51913 .49353 L
.51718 .49544 L
.51545 .49704 L
.51393 .49837 L
.51258 .49947 L
.51138 .50037 L
.51031 .50111 L
.50937 .5017 L
.50852 .50218 L
.50777 .50255 L
.50709 .50284 L
.50649 .50305 L
.50594 .5032 L
.50546 .50331 L
.50502 .50336 L
.50462 .50339 L
.50426 .50338 L
.50394 .50335 L
.50364 .5033 L
.50337 .50324 L
.50313 .50316 L
.5029 .50308 L
.5027 .50298 L
.50251 .50288 L
.50234 .50278 L
.50218 .50268 L
.50204 .50258 L
.5019 .50247 L
.50178 .50237 L
.50167 .50226 L
.50156 .50216 L
Mistroke
.50146 .50207 L
.50137 .50197 L
.50129 .50188 L
.50121 .50179 L
.50113 .5017 L
.50107 .50162 L
.501 .50154 L
.50094 .50146 L
.50089 .50139 L
.50083 .50132 L
.50078 .50125 L
.50074 .50118 L
.5007 .50112 L
.50066 .50106 L
.50062 .50101 L
.50058 .50095 L
.50055 .5009 L
.50052 .50086 L
.50049 .50081 L
.50046 .50077 L
.50043 .50073 L
.50041 .50069 L
.50039 .50065 L
.50037 .50062 L
.50034 .50058 L
.50033 .50055 L
.50031 .50052 L
.50029 .50049 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .50039 L
.50022 .50037 L
.50021 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
Mistroke
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
Mistroke
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.69657 .23782 m
.6721 .27589 L
s
% Start of user PostScript
5.8971935 -7.865475 5.1630246 -6.7233241 MAarrowhead1
% End of user PostScript
1 .158 0 r
.6508 .30871 m
.63225 .33699 L
s
% Start of user PostScript
4.5239428 -5.7387326 3.9674149 -4.8903854 MAarrowhead1
% End of user PostScript
1 .473 0 r
.55433 .45031 m
.54808 .45869 L
s
% Start of user PostScript
1.6298353 -1.4906641 1.442388 -1.2394336 MAarrowhead1
% End of user PostScript
1 .788 0 r
.52134 .49126 m
.51913 .49353 L
s
% Start of user PostScript
0.64005826 -0.26214977 0.57375977 -0.19397561 MAarrowhead1
% End of user PostScript
.897 1 0 r
.50937 .5017 m
.50852 .50218 L
s
% Start of user PostScript
0.28099347 0.051100025 0.2556481 0.065355534 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50462 .50339 m
.50426 .50338 L
s
% Start of user PostScript
0.13859461 0.10163152 0.1278229 0.10145458 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50251 .50288 m
.50234 .50278 L
s
% Start of user PostScript
0.075365523 0.086549989 0.07021594 0.083503213 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50146 .50207 m
.50137 .50197 L
s
% Start of user PostScript
0.043850524 0.061973368 0.041117132 0.059105152 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50089 .50139 m
.50083 .50132 L
s
% Start of user PostScript
0.02657872 0.041593839 0.025013156 0.039475221 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50055 .5009 m
.50052 .50086 L
s
% Start of user PostScript
0.016479409 0.027131661 0.015539103 0.025691449 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50034 .50058 m
.50033 .50055 L
s
% Start of user PostScript
0.010340683 0.017462044 0.009760541 0.016517093 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50022 .50037 m
.50021 .50035 L
s
% Start of user PostScript
0.0065287634 0.011165614 0.0061656641 0.010555737 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50014 .50024 m
.50013 .50022 L
s
% Start of user PostScript
0.004134939 0.0071166299 0.0039059908 0.0067261272 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50009 .50015 m
.50008 .50014 L
s
% Start of user PostScript
0.0026229534 0.004528695 0.002478047 0.0042796315 MAarrowhead1
% End of user PostScript
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0333333 0.5 0.0333333 [
[0 .4875 -18.4688 -20 ]
[0 .4875 18.4688 0 ]
[.16667 .4875 -18.4688 -20 ]
[.16667 .4875 18.4688 0 ]
[.33333 .4875 -13.4688 -20 ]
[.33333 .4875 13.4688 0 ]
[.66667 .4875 -7 -20 ]
[.66667 .4875 7 0 ]
[.83333 .4875 -12 -20 ]
[.83333 .4875 12 0 ]
[1 .4875 -12 -20 ]
[1 .4875 12 0 ]
[.4875 0 -36.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .16667 -36.9375 -10 ]
[.4875 .16667 0 10 ]
[.4875 .33333 -26.9375 -10 ]
[.4875 .33333 0 10 ]
[.4875 .66667 -14 -10 ]
[.4875 .66667 0 10 ]
[.4875 .83333 -24 -10 ]
[.4875 .83333 0 10 ]
[.4875 1 -24 -10 ]
[.4875 1 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.16667 .5 m
.16667 .50625 L
s
gsave
.16667 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.33333 .5 m
.33333 .50625 L
s
gsave
.33333 .4875 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.66667 .5 m
.66667 .50625 L
s
gsave
.66667 .4875 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.83333 .5 m
.83333 .50625 L
s
gsave
.83333 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.5 .16667 m
.50625 .16667 L
s
gsave
.4875 .16667 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 .33333 m
.50625 .33333 L
s
gsave
.4875 .33333 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .66667 m
.50625 .66667 L
s
gsave
.4875 .66667 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .83333 m
.50625 .83333 L
s
gsave
.4875 .83333 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.01 w
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 .147 1 r
.5 Mabswid
.19618 .63683 m
.22793 .6033 L
.25593 .57509 L
.28065 .55144 L
.3025 .5317 L
.32184 .5153 L
.33899 .50176 L
.35422 .49067 L
.36776 .48165 L
.37981 .4744 L
.39057 .46866 L
.40018 .46419 L
.40878 .46079 L
.4165 .45829 L
.42343 .45656 L
.42967 .45546 L
.4353 .45489 L
.44038 .45475 L
.44498 .45497 L
.44915 .45548 L
.45294 .45623 L
.45638 .45716 L
.45953 .45824 L
.4624 .45943 L
.46503 .46071 L
.46744 .46204 L
.46965 .46341 L
.47168 .4648 L
.47356 .4662 L
.47529 .46759 L
.47688 .46897 L
.47836 .47033 L
.47973 .47166 L
.481 .47295 L
.48218 .47421 L
.48328 .47544 L
.4843 .47662 L
.48525 .47776 L
.48614 .47885 L
.48697 .47991 L
.48774 .48092 L
.48847 .48189 L
.48914 .48281 L
.48978 .4837 L
.49037 .48454 L
.49093 .48534 L
.49146 .48611 L
.49195 .48684 L
.49241 .48754 L
.49284 .4882 L
Mistroke
.49325 .48882 L
.49363 .48942 L
.494 .48998 L
.49434 .49052 L
.49466 .49103 L
.49496 .49151 L
.49524 .49197 L
.49551 .49241 L
.49576 .49282 L
.496 .49321 L
.49622 .49358 L
.49643 .49393 L
.49663 .49426 L
.49682 .49457 L
.497 .49487 L
.49716 .49515 L
.49732 .49541 L
.49747 .49566 L
.49761 .4959 L
.49774 .49612 L
.49787 .49634 L
.49799 .49654 L
.4981 .49673 L
.4982 .49691 L
.4983 .49708 L
.4984 .49724 L
.49849 .49739 L
.49857 .49753 L
.49865 .49767 L
.49872 .4978 L
.49879 .49792 L
.49886 .49803 L
.49892 .49814 L
.49898 .49824 L
.49904 .49834 L
.49909 .49843 L
.49914 .49852 L
.49919 .4986 L
.49923 .49868 L
.49928 .49875 L
.49932 .49882 L
.49935 .49888 L
.49939 .49894 L
.49942 .499 L
.49946 .49906 L
.49949 .49911 L
.49951 .49916 L
.49954 .4992 L
.49957 .49925 L
.49959 .49929 L
Mistroke
.49961 .49933 L
.49963 .49937 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .4997 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49988 .49978 L
.49988 .4998 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
Mistroke
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .063 1 r
.38875 .69206 m
.40359 .66639 L
.41644 .64415 L
.42759 .62489 L
.43724 .60819 L
.44561 .59373 L
.45286 .5812 L
.45914 .57034 L
.46459 .56093 L
.46931 .55278 L
.4734 .54572 L
.47694 .5396 L
.48001 .5343 L
.48267 .52971 L
.48498 .52573 L
.48698 .52228 L
.48871 .5193 L
.49021 .51671 L
.49151 .51447 L
.49264 .51253 L
.49362 .51085 L
.49447 .50939 L
.4952 .50813 L
.49584 .50704 L
.49639 .50609 L
.49687 .50527 L
.49728 .50456 L
.49764 .50395 L
.49795 .50341 L
.49822 .50295 L
.49846 .50255 L
.49866 .50221 L
.49884 .50191 L
.49899 .50165 L
.49912 .50143 L
.49924 .50123 L
.49934 .50106 L
.49942 .50092 L
.4995 .50079 L
.49956 .50068 L
.49962 .50059 L
.49967 .50051 L
.49971 .50044 L
.49975 .50038 L
.49978 .50033 L
.49981 .50028 L
.49983 .50024 L
.49986 .50021 L
.49987 .50018 L
.49989 .50015 L
Mistroke
.4999 .50013 L
.49992 .50011 L
.49993 .50009 L
.49994 .50008 L
.49994 .50007 L
.49995 .50006 L
.49996 .50005 L
.49996 .50004 L
.49997 .50004 L
.49997 .50003 L
.49997 .50002 L
.49998 .50002 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .719 0 r
.5606 .68264 m
.55902 .66953 L
.55729 .65755 L
.55545 .64658 L
.55354 .63652 L
.55158 .62728 L
.54959 .61877 L
.5476 .61094 L
.54563 .60371 L
.54367 .59702 L
.54175 .59084 L
.53986 .5851 L
.53803 .57978 L
.53625 .57484 L
.53452 .57024 L
.53286 .56596 L
.53125 .56197 L
.52971 .55825 L
.52822 .55477 L
.5268 .55152 L
.52544 .54848 L
.52414 .54563 L
.52289 .54297 L
.5217 .54047 L
.52057 .53813 L
.5195 .53593 L
.51847 .53386 L
.51749 .53192 L
.51657 .5301 L
.51569 .52839 L
.51485 .52677 L
.51405 .52526 L
.5133 .52383 L
.51258 .52248 L
.51191 .52122 L
.51126 .52002 L
.51065 .5189 L
.51008 .51784 L
.50953 .51684 L
.50901 .5159 L
.50852 .51501 L
.50806 .51418 L
.50762 .51339 L
.5072 .51264 L
.50681 .51194 L
.50644 .51127 L
.50609 .51065 L
.50575 .51006 L
.50544 .5095 L
.50514 .50897 L
Mistroke
.50486 .50847 L
.50459 .50801 L
.50434 .50756 L
.5041 .50714 L
.50388 .50675 L
.50366 .50637 L
.50346 .50602 L
.50327 .50569 L
.50309 .50537 L
.50292 .50508 L
.50276 .5048 L
.50261 .50453 L
.50247 .50428 L
.50233 .50405 L
.5022 .50382 L
.50208 .50361 L
.50197 .50341 L
.50186 .50322 L
.50176 .50305 L
.50166 .50288 L
.50157 .50272 L
.50148 .50257 L
.5014 .50243 L
.50132 .50229 L
.50125 .50217 L
.50118 .50205 L
.50112 .50193 L
.50105 .50183 L
.501 .50173 L
.50094 .50163 L
.50089 .50154 L
.50084 .50146 L
.50079 .50138 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50063 .5011 L
.5006 .50104 L
.50057 .50098 L
.50053 .50093 L
.5005 .50087 L
.50048 .50083 L
.50045 .50078 L
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50056 L
.5003 .50052 L
Mistroke
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .5004 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
Mistroke
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .274 r
.46924 .60977 m
.47462 .59732 L
.47922 .58642 L
.48313 .57686 L
.48646 .56847 L
.48929 .56109 L
.49168 .5546 L
.4937 .54889 L
.4954 .54385 L
.49683 .5394 L
.49802 .53547 L
.49901 .53199 L
.49983 .52891 L
.5005 .52617 L
.50104 .52373 L
.50148 .52157 L
.50183 .51963 L
.5021 .5179 L
.50231 .51636 L
.50246 .51497 L
.50257 .51373 L
.50264 .51261 L
.50267 .5116 L
.50268 .51068 L
.50267 .50986 L
.50264 .50911 L
.5026 .50843 L
.50255 .50781 L
.50248 .50725 L
.50241 .50673 L
.50234 .50626 L
.50226 .50583 L
.50218 .50543 L
.50209 .50507 L
.50201 .50473 L
.50193 .50442 L
.50185 .50414 L
.50177 .50387 L
.50169 .50363 L
.50161 .5034 L
.50154 .50319 L
.50146 .50299 L
.50139 .50281 L
.50132 .50264 L
.50126 .50248 L
.5012 .50233 L
.50114 .50219 L
.50108 .50206 L
.50102 .50194 L
.50097 .50183 L
Mistroke
.50092 .50172 L
.50087 .50162 L
.50083 .50153 L
.50078 .50144 L
.50074 .50136 L
.5007 .50128 L
.50067 .50121 L
.50063 .50114 L
.5006 .50107 L
.50056 .50101 L
.50053 .50096 L
.50051 .5009 L
.50048 .50085 L
.50045 .5008 L
.50043 .50076 L
.5004 .50072 L
.50038 .50068 L
.50036 .50064 L
.50034 .5006 L
.50032 .50057 L
.50031 .50054 L
.50029 .50051 L
.50027 .50048 L
.50026 .50045 L
.50024 .50043 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50012 .50022 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
Mistroke
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
Mistroke
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .472 1 r
.62936 .36092 m
.61401 .38282 L
.60061 .40161 L
.58889 .41772 L
.57865 .43151 L
.56968 .44331 L
.56182 .45339 L
.55494 .46198 L
.5489 .4693 L
.54359 .47551 L
.53892 .48078 L
.53482 .48524 L
.5312 .48899 L
.52801 .49215 L
.52519 .49479 L
.5227 .49699 L
.52049 .49882 L
.51853 .50032 L
.51679 .50155 L
.51524 .50254 L
.51386 .50333 L
.51263 .50396 L
.51153 .50444 L
.51054 .50481 L
.50965 .50507 L
.50886 .50525 L
.50814 .50535 L
.5075 .5054 L
.50691 .5054 L
.50638 .50536 L
.5059 .50529 L
.50546 .50519 L
.50507 .50507 L
.5047 .50494 L
.50437 .50479 L
.50407 .50464 L
.50379 .50447 L
.50353 .50431 L
.5033 .50414 L
.50308 .50398 L
.50288 .50381 L
.50269 .50365 L
.50252 .50349 L
.50236 .50333 L
.50222 .50317 L
.50208 .50303 L
.50195 .50288 L
.50183 .50274 L
.50172 .50261 L
.50162 .50248 L
Mistroke
.50152 .50235 L
.50143 .50224 L
.50135 .50212 L
.50127 .50201 L
.50119 .50191 L
.50112 .50181 L
.50106 .50172 L
.501 .50163 L
.50094 .50154 L
.50089 .50146 L
.50084 .50138 L
.50079 .50131 L
.50074 .50124 L
.5007 .50117 L
.50066 .50111 L
.50062 .50105 L
.50059 .50099 L
.50056 .50094 L
.50053 .50089 L
.5005 .50084 L
.50047 .50079 L
.50044 .50075 L
.50042 .50071 L
.50039 .50067 L
.50037 .50064 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.5003 .50051 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50024 .50041 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
Mistroke
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
Mistroke
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .577 r
.51819 .24143 m
.51062 .26705 L
.50435 .28974 L
.49918 .30987 L
.49495 .32774 L
.49153 .34365 L
.48879 .35782 L
.48663 .37047 L
.48496 .38178 L
.48371 .39191 L
.4828 .40099 L
.48218 .40916 L
.4818 .41652 L
.48163 .42316 L
.48162 .42916 L
.48175 .43459 L
.482 .43952 L
.48233 .44401 L
.48273 .44809 L
.48318 .45181 L
.48368 .45521 L
.4842 .45833 L
.48475 .46119 L
.48531 .46381 L
.48588 .46623 L
.48644 .46845 L
.48701 .47051 L
.48757 .47241 L
.48811 .47417 L
.48865 .4758 L
.48917 .47731 L
.48968 .47871 L
.49017 .48002 L
.49065 .48124 L
.49111 .48237 L
.49155 .48343 L
.49197 .48442 L
.49237 .48534 L
.49276 .48621 L
.49313 .48702 L
.49349 .48778 L
.49382 .48849 L
.49415 .48915 L
.49445 .48978 L
.49474 .49037 L
.49502 .49092 L
.49529 .49144 L
.49554 .49192 L
.49577 .49238 L
.496 .49281 L
Mistroke
.49622 .49322 L
.49642 .4936 L
.49661 .49396 L
.49679 .4943 L
.49697 .49462 L
.49713 .49492 L
.49729 .49521 L
.49744 .49548 L
.49757 .49573 L
.49771 .49597 L
.49783 .49619 L
.49795 .4964 L
.49806 .4966 L
.49817 .49679 L
.49827 .49697 L
.49836 .49714 L
.49845 .4973 L
.49854 .49745 L
.49862 .49759 L
.49869 .49772 L
.49877 .49785 L
.49883 .49797 L
.4989 .49808 L
.49896 .49819 L
.49901 .49829 L
.49907 .49838 L
.49912 .49847 L
.49917 .49856 L
.49921 .49864 L
.49926 .49871 L
.4993 .49878 L
.49934 .49885 L
.49937 .49891 L
.49941 .49897 L
.49944 .49903 L
.49947 .49908 L
.4995 .49913 L
.49953 .49918 L
.49955 .49923 L
.49958 .49927 L
.4996 .49931 L
.49962 .49935 L
.49964 .49938 L
.49966 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
Mistroke
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .944 1 r
.8115 .50968 m
.78234 .52991 L
.75639 .54626 L
.73326 .5593 L
.7126 .56954 L
.69412 .57741 L
.67756 .58329 L
.6627 .58749 L
.64934 .59028 L
.6373 .5919 L
.62643 .59256 L
.6166 .59241 L
.60769 .59161 L
.59961 .59028 L
.59226 .58853 L
.58556 .58644 L
.57944 .5841 L
.57385 .58156 L
.56873 .57888 L
.56404 .57611 L
.55972 .57327 L
.55575 .57042 L
.55208 .56756 L
.5487 .56472 L
.54557 .56193 L
.54267 .55918 L
.53999 .55649 L
.53749 .55388 L
.53518 .55134 L
.53302 .54889 L
.53101 .54652 L
.52914 .54424 L
.52739 .54204 L
.52576 .53994 L
.52424 .53792 L
.52281 .53599 L
.52147 .53414 L
.52022 .53238 L
.51904 .5307 L
.51794 .5291 L
.51691 .52757 L
.51594 .52612 L
.51503 .52474 L
.51417 .52342 L
.51336 .52218 L
.5126 .52099 L
.51189 .51987 L
.51122 .5188 L
.51059 .51779 L
.50999 .51683 L
Mistroke
.50943 .51592 L
.5089 .51506 L
.5084 .51424 L
.50793 .51347 L
.50749 .51274 L
.50707 .51204 L
.50668 .51139 L
.5063 .51077 L
.50595 .51018 L
.50562 .50962 L
.50531 .5091 L
.50501 .5086 L
.50474 .50813 L
.50447 .50768 L
.50423 .50726 L
.50399 .50687 L
.50377 .50649 L
.50356 .50613 L
.50336 .5058 L
.50318 .50548 L
.503 .50518 L
.50284 .50489 L
.50268 .50462 L
.50253 .50437 L
.50239 .50413 L
.50226 .5039 L
.50213 .50369 L
.50202 .50348 L
.50191 .50329 L
.5018 .50311 L
.5017 .50294 L
.50161 .50278 L
.50152 .50263 L
.50143 .50248 L
.50136 .50234 L
.50128 .50222 L
.50121 .50209 L
.50114 .50198 L
.50108 .50187 L
.50102 .50177 L
.50096 .50167 L
.50091 .50158 L
.50086 .50149 L
.50081 .50141 L
.50077 .50133 L
.50073 .50126 L
.50069 .50119 L
.50065 .50112 L
.50061 .50106 L
.50058 .501 L
Mistroke
.50055 .50095 L
.50052 .50089 L
.50049 .50085 L
.50046 .5008 L
.50044 .50075 L
.50041 .50071 L
.50039 .50067 L
.50037 .50064 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .5003 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .5002 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
Mistroke
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .93 r
.41854 .54764 m
.4273 .53761 L
.435 .52913 L
.44179 .52197 L
.44778 .51595 L
.45307 .5109 L
.45774 .50668 L
.46188 .50318 L
.46554 .5003 L
.4688 .49793 L
.4717 .49601 L
.47428 .49446 L
.47658 .49324 L
.47863 .49229 L
.48047 .49156 L
.48212 .49103 L
.48361 .49067 L
.48494 .49043 L
.48615 .49031 L
.48723 .49029 L
.48822 .49034 L
.48911 .49045 L
.48992 .49061 L
.49066 .49081 L
.49133 .49104 L
.49195 .4913 L
.49251 .49157 L
.49303 .49186 L
.4935 .49215 L
.49393 .49245 L
.49434 .49275 L
.49471 .49305 L
.49505 .49335 L
.49536 .49364 L
.49566 .49392 L
.49593 .4942 L
.49618 .49447 L
.49642 .49473 L
.49664 .49499 L
.49684 .49523 L
.49703 .49547 L
.49721 .49569 L
.49737 .49591 L
.49753 .49612 L
.49767 .49632 L
.49781 .49651 L
.49794 .49669 L
.49806 .49686 L
.49817 .49702 L
.49827 .49718 L
Mistroke
.49837 .49733 L
.49847 .49747 L
.49855 .4976 L
.49864 .49773 L
.49871 .49785 L
.49879 .49797 L
.49885 .49808 L
.49892 .49818 L
.49898 .49828 L
.49904 .49837 L
.49909 .49846 L
.49914 .49854 L
.49919 .49862 L
.49924 .4987 L
.49928 .49877 L
.49932 .49884 L
.49936 .4989 L
.49939 .49896 L
.49943 .49902 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49954 .49921 L
.49957 .49926 L
.49959 .4993 L
.49961 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49984 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
Mistroke
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
Mistroke
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .968 r
.80046 .53995 m
.77303 .55658 L
.74856 .56977 L
.72669 .58007 L
.70712 .5879 L
.68958 .59367 L
.67382 .59771 L
.65964 .60029 L
.64685 .60167 L
.6353 .60205 L
.62485 .60161 L
.61537 .6005 L
.60677 .59885 L
.59893 .59678 L
.59179 .59437 L
.58527 .5917 L
.5793 .58884 L
.57383 .58584 L
.56881 .58276 L
.5642 .57962 L
.55994 .57647 L
.55602 .57333 L
.5524 .57022 L
.54904 .56715 L
.54594 .56415 L
.54306 .56122 L
.54038 .55836 L
.53789 .5556 L
.53558 .55293 L
.53342 .55035 L
.53141 .54787 L
.52953 .54549 L
.52777 .5432 L
.52613 .54101 L
.52459 .53892 L
.52316 .53692 L
.52181 .53501 L
.52054 .53319 L
.51936 .53145 L
.51824 .5298 L
.5172 .52823 L
.51621 .52673 L
.51529 .52531 L
.51442 .52396 L
.5136 .52268 L
.51283 .52147 L
.51211 .52031 L
.51143 .51922 L
.51078 .51818 L
.51018 .5172 L
Mistroke
.50961 .51627 L
.50907 .51538 L
.50856 .51455 L
.50808 .51376 L
.50763 .51301 L
.50721 .5123 L
.50681 .51163 L
.50643 .51099 L
.50607 .51039 L
.50573 .50983 L
.50541 .50929 L
.50511 .50878 L
.50483 .5083 L
.50456 .50784 L
.50431 .50741 L
.50407 .50701 L
.50385 .50662 L
.50363 .50626 L
.50343 .50592 L
.50324 .50559 L
.50306 .50528 L
.50289 .50499 L
.50273 .50472 L
.50258 .50446 L
.50244 .50421 L
.5023 .50398 L
.50218 .50376 L
.50206 .50356 L
.50194 .50336 L
.50184 .50318 L
.50174 .503 L
.50164 .50284 L
.50155 .50268 L
.50146 .50253 L
.50138 .50239 L
.50131 .50226 L
.50123 .50214 L
.50117 .50202 L
.5011 .50191 L
.50104 .5018 L
.50098 .5017 L
.50093 .50161 L
.50088 .50152 L
.50083 .50144 L
.50078 .50136 L
.50074 .50128 L
.5007 .50121 L
.50066 .50115 L
.50062 .50108 L
.50059 .50102 L
Mistroke
.50056 .50097 L
.50053 .50091 L
.5005 .50086 L
.50047 .50081 L
.50044 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50035 .50061 L
.50033 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
Mistroke
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .641 0 r
.45378 .36949 m
.45519 .37866 L
.45667 .38706 L
.4582 .39477 L
.45976 .40186 L
.46133 .40838 L
.46291 .4144 L
.46447 .41995 L
.46601 .42509 L
.46752 .42985 L
.469 .43426 L
.47043 .43836 L
.47183 .44216 L
.47317 .44571 L
.47448 .44901 L
.47573 .45208 L
.47693 .45495 L
.47809 .45764 L
.4792 .46014 L
.48026 .46249 L
.48127 .46469 L
.48224 .46675 L
.48316 .46868 L
.48404 .47049 L
.48488 .47219 L
.48568 .47379 L
.48643 .47529 L
.48715 .4767 L
.48784 .47802 L
.48849 .47927 L
.4891 .48044 L
.48969 .48155 L
.49024 .48259 L
.49077 .48357 L
.49127 .48449 L
.49174 .48536 L
.49219 .48618 L
.49261 .48695 L
.49301 .48768 L
.49339 .48837 L
.49375 .48902 L
.4941 .48963 L
.49442 .49021 L
.49472 .49075 L
.49501 .49127 L
.49528 .49175 L
.49554 .49221 L
.49579 .49264 L
.49602 .49305 L
.49624 .49343 L
Mistroke
.49644 .4938 L
.49664 .49414 L
.49682 .49447 L
.497 .49477 L
.49716 .49506 L
.49732 .49533 L
.49746 .49559 L
.4976 .49584 L
.49774 .49607 L
.49786 .49628 L
.49798 .49649 L
.49809 .49668 L
.49819 .49687 L
.49829 .49704 L
.49839 .4972 L
.49848 .49736 L
.49856 .4975 L
.49864 .49764 L
.49871 .49777 L
.49879 .49789 L
.49885 .49801 L
.49892 .49812 L
.49898 .49822 L
.49903 .49832 L
.49908 .49841 L
.49914 .4985 L
.49918 .49858 L
.49923 .49866 L
.49927 .49874 L
.49931 .49881 L
.49935 .49887 L
.49938 .49893 L
.49942 .49899 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
.49956 .49924 L
.49959 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49977 .49959 L
.49978 .49962 L
Mistroke
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .882 r
.7328 .41283 m
.70887 .43686 L
.68774 .45699 L
.66906 .47379 L
.65253 .48774 L
.63786 .49925 L
.62484 .50868 L
.61327 .51634 L
.60295 .52249 L
.59375 .52735 L
.58553 .53114 L
.57817 .53401 L
.57156 .53611 L
.56563 .53756 L
.56029 .53847 L
.55548 .53894 L
.55112 .53903 L
.54719 .53882 L
.54361 .53836 L
.54037 .5377 L
.53741 .53689 L
.53472 .53595 L
.53226 .53492 L
.53001 .53381 L
.52794 .53266 L
.52605 .53148 L
.5243 .53028 L
.52269 .52907 L
.52121 .52787 L
.51984 .52668 L
.51857 .52551 L
.5174 .52437 L
.51631 .52325 L
.5153 .52216 L
.51436 .52111 L
.51348 .5201 L
.51266 .51912 L
.5119 .51817 L
.51119 .51727 L
.51053 .5164 L
.5099 .51557 L
.50932 .51477 L
.50878 .51401 L
.50827 .51328 L
.50779 .51259 L
.50734 .51193 L
.50692 .51131 L
.50652 .51071 L
.50615 .51014 L
.5058 .5096 L
Mistroke
.50547 .50909 L
.50516 .5086 L
.50487 .50814 L
.50459 .5077 L
.50433 .50729 L
.50409 .5069 L
.50386 .50652 L
.50364 .50617 L
.50344 .50584 L
.50325 .50552 L
.50307 .50522 L
.50289 .50493 L
.50273 .50467 L
.50258 .50441 L
.50244 .50417 L
.5023 .50394 L
.50217 .50373 L
.50205 .50352 L
.50194 .50333 L
.50183 .50315 L
.50173 .50298 L
.50163 .50281 L
.50154 .50266 L
.50146 .50251 L
.50138 .50237 L
.5013 .50224 L
.50123 .50212 L
.50116 .502 L
.5011 .50189 L
.50104 .50179 L
.50098 .50169 L
.50093 .5016 L
.50087 .50151 L
.50083 .50143 L
.50078 .50135 L
.50074 .50127 L
.5007 .5012 L
.50066 .50114 L
.50062 .50108 L
.50059 .50102 L
.50056 .50096 L
.50052 .50091 L
.5005 .50086 L
.50047 .50081 L
.50044 .50077 L
.50042 .50072 L
.50039 .50068 L
.50037 .50065 L
.50035 .50061 L
.50033 .50058 L
Mistroke
.50031 .50054 L
.5003 .50051 L
.50028 .50049 L
.50027 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
Mistroke
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .675 r
.36243 .51786 m
.37581 .50683 L
.38768 .49776 L
.39822 .49034 L
.4076 .48435 L
.41596 .47955 L
.42342 .47577 L
.4301 .47286 L
.43608 .47067 L
.44144 .4691 L
.44627 .46804 L
.45061 .46741 L
.45453 .46713 L
.45808 .46714 L
.46129 .46739 L
.4642 .46784 L
.46685 .46844 L
.46926 .46917 L
.47146 .46999 L
.47347 .47088 L
.47532 .47183 L
.47701 .47281 L
.47856 .47381 L
.47999 .47483 L
.48131 .47584 L
.48252 .47685 L
.48365 .47785 L
.48469 .47883 L
.48565 .47979 L
.48655 .48072 L
.48738 .48162 L
.48816 .4825 L
.48888 .48335 L
.48955 .48416 L
.49018 .48495 L
.49076 .4857 L
.49131 .48642 L
.49182 .48711 L
.4923 .48777 L
.49275 .4884 L
.49317 .48901 L
.49357 .48958 L
.49394 .49013 L
.49429 .49065 L
.49461 .49114 L
.49492 .49161 L
.49521 .49206 L
.49548 .49248 L
.49574 .49288 L
.49598 .49326 L
Mistroke
.49621 .49363 L
.49642 .49397 L
.49662 .4943 L
.49681 .4946 L
.49699 .4949 L
.49716 .49517 L
.49732 .49544 L
.49747 .49568 L
.49761 .49592 L
.49774 .49614 L
.49787 .49635 L
.49799 .49655 L
.4981 .49674 L
.4982 .49692 L
.4983 .49709 L
.4984 .49725 L
.49849 .4974 L
.49857 .49754 L
.49865 .49768 L
.49872 .4978 L
.49879 .49792 L
.49886 .49804 L
.49892 .49815 L
.49898 .49825 L
.49904 .49834 L
.49909 .49843 L
.49914 .49852 L
.49919 .4986 L
.49924 .49868 L
.49928 .49875 L
.49932 .49882 L
.49935 .49889 L
.49939 .49895 L
.49942 .499 L
.49946 .49906 L
.49949 .49911 L
.49951 .49916 L
.49954 .49921 L
.49957 .49925 L
.49959 .49929 L
.49961 .49933 L
.49963 .49937 L
.49965 .4994 L
.49967 .49944 L
.49969 .49947 L
.49971 .4995 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .4996 L
Mistroke
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49983 .4997 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49988 .49978 L
.49988 .4998 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .704 1 r
.53109 .21247 m
.52165 .2417 L
.51377 .26753 L
.50721 .29039 L
.50179 .31065 L
.49733 .32863 L
.49371 .34461 L
.49078 .35884 L
.48846 .37153 L
.48664 .38286 L
.48525 .393 L
.48422 .40209 L
.48349 .41025 L
.48302 .4176 L
.48276 .42422 L
.48267 .43019 L
.48272 .4356 L
.48289 .4405 L
.48316 .44495 L
.4835 .449 L
.48391 .45269 L
.48435 .45606 L
.48483 .45914 L
.48534 .46197 L
.48586 .46456 L
.48639 .46694 L
.48693 .46914 L
.48746 .47116 L
.48799 .47303 L
.48852 .47476 L
.48903 .47636 L
.48953 .47784 L
.49001 .47922 L
.49049 .4805 L
.49094 .4817 L
.49138 .48281 L
.49181 .48384 L
.49221 .48481 L
.4926 .48572 L
.49298 .48656 L
.49334 .48735 L
.49368 .48809 L
.49401 .48879 L
.49432 .48944 L
.49461 .49005 L
.4949 .49062 L
.49517 .49116 L
.49542 .49166 L
.49566 .49214 L
.4959 .49259 L
Mistroke
.49612 .49301 L
.49632 .4934 L
.49652 .49378 L
.49671 .49413 L
.49689 .49446 L
.49705 .49477 L
.49721 .49506 L
.49736 .49534 L
.49751 .4956 L
.49764 .49584 L
.49777 .49608 L
.49789 .4963 L
.49801 .4965 L
.49812 .4967 L
.49822 .49688 L
.49832 .49705 L
.49841 .49722 L
.4985 .49737 L
.49858 .49752 L
.49866 .49766 L
.49873 .49778 L
.4988 .49791 L
.49887 .49802 L
.49893 .49813 L
.49899 .49824 L
.49904 .49833 L
.49909 .49843 L
.49914 .49851 L
.49919 .4986 L
.49924 .49867 L
.49928 .49875 L
.49932 .49882 L
.49936 .49888 L
.49939 .49894 L
.49942 .499 L
.49946 .49906 L
.49949 .49911 L
.49951 .49916 L
.49954 .4992 L
.49957 .49925 L
.49959 .49929 L
.49961 .49933 L
.49963 .49937 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
Mistroke
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .4997 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49988 .49978 L
.49988 .4998 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .108 0 r
.24716 .75104 m
.27668 .7102 L
.3025 .67522 L
.32509 .64528 L
.34488 .61971 L
.36222 .59789 L
.37743 .5793 L
.39078 .5635 L
.40252 .5501 L
.41285 .53876 L
.42194 .52918 L
.42997 .52113 L
.43705 .51439 L
.44331 .50876 L
.44886 .50408 L
.45377 .50023 L
.45814 .49707 L
.46202 .4945 L
.46548 .49244 L
.46856 .49081 L
.47132 .48954 L
.47379 .48858 L
.476 .48788 L
.47799 .48739 L
.47978 .48709 L
.4814 .48693 L
.48285 .4869 L
.48418 .48697 L
.48537 .48713 L
.48646 .48735 L
.48745 .48762 L
.48836 .48794 L
.48918 .48829 L
.48994 .48866 L
.49063 .48904 L
.49126 .48944 L
.49185 .48984 L
.49239 .49025 L
.49289 .49065 L
.49335 .49105 L
.49377 .49144 L
.49416 .49183 L
.49453 .4922 L
.49487 .49257 L
.49518 .49292 L
.49548 .49326 L
.49575 .49359 L
.49601 .4939 L
.49625 .49421 L
.49647 .4945 L
Mistroke
.49668 .49478 L
.49687 .49505 L
.49706 .4953 L
.49723 .49554 L
.49739 .49578 L
.49754 .496 L
.49768 .49621 L
.49781 .49641 L
.49794 .4966 L
.49806 .49678 L
.49817 .49695 L
.49827 .49711 L
.49837 .49727 L
.49846 .49742 L
.49855 .49755 L
.49863 .49769 L
.49871 .49781 L
.49878 .49793 L
.49885 .49804 L
.49891 .49815 L
.49897 .49825 L
.49903 .49834 L
.49908 .49844 L
.49913 .49852 L
.49918 .4986 L
.49923 .49868 L
.49927 .49875 L
.49931 .49882 L
.49935 .49888 L
.49939 .49894 L
.49942 .499 L
.49945 .49906 L
.49948 .49911 L
.49951 .49916 L
.49954 .4992 L
.49956 .49925 L
.49959 .49929 L
.49961 .49933 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
Mistroke
.49981 .49968 L
.49982 .4997 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .4998 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.263 0 1 r
.23542 .51161 m
.26064 .49256 L
.28304 .47701 L
.30298 .46445 L
.32076 .45443 L
.33664 .44656 L
.35083 .44051 L
.36356 .436 L
.37498 .43277 L
.38525 .43062 L
.3945 .42938 L
.40285 .42888 L
.4104 .42899 L
.41725 .4296 L
.42346 .43063 L
.42911 .43197 L
.43426 .43358 L
.43895 .43538 L
.44325 .43733 L
.44718 .43939 L
.45079 .44152 L
.45411 .44369 L
.45716 .44589 L
.45998 .44808 L
.46258 .45026 L
.46498 .45241 L
.46721 .45453 L
.46927 .45659 L
.47119 .4586 L
.47297 .46055 L
.47463 .46243 L
.47617 .46425 L
.47761 .46601 L
.47895 .46769 L
.4802 .46931 L
.48138 .47086 L
.48247 .47235 L
.4835 .47376 L
.48446 .47512 L
.48537 .47641 L
.48621 .47764 L
.48701 .47881 L
.48775 .47993 L
.48845 .48099 L
.48911 .482 L
.48973 .48296 L
.49031 .48387 L
.49086 .48473 L
.49138 .48555 L
.49187 .48633 L
Mistroke
.49232 .48707 L
.49275 .48777 L
.49316 .48843 L
.49354 .48906 L
.49391 .48965 L
.49425 .49021 L
.49457 .49074 L
.49487 .49125 L
.49516 .49173 L
.49543 .49218 L
.49568 .4926 L
.49592 .49301 L
.49615 .49339 L
.49636 .49375 L
.49656 .4941 L
.49675 .49442 L
.49693 .49472 L
.4971 .49501 L
.49726 .49529 L
.49741 .49555 L
.49756 .49579 L
.49769 .49602 L
.49782 .49624 L
.49794 .49645 L
.49805 .49664 L
.49816 .49683 L
.49826 .497 L
.49836 .49717 L
.49845 .49732 L
.49854 .49747 L
.49862 .49761 L
.49869 .49774 L
.49877 .49786 L
.49883 .49798 L
.4989 .49809 L
.49896 .4982 L
.49902 .4983 L
.49907 .49839 L
.49912 .49848 L
.49917 .49856 L
.49922 .49864 L
.49926 .49872 L
.4993 .49879 L
.49934 .49886 L
.49938 .49892 L
.49941 .49898 L
.49944 .49903 L
.49947 .49909 L
.4995 .49914 L
.49953 .49919 L
Mistroke
.49956 .49923 L
.49958 .49927 L
.4996 .49931 L
.49962 .49935 L
.49965 .49939 L
.49967 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
Mistroke
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .723 r
.21561 .465 m
.24164 .44899 L
.26486 .43626 L
.28559 .42631 L
.30415 .41871 L
.32078 .41308 L
.33571 .40911 L
.34915 .40653 L
.36126 .40511 L
.3722 .40464 L
.3821 .40496 L
.39107 .40592 L
.39921 .4074 L
.40662 .40929 L
.41338 .4115 L
.41954 .41397 L
.42519 .41662 L
.43035 .41941 L
.4351 .42228 L
.43946 .4252 L
.44348 .42815 L
.44718 .43109 L
.45061 .434 L
.45377 .43687 L
.4567 .43969 L
.45942 .44244 L
.46195 .44511 L
.46429 .44771 L
.46648 .45021 L
.46851 .45263 L
.47041 .45496 L
.47218 .4572 L
.47384 .45935 L
.47539 .46141 L
.47683 .46338 L
.47819 .46526 L
.47946 .46705 L
.48065 .46877 L
.48177 .4704 L
.48282 .47195 L
.48381 .47343 L
.48473 .47484 L
.4856 .47618 L
.48642 .47745 L
.48719 .47865 L
.48792 .47979 L
.4886 .48088 L
.48924 .48191 L
.48985 .48289 L
.49042 .48381 L
Mistroke
.49095 .48469 L
.49146 .48552 L
.49194 .4863 L
.49239 .48705 L
.49281 .48775 L
.49321 .48842 L
.49359 .48905 L
.49395 .48965 L
.49429 .49021 L
.4946 .49075 L
.4949 .49126 L
.49519 .49173 L
.49545 .49219 L
.4957 .49262 L
.49594 .49302 L
.49617 .4934 L
.49638 .49377 L
.49658 .49411 L
.49677 .49443 L
.49695 .49474 L
.49712 .49503 L
.49728 .4953 L
.49743 .49556 L
.49757 .4958 L
.4977 .49603 L
.49783 .49625 L
.49795 .49646 L
.49806 .49665 L
.49817 .49684 L
.49827 .49701 L
.49837 .49718 L
.49846 .49733 L
.49854 .49748 L
.49862 .49762 L
.4987 .49775 L
.49877 .49787 L
.49884 .49799 L
.4989 .4981 L
.49896 .4982 L
.49902 .4983 L
.49907 .4984 L
.49912 .49849 L
.49917 .49857 L
.49922 .49865 L
.49926 .49872 L
.4993 .49879 L
.49934 .49886 L
.49938 .49892 L
.49941 .49898 L
.49944 .49904 L
Mistroke
.49947 .49909 L
.4995 .49914 L
.49953 .49919 L
.49956 .49923 L
.49958 .49928 L
.4996 .49931 L
.49963 .49935 L
.49965 .49939 L
.49967 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49978 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
Mistroke
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.734 1 0 r
.34881 .31542 m
.3589 .32257 L
.36819 .32972 L
.37677 .33683 L
.3847 .34386 L
.39204 .35076 L
.39884 .3575 L
.40516 .36408 L
.41103 .37046 L
.41649 .37664 L
.42157 .3826 L
.42631 .38835 L
.43074 .39388 L
.43487 .39919 L
.43873 .40427 L
.44234 .40914 L
.44572 .4138 L
.44889 .41824 L
.45186 .42248 L
.45465 .42653 L
.45726 .43038 L
.45972 .43404 L
.46203 .43753 L
.46419 .44084 L
.46623 .44399 L
.46815 .44698 L
.46995 .44982 L
.47165 .45251 L
.47325 .45507 L
.47476 .45749 L
.47618 .45979 L
.47751 .46196 L
.47877 .46402 L
.47996 .46597 L
.48108 .46782 L
.48214 .46957 L
.48313 .47123 L
.48407 .4728 L
.48496 .47428 L
.4858 .47569 L
.48659 .47702 L
.48733 .47827 L
.48803 .47946 L
.4887 .48059 L
.48932 .48165 L
.48992 .48266 L
.49047 .48361 L
.491 .48451 L
.4915 .48536 L
.49197 .48616 L
Mistroke
.49241 .48692 L
.49283 .48764 L
.49323 .48832 L
.4936 .48896 L
.49396 .48957 L
.49429 .49014 L
.49461 .49068 L
.4949 .4912 L
.49519 .49168 L
.49545 .49214 L
.4957 .49257 L
.49594 .49298 L
.49616 .49337 L
.49638 .49373 L
.49658 .49408 L
.49676 .4944 L
.49694 .49471 L
.49711 .495 L
.49727 .49528 L
.49742 .49554 L
.49756 .49578 L
.4977 .49602 L
.49783 .49624 L
.49795 .49644 L
.49806 .49664 L
.49817 .49682 L
.49827 .497 L
.49836 .49716 L
.49845 .49732 L
.49854 .49747 L
.49862 .49761 L
.49869 .49774 L
.49877 .49786 L
.49883 .49798 L
.4989 .49809 L
.49896 .4982 L
.49902 .4983 L
.49907 .49839 L
.49912 .49848 L
.49917 .49856 L
.49922 .49864 L
.49926 .49872 L
.4993 .49879 L
.49934 .49886 L
.49938 .49892 L
.49941 .49898 L
.49944 .49903 L
.49947 .49909 L
.4995 .49914 L
.49953 .49919 L
Mistroke
.49956 .49923 L
.49958 .49927 L
.4996 .49931 L
.49963 .49935 L
.49965 .49939 L
.49967 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
Mistroke
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .488 1 r
.73368 .47287 m
.71103 .4913 L
.69093 .50644 L
.67307 .5188 L
.65717 .52877 L
.643 .53673 L
.63034 .54297 L
.61902 .54777 L
.60888 .55134 L
.59977 .55389 L
.59158 .55558 L
.5842 .55655 L
.57754 .55694 L
.57151 .55683 L
.56606 .55632 L
.5611 .5555 L
.55659 .55441 L
.55249 .55312 L
.54874 .55167 L
.54531 .55011 L
.54217 .54846 L
.53929 .54675 L
.53664 .54501 L
.53421 .54325 L
.53196 .54149 L
.52988 .53975 L
.52796 .53803 L
.52619 .53634 L
.52454 .53469 L
.52301 .53309 L
.52159 .53153 L
.52027 .53002 L
.51903 .52856 L
.51788 .52716 L
.51681 .52581 L
.51581 .52452 L
.51487 .52328 L
.514 .5221 L
.51318 .52096 L
.51241 .51988 L
.51169 .51885 L
.51101 .51786 L
.51038 .51693 L
.50978 .51603 L
.50922 .51519 L
.5087 .51438 L
.5082 .51361 L
.50774 .51289 L
.5073 .5122 L
.50689 .51154 L
Mistroke
.5065 .51092 L
.50613 .51033 L
.50579 .50977 L
.50546 .50924 L
.50516 .50874 L
.50487 .50827 L
.5046 .50782 L
.50434 .50739 L
.5041 .50699 L
.50387 .50661 L
.50365 .50625 L
.50345 .50591 L
.50326 .50559 L
.50308 .50528 L
.50291 .50499 L
.50275 .50472 L
.50259 .50446 L
.50245 .50421 L
.50231 .50398 L
.50219 .50376 L
.50207 .50356 L
.50195 .50336 L
.50184 .50318 L
.50174 .503 L
.50164 .50284 L
.50155 .50268 L
.50147 .50253 L
.50139 .5024 L
.50131 .50226 L
.50124 .50214 L
.50117 .50202 L
.50111 .50191 L
.50104 .5018 L
.50099 .50171 L
.50093 .50161 L
.50088 .50152 L
.50083 .50144 L
.50079 .50136 L
.50074 .50128 L
.5007 .50121 L
.50066 .50115 L
.50063 .50108 L
.50059 .50102 L
.50056 .50097 L
.50053 .50091 L
.5005 .50086 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
Mistroke
.50038 .50065 L
.50036 .50062 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
Mistroke
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .586 r
.82229 .19694 m
.78503 .2474 L
.75244 .29057 L
.72389 .32746 L
.69887 .35893 L
.67692 .38574 L
.65765 .40852 L
.64071 .42785 L
.62581 .44421 L
.61268 .45801 L
.6011 .46962 L
.59088 .47935 L
.58184 .48747 L
.57384 .4942 L
.56674 .49976 L
.56044 .50432 L
.55484 .50801 L
.54985 .51098 L
.5454 .51333 L
.54142 .51515 L
.53785 .51653 L
.53466 .51754 L
.53179 .51824 L
.5292 .51868 L
.52687 .5189 L
.52476 .51894 L
.52286 .51884 L
.52113 .51861 L
.51955 .51829 L
.51812 .51789 L
.51682 .51744 L
.51563 .51693 L
.51454 .5164 L
.51354 .51584 L
.51262 .51526 L
.51177 .51468 L
.511 .51409 L
.51028 .51351 L
.50961 .51293 L
.509 .51237 L
.50843 .51181 L
.5079 .51127 L
.50741 .51074 L
.50696 .51023 L
.50653 .50974 L
.50614 .50927 L
.50577 .50881 L
.50542 .50837 L
.5051 .50795 L
.5048 .50754 L
Mistroke
.50452 .50716 L
.50425 .50679 L
.50401 .50644 L
.50377 .5061 L
.50356 .50578 L
.50335 .50548 L
.50316 .50519 L
.50298 .50492 L
.50281 .50465 L
.50265 .50441 L
.5025 .50417 L
.50236 .50395 L
.50222 .50373 L
.5021 .50353 L
.50198 .50334 L
.50187 .50316 L
.50177 .50299 L
.50167 .50283 L
.50157 .50267 L
.50149 .50253 L
.5014 .50239 L
.50132 .50226 L
.50125 .50214 L
.50118 .50202 L
.50112 .50191 L
.50105 .50181 L
.501 .50171 L
.50094 .50161 L
.50089 .50153 L
.50084 .50144 L
.50079 .50136 L
.50075 .50129 L
.50071 .50122 L
.50067 .50115 L
.50063 .50109 L
.5006 .50103 L
.50056 .50097 L
.50053 .50092 L
.5005 .50087 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50036 .50062 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50047 L
Mistroke
.50025 .50044 L
.50024 .50042 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .5003 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .5001 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
Mistroke
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .624 0 r
.20191 .65519 m
.23354 .62032 L
.26139 .59088 L
.28595 .56611 L
.30764 .54534 L
.3268 .52801 L
.34377 .51361 L
.35881 .50172 L
.37217 .49198 L
.38404 .48405 L
.39462 .47769 L
.40405 .47264 L
.41248 .4687 L
.42003 .46572 L
.4268 .46352 L
.43287 .46199 L
.43835 .46102 L
.44328 .46051 L
.44773 .46038 L
.45177 .46057 L
.45542 .46102 L
.45875 .46167 L
.46177 .46248 L
.46453 .46343 L
.46704 .46447 L
.46935 .46558 L
.47146 .46675 L
.4734 .46795 L
.47518 .46916 L
.47683 .47039 L
.47834 .47161 L
.47974 .47281 L
.48104 .474 L
.48224 .47517 L
.48335 .4763 L
.48438 .47741 L
.48535 .47848 L
.48624 .47951 L
.48708 .48051 L
.48785 .48147 L
.48858 .4824 L
.48926 .48328 L
.48989 .48413 L
.49049 .48494 L
.49104 .48571 L
.49157 .48645 L
.49205 .48716 L
.49251 .48783 L
.49294 .48847 L
.49335 .48908 L
Mistroke
.49373 .48966 L
.49409 .49021 L
.49442 .49073 L
.49474 .49122 L
.49504 .49169 L
.49532 .49214 L
.49558 .49256 L
.49583 .49297 L
.49606 .49335 L
.49628 .49371 L
.49649 .49405 L
.49669 .49437 L
.49687 .49468 L
.49705 .49497 L
.49721 .49524 L
.49737 .4955 L
.49751 .49575 L
.49765 .49598 L
.49778 .4962 L
.49791 .49641 L
.49802 .4966 L
.49813 .49679 L
.49824 .49697 L
.49833 .49713 L
.49843 .49729 L
.49851 .49744 L
.49859 .49758 L
.49867 .49771 L
.49875 .49784 L
.49882 .49796 L
.49888 .49807 L
.49894 .49817 L
.499 .49827 L
.49906 .49837 L
.49911 .49846 L
.49916 .49854 L
.4992 .49862 L
.49925 .4987 L
.49929 .49877 L
.49933 .49884 L
.49937 .4989 L
.4994 .49896 L
.49943 .49902 L
.49947 .49907 L
.49949 .49913 L
.49952 .49917 L
.49955 .49922 L
.49957 .49926 L
.4996 .4993 L
.49962 .49934 L
Mistroke
.49964 .49938 L
.49966 .49941 L
.49968 .49944 L
.4997 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49956 L
.49976 .49958 L
.49977 .4996 L
.49978 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
Mistroke
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .118 0 r
.76568 .70622 m
.74528 .70481 L
.72679 .70214 L
.70997 .69847 L
.69466 .69401 L
.68069 .68892 L
.66792 .68337 L
.65623 .67748 L
.64552 .67134 L
.63567 .66506 L
.62661 .6587 L
.61826 .65233 L
.61055 .64599 L
.60343 .63973 L
.59684 .63357 L
.59072 .62755 L
.58505 .62167 L
.57979 .61597 L
.57489 .61045 L
.57032 .60512 L
.56607 .59998 L
.5621 .59503 L
.55839 .59029 L
.55493 .58573 L
.55169 .58138 L
.54865 .57721 L
.54581 .57323 L
.54315 .56943 L
.54065 .56582 L
.53831 .56237 L
.5361 .55909 L
.53404 .55596 L
.53209 .553 L
.53026 .55018 L
.52855 .5475 L
.52693 .54496 L
.52541 .54254 L
.52397 .54026 L
.52262 .53809 L
.52135 .53603 L
.52015 .53408 L
.51902 .53224 L
.51796 .53049 L
.51695 .52883 L
.51601 .52726 L
.51511 .52578 L
.51427 .52437 L
.51348 .52304 L
.51273 .52178 L
.51202 .52059 L
Mistroke
.51135 .51947 L
.51072 .5184 L
.51013 .51739 L
.50957 .51644 L
.50904 .51554 L
.50854 .51469 L
.50806 .51388 L
.50762 .51312 L
.5072 .5124 L
.5068 .51172 L
.50642 .51107 L
.50607 .51047 L
.50573 .50989 L
.50541 .50935 L
.50512 .50883 L
.50483 .50835 L
.50457 .50789 L
.50431 .50745 L
.50408 .50704 L
.50385 .50666 L
.50364 .50629 L
.50344 .50594 L
.50325 .50562 L
.50307 .50531 L
.5029 .50501 L
.50274 .50474 L
.50259 .50448 L
.50245 .50423 L
.50231 .504 L
.50218 .50378 L
.50206 .50357 L
.50195 .50337 L
.50184 .50319 L
.50174 .50301 L
.50164 .50285 L
.50155 .50269 L
.50147 .50254 L
.50139 .5024 L
.50131 .50227 L
.50124 .50214 L
.50117 .50203 L
.50111 .50191 L
.50104 .50181 L
.50099 .50171 L
.50093 .50161 L
.50088 .50153 L
.50083 .50144 L
.50079 .50136 L
.50074 .50129 L
.5007 .50122 L
Mistroke
.50066 .50115 L
.50063 .50109 L
.50059 .50103 L
.50056 .50097 L
.50053 .50092 L
.5005 .50087 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50036 .50062 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
Mistroke
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.805 0 1 r
.74198 .31503 m
.71497 .34891 L
.69128 .37775 L
.67047 .40226 L
.65218 .42305 L
.63609 .44064 L
.62191 .45548 L
.60941 .46795 L
.59836 .4784 L
.5886 .48712 L
.57995 .49435 L
.57228 .50031 L
.56547 .50518 L
.55941 .50914 L
.55402 .51231 L
.5492 .51482 L
.5449 .51676 L
.54104 .51823 L
.53758 .51929 L
.53447 .52003 L
.53168 .52048 L
.52915 .5207 L
.52687 .52072 L
.52481 .52059 L
.52293 .52033 L
.52123 .51997 L
.51968 .51953 L
.51826 .51902 L
.51697 .51847 L
.51579 .51788 L
.51471 .51727 L
.51371 .51664 L
.51279 .516 L
.51195 .51536 L
.51117 .51472 L
.51045 .51409 L
.50978 .51347 L
.50916 .51286 L
.50859 .51227 L
.50806 .5117 L
.50756 .51114 L
.5071 .5106 L
.50667 .51009 L
.50627 .50959 L
.5059 .50911 L
.50555 .50865 L
.50522 .50821 L
.50491 .50779 L
.50463 .50739 L
.50436 .50701 L
Mistroke
.5041 .50664 L
.50387 .50629 L
.50365 .50596 L
.50344 .50565 L
.50324 .50535 L
.50306 .50506 L
.50288 .50479 L
.50272 .50454 L
.50256 .50429 L
.50242 .50406 L
.50228 .50384 L
.50216 .50364 L
.50203 .50344 L
.50192 .50325 L
.50181 .50308 L
.50171 .50291 L
.50162 .50275 L
.50153 .5026 L
.50144 .50246 L
.50136 .50233 L
.50128 .5022 L
.50121 .50208 L
.50115 .50196 L
.50108 .50186 L
.50102 .50176 L
.50097 .50166 L
.50091 .50157 L
.50086 .50148 L
.50081 .5014 L
.50077 .50132 L
.50073 .50125 L
.50069 .50118 L
.50065 .50112 L
.50061 .50106 L
.50058 .501 L
.50055 .50094 L
.50052 .50089 L
.50049 .50084 L
.50046 .5008 L
.50044 .50075 L
.50041 .50071 L
.50039 .50067 L
.50037 .50063 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
Mistroke
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .5003 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50012 .50022 L
.50012 .5002 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
Mistroke
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .225 0 r
.63162 .63297 m
.62222 .62937 L
.61362 .62546 L
.60574 .62134 L
.59852 .61708 L
.59187 .61272 L
.58576 .60833 L
.58012 .60393 L
.57492 .59957 L
.5701 .59526 L
.56565 .59104 L
.56152 .58691 L
.55768 .58289 L
.55412 .57899 L
.5508 .57521 L
.54771 .57156 L
.54483 .56805 L
.54214 .56468 L
.53963 .56144 L
.53728 .55834 L
.53509 .55536 L
.53303 .55252 L
.5311 .54981 L
.5293 .54723 L
.5276 .54476 L
.52601 .54241 L
.52452 .54018 L
.52312 .53805 L
.5218 .53603 L
.52056 .53412 L
.51939 .53229 L
.51829 .53056 L
.51726 .52892 L
.51628 .52737 L
.51537 .52589 L
.5145 .52449 L
.51369 .52317 L
.51292 .52191 L
.5122 .52072 L
.51152 .5196 L
.51088 .51853 L
.51027 .51752 L
.5097 .51657 L
.50916 .51566 L
.50865 .51481 L
.50817 .514 L
.50771 .51323 L
.50729 .51251 L
.50688 .51182 L
.5065 .51117 L
Mistroke
.50614 .51056 L
.5058 .50998 L
.50548 .50943 L
.50518 .50892 L
.50489 .50843 L
.50462 .50796 L
.50436 .50753 L
.50412 .50711 L
.50389 .50672 L
.50368 .50635 L
.50348 .506 L
.50328 .50567 L
.5031 .50536 L
.50293 .50507 L
.50277 .50479 L
.50262 .50452 L
.50247 .50427 L
.50234 .50404 L
.50221 .50382 L
.50208 .50361 L
.50197 .50341 L
.50186 .50322 L
.50176 .50304 L
.50166 .50288 L
.50157 .50272 L
.50148 .50257 L
.5014 .50243 L
.50132 .50229 L
.50125 .50217 L
.50118 .50205 L
.50112 .50193 L
.50106 .50183 L
.501 .50173 L
.50094 .50163 L
.50089 .50154 L
.50084 .50146 L
.50079 .50138 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50063 .5011 L
.5006 .50104 L
.50057 .50098 L
.50053 .50093 L
.5005 .50087 L
.50048 .50083 L
.50045 .50078 L
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
Mistroke
.50036 .50062 L
.50034 .50059 L
.50032 .50056 L
.5003 .50052 L
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .5004 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
Mistroke
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .528 0 r
.71806 .39985 m
.69523 .4241 L
.6751 .44451 L
.65733 .46163 L
.64162 .47593 L
.62772 .48781 L
.6154 .49763 L
.60446 .50569 L
.59474 .51225 L
.58608 .51752 L
.57836 .52171 L
.57146 .52498 L
.56529 .52748 L
.55975 .52932 L
.55478 .53061 L
.5503 .53144 L
.54627 .53189 L
.54263 .53202 L
.53933 .5319 L
.53634 .53156 L
.53363 .53105 L
.53116 .5304 L
.52891 .52965 L
.52686 .52882 L
.52497 .52792 L
.52325 .52699 L
.52167 .52602 L
.52021 .52504 L
.51887 .52405 L
.51764 .52306 L
.5165 .52208 L
.51544 .52112 L
.51446 .52018 L
.51355 .51925 L
.51271 .51836 L
.51193 .51749 L
.5112 .51665 L
.51052 .51584 L
.50989 .51506 L
.50929 .51431 L
.50874 .51359 L
.50822 .5129 L
.50774 .51224 L
.50729 .51162 L
.50686 .51101 L
.50647 .51044 L
.50609 .5099 L
.50574 .50938 L
.50541 .50888 L
.5051 .50841 L
Mistroke
.50481 .50796 L
.50454 .50754 L
.50428 .50714 L
.50404 .50675 L
.50381 .50639 L
.5036 .50605 L
.50339 .50572 L
.5032 .50541 L
.50302 .50512 L
.50285 .50484 L
.50269 .50458 L
.50254 .50433 L
.5024 .50409 L
.50227 .50387 L
.50214 .50366 L
.50202 .50346 L
.50191 .50327 L
.5018 .50309 L
.5017 .50292 L
.50161 .50276 L
.50152 .50261 L
.50144 .50247 L
.50136 .50233 L
.50128 .50221 L
.50121 .50208 L
.50114 .50197 L
.50108 .50186 L
.50102 .50176 L
.50096 .50166 L
.50091 .50157 L
.50086 .50148 L
.50081 .5014 L
.50077 .50133 L
.50073 .50125 L
.50069 .50118 L
.50065 .50112 L
.50061 .50106 L
.50058 .501 L
.50055 .50094 L
.50052 .50089 L
.50049 .50084 L
.50046 .5008 L
.50044 .50075 L
.50041 .50071 L
.50039 .50067 L
.50037 .50064 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
Mistroke
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .5003 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50012 .50022 L
.50012 .5002 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50015 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
Mistroke
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .326 r
.53766 .46581 m
.53333 .47159 L
.52955 .47653 L
.52623 .48075 L
.52332 .48435 L
.52077 .48741 L
.51852 .49 L
.51655 .4922 L
.51481 .49406 L
.51328 .49563 L
.51193 .49694 L
.51074 .49804 L
.50968 .49895 L
.50874 .49971 L
.50791 .50033 L
.50717 .50084 L
.50651 .50124 L
.50593 .50157 L
.5054 .50182 L
.50494 .50202 L
.50452 .50216 L
.50414 .50227 L
.5038 .50233 L
.50349 .50237 L
.50322 .50238 L
.50297 .50238 L
.50274 .50236 L
.50254 .50232 L
.50235 .50227 L
.50218 .50222 L
.50203 .50216 L
.50188 .50209 L
.50175 .50202 L
.50163 .50195 L
.50152 .50188 L
.50142 .5018 L
.50133 .50173 L
.50124 .50166 L
.50116 .50158 L
.50109 .50151 L
.50102 .50145 L
.50096 .50138 L
.5009 .50131 L
.50084 .50125 L
.50079 .50119 L
.50074 .50113 L
.5007 .50108 L
.50066 .50102 L
.50062 .50097 L
.50058 .50092 L
Mistroke
.50055 .50087 L
.50052 .50083 L
.50049 .50078 L
.50046 .50074 L
.50043 .5007 L
.50041 .50067 L
.50038 .50063 L
.50036 .5006 L
.50034 .50057 L
.50032 .50054 L
.5003 .50051 L
.50029 .50048 L
.50027 .50045 L
.50026 .50043 L
.50024 .50041 L
.50023 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
Mistroke
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.514 1 0 r
.80179 .54729 m
.7744 .56332 L
.74995 .57597 L
.7281 .58577 L
.70852 .59317 L
.69097 .59854 L
.67518 .60221 L
.66097 .60446 L
.64816 .60553 L
.63657 .60564 L
.62608 .60495 L
.61656 .60361 L
.60792 .60175 L
.60004 .59948 L
.59286 .59689 L
.58629 .59405 L
.58028 .59104 L
.57477 .5879 L
.56971 .58469 L
.56505 .58143 L
.56076 .57817 L
.55679 .57492 L
.55313 .57171 L
.54974 .56855 L
.5466 .56546 L
.54369 .56245 L
.54098 .55953 L
.53846 .5567 L
.53612 .55396 L
.53393 .55132 L
.5319 .54879 L
.52999 .54635 L
.52821 .54401 L
.52655 .54178 L
.52499 .53964 L
.52353 .5376 L
.52216 .53565 L
.52088 .53379 L
.51967 .53202 L
.51854 .53034 L
.51748 .52873 L
.51648 .52721 L
.51554 .52576 L
.51466 .52439 L
.51383 .52308 L
.51305 .52185 L
.51231 .52067 L
.51162 .51956 L
.51096 .5185 L
.51035 .5175 L
Mistroke
.50977 .51655 L
.50922 .51565 L
.50871 .5148 L
.50822 .514 L
.50776 .51324 L
.50733 .51251 L
.50692 .51183 L
.50654 .51119 L
.50617 .51057 L
.50583 .51 L
.50551 .50945 L
.5052 .50893 L
.50491 .50844 L
.50464 .50798 L
.50438 .50754 L
.50414 .50713 L
.50391 .50674 L
.50369 .50637 L
.50349 .50602 L
.5033 .50569 L
.50311 .50537 L
.50294 .50508 L
.50278 .5048 L
.50263 .50454 L
.50248 .50429 L
.50234 .50405 L
.50221 .50383 L
.50209 .50362 L
.50198 .50342 L
.50187 .50323 L
.50176 .50305 L
.50167 .50288 L
.50158 .50273 L
.50149 .50258 L
.50141 .50243 L
.50133 .5023 L
.50126 .50217 L
.50119 .50205 L
.50112 .50194 L
.50106 .50183 L
.501 .50173 L
.50095 .50164 L
.50089 .50155 L
.50084 .50146 L
.5008 .50138 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50064 .5011 L
.5006 .50104 L
Mistroke
.50057 .50098 L
.50054 .50093 L
.50051 .50088 L
.50048 .50083 L
.50045 .50078 L
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50056 L
.5003 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .5004 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
Mistroke
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .337 r
.28006 .63714 m
.30391 .60928 L
.32487 .58566 L
.34333 .56569 L
.35959 .54886 L
.37394 .53472 L
.38662 .52289 L
.39783 .51303 L
.40776 .50487 L
.41657 .49815 L
.4244 .49266 L
.43136 .48822 L
.43757 .48467 L
.44311 .48188 L
.44806 .47972 L
.4525 .47811 L
.45649 .47695 L
.46007 .47617 L
.4633 .47571 L
.46621 .47551 L
.46884 .47552 L
.47123 .47572 L
.47339 .47605 L
.47536 .47651 L
.47715 .47705 L
.47879 .47766 L
.48028 .47833 L
.48165 .47903 L
.48291 .47977 L
.48406 .48051 L
.48512 .48127 L
.4861 .48203 L
.48701 .48278 L
.48784 .48352 L
.48862 .48425 L
.48933 .48496 L
.49 .48566 L
.49062 .48633 L
.49119 .48698 L
.49173 .48761 L
.49223 .48822 L
.4927 .4888 L
.49313 .48936 L
.49354 .4899 L
.49392 .49041 L
.49428 .49091 L
.49461 .49137 L
.49492 .49182 L
.49522 .49225 L
.49549 .49266 L
Mistroke
.49575 .49304 L
.49599 .49341 L
.49622 .49376 L
.49644 .49409 L
.49664 .49441 L
.49683 .49471 L
.49701 .49499 L
.49718 .49526 L
.49734 .49552 L
.49749 .49576 L
.49763 .49599 L
.49776 .4962 L
.49789 .49641 L
.498 .49661 L
.49812 .49679 L
.49822 .49697 L
.49832 .49713 L
.49841 .49729 L
.4985 .49744 L
.49859 .49758 L
.49866 .49771 L
.49874 .49783 L
.49881 .49795 L
.49887 .49806 L
.49894 .49817 L
.499 .49827 L
.49905 .49837 L
.4991 .49846 L
.49915 .49854 L
.4992 .49862 L
.49924 .4987 L
.49929 .49877 L
.49933 .49884 L
.49936 .4989 L
.4994 .49896 L
.49943 .49902 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49922 L
.49957 .49926 L
.4996 .4993 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49944 L
.4997 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49956 L
Mistroke
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.4998 .49965 L
.49981 .49967 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .656 0 r
.68474 .17454 m
.65995 .21778 L
.63848 .25525 L
.61988 .28774 L
.60377 .3159 L
.58982 .3403 L
.57773 .36146 L
.56727 .3798 L
.5582 .39571 L
.55035 .40949 L
.54356 .42145 L
.53767 .43181 L
.53257 .4408 L
.52816 .4486 L
.52434 .45536 L
.52104 .46122 L
.51818 .4663 L
.5157 .47072 L
.51356 .47454 L
.5117 .47787 L
.5101 .48075 L
.50871 .48325 L
.50751 .48542 L
.50647 .4873 L
.50557 .48894 L
.5048 .49036 L
.50413 .4916 L
.50355 .49267 L
.50305 .4936 L
.50261 .49441 L
.50224 .49512 L
.50192 .49573 L
.50164 .49626 L
.5014 .49673 L
.5012 .49713 L
.50102 .49748 L
.50087 .49779 L
.50073 .49806 L
.50062 .49829 L
.50052 .49849 L
.50044 .49867 L
.50037 .49883 L
.50031 .49896 L
.50025 .49908 L
.50021 .49918 L
.50017 .49928 L
.50014 .49936 L
.50011 .49943 L
.50009 .49949 L
.50007 .49954 L
Mistroke
.50005 .49959 L
.50004 .49963 L
.50003 .49967 L
.50002 .4997 L
.50001 .49973 L
.5 .49976 L
.49999 .49978 L
.49999 .4998 L
.49999 .49982 L
.49998 .49983 L
.49998 .49985 L
.49998 .49986 L
.49998 .49987 L
.49998 .49988 L
.49998 .49989 L
.49998 .4999 L
.49998 .49991 L
.49998 .49992 L
.49998 .49992 L
.49998 .49993 L
.49998 .49993 L
.49998 .49994 L
.49998 .49994 L
.49998 .49995 L
.49998 .49995 L
.49998 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.49999 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
Mistroke
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.496 1 0 r
.64014 .71485 m
.63179 .7041 L
.62397 .6938 L
.61667 .68393 L
.60983 .67451 L
.60342 .6655 L
.59741 .65691 L
.59177 .64873 L
.58648 .64093 L
.58151 .63351 L
.57685 .62645 L
.57246 .61974 L
.56834 .61337 L
.56446 .60731 L
.56081 .60157 L
.55737 .59612 L
.55413 .59095 L
.55109 .58604 L
.54821 .5814 L
.54551 .57699 L
.54296 .57282 L
.54056 .56887 L
.53829 .56513 L
.53615 .56158 L
.53414 .55823 L
.53223 .55505 L
.53044 .55205 L
.52875 .54921 L
.52715 .54652 L
.52564 .54397 L
.52422 .54157 L
.52287 .53929 L
.52161 .53714 L
.52041 .5351 L
.51928 .53318 L
.51821 .53136 L
.5172 .52963 L
.51625 .52801 L
.51535 .52647 L
.5145 .52502 L
.5137 .52364 L
.51294 .52234 L
.51223 .52111 L
.51155 .51995 L
.51091 .51885 L
.51031 .51782 L
.50974 .51684 L
.5092 .51591 L
.5087 .51503 L
.50822 .51421 L
Mistroke
.50776 .51342 L
.50733 .51269 L
.50693 .51199 L
.50655 .51133 L
.50619 .5107 L
.50585 .51011 L
.50552 .50956 L
.50522 .50903 L
.50493 .50853 L
.50466 .50806 L
.5044 .50762 L
.50416 .5072 L
.50393 .5068 L
.50371 .50643 L
.50351 .50607 L
.50331 .50574 L
.50313 .50542 L
.50296 .50512 L
.5028 .50484 L
.50264 .50457 L
.5025 .50432 L
.50236 .50408 L
.50223 .50386 L
.50211 .50365 L
.50199 .50345 L
.50188 .50326 L
.50178 .50308 L
.50168 .50291 L
.50159 .50275 L
.5015 .50259 L
.50142 .50245 L
.50134 .50232 L
.50126 .50219 L
.50119 .50207 L
.50113 .50195 L
.50107 .50185 L
.50101 .50174 L
.50095 .50165 L
.5009 .50156 L
.50085 .50147 L
.5008 .50139 L
.50076 .50131 L
.50072 .50124 L
.50068 .50117 L
.50064 .50111 L
.5006 .50105 L
.50057 .50099 L
.50054 .50094 L
.50051 .50088 L
.50048 .50083 L
Mistroke
.50046 .50079 L
.50043 .50075 L
.50041 .5007 L
.50038 .50067 L
.50036 .50063 L
.50034 .50059 L
.50032 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.50019 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50016 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
Mistroke
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.782 1 0 r
.30156 .34898 m
.31686 .34975 L
.33073 .35149 L
.34334 .35401 L
.35481 .35714 L
.36527 .36076 L
.37483 .36475 L
.38357 .369 L
.39159 .37346 L
.39895 .37803 L
.40572 .38267 L
.41196 .38734 L
.41771 .39199 L
.42303 .39659 L
.42795 .40112 L
.43251 .40555 L
.43673 .40988 L
.44066 .41408 L
.44431 .41816 L
.44771 .4221 L
.45088 .42589 L
.45384 .42955 L
.4566 .43306 L
.45918 .43643 L
.46159 .43965 L
.46385 .44274 L
.46596 .44568 L
.46794 .44849 L
.4698 .45118 L
.47154 .45373 L
.47318 .45616 L
.47472 .45848 L
.47616 .46068 L
.47752 .46277 L
.4788 .46475 L
.48 .46664 L
.48113 .46843 L
.4822 .47012 L
.4832 .47173 L
.48414 .47326 L
.48503 .4747 L
.48587 .47607 L
.48666 .47737 L
.48741 .4786 L
.48811 .47976 L
.48878 .48087 L
.4894 .48191 L
.48999 .4829 L
.49055 .48383 L
.49107 .48471 L
Mistroke
.49157 .48555 L
.49204 .48634 L
.49248 .48709 L
.4929 .48779 L
.49329 .48846 L
.49366 .4891 L
.49401 .48969 L
.49435 .49026 L
.49466 .49079 L
.49495 .4913 L
.49523 .49178 L
.4955 .49223 L
.49575 .49266 L
.49598 .49306 L
.4962 .49344 L
.49641 .4938 L
.49661 .49414 L
.4968 .49447 L
.49697 .49477 L
.49714 .49506 L
.4973 .49533 L
.49745 .49559 L
.49759 .49583 L
.49772 .49606 L
.49785 .49628 L
.49797 .49648 L
.49808 .49668 L
.49818 .49686 L
.49828 .49703 L
.49838 .4972 L
.49847 .49735 L
.49855 .4975 L
.49863 .49763 L
.49871 .49776 L
.49878 .49789 L
.49885 .498 L
.49891 .49811 L
.49897 .49822 L
.49903 .49832 L
.49908 .49841 L
.49913 .4985 L
.49918 .49858 L
.49922 .49866 L
.49927 .49873 L
.49931 .4988 L
.49935 .49887 L
.49938 .49893 L
.49942 .49899 L
.49945 .49904 L
.49948 .4991 L
Mistroke
.49951 .49915 L
.49953 .49919 L
.49956 .49924 L
.49958 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .49939 L
.49967 .49943 L
.49969 .49946 L
.4997 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49976 .49959 L
.49978 .49961 L
.49979 .49964 L
.4998 .49966 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49982 L
.4999 .49983 L
.4999 .49984 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
Mistroke
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .062 r
.77672 .67595 m
.7546 .67814 L
.73462 .67862 L
.71653 .6777 L
.70013 .67564 L
.68523 .67266 L
.67167 .66895 L
.6593 .66467 L
.648 .65995 L
.63766 .65492 L
.62819 .64965 L
.61948 .64424 L
.61148 .63874 L
.6041 .63323 L
.5973 .62773 L
.59101 .62229 L
.5852 .61693 L
.57981 .61169 L
.57481 .60657 L
.57016 .6016 L
.56584 .59678 L
.56182 .59212 L
.55808 .58763 L
.55458 .58331 L
.55132 .57916 L
.54827 .57517 L
.54542 .57136 L
.54275 .56771 L
.54025 .56423 L
.53791 .5609 L
.53571 .55773 L
.53365 .55471 L
.53171 .55184 L
.5299 .5491 L
.52819 .5465 L
.52658 .54403 L
.52507 .54168 L
.52365 .53945 L
.52231 .53733 L
.52105 .53533 L
.51987 .53343 L
.51875 .53162 L
.5177 .52991 L
.5167 .52829 L
.51577 .52676 L
.51489 .5253 L
.51406 .52393 L
.51327 .52263 L
.51253 .52139 L
.51183 .52023 L
Mistroke
.51118 .51912 L
.51055 .51808 L
.50997 .51709 L
.50941 .51615 L
.50889 .51527 L
.5084 .51443 L
.50793 .51364 L
.50749 .51289 L
.50708 .51219 L
.50669 .51152 L
.50632 .51088 L
.50597 .51029 L
.50564 .50972 L
.50533 .50919 L
.50503 .50868 L
.50475 .50821 L
.50449 .50775 L
.50424 .50733 L
.50401 .50692 L
.50379 .50654 L
.50358 .50618 L
.50338 .50584 L
.50319 .50552 L
.50302 .50522 L
.50285 .50493 L
.50269 .50466 L
.50254 .5044 L
.5024 .50416 L
.50227 .50393 L
.50215 .50371 L
.50203 .50351 L
.50192 .50332 L
.50181 .50313 L
.50171 .50296 L
.50162 .5028 L
.50153 .50264 L
.50144 .5025 L
.50136 .50236 L
.50129 .50223 L
.50122 .50211 L
.50115 .50199 L
.50109 .50188 L
.50103 .50178 L
.50097 .50168 L
.50092 .50159 L
.50087 .5015 L
.50082 .50142 L
.50077 .50134 L
.50073 .50127 L
.50069 .5012 L
Mistroke
.50065 .50113 L
.50062 .50107 L
.50058 .50101 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .5008 L
.50044 .50076 L
.50041 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .50061 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50016 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
Mistroke
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .395 r
.70674 .49318 m
.68708 .50786 L
.66962 .51982 L
.65407 .52946 L
.6402 .53714 L
.62782 .54316 L
.61674 .54776 L
.60681 .55118 L
.5979 .55361 L
.58988 .5552 L
.58265 .55609 L
.57612 .55641 L
.57022 .55626 L
.56487 .55572 L
.56001 .55487 L
.5556 .55377 L
.55157 .55247 L
.54789 .55102 L
.54453 .54946 L
.54145 .54782 L
.53862 .54612 L
.53602 .5444 L
.53363 .54265 L
.53142 .54091 L
.52939 .53919 L
.5275 .53749 L
.52576 .53582 L
.52414 .53419 L
.52263 .5326 L
.52124 .53106 L
.51994 .52958 L
.51873 .52814 L
.5176 .52676 L
.51654 .52543 L
.51556 .52415 L
.51464 .52293 L
.51378 .52176 L
.51297 .52064 L
.51221 .51958 L
.5115 .51856 L
.51084 .51759 L
.51021 .51667 L
.50963 .51579 L
.50908 .51495 L
.50856 .51416 L
.50807 .5134 L
.50761 .51269 L
.50718 .51201 L
.50678 .51136 L
.5064 .51075 L
Mistroke
.50604 .51017 L
.5057 .50962 L
.50538 .5091 L
.50508 .50861 L
.50479 .50814 L
.50452 .5077 L
.50427 .50728 L
.50403 .50688 L
.50381 .50651 L
.5036 .50615 L
.5034 .50582 L
.50321 .5055 L
.50303 .5052 L
.50286 .50491 L
.5027 .50464 L
.50255 .50439 L
.50241 .50415 L
.50228 .50392 L
.50215 .50371 L
.50203 .5035 L
.50192 .50331 L
.50181 .50313 L
.50171 .50296 L
.50162 .50279 L
.50153 .50264 L
.50145 .5025 L
.50137 .50236 L
.50129 .50223 L
.50122 .50211 L
.50115 .50199 L
.50109 .50188 L
.50103 .50178 L
.50097 .50168 L
.50092 .50159 L
.50087 .5015 L
.50082 .50142 L
.50077 .50134 L
.50073 .50126 L
.50069 .5012 L
.50065 .50113 L
.50062 .50107 L
.50058 .50101 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .5008 L
.50044 .50076 L
.50041 .50072 L
.50039 .50068 L
.50037 .50064 L
Mistroke
.50035 .50061 L
.50033 .50057 L
.50031 .50054 L
.5003 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50016 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
Mistroke
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.264 0 1 r
.69928 .76008 m
.68637 .74908 L
.67443 .73824 L
.66337 .72761 L
.65311 .71724 L
.64359 .70714 L
.63473 .69735 L
.62649 .68789 L
.61881 .67875 L
.61165 .66996 L
.60497 .66151 L
.59872 .6534 L
.59288 .64564 L
.58742 .63821 L
.5823 .63111 L
.5775 .62433 L
.57301 .61786 L
.56879 .6117 L
.56483 .60584 L
.56111 .60026 L
.55761 .59495 L
.55433 .5899 L
.55124 .58511 L
.54833 .58056 L
.5456 .57625 L
.54302 .57215 L
.5406 .56827 L
.53831 .56458 L
.53616 .56109 L
.53413 .55779 L
.53222 .55465 L
.53042 .55169 L
.52872 .54888 L
.52712 .54622 L
.52561 .5437 L
.52418 .54132 L
.52283 .53906 L
.52156 .53693 L
.52037 .53491 L
.51923 .533 L
.51817 .53119 L
.51716 .52948 L
.51621 .52787 L
.51531 .52634 L
.51446 .52489 L
.51366 .52353 L
.51291 .52224 L
.51219 .52102 L
.51152 .51986 L
.51088 .51877 L
Mistroke
.51028 .51774 L
.50971 .51676 L
.50917 .51584 L
.50867 .51497 L
.50819 .51415 L
.50774 .51337 L
.50731 .51263 L
.50691 .51194 L
.50652 .51128 L
.50616 .51066 L
.50582 .51007 L
.5055 .50952 L
.5052 .50899 L
.50491 .5085 L
.50464 .50803 L
.50439 .50759 L
.50414 .50717 L
.50391 .50678 L
.5037 .5064 L
.5035 .50605 L
.5033 .50572 L
.50312 .5054 L
.50295 .5051 L
.50279 .50482 L
.50263 .50456 L
.50249 .50431 L
.50235 .50407 L
.50222 .50384 L
.5021 .50363 L
.50198 .50343 L
.50187 .50324 L
.50177 .50306 L
.50167 .5029 L
.50158 .50274 L
.50149 .50258 L
.50141 .50244 L
.50133 .50231 L
.50126 .50218 L
.50119 .50206 L
.50112 .50195 L
.50106 .50184 L
.501 .50174 L
.50095 .50164 L
.5009 .50155 L
.50085 .50147 L
.5008 .50139 L
.50076 .50131 L
.50071 .50124 L
.50067 .50117 L
.50064 .5011 L
Mistroke
.5006 .50104 L
.50057 .50099 L
.50054 .50093 L
.50051 .50088 L
.50048 .50083 L
.50045 .50079 L
.50043 .50074 L
.50041 .5007 L
.50038 .50066 L
.50036 .50063 L
.50034 .50059 L
.50032 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.50019 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
Mistroke
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .533 r
.80941 .25148 m
.77461 .29593 L
.74409 .33382 L
.71731 .36606 L
.69378 .39344 L
.6731 .41665 L
.65488 .43626 L
.63883 .45279 L
.62467 .46666 L
.61216 .47827 L
.60109 .48793 L
.59128 .49593 L
.58258 .50251 L
.57485 .50788 L
.56797 .51222 L
.56183 .51568 L
.55636 .5184 L
.55146 .52049 L
.54707 .52205 L
.54313 .52317 L
.53959 .52391 L
.53639 .52434 L
.53351 .52452 L
.53091 .52448 L
.52854 .52427 L
.5264 .52392 L
.52445 .52345 L
.52268 .5229 L
.52106 .52228 L
.51957 .52161 L
.51822 .5209 L
.51697 .52017 L
.51583 .51942 L
.51477 .51866 L
.5138 .5179 L
.51291 .51715 L
.51208 .51641 L
.51131 .51568 L
.5106 .51497 L
.50994 .51428 L
.50932 .51361 L
.50875 .51296 L
.50822 .51233 L
.50772 .51172 L
.50726 .51114 L
.50683 .51058 L
.50642 .51005 L
.50604 .50954 L
.50569 .50905 L
.50536 .50858 L
Mistroke
.50505 .50814 L
.50476 .50771 L
.50448 .50731 L
.50422 .50692 L
.50398 .50656 L
.50375 .50621 L
.50354 .50588 L
.50334 .50556 L
.50315 .50526 L
.50297 .50498 L
.50281 .50471 L
.50265 .50446 L
.5025 .50422 L
.50236 .50399 L
.50223 .50377 L
.5021 .50357 L
.50198 .50338 L
.50187 .50319 L
.50177 .50302 L
.50167 .50285 L
.50158 .5027 L
.50149 .50255 L
.50141 .50241 L
.50133 .50228 L
.50126 .50215 L
.50119 .50204 L
.50112 .50192 L
.50106 .50182 L
.501 .50172 L
.50094 .50163 L
.50089 .50154 L
.50084 .50145 L
.5008 .50137 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50063 .50109 L
.5006 .50103 L
.50057 .50098 L
.50053 .50092 L
.5005 .50087 L
.50048 .50082 L
.50045 .50078 L
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50055 L
.5003 .50052 L
Mistroke
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .50039 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
Mistroke
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .855 r
.73937 .66617 m
.72055 .66675 L
.70352 .66599 L
.68809 .66415 L
.67406 .66144 L
.6613 .65803 L
.64966 .65407 L
.63903 .6497 L
.62931 .64502 L
.62039 .64012 L
.61221 .63508 L
.60468 .62996 L
.59775 .62481 L
.59136 .61967 L
.58545 .61459 L
.57998 .60958 L
.57492 .60467 L
.57022 .59989 L
.56586 .59523 L
.5618 .59072 L
.55803 .58636 L
.55451 .58215 L
.55123 .57811 L
.54816 .57422 L
.5453 .57049 L
.54262 .56691 L
.54012 .5635 L
.53777 .56023 L
.53557 .55711 L
.53351 .55414 L
.53157 .55131 L
.52976 .54861 L
.52805 .54605 L
.52645 .54361 L
.52494 .54129 L
.52352 .53909 L
.52219 .537 L
.52093 .53502 L
.51975 .53314 L
.51864 .53135 L
.51759 .52966 L
.5166 .52806 L
.51567 .52654 L
.51479 .5251 L
.51397 .52373 L
.51319 .52244 L
.51245 .52122 L
.51176 .52007 L
.5111 .51897 L
.51048 .51794 L
Mistroke
.5099 .51696 L
.50935 .51603 L
.50883 .51515 L
.50834 .51432 L
.50788 .51354 L
.50744 .5128 L
.50703 .51209 L
.50664 .51143 L
.50627 .5108 L
.50593 .51021 L
.5056 .50965 L
.50529 .50912 L
.505 .50862 L
.50472 .50814 L
.50446 .5077 L
.50421 .50727 L
.50398 .50687 L
.50376 .5065 L
.50355 .50614 L
.50336 .5058 L
.50317 .50548 L
.503 .50518 L
.50283 .50489 L
.50267 .50462 L
.50253 .50437 L
.50239 .50413 L
.50226 .5039 L
.50213 .50369 L
.50201 .50348 L
.5019 .50329 L
.5018 .50311 L
.5017 .50294 L
.5016 .50278 L
.50152 .50262 L
.50143 .50248 L
.50135 .50234 L
.50128 .50221 L
.50121 .50209 L
.50114 .50198 L
.50108 .50187 L
.50102 .50176 L
.50096 .50167 L
.50091 .50158 L
.50086 .50149 L
.50081 .50141 L
.50077 .50133 L
.50073 .50126 L
.50069 .50119 L
.50065 .50112 L
.50061 .50106 L
Mistroke
.50058 .501 L
.50055 .50095 L
.50052 .50089 L
.50049 .50084 L
.50046 .5008 L
.50044 .50075 L
.50041 .50071 L
.50039 .50067 L
.50037 .50064 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .5003 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .5002 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
Mistroke
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .602 1 r
.25039 .3141 m
.26973 .31469 L
.28725 .31654 L
.30317 .3194 L
.31765 .32307 L
.33084 .32738 L
.34289 .33218 L
.35391 .33734 L
.36401 .34276 L
.37327 .34836 L
.3818 .35406 L
.38964 .3598 L
.39688 .36553 L
.40356 .37121 L
.40974 .37681 L
.41547 .3823 L
.42078 .38767 L
.42571 .39288 L
.43029 .39794 L
.43455 .40284 L
.43853 .40756 L
.44223 .4121 L
.44569 .41647 L
.44893 .42066 L
.45195 .42468 L
.45477 .42852 L
.45742 .43219 L
.4599 .4357 L
.46223 .43904 L
.46441 .44222 L
.46646 .44526 L
.46839 .44814 L
.47019 .45089 L
.47189 .4535 L
.47349 .45598 L
.475 .45833 L
.47641 .46056 L
.47774 .46268 L
.479 .46469 L
.48018 .46659 L
.48129 .4684 L
.48234 .47011 L
.48333 .47173 L
.48426 .47326 L
.48514 .47472 L
.48597 .47609 L
.48675 .4774 L
.48749 .47863 L
.48819 .4798 L
.48885 .4809 L
Mistroke
.48947 .48194 L
.49005 .48293 L
.4906 .48387 L
.49112 .48475 L
.49162 .48559 L
.49208 .48638 L
.49252 .48712 L
.49293 .48783 L
.49332 .4885 L
.49369 .48913 L
.49404 .48973 L
.49437 .49029 L
.49468 .49082 L
.49498 .49133 L
.49525 .49181 L
.49552 .49226 L
.49576 .49268 L
.496 .49309 L
.49622 .49347 L
.49643 .49383 L
.49662 .49417 L
.49681 .49449 L
.49699 .49479 L
.49715 .49508 L
.49731 .49535 L
.49746 .4956 L
.4976 .49585 L
.49773 .49607 L
.49786 .49629 L
.49797 .4965 L
.49809 .49669 L
.49819 .49687 L
.49829 .49704 L
.49839 .49721 L
.49848 .49736 L
.49856 .49751 L
.49864 .49764 L
.49871 .49777 L
.49878 .4979 L
.49885 .49801 L
.49891 .49812 L
.49897 .49822 L
.49903 .49832 L
.49908 .49841 L
.49914 .4985 L
.49918 .49858 L
.49923 .49866 L
.49927 .49874 L
.49931 .49881 L
.49935 .49887 L
Mistroke
.49938 .49893 L
.49942 .49899 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
.49956 .49924 L
.49959 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49977 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
Mistroke
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .03 1 r
.57574 .338 m
.56493 .35842 L
.5556 .37618 L
.54755 .39163 L
.54062 .40508 L
.53464 .41679 L
.52949 .42699 L
.52505 .43588 L
.52124 .44363 L
.51796 .45038 L
.51515 .45628 L
.51273 .46143 L
.51065 .46594 L
.50888 .46987 L
.50736 .47332 L
.50606 .47633 L
.50495 .47898 L
.50401 .48129 L
.50321 .48333 L
.50253 .48512 L
.50195 .4867 L
.50147 .48808 L
.50106 .48931 L
.50072 .49039 L
.50043 .49134 L
.5002 .49219 L
.5 .49294 L
.49984 .49361 L
.49971 .4942 L
.49961 .49473 L
.49953 .4952 L
.49946 .49562 L
.49941 .49599 L
.49938 .49633 L
.49935 .49664 L
.49934 .49691 L
.49933 .49716 L
.49933 .49738 L
.49933 .49758 L
.49934 .49776 L
.49935 .49793 L
.49937 .49808 L
.49938 .49822 L
.4994 .49834 L
.49942 .49846 L
.49944 .49857 L
.49946 .49866 L
.49948 .49875 L
.4995 .49884 L
.49952 .49891 L
Mistroke
.49954 .49898 L
.49956 .49905 L
.49958 .49911 L
.4996 .49916 L
.49962 .49921 L
.49964 .49926 L
.49966 .49931 L
.49967 .49935 L
.49969 .49939 L
.4997 .49943 L
.49972 .49946 L
.49973 .49949 L
.49975 .49952 L
.49976 .49955 L
.49977 .49958 L
.49978 .4996 L
.4998 .49962 L
.49981 .49964 L
.49982 .49967 L
.49983 .49968 L
.49984 .4997 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49987 .49976 L
.49988 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.49991 .49983 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
Mistroke
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .596 1 r
.71628 .46059 m
.69499 .47899 L
.67612 .49421 L
.65938 .50671 L
.6445 .51689 L
.63125 .52511 L
.61944 .53165 L
.60889 .53678 L
.59946 .5407 L
.591 .54361 L
.5834 .54568 L
.57657 .54703 L
.57041 .54779 L
.56485 .54806 L
.55982 .54793 L
.55527 .54747 L
.55113 .54675 L
.54736 .54581 L
.54393 .5447 L
.5408 .54347 L
.53794 .54214 L
.53531 .54074 L
.5329 .5393 L
.53069 .53782 L
.52865 .53634 L
.52677 .53486 L
.52503 .53339 L
.52343 .53194 L
.52194 .53052 L
.52056 .52913 L
.51928 .52778 L
.51809 .52647 L
.51699 .5252 L
.51595 .52397 L
.51499 .5228 L
.51409 .52166 L
.51325 .52058 L
.51247 .51954 L
.51174 .51854 L
.51105 .51759 L
.5104 .51668 L
.5098 .51581 L
.50923 .51499 L
.5087 .5142 L
.5082 .51345 L
.50773 .51274 L
.50729 .51206 L
.50688 .51142 L
.50649 .51081 L
.50612 .51023 L
Mistroke
.50577 .50968 L
.50545 .50916 L
.50514 .50867 L
.50485 .5082 L
.50458 .50775 L
.50432 .50733 L
.50408 .50694 L
.50385 .50656 L
.50364 .5062 L
.50344 .50586 L
.50325 .50554 L
.50306 .50524 L
.50289 .50496 L
.50273 .50468 L
.50258 .50443 L
.50244 .50419 L
.5023 .50396 L
.50218 .50374 L
.50205 .50353 L
.50194 .50334 L
.50183 .50316 L
.50173 .50298 L
.50164 .50282 L
.50155 .50267 L
.50146 .50252 L
.50138 .50238 L
.5013 .50225 L
.50123 .50213 L
.50116 .50201 L
.5011 .5019 L
.50104 .50179 L
.50098 .5017 L
.50093 .5016 L
.50088 .50151 L
.50083 .50143 L
.50078 .50135 L
.50074 .50128 L
.5007 .50121 L
.50066 .50114 L
.50062 .50108 L
.50059 .50102 L
.50056 .50096 L
.50053 .50091 L
.5005 .50086 L
.50047 .50081 L
.50044 .50077 L
.50042 .50072 L
.5004 .50068 L
.50037 .50065 L
.50035 .50061 L
Mistroke
.50033 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50022 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
Mistroke
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.849 1 0 r
.52675 .24438 m
.51844 .2703 L
.5115 .29322 L
.50574 .3135 L
.50098 .33148 L
.49707 .34744 L
.4939 .36163 L
.49134 .37427 L
.48931 .38554 L
.48773 .39561 L
.48653 .40462 L
.48564 .4127 L
.48502 .41996 L
.48462 .42649 L
.48441 .43238 L
.48435 .4377 L
.48441 .44251 L
.48458 .44688 L
.48483 .45084 L
.48515 .45445 L
.48552 .45773 L
.48593 .46074 L
.48637 .46349 L
.48683 .466 L
.4873 .46832 L
.48778 .47044 L
.48827 .4724 L
.48875 .47421 L
.48923 .47588 L
.4897 .47742 L
.49016 .47885 L
.49061 .48018 L
.49104 .48141 L
.49147 .48255 L
.49188 .48362 L
.49227 .48461 L
.49265 .48554 L
.49302 .48641 L
.49337 .48721 L
.49371 .48797 L
.49403 .48868 L
.49433 .48934 L
.49463 .48996 L
.49491 .49054 L
.49517 .49109 L
.49543 .4916 L
.49567 .49208 L
.4959 .49254 L
.49612 .49296 L
.49632 .49336 L
Mistroke
.49652 .49374 L
.49671 .49409 L
.49688 .49443 L
.49705 .49474 L
.49721 .49504 L
.49736 .49531 L
.4975 .49558 L
.49764 .49583 L
.49777 .49606 L
.49789 .49628 L
.498 .49649 L
.49811 .49668 L
.49822 .49687 L
.49831 .49704 L
.4984 .49721 L
.49849 .49736 L
.49857 .49751 L
.49865 .49765 L
.49873 .49778 L
.4988 .4979 L
.49886 .49802 L
.49892 .49813 L
.49898 .49823 L
.49904 .49833 L
.49909 .49842 L
.49914 .49851 L
.49919 .49859 L
.49923 .49867 L
.49928 .49874 L
.49932 .49881 L
.49935 .49888 L
.49939 .49894 L
.49942 .499 L
.49945 .49905 L
.49948 .49911 L
.49951 .49915 L
.49954 .4992 L
.49956 .49925 L
.49959 .49929 L
.49961 .49933 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .4996 L
.49978 .49962 L
Mistroke
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .4997 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .4998 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .099 1 r
.45016 .3411 m
.45126 .35271 L
.45253 .36329 L
.45391 .37296 L
.45538 .38181 L
.45692 .38993 L
.45849 .39739 L
.46008 .40425 L
.46168 .41057 L
.46327 .4164 L
.46484 .42179 L
.46639 .42678 L
.4679 .43141 L
.46938 .4357 L
.47081 .43968 L
.4722 .44339 L
.47354 .44684 L
.47483 .45006 L
.47608 .45306 L
.47727 .45586 L
.47842 .45848 L
.47951 .46093 L
.48056 .46323 L
.48156 .46538 L
.48252 .46739 L
.48343 .46928 L
.4843 .47105 L
.48512 .47272 L
.48591 .47428 L
.48666 .47575 L
.48736 .47713 L
.48804 .47843 L
.48868 .47965 L
.48929 .4808 L
.48986 .48189 L
.49041 .48291 L
.49093 .48387 L
.49142 .48477 L
.49188 .48563 L
.49232 .48643 L
.49274 .48719 L
.49313 .4879 L
.49351 .48858 L
.49386 .48922 L
.4942 .48982 L
.49451 .49038 L
.49481 .49092 L
.4951 .49142 L
.49537 .4919 L
.49562 .49235 L
Mistroke
.49586 .49277 L
.49609 .49317 L
.4963 .49355 L
.4965 .49391 L
.4967 .49425 L
.49688 .49456 L
.49705 .49486 L
.49721 .49515 L
.49736 .49542 L
.49751 .49567 L
.49765 .49591 L
.49778 .49614 L
.4979 .49635 L
.49801 .49655 L
.49812 .49674 L
.49823 .49692 L
.49832 .49709 L
.49842 .49725 L
.4985 .4974 L
.49859 .49755 L
.49866 .49768 L
.49874 .49781 L
.49881 .49793 L
.49887 .49804 L
.49893 .49815 L
.49899 .49825 L
.49905 .49835 L
.4991 .49844 L
.49915 .49853 L
.4992 .49861 L
.49924 .49869 L
.49928 .49876 L
.49932 .49883 L
.49936 .49889 L
.4994 .49895 L
.49943 .49901 L
.49946 .49906 L
.49949 .49912 L
.49952 .49917 L
.49954 .49921 L
.49957 .49925 L
.49959 .4993 L
.49962 .49933 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
Mistroke
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49984 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.852 0 1 r
.30325 .79443 m
.32846 .75331 L
.35037 .71777 L
.36941 .68708 L
.38596 .66057 L
.40035 .63768 L
.41287 .61793 L
.42375 .60089 L
.43323 .5862 L
.44147 .57354 L
.44866 .56263 L
.45492 .55324 L
.46037 .54516 L
.46513 .53821 L
.46929 .53224 L
.47291 .52711 L
.47608 .52272 L
.47885 .51895 L
.48127 .51573 L
.4834 .51297 L
.48526 .51062 L
.48689 .50862 L
.48832 .50692 L
.48958 .50547 L
.49068 .50425 L
.49166 .50321 L
.49252 .50235 L
.49328 .50162 L
.49395 .50101 L
.49454 .5005 L
.49507 .50008 L
.49553 .49974 L
.49595 .49946 L
.49632 .49924 L
.49665 .49906 L
.49694 .49892 L
.49721 .49882 L
.49744 .49874 L
.49766 .49868 L
.49785 .49865 L
.49802 .49863 L
.49818 .49862 L
.49832 .49863 L
.49844 .49865 L
.49856 .49867 L
.49867 .4987 L
.49876 .49873 L
.49885 .49876 L
.49893 .4988 L
.499 .49884 L
Mistroke
.49907 .49888 L
.49913 .49893 L
.49919 .49897 L
.49924 .49901 L
.49929 .49905 L
.49934 .49909 L
.49938 .49914 L
.49942 .49917 L
.49946 .49921 L
.49949 .49925 L
.49952 .49929 L
.49955 .49932 L
.49958 .49935 L
.4996 .49939 L
.49963 .49942 L
.49965 .49945 L
.49967 .49948 L
.49969 .4995 L
.49971 .49953 L
.49972 .49955 L
.49974 .49958 L
.49975 .4996 L
.49977 .49962 L
.49978 .49964 L
.49979 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49985 .49975 L
.49986 .49977 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
Mistroke
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.707 1 0 r
.57184 .31087 m
.56079 .33358 L
.55129 .3534 L
.54313 .37071 L
.53614 .38583 L
.53015 .39905 L
.52502 .41062 L
.52064 .42075 L
.5169 .42962 L
.51371 .43741 L
.511 .44424 L
.5087 .45025 L
.50676 .45553 L
.50511 .46018 L
.50373 .46429 L
.50257 .46791 L
.5016 .47111 L
.5008 .47394 L
.50013 .47645 L
.49959 .47868 L
.49914 .48067 L
.49879 .48243 L
.4985 .48401 L
.49828 .48541 L
.49811 .48667 L
.49799 .4878 L
.4979 .48882 L
.49785 .48973 L
.49782 .49055 L
.49781 .49129 L
.49782 .49197 L
.49784 .49258 L
.49788 .49313 L
.49792 .49363 L
.49798 .49409 L
.49803 .49451 L
.49809 .4949 L
.49816 .49525 L
.49822 .49557 L
.49829 .49587 L
.49836 .49614 L
.49843 .4964 L
.49849 .49663 L
.49856 .49684 L
.49862 .49704 L
.49869 .49723 L
.49875 .4974 L
.49881 .49756 L
.49886 .49771 L
.49892 .49785 L
Mistroke
.49897 .49798 L
.49902 .4981 L
.49907 .49821 L
.49912 .49832 L
.49917 .49842 L
.49921 .49851 L
.49925 .4986 L
.49929 .49868 L
.49933 .49875 L
.49936 .49883 L
.49939 .49889 L
.49943 .49896 L
.49946 .49902 L
.49949 .49907 L
.49951 .49912 L
.49954 .49917 L
.49956 .49922 L
.49959 .49926 L
.49961 .49931 L
.49963 .49935 L
.49965 .49938 L
.49967 .49942 L
.49969 .49945 L
.4997 .49948 L
.49972 .49951 L
.49974 .49954 L
.49975 .49956 L
.49976 .49959 L
.49978 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
Mistroke
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
Mistroke
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .811 0 r
.7559 .2508 m
.72612 .29168 L
.70008 .32667 L
.67729 .3566 L
.65732 .38216 L
.63982 .40396 L
.62446 .42251 L
.61097 .43826 L
.5991 .45162 L
.58866 .46291 L
.57946 .47243 L
.57134 .48042 L
.56417 .48711 L
.55783 .49268 L
.55221 .4973 L
.54722 .5011 L
.54279 .5042 L
.53885 .50671 L
.53534 .50871 L
.5322 .51029 L
.5294 .51151 L
.52689 .51242 L
.52463 .51307 L
.52261 .51351 L
.52078 .51377 L
.51913 .51388 L
.51764 .51387 L
.51629 .51376 L
.51507 .51357 L
.51395 .51331 L
.51294 .513 L
.51201 .51266 L
.51116 .51228 L
.51039 .51188 L
.50968 .51146 L
.50902 .51104 L
.50842 .51061 L
.50787 .51018 L
.50736 .50975 L
.50688 .50933 L
.50645 .50892 L
.50604 .50852 L
.50566 .50812 L
.50531 .50774 L
.50499 .50737 L
.50468 .50702 L
.5044 .50667 L
.50414 .50634 L
.50389 .50602 L
.50366 .50572 L
Mistroke
.50344 .50543 L
.50324 .50515 L
.50305 .50489 L
.50288 .50463 L
.50271 .50439 L
.50255 .50416 L
.50241 .50394 L
.50227 .50373 L
.50214 .50353 L
.50202 .50335 L
.5019 .50317 L
.50179 .503 L
.50169 .50284 L
.5016 .50268 L
.50151 .50254 L
.50142 .5024 L
.50134 .50227 L
.50127 .50215 L
.5012 .50203 L
.50113 .50192 L
.50107 .50182 L
.50101 .50172 L
.50095 .50163 L
.5009 .50154 L
.50085 .50145 L
.5008 .50137 L
.50076 .5013 L
.50071 .50123 L
.50068 .50116 L
.50064 .5011 L
.5006 .50104 L
.50057 .50098 L
.50054 .50093 L
.50051 .50087 L
.50048 .50083 L
.50045 .50078 L
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50056 L
.5003 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .5004 L
.50022 .50037 L
.5002 .50035 L
Mistroke
.50019 .50033 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
Mistroke
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .097 r
.26934 .59164 m
.29317 .56734 L
.3142 .54695 L
.33279 .52991 L
.34923 .51573 L
.36381 .50402 L
.37675 .49439 L
.38824 .48655 L
.39848 .48023 L
.40761 .47521 L
.41576 .47127 L
.42305 .46826 L
.42959 .46603 L
.43547 .46446 L
.44075 .46343 L
.44551 .46286 L
.44981 .46266 L
.4537 .46277 L
.45722 .46314 L
.46042 .46371 L
.46333 .46445 L
.46599 .46531 L
.46841 .46628 L
.47063 .46731 L
.47266 .4684 L
.47452 .46953 L
.47623 .47067 L
.47781 .47182 L
.47927 .47297 L
.48061 .47412 L
.48185 .47524 L
.48301 .47634 L
.48407 .47742 L
.48506 .47847 L
.48599 .47949 L
.48684 .48047 L
.48764 .48142 L
.48839 .48233 L
.48908 .48321 L
.48973 .48405 L
.49034 .48486 L
.49091 .48563 L
.49144 .48637 L
.49194 .48707 L
.49241 .48775 L
.49285 .48839 L
.49326 .489 L
.49364 .48958 L
.49401 .49013 L
.49435 .49065 L
Mistroke
.49467 .49115 L
.49497 .49162 L
.49526 .49207 L
.49553 .4925 L
.49578 .4929 L
.49602 .49328 L
.49624 .49365 L
.49645 .49399 L
.49665 .49432 L
.49684 .49463 L
.49701 .49492 L
.49718 .49519 L
.49734 .49546 L
.49749 .4957 L
.49763 .49594 L
.49776 .49616 L
.49788 .49637 L
.498 .49657 L
.49811 .49676 L
.49822 .49693 L
.49831 .4971 L
.49841 .49726 L
.4985 .49741 L
.49858 .49755 L
.49866 .49769 L
.49873 .49781 L
.4988 .49793 L
.49887 .49805 L
.49893 .49816 L
.49899 .49826 L
.49905 .49835 L
.4991 .49844 L
.49915 .49853 L
.4992 .49861 L
.49924 .49869 L
.49928 .49876 L
.49932 .49883 L
.49936 .49889 L
.49939 .49895 L
.49943 .49901 L
.49946 .49906 L
.49949 .49912 L
.49952 .49916 L
.49954 .49921 L
.49957 .49925 L
.49959 .4993 L
.49962 .49933 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
Mistroke
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49984 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
Mistroke
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .444 r
.20675 .73942 m
.23983 .69693 L
.26882 .6607 L
.29426 .62985 L
.3166 .60363 L
.33625 .58141 L
.35353 .56262 L
.36876 .54677 L
.3822 .53345 L
.39407 .5223 L
.40456 .513 L
.41386 .5053 L
.4221 .49895 L
.42942 .49376 L
.43594 .48956 L
.44175 .48619 L
.44693 .48354 L
.45156 .48149 L
.45571 .47995 L
.45943 .47883 L
.46278 .47808 L
.46579 .47762 L
.46851 .47741 L
.47097 .4774 L
.4732 .47756 L
.47522 .47786 L
.47706 .47826 L
.47873 .47876 L
.48025 .47932 L
.48165 .47993 L
.48292 .48057 L
.48409 .48125 L
.48517 .48194 L
.48616 .48263 L
.48707 .48333 L
.48791 .48403 L
.48869 .48471 L
.48941 .48539 L
.49008 .48605 L
.4907 .48669 L
.49128 .48731 L
.49181 .48792 L
.49231 .4885 L
.49278 .48906 L
.49321 .4896 L
.49362 .49012 L
.49399 .49062 L
.49435 .4911 L
.49468 .49155 L
.49499 .49199 L
Mistroke
.49528 .49241 L
.49555 .4928 L
.49581 .49318 L
.49605 .49354 L
.49628 .49388 L
.49649 .4942 L
.49669 .49451 L
.49688 .49481 L
.49706 .49508 L
.49722 .49535 L
.49738 .4956 L
.49753 .49583 L
.49767 .49606 L
.4978 .49627 L
.49792 .49647 L
.49804 .49667 L
.49815 .49685 L
.49825 .49702 L
.49835 .49718 L
.49844 .49733 L
.49853 .49748 L
.49861 .49762 L
.49869 .49775 L
.49876 .49787 L
.49883 .49799 L
.49889 .4981 L
.49895 .4982 L
.49901 .4983 L
.49907 .49839 L
.49912 .49848 L
.49917 .49857 L
.49921 .49864 L
.49926 .49872 L
.4993 .49879 L
.49934 .49886 L
.49937 .49892 L
.49941 .49898 L
.49944 .49903 L
.49947 .49909 L
.4995 .49914 L
.49953 .49918 L
.49955 .49923 L
.49958 .49927 L
.4996 .49931 L
.49962 .49935 L
.49964 .49939 L
.49966 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
Mistroke
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
Mistroke
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .681 r
.27431 .22929 m
.28947 .2395 L
.30344 .24978 L
.31631 .26003 L
.32821 .2702 L
.33921 .28021 L
.3494 .29002 L
.35885 .2996 L
.36763 .30892 L
.37579 .31796 L
.38339 .32669 L
.39046 .33512 L
.39706 .34324 L
.40322 .35103 L
.40898 .35851 L
.41436 .36568 L
.4194 .37253 L
.42412 .37909 L
.42854 .38534 L
.43268 .3913 L
.43657 .39698 L
.44022 .40239 L
.44365 .40754 L
.44688 .41244 L
.4499 .41709 L
.45275 .42151 L
.45543 .4257 L
.45796 .42969 L
.46033 .43346 L
.46257 .43705 L
.46467 .44044 L
.46666 .44366 L
.46853 .44671 L
.47029 .4496 L
.47195 .45234 L
.47352 .45493 L
.47499 .45738 L
.47639 .4597 L
.4777 .4619 L
.47894 .46398 L
.48012 .46595 L
.48122 .46781 L
.48226 .46957 L
.48325 .47124 L
.48418 .47281 L
.48505 .4743 L
.48588 .47571 L
.48666 .47704 L
.4874 .4783 L
.4881 .47949 L
Mistroke
.48876 .48062 L
.48938 .48169 L
.48997 .48269 L
.49052 .48364 L
.49105 .48454 L
.49154 .48539 L
.49201 .4862 L
.49245 .48696 L
.49287 .48767 L
.49326 .48835 L
.49363 .48899 L
.49398 .4896 L
.49432 .49017 L
.49463 .49071 L
.49493 .49122 L
.49521 .49171 L
.49547 .49216 L
.49572 .49259 L
.49596 .493 L
.49618 .49339 L
.49639 .49375 L
.49659 .4941 L
.49678 .49442 L
.49695 .49473 L
.49712 .49502 L
.49728 .49529 L
.49743 .49555 L
.49757 .4958 L
.49771 .49603 L
.49783 .49625 L
.49795 .49646 L
.49807 .49665 L
.49817 .49684 L
.49827 .49701 L
.49837 .49717 L
.49846 .49733 L
.49854 .49748 L
.49862 .49762 L
.4987 .49775 L
.49877 .49787 L
.49884 .49799 L
.4989 .4981 L
.49896 .4982 L
.49902 .4983 L
.49907 .4984 L
.49913 .49849 L
.49917 .49857 L
.49922 .49865 L
.49926 .49872 L
.4993 .49879 L
Mistroke
.49934 .49886 L
.49938 .49892 L
.49941 .49898 L
.49944 .49904 L
.49948 .49909 L
.4995 .49914 L
.49953 .49919 L
.49956 .49923 L
.49958 .49928 L
.4996 .49932 L
.49963 .49935 L
.49965 .49939 L
.49967 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49978 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
Mistroke
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .111 r
.6697 .50516 m
.65381 .51619 L
.63967 .52511 L
.62707 .53222 L
.61581 .53781 L
.60574 .5421 L
.59672 .54531 L
.58863 .5476 L
.58135 .54913 L
.57478 .55002 L
.56886 .55038 L
.56351 .5503 L
.55866 .54987 L
.55425 .54915 L
.55025 .54819 L
.5466 .54706 L
.54327 .54579 L
.54022 .5444 L
.53744 .54295 L
.53488 .54144 L
.53253 .5399 L
.53036 .53834 L
.52836 .53679 L
.52652 .53524 L
.52482 .53372 L
.52324 .53222 L
.52178 .53076 L
.52042 .52934 L
.51916 .52796 L
.51798 .52662 L
.51689 .52533 L
.51587 .52409 L
.51492 .52289 L
.51403 .52175 L
.5132 .52065 L
.51242 .5196 L
.51169 .51859 L
.51101 .51763 L
.51037 .51672 L
.50977 .51584 L
.50921 .51501 L
.50868 .51422 L
.50818 .51347 L
.50772 .51276 L
.50728 .51208 L
.50686 .51143 L
.50648 .51082 L
.50611 .51024 L
.50576 .50969 L
.50544 .50917 L
Mistroke
.50513 .50867 L
.50485 .5082 L
.50457 .50776 L
.50432 .50734 L
.50408 .50694 L
.50385 .50656 L
.50364 .5062 L
.50343 .50586 L
.50324 .50554 L
.50306 .50524 L
.50289 .50495 L
.50273 .50468 L
.50258 .50443 L
.50244 .50418 L
.5023 .50396 L
.50217 .50374 L
.50205 .50353 L
.50194 .50334 L
.50183 .50316 L
.50173 .50298 L
.50163 .50282 L
.50154 .50266 L
.50146 .50252 L
.50138 .50238 L
.5013 .50225 L
.50123 .50212 L
.50116 .50201 L
.5011 .5019 L
.50104 .50179 L
.50098 .50169 L
.50093 .5016 L
.50088 .50151 L
.50083 .50143 L
.50078 .50135 L
.50074 .50128 L
.5007 .50121 L
.50066 .50114 L
.50062 .50108 L
.50059 .50102 L
.50056 .50096 L
.50053 .50091 L
.5005 .50086 L
.50047 .50081 L
.50044 .50077 L
.50042 .50072 L
.5004 .50068 L
.50037 .50065 L
.50035 .50061 L
.50033 .50058 L
.50032 .50055 L
Mistroke
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
Mistroke
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .128 0 r
.63255 .31315 m
.61582 .33977 L
.60127 .36275 L
.58861 .38257 L
.5776 .39966 L
.56801 .41439 L
.55966 .42708 L
.55238 .43801 L
.54604 .44741 L
.54051 .45549 L
.53568 .46244 L
.53146 .46841 L
.52778 .47352 L
.52456 .4779 L
.52175 .48166 L
.51928 .48486 L
.51712 .4876 L
.51522 .48993 L
.51356 .49191 L
.5121 .4936 L
.51081 .49502 L
.50968 .49623 L
.50868 .49724 L
.5078 .49809 L
.50702 .4988 L
.50633 .49939 L
.50572 .49988 L
.50518 .50028 L
.5047 .5006 L
.50427 .50086 L
.50388 .50107 L
.50354 .50123 L
.50324 .50136 L
.50296 .50145 L
.50271 .50151 L
.50249 .50156 L
.50229 .50158 L
.50211 .50159 L
.50195 .50158 L
.5018 .50156 L
.50167 .50154 L
.50154 .50151 L
.50143 .50147 L
.50133 .50143 L
.50124 .50138 L
.50115 .50134 L
.50107 .50129 L
.501 .50124 L
.50094 .50119 L
.50087 .50114 L
Mistroke
.50082 .50109 L
.50077 .50105 L
.50072 .501 L
.50067 .50095 L
.50063 .50091 L
.50059 .50087 L
.50055 .50082 L
.50052 .50078 L
.50049 .50075 L
.50046 .50071 L
.50043 .50067 L
.50041 .50064 L
.50038 .50061 L
.50036 .50058 L
.50034 .50055 L
.50032 .50052 L
.5003 .50049 L
.50028 .50046 L
.50027 .50044 L
.50025 .50042 L
.50024 .50039 L
.50022 .50037 L
.50021 .50035 L
.5002 .50033 L
.50019 .50032 L
.50018 .5003 L
.50017 .50028 L
.50016 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50013 .50021 L
.50012 .5002 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
Mistroke
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.17 1 0 r
.78435 .73971 m
.76295 .73641 L
.7435 .73196 L
.72578 .72661 L
.70962 .72057 L
.69484 .71399 L
.6813 .70704 L
.66889 .69982 L
.65748 .69244 L
.64698 .68498 L
.63731 .67751 L
.62837 .67009 L
.62012 .66276 L
.61247 .65557 L
.60538 .64853 L
.5988 .64167 L
.59269 .63502 L
.587 .62858 L
.58171 .62236 L
.57677 .61636 L
.57216 .6106 L
.56786 .60507 L
.56384 .59977 L
.56007 .59469 L
.55655 .58984 L
.55325 .5852 L
.55016 .58078 L
.54725 .57657 L
.54453 .57255 L
.54197 .56873 L
.53957 .5651 L
.53731 .56165 L
.53519 .55837 L
.53319 .55525 L
.53131 .55229 L
.52954 .54948 L
.52787 .54682 L
.5263 .5443 L
.52482 .54191 L
.52343 .53964 L
.52212 .53749 L
.52088 .53546 L
.51971 .53353 L
.51861 .53171 L
.51758 .52998 L
.5166 .52834 L
.51567 .5268 L
.5148 .52533 L
.51398 .52395 L
.5132 .52264 L
Mistroke
.51247 .5214 L
.51178 .52023 L
.51112 .51912 L
.51051 .51807 L
.50993 .51708 L
.50938 .51614 L
.50886 .51526 L
.50837 .51442 L
.5079 .51363 L
.50747 .51288 L
.50705 .51217 L
.50666 .5115 L
.5063 .51087 L
.50595 .51027 L
.50562 .50971 L
.50531 .50917 L
.50502 .50867 L
.50474 .50819 L
.50448 .50774 L
.50423 .50731 L
.504 .50691 L
.50378 .50653 L
.50357 .50617 L
.50337 .50583 L
.50319 .50551 L
.50301 .50521 L
.50284 .50492 L
.50269 .50465 L
.50254 .50439 L
.5024 .50415 L
.50227 .50392 L
.50214 .50371 L
.50202 .5035 L
.50191 .50331 L
.50181 .50313 L
.50171 .50295 L
.50161 .50279 L
.50152 .50264 L
.50144 .50249 L
.50136 .50236 L
.50129 .50223 L
.50121 .5021 L
.50115 .50199 L
.50108 .50188 L
.50102 .50177 L
.50097 .50168 L
.50091 .50158 L
.50086 .5015 L
.50082 .50141 L
.50077 .50134 L
Mistroke
.50073 .50126 L
.50069 .50119 L
.50065 .50113 L
.50061 .50106 L
.50058 .50101 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .5008 L
.50044 .50076 L
.50041 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .5006 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .50041 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
Mistroke
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .268 r
.56722 .71385 m
.56571 .69824 L
.564 .68401 L
.56213 .671 L
.56014 .65909 L
.55807 .64817 L
.55594 .63813 L
.55379 .6289 L
.55164 .6204 L
.54949 .61255 L
.54737 .60529 L
.54528 .59858 L
.54324 .59235 L
.54126 .58658 L
.53932 .58121 L
.53745 .57622 L
.53565 .57158 L
.5339 .56725 L
.53223 .56321 L
.53062 .55943 L
.52907 .55591 L
.5276 .55261 L
.52619 .54952 L
.52484 .54663 L
.52355 .54391 L
.52232 .54137 L
.52115 .53898 L
.52004 .53674 L
.51898 .53464 L
.51797 .53266 L
.51702 .5308 L
.51611 .52905 L
.51525 .5274 L
.51443 .52585 L
.51365 .5244 L
.51292 .52302 L
.51222 .52173 L
.51156 .52051 L
.51093 .51936 L
.51034 .51827 L
.50978 .51725 L
.50925 .51629 L
.50874 .51538 L
.50827 .51452 L
.50782 .51372 L
.50739 .51295 L
.50699 .51223 L
.5066 .51155 L
.50624 .51091 L
.5059 .51031 L
Mistroke
.50558 .50973 L
.50527 .5092 L
.50498 .50869 L
.50471 .5082 L
.50445 .50775 L
.50421 .50732 L
.50397 .50692 L
.50376 .50653 L
.50355 .50617 L
.50335 .50583 L
.50317 .50551 L
.503 .50521 L
.50283 .50492 L
.50268 .50465 L
.50253 .50439 L
.50239 .50415 L
.50226 .50392 L
.50213 .5037 L
.50202 .5035 L
.50191 .5033 L
.5018 .50312 L
.5017 .50295 L
.50161 .50279 L
.50152 .50263 L
.50144 .50249 L
.50136 .50235 L
.50128 .50222 L
.50121 .5021 L
.50114 .50198 L
.50108 .50187 L
.50102 .50177 L
.50097 .50167 L
.50091 .50158 L
.50086 .50149 L
.50081 .50141 L
.50077 .50133 L
.50073 .50126 L
.50069 .50119 L
.50065 .50112 L
.50061 .50106 L
.50058 .501 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .5008 L
.50044 .50076 L
.50041 .50071 L
.50039 .50068 L
.50037 .50064 L
.50035 .5006 L
Mistroke
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50045 L
.50025 .50043 L
.50023 .50041 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
Mistroke
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .274 r
.60983 .71672 m
.60438 .70374 L
.59914 .69161 L
.59413 .68027 L
.58933 .66966 L
.58474 .65972 L
.58037 .65041 L
.57619 .64168 L
.57221 .63349 L
.56842 .6258 L
.56481 .61858 L
.56138 .6118 L
.55812 .60542 L
.55503 .59942 L
.55209 .59378 L
.5493 .58847 L
.54665 .58347 L
.54414 .57877 L
.54176 .57434 L
.5395 .57016 L
.53736 .56622 L
.53534 .56251 L
.53342 .55902 L
.5316 .55572 L
.52988 .55261 L
.52826 .54968 L
.52671 .54691 L
.52526 .5443 L
.52388 .54184 L
.52257 .53951 L
.52134 .53732 L
.52017 .53525 L
.51906 .53329 L
.51802 .53144 L
.51703 .5297 L
.5161 .52806 L
.51521 .5265 L
.51438 .52504 L
.51359 .52365 L
.51284 .52234 L
.51214 .52111 L
.51147 .51994 L
.51084 .51884 L
.51024 .5178 L
.50968 .51681 L
.50915 .51589 L
.50864 .51501 L
.50817 .51418 L
.50772 .5134 L
.50729 .51266 L
Mistroke
.50689 .51196 L
.50651 .5113 L
.50615 .51068 L
.50582 .51009 L
.5055 .50953 L
.50519 .509 L
.50491 .50851 L
.50464 .50804 L
.50438 .50759 L
.50414 .50718 L
.50391 .50678 L
.5037 .50641 L
.50349 .50605 L
.5033 .50572 L
.50312 .5054 L
.50295 .50511 L
.50278 .50482 L
.50263 .50456 L
.50249 .50431 L
.50235 .50407 L
.50222 .50385 L
.5021 .50363 L
.50198 .50343 L
.50187 .50324 L
.50177 .50306 L
.50167 .5029 L
.50158 .50274 L
.50149 .50259 L
.50141 .50244 L
.50133 .50231 L
.50126 .50218 L
.50119 .50206 L
.50112 .50195 L
.50106 .50184 L
.501 .50174 L
.50095 .50164 L
.5009 .50155 L
.50085 .50147 L
.5008 .50139 L
.50076 .50131 L
.50071 .50124 L
.50067 .50117 L
.50064 .5011 L
.5006 .50104 L
.50057 .50099 L
.50054 .50093 L
.50051 .50088 L
.50048 .50083 L
.50045 .50079 L
.50043 .50074 L
Mistroke
.50041 .5007 L
.50038 .50066 L
.50036 .50063 L
.50034 .50059 L
.50032 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.50019 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
Mistroke
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.261 1 0 r
.28835 .8031 m
.31517 .76014 L
.33849 .72306 L
.35877 .69106 L
.37641 .66345 L
.39177 .63965 L
.40513 .61913 L
.41678 .60145 L
.42692 .58623 L
.43577 .57314 L
.44348 .56188 L
.45021 .55221 L
.45609 .5439 L
.46122 .53678 L
.46571 .53068 L
.46964 .52546 L
.47308 .521 L
.47609 .51719 L
.47874 .51395 L
.48106 .51119 L
.4831 .50885 L
.48489 .50686 L
.48647 .50519 L
.48787 .50378 L
.4891 .5026 L
.49018 .50162 L
.49115 .5008 L
.492 .50012 L
.49276 .49957 L
.49343 .49912 L
.49403 .49875 L
.49456 .49847 L
.49504 .49824 L
.49547 .49807 L
.49585 .49795 L
.4962 .49786 L
.49651 .4978 L
.49679 .49777 L
.49704 .49776 L
.49727 .49777 L
.49748 .4978 L
.49766 .49783 L
.49784 .49788 L
.49799 .49793 L
.49813 .49799 L
.49826 .49805 L
.49838 .49812 L
.49849 .49819 L
.4986 .49826 L
.49869 .49833 L
Mistroke
.49877 .49839 L
.49885 .49846 L
.49893 .49853 L
.49899 .4986 L
.49906 .49866 L
.49912 .49872 L
.49917 .49878 L
.49922 .49884 L
.49927 .4989 L
.49931 .49895 L
.49935 .499 L
.49939 .49905 L
.49943 .4991 L
.49946 .49915 L
.49949 .49919 L
.49952 .49923 L
.49955 .49927 L
.49958 .49931 L
.4996 .49935 L
.49962 .49938 L
.49965 .49941 L
.49967 .49945 L
.49968 .49948 L
.4997 .4995 L
.49972 .49953 L
.49974 .49956 L
.49975 .49958 L
.49976 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .4997 L
.49983 .49972 L
.49984 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .4998 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
Mistroke
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
Mistroke
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .76 r
.61932 .2897 m
.6033 .31764 L
.58944 .34185 L
.57742 .36284 L
.56702 .38103 L
.558 .3968 L
.5502 .41047 L
.54344 .42232 L
.53758 .4326 L
.53251 .4415 L
.52812 .44923 L
.52432 .45593 L
.52103 .46173 L
.51818 .46677 L
.51571 .47114 L
.51358 .47493 L
.51173 .47821 L
.51013 .48106 L
.50875 .48354 L
.50755 .48568 L
.50651 .48755 L
.50562 .48916 L
.50484 .49057 L
.50417 .49179 L
.50359 .49284 L
.50309 .49376 L
.50266 .49456 L
.50229 .49525 L
.50196 .49586 L
.50168 .49638 L
.50144 .49684 L
.50124 .49723 L
.50106 .49758 L
.5009 .49788 L
.50077 .49814 L
.50065 .49837 L
.50056 .49857 L
.50047 .49874 L
.5004 .49889 L
.50034 .49902 L
.50028 .49914 L
.50024 .49924 L
.5002 .49932 L
.50016 .4994 L
.50013 .49947 L
.50011 .49953 L
.50009 .49958 L
.50007 .49963 L
.50005 .49967 L
.50004 .4997 L
Mistroke
.50003 .49973 L
.50002 .49976 L
.50001 .49978 L
.50001 .49981 L
.5 .49982 L
.5 .49984 L
.5 .49986 L
.49999 .49987 L
.49999 .49988 L
.49999 .49989 L
.49999 .4999 L
.49999 .49991 L
.49999 .49992 L
.49998 .49992 L
.49998 .49993 L
.49998 .49994 L
.49998 .49994 L
.49998 .49995 L
.49998 .49995 L
.49999 .49995 L
.49999 .49996 L
.49999 .49996 L
.49999 .49996 L
.49999 .49997 L
.49999 .49997 L
.49999 .49997 L
.49999 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
Mistroke
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.249 0 1 r
.53083 .44744 m
.52674 .45449 L
.52318 .4606 L
.52011 .46589 L
.51744 .47047 L
.51513 .47444 L
.51312 .47788 L
.51138 .48085 L
.50988 .48343 L
.50857 .48566 L
.50744 .4876 L
.50645 .48927 L
.5056 .49072 L
.50486 .49198 L
.50422 .49306 L
.50367 .49401 L
.50319 .49482 L
.50277 .49552 L
.50241 .49613 L
.50209 .49666 L
.50182 .49712 L
.50158 .49751 L
.50138 .49786 L
.5012 .49815 L
.50104 .49841 L
.50091 .49863 L
.50079 .49882 L
.50069 .49899 L
.5006 .49913 L
.50053 .49925 L
.50046 .49936 L
.5004 .49945 L
.50035 .49953 L
.50031 .4996 L
.50027 .49966 L
.50024 .49971 L
.50021 .49975 L
.50018 .49979 L
.50016 .49982 L
.50014 .49985 L
.50012 .49987 L
.50011 .49989 L
.5001 .49991 L
.50009 .49993 L
.50008 .49994 L
.50007 .49995 L
.50006 .49996 L
.50005 .49997 L
.50005 .49997 L
.50004 .49998 L
Mistroke
.50004 .49998 L
.50003 .49999 L
.50003 .49999 L
.50003 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .918 1 r
.28419 .65528 m
.30806 .62599 L
.32901 .60108 L
.34743 .57994 L
.36362 .56204 L
.37789 .54693 L
.39047 .53422 L
.40157 .52355 L
.41139 .51465 L
.42008 .50725 L
.42778 .50114 L
.43462 .49613 L
.4407 .49206 L
.44611 .48878 L
.45094 .48618 L
.45525 .48415 L
.45911 .48261 L
.46258 .48148 L
.46569 .48068 L
.46849 .48018 L
.47101 .47991 L
.47329 .47983 L
.47535 .47992 L
.47722 .48014 L
.47892 .48047 L
.48047 .48088 L
.48188 .48136 L
.48316 .48189 L
.48434 .48245 L
.48542 .48304 L
.48641 .48365 L
.48732 .48427 L
.48816 .4849 L
.48894 .48552 L
.48965 .48613 L
.49032 .48674 L
.49093 .48733 L
.4915 .48791 L
.49203 .48847 L
.49252 .48902 L
.49298 .48955 L
.4934 .49006 L
.4938 .49055 L
.49417 .49102 L
.49452 .49147 L
.49484 .4919 L
.49514 .49231 L
.49543 .49271 L
.49569 .49309 L
.49594 .49345 L
Mistroke
.49618 .49379 L
.4964 .49412 L
.4966 .49443 L
.4968 .49472 L
.49698 .495 L
.49715 .49527 L
.49731 .49552 L
.49747 .49576 L
.49761 .49599 L
.49774 .4962 L
.49787 .49641 L
.49799 .4966 L
.4981 .49679 L
.49821 .49696 L
.49831 .49713 L
.4984 .49728 L
.49849 .49743 L
.49858 .49757 L
.49866 .4977 L
.49873 .49783 L
.4988 .49795 L
.49887 .49806 L
.49893 .49817 L
.49899 .49827 L
.49905 .49836 L
.4991 .49845 L
.49915 .49854 L
.4992 .49862 L
.49924 .49869 L
.49928 .49876 L
.49932 .49883 L
.49936 .4989 L
.4994 .49896 L
.49943 .49901 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49954 .49921 L
.49957 .49926 L
.49959 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
Mistroke
.49978 .49962 L
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.997 1 0 r
.17164 .47098 m
.20195 .45143 L
.22896 .43578 L
.25307 .42344 L
.27463 .41389 L
.29394 .40672 L
.31126 .40153 L
.32683 .398 L
.34086 .39587 L
.35351 .39488 L
.36495 .39485 L
.37531 .3956 L
.3847 .39698 L
.39325 .39887 L
.40103 .40116 L
.40812 .40377 L
.41461 .40661 L
.42055 .40962 L
.426 .41275 L
.431 .41595 L
.43561 .4192 L
.43985 .42245 L
.44377 .42568 L
.44739 .42887 L
.45075 .43201 L
.45385 .43508 L
.45674 .43807 L
.45941 .44097 L
.46191 .44378 L
.46423 .4465 L
.46639 .44912 L
.46841 .45163 L
.47029 .45405 L
.47206 .45637 L
.4737 .45859 L
.47525 .46071 L
.47669 .46273 L
.47805 .46467 L
.47932 .46651 L
.48051 .46826 L
.48163 .46993 L
.48268 .47152 L
.48367 .47303 L
.4846 .47447 L
.48548 .47583 L
.4863 .47712 L
.48707 .47835 L
.4878 .47952 L
.48849 .48062 L
.48914 .48167 L
Mistroke
.48975 .48266 L
.49032 .4836 L
.49086 .48449 L
.49137 .48533 L
.49186 .48613 L
.49231 .48688 L
.49274 .4876 L
.49314 .48828 L
.49352 .48892 L
.49388 .48952 L
.49422 .49009 L
.49454 .49064 L
.49485 .49115 L
.49513 .49163 L
.4954 .49209 L
.49566 .49253 L
.4959 .49294 L
.49612 .49332 L
.49634 .49369 L
.49654 .49404 L
.49673 .49436 L
.49691 .49467 L
.49708 .49497 L
.49725 .49524 L
.4974 .49551 L
.49754 .49575 L
.49768 .49599 L
.49781 .49621 L
.49793 .49642 L
.49804 .49661 L
.49815 .4968 L
.49825 .49698 L
.49835 .49714 L
.49844 .4973 L
.49852 .49745 L
.49861 .49759 L
.49868 .49772 L
.49876 .49785 L
.49882 .49797 L
.49889 .49808 L
.49895 .49818 L
.49901 .49828 L
.49906 .49838 L
.49911 .49847 L
.49916 .49855 L
.49921 .49863 L
.49925 .49871 L
.49929 .49878 L
.49933 .49885 L
.49937 .49891 L
Mistroke
.4994 .49897 L
.49944 .49903 L
.49947 .49908 L
.4995 .49913 L
.49953 .49918 L
.49955 .49922 L
.49958 .49927 L
.4996 .49931 L
.49962 .49935 L
.49964 .49938 L
.49966 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49953 L
.49975 .49956 L
.49976 .49958 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
Mistroke
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .294 r
.62961 .59907 m
.61963 .59853 L
.61058 .59736 L
.60235 .59568 L
.59486 .59361 L
.58803 .59122 L
.5818 .58859 L
.57609 .58579 L
.57085 .58286 L
.56604 .57986 L
.56162 .57681 L
.55755 .57375 L
.55379 .5707 L
.55032 .56768 L
.5471 .56471 L
.54412 .56181 L
.54136 .55897 L
.53879 .55622 L
.53641 .55355 L
.53419 .55097 L
.53211 .54849 L
.53018 .54609 L
.52838 .54379 L
.52669 .54159 L
.52512 .53948 L
.52364 .53746 L
.52226 .53553 L
.52096 .53369 L
.51975 .53194 L
.51861 .53027 L
.51754 .52868 L
.51653 .52716 L
.51559 .52572 L
.5147 .52435 L
.51387 .52306 L
.51308 .52182 L
.51234 .52065 L
.51164 .51954 L
.51099 .51849 L
.51037 .51749 L
.50979 .51655 L
.50924 .51565 L
.50872 .5148 L
.50823 .514 L
.50777 .51324 L
.50734 .51252 L
.50693 .51183 L
.50655 .51119 L
.50618 .51058 L
.50584 .51 L
Mistroke
.50551 .50945 L
.50521 .50893 L
.50492 .50845 L
.50465 .50798 L
.50439 .50755 L
.50414 .50713 L
.50392 .50674 L
.5037 .50637 L
.50349 .50602 L
.5033 .50569 L
.50312 .50538 L
.50295 .50508 L
.50278 .5048 L
.50263 .50454 L
.50248 .50429 L
.50235 .50405 L
.50222 .50383 L
.50209 .50362 L
.50198 .50342 L
.50187 .50323 L
.50177 .50305 L
.50167 .50289 L
.50158 .50273 L
.50149 .50258 L
.50141 .50243 L
.50133 .5023 L
.50126 .50217 L
.50119 .50205 L
.50112 .50194 L
.50106 .50183 L
.501 .50173 L
.50095 .50164 L
.50089 .50155 L
.50084 .50146 L
.5008 .50138 L
.50075 .50131 L
.50071 .50123 L
.50067 .50117 L
.50064 .5011 L
.5006 .50104 L
.50057 .50098 L
.50054 .50093 L
.50051 .50088 L
.50048 .50083 L
.50045 .50078 L
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
Mistroke
.50032 .50056 L
.5003 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.5002 .50035 L
.50019 .50033 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
Mistroke
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .063 1 r
.5249 .25053 m
.51691 .27575 L
.51024 .29805 L
.5047 .31779 L
.50014 .33529 L
.4964 .35084 L
.49336 .36466 L
.49093 .37697 L
.489 .38796 L
.4875 .39778 L
.48637 .40657 L
.48554 .41446 L
.48497 .42155 L
.48461 .42792 L
.48443 .43368 L
.4844 .43888 L
.48449 .44358 L
.48467 .44785 L
.48494 .45173 L
.48527 .45526 L
.48564 .45848 L
.48606 .46142 L
.4865 .46411 L
.48696 .46658 L
.48743 .46885 L
.48791 .47093 L
.4884 .47285 L
.48888 .47463 L
.48935 .47626 L
.48982 .47778 L
.49028 .47918 L
.49072 .48049 L
.49116 .4817 L
.49158 .48282 L
.49198 .48387 L
.49237 .48485 L
.49275 .48576 L
.49311 .48661 L
.49346 .48741 L
.49379 .48815 L
.49411 .48885 L
.49441 .4895 L
.4947 .49011 L
.49498 .49068 L
.49524 .49122 L
.49549 .49172 L
.49573 .4922 L
.49595 .49264 L
.49617 .49306 L
.49637 .49346 L
Mistroke
.49657 .49383 L
.49675 .49418 L
.49693 .49451 L
.49709 .49482 L
.49725 .49511 L
.4974 .49538 L
.49754 .49564 L
.49767 .49588 L
.4978 .49611 L
.49792 .49633 L
.49803 .49654 L
.49814 .49673 L
.49824 .49691 L
.49834 .49708 L
.49843 .49725 L
.49851 .4974 L
.49859 .49754 L
.49867 .49768 L
.49874 .49781 L
.49881 .49793 L
.49888 .49804 L
.49894 .49815 L
.499 .49825 L
.49905 .49835 L
.49911 .49844 L
.49915 .49853 L
.4992 .49861 L
.49924 .49869 L
.49929 .49876 L
.49933 .49883 L
.49936 .49889 L
.4994 .49895 L
.49943 .49901 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49921 L
.49957 .49926 L
.49959 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
Mistroke
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .007 r
.28131 .40122 m
.2997 .39569 L
.31623 .39193 L
.33112 .38965 L
.34455 .38859 L
.35669 .38855 L
.36768 .38933 L
.37766 .39078 L
.38673 .39278 L
.39498 .3952 L
.40252 .39796 L
.4094 .40096 L
.41571 .40415 L
.42149 .40747 L
.4268 .41087 L
.43169 .41431 L
.43619 .41775 L
.44035 .42118 L
.44419 .42456 L
.44775 .42789 L
.45104 .43114 L
.4541 .43431 L
.45694 .43739 L
.45959 .44037 L
.46205 .44325 L
.46435 .44603 L
.46649 .4487 L
.46849 .45126 L
.47036 .45372 L
.4721 .45607 L
.47374 .45832 L
.47528 .46047 L
.47671 .46252 L
.47806 .46447 L
.47933 .46634 L
.48051 .46811 L
.48163 .46979 L
.48268 .47139 L
.48367 .47292 L
.48459 .47436 L
.48547 .47573 L
.48629 .47704 L
.48706 .47827 L
.48779 .47944 L
.48848 .48055 L
.48912 .4816 L
.48973 .4826 L
.49031 .48354 L
.49085 .48444 L
.49136 .48529 L
Mistroke
.49184 .48609 L
.4923 .48684 L
.49273 .48756 L
.49313 .48824 L
.49351 .48888 L
.49387 .48949 L
.49421 .49007 L
.49453 .49061 L
.49484 .49113 L
.49512 .49161 L
.49539 .49207 L
.49565 .49251 L
.49589 .49292 L
.49612 .49331 L
.49633 .49367 L
.49653 .49402 L
.49673 .49435 L
.49691 .49466 L
.49708 .49495 L
.49724 .49523 L
.49739 .49549 L
.49754 .49574 L
.49767 .49598 L
.4978 .4962 L
.49792 .49641 L
.49804 .49661 L
.49814 .49679 L
.49825 .49697 L
.49834 .49714 L
.49844 .49729 L
.49852 .49744 L
.4986 .49758 L
.49868 .49772 L
.49875 .49784 L
.49882 .49796 L
.49889 .49807 L
.49895 .49818 L
.49901 .49828 L
.49906 .49837 L
.49911 .49846 L
.49916 .49855 L
.49921 .49863 L
.49925 .4987 L
.49929 .49878 L
.49933 .49884 L
.49937 .49891 L
.4994 .49897 L
.49944 .49902 L
.49947 .49908 L
.4995 .49913 L
Mistroke
.49952 .49918 L
.49955 .49922 L
.49958 .49926 L
.4996 .49931 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49945 L
.4997 .49948 L
.49971 .49951 L
.49973 .49953 L
.49975 .49956 L
.49976 .49958 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
Mistroke
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .503 0 r
.768 .56736 m
.74425 .5792 L
.723 .58831 L
.70397 .59512 L
.68688 .6 L
.67152 .60325 L
.65768 .60516 L
.64519 .60594 L
.63389 .60581 L
.62366 .60492 L
.61437 .60342 L
.60592 .60143 L
.59823 .59905 L
.59121 .59638 L
.58478 .59348 L
.5789 .59042 L
.57351 .58725 L
.56855 .58401 L
.56399 .58074 L
.55978 .57747 L
.55589 .57422 L
.5523 .57101 L
.54897 .56787 L
.54589 .56479 L
.54303 .56179 L
.54037 .55889 L
.53789 .55607 L
.53559 .55336 L
.53344 .55074 L
.53143 .54823 L
.52956 .54581 L
.52781 .5435 L
.52617 .54128 L
.52464 .53917 L
.5232 .53714 L
.52185 .53522 L
.52059 .53338 L
.5194 .53163 L
.51829 .52996 L
.51724 .52838 L
.51626 .52687 L
.51533 .52544 L
.51446 .52408 L
.51364 .52279 L
.51287 .52157 L
.51215 .52041 L
.51146 .51931 L
.51082 .51827 L
.51021 .51728 L
.50964 .51634 L
Mistroke
.5091 .51545 L
.50859 .51461 L
.50811 .51382 L
.50766 .51307 L
.50723 .51235 L
.50683 .51168 L
.50645 .51104 L
.50609 .51044 L
.50575 .50987 L
.50543 .50933 L
.50513 .50882 L
.50485 .50833 L
.50458 .50788 L
.50433 .50744 L
.50409 .50704 L
.50386 .50665 L
.50365 .50628 L
.50344 .50594 L
.50325 .50561 L
.50307 .5053 L
.5029 .50501 L
.50274 .50474 L
.50259 .50448 L
.50245 .50423 L
.50231 .504 L
.50219 .50378 L
.50207 .50357 L
.50195 .50337 L
.50184 .50319 L
.50174 .50301 L
.50165 .50285 L
.50155 .50269 L
.50147 .50254 L
.50139 .5024 L
.50131 .50227 L
.50124 .50214 L
.50117 .50203 L
.50111 .50191 L
.50105 .50181 L
.50099 .50171 L
.50093 .50162 L
.50088 .50153 L
.50083 .50144 L
.50079 .50136 L
.50074 .50129 L
.5007 .50122 L
.50066 .50115 L
.50063 .50109 L
.50059 .50103 L
.50056 .50097 L
Mistroke
.50053 .50092 L
.5005 .50087 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50036 .50062 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
Mistroke
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .883 0 r
.65882 .81035 m
.65086 .79186 L
.64324 .77457 L
.63594 .7584 L
.62897 .74326 L
.62231 .72907 L
.61596 .71577 L
.6099 .70329 L
.60414 .69158 L
.59865 .68058 L
.59343 .67024 L
.58847 .66053 L
.58376 .6514 L
.57929 .6428 L
.57504 .63472 L
.57101 .62711 L
.56719 .61994 L
.56357 .61319 L
.56013 .60683 L
.55688 .60083 L
.5538 .59519 L
.55088 .58986 L
.54811 .58484 L
.54549 .5801 L
.54302 .57564 L
.54067 .57142 L
.53845 .56745 L
.53635 .5637 L
.53436 .56016 L
.53248 .55682 L
.53071 .55366 L
.52902 .55069 L
.52743 .54788 L
.52593 .54522 L
.52451 .54272 L
.52316 .54035 L
.52189 .53812 L
.52069 .53601 L
.51955 .53402 L
.51848 .53214 L
.51746 .53036 L
.5165 .52868 L
.5156 .5271 L
.51474 .5256 L
.51393 .52419 L
.51316 .52285 L
.51244 .52159 L
.51175 .5204 L
.51111 .51927 L
.51049 .51821 L
Mistroke
.50992 .5172 L
.50937 .51625 L
.50885 .51536 L
.50837 .51451 L
.50791 .51371 L
.50747 .51295 L
.50706 .51224 L
.50667 .51156 L
.5063 .51093 L
.50596 .51032 L
.50563 .50975 L
.50532 .50922 L
.50502 .50871 L
.50475 .50823 L
.50449 .50777 L
.50424 .50734 L
.50401 .50694 L
.50378 .50656 L
.50358 .5062 L
.50338 .50585 L
.50319 .50553 L
.50302 .50523 L
.50285 .50494 L
.50269 .50467 L
.50254 .50441 L
.5024 .50417 L
.50227 .50394 L
.50215 .50372 L
.50203 .50351 L
.50192 .50332 L
.50181 .50314 L
.50171 .50296 L
.50162 .5028 L
.50153 .50265 L
.50144 .5025 L
.50136 .50236 L
.50129 .50223 L
.50122 .50211 L
.50115 .50199 L
.50109 .50188 L
.50103 .50178 L
.50097 .50168 L
.50092 .50159 L
.50087 .5015 L
.50082 .50142 L
.50077 .50134 L
.50073 .50127 L
.50069 .5012 L
.50065 .50113 L
.50062 .50107 L
Mistroke
.50058 .50101 L
.50055 .50095 L
.50052 .5009 L
.50049 .50085 L
.50046 .5008 L
.50044 .50076 L
.50041 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .50061 L
.50033 .50057 L
.50031 .50054 L
.5003 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50016 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
Mistroke
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .11 1 r
.55447 .25591 m
.54381 .28263 L
.53476 .30611 L
.52709 .32675 L
.52062 .34493 L
.51516 .36096 L
.51059 .3751 L
.50676 .3876 L
.50358 .39866 L
.50095 .40846 L
.49879 .41716 L
.49703 .42489 L
.49561 .43177 L
.49448 .43791 L
.4936 .44339 L
.49292 .44829 L
.49242 .45269 L
.49206 .45664 L
.49183 .46019 L
.4917 .46339 L
.49165 .46628 L
.49168 .46889 L
.49176 .47126 L
.49188 .47341 L
.49205 .47537 L
.49224 .47715 L
.49246 .47878 L
.49269 .48027 L
.49293 .48163 L
.49318 .48289 L
.49344 .48404 L
.4937 .4851 L
.49395 .48607 L
.49421 .48698 L
.49446 .48781 L
.49471 .48859 L
.49495 .4893 L
.49518 .48997 L
.49541 .49059 L
.49563 .49116 L
.49584 .4917 L
.49605 .4922 L
.49624 .49267 L
.49643 .4931 L
.49661 .49351 L
.49678 .49389 L
.49695 .49425 L
.49711 .49459 L
.49726 .4949 L
.4974 .4952 L
Mistroke
.49754 .49547 L
.49767 .49573 L
.49779 .49598 L
.49791 .49621 L
.49802 .49642 L
.49813 .49662 L
.49823 .49682 L
.49832 .497 L
.49841 .49717 L
.4985 .49732 L
.49858 .49747 L
.49866 .49762 L
.49873 .49775 L
.4988 .49788 L
.49886 .49799 L
.49892 .49811 L
.49898 .49821 L
.49904 .49831 L
.49909 .49841 L
.49914 .49849 L
.49919 .49858 L
.49923 .49866 L
.49927 .49873 L
.49931 .4988 L
.49935 .49887 L
.49939 .49893 L
.49942 .49899 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
.49956 .49924 L
.49959 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .49939 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49977 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
Mistroke
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .34 r
.17615 .40631 m
.20458 .39316 L
.23002 .38319 L
.25284 .37588 L
.27334 .3708 L
.2918 .3676 L
.30844 .36596 L
.32347 .36559 L
.33708 .36629 L
.34942 .36784 L
.36063 .37008 L
.37083 .37287 L
.38014 .37609 L
.38864 .37964 L
.39642 .38344 L
.40355 .3874 L
.4101 .39147 L
.41612 .3956 L
.42167 .39976 L
.42679 .40389 L
.43152 .40799 L
.4359 .41202 L
.43995 .41596 L
.44371 .41981 L
.44721 .42355 L
.45046 .42718 L
.45348 .43069 L
.4563 .43407 L
.45893 .43732 L
.46139 .44044 L
.46368 .44344 L
.46583 .44631 L
.46783 .44905 L
.46971 .45167 L
.47148 .45417 L
.47313 .45656 L
.47468 .45883 L
.47614 .461 L
.47751 .46306 L
.47879 .46501 L
.48 .46687 L
.48114 .46864 L
.48221 .47032 L
.48321 .47191 L
.48416 .47342 L
.48505 .47485 L
.48589 .47621 L
.48669 .47749 L
.48743 .47871 L
.48814 .47987 L
Mistroke
.4888 .48096 L
.48942 .482 L
.49001 .48298 L
.49057 .4839 L
.4911 .48478 L
.49159 .48561 L
.49206 .4864 L
.4925 .48714 L
.49292 .48785 L
.49331 .48851 L
.49368 .48914 L
.49403 .48974 L
.49436 .4903 L
.49467 .49083 L
.49497 .49133 L
.49525 .49181 L
.49551 .49226 L
.49576 .49269 L
.49599 .49309 L
.49621 .49347 L
.49642 .49383 L
.49662 .49417 L
.49681 .49449 L
.49698 .49479 L
.49715 .49508 L
.49731 .49535 L
.49746 .4956 L
.4976 .49585 L
.49773 .49607 L
.49785 .49629 L
.49797 .49649 L
.49809 .49669 L
.49819 .49687 L
.49829 .49704 L
.49838 .49721 L
.49847 .49736 L
.49856 .4975 L
.49864 .49764 L
.49871 .49777 L
.49878 .49789 L
.49885 .49801 L
.49891 .49812 L
.49897 .49822 L
.49903 .49832 L
.49908 .49841 L
.49913 .4985 L
.49918 .49858 L
.49923 .49866 L
.49927 .49874 L
.49931 .49881 L
Mistroke
.49935 .49887 L
.49938 .49893 L
.49942 .49899 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
.49956 .49924 L
.49959 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49977 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
Mistroke
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .002 r
.40915 .47768 m
.41721 .47361 L
.42442 .47048 L
.43088 .46814 L
.43668 .46645 L
.44189 .46532 L
.44659 .46464 L
.45083 .46435 L
.45466 .46438 L
.45813 .46466 L
.46128 .46515 L
.46414 .46581 L
.46675 .4666 L
.46913 .46749 L
.47131 .46846 L
.4733 .46949 L
.47513 .47055 L
.47681 .47164 L
.47835 .47274 L
.47978 .47384 L
.48109 .47494 L
.48231 .47602 L
.48343 .47708 L
.48448 .47812 L
.48545 .47913 L
.48635 .48011 L
.48718 .48106 L
.48796 .48197 L
.48869 .48286 L
.48937 .48371 L
.49 .48452 L
.4906 .4853 L
.49115 .48605 L
.49167 .48676 L
.49216 .48745 L
.49261 .4881 L
.49304 .48872 L
.49344 .48931 L
.49382 .48987 L
.49417 .49041 L
.4945 .49092 L
.49482 .4914 L
.49511 .49186 L
.49539 .4923 L
.49565 .49271 L
.49589 .4931 L
.49613 .49347 L
.49634 .49383 L
.49655 .49416 L
.49674 .49448 L
Mistroke
.49692 .49478 L
.4971 .49506 L
.49726 .49533 L
.49741 .49558 L
.49756 .49582 L
.49769 .49605 L
.49782 .49627 L
.49794 .49647 L
.49806 .49666 L
.49816 .49685 L
.49827 .49702 L
.49836 .49718 L
.49845 .49734 L
.49854 .49748 L
.49862 .49762 L
.4987 .49775 L
.49877 .49788 L
.49884 .49799 L
.4989 .4981 L
.49896 .49821 L
.49902 .49831 L
.49907 .4984 L
.49912 .49849 L
.49917 .49857 L
.49922 .49865 L
.49926 .49872 L
.4993 .49879 L
.49934 .49886 L
.49938 .49892 L
.49941 .49898 L
.49944 .49904 L
.49947 .49909 L
.4995 .49914 L
.49953 .49919 L
.49956 .49923 L
.49958 .49928 L
.4996 .49932 L
.49963 .49935 L
.49965 .49939 L
.49967 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49978 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
Mistroke
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .704 0 r
.49821 .53225 m
.49911 .52909 L
.49985 .52628 L
.50046 .52379 L
.50095 .52158 L
.50135 .51961 L
.50167 .51785 L
.50191 .51628 L
.5021 .51488 L
.50224 .51362 L
.50234 .51248 L
.5024 .51146 L
.50243 .51055 L
.50244 .50972 L
.50243 .50897 L
.5024 .50829 L
.50237 .50767 L
.50232 .5071 L
.50226 .50659 L
.50219 .50612 L
.50213 .50569 L
.50205 .5053 L
.50198 .50494 L
.50191 .50461 L
.50183 .5043 L
.50175 .50402 L
.50168 .50376 L
.50161 .50352 L
.50154 .5033 L
.50147 .50309 L
.5014 .5029 L
.50133 .50272 L
.50127 .50255 L
.50121 .5024 L
.50115 .50226 L
.50109 .50212 L
.50103 .50199 L
.50098 .50188 L
.50093 .50177 L
.50088 .50166 L
.50084 .50157 L
.50079 .50148 L
.50075 .50139 L
.50071 .50131 L
.50068 .50123 L
.50064 .50116 L
.50061 .5011 L
.50057 .50104 L
.50054 .50098 L
.50051 .50092 L
Mistroke
.50049 .50087 L
.50046 .50082 L
.50044 .50077 L
.50041 .50073 L
.50039 .50069 L
.50037 .50065 L
.50035 .50061 L
.50033 .50058 L
.50031 .50055 L
.50029 .50052 L
.50028 .50049 L
.50026 .50046 L
.50025 .50044 L
.50024 .50041 L
.50022 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
Mistroke
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.612 1 0 r
.47414 .19021 m
.46957 .21767 L
.46605 .24223 L
.46342 .26424 L
.46153 .28399 L
.46027 .30175 L
.45953 .31776 L
.45923 .3322 L
.45928 .34525 L
.45962 .35709 L
.46019 .36782 L
.46095 .37759 L
.46187 .38648 L
.46289 .3946 L
.46401 .40202 L
.46519 .40882 L
.46641 .41505 L
.46765 .42079 L
.46891 .42606 L
.47017 .43092 L
.47142 .43541 L
.47265 .43957 L
.47387 .44341 L
.47505 .44697 L
.4762 .45028 L
.47732 .45335 L
.47841 .45621 L
.47945 .45888 L
.48046 .46136 L
.48143 .46368 L
.48236 .46584 L
.48325 .46787 L
.4841 .46976 L
.48492 .47153 L
.4857 .47319 L
.48644 .47475 L
.48715 .47621 L
.48782 .47758 L
.48846 .47887 L
.48907 .48008 L
.48965 .48122 L
.4902 .48229 L
.49073 .48329 L
.49122 .48424 L
.49169 .48513 L
.49214 .48597 L
.49256 .48676 L
.49297 .4875 L
.49335 .4882 L
.49371 .48886 L
Mistroke
.49405 .48949 L
.49437 .49007 L
.49468 .49063 L
.49497 .49115 L
.49524 .49164 L
.4955 .49211 L
.49575 .49255 L
.49598 .49296 L
.4962 .49335 L
.49641 .49372 L
.4966 .49407 L
.49679 .4944 L
.49697 .49471 L
.49713 .495 L
.49729 .49528 L
.49744 .49554 L
.49758 .49579 L
.49771 .49602 L
.49784 .49624 L
.49796 .49645 L
.49807 .49664 L
.49818 .49683 L
.49828 .497 L
.49837 .49717 L
.49846 .49733 L
.49855 .49747 L
.49863 .49761 L
.4987 .49775 L
.49877 .49787 L
.49884 .49799 L
.4989 .4981 L
.49896 .4982 L
.49902 .4983 L
.49908 .4984 L
.49913 .49848 L
.49917 .49857 L
.49922 .49865 L
.49926 .49872 L
.4993 .49879 L
.49934 .49886 L
.49938 .49892 L
.49941 .49898 L
.49944 .49904 L
.49948 .49909 L
.4995 .49914 L
.49953 .49919 L
.49956 .49923 L
.49958 .49928 L
.4996 .49932 L
.49963 .49935 L
Mistroke
.49965 .49939 L
.49967 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49978 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
Mistroke
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.699 1 0 r
.51209 .77712 m
.51722 .75181 L
.52129 .72923 L
.52447 .70905 L
.52689 .691 L
.52868 .67481 L
.52993 .66027 L
.53073 .64719 L
.53117 .63539 L
.53129 .62474 L
.53116 .6151 L
.53083 .60636 L
.53033 .59842 L
.52969 .5912 L
.52896 .58461 L
.52814 .5786 L
.52726 .57309 L
.52635 .56805 L
.5254 .56342 L
.52444 .55916 L
.52347 .55524 L
.52251 .55163 L
.52156 .54829 L
.52062 .54519 L
.51969 .54233 L
.51879 .53968 L
.51792 .53721 L
.51707 .53492 L
.51625 .53278 L
.51546 .53079 L
.5147 .52894 L
.51397 .52721 L
.51327 .52559 L
.51259 .52408 L
.51195 .52266 L
.51134 .52133 L
.51075 .52009 L
.51019 .51893 L
.50966 .51783 L
.50915 .51681 L
.50867 .51584 L
.50821 .51494 L
.50777 .51409 L
.50736 .51329 L
.50696 .51253 L
.50659 .51182 L
.50624 .51116 L
.5059 .51053 L
.50558 .50993 L
.50528 .50938 L
Mistroke
.505 .50885 L
.50472 .50835 L
.50447 .50789 L
.50423 .50745 L
.504 .50703 L
.50378 .50664 L
.50357 .50627 L
.50338 .50592 L
.50319 .50559 L
.50302 .50528 L
.50285 .50499 L
.5027 .50471 L
.50255 .50445 L
.50241 .5042 L
.50228 .50397 L
.50215 .50375 L
.50203 .50354 L
.50192 .50335 L
.50182 .50316 L
.50172 .50299 L
.50162 .50282 L
.50153 .50267 L
.50145 .50252 L
.50137 .50238 L
.50129 .50225 L
.50122 .50212 L
.50116 .50201 L
.50109 .5019 L
.50103 .50179 L
.50098 .50169 L
.50092 .5016 L
.50087 .50151 L
.50082 .50143 L
.50078 .50135 L
.50073 .50127 L
.50069 .5012 L
.50066 .50114 L
.50062 .50107 L
.50059 .50102 L
.50055 .50096 L
.50052 .50091 L
.50049 .50086 L
.50047 .50081 L
.50044 .50076 L
.50042 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .50061 L
.50033 .50058 L
.50031 .50054 L
Mistroke
.5003 .50051 L
.50028 .50049 L
.50026 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
Mistroke
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .225 0 r
.51993 .61288 m
.5206 .60359 L
.52101 .59522 L
.52118 .58766 L
.52116 .58083 L
.521 .57465 L
.52071 .56903 L
.52032 .56393 L
.51985 .55928 L
.51932 .55503 L
.51874 .55115 L
.51813 .5476 L
.5175 .54434 L
.51685 .54135 L
.5162 .53859 L
.51554 .53605 L
.51489 .53371 L
.51425 .53154 L
.51362 .52953 L
.513 .52767 L
.5124 .52594 L
.51182 .52434 L
.51126 .52285 L
.51071 .52145 L
.51019 .52016 L
.50968 .51895 L
.5092 .51782 L
.50873 .51676 L
.50829 .51577 L
.50786 .51485 L
.50746 .51398 L
.50707 .51317 L
.5067 .51241 L
.50635 .51169 L
.50602 .51102 L
.5057 .51039 L
.5054 .5098 L
.50511 .50924 L
.50484 .50871 L
.50458 .50822 L
.50433 .50776 L
.5041 .50732 L
.50388 .50691 L
.50367 .50652 L
.50347 .50615 L
.50328 .50581 L
.5031 .50548 L
.50294 .50518 L
.50278 .50489 L
.50262 .50462 L
Mistroke
.50248 .50436 L
.50235 .50412 L
.50222 .50389 L
.5021 .50367 L
.50198 .50347 L
.50187 .50327 L
.50177 .50309 L
.50167 .50292 L
.50158 .50276 L
.5015 .50261 L
.50141 .50246 L
.50134 .50233 L
.50126 .5022 L
.50119 .50208 L
.50113 .50196 L
.50107 .50185 L
.50101 .50175 L
.50095 .50165 L
.5009 .50156 L
.50085 .50148 L
.5008 .50139 L
.50076 .50132 L
.50072 .50124 L
.50068 .50118 L
.50064 .50111 L
.50061 .50105 L
.50057 .50099 L
.50054 .50094 L
.50051 .50089 L
.50048 .50084 L
.50046 .50079 L
.50043 .50075 L
.50041 .50071 L
.50038 .50067 L
.50036 .50063 L
.50034 .5006 L
.50032 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.50019 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50016 .50027 L
Mistroke
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
Mistroke
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .273 r
.48503 .63548 m
.48951 .62168 L
.49325 .60949 L
.49637 .59871 L
.49894 .58915 L
.50106 .58067 L
.50279 .57314 L
.50418 .56643 L
.50529 .56045 L
.50616 .5551 L
.50682 .55032 L
.50732 .54604 L
.50767 .5422 L
.5079 .53874 L
.50803 .53562 L
.50808 .53281 L
.50806 .53026 L
.50799 .52795 L
.50786 .52586 L
.50771 .52395 L
.50752 .52222 L
.50732 .52063 L
.50709 .51918 L
.50686 .51786 L
.50662 .51664 L
.50637 .51552 L
.50612 .51449 L
.50587 .51354 L
.50562 .51266 L
.50538 .51185 L
.50514 .51109 L
.50491 .5104 L
.50468 .50975 L
.50446 .50915 L
.50424 .50859 L
.50404 .50806 L
.50384 .50758 L
.50365 .50712 L
.50347 .5067 L
.50329 .5063 L
.50312 .50593 L
.50296 .50558 L
.50281 .50526 L
.50266 .50495 L
.50252 .50467 L
.50239 .5044 L
.50227 .50415 L
.50215 .50391 L
.50203 .50369 L
.50192 .50348 L
Mistroke
.50182 .50328 L
.50172 .50309 L
.50163 .50292 L
.50154 .50275 L
.50146 .5026 L
.50138 .50245 L
.50131 .50232 L
.50124 .50219 L
.50117 .50206 L
.5011 .50195 L
.50104 .50184 L
.50099 .50174 L
.50093 .50164 L
.50088 .50155 L
.50083 .50146 L
.50079 .50138 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50063 .5011 L
.5006 .50104 L
.50056 .50098 L
.50053 .50093 L
.5005 .50088 L
.50048 .50083 L
.50045 .50078 L
.50042 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50056 L
.5003 .50052 L
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .5004 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50014 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
Mistroke
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
Mistroke
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .949 1 r
.40976 .4835 m
.4179 .47893 L
.42517 .47535 L
.43167 .47259 L
.43749 .47054 L
.44272 .46907 L
.44742 .4681 L
.45166 .46754 L
.45548 .46732 L
.45894 .46738 L
.46208 .46767 L
.46492 .46814 L
.46751 .46877 L
.46987 .46951 L
.47202 .47034 L
.47399 .47124 L
.47579 .47218 L
.47744 .47316 L
.47896 .47416 L
.48036 .47517 L
.48165 .47618 L
.48284 .47718 L
.48395 .47817 L
.48497 .47914 L
.48591 .48009 L
.48679 .48101 L
.48761 .4819 L
.48837 .48277 L
.48907 .4836 L
.48973 .48441 L
.49035 .48518 L
.49092 .48592 L
.49146 .48664 L
.49196 .48732 L
.49243 .48797 L
.49288 .48859 L
.49329 .48918 L
.49368 .48975 L
.49404 .49028 L
.49438 .4908 L
.49471 .49128 L
.49501 .49175 L
.49529 .49218 L
.49556 .4926 L
.49581 .493 L
.49605 .49337 L
.49627 .49373 L
.49648 .49407 L
.49668 .49439 L
.49686 .49469 L
Mistroke
.49704 .49498 L
.49721 .49525 L
.49736 .49551 L
.49751 .49576 L
.49765 .49599 L
.49778 .49621 L
.4979 .49641 L
.49802 .49661 L
.49813 .49679 L
.49823 .49697 L
.49833 .49714 L
.49842 .49729 L
.49851 .49744 L
.49859 .49758 L
.49867 .49771 L
.49875 .49784 L
.49881 .49796 L
.49888 .49807 L
.49894 .49818 L
.499 .49828 L
.49906 .49837 L
.49911 .49846 L
.49916 .49854 L
.4992 .49862 L
.49925 .4987 L
.49929 .49877 L
.49933 .49884 L
.49937 .4989 L
.4994 .49896 L
.49943 .49902 L
.49946 .49907 L
.49949 .49913 L
.49952 .49917 L
.49955 .49922 L
.49957 .49926 L
.4996 .4993 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49944 L
.4997 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49956 L
.49976 .49958 L
.49977 .4996 L
.49978 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49968 L
Mistroke
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .386 1 r
.54417 .57579 m
.54172 .57165 L
.53941 .56772 L
.53722 .56401 L
.53516 .5605 L
.53322 .55718 L
.53138 .55404 L
.52964 .55107 L
.528 .54827 L
.52645 .54562 L
.52499 .54311 L
.52361 .54074 L
.5223 .5385 L
.52107 .53638 L
.51991 .53438 L
.51881 .53249 L
.51777 .5307 L
.51679 .52901 L
.51586 .52742 L
.51499 .52591 L
.51416 .52448 L
.51338 .52313 L
.51264 .52186 L
.51194 .52066 L
.51128 .51952 L
.51066 .51844 L
.51007 .51743 L
.50952 .51647 L
.50899 .51556 L
.5085 .5147 L
.50803 .51389 L
.50758 .51313 L
.50717 .5124 L
.50677 .51172 L
.5064 .51108 L
.50604 .51047 L
.50571 .50989 L
.5054 .50934 L
.5051 .50883 L
.50482 .50834 L
.50455 .50788 L
.5043 .50745 L
.50406 .50704 L
.50384 .50665 L
.50363 .50628 L
.50343 .50594 L
.50324 .50561 L
.50306 .5053 L
.50289 .50501 L
.50273 .50473 L
Mistroke
.50258 .50447 L
.50244 .50423 L
.50231 .50399 L
.50218 .50377 L
.50206 .50356 L
.50194 .50337 L
.50184 .50318 L
.50174 .50301 L
.50164 .50284 L
.50155 .50268 L
.50146 .50254 L
.50138 .5024 L
.50131 .50226 L
.50124 .50214 L
.50117 .50202 L
.5011 .50191 L
.50104 .50181 L
.50098 .50171 L
.50093 .50161 L
.50088 .50152 L
.50083 .50144 L
.50078 .50136 L
.50074 .50128 L
.5007 .50121 L
.50066 .50115 L
.50063 .50108 L
.50059 .50102 L
.50056 .50097 L
.50053 .50091 L
.5005 .50086 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50035 .50061 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
Mistroke
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
Mistroke
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.389 1 0 r
.6198 .52188 m
.609 .52795 L
.59935 .53271 L
.59072 .53637 L
.58299 .5391 L
.57605 .54105 L
.5698 .54234 L
.56418 .54308 L
.5591 .54338 L
.55451 .5433 L
.55035 .54291 L
.54657 .54228 L
.54313 .54146 L
.54 .54048 L
.53715 .53937 L
.53453 .53818 L
.53214 .53692 L
.52994 .53562 L
.52793 .5343 L
.52607 .53296 L
.52436 .53162 L
.52277 .53029 L
.52131 .52898 L
.51996 .52769 L
.5187 .52644 L
.51754 .52521 L
.51645 .52403 L
.51544 .52288 L
.51451 .52177 L
.51363 .5207 L
.51281 .51967 L
.51205 .51869 L
.51134 .51774 L
.51067 .51684 L
.51004 .51597 L
.50946 .51515 L
.50891 .51436 L
.50839 .51361 L
.50791 .5129 L
.50746 .51222 L
.50703 .51157 L
.50663 .51096 L
.50625 .51037 L
.5059 .50982 L
.50556 .50929 L
.50525 .5088 L
.50495 .50832 L
.50467 .50787 L
.50441 .50745 L
.50416 .50705 L
Mistroke
.50393 .50666 L
.50371 .5063 L
.5035 .50596 L
.50331 .50563 L
.50312 .50533 L
.50295 .50504 L
.50278 .50476 L
.50263 .5045 L
.50248 .50426 L
.50235 .50402 L
.50222 .5038 L
.50209 .50359 L
.50198 .5034 L
.50187 .50321 L
.50176 .50304 L
.50167 .50287 L
.50157 .50271 L
.50149 .50256 L
.5014 .50242 L
.50133 .50229 L
.50125 .50216 L
.50118 .50204 L
.50112 .50193 L
.50106 .50183 L
.501 .50172 L
.50094 .50163 L
.50089 .50154 L
.50084 .50146 L
.5008 .50138 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50063 .5011 L
.5006 .50104 L
.50057 .50098 L
.50053 .50093 L
.50051 .50087 L
.50048 .50083 L
.50045 .50078 L
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50056 L
.5003 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
Mistroke
.50023 .5004 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
Mistroke
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .93 0 r
.35067 .4293 m
.36315 .42583 L
.37438 .42354 L
.3845 .42222 L
.39363 .42171 L
.40189 .42188 L
.40938 .42258 L
.41617 .42373 L
.42235 .42524 L
.42798 .42702 L
.43312 .42901 L
.43783 .43117 L
.44213 .43344 L
.44608 .43579 L
.44972 .43818 L
.45306 .4406 L
.45614 .44302 L
.45899 .44541 L
.46162 .44778 L
.46406 .4501 L
.46632 .45236 L
.46842 .45457 L
.47037 .45671 L
.47218 .45878 L
.47388 .46078 L
.47545 .46271 L
.47692 .46456 L
.4783 .46633 L
.47958 .46804 L
.48078 .46966 L
.48191 .47122 L
.48297 .47271 L
.48395 .47413 L
.48488 .47548 L
.48575 .47676 L
.48657 .47799 L
.48734 .47915 L
.48806 .48026 L
.48874 .48131 L
.48938 .48231 L
.48998 .48326 L
.49055 .48416 L
.49108 .48501 L
.49158 .48582 L
.49206 .48658 L
.4925 .48731 L
.49292 .488 L
.49332 .48865 L
.49369 .48927 L
.49404 .48985 L
Mistroke
.49437 .4904 L
.49469 .49093 L
.49498 .49142 L
.49526 .49189 L
.49553 .49233 L
.49577 .49275 L
.49601 .49315 L
.49623 .49352 L
.49644 .49388 L
.49664 .49421 L
.49682 .49453 L
.497 .49483 L
.49717 .49512 L
.49732 .49538 L
.49747 .49564 L
.49761 .49588 L
.49774 .4961 L
.49787 .49632 L
.49798 .49652 L
.4981 .49671 L
.4982 .49689 L
.4983 .49706 L
.49839 .49723 L
.49848 .49738 L
.49857 .49752 L
.49865 .49766 L
.49872 .49779 L
.49879 .49791 L
.49886 .49802 L
.49892 .49813 L
.49898 .49824 L
.49904 .49833 L
.49909 .49843 L
.49914 .49851 L
.49919 .49859 L
.49923 .49867 L
.49927 .49874 L
.49931 .49881 L
.49935 .49888 L
.49939 .49894 L
.49942 .499 L
.49945 .49905 L
.49948 .49911 L
.49951 .49916 L
.49954 .4992 L
.49956 .49925 L
.49959 .49929 L
.49961 .49933 L
.49963 .49936 L
.49965 .4994 L
Mistroke
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .4997 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .4998 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
Mistroke
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.517 0 1 r
.68802 .38843 m
.66776 .41171 L
.64994 .43143 L
.63425 .44808 L
.62041 .46209 L
.6082 .47384 L
.5974 .48365 L
.58784 .4918 L
.57937 .49854 L
.57185 .50406 L
.56517 .50856 L
.55922 .51218 L
.55391 .51505 L
.54916 .51729 L
.54492 .51899 L
.54111 .52025 L
.53769 .52113 L
.53462 .5217 L
.53184 .522 L
.52934 .52209 L
.52707 .522 L
.52501 .52176 L
.52315 .52141 L
.52145 .52096 L
.5199 .52044 L
.51849 .51986 L
.51719 .51924 L
.51601 .51859 L
.51492 .51793 L
.51392 .51725 L
.51299 .51657 L
.51214 .51589 L
.51136 .51521 L
.51063 .51455 L
.50996 .5139 L
.50933 .51326 L
.50875 .51265 L
.50821 .51205 L
.50771 .51147 L
.50724 .51091 L
.50681 .51037 L
.5064 .50986 L
.50602 .50936 L
.50566 .50889 L
.50533 .50843 L
.50502 .508 L
.50473 .50759 L
.50445 .50719 L
.50419 .50682 L
.50395 .50646 L
Mistroke
.50373 .50612 L
.50351 .50579 L
.50331 .50548 L
.50312 .50519 L
.50295 .50491 L
.50278 .50465 L
.50262 .5044 L
.50248 .50416 L
.50234 .50394 L
.50221 .50373 L
.50208 .50353 L
.50197 .50333 L
.50186 .50315 L
.50175 .50298 L
.50165 .50282 L
.50156 .50267 L
.50147 .50252 L
.50139 .50238 L
.50132 .50225 L
.50124 .50213 L
.50117 .50201 L
.50111 .5019 L
.50105 .5018 L
.50099 .5017 L
.50093 .50161 L
.50088 .50152 L
.50083 .50144 L
.50079 .50136 L
.50074 .50128 L
.5007 .50121 L
.50066 .50114 L
.50063 .50108 L
.50059 .50102 L
.50056 .50097 L
.50053 .50091 L
.5005 .50086 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50036 .50061 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
Mistroke
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
Mistroke
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .643 1 r
.48872 .2926 m
.48509 .3114 L
.48223 .32817 L
.48002 .34317 L
.47836 .35661 L
.47715 .36866 L
.47633 .3795 L
.47584 .38926 L
.47561 .39806 L
.47561 .40602 L
.47578 .41323 L
.4761 .41977 L
.47654 .42571 L
.47707 .43113 L
.47768 .43607 L
.47833 .44058 L
.47903 .44471 L
.47976 .4485 L
.4805 .45199 L
.48126 .45519 L
.48201 .45815 L
.48276 .46087 L
.4835 .46339 L
.48423 .46572 L
.48494 .46789 L
.48563 .46989 L
.48631 .47176 L
.48696 .47349 L
.48759 .47511 L
.4882 .47661 L
.48878 .47802 L
.48934 .47933 L
.48988 .48055 L
.49039 .4817 L
.49089 .48277 L
.49136 .48378 L
.4918 .48472 L
.49223 .48561 L
.49264 .48644 L
.49303 .48722 L
.49339 .48795 L
.49374 .48864 L
.49408 .48928 L
.49439 .48989 L
.49469 .49047 L
.49498 .491 L
.49525 .49151 L
.4955 .49199 L
.49575 .49244 L
.49598 .49286 L
Mistroke
.4962 .49326 L
.4964 .49364 L
.4966 .494 L
.49678 .49433 L
.49696 .49465 L
.49712 .49495 L
.49728 .49523 L
.49743 .49549 L
.49757 .49574 L
.4977 .49598 L
.49783 .4962 L
.49795 .49641 L
.49806 .49661 L
.49817 .4968 L
.49827 .49698 L
.49836 .49715 L
.49845 .4973 L
.49854 .49745 L
.49862 .49759 L
.49869 .49773 L
.49876 .49785 L
.49883 .49797 L
.4989 .49808 L
.49896 .49819 L
.49901 .49829 L
.49907 .49838 L
.49912 .49847 L
.49917 .49856 L
.49921 .49864 L
.49926 .49871 L
.4993 .49878 L
.49934 .49885 L
.49937 .49891 L
.49941 .49897 L
.49944 .49903 L
.49947 .49908 L
.4995 .49913 L
.49953 .49918 L
.49955 .49923 L
.49958 .49927 L
.4996 .49931 L
.49962 .49935 L
.49964 .49938 L
.49966 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
Mistroke
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .736 r
.23165 .54587 m
.258 .52333 L
.28135 .5047 L
.30208 .48941 L
.32051 .47698 L
.33692 .46696 L
.35155 .45901 L
.36462 .4528 L
.37632 .44806 L
.38681 .44456 L
.39623 .44211 L
.40471 .44052 L
.41235 .43966 L
.41925 .4394 L
.4255 .43964 L
.43116 .44027 L
.4363 .44123 L
.44098 .44245 L
.44524 .44387 L
.44914 .44545 L
.4527 .44714 L
.45596 .44891 L
.45896 .45074 L
.46172 .4526 L
.46426 .45447 L
.4666 .45634 L
.46876 .45819 L
.47076 .46001 L
.47261 .4618 L
.47433 .46354 L
.47593 .46524 L
.47741 .46688 L
.47879 .46847 L
.48008 .47001 L
.48128 .47148 L
.4824 .4729 L
.48345 .47426 L
.48443 .47557 L
.48534 .47681 L
.4862 .47801 L
.487 .47914 L
.48776 .48023 L
.48846 .48126 L
.48913 .48225 L
.48975 .48318 L
.49034 .48407 L
.49089 .48492 L
.49141 .48572 L
.49189 .48649 L
.49235 .48721 L
Mistroke
.49278 .4879 L
.49319 .48855 L
.49357 .48917 L
.49394 .48975 L
.49428 .49031 L
.4946 .49083 L
.4949 .49133 L
.49518 .4918 L
.49545 .49225 L
.49571 .49267 L
.49594 .49307 L
.49617 .49345 L
.49638 .49381 L
.49658 .49415 L
.49677 .49447 L
.49695 .49477 L
.49712 .49505 L
.49728 .49533 L
.49743 .49558 L
.49757 .49582 L
.49771 .49605 L
.49784 .49627 L
.49796 .49648 L
.49807 .49667 L
.49818 .49685 L
.49828 .49702 L
.49837 .49719 L
.49846 .49734 L
.49855 .49749 L
.49863 .49763 L
.4987 .49776 L
.49877 .49788 L
.49884 .498 L
.49891 .49811 L
.49897 .49821 L
.49902 .49831 L
.49908 .4984 L
.49913 .49849 L
.49918 .49857 L
.49922 .49865 L
.49926 .49873 L
.49931 .4988 L
.49934 .49886 L
.49938 .49893 L
.49941 .49899 L
.49945 .49904 L
.49948 .49909 L
.49951 .49914 L
.49953 .49919 L
.49956 .49924 L
Mistroke
.49958 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .49939 L
.49967 .49942 L
.49969 .49946 L
.4997 .49949 L
.49972 .49951 L
.49974 .49954 L
.49975 .49957 L
.49976 .49959 L
.49978 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
Mistroke
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .946 r
.18055 .41154 m
.20867 .3982 L
.23385 .38802 L
.25642 .38052 L
.27669 .37525 L
.29492 .37186 L
.31137 .37002 L
.32622 .36948 L
.33965 .36999 L
.35183 .37137 L
.3629 .37344 L
.37296 .37607 L
.38214 .37913 L
.39052 .38253 L
.39819 .38618 L
.40522 .39 L
.41167 .39394 L
.4176 .39795 L
.42306 .40198 L
.4281 .406 L
.43275 .40999 L
.43706 .41391 L
.44105 .41776 L
.44475 .42151 L
.44818 .42516 L
.45137 .4287 L
.45435 .43213 L
.45712 .43543 L
.4597 .43861 L
.46211 .44166 L
.46437 .44459 L
.46647 .4474 L
.46844 .45008 L
.47029 .45265 L
.47202 .4551 L
.47364 .45743 L
.47517 .45966 L
.4766 .46178 L
.47794 .4638 L
.4792 .46571 L
.48039 .46753 L
.4815 .46926 L
.48255 .47091 L
.48354 .47247 L
.48447 .47395 L
.48534 .47535 L
.48617 .47668 L
.48694 .47794 L
.48768 .47913 L
.48837 .48027 L
Mistroke
.48902 .48134 L
.48963 .48235 L
.49021 .48331 L
.49076 .48422 L
.49127 .48508 L
.49176 .4859 L
.49221 .48667 L
.49265 .4874 L
.49306 .48809 L
.49344 .48874 L
.4938 .48935 L
.49415 .48994 L
.49447 .49049 L
.49478 .49101 L
.49507 .4915 L
.49534 .49197 L
.4956 .49241 L
.49584 .49283 L
.49607 .49322 L
.49629 .4936 L
.49649 .49395 L
.49669 .49428 L
.49687 .49459 L
.49704 .49489 L
.49721 .49517 L
.49736 .49544 L
.49751 .49569 L
.49764 .49593 L
.49777 .49615 L
.4979 .49636 L
.49801 .49656 L
.49812 .49675 L
.49823 .49693 L
.49832 .4971 L
.49842 .49726 L
.4985 .49741 L
.49859 .49755 L
.49866 .49769 L
.49874 .49782 L
.49881 .49794 L
.49887 .49805 L
.49894 .49816 L
.49899 .49826 L
.49905 .49835 L
.4991 .49845 L
.49915 .49853 L
.4992 .49861 L
.49924 .49869 L
.49928 .49876 L
.49932 .49883 L
Mistroke
.49936 .49889 L
.4994 .49895 L
.49943 .49901 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49921 L
.49957 .49926 L
.49959 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
Mistroke
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .313 r
.21246 .58934 m
.2416 .56139 L
.26736 .53806 L
.29016 .51868 L
.31037 .50267 L
.32832 .48955 L
.34427 .47888 L
.35848 .4703 L
.37116 .46349 L
.38248 .45819 L
.39262 .45416 L
.40171 .45119 L
.40988 .44912 L
.41723 .4478 L
.42385 .44711 L
.42984 .44693 L
.43525 .44717 L
.44016 .44776 L
.44463 .44862 L
.44869 .44971 L
.45239 .45097 L
.45577 .45236 L
.45886 .45385 L
.4617 .45541 L
.4643 .45702 L
.4667 .45865 L
.4689 .46029 L
.47093 .46192 L
.47281 .46354 L
.47455 .46513 L
.47616 .46669 L
.47766 .46822 L
.47905 .4697 L
.48034 .47113 L
.48154 .47252 L
.48266 .47386 L
.4837 .47515 L
.48468 .47638 L
.48559 .47757 L
.48644 .47871 L
.48724 .4798 L
.48798 .48084 L
.48868 .48183 L
.48934 .48277 L
.48995 .48367 L
.49053 .48453 L
.49108 .48535 L
.49159 .48612 L
.49207 .48686 L
.49252 .48756 L
Mistroke
.49294 .48823 L
.49334 .48886 L
.49372 .48946 L
.49407 .49002 L
.4944 .49056 L
.49472 .49107 L
.49501 .49156 L
.49529 .49201 L
.49556 .49245 L
.4958 .49286 L
.49604 .49325 L
.49626 .49362 L
.49647 .49396 L
.49666 .49429 L
.49685 .4946 L
.49702 .4949 L
.49719 .49518 L
.49735 .49544 L
.49749 .49569 L
.49763 .49593 L
.49776 .49615 L
.49789 .49636 L
.498 .49656 L
.49811 .49675 L
.49822 .49693 L
.49832 .4971 L
.49841 .49726 L
.4985 .49741 L
.49858 .49755 L
.49866 .49769 L
.49873 .49781 L
.4988 .49793 L
.49887 .49805 L
.49893 .49815 L
.49899 .49826 L
.49905 .49835 L
.4991 .49844 L
.49915 .49853 L
.4992 .49861 L
.49924 .49869 L
.49928 .49876 L
.49932 .49883 L
.49936 .49889 L
.49939 .49895 L
.49943 .49901 L
.49946 .49906 L
.49949 .49912 L
.49952 .49916 L
.49954 .49921 L
.49957 .49925 L
Mistroke
.49959 .4993 L
.49962 .49933 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49984 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
Mistroke
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.924 0 1 r
.80628 .69169 m
.78173 .6944 L
.75956 .69519 L
.73949 .6944 L
.7213 .69232 L
.70478 .68921 L
.68975 .68526 L
.67605 .68067 L
.66353 .67558 L
.65208 .67012 L
.64159 .6644 L
.63195 .65851 L
.6231 .65252 L
.61494 .64649 L
.60741 .64047 L
.60046 .63452 L
.59403 .62865 L
.58807 .6229 L
.58255 .61729 L
.57741 .61183 L
.57264 .60654 L
.5682 .60142 L
.56407 .59649 L
.56021 .59173 L
.5566 .58717 L
.55324 .58279 L
.55009 .5786 L
.54714 .57458 L
.54439 .57075 L
.5418 .56709 L
.53938 .5636 L
.5371 .56027 L
.53497 .55711 L
.53296 .5541 L
.53108 .55123 L
.5293 .54851 L
.52764 .54592 L
.52607 .54347 L
.5246 .54114 L
.52321 .53893 L
.5219 .53683 L
.52067 .53485 L
.51951 .53296 L
.51841 .53118 L
.51738 .52949 L
.51641 .52789 L
.51549 .52637 L
.51463 .52493 L
.51381 .52358 L
.51304 .52229 L
Mistroke
.51232 .52107 L
.51163 .51992 L
.51099 .51883 L
.51038 .5178 L
.5098 .51683 L
.50926 .51591 L
.50874 .51503 L
.50826 .51421 L
.5078 .51343 L
.50737 .51269 L
.50696 .512 L
.50658 .51134 L
.50621 .51071 L
.50587 .51013 L
.50555 .50957 L
.50524 .50904 L
.50495 .50855 L
.50468 .50808 L
.50442 .50763 L
.50417 .50721 L
.50394 .50681 L
.50373 .50644 L
.50352 .50609 L
.50333 .50575 L
.50314 .50543 L
.50297 .50513 L
.5028 .50485 L
.50265 .50458 L
.5025 .50433 L
.50237 .50409 L
.50224 .50387 L
.50211 .50366 L
.502 .50345 L
.50189 .50326 L
.50178 .50308 L
.50168 .50291 L
.50159 .50275 L
.5015 .5026 L
.50142 .50246 L
.50134 .50232 L
.50127 .50219 L
.5012 .50207 L
.50113 .50196 L
.50107 .50185 L
.50101 .50175 L
.50095 .50165 L
.5009 .50156 L
.50085 .50148 L
.50081 .50139 L
.50076 .50132 L
Mistroke
.50072 .50125 L
.50068 .50118 L
.50064 .50111 L
.50061 .50105 L
.50057 .50099 L
.50054 .50094 L
.50051 .50089 L
.50048 .50084 L
.50046 .50079 L
.50043 .50075 L
.50041 .50071 L
.50039 .50067 L
.50036 .50063 L
.50034 .5006 L
.50033 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50029 L
.50016 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
Mistroke
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .499 r
.72317 .70395 m
.70673 .69987 L
.69176 .69505 L
.67809 .68967 L
.66558 .68387 L
.65413 .67777 L
.64361 .67147 L
.63395 .66505 L
.62505 .65857 L
.61684 .65211 L
.60927 .64569 L
.60226 .63937 L
.59577 .63317 L
.58975 .62711 L
.58416 .62121 L
.57896 .61549 L
.57413 .60996 L
.56963 .60462 L
.56543 .59948 L
.56151 .59454 L
.55785 .5898 L
.55442 .58526 L
.55122 .58091 L
.54822 .57676 L
.54541 .57279 L
.54277 .56901 L
.5403 .5654 L
.53798 .56197 L
.5358 .5587 L
.53375 .5556 L
.53183 .55264 L
.53002 .54984 L
.52831 .54718 L
.52671 .54465 L
.5252 .54225 L
.52378 .53998 L
.52244 .53782 L
.52118 .53578 L
.51999 .53384 L
.51887 .53201 L
.51782 .53027 L
.51682 .52862 L
.51588 .52707 L
.515 .52559 L
.51416 .5242 L
.51337 .52288 L
.51263 .52163 L
.51193 .52044 L
.51127 .51933 L
.51064 .51827 L
Mistroke
.51005 .51727 L
.50949 .51632 L
.50897 .51543 L
.50847 .51458 L
.508 .51378 L
.50756 .51302 L
.50714 .51231 L
.50675 .51163 L
.50637 .51099 L
.50602 .51039 L
.50569 .50982 L
.50537 .50928 L
.50508 .50877 L
.5048 .50829 L
.50453 .50783 L
.50428 .5074 L
.50404 .50699 L
.50382 .50661 L
.50361 .50624 L
.50341 .5059 L
.50322 .50557 L
.50305 .50527 L
.50288 .50498 L
.50272 .5047 L
.50257 .50444 L
.50243 .5042 L
.50229 .50397 L
.50217 .50375 L
.50205 .50354 L
.50193 .50335 L
.50183 .50316 L
.50173 .50299 L
.50163 .50282 L
.50154 .50267 L
.50146 .50252 L
.50138 .50238 L
.5013 .50225 L
.50123 .50213 L
.50116 .50201 L
.5011 .5019 L
.50104 .50179 L
.50098 .5017 L
.50093 .5016 L
.50087 .50151 L
.50083 .50143 L
.50078 .50135 L
.50074 .50128 L
.5007 .50121 L
.50066 .50114 L
.50062 .50108 L
Mistroke
.50059 .50102 L
.50056 .50096 L
.50052 .50091 L
.5005 .50086 L
.50047 .50081 L
.50044 .50077 L
.50042 .50072 L
.5004 .50068 L
.50037 .50065 L
.50035 .50061 L
.50033 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50043 L
.50024 .50041 L
.50022 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
Mistroke
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.823 1 0 r
.22581 .77365 m
.25786 .72923 L
.28589 .69117 L
.31041 .65861 L
.33188 .63078 L
.35069 .60703 L
.3672 .5868 L
.38168 .5696 L
.39442 .555 L
.40562 .54265 L
.41549 .53222 L
.42419 .52344 L
.43187 .51609 L
.43866 .50994 L
.44467 .50484 L
.45 .50063 L
.45473 .49717 L
.45893 .49437 L
.46268 .49211 L
.46602 .49032 L
.46901 .48893 L
.47168 .48787 L
.47407 .48709 L
.47623 .48655 L
.47817 .4862 L
.47991 .48602 L
.48149 .48598 L
.48292 .48604 L
.48421 .4862 L
.48539 .48643 L
.48646 .48672 L
.48744 .48705 L
.48833 .48742 L
.48915 .48781 L
.48989 .48823 L
.49058 .48865 L
.49121 .48908 L
.49179 .48951 L
.49233 .48995 L
.49283 .49037 L
.49329 .4908 L
.49371 .49121 L
.4941 .49161 L
.49447 .492 L
.49481 .49238 L
.49513 .49275 L
.49542 .4931 L
.4957 .49344 L
.49596 .49377 L
.4962 .49408 L
Mistroke
.49642 .49438 L
.49663 .49467 L
.49683 .49494 L
.49701 .4952 L
.49719 .49545 L
.49735 .49569 L
.4975 .49592 L
.49764 .49613 L
.49778 .49634 L
.49791 .49653 L
.49802 .49672 L
.49814 .49689 L
.49824 .49706 L
.49834 .49722 L
.49843 .49737 L
.49852 .49751 L
.49861 .49764 L
.49868 .49777 L
.49876 .49789 L
.49883 .49801 L
.49889 .49812 L
.49895 .49822 L
.49901 .49831 L
.49907 .49841 L
.49912 .49849 L
.49917 .49858 L
.49921 .49865 L
.49926 .49873 L
.4993 .4988 L
.49934 .49886 L
.49938 .49893 L
.49941 .49898 L
.49944 .49904 L
.49947 .49909 L
.4995 .49914 L
.49953 .49919 L
.49956 .49923 L
.49958 .49928 L
.4996 .49932 L
.49963 .49935 L
.49965 .49939 L
.49967 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49957 L
.49976 .49959 L
.49978 .49961 L
.49979 .49963 L
Mistroke
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .047 r
.3767 .20505 m
.38166 .2245 L
.38659 .24245 L
.39145 .25904 L
.39624 .2744 L
.40092 .28863 L
.40548 .30184 L
.40991 .31411 L
.4142 .32553 L
.41835 .33616 L
.42234 .34607 L
.42618 .35532 L
.42987 .36395 L
.43341 .37202 L
.43679 .37957 L
.44003 .38664 L
.44312 .39326 L
.44607 .39946 L
.44888 .40528 L
.45156 .41075 L
.45411 .41588 L
.45653 .4207 L
.45884 .42522 L
.46103 .42948 L
.46311 .43349 L
.46508 .43726 L
.46696 .4408 L
.46873 .44414 L
.47042 .44729 L
.47201 .45025 L
.47353 .45304 L
.47496 .45568 L
.47632 .45816 L
.47761 .4605 L
.47883 .4627 L
.47998 .46478 L
.48107 .46674 L
.4821 .4686 L
.48308 .47034 L
.484 .47199 L
.48488 .47355 L
.48571 .47502 L
.48649 .4764 L
.48723 .47771 L
.48793 .47895 L
.48859 .48011 L
.48922 .48121 L
.48981 .48225 L
.49037 .48323 L
.4909 .48416 L
Mistroke
.4914 .48504 L
.49187 .48587 L
.49232 .48665 L
.49274 .48738 L
.49314 .48808 L
.49352 .48874 L
.49387 .48936 L
.49421 .48995 L
.49453 .4905 L
.49483 .49103 L
.49511 .49152 L
.49538 .49199 L
.49564 .49243 L
.49588 .49285 L
.49611 .49325 L
.49632 .49362 L
.49652 .49397 L
.49671 .4943 L
.49689 .49462 L
.49707 .49491 L
.49723 .49519 L
.49738 .49546 L
.49752 .49571 L
.49766 .49595 L
.49779 .49617 L
.49791 .49638 L
.49803 .49658 L
.49814 .49677 L
.49824 .49695 L
.49834 .49712 L
.49843 .49727 L
.49851 .49742 L
.4986 .49757 L
.49867 .4977 L
.49875 .49783 L
.49882 .49795 L
.49888 .49806 L
.49894 .49817 L
.499 .49827 L
.49906 .49836 L
.49911 .49845 L
.49916 .49854 L
.4992 .49862 L
.49925 .4987 L
.49929 .49877 L
.49933 .49884 L
.49936 .4989 L
.4994 .49896 L
.49943 .49902 L
.49946 .49907 L
Mistroke
.49949 .49912 L
.49952 .49917 L
.49955 .49922 L
.49957 .49926 L
.4996 .4993 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49944 L
.4997 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49956 L
.49976 .49958 L
.49977 .4996 L
.49978 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
Mistroke
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .347 1 r
.63982 .68684 m
.63086 .67871 L
.62257 .67074 L
.61487 .66295 L
.60772 .65538 L
.60108 .64804 L
.5949 .64094 L
.58914 .63409 L
.58376 .62749 L
.57875 .62116 L
.57406 .61507 L
.56968 .60925 L
.56558 .60368 L
.56174 .59835 L
.55814 .59326 L
.55477 .58842 L
.55161 .58379 L
.54863 .5794 L
.54584 .57521 L
.54322 .57123 L
.54076 .56744 L
.53844 .56385 L
.53626 .56044 L
.53421 .5572 L
.53228 .55413 L
.53046 .55121 L
.52874 .54845 L
.52713 .54583 L
.52561 .54335 L
.52417 .541 L
.52282 .53877 L
.52155 .53667 L
.52034 .53467 L
.51921 .53278 L
.51814 .53099 L
.51713 .5293 L
.51618 .5277 L
.51528 .52619 L
.51443 .52475 L
.51363 .5234 L
.51287 .52212 L
.51216 .52091 L
.51149 .51976 L
.51085 .51868 L
.51025 .51765 L
.50968 .51668 L
.50915 .51577 L
.50864 .5149 L
.50816 .51408 L
.50771 .51331 L
Mistroke
.50728 .51258 L
.50688 .51188 L
.5065 .51123 L
.50614 .51061 L
.5058 .51003 L
.50548 .50948 L
.50518 .50896 L
.50489 .50846 L
.50462 .508 L
.50437 .50756 L
.50413 .50714 L
.5039 .50675 L
.50369 .50638 L
.50348 .50602 L
.50329 .50569 L
.50311 .50538 L
.50294 .50508 L
.50277 .5048 L
.50262 .50454 L
.50248 .50429 L
.50234 .50405 L
.50221 .50383 L
.50209 .50362 L
.50197 .50342 L
.50187 .50323 L
.50176 .50305 L
.50167 .50288 L
.50157 .50272 L
.50149 .50257 L
.5014 .50243 L
.50133 .5023 L
.50125 .50217 L
.50119 .50205 L
.50112 .50194 L
.50106 .50183 L
.501 .50173 L
.50094 .50164 L
.50089 .50155 L
.50084 .50146 L
.5008 .50138 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50064 .5011 L
.5006 .50104 L
.50057 .50098 L
.50054 .50093 L
.50051 .50088 L
.50048 .50083 L
.50045 .50078 L
Mistroke
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50056 L
.5003 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .5004 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
Mistroke
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.501 1 0 r
.23488 .69988 m
.26441 .66303 L
.29032 .63166 L
.31307 .60501 L
.33308 .58242 L
.35069 .56331 L
.3662 .54721 L
.37989 .53367 L
.39198 .52234 L
.40267 .5129 L
.41214 .50508 L
.42054 .49863 L
.42801 .49337 L
.43465 .48911 L
.44056 .4857 L
.44585 .48301 L
.45057 .48094 L
.4548 .47938 L
.4586 .47826 L
.46201 .4775 L
.46508 .47704 L
.46786 .47684 L
.47036 .47684 L
.47264 .47701 L
.4747 .47732 L
.47657 .47774 L
.47828 .47825 L
.47983 .47883 L
.48126 .47946 L
.48256 .48012 L
.48375 .48081 L
.48485 .48152 L
.48586 .48223 L
.48679 .48295 L
.48765 .48366 L
.48845 .48436 L
.48918 .48505 L
.48987 .48573 L
.4905 .48639 L
.49109 .48703 L
.49163 .48764 L
.49214 .48824 L
.49262 .48882 L
.49306 .48937 L
.49348 .4899 L
.49386 .49041 L
.49422 .4909 L
.49456 .49137 L
.49488 .49181 L
.49518 .49224 L
Mistroke
.49546 .49264 L
.49572 .49303 L
.49596 .49339 L
.4962 .49374 L
.49641 .49407 L
.49662 .49439 L
.49681 .49469 L
.49699 .49497 L
.49716 .49524 L
.49732 .4955 L
.49747 .49574 L
.49761 .49597 L
.49775 .49619 L
.49787 .4964 L
.49799 .49659 L
.4981 .49678 L
.49821 .49695 L
.49831 .49712 L
.4984 .49728 L
.49849 .49742 L
.49858 .49756 L
.49866 .4977 L
.49873 .49782 L
.4988 .49794 L
.49887 .49806 L
.49893 .49816 L
.49899 .49826 L
.49905 .49836 L
.4991 .49845 L
.49915 .49853 L
.4992 .49861 L
.49924 .49869 L
.49928 .49876 L
.49932 .49883 L
.49936 .49889 L
.49939 .49896 L
.49943 .49901 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49954 .49921 L
.49957 .49926 L
.49959 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
Mistroke
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
Mistroke
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .179 r
.30472 .69664 m
.32759 .66484 L
.34758 .63759 L
.36507 .61426 L
.38038 .59433 L
.3938 .57731 L
.40556 .56281 L
.41589 .55047 L
.42497 .54 L
.43295 .53114 L
.43998 .52365 L
.44617 .51734 L
.45164 .51205 L
.45648 .50763 L
.46075 .50396 L
.46454 .50092 L
.46791 .49843 L
.4709 .4964 L
.47356 .49476 L
.47594 .49346 L
.47806 .49245 L
.47996 .49167 L
.48166 .49109 L
.48319 .49069 L
.48456 .49043 L
.4858 .49028 L
.48692 .49023 L
.48793 .49027 L
.48885 .49037 L
.48968 .49052 L
.49044 .49071 L
.49113 .49094 L
.49177 .49119 L
.49234 .49146 L
.49287 .49175 L
.49336 .49204 L
.4938 .49234 L
.49421 .49264 L
.49459 .49295 L
.49494 .49324 L
.49527 .49354 L
.49557 .49383 L
.49585 .49411 L
.4961 .49438 L
.49635 .49465 L
.49657 .4949 L
.49678 .49515 L
.49697 .49539 L
.49715 .49562 L
.49732 .49584 L
Mistroke
.49748 .49605 L
.49763 .49625 L
.49777 .49644 L
.4979 .49663 L
.49802 .4968 L
.49813 .49697 L
.49824 .49713 L
.49834 .49728 L
.49844 .49742 L
.49853 .49756 L
.49861 .49769 L
.49869 .49781 L
.49876 .49793 L
.49883 .49804 L
.4989 .49815 L
.49896 .49825 L
.49902 .49834 L
.49907 .49843 L
.49913 .49852 L
.49917 .4986 L
.49922 .49867 L
.49926 .49875 L
.49931 .49881 L
.49934 .49888 L
.49938 .49894 L
.49942 .499 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49953 .4992 L
.49956 .49924 L
.49958 .49929 L
.49961 .49932 L
.49963 .49936 L
.49965 .4994 L
.49967 .49943 L
.49969 .49946 L
.4997 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49976 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
Mistroke
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .501 1 r
.37697 .32411 m
.38459 .33234 L
.39169 .34032 L
.39829 .34803 L
.40444 .35546 L
.41018 .3626 L
.41555 .36946 L
.42056 .37604 L
.42524 .38234 L
.42963 .38836 L
.43374 .39412 L
.4376 .3996 L
.44121 .40484 L
.4446 .40982 L
.44779 .41457 L
.45078 .41908 L
.45359 .42337 L
.45623 .42745 L
.45872 .43132 L
.46106 .43499 L
.46326 .43848 L
.46533 .44179 L
.46728 .44493 L
.46912 .4479 L
.47086 .45072 L
.47249 .45339 L
.47403 .45592 L
.47548 .45831 L
.47685 .46058 L
.47814 .46272 L
.47936 .46476 L
.48051 .46668 L
.48159 .4685 L
.48262 .47022 L
.48358 .47185 L
.48449 .47339 L
.48535 .47485 L
.48617 .47622 L
.48693 .47753 L
.48766 .47876 L
.48834 .47993 L
.48899 .48103 L
.4896 .48207 L
.49017 .48305 L
.49071 .48398 L
.49123 .48487 L
.49171 .4857 L
.49217 .48648 L
.4926 .48723 L
.49301 .48793 L
Mistroke
.4934 .48859 L
.49376 .48922 L
.49411 .48981 L
.49443 .49037 L
.49474 .4909 L
.49503 .49141 L
.4953 .49188 L
.49556 .49233 L
.49581 .49275 L
.49604 .49315 L
.49626 .49353 L
.49646 .49388 L
.49666 .49422 L
.49684 .49454 L
.49702 .49484 L
.49718 .49512 L
.49734 .49539 L
.49748 .49565 L
.49762 .49589 L
.49775 .49611 L
.49788 .49633 L
.49799 .49653 L
.49811 .49672 L
.49821 .4969 L
.49831 .49707 L
.4984 .49723 L
.49849 .49739 L
.49857 .49753 L
.49865 .49767 L
.49873 .49779 L
.4988 .49792 L
.49886 .49803 L
.49893 .49814 L
.49898 .49824 L
.49904 .49834 L
.49909 .49843 L
.49914 .49852 L
.49919 .4986 L
.49924 .49868 L
.49928 .49875 L
.49932 .49882 L
.49935 .49888 L
.49939 .49894 L
.49942 .499 L
.49946 .49906 L
.49949 .49911 L
.49951 .49916 L
.49954 .4992 L
.49957 .49925 L
.49959 .49929 L
Mistroke
.49961 .49933 L
.49963 .49937 L
.49965 .4994 L
.49967 .49943 L
.49969 .49947 L
.49971 .49949 L
.49972 .49952 L
.49974 .49955 L
.49975 .49957 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49981 .49968 L
.49982 .4997 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49988 .49978 L
.49988 .4998 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49985 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
Mistroke
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.359 1 0 r
.52516 .28561 m
.51793 .30753 L
.51189 .3269 L
.50685 .34404 L
.50267 .35921 L
.49924 .37267 L
.49643 .38463 L
.49415 .39527 L
.49233 .40475 L
.4909 .41321 L
.4898 .42078 L
.48897 .42756 L
.48837 .43364 L
.48796 .43911 L
.48772 .44404 L
.48761 .44848 L
.48761 .4525 L
.48771 .45614 L
.48787 .45944 L
.4881 .46244 L
.48837 .46518 L
.48868 .46767 L
.48902 .46995 L
.48937 .47204 L
.48974 .47396 L
.49012 .47572 L
.4905 .47734 L
.49089 .47883 L
.49127 .48021 L
.49164 .48148 L
.49201 .48266 L
.49237 .48375 L
.49272 .48477 L
.49307 .48571 L
.4934 .48659 L
.49372 .4874 L
.49402 .48817 L
.49432 .48888 L
.4946 .48954 L
.49488 .49016 L
.49514 .49074 L
.49539 .49128 L
.49562 .49179 L
.49585 .49227 L
.49607 .49272 L
.49627 .49314 L
.49647 .49353 L
.49666 .4939 L
.49683 .49425 L
.497 .49458 L
Mistroke
.49716 .49488 L
.49731 .49517 L
.49746 .49545 L
.49759 .4957 L
.49772 .49595 L
.49785 .49617 L
.49796 .49639 L
.49807 .49659 L
.49818 .49678 L
.49828 .49696 L
.49837 .49713 L
.49846 .49729 L
.49854 .49744 L
.49862 .49758 L
.4987 .49772 L
.49877 .49785 L
.49884 .49797 L
.4989 .49808 L
.49896 .49818 L
.49902 .49829 L
.49907 .49838 L
.49912 .49847 L
.49917 .49856 L
.49922 .49863 L
.49926 .49871 L
.4993 .49878 L
.49934 .49885 L
.49937 .49891 L
.49941 .49897 L
.49944 .49903 L
.49947 .49908 L
.4995 .49913 L
.49953 .49918 L
.49955 .49923 L
.49958 .49927 L
.4996 .49931 L
.49962 .49935 L
.49964 .49938 L
.49966 .49942 L
.49968 .49945 L
.4997 .49948 L
.49972 .49951 L
.49973 .49954 L
.49975 .49956 L
.49976 .49959 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
Mistroke
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49994 .49989 L
.49994 .49989 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.222 0 1 r
.81414 .21013 m
.77795 .2588 L
.74628 .30041 L
.71853 .33596 L
.69421 .36626 L
.67287 .39206 L
.65412 .41398 L
.63764 .43255 L
.62313 .44826 L
.61035 .46149 L
.59907 .47262 L
.58911 .48192 L
.58029 .48968 L
.57249 .4961 L
.56556 .50139 L
.55941 .50571 L
.55394 .5092 L
.54906 .512 L
.5447 .5142 L
.54081 .51589 L
.53732 .51716 L
.53419 .51808 L
.53137 .51869 L
.52884 .51906 L
.52655 .51922 L
.52448 .51921 L
.5226 .51906 L
.5209 .5188 L
.51936 .51844 L
.51795 .51802 L
.51666 .51754 L
.51549 .51701 L
.51441 .51646 L
.51343 .51589 L
.51252 .5153 L
.51169 .51471 L
.51092 .51411 L
.51021 .51352 L
.50955 .51294 L
.50894 .51237 L
.50838 .51181 L
.50785 .51126 L
.50737 .51073 L
.50692 .51022 L
.5065 .50973 L
.5061 .50925 L
.50574 .50879 L
.50539 .50835 L
.50508 .50793 L
.50478 .50753 L
Mistroke
.5045 .50714 L
.50423 .50677 L
.50399 .50642 L
.50376 .50609 L
.50354 .50577 L
.50334 .50546 L
.50315 .50518 L
.50297 .5049 L
.5028 .50464 L
.50264 .50439 L
.50249 .50416 L
.50235 .50393 L
.50222 .50372 L
.50209 .50352 L
.50197 .50333 L
.50186 .50315 L
.50176 .50298 L
.50166 .50282 L
.50157 .50267 L
.50148 .50252 L
.5014 .50238 L
.50132 .50225 L
.50125 .50213 L
.50118 .50201 L
.50111 .5019 L
.50105 .5018 L
.50099 .5017 L
.50094 .50161 L
.50088 .50152 L
.50084 .50144 L
.50079 .50136 L
.50075 .50128 L
.5007 .50121 L
.50067 .50115 L
.50063 .50108 L
.50059 .50102 L
.50056 .50097 L
.50053 .50091 L
.5005 .50086 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
.5004 .50069 L
.50038 .50065 L
.50036 .50062 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
Mistroke
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
Mistroke
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.431 1 0 r
.7924 .44681 m
.76362 .47168 L
.73811 .49224 L
.71548 .50914 L
.69536 .5229 L
.67746 .53401 L
.66149 .54284 L
.64723 .54977 L
.63447 .55507 L
.62303 .559 L
.61276 .56179 L
.60353 .56362 L
.5952 .56464 L
.58769 .56501 L
.58089 .56483 L
.57472 .56421 L
.56913 .56322 L
.56404 .56195 L
.5594 .56046 L
.55517 .55879 L
.5513 .55699 L
.54775 .5551 L
.54449 .55314 L
.5415 .55115 L
.53874 .54914 L
.5362 .54714 L
.53385 .54515 L
.53168 .54319 L
.52967 .54127 L
.52781 .53939 L
.52607 .53756 L
.52446 .53579 L
.52297 .53407 L
.52157 .53242 L
.52027 .53083 L
.51906 .52929 L
.51792 .52783 L
.51686 .52642 L
.51587 .52507 L
.51494 .52378 L
.51407 .52255 L
.51325 .52138 L
.51249 .52027 L
.51177 .5192 L
.51109 .51819 L
.51046 .51723 L
.50986 .51631 L
.5093 .51544 L
.50877 .51462 L
.50828 .51383 L
Mistroke
.50781 .51309 L
.50737 .51239 L
.50695 .51172 L
.50656 .51109 L
.50619 .51049 L
.50585 .50992 L
.50552 .50938 L
.50521 .50887 L
.50492 .50839 L
.50465 .50793 L
.50439 .5075 L
.50414 .50709 L
.50391 .5067 L
.5037 .50633 L
.50349 .50599 L
.5033 .50566 L
.50311 .50535 L
.50294 .50506 L
.50278 .50478 L
.50262 .50452 L
.50248 .50427 L
.50234 .50404 L
.50221 .50381 L
.50209 .5036 L
.50197 .50341 L
.50187 .50322 L
.50176 .50304 L
.50166 .50287 L
.50157 .50272 L
.50149 .50257 L
.5014 .50243 L
.50133 .50229 L
.50125 .50217 L
.50118 .50205 L
.50112 .50193 L
.50106 .50183 L
.501 .50173 L
.50094 .50163 L
.50089 .50154 L
.50084 .50146 L
.5008 .50138 L
.50075 .5013 L
.50071 .50123 L
.50067 .50116 L
.50063 .5011 L
.5006 .50104 L
.50057 .50098 L
.50053 .50093 L
.50051 .50088 L
.50048 .50083 L
Mistroke
.50045 .50078 L
.50043 .50074 L
.5004 .5007 L
.50038 .50066 L
.50036 .50062 L
.50034 .50059 L
.50032 .50056 L
.5003 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .5004 L
.50022 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
Mistroke
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.337 1 0 r
.67738 .28128 m
.6557 .31395 L
.6368 .34207 L
.62033 .36625 L
.60595 .38703 L
.5934 .40488 L
.58244 .42019 L
.57286 .43332 L
.56448 .44455 L
.55714 .45416 L
.55072 .46236 L
.54508 .46935 L
.54014 .4753 L
.53579 .48036 L
.53197 .48464 L
.52861 .48826 L
.52565 .49131 L
.52303 .49387 L
.52072 .49601 L
.51867 .49779 L
.51686 .49927 L
.51526 .50048 L
.51383 .50147 L
.51256 .50227 L
.51142 .50291 L
.51041 .50341 L
.50951 .5038 L
.5087 .50408 L
.50797 .50429 L
.50731 .50443 L
.50673 .50451 L
.50619 .50454 L
.50571 .50453 L
.50528 .50449 L
.50488 .50442 L
.50452 .50434 L
.50419 .50424 L
.50389 .50412 L
.50362 .504 L
.50337 .50387 L
.50314 .50373 L
.50293 .50359 L
.50273 .50345 L
.50255 .50331 L
.50239 .50317 L
.50223 .50303 L
.50209 .5029 L
.50196 .50277 L
.50184 .50264 L
.50172 .50252 L
Mistroke
.50162 .5024 L
.50152 .50228 L
.50143 .50217 L
.50134 .50206 L
.50126 .50196 L
.50119 .50186 L
.50112 .50176 L
.50105 .50167 L
.50099 .50159 L
.50093 .5015 L
.50088 .50143 L
.50083 .50135 L
.50078 .50128 L
.50074 .50121 L
.50069 .50115 L
.50065 .50109 L
.50062 .50103 L
.50058 .50097 L
.50055 .50092 L
.50052 .50087 L
.50049 .50082 L
.50046 .50078 L
.50044 .50074 L
.50041 .5007 L
.50039 .50066 L
.50037 .50062 L
.50035 .50059 L
.50033 .50056 L
.50031 .50053 L
.50029 .5005 L
.50028 .50047 L
.50026 .50045 L
.50025 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50016 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
Mistroke
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
Mistroke
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .314 r
.25287 .24863 m
.27049 .25556 L
.2866 .26304 L
.30137 .2709 L
.31492 .27902 L
.32737 .2873 L
.33884 .29564 L
.34942 .30398 L
.35918 .31224 L
.36821 .32039 L
.37658 .32838 L
.38434 .33619 L
.39154 .34379 L
.39823 .35116 L
.40446 .35829 L
.41027 .36517 L
.41568 .37179 L
.42073 .37816 L
.42545 .38427 L
.42986 .39013 L
.43399 .39573 L
.43786 .40108 L
.44148 .40619 L
.44488 .41107 L
.44806 .41571 L
.45105 .42014 L
.45386 .42435 L
.4565 .42835 L
.45898 .43215 L
.46132 .43577 L
.46351 .4392 L
.46558 .44246 L
.46752 .44555 L
.46935 .44848 L
.47108 .45126 L
.4727 .45389 L
.47423 .45639 L
.47568 .45875 L
.47704 .46099 L
.47832 .46311 L
.47953 .46512 L
.48067 .46702 L
.48175 .46882 L
.48276 .47052 L
.48372 .47213 L
.48463 .47365 L
.48548 .47509 L
.48629 .47646 L
.48705 .47775 L
.48777 .47897 L
Mistroke
.48844 .48012 L
.48908 .48121 L
.48969 .48224 L
.49026 .48322 L
.4908 .48414 L
.49131 .48501 L
.49179 .48583 L
.49224 .48661 L
.49267 .48735 L
.49308 .48804 L
.49346 .4887 L
.49382 .48932 L
.49416 .48991 L
.49448 .49047 L
.49479 .49099 L
.49508 .49149 L
.49535 .49195 L
.4956 .4924 L
.49585 .49282 L
.49608 .49321 L
.49629 .49359 L
.4965 .49394 L
.49669 .49427 L
.49687 .49459 L
.49704 .49489 L
.49721 .49517 L
.49736 .49543 L
.49751 .49569 L
.49764 .49592 L
.49777 .49615 L
.4979 .49636 L
.49801 .49656 L
.49812 .49675 L
.49823 .49693 L
.49832 .4971 L
.49842 .49726 L
.4985 .49741 L
.49859 .49755 L
.49866 .49769 L
.49874 .49781 L
.49881 .49794 L
.49887 .49805 L
.49894 .49816 L
.49899 .49826 L
.49905 .49835 L
.4991 .49844 L
.49915 .49853 L
.4992 .49861 L
.49924 .49869 L
.49928 .49876 L
Mistroke
.49932 .49883 L
.49936 .49889 L
.4994 .49895 L
.49943 .49901 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49921 L
.49957 .49926 L
.49959 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
Mistroke
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.614 1 0 r
.48687 .33443 m
.48436 .34915 L
.48242 .36232 L
.48097 .37411 L
.47991 .38469 L
.4792 .3942 L
.47877 .40277 L
.47857 .4105 L
.47856 .41748 L
.47872 .42381 L
.479 .42955 L
.47939 .43477 L
.47986 .43952 L
.48039 .44386 L
.48097 .44782 L
.48158 .45145 L
.48222 .45478 L
.48287 .45784 L
.48353 .46065 L
.4842 .46325 L
.48486 .46564 L
.48551 .46785 L
.48615 .4699 L
.48677 .4718 L
.48738 .47356 L
.48797 .4752 L
.48855 .47672 L
.4891 .47814 L
.48963 .47946 L
.49015 .48069 L
.49064 .48185 L
.49111 .48292 L
.49156 .48393 L
.49199 .48487 L
.49241 .48576 L
.4928 .48658 L
.49318 .48736 L
.49353 .48809 L
.49387 .48877 L
.4942 .48942 L
.49451 .49002 L
.4948 .49059 L
.49508 .49112 L
.49534 .49163 L
.49559 .4921 L
.49583 .49255 L
.49605 .49297 L
.49626 .49336 L
.49647 .49373 L
.49666 .49408 L
Mistroke
.49684 .49442 L
.49701 .49473 L
.49717 .49502 L
.49733 .4953 L
.49747 .49556 L
.49761 .49581 L
.49774 .49604 L
.49787 .49626 L
.49798 .49647 L
.49809 .49667 L
.4982 .49685 L
.4983 .49703 L
.49839 .49719 L
.49848 .49735 L
.49856 .49749 L
.49864 .49763 L
.49871 .49776 L
.49879 .49789 L
.49885 .498 L
.49892 .49811 L
.49897 .49822 L
.49903 .49832 L
.49908 .49841 L
.49913 .4985 L
.49918 .49858 L
.49923 .49866 L
.49927 .49873 L
.49931 .4988 L
.49935 .49887 L
.49938 .49893 L
.49942 .49899 L
.49945 .49905 L
.49948 .4991 L
.49951 .49915 L
.49954 .4992 L
.49956 .49924 L
.49959 .49928 L
.49961 .49932 L
.49963 .49936 L
.49965 .49939 L
.49967 .49943 L
.49969 .49946 L
.49971 .49949 L
.49972 .49952 L
.49974 .49954 L
.49975 .49957 L
.49976 .49959 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
Mistroke
.49981 .49968 L
.49982 .49969 L
.49983 .49971 L
.49984 .49973 L
.49985 .49974 L
.49986 .49976 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .49981 L
.49989 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49984 L
.49992 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
Mistroke
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.656 0 1 r
.58068 .74652 m
.57865 .72875 L
.57641 .71251 L
.57401 .69766 L
.5715 .68404 L
.56892 .67153 L
.56631 .66003 L
.56367 .64944 L
.56105 .63967 L
.55845 .63064 L
.5559 .62229 L
.55339 .61455 L
.55095 .60737 L
.54857 .6007 L
.54627 .5945 L
.54404 .58873 L
.5419 .58335 L
.53983 .57833 L
.53785 .57365 L
.53594 .56927 L
.53412 .56518 L
.53238 .56135 L
.53071 .55776 L
.52912 .5544 L
.52761 .55124 L
.52616 .54829 L
.52479 .54551 L
.52348 .5429 L
.52224 .54045 L
.52105 .53814 L
.51993 .53597 L
.51887 .53393 L
.51785 .53201 L
.5169 .53021 L
.51599 .5285 L
.51512 .5269 L
.5143 .52539 L
.51353 .52397 L
.5128 .52263 L
.5121 .52136 L
.51144 .52017 L
.51082 .51904 L
.51023 .51798 L
.50967 .51698 L
.50914 .51603 L
.50865 .51514 L
.50817 .5143 L
.50773 .51351 L
.5073 .51276 L
.5069 .51205 L
Mistroke
.50652 .51138 L
.50617 .51075 L
.50583 .51016 L
.50551 .50959 L
.50521 .50906 L
.50492 .50856 L
.50465 .50809 L
.50439 .50764 L
.50415 .50722 L
.50392 .50682 L
.50371 .50644 L
.5035 .50609 L
.50331 .50575 L
.50313 .50543 L
.50296 .50513 L
.50279 .50485 L
.50264 .50458 L
.5025 .50433 L
.50236 .50409 L
.50223 .50386 L
.50211 .50365 L
.50199 .50345 L
.50188 .50326 L
.50178 .50308 L
.50168 .50291 L
.50159 .50275 L
.5015 .5026 L
.50142 .50245 L
.50134 .50232 L
.50126 .50219 L
.50119 .50207 L
.50113 .50196 L
.50107 .50185 L
.50101 .50175 L
.50095 .50165 L
.5009 .50156 L
.50085 .50147 L
.5008 .50139 L
.50076 .50132 L
.50072 .50124 L
.50068 .50117 L
.50064 .50111 L
.50061 .50105 L
.50057 .50099 L
.50054 .50094 L
.50051 .50088 L
.50048 .50084 L
.50046 .50079 L
.50043 .50075 L
.50041 .5007 L
Mistroke
.50038 .50067 L
.50036 .50063 L
.50034 .50059 L
.50032 .50056 L
.50031 .50053 L
.50029 .5005 L
.50027 .50047 L
.50026 .50045 L
.50024 .50042 L
.50023 .5004 L
.50022 .50038 L
.50021 .50036 L
.50019 .50034 L
.50018 .50032 L
.50017 .5003 L
.50016 .50028 L
.50016 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50023 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50014 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
Mistroke
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.534 1 0 r
.69151 .6615 m
.6771 .65927 L
.664 .65627 L
.65207 .65266 L
.64118 .64859 L
.63123 .64416 L
.62211 .63947 L
.61375 .63461 L
.60607 .62963 L
.599 .62461 L
.59248 .61958 L
.58647 .61458 L
.5809 .60964 L
.57575 .60479 L
.57098 .60005 L
.56655 .59543 L
.56243 .59095 L
.5586 .58661 L
.55504 .58242 L
.55171 .57838 L
.54861 .5745 L
.54571 .57077 L
.543 .5672 L
.54046 .56378 L
.53809 .56051 L
.53587 .55739 L
.53378 .55441 L
.53183 .55158 L
.52999 .54887 L
.52827 .5463 L
.52665 .54385 L
.52513 .54152 L
.5237 .53931 L
.52235 .53721 L
.52109 .53522 L
.5199 .53333 L
.51877 .53154 L
.51772 .52984 L
.51672 .52823 L
.51578 .5267 L
.5149 .52525 L
.51406 .52388 L
.51328 .52259 L
.51254 .52136 L
.51184 .52019 L
.51118 .51909 L
.51056 .51805 L
.50997 .51706 L
.50942 .51613 L
.50889 .51525 L
Mistroke
.5084 .51442 L
.50793 .51363 L
.50749 .51288 L
.50708 .51217 L
.50669 .51151 L
.50632 .51087 L
.50597 .51028 L
.50564 .50971 L
.50532 .50918 L
.50503 .50868 L
.50475 .5082 L
.50449 .50775 L
.50424 .50732 L
.50401 .50692 L
.50379 .50654 L
.50358 .50618 L
.50338 .50584 L
.50319 .50552 L
.50302 .50521 L
.50285 .50493 L
.50269 .50466 L
.50254 .5044 L
.5024 .50416 L
.50227 .50393 L
.50215 .50371 L
.50203 .50351 L
.50192 .50331 L
.50181 .50313 L
.50171 .50296 L
.50162 .5028 L
.50153 .50264 L
.50144 .5025 L
.50136 .50236 L
.50129 .50223 L
.50122 .50211 L
.50115 .50199 L
.50109 .50188 L
.50103 .50178 L
.50097 .50168 L
.50092 .50159 L
.50087 .5015 L
.50082 .50142 L
.50077 .50134 L
.50073 .50126 L
.50069 .50119 L
.50065 .50113 L
.50062 .50107 L
.50058 .50101 L
.50055 .50095 L
.50052 .5009 L
Mistroke
.50049 .50085 L
.50046 .5008 L
.50044 .50076 L
.50041 .50072 L
.50039 .50068 L
.50037 .50064 L
.50035 .50061 L
.50033 .50057 L
.50031 .50054 L
.50029 .50051 L
.50028 .50048 L
.50026 .50046 L
.50025 .50043 L
.50023 .50041 L
.50022 .50038 L
.50021 .50036 L
.5002 .50034 L
.50019 .50032 L
.50018 .50031 L
.50017 .50029 L
.50016 .50027 L
.50015 .50026 L
.50014 .50024 L
.50013 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .50019 L
.50011 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50016 L
.50008 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50012 L
.50007 .50012 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
Mistroke
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .258 r
.49823 .17647 m
.49108 .20686 L
.48529 .2339 L
.48065 .258 L
.477 .27951 L
.47418 .29875 L
.47206 .31597 L
.47053 .33143 L
.4695 .34533 L
.46888 .35785 L
.46859 .36914 L
.4686 .37935 L
.46883 .3886 L
.46925 .39699 L
.46982 .40462 L
.4705 .41156 L
.47129 .4179 L
.47214 .4237 L
.47304 .429 L
.47397 .43387 L
.47493 .43834 L
.4759 .44245 L
.47687 .44624 L
.47784 .44974 L
.47879 .45298 L
.47973 .45597 L
.48064 .45875 L
.48153 .46133 L
.4824 .46372 L
.48324 .46595 L
.48405 .46802 L
.48483 .46995 L
.48558 .47176 L
.4863 .47344 L
.48699 .47502 L
.48765 .47649 L
.48829 .47787 L
.48889 .47916 L
.48947 .48037 L
.49002 .48151 L
.49054 .48258 L
.49104 .48358 L
.49151 .48452 L
.49196 .4854 L
.49239 .48623 L
.4928 .48701 L
.49318 .48775 L
.49355 .48844 L
.49389 .48909 L
.49422 .48971 L
Mistroke
.49454 .49029 L
.49483 .49083 L
.49511 .49135 L
.49538 .49183 L
.49563 .49229 L
.49587 .49272 L
.49609 .49312 L
.4963 .49351 L
.49651 .49387 L
.4967 .49421 L
.49688 .49453 L
.49705 .49483 L
.49721 .49512 L
.49736 .49539 L
.49751 .49565 L
.49764 .49589 L
.49777 .49612 L
.49789 .49633 L
.49801 .49653 L
.49812 .49673 L
.49822 .49691 L
.49832 .49708 L
.49841 .49724 L
.4985 .49739 L
.49858 .49754 L
.49866 .49767 L
.49873 .4978 L
.4988 .49792 L
.49887 .49804 L
.49893 .49815 L
.49899 .49825 L
.49905 .49834 L
.4991 .49844 L
.49915 .49852 L
.4992 .4986 L
.49924 .49868 L
.49928 .49875 L
.49932 .49882 L
.49936 .49889 L
.49939 .49895 L
.49943 .49901 L
.49946 .49906 L
.49949 .49911 L
.49952 .49916 L
.49954 .49921 L
.49957 .49925 L
.49959 .49929 L
.49961 .49933 L
.49964 .49937 L
.49966 .4994 L
Mistroke
.49967 .49944 L
.49969 .49947 L
.49971 .4995 L
.49973 .49952 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.49979 .49964 L
.4998 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49971 L
.49984 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
Mistroke
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .347 1 r
.30876 .45756 m
.32583 .44858 L
.3411 .44161 L
.35476 .43633 L
.36702 .43247 L
.37803 .42981 L
.38795 .42815 L
.39689 .42732 L
.40497 .42718 L
.41229 .4276 L
.41892 .42847 L
.42495 .42971 L
.43044 .43125 L
.43544 .43301 L
.44001 .43494 L
.4442 .43701 L
.44804 .43916 L
.45156 .44137 L
.4548 .44361 L
.45779 .44586 L
.46055 .4481 L
.46309 .45032 L
.46545 .4525 L
.46763 .45463 L
.46966 .45672 L
.47154 .45874 L
.47329 .4607 L
.47492 .46259 L
.47644 .46442 L
.47786 .46617 L
.47918 .46786 L
.48042 .46948 L
.48157 .47103 L
.48266 .47251 L
.48367 .47393 L
.48462 .47528 L
.48551 .47656 L
.48635 .47779 L
.48713 .47896 L
.48787 .48007 L
.48856 .48113 L
.48921 .48213 L
.48983 .48308 L
.4904 .48399 L
.49095 .48485 L
.49146 .48566 L
.49194 .48643 L
.49239 .48717 L
.49282 .48786 L
.49322 .48852 L
Mistroke
.4936 .48914 L
.49396 .48973 L
.4943 .49029 L
.49461 .49082 L
.49491 .49132 L
.4952 .49179 L
.49546 .49224 L
.49572 .49266 L
.49595 .49306 L
.49618 .49344 L
.49639 .4938 L
.49659 .49414 L
.49678 .49446 L
.49696 .49477 L
.49713 .49505 L
.49729 .49533 L
.49744 .49558 L
.49758 .49583 L
.49771 .49605 L
.49784 .49627 L
.49796 .49648 L
.49807 .49667 L
.49818 .49685 L
.49828 .49703 L
.49837 .49719 L
.49846 .49734 L
.49855 .49749 L
.49863 .49763 L
.4987 .49776 L
.49878 .49788 L
.49884 .498 L
.49891 .49811 L
.49897 .49821 L
.49902 .49831 L
.49908 .4984 L
.49913 .49849 L
.49918 .49858 L
.49922 .49865 L
.49927 .49873 L
.49931 .4988 L
.49934 .49886 L
.49938 .49893 L
.49941 .49899 L
.49945 .49904 L
.49948 .49909 L
.49951 .49914 L
.49953 .49919 L
.49956 .49924 L
.49958 .49928 L
.49961 .49932 L
Mistroke
.49963 .49936 L
.49965 .49939 L
.49967 .49942 L
.49969 .49946 L
.4997 .49949 L
.49972 .49951 L
.49974 .49954 L
.49975 .49957 L
.49976 .49959 L
.49978 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .49971 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49987 .49977 L
.49987 .49978 L
.49988 .49979 L
.49989 .4998 L
.49989 .49981 L
.4999 .49983 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49988 L
.49993 .49988 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49995 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49997 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
Mistroke
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .016 r
.3871 .4223 m
.39599 .42197 L
.40403 .42226 L
.41133 .42308 L
.41795 .42432 L
.42397 .42588 L
.42947 .42771 L
.43448 .42974 L
.43907 .43192 L
.44328 .43421 L
.44714 .43656 L
.45069 .43896 L
.45396 .44137 L
.45697 .44377 L
.45976 .44615 L
.46234 .4485 L
.46472 .4508 L
.46694 .45305 L
.46899 .45523 L
.4709 .45735 L
.47268 .4594 L
.47434 .46137 L
.47589 .46327 L
.47733 .4651 L
.47868 .46685 L
.47994 .46853 L
.48112 .47014 L
.48222 .47167 L
.48326 .47314 L
.48423 .47453 L
.48514 .47587 L
.486 .47713 L
.4868 .47834 L
.48756 .47949 L
.48826 .48058 L
.48893 .48161 L
.48956 .48259 L
.49015 .48353 L
.49071 .48441 L
.49123 .48525 L
.49172 .48605 L
.49219 .4868 L
.49263 .48752 L
.49304 .48819 L
.49343 .48883 L
.4938 .48944 L
.49414 .49002 L
.49447 .49056 L
.49478 .49107 L
.49507 .49156 L
Mistroke
.49534 .49202 L
.4956 .49246 L
.49584 .49287 L
.49608 .49326 L
.49629 .49363 L
.4965 .49398 L
.49669 .49431 L
.49688 .49462 L
.49705 .49492 L
.49721 .4952 L
.49737 .49546 L
.49751 .49571 L
.49765 .49595 L
.49778 .49617 L
.4979 .49638 L
.49802 .49658 L
.49813 .49677 L
.49823 .49694 L
.49833 .49711 L
.49842 .49727 L
.49851 .49742 L
.49859 .49756 L
.49867 .4977 L
.49874 .49782 L
.49881 .49794 L
.49888 .49806 L
.49894 .49816 L
.499 .49827 L
.49905 .49836 L
.4991 .49845 L
.49915 .49854 L
.4992 .49862 L
.49924 .49869 L
.49929 .49877 L
.49933 .49883 L
.49936 .4989 L
.4994 .49896 L
.49943 .49902 L
.49946 .49907 L
.49949 .49912 L
.49952 .49917 L
.49955 .49922 L
.49957 .49926 L
.4996 .4993 L
.49962 .49934 L
.49964 .49937 L
.49966 .49941 L
.49968 .49944 L
.4997 .49947 L
.49971 .4995 L
Mistroke
.49973 .49953 L
.49974 .49955 L
.49976 .49958 L
.49977 .4996 L
.49978 .49962 L
.4998 .49965 L
.49981 .49966 L
.49982 .49968 L
.49983 .4997 L
.49984 .49972 L
.49985 .49973 L
.49985 .49975 L
.49986 .49976 L
.49987 .49977 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49986 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
Mistroke
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.83 1 0 r
.60383 .71936 m
.599 .70572 L
.59432 .69304 L
.58979 .68123 L
.58542 .67024 L
.58122 .65998 L
.57718 .65041 L
.5733 .64146 L
.56959 .63309 L
.56604 .62527 L
.56265 .61793 L
.55941 .61106 L
.55632 .60462 L
.55337 .59858 L
.55057 .5929 L
.5479 .58757 L
.54537 .58257 L
.54296 .57786 L
.54067 .57343 L
.53849 .56927 L
.53643 .56535 L
.53447 .56166 L
.53262 .55818 L
.53086 .55491 L
.52919 .55182 L
.52761 .54892 L
.52611 .54618 L
.52469 .5436 L
.52335 .54116 L
.52208 .53886 L
.52088 .5367 L
.51974 .53465 L
.51866 .53272 L
.51764 .53091 L
.51668 .52919 L
.51576 .52757 L
.5149 .52604 L
.51409 .52459 L
.51331 .52323 L
.51258 .52194 L
.51189 .52073 L
.51124 .51958 L
.51062 .5185 L
.51004 .51747 L
.50949 .51651 L
.50897 .51559 L
.50847 .51473 L
.50801 .51392 L
.50757 .51315 L
.50715 .51242 L
Mistroke
.50676 .51174 L
.50639 .51109 L
.50604 .51048 L
.5057 .5099 L
.50539 .50935 L
.50509 .50884 L
.50481 .50835 L
.50455 .50789 L
.5043 .50745 L
.50406 .50704 L
.50384 .50665 L
.50363 .50629 L
.50343 .50594 L
.50324 .50561 L
.50306 .5053 L
.50289 .50501 L
.50273 .50473 L
.50258 .50447 L
.50244 .50423 L
.5023 .50399 L
.50218 .50377 L
.50206 .50356 L
.50194 .50337 L
.50184 .50318 L
.50174 .50301 L
.50164 .50284 L
.50155 .50268 L
.50146 .50254 L
.50138 .5024 L
.50131 .50226 L
.50123 .50214 L
.50117 .50202 L
.5011 .50191 L
.50104 .5018 L
.50098 .50171 L
.50093 .50161 L
.50088 .50152 L
.50083 .50144 L
.50078 .50136 L
.50074 .50128 L
.5007 .50121 L
.50066 .50115 L
.50063 .50108 L
.50059 .50102 L
.50056 .50097 L
.50053 .50091 L
.5005 .50086 L
.50047 .50082 L
.50045 .50077 L
.50042 .50073 L
Mistroke
.5004 .50069 L
.50038 .50065 L
.50035 .50061 L
.50034 .50058 L
.50032 .50055 L
.5003 .50052 L
.50028 .50049 L
.50027 .50046 L
.50025 .50044 L
.50024 .50041 L
.50023 .50039 L
.50021 .50037 L
.5002 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .50029 L
.50016 .50028 L
.50015 .50026 L
.50014 .50025 L
.50014 .50023 L
.50013 .50022 L
.50012 .50021 L
.50011 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50006 .50011 L
.50006 .50011 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50003 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50002 .50004 L
Mistroke
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.432 1 0 r
.4339 .32787 m
.43624 .33962 L
.43863 .35042 L
.44103 .36036 L
.44343 .36953 L
.44582 .37799 L
.44817 .38582 L
.45047 .39307 L
.45272 .39979 L
.45491 .40603 L
.45704 .41184 L
.4591 .41723 L
.46108 .42226 L
.46299 .42695 L
.46483 .43133 L
.46659 .43542 L
.46828 .43924 L
.4699 .44282 L
.47144 .44617 L
.47292 .44931 L
.47433 .45225 L
.47567 .45501 L
.47694 .4576 L
.47816 .46004 L
.47932 .46232 L
.48041 .46447 L
.48146 .46649 L
.48245 .46839 L
.48339 .47018 L
.48428 .47187 L
.48513 .47345 L
.48593 .47495 L
.48669 .47636 L
.48741 .47768 L
.48809 .47893 L
.48874 .48011 L
.48935 .48122 L
.48993 .48227 L
.49048 .48326 L
.491 .48419 L
.49149 .48507 L
.49195 .4859 L
.49239 .48668 L
.49281 .48742 L
.4932 .48812 L
.49358 .48878 L
.49393 .4894 L
.49426 .48999 L
.49458 .49054 L
.49487 .49107 L
Mistroke
.49515 .49156 L
.49542 .49203 L
.49567 .49247 L
.49591 .49289 L
.49613 .49328 L
.49635 .49365 L
.49655 .494 L
.49674 .49433 L
.49692 .49465 L
.49709 .49494 L
.49725 .49522 L
.4974 .49549 L
.49754 .49573 L
.49768 .49597 L
.49781 .49619 L
.49793 .4964 L
.49804 .4966 L
.49815 .49679 L
.49825 .49697 L
.49835 .49713 L
.49844 .49729 L
.49852 .49744 L
.4986 .49758 L
.49868 .49772 L
.49875 .49784 L
.49882 .49796 L
.49889 .49807 L
.49895 .49818 L
.49901 .49828 L
.49906 .49837 L
.49911 .49846 L
.49916 .49855 L
.49921 .49863 L
.49925 .4987 L
.49929 .49878 L
.49933 .49884 L
.49937 .49891 L
.4994 .49897 L
.49944 .49902 L
.49947 .49908 L
.4995 .49913 L
.49952 .49918 L
.49955 .49922 L
.49958 .49927 L
.4996 .49931 L
.49962 .49934 L
.49964 .49938 L
.49966 .49941 L
.49968 .49945 L
.4997 .49948 L
Mistroke
.49971 .49951 L
.49973 .49953 L
.49975 .49956 L
.49976 .49958 L
.49977 .49961 L
.49979 .49963 L
.4998 .49965 L
.49981 .49967 L
.49982 .49969 L
.49983 .4997 L
.49984 .49972 L
.49985 .49974 L
.49986 .49975 L
.49986 .49976 L
.49987 .49978 L
.49988 .49979 L
.49988 .4998 L
.49989 .49981 L
.4999 .49982 L
.4999 .49983 L
.49991 .49984 L
.49991 .49985 L
.49992 .49986 L
.49992 .49987 L
.49993 .49987 L
.49993 .49988 L
.49993 .49989 L
.49994 .49989 L
.49994 .4999 L
.49994 .4999 L
.49995 .49991 L
.49995 .49991 L
.49995 .49992 L
.49996 .49992 L
.49996 .49993 L
.49996 .49993 L
.49996 .49994 L
.49996 .49994 L
.49997 .49994 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49997 .49995 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49996 L
.49998 .49997 L
.49998 .49997 L
.49998 .49997 L
Mistroke
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .237 0 r
.69657 .23782 m
.6721 .27589 L
.6508 .30871 L
.63225 .33699 L
.61609 .36134 L
.602 .3823 L
.58972 .40032 L
.579 .41581 L
.56964 .42912 L
.56147 .44053 L
.55433 .45031 L
.54808 .45869 L
.54261 .46585 L
.53782 .47196 L
.53362 .47717 L
.52993 .48161 L
.52669 .48537 L
.52384 .48856 L
.52134 .49126 L
.51913 .49353 L
.51718 .49544 L
.51545 .49704 L
.51393 .49837 L
.51258 .49947 L
.51138 .50037 L
.51031 .50111 L
.50937 .5017 L
.50852 .50218 L
.50777 .50255 L
.50709 .50284 L
.50649 .50305 L
.50594 .5032 L
.50546 .50331 L
.50502 .50336 L
.50462 .50339 L
.50426 .50338 L
.50394 .50335 L
.50364 .5033 L
.50337 .50324 L
.50313 .50316 L
.5029 .50308 L
.5027 .50298 L
.50251 .50288 L
.50234 .50278 L
.50218 .50268 L
.50204 .50258 L
.5019 .50247 L
.50178 .50237 L
.50167 .50226 L
.50156 .50216 L
Mistroke
.50146 .50207 L
.50137 .50197 L
.50129 .50188 L
.50121 .50179 L
.50113 .5017 L
.50107 .50162 L
.501 .50154 L
.50094 .50146 L
.50089 .50139 L
.50083 .50132 L
.50078 .50125 L
.50074 .50118 L
.5007 .50112 L
.50066 .50106 L
.50062 .50101 L
.50058 .50095 L
.50055 .5009 L
.50052 .50086 L
.50049 .50081 L
.50046 .50077 L
.50043 .50073 L
.50041 .50069 L
.50039 .50065 L
.50037 .50062 L
.50034 .50058 L
.50033 .50055 L
.50031 .50052 L
.50029 .50049 L
.50027 .50047 L
.50026 .50044 L
.50024 .50042 L
.50023 .50039 L
.50022 .50037 L
.50021 .50035 L
.50019 .50033 L
.50018 .50031 L
.50017 .5003 L
.50016 .50028 L
.50015 .50027 L
.50015 .50025 L
.50014 .50024 L
.50013 .50022 L
.50012 .50021 L
.50012 .5002 L
.50011 .50019 L
.5001 .50018 L
.5001 .50017 L
.50009 .50016 L
.50009 .50015 L
.50008 .50014 L
Mistroke
.50008 .50013 L
.50007 .50013 L
.50007 .50012 L
.50007 .50011 L
.50006 .50011 L
.50006 .5001 L
.50006 .5001 L
.50005 .50009 L
.50005 .50009 L
.50005 .50008 L
.50004 .50008 L
.50004 .50007 L
.50004 .50007 L
.50004 .50006 L
.50004 .50006 L
.50003 .50006 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50005 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50004 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
Mistroke
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{1000, 1000},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000?X0003j2000`400?l00000o`00003ooooonf[o
oookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00
oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[
oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Z
oooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooook
J_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z
003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooook
J^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooo
nf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oo
oo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]Zjooo
nfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oo
oo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[o
oookJ_oooo]ZjooonfX00?3ooo]Z0ol007oooookJ_3ooo]Z0ol007oooookJPCooo]Z003`oookJP?o
001ooooonf[`oookJP?o001ooooonfX4oookJP00l?oonfX3o`00Oooooo]Zl?oonfX3o`00Oooooo]Z
1?oonfX00>3ooo]Z2_l007l6oookJP?o001o2?oonfX4o`000?oooo]Ze?oonfX:o`00O`Kooo]Z0ol0
07l8oookJPCo0000mooonfX002Kooo]Z0ol0o`0<oookJP;oo`0H3?oonfX00oooW`3oiOl0onGo0003
onGo00cooo]Z0_l09Ol;oookJP03ool0D?oonf[ooo]Z00Cooo]Z00?oo`2loookJ_oonfX00ooonfX0
1?m30?oo05SooookJ_l0o`@2oookJPGoU?l000Oo0?oboiCo0?oonf[o09[oo`3oD?l0P?oooo]Z00Wo
iOl000Cooj@0oookJ_oonf[oW?l01?oonfX00ooo04;ooo]ZoookJP04oookJP05o`2Toooonf[ooo]Z
oookJ_nMo`001?oonfX00ooo09?ooo]Zo`2do`03oookJP03omWo0?l04?oooo]Z00Sooo]Z00?oFol0
oookJ_oonfX04OoonfX00ol07?oooo]ZoookJP0FoookJP[o001o1_oonfX3o`00O`Sooo]Z1_l0000?
oookJP03okCo0?oonf[ooo]Z02gooo]Z00?o00OooookJ_oonfX0;ooonfX00oooY`3o0?o2oookJP08
oookJP03ocl0oooonf[ooo]Z04kooo]Z1oooN@14oookJP;o0?l03OoonfX2ool060_ooo]Z0oooW`0@
oookJP;o02Go2ooonfX00ooo053ooo]ZoookJP04oookJP03ool0_?oonf[ooo]Z00?ooo]Z00?o05So
oookJ_l0o`@00ooonfX02_l0okWooo]Zoooo0?l0o`7o0?obool0Eoo8o`3o09[ook_o0?l0oe02oook
JP;oo`0<0_oonfX01Om^o`3ooo]ZoookJ_oonf[o01Wo00;ooo]Z00?oW?l0oookJ_oonfX00_oonfX0
0ooo04;ooo]ZoookJP04oookJP05o`2Toooonf[ooo]ZoookJ_nMo`001?oonfX01?oo09?ooo]Zoook
J_l0]?l3oookJP03o`0@oooonf[ooo]Z00Oooo]Z00?oFol0oookJ_oonfX04OoonfX00ol07?oooo]Z
oookJP0FoookJP[o001o1_oonfX3o`00O`Sooo]Z1_l0000@oookJP03okCo0?oonf[ooo]Z02cooo]Z
00?o00OooookJ_oonfX0;ooonfX00oooY`3o0?o2o`3o`P08oookJP03ocl0oooonf[ooo]Z05;ooo]Z
00?oob00oookJ_oonfX08OoonfX002Wooo]Z0ol0o`0;oookJP;oo`0H2ooonfX6onGo00gooo]Z00?o
02GooookJ_oonfX02OoonfX00ooo053ooo]ZoookJP04oookJP03ool0_?oonf[ooo]Z00;ooo]Z00Go
@`3oo`1Hoooonf[oonh0o`3o1002oookJPCoU?l000Ko0?obool0EonDo`3o09[ook_o0?l0oe02oook
JPSoiOl000Cooj@0oookJ_oonf[oW?l01?oonfX00ooo04;ooo]ZoookJP04oookJP05o`2Toooonf[o
oo]ZoookJ_nMo`001?oonfX01?oo09?ooo]ZoookJ_l0]?l2oookJP03omWo0?l04?oooo]Z00Sooo]Z
00?oFol0oookJ_oonfX04OoonfX00ol07?oooo]ZoookJP0VoookJP?o001o2?oonfX4o`00017ooo]Z
00?o]?l0oookJ_oonfX0;OoonfX00ol01ooooo]ZoookJP0_oookJP03oonW0?l0ol;ooo]Z00Sooo]Z
00?o?`3ooookJ_oonfX0COoonfX9oomi04Gooo]Z0ol0o`0<oookJP;oo`0H3?oonfX00oooW`3ooo]Z
oookJP0?oookJP03o`0Uoooonf[ooo]Z00Sooo]Z00?oo`1@oookJ_oonfX01OoonfX00ooo0;cooo]Z
oookJP02oookJP04o`1Hoooonf[oonh0o`3o10?ooo]Z00Wo0?nioooo0?l0o`7o0?oboookJ_oo05Oo
09[ook_o0?l0oe000ooonfX01?oo00cooo]ZoookJ_m^o`03oookJP04o`0Ioooonf[ooo]Zoico00Co
oo]Z00?oo`12oookJ_oonfX01?oonfX01Ol0Y?oooo]ZoookJ_oonf[oWOl000Cooo]Z00Coo`2Coook
J_oonf[o0;Co0ooonfX00ol04?oooo]ZoookJP07oookJP03oe_o0?oonf[ooo]Z017ooo]Z00?o01co
oookJ_oonfX09_oonfX3o`00O`Sooo]Z1?l0000BoookJP03okCo0?oonf[ooo]Z02cooo]Z00?o00Oo
oookJ_oonfX0;ooonfX00oooY`3o0?o2oookJP08oookJP03ocl0oooonf[ooo]Z05;ooo]Z00?oob00
oookJ_oonfX08OoonfX002cooo]Z0ol0o`0:oookJP?oo`0H1ooonfX8onGo00gooo]Z00?o02Gooook
J_oonfX02OoonfX00ooo053ooo]ZoookJP03oookJP03ool0_?oonf[ooo]Z00?ooo]Z00Co@`3oo`1H
oooonf[o0?l40ooonfX4oiCo0006o`3ol_nDo`3ooo]Zo`2Joonko`3o0?m@0_oonfX7onGo0005o`0I
ooooY03ooo]ZoookJ_nLo`001?oonfX00ooo04;ooo]ZoookJP03oookJP05o`2Toooonf[ooo]Zoook
J_nMo`001?oonfX01?oo09?ooo]ZoookJ_l0]?l2oookJP03omWo0?l04?oooo]Z00Sooo]Z00?oFol0
oookJ_oonfX04OoonfX00ol07?oooo]ZoookJP0VoookJP?o001o2?oonfX4o`00017ooo]Z00?o]?l0
oookJ_oonfX0;?oonfX00ol01ooooo]ZoookJP0_oookJP03oonW0?l0ol;ooo]Z00Sooo]Z00?o?`3o
oookJ_oonfX0C_oonfX7oomi04[ooo]Z0ol0o`0;oookJP?oo`0H2_oonfX2oonO013ooo]Z00?o02Go
oookJ_oonfX02?oonfX00ooo053ooo]ZoookJP04oookJP03ool0_?oonf[ooo]Z00?ooo]Z00?o05So
oookJ_l0o`@01?oonfX02Ol0okWoool0o`3o0Ol0oo;oo`1GolSo0?l0V_oo^ol0o`3oD003oookJP04
ool03?oonf[ooo]Zofko00?ooo]Z00Co01WooookJ_oonf[oW?l01?oonfX00ooo04;ooo]ZoookJP04
oookJP04o`2Toooonf[ooo]Zoigo00Cooo]Z00Coo`2CoookJ_oonf[o0;Co0ooonfX00ol04?oooo]Z
oookJP07oookJP03oe_o0?oonf[ooo]Z017ooo]Z00?o01cooookJ_oonfX09_oonfX3o`00O`Sooo]Z
1?l0000AoookJP03okCo0?oonf[ooo]Z02cooo]Z00?o00OooookJ_oonfX0;ooonfX00oooY`3o0?o2
oookJP08oookJP03ocl0oooonf[ooo]Z05;ooo]Z00?oob00oookJ_oonfX08_oonfX002oooo]Z0ol0
o`0:oookJP;oo`0H1?oonfX:onGo00gooo]Z0_l09Ol:oookJP03ool0D?oonf[ooo]Z00?ooo]Z00?o
o`2loookJ_oonfX00ooonfX01?m30?oo05SooookJ_l0o`@3oookJPCoU?l000So0?obolSo0?oonf[o
09[oo`3oD?l0P?oooo]Zool030KoiOl000Gooo]Zo`0Ioooonf[ooo]Zoico0004oookJP03ool0@_oo
nf[ooo]Z00Cooo]Z00Go0:CooookJ_oonf[ooo]Zoigo0004oookJP03ool0Tooonf[o0;Co00?ooo]Z
00?o013ooookJ_oonfX01ooonfX00omKo`3ooo]ZoookJP0AoookJP03o`0Loooonf[ooo]Z02Kooo]Z
0ol007l8oookJPCo00004?oonfX00ondo`3ooo]ZoookJP0]oookJP03o`07oooonf[ooo]Z02oooo]Z
00?oojL0o`3o`_oonfX01ooonfX00olo0?oooo]ZoookJP1>oookJPOoogT0C_oonfX3o`3o00_ooo]Z
0_oo01P:oookJP;ooil03ooonfX00ol09Ooooo]ZoookJP08oookJP03ool0D?oonf[ooo]Z00Cooo]Z
00?oo`2loookJ_oonfX00ooonfX00ol0F?oooo]Zo`3o1003oookJP0:o`3o^Ooonf[oool0o`3o0Ol0
oo;oo`1GolSo0?l0V_oo0?m@o`20o`;ooo]Z00Coo`0<oookJ_oonf[oK_l00ooonfX01?l06Ooooo]Z
oookJ_nLo`04oookJP03ool0@_oonf[ooo]Z00Cooo]Z00Go0:CooookJ_oonf[ooo]Zoigo0004oook
JP03ool0Tooonf[o0;Co00Cooo]Z00?o013ooookJ_oonfX01_oonfX00omKo`3ooo]ZoookJP0Aoook
JP03o`0Loooonf[ooo]Z02Kooo]Z0ol007l8oookJPCo00004OoonfX00ondo`3ooo]ZoookJP0/oook
JP03o`07oooonf[ooo]Z02oooo]Z00?oojL0o`3o`_oonfX02?oonfX00olo0?oooo]ZoookJP1Aoook
JP03oolP0?oonf[ooo]Z02?ooo]Z000boookJP?o0?l02OoonfX2ool060Cooo]Z2OoUo`0>oookJP03
o`0Uoooonf[ooo]Z00Sooo]Z00?oo`1@oookJ_oonfX00ooonfX00ooo0;cooo]ZoookJP03oookJP04
od<0ool0F?oooo]Zo`3o10?ooo]Z1?nDo`001Ol0oo;ob?l0o`2Joonko`3o0?m@00;ooo]Z00?oo`0<
onGo0?oUo`001?oUo`001Ooonf[o01WooookJ_oonf[oW?l000Cooo]Z00?oo`12oookJ_oonfX00ooo
nfX01Ol0Y?oooo]ZoookJ_oonf[oWOl000Cooo]Z00Coo`2CoookJ_oonf[o0;Co0_oonfX00ooIo`3o
013ooookJP08oookJP03oe_o0?oonf[ooo]Z013ooo]Z00?o01cooookJ_oonfX09_oonfX3o`00O`So
oo]Z1?l0000@oookJP03okCo0?oonf[ooo]Z02cooo]Z00?o00OooookJ_oonfX0;ooonfX00oooY`3o
0?o2oookJP08oookJP03ocl0oooonf[ooo]Z04kooo]Z1_ooN@1BoookJP?o0?l02_oonfX2ool060[o
oo]Z00?ooil0oookJ_oonfX03OoonfX00ol09Ooooo]ZoookJP08oookJP03ool0D?oonf[ooo]Z00Co
oo]Z00?oo`2loookJ_oonfX00ooonfX00ol0F?oooo]Zo`3o1003oookJP0:o`3o^Oooo`3o0?l1oook
J_l0oo;oo`1Go`2Joooonf[o0?m@o`3o[P;ooo]Z00Coo`0<oookJ_oonf[oK_l00ooonfX01?l06Ooo
oo]ZoookJ_nLo`04oookJP03ool0@_oonf[ooo]Z00Cooo]Z00Co0:CooookJ_oonf[oWOl01?oonfX0
1?oo09?ooo]ZoookJ_l0]?l3oookJP03o`0@oooonf[ooo]Z00Oooo]Z00?oFol0oookJ_oonfX04?oo
nfX00ol07?oooo]ZoookJP0VoookJP?o001o2?oonfX4o`00017ooo]Z00?o]?l0oookJ_oonfX0:ooo
nfX00ol01ooooo]ZoookJP0_oookJP03oonW0?l0ol;ooo]Z00Sooo]Z00?o?`3ooookJ_oonfX0DOoo
nfX00ooo803ooo]ZoookJP0ToookJP00=OoonfX2o`3o00Wooo]Z0_oo01P5oookJPOoiOl03_oonfX0
0ol09Ooooo]ZoookJP08oookJP03ool0D?oonf[ooo]Z00?ooo]Z00?oo`2loookJ_oonfX00ooonfX0
1?m30?oo05SooookJ_l0o`@3oookJP09o`3o^OnDo`3oU?l0oiCo0?l0oo;ooo]Zo`2Jool0oe3o083o
00;oU?l000?oo`0<onGo0?oUo`000ooUo`001Ooonf[o01WooookJ_oonf[oW?l000Cooo]Z00?oo`12
oookJ_oonfX00ooonfX01Ol0Y?oooo]ZoookJ_oonf[oWOl000Cooo]Z00Coo`2CoookJ_oonf[o0;Co
0_oonfX00ooIo`3o013ooookJP08oookJP03oe_o0?oonf[ooo]Z013ooo]Z00?o01cooookJ_oonfX0
8ooonfX6o`00O`Sooo]Z1?l0000@oookJP03okCo0?oonf[ooo]Z02cooo]Z00?o00OooookJ_oonfX0
;_oonfX00oooY`3ooo]Zo`3o`P08oookJP03ocl0oooonf[ooo]Z04oooo]Z1OooN@1FoookJP;o0?l0
2_oonfX2ool060Wooo]Z0_ooW`0>oookJP03o`0Uoooonf[ooo]Z00Sooo]Z00?oo`1@oookJ_oonfX0
1?oonfX00ooo0;cooo]ZoookJP03oookJP03o`1Hoooonf[o0?l400?ooo]Z00Wo0?nioooo0?l0o`7o
oo]Zo`3ol_o8o`3o09[oo`3oD?l0P?l00_oonfX01?oo00cooo]ZoookJ_m^o`03oookJP05o`0Ioooo
nf[ooo]ZoookJ_nLo`000ooonfX00ooo04;ooo]ZoookJP04oookJP04o`2Toooonf[ooo]Zoigo00Co
oo]Z00Coo`2CoookJ_oonf[o0;Co0ooonfX00ol04?oooo]ZoookJP07oookJP03oe_o0?oonf[ooo]Z
013ooo]Z00?o01cooookJ_oonfX08ooonfX6o`00O`Sooo]Z1?l0000@oookJP03okCo0?oonf[ooo]Z
02cooo]Z00?o00OooookJ_oonfX0;_oonfX00oooY`3ooo]Zo`3o`P08oookJP03ocl0oooonf[ooo]Z
05;ooo]Z00?oob00oookJ_oonfX09?oonfX003Oooo]Z0ol0o`08oookJP;oo`0H1_oonfX5onGo00ko
oo]Z0_l09Ol9oookJP03ool0D?oonf[ooo]Z00?ooo]Z00?oo`2loookJ_oonfX00ooonfX01?m30?oo
05Soo`3o1?ookP02oookJP0<o`3o^Ooonf[oU?l0oiCo0?l0oo;ob?l0oiCo0?l0V_oo0?m@o`20oonD
o`3oo`0<1OoUo`02oookJP03o`0Ioooonf[oW?l000Gooo]Z00?oo`12oookJ_oonfX00ooonfX01Ol0
Y?oooo]ZoookJ_oonf[oWOl000Cooo]Z00?oo`2CoookJ_l0]?l00ooonfX00ol04?oooo]ZoookJP07
oookJP03oe_o0?oonf[ooo]Z013ooo]Z00?o01cooookJ_oonfX08ooonfX6o`00O`Sooo]Z1?l0000@
oookJP03okCo0?oonf[ooo]Z02cooo]Z00?o00OooookJ_oonfX0;_oonfX00oooY`3o0?o2oookJP08
oookJP03ocl0oooonf[ooo]Z04kooo]Z1OooN@1IoookJP?o0?l02OoonfX2ool060Wooo]Z0_ooW`0=
oookJP;o02Go2OoonfX00ooo053ooo]ZoookJP04oookJP03ool0_?oonf[ooo]Z00?ooo]Z00?o05So
o`3o1?ookP000ooonfX02Ol0okWoool0o`3o0Ol0oo;oo`1GolSo0?l0V_oo0?m@o`20o`02oookJP04
ool03?oonf[ooo]Zofko00?ooo]Z00Co01WooookJ_oonf[oW?l01?oonfX00ooo04;ooo]ZoookJP03
oookJP05o`2Toooonf[ooo]ZoookJ_nMo`001?oonfX00ooo09?ooo]Zo`2do`03oookJP03o`0@oooo
nf[ooo]Z00Oooo]Z00?oFol0oookJ_oonfX04?oonfX00ol07?oooo]ZoookJP0SoookJPKo001o2?oo
nfX4o`00013ooo]Z00?o]?l0oookJ_oonfX0;?oonfX00ol01ooooo]ZoookJP0^oookJP03oonW0?l0
ol;ooo]Z00Sooo]Z00?o?`3ooookJ_oonfX0DOoonfX00ooo803ooo]ZoookJP0UoookJP00>_oonfX2
o`3o00Sooo]Z0_oo01P7oookJP?oiOl03ooonfX00ol09Ooooo]ZoookJP07oookJP03ool0D?oonf[o
oo]Z00?ooo]Z00?oo`2loookJ_oonfX00_oonfX01Om30?oooo]Zo`1Hool0o`Coonh000;ooo]Z00Wo
0?nioookJ_nDo`3oU?l0o`3ol_o8o`3o09[ooiCo0?l0oe000_nDo`000ooo00coiOl0onGo0002onGo
00;ooo]Z00Co01WooookJ_oonf[oW?l01?oonfX00ooo04;ooo]ZoookJP03oookJP05o`2Toooonf[o
oo]ZoookJ_nMo`001?oonfX00ooo09?ooo]Zo`2do`03oookJP03o`0@oooonf[ooo]Z00Oooo]Z00?o
Fol0oookJ_oonfX04?oonfX00ol07?oooo]ZoookJP0UoookJPCo001o2?oonfX4o`0000oooo]Z00?o
]?l0oookJ_oonfX0;?oonfX00ol01ooooo]ZoookJP0^oookJP03oonW0?l0ol;ooo]Z00Sooo]Z00?o
?`3ooookJ_oonfX0CooonfX3oomi05kooo]Z0_l0o`09oookJP;oo`0H2OoonfX00oooW`3ooo]Zoook
JP0<oookJP03o`0Uoooonf[ooo]Z00Oooo]Z00?oo`1@oookJ_oonfX01?oonfX00ooo0;cooo]Zoook
JP02oookJP04od<0ool0F?oo0?l4ooo^00;ooo]Z00co0?nioookJ_l0o`7ooo]Zo`3ol_oo05Oo09[o
oookJ_l0oe3o0?n^oookJ_oo00`2oookJP05ofko0?oonf[ooo]ZoookJ_l06Ol00ooonfX01OnLo`3o
oo]ZoookJ_oonf[oo`1200Kooo]Z00Co0:CooookJ_oonf[oWOl01?oonfX00ooo09?ooo]Zo`2do`03
oookJP03o`0@oooonf[ooo]Z00Oooo]Z00?oFol0oookJ_oonfX04?oonfX00ol07?oooo]ZoookJP0U
oookJPCo001o2?oonfX4o`00013ooo]Z00?o]?l0oookJ_oonfX0:ooonfX00ol01ooooo]ZoookJP0^
oookJP03oonW0?l0ol;ooo]Z00Sooo]Z00?o?`3ooookJ_oonfX0DOoonfX00ooo803ooo]ZoookJP0V
oookJP00??oonfX2o`3o00Sooo]Z0_oo01P8oookJP03onGo0?ooW`3ooo]Z00gooo]Z00?o02Gooook
J_oonfX01ooonfX00ooo053ooo]ZoookJP03oookJP03ool0_?oonf[ooo]Z00;ooo]Z00Go@`3oo`1H
oooonf[o0?l4ooo^0002oookJP0<o`3o^Oooo`3oU?l0oiCo0?l0oo;oU?l0o`2Jool0oe3o083ooiCo
0?oo00cooo]Z0ooUo`02oookJP04o`0Ioooonf[ooo]Zoico00Gooo]Z00?oo`12oookJ_oonfX00_oo
nfX01Ol0Y?oooo]ZoookJ_oonf[oWOl000Cooo]Z00?oo`2CoookJ_l0]?l00ooonfX00ol04?oooo]Z
oookJP07oookJP03oe_o0?oonf[ooo]Z013ooo]Z00?o01cooookJ_oonfX09_oonfX3o`00O`Sooo]Z
1?l0000?oookJP03okCo0?oonf[ooo]Z02cooo]Z00?o00OooookJ_oonfX0;_oonfX00oooY`3o0?o2
oookJP07oookJP03ocl0oooonf[ooo]Z04oooo]Z0oooN@1QoookJP;o0?l02OoonfX00ooo01Sooo]Z
oookJP07oookJP;ooil03OoonfX00ol09Ooooo]ZoookJP07oookJP03ool0D?oonf[ooo]Z00Cooo]Z
00?oo`2loookJ_oonfX00_oonfX01?l0F?oooo]Zo`3o1?ookP02oookJP09o`3o^Oooo`3o0?l1oook
J_l0oo;ob?l0o`2Jool0oe3o083o00;ooo]Z00?oo`0<oookJ_m^o`000ooonfX01OooY03o01Wooook
J_oonf[oW?l000Cooo]Z00?oo`12oookJ_oonfX00ooonfX01?l0Y?oooo]ZoookJ_nMo`04oookJP04
ool0Tooonf[ooo]Zo`2do`?ooo]Z00?o013ooookJ_oonfX01_oonfX00omKo`3ooo]ZoookJP0@oook
JP03o`0Loooonf[ooo]Z02Kooo]Z0ol007l8oookJPCo00003ooonfX00ondo`3ooo]ZoookJP0/oook
JP03o`07oooonf[ooo]Z02kooo]Z00?oojL0o`3o`_oonfX02?oonfX00olo0?oooo]ZoookJP1Aoook
JP03oolP0?oonf[ooo]Z02Kooo]Z000noookJP?o0?l01ooonfX2ool060Sooo]Z00?ooil0oookJ_oo
nfX03?oonfX00ol09Ooooo]ZoookJP07oookJP03ool0D?oonf[ooo]Z00?ooo]Z00?oo`2loookJ_oo
nfX00_oonfX01?m30?oo05Soo`3o1?ookP02oookJP09o`3o^Ooonf[oool0oiCo0?l0oo;ob?l0o`2J
oonDo`3o0?m@00;oU?l000?oo`0<oookJ_oUo`000_oUo`02oookJP04o`0Ioooonf[ooo]Zoico00Co
oo]Z00?oo`12oookJ_oonfX00ooonfX01?l0Y?oooo]ZoookJ_nMo`04oookJP04ool0Tooonf[ooo]Z
o`2do`;ooo]Z00?o013oomWo0?oonfX01ooonfX00omKo`3ooo]ZoookJP0@oookJP03o`0Loooonf[o
oo]Z037ooo]Z1?l0000?oookJP03okCo0?oonf[ooo]Z02_ooo]Z00?o00OooookJ_oonfX0;_oonfX0
0oooY`3o0?o2oookJP08oookJP03ocl0oooonf[ooo]Z04oooo]Z0_ooN@1ToookJP?o0?l01ooonfX2
ool060Wooo]Z00?ooil0oookJ_oonfX02ooonfX00ol09Ooooo]ZoookJP07oookJP03ool0D?oonf[o
oo]Z00Cooo]Z00?oo`2loookJ_oonfX00_oonfX00ol0F?oo0?l4ooo^0003oookJP0;o`3o^Oooo`3o
0?l1o`3ol_oo05Oo09[ooookJ_l0oe3o0?n^oookJ_oo00`00_oonfX01Om^o`3ooo]ZoookJ_oonf[o
01Wo00?ooo]Z00GoW?l0oookJ_oonf[ooo]Zool0@P05oookJP05o`2Toooonf[ooo]ZoookJ_nMo`00
0ooonfX01?oo09?ooo]ZoookJ_l0]?l3oookJP03o`0@oooonf[ooo]Z00Kooo]Z00?oFol0oookJ_oo
nfX04?oonfX00ol07?oooo]ZoookJP0aoookJPCo00003ooonfX00ondo`3ooo]ZoookJP0[oookJP03
o`07oooonf[ooo]Z02kooo]Z00?oojL0o`3o`_oonfX02?oonfX00olo0?oooo]ZoookJP1AoookJP03
oolP0?oonf[ooo]Z02Oooo]Z0011oookJP;o0?l01ooonfX2ool060Oooo]Z0_ooW`0=oookJP;o02Go
2?oonfX00ooo053ooo]ZoookJP03oookJP03ool0_?oonf[ooo]Z00;ooo]Z00Co@`3oo`1Hool0o`Co
onh00_oonfX02Ol0okWooo]Zo`3o0Ooonf[o0?obolSo0?l0V_oo0?m@o`20o`02oiCo00;oA?l00_oU
o`02oookJP04o`0Ioooonf[ooo]Zoico00Gooo]Z00?oo`12oookJ_oonfX00_oonfX01Ol0Y?oooo]Z
oookJ_oonf[oWOl000Cooo]Z00?oo`2CoookJ_l0]?l00_oonfX00ol04?oofOl0oookJP07oookJP03
oe_o0?oonf[ooo]Z013ooo]Z00?o01cooookJ_oonfX0<OoonfX5o`0000gooo]Z00?o]?l0oookJ_oo
nfX0;?oonfX00ol01ooooo]ZoookJP0^oookJP03oonW0?l0ol;ooo]Z00Oooo]Z00?o?`3ooookJ_oo
nfX0D?oonfX00oooN@3ooo]ZoookJP1VoookJP;o0?l01ooonfX2ool060Sooo]Z00?ooil0oookJ_oo
nfX02ooonfX2o`0Uo`Sooo]Z00?oo`1@oookJ_oonfX01?oonfX00ooo0;cooo]ZoookJP02oookJP03
o`1Hool0o`Coonh000;ooo]Z00Wo0?nioookJ_l0o`7ooo]Zo`3ol_o8o`3o09[oo`3oD?l0P?l00_oo
nfX00ooo00cooo]Zofko0003oookJP05oonT0?l06Ooooo]ZoookJ_nLo`001?oonfX00ooo04;ooo]Z
oookJP03oookJP04o`2Toooonf[ooo]Zoigo00Cooo]Z00?oo`2CoookJ_l0]?l00ooonfX00ol04?oo
oo]ZoookJP06oookJP03oe_o0?oonf[ooo]Z013ooo]Z00?o01cooookJ_oonfX0<OoonfX5o`0000ko
oo]Z00?o]?l0oookJ_oonfX0:ooonfX00ol01ooooo]ZoookJP0^oookJP03oonW0?l0ol;ooo]Z00Oo
oo]Z00?o?`3ooookJ_oonfX0DOoonfX00ooo803ooo]ZoookJP0XoookJP009OoonfX4ool0[1[ooo]Z
0_l0o`07oookJP;oo`0H1ooonfX00oooW`3ooo]ZoookJP0<oookJP03o`0Uoooonf[ooo]Z00Kooo]Z
00?oo`1@oookJ_oonfX00ooonfX00ooo0;cooo]ZoookJP02oookJP0>od<0ool0F?oo0?l4ooo^0?oo
nf[o0?nioookJ_ooo`3o0?l1oookJ_l0oo;ob?l0o`2Jool0oe04odCo0003oookJ_oUo`3ooo]Z00;o
oo]Z00Co01WooookJ_oonf[oW?l01?oonfX00ooo04;ooo]ZoookJP02oookJP05o`2Toooonf[ooo]Z
oookJ_nMo`001?oonfX00ooo09?ooo]Zo`2do`03oookJP03o`0@oooonf[ooo]Z00Oooo]Z00?oFol0
oookJ_oonfX03ooonfX00ol07?oooo]ZoookJP0aoookJPCo00003_oonfX00ondo`3ooo]ZoookJP0[
oookJP03o`07oooonf[ooo]Z02kooo]Z00?oojL0o`3o`_oonfX01ooonfX00olo0?oooo]ZoookJP1@
oookJP03oomi0?oonf[ooo]Z04_ooo]Z1?oo0:`JoookJP;o0?l01ooonfX2ool060Oooo]Z0_ooW`0=
oookJP03o`0Uoooonf[ooo]Z00Kooo]Z00?oo`1@oookJ_oonfX01?oonfX02?oo0;cooo]ZoookJ_oo
nf[o@`3oo`1Hool0o`Coonh00_oonfX02ol0okWoool0o`3o0Ooonf[o0?obolSo0?l0V_oo0?m@o`20
oooonf[oo`0<00;ooo]Z00GoK_l0oookJ_oonf[ooo]Zo`0Io`02oookJP03oico0?oonf[ooo]Z00;o
oo]Z00?oo`12oookJ_oonfX00ooonfX01?l0Y?oooo]ZoookJ_nMo`04oookJP04ool0Tooonf[ooo]Z
o`2do`;ooo]Z00?o013ooookJ_oonfX01ooonfX00omKo`3ooo]ZoookJP0?oookJP03o`0Loooonf[o
oo]Z037ooo]Z1?l0000>oookJP03okCo0?oonf[ooo]Z02_ooo]Z00?o00OooookJ_oonfX0;_oonfX0
0oooY`3o0?o2oookJP08oookJP03ocl0oooonf[ooo]Z053ooo]Z00?oob00oookJ_oonfX0:OoonfX0
02Gooo]Z1?l0l_l3ool0[1Wooo]Z0_l0o`07oookJP;oo`0H1_oonfX2oonO00gooo]Z00?o02Gooook
J_oonfX01_oonfX00ooo053ooo]ZoookJP02oookJP03ool0_?oonf[ooo]Z00?ooo]Z00?o05Sooook
J_l0o`@00_oonfX01ol0okWooo]Zoooo0?l0o`7o0?obool0Eol0V_l01Om4o`000ooonf[oK_l0oook
JP02oookJP04o`0Ioooonf[ooo]Zoico00Cooo]Z00?oo`12oookJ_oonfX00ooonfX01?l0Y?oooo]Z
oookJ_nMo`04oookJP03ool0Tooonf[o0;Co00?ooo]Z00?o013ooookJ_oonfX01ooonfX00omKo`3o
oo]ZoookJP0?oookJP03o`0Loooonf[ooo]Z037ooo]Z1?l0000>oookJP03okCo0?oonf[ooo]Z02_o
oo]Z00?o00OooookJ_oonfX0;OoonfX00oooY`3ooo]Zo`3o`P08oookJP03ocl0oooonf[ooo]Z053o
oo]Z00?oob00oookJ_oonfX0BooonfX4o`3bo`?oo`2/6OoonfX2o`3o00Oooo]Z0_oo01P7oookJP03
oonO0?oonf[ooo]Z00_ooo]Z00?o02GooookJ_oonfX01_oonfX00ooo053ooo]ZoookJP03oookJP03
ool0_?oonf[ooo]Z00;ooo]Z00Co05SooookJ_l0o`Coonh00_oonfX02?l0okWoool0o`3o0Ol0oo;o
o`1Go`2Joonko`3o0?m@0_oonfX00ooo00cooo]Zofko0003oookJP05o`0Ioooonf[ooo]ZoookJ_nL
o`000ooonfX00ooo04;ooo]ZoookJP03oookJP05o`2Toooonf[ooo]ZoookJ_nMo`000ooonfX01?oo
09?ooo]ZoookJ_l0]?l2oookJP03o`0@oooonf[ooo]Z00Oooo]Z00?oFol0oookJ_oonfX03ooonfX0
0ol07?oooo]ZoookJP0aoookJPCo00003_oonfX00ondo`3ooo]ZoookJP0[oookJP03o`07oooonf[o
oo]Z02gooo]Z00?oojL0oookJ_l0ol802?oonfX00olo0?oooo]ZoookJP1AoookJP03oolP0?oonf[o
oo]Z02Wooo]Z000YoookJPCo0?;o0_oo0:`HoookJP;o0?l01ooonfX00ooo01Sooo]ZoookJP05oook
JP03oonO0?oonf[ooo]Z00_ooo]Z00?o02GooookJ_oonfX01_oonfX00ooo053ooo]ZoookJP02oook
JP03ool0_?oonf[ooo]Z00;ooo]Z00Co@`3oo`1Hool0o`Coonh00_nDo`001?l0okWooo]Zo`3o0Ooo
nfX8odCo0006oookJ_m^o`3ooo]ZoookJ_l06Ooooj@00_oonfX00onLo`3ooo]ZoookJP02oookJP03
ool0@_oonf[ooo]Z00;ooo]Z00Go0:CooookJ_oonf[ooo]Zoigo0003oookJP04ool0Tooonf[o0;Co
oookJP;oiOl000?o013oomWo0?oonfX01ooonfX00omKo`3ooo]ZoookJP0?oookJP03o`0Loooonf[o
oo]Z037ooo]Z1?l0000=oookJP03okCo0?oonf[ooo]Z02_ooo]Z00?o00OooookJ_oonfX0;_oonfX0
0oooY`3o0?o2oookJP07oookJP03ocl0oooonf[ooo]Z053ooo]Z00?oob00oookJ_oonfX0D?oonfX5
o`3bo`03ool0[?oonf[ooo]Z01Kooo]Z0_l0o`07oookJP03ool06?oonf[ooo]Z00Gooo]Z0_ooW`0<
oookJP03o`0Uoooonf[ooo]Z00Kooo]Z00?oo`1@oookJ_oonfX00ooonfX00ooo0;cooo]ZoookJP02
oookJP03o`1Hool0o`Coonh000?ooo]Z00[o0?nio`3o0Ooonf[o0?obolSo0?l0V_oo0?m@o`20oooo
nf[oo`0<0_oonfX01Om^o`3ooo]ZoookJ_oonf[o01Wo00;ooo]Z00?oW?l0oookJ_oonfX00_oonfX0
0ooo04;ooo]ZoookJP03oookJP04o`2Toooonf[ooo]Zoigo00?ooo]Z00Coo`2CoookJ_oonf[o0;Co
0ooonfX00ol04?oooo]ZoookJP06oookJP03oe_o0?oonf[ooo]Z00oooo]Z00?o01cooookJ_oonfX0
<OoonfX4o`0000kooo]Z00?o]?l0oookJ_oonfX0:_oonfX00ol01ooooo]ZoookJP0^oookJP03oonW
0?l0ol;ooo]Z00Sooo]Z00?o?`3ooookJ_oonfX0D?oonfX00ooo803ooo]ZoookJP0ZoookJP00;Ooo
nfX3o`3bo`;oo`2/5ooonfX2o`3o00Kooo]Z0_oo01P6oookJP;ooil03?oonfX2o`0Uo`Oooo]Z00?o
o`1@oookJ_oonfX00_oonfX00ooo0;cooo]ZoookJP02oookJP08od<0ool0F?oo0?l4ooo^0?nDo`3o
0?nioookJ_ooo`0:odCo0005ofko0?oonf[ooo]ZoookJ_l06Ol00_oonfX00onLo`3ooo]ZoookJP02
oookJP03ool0@_oonf[ooo]Z00?ooo]Z00Co0:CooookJ_oonf[oWOl01?oonfX5onGo0003o`0@oooI
o`3ooo]Z00Oooo]Z00?oFol0oookJ_oonfX03ooonfX00ol07?oooo]ZoookJP0aoookJPCo00003Ooo
nfX00ondo`3ooo]ZoookJP0[oookJP03o`07oooonf[ooo]Z02gooo]Z00?oojL0oookJ_l0ol802?oo
nfX00olo0?oooo]ZoookJP1?oookJP03oolP0?oonf[ooo]Z05Kooo]Z0ol0l_l00ooo0:cooo]Zoook
JP0EoookJP;o0?l01_oonfX2ool060Oooo]Z00?ooil0oookJ_oonfX02_oonfX2o`0Uo`Oooo]Z00?o
o`1@oookJ_oonfX00ooonfX02?oo0;cooo]ZoookJ_oonf[o@`3oo`1Hool0o`Coonh00_oonfX02ol0
okWoool0o`3o0Ol0oo;oo`1GolSo0?l0V_oo0?m@o`3o[_oonf[oo`0<00;ooo]Z00CoK_l0oookJ_oo
nf[o01Wo0ooonfX01OnLo`3ooo]ZoookJ_oonf[oo`1200Gooo]Z00Co0:CooookJ_oonf[oWOl01?oo
nfX00ooo09?ooo]Zo`2do`03oookJP03o`0@oooonf[ooo]Z00Kooo]Z00?oFol0oookJ_oonfX03ooo
nfX00ol07?oooo]ZoookJP0aoookJPCo00003OoonfX00ondo`3ooo]ZoookJP0[oookJP03o`07oooo
nf[ooo]Z02gooo]Z00?oojL0oookJ_l0ol802?oonfX00olo0?oooo]ZoookJP1@oookJP03oolP0?oo
nf[ooo]Z02_ooo]Z000`oookJP?o0?;o0_oo0:`FoookJP03o`3o0?oonf[ooo]Z00Gooo]Z0_oo01P6
oookJP03oonO0?oonf[ooo]Z00_ooo]Z00?o02GooookJ_oonfX01OoonfX00ooo053ooo]ZoookJP02
oookJP08ool0_?oonf[ooo]ZoookJ_nDo`3o05SooiCo0?l0o`@2oiCo0003o`3o^Ooonf[oool000[o
A?l000OoK_l0oookJ_oonf[o01WooonT0?oonf[oW?l000Gooo]Z00?oo`12oookJ_oonfX00_oonfX0
1?l0Y?oooo]ZoookJ_nMo`02oookJPOoiOl000?o013oomWo0?oonfX01ooonfX00omKo`3ooo]Zoook
JP0?oookJP03o`0Loooonf[ooo]Z037ooo]Z1?l0000=oookJP03okCo0?oonf[ooo]Z02[ooo]Z00?o
00OooookJ_oonfX0;_oonfX00oooY`3o0?o2oookJP07oookJP03ocl0oooonf[ooo]Z04oooo]Z00?o
ob00oookJ_oonfX0F_oonfX3o`3bo`03ool0[?oonf[ooo]Z01Cooo]Z00?o0?l0oookJ_oonfX01Ooo
nfX2ool060Kooo]Z00?ooil0oookJ_oonfX02ooonfX00ol09Ooooo]ZoookJP05oookJP03ool0D?oo
nf[ooo]Z00?ooo]Z00Soo`2loookJ_oonf[ooo]Zo`1Hoooonf[o0?l4ooo^00;ooo]Z00So0?nioooo
0?l0o`7o0?obool0Eol0V_oo0?m@o`20o`;ooo]Z00?oo`0<oookJ_m^o`000ooonfX01?l06Ooooo]Z
oookJ_nLo`04oookJP03ool0@_oonf[ooo]Z00;ooo]Z00Go0:CooookJ_oonf[ooo]Zoigo0003oook
JP04ool0Tooonf[ooo]Zo`2do`;ooo]Z00?o013ooookJ_oonfX01_oonfX00omKo`3ooo]ZoookJP0?
oookJP03o`0Loooonf[ooo]Z037ooo]Z1?l0000=oookJP03okCo0?oonf[ooo]Z02[ooo]Z00?o00Oo
oookJ_oonfX0;_oonfX00oooY`3o0?o2oookJP08oookJP03ocl0oooonf[ooo]Z04oooo]Z00?oob00
oookJ_oonfX0;?oonfX003?ooo]Z0ol0l_l2ool0[1Cooo]Z0_l0o`07oookJP03ool06?oonf[ooo]Z
00Cooo]Z0_ooW`0<oookJP03o`0Uoooonf[ooo]Z00Gooo]Z00?oo`1@oookJ_oonfX00_oonfX00ooo
0;cooo]ZoiCo0002oiCo0008o`1HoonDo`3o0?l4oiCo0?oonf[o0?nioookJ_l0o`47odCo0003ool0
3?m4o`3oK_l000;ooo]Z00Go01WooonT0?oonf[ooo]Zoico0004oookJP03ool0@_oonf[ooo]Z00;o
oo]Z00Co0:CooookJ_oonf[oWOl00_oonfX7onGo0003o`0@oooIo`3ooo]Z00Oooo]Z00?oFol0oook
J_oonfX03ooonfX00ol07?oooo]ZoookJP0aoookJPCo00003?oonfX00ondo`3ooo]ZoookJP0[oook
JP03o`07oooonf[ooo]Z02gooo]Z00?oojL0o`3o`_oonfX01ooonfX00olo0?oooo]ZoookJP1@oook
JP03oolP0?oonf[ooo]Z05gooo]Z0ol0l_l00ooo0:cooo]ZoookJP0BoookJP;o0?l01ooonfX00ooo
01Sooo]ZoookJP04oookJP;ooil03?oonfX00ol09Ooooo]ZoookJP05oookJP03ool0D?oonf[ooo]Z
00?ooo]Z00Ooo`2loookJ_oonf[ooo]Zo`1Hoooonf[o0?l400?ooo]Z00[o0?nio`3o0Ooonf[o0?ob
olSo0?l0V_oo0?m@o`20oooonf[oo`0<0_oonfX01?m^o`3ooo]ZoookJ_l06Ol2oookJP03oico0?oo
nf[ooo]Z00;ooo]Z00?oo`12oookJ_oonfX00ooonfX01?l0Y?oooo]ZoookJ_nMo`03oookJP04ool0
Tooonf[ooo]Zo`2do`;ooo]Z00?o013ooookJ_oonfX01_oonfX00omKo`3ooo]ZoookJP0?oookJP03
o`0Loooonf[ooo]Z037ooo]Z1?l0000=oookJP03okCo0?oonf[ooo]Z02[ooo]Z00?o00OooookJ_oo
nfX0;OoonfX00oooY`3o0?o2oookJP08oookJP03ocl0oooonf[ooo]Z053ooo]Z00?oob00oookJ_oo
nfX0;?oonfX003Kooo]Z0ol0l_l2ool0[0[ooo]Z0_oob@07oookJP;o0?l01_oonfX2ool060Kooo]Z
00?ooil0oookJ_oonfX02_oonfX00ol09Ooooo]ZoookJP05oookJP03ool0D?oonf[ooo]Z00;ooo]Z
00?oo`2loiCo0?nDo`000_nDo`002?l0F?ooonh0o`3o1?nDo`3ooo]Zo`3o^Oooo`3o0?l12Om4o`00
1om^o`3ooo]ZoookJ_l06Ooooj@0oookJ_nLo`001?oonfX00ooo04;ooo]ZoookJP03oookJP04o`2T
oooonf[ooo]Zoigo00;ooo]Z1ooUo`000ol04?oooo]ZoookJP06oookJP03oe_o0?oonf[ooo]Z00oo
oo]Z00?o01cooookJ_oonfX0<OoonfX4o`0000cooo]Z00?o]?l0oookJ_oonfX0:ooonfX00ol01ooo
oo]ZoookJP0/oookJP03oonW0?oonf[o0?o200Sooo]Z00?o?`3ooookJ_oonfX0CooonfX00ooo803o
oo]ZoookJP1QoookJP?o0?;o00?oo`2/oookJ_oonfX04OoonfX2o`3o00Kooo]Z0_oo01P6oookJP03
oonO0?oonf[ooo]Z00[ooo]Z00?o02GooookJ_oonfX01OoonfX00ooo053ooo]ZoookJP02oookJP03
ool0_?oonf[ooo]Z00;ooo]Z00?o05SooookJ_l0o`@00_oonfX02?l0okWoool0o`3o0Ol0oo;oo`1G
olSo0?l0V_oo0?m@0_oonfX01?oo00cooo]ZoookJ_m^o`02oookJP04o`0Ioooonf[ooo]Zoico00?o
oo]Z00?oo`12oookJ_oonfX00ooonfX01?l0Y?oooo]ZoookJ_nMo`04oookJP03ool0Tooonf[o0;Co
00;ooo]Z00?ofOl0o`0@oooonfX01_oonfX00omKo`3ooo]ZoookJP0?oookJP03o`0Loooonf[ooo]Z
037ooo]Z1?l0000<oookJP03okCo0?oonf[ooo]Z02_ooo]Z00?o00OooookJ_oonfX0;?oonfX00ooo
Y`3ooo]Zo`3o`P08oookJP03ocl0oooonf[ooo]Z053ooo]Z00?oob00oookJ_oonfX0;OoonfX003Wo
oo]Z0_l0l_l3ool0[0Oooo]Z0ooob@08oookJP;o0?l01_oonfX2ool060Gooo]Z00?ooil0oookJ_oo
nfX02_oonfX00ol09Ooooo]ZoookJP05oookJP03ool0D?oonf[ooo]Z00;ooo]Z00?oo`2loiCo0?nD
o`000_nDo`001Ol0F?oo0?l4oiCo0?oonf[o0?ni00;oiOl01om4o`001ooo00coA?l0oookJ_m^o`3o
oo]Zo`0IooooY0000_oonfX00onLo`3ooo]ZoookJP02oookJP03ool0@_oonf[ooo]Z00;ooo]Z00Co
0:CooookJ_oonf[oWOl00_oonfX7onGo0003o`0@oooIo`3ooo]Z00Oooo]Z00?oFol0oookJ_oonfX0
3_oonfX00ol07?oooo]ZoookJP0aoookJPCo00003?oonfX00ondo`3ooo]ZoookJP0ZoookJP03o`07
oooonf[ooo]Z02gooo]Z00?oojL0o`3o`_oonfX01ooonfX00olo0?oooo]ZoookJP1?oookJP03oolP
0?oonf[ooo]Z06Gooo]Z0_l0l_l2ool0[1;ooo]Z0_l0o`06oookJP;oo`0H1OoonfX00oooW`3ooo]Z
oookJP0:oookJP03o`0Uoooonf[ooo]Z00Gooo]Z00?oo`1@oookJ_oonfX00_oonfX02?oo0;cooo]Z
oookJ_oonf[o@`3oo`1Hool0o`Coonh00_oonfX02?l0okWo0?l1oookJ_l0oo;oo`1Go`2Jool0oe3o
083o0_oonfX00ooo00cooo]Zofko0002oookJP04o`0Ioooonf[ooo]Zoico00Cooo]Z00?oo`12oook
J_oonfX00_oonfX01Ol0Y?oooo]ZoookJ_oonf[oWOl000?ooo]Z00?oo`2CoookJ_l0]?l00ooonfX0
0ol04?oooo]ZoookJP06oookJP03oe_o0?oonf[ooo]Z00kooo]Z00?o01cooookJ_oonfX0<OoonfX4
o`0000cooo]Z00?o]?l0oookJ_oonfX0:_oonfX00ol01ooooo]ZoookJP0]oookJP03oonW0?l0ol;o
oo]Z00Sooo]Z00?o?`3ooookJ_oonfX0CooonfX00ooo803ooo]ZoookJP0^oookJP00>ooonfX3o`3b
o`?oo`2/0ooonfX5ooo900Wooo]Z0_l0o`06oookJP03ool06?oonf[ooo]Z00?ooo]Z0_ooW`0;oook
JP03o`0Uoooonf[ooo]Z00Gooo]Z00?oo`1@oookJ_oonfX00_oonfX02?oo0;coU?l0oiCo0?nDo`3o
05SooiCo0?l0o`Cooo]Z0ooUo`000ol0o`7oA?l0odCo0005odCo0003ool03?oonf[oK_l000;ooo]Z
00Co01WooonT0?oonf[oW?l01?oonfX00ooo04;ooo]ZoookJP02oookJP04o`2Toooonf[ooo]Zoigo
00?ooo]Z1_oUo`000ol04?oofOl0oookJP07oookJP03oe_o0?oonf[ooo]Z00kooo]Z00?o01cooook
J_oonfX0<OoonfX4o`0000_ooo]Z00?o]?l0oookJ_oonfX0:ooonfX00ol01ooooo]ZoookJP0/oook
JP03oonW0?oonf[o0?o200Oooo]Z00?o?`3ooookJ_oonfX0D?oonfX00ooo803ooo]ZoookJP1Woook
JP?o0?;o0_oo0:`AoookJP;o0?l01_oonfX00ooo01Sooo]ZoookJP03oookJP;ooil02ooonfX00ol0
9Ooooo]ZoookJP05oookJP03ool0D?oonf[ooo]Z00;ooo]Z00Soo`2loookJ_oonf[ooo]Zo`1Hoooo
nf[o0?l4ooo^00;ooo]Z00Ooool0o`3o0Ooonf[o0?obolSo0?l0V_oo0?m@00;ooo]Z00Coo`0<oook
J_oonf[oK_l00_oonfX00ol06Ooooo]Zoico0004oookJP03ool0@_oonf[ooo]Z00?ooo]Z00Co0:Co
oookJ_oonf[oWOl00ooonfX01?oo09?ooo]ZoookJ_l0]?l2oookJP03o`0@oooonf[ooo]Z00Kooo]Z
00?oFol0oookJ_oonfX03_oonfX00ol07?oooo]ZoookJP0aoookJPCo00003?oonfX00ondo`3ooo]Z
oookJP0ZoookJP03o`07oooonf[ooo]Z02cooo]Z00?oojL0oookJ_l0ol802?oonfX00olo0?oooo]Z
oookJP1@oookJP03oolP0?oonf[ooo]Z02kooo]Z000noookJP?o0?;o0ooo0:`6ooo900[ooo]Z00?o
0?l0oookJ_oonfX01?oonfX00ooo01Sooo]ZoookJP04oookJP03oonO0?oonf[ooo]Z00Wooo]Z00?o
02GooookJ_oonfX01?oonfX00ooo053ooo]ZoookJP03oookJP05ool0_?nDo`3oU?l0oiCo0?l0F?l0
1_oUo`000ol0o`7o0?obodCo0004odCo0007ool03?oonf[ooo]Zofko0?oonf[o01WooonT0002oook
JP05oico0?oonf[ooo]ZoookJ_oo04801OoonfX01?l0Y?oooo]ZoookJ_nMo`03oookJPGoiOl000?o
oo]Zo`0@oooonfX01ooonfX00omKo`3ooo]ZoookJP0>oookJP03o`0Loooonf[ooo]Z037ooo]Z1?l0
000;oookJP03okCo0?oonf[ooo]Z02[ooo]Z00?o00OooookJ_oonfX0;OoonfX00oooY`3o0?o2oook
JP07oookJP03ocl0oooonf[ooo]Z04oooo]Z00?oob00oookJ_oonfX0JooonfX3o`3bo`;oo`2/4?oo
nfX00ol0o`3ooo]ZoookJP04oookJP03ool06?oonf[ooo]Z00Cooo]Z00?ooil0oookJ_oonfX02Ooo
nfX00ol09Ooooo]ZoookJP04oookJP03ool0D?oonf[ooo]Z00?ooo]Z00Ooo`2loookJ_oonf[ooo]Z
o`1Hoooonf[o0?l400;ooo]Z00So0?nioooo0?l0o`7o0?obool0Eol0V_oo^ol0o`3oD0;ooo]Z00?o
o`0<oookJ_m^o`000_oonfX01?l06Ooooj@0oookJ_nLo`03oookJP03ool0@_oonf[ooo]Z00?ooo]Z
00Co0:CooookJ_oonf[oWOl01?oonfX00ooo09?ooo]Zo`2do`02oookJP03o`0@oooonf[ooo]Z00Ko
oo]Z00?oFol0oookJ_oonfX03_oonfX00ol07?oooo]ZoookJP0aoookJPCo00003?oonfX00ondo`3o
oo]ZoookJP0YoookJP03o`07oooonf[ooo]Z02gooo]Z00?oojL0o`3o`_oonfX02?oonfX00olo0?oo
oo]ZoookJP1?oookJP03oolP0?oonf[ooo]Z02oooo]Z0011oookJP?o0?;o1ooob@0:oookJP;o0?l0
1OoonfX2ool060Gooo]Z00?oiOl0oonO0?oonfX02OoonfX00ol09Ooooo]ZoookJP04oookJP03ool0
D?oonf[ooo]Z00?ooo]Z00?oo`2loiCo0?nDo`001ooUo`000ol0o`7oA?l0o`3olP05odCo0003ool0
3?oonf[oK_l000;ooo]Z00Co01WooookJ_oonf[oW?l01?oonfX00ooo04;ooo]ZoookJP02oookJP04
o`2Toooonf[ooo]Zoigo00?ooo]Z1_oUo`000ol04?oooo]ZoookJP06oookJP03oe_o0?oonf[ooo]Z
00kooo]Z00?o01cooookJ_oonfX0<OoonfX5o`0000[ooo]Z00?o]?l0oookJ_oonfX0:_oonfX00ol0
1ooooo]ZoookJP0/oookJP03oonW0?oonf[o0?o200Oooo]Z00?o?`3ooookJ_oonfX0CooonfX00ooo
803ooo]ZoookJP1_oookJP?o0?;o00?oo`2/oookJ_oonfX03OoonfX2o`3o00Gooo]Z0_oo01P5oook
JP;ooil02_oonfX00ol09Ooooo]ZoookJP04oookJP03ool0D?oonf[ooo]Z00?ooo]Z00Ooo`2loook
J_oonf[ooo]Zo`1Hoooonf[o0?l400;ooo]Z00[o0?nio`3o0Ooonf[o0?obolSo0?l0V_oo0?m@o`20
oooonf[oo`0<0_oonfX01_m^o`3ooo]ZoookJ_l06Ooooo]Zoico00Cooo]Z00?oo`12oookJ_oonfX0
0_oonfX01Ol0Y?oooo]ZoookJ_oonf[oWOl000?ooo]Z00?oo`2CoookJ_l0]?l00_oonfX00ooIo`3o
013ooookJP06oookJP03oe_o0?oonf[ooo]Z00kooo]Z00?o01cooookJ_oonfX0<OoonfX5o`0000[o
oo]Z00?o]?l0oookJ_oonfX0:_oonfX00ol01ooooo]ZoookJP0/oookJP03oonW0?oonf[o0?o200So
oo]Z00?o?`3ooookJ_oonfX0CooonfX00ooo803ooo]ZoookJP0`oookJP00@ooonfX01?oob@3o0?;o
o`3bool0l_l6ooo900[ooo]Z0_l0o`05oookJP03ool06?oonf[ooo]Z00;ooo]Z00?oiOl0oookJ_oo
W`002_oonfX00ol09Ooooo]ZoookJP04oookJP03ool0D?oonf[ooo]Z00;ooo]Z00?oo`2loookJ_oU
o`002?oUo`02odCo0003o`3ol_m4o`3oA?l000;oA?l000Ooo`0<oookJ_oonf[oK_l0oookJ_l06Ooo
oj@000;ooo]Z00GoW?l0oookJ_oonf[ooo]Zool0@P04oookJP04o`2Toooonf[ooo]Zoigo00;ooo]Z
1ooUo`000ol04?oooo]ZoookJP06oookJP03oe_o0?oonf[ooo]Z00oooo]Z00?o01cooookJ_oonfX0
<?oonfX4o`0000[ooo]Z00?o]?l0oookJ_oonfX0:_oonfX00ol01ooooo]ZoookJP0]oookJP03oonW
0?l0ol;ooo]Z00Oooo]Z00?o?`3ooookJ_oonfX0C_oonfX00ooo803ooo]ZoookJP1coookJP?o0?;o
3ooonfX2o`3o00Gooo]Z00?oo`0HoookJ_oonfX01?oonfX00oooW`3ooo]ZoookJP08oookJP03o`0U
oooonf[ooo]Z00Cooo]Z00?oo`1@oookJ_oonfX00_oonfX00ooo0;cooo]ZoookJP02oookJP0<o`1H
oooonf[o0?l4oookJ_l0okWoool0o`3o0Ooonf[o0?obolSo0?l0V_oo0?m@0_oonfX02Ooo00cooo]Z
oookJ_m^o`3ooo]Zo`0IooooY03ooo]Zoico0003oookJP03ool0@_oonf[ooo]Z00?ooo]Z00Co0:Co
oookJ_oonf[oWOl00ooonfX00ooo09?ooo]Zo`2do`02oookJP03omWo0?l04?oooo]Z00Kooo]Z00?o
Fol0oookJ_oonfX03ooonfX00ol07?oooo]ZoookJP0`oookJPCo00002ooonfX00ondo`3ooo]Zoook
JP0YoookJP03o`07oooonf[ooo]Z02gooo]Z00?oojL0o`3o`_oonfX01ooonfX00olo0?oooo]Zoook
JP1?oookJP03oolP0?oonf[ooo]Z037ooo]Z0013oookJPCoolT00_l0l_l5ooo900_ooo]Z00?o0?l0
oookJ_oonfX00ooonfX2ool06006oookJ_oUo`3oiOl0onGo0?oonf[ooil02_oonfX00ol09Ooooo]Z
oookJP04oookJP03ool0D?oonf[ooo]Z00;ooo]Z00?oo`2loookJ_oonfX01ooUo`02odCo0003o`3o
l_m4o`3oA?l000?oA?l000?oo`0<oookJ_m^o`000_oonfX01?l06Ooooo]ZoookJ_nLo`04oookJP03
ool0@_oonf[ooo]Z00;ooo]Z00Co0:CooookJ_oonf[oWOl02?oUo`000ooonf[o013ooookJP06oook
JP03oe_o0?oonf[ooo]Z00oooo]Z00?o01cooookJ_oonfX0<?oonfX4o`0000[ooo]Z00?o]?l0oook
J_oonfX0:_oonfX00ol01ooooo]ZoookJP0/oookJP03oonW0?oonf[o0?o200Oooo]Z00?o?`3ooook
J_oonfX0CooonfX00ooo803ooo]ZoookJP1foookJP;o0?;o3ooonfX00ol0o`3ooo]ZoookJP03oook
JP;oo`0H1OoonfX00oooW`3ooo]ZoookJP08oookJP03o`0Uoooonf[ooo]Z00Cooo]Z00?oo`1@oook
J_oonfX00_oonfX01ooo0;cooo]ZoookJ_oonf[o@`3oo`1Hool0o`@00_oonfX02?l0okWoool0o`3o
0Ol0oo;oo`1Go`2Jool0oe3o083o0_oonfX00ooo00cooo]Zofko0002oookJP03o`0Ioooonf[oW?l0
00Cooo]Z00?oo`12oookJ_oonfX00_oonfX01Ol0Y?oooo]ZoookJ_oonf[oWOl000?ooo]Z00?oo`2C
oookJ_l0]?l00_oonfX00ol04?oooo]ZoookJP05oookJP03oe_o0?oonf[ooo]Z00oooo]Z00?o01co
oookJ_oonfX0<?oonfX4o`0000_ooo]Z00?o]?l0oookJ_oonfX0:OoonfX00ol01ooooo]ZoookJP0/
oookJP03oonW0?oonf[o0?o200Sooo]Z00?o?`3ooookJ_oonfX0CooonfX00ooo803ooo]ZoookJP0a
oookJP00@_oonfX7ooo900;o0?;o1?oob@0;oookJP;o0?l01OoonfX5onGo0003oookJ_ooW`3ooil0
00Wooo]Z00?o02GooookJ_oonfX01?oonfX00ooo053ooo]ZoookJP02oookJP03ool0_?oonf[ooo]Z
00KoiOl00om4o`000ol0oo;oA?l0odCo0002odCo0004ool03?oonf[ooo]Zofko00;ooo]Z00Go01Wo
oookJ_oonf[oW?l0onGo0002oookJP03ool0@_oonf[ooo]Z00;ooo]Z00Co0:CooookJ_oonf[oWOl0
2?oUo`000ooonf[o013ooookJP06oookJP03oe_o0?oonf[ooo]Z00oooo]Z00?o01cooookJ_oonfX0
<?oonfX4o`0000[ooo]Z00?o]?l0oookJ_oonfX0:OoonfX00ol01ooooo]ZoookJP0/oookJP03oonW
0?oonf[o0?o200Oooo]Z00?o?`3ooookJ_oonfX0CooonfX00ooo803ooo]ZoookJP1ioookJP;o0?;o
00?oo`2/oookJ_oonfX02ooonfX2o`3o00Gooo]Z00?oo`0HoookJ_oonfX00ooonfX2oonO00Wooo]Z
00?o02GooookJ_oonfX01?oonfX00ooo053ooo]ZoookJP02oookJP07ool0_?oonf[ooo]ZoookJ_l0
F?oooo]Zo`3o1002oookJP0:o`3o^Ol0o`7ooo]Zo`3ol_o8o`3o09[oo`3oD?l0ojkooo]Zool030;o
oo]Z00KoK_l0oookJ_l06Ooooj@0oookJ_nLo`03oookJP03ool0@_oonf[ooo]Z00;ooo]Z00Go0:Co
oookJ_oonf[ooo]Zoigo0003oookJP03ool0Tooonf[o0;Co00;ooo]Z00?o013ooookJ_oonfX01Ooo
nfX00omKo`3ooo]ZoookJP0?oookJP03o`0Loooonf[ooo]Z033ooo]Z1?l0000:oookJP03okCo0?oo
nf[ooo]Z02Wooo]Z00?o00OooookJ_oonfX0;?oonfX00oooY`3ooo]Zo`3o`P08oookJP03ocl0oooo
nf[ooo]Z04oooo]Z00?oob00oookJ_oonfX0<_oonfX004Kooo]Z1Ooob@02o`3bo`?oolT03?oonfX2
o`3o00?ooo]Z1_oUo`02oookJP03oonO0?oonf[ooo]Z00Oooo]Z00?o02GooookJ_oonfX00ooonfX0
0ooo053ooo]ZoookJP03oookJP03ool0_?oonf[ooo]Z00KoiOl02?m4o`000ooo00cooo]Zofko0002
oookJP?oiOl000GoW?l0onGo0?oonf[ooo]Zool0@P04oookJP04o`2Toooonf[ooo]Zoigo00SoiOl0
00?ooo]Zo`0@oooonfX01ooonfX00omKo`3ooo]ZoookJP0>oookJP03o`0Loooonf[ooo]Z033ooo]Z
1?l00009oookJP03okCo0?oonf[ooo]Z02[ooo]Z00?o00OooookJ_oonfX0;?oonfX00oooY`3o0?o2
oookJP07oookJP03ocl0oooonf[ooo]Z04kooo]Z00?oob00oookJ_oonfX0O?oonfX2o`3bo`03ool0
[?oonf[ooo]Z00_ooo]Z0_l0o`04oookJP03ool06?oonf[ooo]Z00Cooo]Z00?ooil0oookJ_oonfX0
1ooonfX00ol09Ooooo]ZoookJP04oookJP03ool0D?oonf[ooo]Z00;ooo]Z013oo`2loookJ_oonf[o
oo]Zo`1Hoooonf[o0?l4oookJ_l0okWoool0o`3o0Ol0oo;oo`1GolSo0?l0V_oo0?m@0_oonfX02?oo
00cooo]Zofko0?oonf[o01WooonT0?oonf[oW?l00ooonfX00ooo04;ooo]ZoookJP03oookJP04o`2T
oooonf[ooo]Zoigo00?ooo]Z00?oo`2CoookJ_l0]?l00_oonfX00ol04?oooo]ZoookJP06oookJP03
oe_o0?oonf[ooo]Z00kooo]Z00?o01cooookJ_oonfX0<?oonfX4o`0000[ooo]Z00?o]?l0oookJ_oo
nfX0:OoonfX00ol01ooooo]ZoookJP0/oookJP03oonW0?l0ol;ooo]Z00Sooo]Z00?o?`3ooookJ_oo
nfX0C_oonfX00ooo803ooo]ZoookJP0coookJP00BooonfX2ooo900?o0?;o00?oolT0oookJ_oonfX0
2ooonfX00ol0o`3ooo]ZonGo0007onGo00;ooo]Z00?ooil0oookJ_oonfX01ooonfX00ol09Ooooo]Z
oookJP03oookJP03ool0D?oonf[ooo]Z00?ooo]Z00?oo`2loookJ_oonfX01OoUo`05odCo0004o`3o
D?l0P?ooA?l0ool030;ooo]Z00?oK_l0onGo0?oUo`000ooUo`001OnLo`3ooo]ZoookJ_oonf[oo`12
00Cooo]Z00Co0:CooookJ_oonf[oWOl01ooUo`000ooonf[ofOl0o`0@o`07oookJP03oe_o0?oonf[o
oo]Z00kooo]Z00?o01cooookJ_oonfX0<?oonfX4o`0000Wooo]Z00?o]?l0oookJ_oonfX0:_oonfX0
0ol01ooooo]ZoookJP0[oookJP03oonW0?oonf[o0?o200Oooo]Z00?o?`3ooookJ_oonfX0C_oonfX0
0ooo803ooo]ZoookJP1ooookJP?o0?;o3OoonfX00ol0o`3ooo]ZoookJP02oookJP;oo`0H1OoonfX0
0oooW`3ooo]ZoookJP07oookJP03o`0Uoooonf[ooo]Z00Cooo]Z00?oo`1@oookJ_oonfX00_oonfX0
4_oo0;cooo]ZoookJ_oonf[o05Soo`3o1?ookP3ooo]Zo`3o^Oooo`3o0?l1o`3ol_o8o`3o09[oo`3o
D?l0P?oooo]Zool030;ooo]Z00KoK_l0oookJ_l06Ooooj@0oookJ_nLo`03oookJP03ool0@_oonf[o
oo]Z00;ooo]Z00Go0:CooookJ_oonf[ooo]Zoigo0002oookJP03ool0Tooonf[o0;Co00;ooo]Z00?o
fOl0o`0@oooonfX01_oonfX00omKo`3ooo]ZoookJP0>oookJP03o`0Loooonf[ooo]Z033ooo]Z1?l0
000:oookJP03okCo0?oonf[ooo]Z02Wooo]Z00?o00OooookJ_oonfX0:ooonfX00oooY`3ooo]Zo`3o
`P08oookJP03ocl0oooonf[ooo]Z04kooo]Z00?oob00oookJ_oonfX0=?oonfX0053ooo]Z0_l0l_l0
0ooo0:cooo]ZoookJP0:oookJP;o0?l02?oUo`02oookJP03oonO0?oonf[ooo]Z00Oooo]Z00?o02Go
oookJ_oonfX00ooonfX00ooo053ooo]ZoookJP02oookJP04ool0_?oonf[ooo]ZoiCo00GoiOl01Om4
o`001_l0oe3oA?l0oookJ_oo00coiOl0ofko00GoiOl000GoW?l0onGo0?oonf[ooo]Zool0@P04oook
JP04o`2Toooonf[ooo]Zoigo00OoiOl00_oonfX00ol04?oooo]ZoookJP05oookJP03oe_o0?oonf[o
oo]Z00kooo]Z00?o01cooookJ_oonfX0<?oonfX4o`0000Wooo]Z00?o]?l0oookJ_oonfX0:OoonfX0
0ol01ooooo]ZoookJP0/oookJP03oonW0?l0ol;ooo]Z00Oooo]Z00?o?`3ooookJ_oonfX0C_oonfX0
0ooo803ooo]ZoookJP22oookJP;o0?;o3?oonfX2o`3o00Cooo]Z00?oo`0HoookJ_oonfX00ooonfX0
0oooW`3ooo]ZoookJP07oookJP03o`0Uoooonf[ooo]Z00Cooo]Z00Goo`1@oookJ_oonf[ooo]Zool0
_004oookJP0;o`1Hool0o`Cooo]ZoookJ_l0okWoool0o`3o0Ol0oo;ob?l0o`2Jool0oe000_oonfX0
1_oo00cooo]Zofko0?oonf[o01WooonT00;ooo]Z00CoW?l0oookJ_oonf[oo`121OoonfX01?l0Y?oo
oo]ZoookJ_nMo`03oookJP03ool0Tol0]?oooo]Z00;ooo]Z00?o013ooookJ_oonfX01OoonfX00omK
o`3ooo]ZoookJP0>oookJP03o`0Loooonf[ooo]Z033ooo]Z1?l00009oookJP03okCo0?oonf[ooo]Z
02Wooo]Z00?o00OooookJ_oonfX0;?oonfX00oooY`3o0?o2oookJP08oookJP03ocl0oooonf[ooo]Z
04kooo]Z00?oob00oookJ_oonfX0=?oonfX005;ooo]Z0_l0l_l00ooo0:cooo]ZoookJP0:oookJP;o
0?l01_oUo`03oookJP03oonO0?oonf[ooo]Z00Oooo]Z00?o02GooookJ_oonfX00ooonfX00ooo053o
oo]ZoookJP02oookJP05ool0_?nDo`3oU?l0oiCo0?l0F?l00ooUo`06odCo0006o`3oD?m4o`3oo`0<
onGo0?nDo`3oK_l01?oUo`001OnLo`3oiOl0oookJ_oonf[oo`1200Cooo]Z00Go0:CooookJ_oonf[o
WOl0oookJP06onGo00;ooo]Z00?o013ooookJ_oonfX01OoonfX00omKo`3ooo]ZoookJP0>oookJP03
o`0Loooonf[ooo]Z033ooo]Z1?l00008oookJP03okCo0?oonf[ooo]Z02[ooo]Z00?o00OooookJ_oo
nfX0:ooonfX00oooY`3ooo]Zo`3o`P07oookJP03ocl0oooonf[ooo]Z04kooo]Z00?oob00oookJ_oo
nfX0QOoonfX2o`3bo`cooo]Z0_l0o`03oookJP;oo`0H1?oonfX2oonO00Sooo]Z00?o02GooookJ_oo
nfX01?oonfX01Ooo053ooo]ZoookJ_oonf[oo`2l00?ooo]Z00ko@`3oo`1Hool0o`Cooo]Zo`3o^Ooo
nf[o0?l1o`3ol_o8o`3o09[ook_o0?l0oe3ooo]Zool030;ooo]Z00KoK_l0oookJ_l06Ooooj@0oook
J_nLo`03oookJP03ool0@_oonf[ooo]Z00;ooo]Z00Co0:CooookJ_oonf[oWOl00ooonfX00ooo09?o
oo]Zo`2do`02oookJP03o`0@oooonf[ooo]Z00Gooo]Z00?oFol0oookJ_oonfX03_oonfX00ol07?oo
oo]ZoookJP0`oookJPCo00002OoonfX00ondo`3ooo]ZoookJP0YoookJP03o`07oooonf[ooo]Z02_o
oo]Z00?oojL0oookJ_l0ol802?oonfX00olo0?oooo]ZoookJP1>oookJP03oolP0?oonf[ooo]Z03Go
oo]Z001DoookJP;o0?;o00?oo`2/oookJ_oonfX02_oonfX00ol0o`3oiOl0onGo0004onGo00?ooo]Z
00?ooil0oookJ_oonfX01ooonfX00ol09Ooooo]ZoookJP03oookJP04ool0D?oonf[ooo]ZoookJPCo
U?l000?o05SooookJ_oUo`000_oUo`05odCo0003o`3oD?m4o`3oU?l000?oU?l000?oK_l0onGo0?oU
o`000_oUo`001OnLo`3ooo]ZoookJ_oonf[oo`1200Cooo]Z00Co0:CooookJ_oUo`3oWOl01_oUo`02
oookJP03o`0@oooonf[ooo]Z00Gooo]Z00?oFol0oookJ_oonfX03_oonfX00ol07?oooo]ZoookJP0`
oookJPCo00002?oonfX00ondo`3ooo]ZoookJP0YoookJP03o`07oooonf[ooo]Z02cooo]Z00?oojL0
o`3o`_oonfX01_oonfX00olo0?oooo]ZoookJP1>oookJP03oolP0?oonf[ooo]Z08Sooo]Z0_l0l_l<
oookJP03o`3o0?oonf[ooo]Z00;ooo]Z00?oo`0HoookJ_oonfX00ooonfX00oooW`3ooo]ZoookJP06
oookJP03o`0Uoooonf[ooo]Z00Cooo]Z00Goo`1@oookJ_oonf[ooo]Zool0_003oookJP0Co`1Hoooo
nf[o0?l4oookJ_l0okWoool0o`3o0Ol0oo;ob?l0o`2Jool0oe3o0?n^oookJ_oo00cooo]Zofko0?oo
nf[o01WooonT0002oookJP04oico0?oonf[ooo]Zool0@PCooo]Z00Go0:CooookJ_oonf[ooo]Zoigo
0002oookJP03ool0Tooonf[o0;Co00;ooo]Z00?o013ooookJ_oonfX01OoonfX00omKo`3ooo]Zoook
JP0>oookJP03o`0Loooonf[ooo]Z033ooo]Z1?l00009oookJP03okCo0?oonf[ooo]Z02Sooo]Z00?o
00OooookJ_oonfX0;?oonfX00oooY`3o0?o2oookJP07oookJP03ocl0oooonf[ooo]Z04kooo]Z00?o
ob00oookJ_oonfX0=_oonfX005Kooo]Z0_l0l_l00ooo0:cooo]ZoookJP09oookJP;o0?l01OoUo`03
oookJP03oonO0?oonf[ooo]Z00Oooo]Z00?o02GooookJ_oonfX00_oonfX00ooo053ooo]ZoookJP06
oiCo0005o`1Hoooonf[oiOl0onGo0?oonfX01Om4o`000ol0oe3oU?l0oiCo0002oiCo0003ofko0?oU
o`3oiOl000;oiOl000GoW?l0oookJ_oonf[ooo]Zool0@P03oookJPCoiOl000?oWOl0onGo0?oUo`00
0ooUo`001Ol0]?oooo]ZoookJ_oIo`3o013o00Kooo]Z00?oFol0oookJ_oonfX03_oonfX00ol07?oo
oo]ZoookJP0`oookJPCo00002?oonfX00ondo`3ooo]ZoookJP0YoookJP03o`07oooonf[ooo]Z02_o
oo]Z00?oojL0oookJ_l0ol801ooonfX00olo0?oooo]ZoookJP1>oookJP03oolP0?oonf[ooo]Z08[o
oo]Z0_l0l_l;oookJP;o0?l00ooonfX00ooo01Sooo]ZoookJP03oookJP03oonO0?oonf[ooo]Z00Ko
oo]Z00?o02GooookJ_oonfX00ooonfX00ooo053ooo]ZoookJP02oookJP06ool0_?oonf[ooo]Zoook
J_l0F?oo0?l40_oonfX01ol0okWoool0o`3o0Ol0oo;ob?l0o`2Jool0oe000_oonfX02?oo00coK_l0
oookJ_oonf[o01WooonT0?oonf[oW?l00ooonfX00ooo04;ooo]ZoookJP02oookJP04o`2Toooonf[o
oo]Zoigo00?ooo]Z00Koo`2Co`2doooonf[ooo]ZomWo0?l04?l6oookJP03oe_o0?oonf[ooo]Z00ko
oo]Z00?o01cooookJ_oonfX0<?oonfX4o`0000Wooo]Z00?o]?l0oookJ_oonfX0:?oonfX00ol01ooo
oo]ZoookJP0[oookJP03oonW0?oonf[o0?o200Sooo]Z00?o?`3ooookJ_oonfX0C_oonfX00ooo803o
oo]ZoookJP0foookJP00F?oonfX2o`3bo`03ool0[?oonf[ooo]Z00Wooo]Z00?o0?l0oookJ_oUo`00
0ooUo`03oookJP03oonO0?oonf[ooo]Z00Oooo]Z00?o02GooookJ_oonfX00_oonfX00ooo053oU?l0
oiCo0006oiCo0003o`1Hoooonf[oiOl000;ooo]Z0_m4o`02oiCo0003o`3oD?nDo`3oU?l000?oU?l0
00?oK_l0onGo0?oUo`000_oUo`001OnLo`3ooo]ZoookJ_oo04;ooo]Z00KoiOl000?oWOl0onGo0?oU
o`000ooUo`001Ol0]?oooo]ZoookJ_oonf[o013o00Kooo]Z00?oFol0oookJ_oonfX03_oonfX00ol0
7?oooo]ZoookJP0`oookJPCo00001ooonfX00ondo`3ooo]ZoookJP0YoookJP03o`07oooonf[ooo]Z
02_ooo]Z00?oojL0oookJ_l0ol801ooonfX00olo0?oooo]ZoookJP1>oookJP03oolP0?oonf[ooo]Z
01Oooo]Z00?oo`00oookJ_oonfX0LooonfX2o`3bo`_ooo]Z00Co0?l0oookJ_oonf[ooo]Z0_oo01P4
oookJP03oonO0?oonf[ooo]Z00Kooo]Z00?o02GooookJ_oonfX00ooonfX00ooo053ooo]ZoookJP02
oookJP06ool0_?oonf[ooo]ZoookJ_l0F?oo0?l40_oonfX03_l0okWo0?l1o`3ol_o8o`3o09[oo`3o
D?l0P?oooo]Zool03?oonf[oK_l0oookJ_l06Ooooj@00_oonfX01?nLo`3ooo]ZoookJ_oo0484oook
JP04o`2Toooonf[ooo]Zoigo00?ooo]Z00?oo`2Co`2doooonfX00_oonfX00ol04?oooo]ZoookJP04
oookJP03oe_o0?oonf[ooo]Z00kooo]Z00?o01cooookJ_oonfX0<?oonfX4o`0000Sooo]Z00?o]?l0
oookJ_oonfX0:?oonfX00ol01ooooo]ZoookJP0[oookJP03oonW0?oonf[o0?o200Sooo]Z00?o?`3o
oookJ_oonfX0C_oonfX00ooo803ooo]ZoookJP0goookJP00F_oonfX2o`3bo`03ool0[?oonf[ooo]Z
00Sooo]Z0_l0o`02oookJP;oiOl00ooonfX2oonO00Sooo]Z00?o02GooookJ_oonfX00_oonfX00ooo
053ooo]ZoiCo0006oiCo0005o`1Hoooonf[oiOl0oookJ_m4o`001?nDo`000ol0oe3oU?l0oiCo0002
oiCo0003ofko0?oUo`3oiOl000;oiOl000GoW?l0oookJ_oonf[ooo]Zool0@P07onGo0003oigo0?oo
nf[oiOl000?oiOl000Co0;CooookJ_oonf[o013o1ooonfX00omKo`3ooo]ZoookJP0=oookJP03o`0L
oooonf[ooo]Z033ooo]Z1Ol00006oookJP03okCo0?oonf[ooo]Z02Wooo]Z00?o00OooookJ_oonfX0
:ooonfX00oooY`3ooo]Zo`3o`P07oookJP03ocl0oooonf[ooo]Z04gooo]Z00?oob00oookJ_oonfX0
6?oonfX00ooo05?ooo]ZoookJP1eoookJP03o`3boooo0:cooo]Z00Wooo]Z0_l0o`03oookJP03ool0
6?oonf[ooo]Z00;ooo]Z0_ooW`07oookJP03o`0Uoooonf[ooo]Z00?ooo]Z00Goo`1@oookJ_oonf[o
oo]Zool0_004oookJP0>o`1Hool0o`Cooo]Zo`3o^Oooo`3o0?l1o`3ol_o8o`3o09[oo`3oD?l0ojko
oo]Zool03?m^o`02oookJP04o`0Ioooonf[ooo]Zoico00;ooo]Z00?oo`12oookJ_oonfX00_oonfX0
1Ol0Y?oooo]ZoookJ_oonf[oWOl000;ooo]Z00?oo`2CoookJ_l0]?l00_oonfX00ol04?oooo]Zoook
JP05oookJP03oe_o0?oonf[ooo]Z00gooo]Z00?o01cooookJ_oonfX0<?oonfX5o`0000Oooo]Z00?o
]?l0oookJ_oonfX0:?oonfX00ol01ooooo]ZoookJP0[oookJP03oonW0?oonf[o0?o200Sooo]Z00?o
?`3ooookJ_oonfX0COoonfX00ooo803ooo]ZoookJP0HoookJP03ool0Dooonf[ooo]Z01gooo]Z001L
oookJP;o0?;o00?oo`2/oookJ_oonfX02?oonfX01_l0o`3ooo]ZoookJ_oonf[oiOl0ool060?ooo]Z
00?ooil0oookJ_oonfX01_oonfX00ol09Ooooo]ZoookJP02oookJP03ool0D?oonf[oU?l000GoU?l0
00?o@`3oo`1Hool0o`@00_oonfX00ol0okWoU?l0oiCo0002oiCo0006o`3oD?nDo`3oU?l0oiCo0?oo
nf[oK_l01?oUo`001OnLo`3ooo]ZoookJ_oo04;ooo]Z00KoiOl000?oWOl0oookJ_oUo`000ooUo`00
1Ol0]?oooo]ZoookJ_l04?oooo]Z00?oiOl00ooonfX00omKo`3ooo]ZoookJP0=oookJP03o`0Loooo
nf[ooo]Z033ooo]Z1?l00007oookJP03okCo0?oonf[ooo]Z02Wooo]Z00?o00OooookJ_oonfX0:_oo
nfX00oooY`3ooo]Zo`3o`P07oookJP03ocl0oooonf[ooo]Z04gooo]Z00?oob00oookJ_oonfX06Ooo
nfX00ooo05?ooo]ZoookJP1foookJP;o0?;o00?oo`2/oookJ_oonfX02?oonfX01?l0o`3ooo]Zoook
J_oonfX2ool060Cooo]Z00?ooil0oookJ_oonfX01OoonfX00ol09Ooooo]ZoookJP03oookJP05ool0
D?oonf[ooo]ZoookJ_oo0;`00ooonfX04_m30?oo0?l4oookJ_oonf[o0?nioooo0?oo05Oo0?obo`2J
oonko`3o0?m@oookJ_oo00cooo]Zofko0?oonf[o01WooonT00;ooo]Z00CoW?l0oookJ_oonf[oo`12
1?oonfX01?l0Y?oooo]ZoookJ_nMo`03oookJP05ool0Tol0]?oooo]ZoookJ_l04?l01ooonfX00omK
o`3ooo]ZoookJP0=oookJP03o`0Loooonf[ooo]Z033ooo]Z1?l00008oookJP03okCo0?oonf[ooo]Z
02Sooo]Z00?o00OooookJ_oonfX0:_oonfX00oooY`3ooo]Zo`3o`P08oookJP03ocl0oooonf[ooo]Z
04gooo]Z00?oob00oookJ_oonfX06OoonfX00ooo05?ooo]ZoookJP0MoookJP00G_oonfX2o`3bo`03
ool0[?oonf[ooo]Z00Oooo]Z0_l0o`03oookJP04ool06?oob@3ooo]ZoookJP;ooil01ooonfX00ol0
9Ooooo]ZoookJP02oookJP03ool0D?oonf[oU?l000GoU?l000?o05SooookJ_l0o`@00_oonfX01Ol0
okWoU?l0oiCo0?nDo`3o0?m@00?oU?l000?ooo]Zofko0?oUo`000ooUo`001?nLo`3ooo]ZoookJ_oo
0482oookJPGoiOl000?oWOl0oookJ_oonfX00ooUo`001Ol0]?oooo]ZonGo0?oUo`3o013o00?oiOl0
0ooonfX00omKo`3ooo]ZoookJP0=oookJP03o`0Loooonf[ooo]Z033ooo]Z1?l00007oookJP03okCo
0?oonf[ooo]Z02Sooo]Z00?o00OooookJ_oonfX0:ooonfX00oooY`3o0?o2oookJP07oookJP03ocl0
oooonf[ooo]Z04gooo]Z00?oob00oookJ_oonfX06?oonfX00ooo05?ooo]ZoookJP1ioookJP;o0?;o
00?oo`2/oookJ_oonfX01ooonfX2o`3o00?ooo]Z00?oo`0HoookJ_oonfX00_oonfX00oooW`3ooo]Z
oookJP05oookJP03o`0Uoooonf[ooo]Z00?ooo]Z00Goo`1@oookJ_oonf[ooo]Zool0_003oookJP0>
o`1Hool0o`Cooo]ZoookJ_l0okWo0?l1ool0Eol0oo;o09[oo`3oD?l0ojkooo]Zool03?m^o`02oook
JP04o`0Ioooonf[ooo]Zoico00;ooo]Z00?oo`12oookJ_oonfX00_oonfX01?l0Y?oooo]ZoookJ_nM
o`03oookJP06ool0Tol0]?oooo]ZoookJ_oIo`3o013o1_oonfX00omKo`3ooo]ZoookJP0=oookJP03
o`0Loooonf[ooo]Z033ooo]Z1?l00008oookJP03okCo0?oonf[ooo]Z02Oooo]Z00?o00OooookJ_oo
nfX0:ooonfX00oooY`3ooo]Zo`3o`P08oookJP03ocl0oooonf[ooo]Z04gooo]Z00?oob00oookJ_oo
nfX06?oonfX00ooo05?ooo]ZoookJP0NoookJP00H?oonfX2o`3bo`03ool0[?oonf[ooo]Z00Oooo]Z
00Go0?l0oookJ_oonf[ooo]Zooo90004oookJP03oonO0?oonf[ooo]Z00Gooo]Z00?o02GooookJ_oo
nfX00_oonfX7oiCo0007oookJ_l0F?ooonh0o`3o1?oonf[o0?nioooo0003oiCo0006o`3oD?nDo`3o
U?l0oiCo0?oonf[oK_l00ooUo`001_oonf[oW?l0oookJ_oonf[oo`12oookJPKoiOl000?oWOl0oook
J_oonfX01_oUo`001?l04?ooiOl0onGo0?oUo`03oookJP03oe_o0?oonf[ooo]Z00gooo]Z00?o01co
oookJ_oonfX0<?oonfX4o`0000Kooo]Z00?o]?l0oookJ_oonfX0:OoonfX00ol01ooooo]ZoookJP0Z
oookJP03oonW0?oonf[o0?o200Oooo]Z00?o?`3ooookJ_oonfX0COoonfX00ooo803ooo]ZoookJP0H
oookJP03ool0Dooonf[ooo]Z07cooo]Z0_l0l_l00ooo0:cooo]ZoookJP07oookJP04o`3o0?oonf[o
oo]ZoookJP;oo`0H0ooonfX2oonO00Kooo]Z00?o02GooookJ_oonfX00ooonfX01Ooo053ooo]Zoook
J_oonf[oo`2l00?ooo]Z00ko05Soo`3o1?oonf[o0?nioooo0?oo05Oo0?obolSo0?l0V_oo0?m@oook
J_oo00cooo]Zofko00;ooo]Z00Co01WooookJ_oonf[oW?l00_oonfX00ooo04;ooo]ZoookJP02oook
JP04o`2Toooonf[ooo]Zoigo00;ooo]Z00Koo`2Co`2doooonf[ooo]ZomWo0?l04?l6oookJP03oe_o
0?oonf[ooo]Z00gooo]Z00?o01cooookJ_oonfX0<?oonfX4o`0000Oooo]Z00?o]?l0oookJ_oonfX0
:?oonfX00ol01ooooo]ZoookJP0ZoookJP03oonW0?oonf[o0?o200Sooo]Z00?o?`3ooookJ_oonfX0
COoonfX00ooo803ooo]ZoookJP0HoookJP03ool0Dooonf[ooo]Z01oooo]Z001RoookJP03o`3boooo
0:cooo]Z00Sooo]Z00?o0?l0oookJ_oob@000_oob@001Ooo01Sooo]ZoookJ_oonf[ooil000Oooo]Z
00?o02GooookJ_oonfX02OnDo`000ooonf[o05Soo`3o1002oookJP05o`3o^Ol0o`7oU?l0oiCo0?l0
oe000onDo`000ooonf[oK_l0onGo0002onGo0005oookJ_nLo`3ooo]ZoookJ_oo04800_oonfX5onGo
0003oigo0?oonf[ooo]Z00KoiOl000?o013oonGo0?oUo`000_oUo`02oookJP03oe_o0?oonf[ooo]Z
00gooo]Z00?o01cooookJ_oonfX0<?oonfX4o`0000Kooo]Z00?o]?l0oookJ_oonfX0:?oonfX00ol0
1ooooo]ZoookJP0[oookJP03oonW0?l0ol;ooo]Z00Kooo]Z00?o?`3ooookJ_oonfX0COoonfX00ooo
803ooo]ZoookJP0HoookJP03ool0Dooonf[ooo]Z07oooo]Z00?o0?;oool0[?oonfX02?oonfX00ol0
o`3ooo]ZoookJP02oookJP03ool06?oonf[ooo]Z00;ooo]Z00?ooil0oookJ_oonfX01?oonfX00ol0
9Ooooo]ZoookJP03oookJP05ool0D?oonf[ooo]ZoookJ_oo0;`00ooonfX03Ol0o`Coonh0oookJ_l0
okWo0?l1ool0Eol0oo;o09[oo`3oD?l0P?oooo]Zool03?m^o`000_oonfX01?l06Ooooo]ZoookJ_nL
o`02oookJP03ool0@_oonf[ooo]Z00;ooo]Z00Co0:CooookJ_oonf[oWOl00ooonfX01Ooo09?o0;Co
oookJ_oonf[o013o00Kooo]Z00?oFol0oookJ_oonfX03OoonfX00ol07?oooo]ZoookJP0`oookJPCo
00001ooonfX00ondo`3ooo]ZoookJP0WoookJP03o`07oooonf[ooo]Z02_ooo]Z00?oojL0o`3o`_oo
nfX01ooonfX00olo0?oooo]ZoookJP1=oookJP03oolP0?oonf[ooo]Z01Sooo]Z00?oo`1CoookJ_oo
nfX08?oonfX006?ooo]Z0_l0l_l00ooo0:cooo]ZoookJP06oookJPGoolT000Coo`0HoookJ_oonf[o
oo]Z0_ooW`06oookJP03o`0UoonDo`3oU?l000SoU?l000Cooo]Zod<0ool0F?oo0?l40_oonfX01Ooo
o`3o0?l1oiCo0?nDo`3o0?m@00;oU?l000?oo`0<oookJ_m^o`000ooUo`001_oonf[oW?l0oookJ_oo
nf[oo`12oiCo00GoiOl000KoWOl0oookJ_oonf[ooo]ZonGo0?oonfX8onGo00;ooo]Z00?oFol0oook
J_oonfX03OoonfX00ol07?oooo]ZoookJP0`oookJPCo00001_oonfX00ondo`3ooo]ZoookJP0Xoook
JP03o`07oooonf[ooo]Z02[ooo]Z00?oojL0oookJ_l0ol801ooonfX00olo0?oooo]ZoookJP1<oook
JP03oolP0?oonf[ooo]Z01Wooo]Z00?oo`1CoookJ_oonfX0P?oonfX2o`3bo`03ool0[?oonf[ooo]Z
00Kooo]Z0_l0o`03oookJP03ool06?oonf[ooo]Z00;ooo]Z00?ooil0oookJ_oonfX01?oonfX00ol0
9Ooooo]ZoookJP03oookJP04ool0D?oonf[ooo]Zool0_0?ooo]Z00ko@`3oo`3o1?oonf[ooo]Zoooo
0?l0o`7oo`1Go`3ol_l0V_oo0?m@o`3o[_oo00cooo]Zofko00;ooo]Z00Co01WooookJ_oonf[oW?l0
0_oonfX01Ooo04;ooo]ZoookJ_oonf[o0:Co00;ooo]Z00KoWOl0oookJ_oonf[ooo]Zool0Tol0]?l2
oookJP03o`0@oooonf[ooo]Z00Gooo]Z00?oFol0oookJ_oonfX03OoonfX00ol07?oooo]ZoookJP0_
oookJPCo00001ooonfX00ondo`3ooo]ZoookJP0WoookJP03o`07oooonf[ooo]Z02[ooo]Z00?oojL0
oookJ_l0ol802?oonfX00olo0?oooo]ZoookJP1<oookJP03oolP0?oonf[ooo]Z01Sooo]Z00?oo`1C
oookJ_oonfX08OoonfX006Gooo]Z0_l0l_l00ooo0:cooo]ZoookJP04oookJPKoolT000?oo`0Hoook
J_oonfX00_oonfX00oooW`3ooo]ZoookJP04oookJP03o`0Uoooonf[oU?l000SoU?l000?ooo]Zo`1H
ool0o`@00_oonfX2odCo0004o`3ol_nDo`3oU?l0o`3oD0;oU?l000?ooo]Zofko0?oonfX00_oUo`00
1ooonf[oU?l0oiCo0?nDo`3oo`12oiCo0?oonfX01OoUo`001?nMo`3ooo]ZoookJ_oo09<9onGo00?o
oo]Z00?oFol0oookJ_oonfX03?oonfX00ol07?oooo]ZoookJP0`oookJPCo00001OoonfX00ondo`3o
oo]ZoookJP0XoookJP03o`07oooonf[ooo]Z02_ooo]Z00?oojL0o`3o`_oonfX01_oonfX00olo0?oo
oo]ZoookJP1=oookJP03oolP0?oonf[ooo]Z01Sooo]Z00?oo`1CoookJ_oonfX0PooonfX2o`3bo`03
ool0[?oonf[ooo]Z00Kooo]Z00Co0?l0oookJ_oonf[ooo]Z0_oo01P3oookJP03oonO0?oonf[ooo]Z
00Cooo]Z00?o02GooookJ_oonfX00ooonfX01?oo053ooo]ZoookJ_oo0;`3oookJP0=o`1Hool0o`Co
oo]Zo`3o^Oooo`3o0?l1o`3ol_l0V_oo^ol0o`3oD?oonf[oo`0<ofko0002oookJP04o`0Ioooonf[o
oo]Zoico00;ooo]Z00?oo`12oookJ_oonfX00_oonfX01?l0Y?oooo]ZoookJ_nMo`02oookJP05ool0
Tol0]?oooo]ZoookJ_l04?l01ooonfX00omKo`3ooo]ZoookJP0=oookJP03o`0Loooonf[ooo]Z02oo
oo]Z1?l00006oookJP03okCo0?oonf[ooo]Z02Oooo]Z00?o00OooookJ_oonfX0:ooonfX00oooY`3o
0?o2oookJP07oookJP03ocl0oooonf[ooo]Z04gooo]Z00?oob00oookJ_oonfX06?oonfX00ooo05?o
oo]ZoookJP0QoookJP00IooonfX00ol0l_ooo`2/ool0[003oookJPSoolT000?oo`0HoookJ_oonfX0
0_oonfX00oooW`3ooo]ZoookJP04oookJP03o`0Uoooonf[oU?l000OoU?l00_oonfX00ol0F?oo0?l4
odCo0002odCo0004o`3o0Ol0oo;oU?l0o`3oD0;oU?l000Coo`0<oookJ_m^o`3ooo]Z1_nDo`000ooo
04;ooo]ZoookJP04onGo0004oigo0?oonf[ooo]ZoookJPWoiOl00ooonfX00omKo`3ooo]ZoookJP0<
oookJP03o`0Loooonf[ooo]Z033ooo]Z1?l00005oookJP03okCo0?oonf[ooo]Z02Sooo]Z00?o00Oo
oookJ_oonfX0:_oonfX00oooY`3o0?o2oookJP07oookJP03ocl0oooonf[ooo]Z04cooo]Z00?oob00
oookJ_oonfX06?oonfX00ooo05?ooo]ZoookJP26oookJP03o`3boooo0:coo`2/00Oooo]Z0_l0o`03
oookJP05ool06?oonf[ooo]ZoookJ_ooW`001_oonfX00ol09Ooooo]ZoookJP02oookJP05ool0D?oo
nf[ooo]ZoookJ_oo0;`00ooonfX03Ol0F?oo0?l4oookJ_l0okWo0?l1oookJ_l0oo;o09[oo`3oD?l0
ojkoo`0<oookJ_m^o`000_oonfX00ol06Ooooo]Zoico0003oookJP05ool0@_oonf[ooo]ZoookJ_l0
Y?l00_oonfX01OnMo`3ooo]ZoookJ_oo09?o0;Co00;ooo]Z00?ofOl0o`0@oooonfX01OoonfX00omK
o`3ooo]ZoookJP0=oookJP03o`0Loooonf[ooo]Z02oooo]Z1?l00006oookJP03okCo0?oonf[ooo]Z
02Oooo]Z00?o00OooookJ_oonfX0:_oonfX00oooY`3ooo]Zo`3o`P08oookJP03ocl0oooonf[ooo]Z
04cooo]Z00?oob00oookJ_oonfX06?oonfX00ooo05?ooo]ZoookJP0RoookJP00J?oonfX2o`3bo`03
ool0[?oonf[oolT000WoolT00_oo01P3oookJP03oonO0?oonf[ooo]Z00Cooo]Z00?o02GooookJ_nD
o`001OnDo`001_oonf[oU?l0oookJ_m30?oo05Soo`3o10?oA?l000Ko0?l1o`3ol_nDo`3o0?m@oiCo
0?oo00`2oookJP03ofko0?nDo`3oU?l000CoU?l000?oo`12oiCo0?oonfX01?oUo`001OnMo`3ooo]Z
oookJ_oonf[oo`2C00SoiOl00ooonfX00omKo`3ooo]ZoookJP0<oookJP03o`0Loooonf[ooo]Z033o
oo]Z1?l00005oookJP03okCo0?oonf[ooo]Z02Sooo]Z00?o00OooookJ_oonfX0:OoonfX00oooY`3o
oo]Zo`3o`P07oookJP03ocl0oooonf[ooo]Z04cooo]Z00?oob00oookJ_oonfX06?oonfX00ooo05?o
oo]ZoookJP28oookJP;o0?;o00?oo`2/oookJ_oonfX01_oonfX01?l0o`3ooo]ZoookJ_oonfX2ool0
60;ooo]Z00?ooil0oookJ_oonfX01?oonfX00ol09Ooooo]ZoookJP02oookJP05ool0D?oonf[ooo]Z
oookJ_oo0;`00_oonfX04?m30?oo0?l4oookJ_oonf[oool0o`3o0Ooo05Oo0?obo`2Jool0oe3ooo]Z
ool03?oonf[oK_l0oookJ_l06Ol2oookJP04oico0?oonf[ooo]Zool0@P?ooo]Z00Co0:CooookJ_oo
nf[oWOl00ooonfX01Ooo09?o0;CooookJ_oonf[o013o00Kooo]Z00?oFol0oookJ_oonfX03OoonfX0
0ol07?oooo]ZoookJP0_oookJPCo00001_oonfX00ondo`3ooo]ZoookJP0WoookJP03o`07oooonf[o
oo]Z02Wooo]Z00?oojL0oookJ_l0ol802?oonfX00olo0?oooo]ZoookJP1<oookJP03oolP0?oonf[o
oo]Z01Sooo]Z00?oo`1CoookJ_oonfX08ooonfX006[ooo]Z00Co0?;oool0[?oo0:cooo]Z2?oob@02
oookJP05ool06?oonf[ooo]ZoookJ_ooW`001OoonfX01?l09Ooooo]ZoookJ_oonfX5oiCo0005ool0
_?oonf[ooo]Zo`1Hool0o`@00om4o`02oiCo0007odCo0?l0oe3oU?l0oookJ_oo00cooo]Zofko0006
oiCo0004ool0@_nDo`3ooo]ZoookJP?oiOl000Kooo]Zoigo0?oonf[ooo]Zool0TooonfX7onGo00?o
oo]Z00?oFol0oookJ_oonfX03?oonfX00ol07?oooo]ZoookJP0`oookJPCo00001OoonfX00ondo`3o
oo]ZoookJP0WoookJP03o`07oooonf[ooo]Z02[ooo]Z00?oojL0o`3o`_oonfX01_oonfX00olo0?oo
oo]ZoookJP1=oookJP03oolP0?oonf[ooo]Z01Sooo]Z00?oo`1CoookJ_oonfX0R_oonfX00ol0l_oo
o`2/ool0[007oookJP03o`3o0?oonf[ooo]Z00;ooo]Z00Coo`0HoookJ_oonf[ooil01OoonfX00ol0
9Ooooo]ZoookJP03oookJP04ool0D?oonf[ooo]Zool0_0?ooo]Z00go05Soo`3o1?oonf[o0?nio`3o
0Ooonf[o0?obo`2Jool0oe3o083oool03?oonf[oK_l000;ooo]Z00?o01WooookJ_nLo`000_oonfX0
0ooo04;ooo]ZoookJP02oookJP04o`2Toooonf[ooo]Zoigo00;ooo]Z00Goo`2Co`2doooonf[ooo]Z
o`0@o`07oookJP03oe_o0?oonf[ooo]Z00cooo]Z00?o01cooookJ_oonfX0;ooonfX4o`0000Kooo]Z
00?o]?l0oookJ_oonfX09_oonfX00ol01ooooo]ZoookJP0ZoookJP03oonW0?oonf[o0?o200Oooo]Z
00?o?`3ooookJ_oonfX0COoonfX00ooo803ooo]ZoookJP0GoookJP03ool0Dooonf[ooo]Z02Cooo]Z
001[oookJP;o0?;o00Coo`2/oookJ_oonf[ooo]Z1_oob@02oookJP05ool06?oonf[ooo]ZoookJ_oo
W`001OoonfX01?l09Ooooo]ZoookJ_oonfX4oiCo0006oookJ_oo0;cooo]ZoookJ_l0F?oo0?l41?nD
o`002?l0oo;oA?l0o`3oD?nDo`3ooo]Zool03?oonf[oK_l01_nDo`000ooo04;ooo]ZoookJP03onGo
0003oookJ_nMo`3ooo]Z00;ooo]Z00?oo`2ConGo0?oUo`001OoUo`03oookJP03oe_o0?oonf[ooo]Z
00cooo]Z00?o01cooookJ_oonfX0<?oonfX4o`0000Cooo]Z00?o]?l0oookJ_oonfX0:?oonfX00ol0
1ooooo]ZoookJP0YoookJP03oonW0?oonf[o0?o200Oooo]Z00?o?`3ooookJ_oonfX0C?oonfX00ooo
803ooo]ZoookJP0HoookJP03ool0Dooonf[ooo]Z08cooo]Z0_l0l_l00ooo0:cooo]ZoookJP05oook
JP;o0?l00ooonfX01?oo01Sooo]ZoookJ_ooW`05oookJP03o`0Uoooonf[ooo]Z00?ooo]Z00Coo`1@
oookJ_oonf[oo`2l0_oonfX04?m30?oo05Soo`3o1?oonf[oool0o`3o0Ooonf[o0?obo`2Jool0oe3o
oo]Zool03?oonf[oK_l0oookJ_l06Ol2oookJP04oico0?oonf[ooo]Zool0@P?ooo]Z00Co0:Cooook
J_oonf[oWOl00_oonfX01Ooo09?o0;CooookJ_oonf[o013o00Oooo]Z00?oFol0oookJ_oonfX03?oo
nfX00ol07?oooo]ZoookJP0_oookJPCo00001OoonfX00ondo`3ooo]ZoookJP0WoookJP03o`07oooo
nf[ooo]Z02Wooo]Z00?oojL0oookJ_l0ol802?oonfX00olo0?oooo]ZoookJP1<oookJP03oolP0?oo
nf[ooo]Z01Sooo]Z00?oo`1CoookJ_oonfX09?oonfX006gooo]Z0_l0l_l4oookJPGoolT00_oonfX0
1Ooo01Sooo]ZoookJ_oonf[ooil000Gooo]Z00Co02GooookJ_oonf[ooo]Z1?nDo`001Ooonf[oo`2l
oookJ_oonf[o0?l400GoU?l000Ooo`1Go`2Jool0oe3ooo]Zool03?oonf[oK_l000KoU?l000Coo`12
oookJ_oonf[ooo]Z0_oUo`000ooonf[oWOl0oookJP02oookJP03ool0Tol0]?ooiOl000GoiOl00ooo
nfX00omKo`3ooo]ZoookJP0<oookJP03o`0Loooonf[ooo]Z033ooo]Z1Ol00003oookJP03okCo0?oo
nf[ooo]Z02Oooo]Z00?o00OooookJ_oonfX0:_oonfX00oooY`3o0?o2oookJP06oookJP03ocl0oooo
nf[ooo]Z04cooo]Z00?oob00oookJ_oonfX06?oonfX00ooo05?ooo]ZoookJP2?oookJP;o0?;o2?oo
nfX01Ol0o`3ooo]ZoookJ_oonf[oo`0H00;ooo]Z00?ooil0oookJ_oonfX00ooonfX00ol09Ooooo]Z
oookJP03oookJP04ool0D?oonf[ooo]Zool0_0;ooo]Z01;o05Soo`3o1?oonf[ooo]Zoooo0?l0o`7o
0?obool0Eonko`3o0?m@ool03?oonf[oK_l0oookJ_ooY03o01WooookJ_nLo`02oookJP05ool0@_oo
nf[ooo]ZoookJ_l0Y?l00_oonfX01_nMo`3ooo]ZoookJ_oonf[oo`2Co`2do`;ooo]Z00?o013ooook
J_oonfX01?oonfX00omKo`3ooo]ZoookJP0<oookJP03o`0Loooonf[ooo]Z02oooo]Z1Ol00004oook
JP03okCo0?oonf[ooo]Z02Kooo]Z00?o00OooookJ_oonfX0:_oonfX00oooY`3ooo]Zo`3o`P07oook
JP03ocl0oooonf[ooo]Z04cooo]Z00?oob00oookJ_oonfX06?oonfX00ooo05?ooo]ZoookJP0Uoook
JP00KooonfX00ol0l_ooo`2/oookJP02oookJPGoolT00_oonfX01Ooo01Sooo]ZoookJ_oonf[ooil0
00Gooo]Z00?o02GooookJ_oonfX01?nDo`02oookJP?oU?l000?o0?l4oiCo0?nDo`000_nDo`002?l0
oo;oA?l0o`3oD?l0ojkooo]Zool03?oonf[oK_l01_nDo`001Ooo04;ooo]ZoookJ_oonf[oiOl000;o
oo]Z00GoWOl0oookJ_oonf[oo`2CoookJP06onGo00?ooo]Z00?oFol0oookJ_oonfX03?oonfX00ol0
7?oooo]ZoookJP0`oookJPCo00001?oonfX00ondo`3ooo]ZoookJP0WoookJP03o`07oooonf[ooo]Z
02Wooo]Z00?oojL0oookJ_l0ol801ooonfX00olo0?oooo]ZoookJP1;oookJP03oolP0?oonf[ooo]Z
01Sooo]Z00?oo`1CoookJ_oonfX0T_oonfX00ol0l_ooo`2/oookJP06oookJP05o`3o0?oonf[ooo]Z
oookJ_oo01P00_oonfX00oooW`3ooo]ZoookJP03oookJP03o`0Uoooonf[ooo]Z00?ooo]Z00Coo`1@
oookJ_oonf[oo`2l0_oonfX03ol0F?oo0?l4oookJ_l0okWo0?l1oookJ_l0oo;o09[oo`3oD?oonf[o
o`0<oookJ_m^o`3ooo]Zo`0Io`02oookJP04oico0?oonf[ooo]Zool0@P?ooo]Z00Co0:CooookJ_oo
nf[oWOl00_oonfX01Ooo09?o0;CooookJ_oonf[o013o00Kooo]Z00?oFol0oookJ_oonfX03?oonfX0
0ol07?oooo]ZoookJP0_oookJPCo00001OoonfX00ondo`3ooo]ZoookJP0VoookJP03o`07oooonf[o
oo]Z02Wooo]Z00?oojL0oookJ_l0ol802?oonfX00olo0?oooo]ZoookJP1;oookJP03oolP0?oonf[o
oo]Z01Sooo]Z00?oo`1CoookJ_oonfX09_oonfX0073ooo]Z0_l0l_l01?oonf[oolT0ooo90?oob@02
oookJP;oolT00_oonfX01Ooo01Sooo]ZoookJ_oonf[ooil000Gooo]Z00?o02GooiCo0?nDo`000onD
o`000ooonf[oU?l0oiCo0003oiCo000=o`3o1?nDo`3oU?l0oiCo0?l0o`7o0?obolSo0?l0oe3ooo]Z
ool03?oonf[oK_l0oookJP05oiCo0005ool0@_oonf[ooo]ZoookJ_l0Y?l00_oonfX01_nMo`3ooo]Z
oookJ_oonf[oo`2Co`2do`GoiOl01?oonfX00omKo`3ooo]ZoookJP0;oookJP03o`0Loooonf[ooo]Z
033ooo]Z1?l00004oookJP03okCo0?oonf[ooo]Z02Kooo]Z00?o00OooookJ_oonfX0:_oonfX00ooo
Y`3o0?o2oookJP06oookJP03ocl0oooonf[ooo]Z04cooo]Z00?oob00oookJ_oonfX06?oonfX00ooo
05?ooo]ZoookJP2CoookJP;o0?;o1ooonfX01Ol0o`3ooo]ZoookJ_oonf[oo`0H00;ooo]Z00?ooil0
oookJ_oonfX00ooonfX00ol09Ooooo]ZoookJP03oookJP0Gool0D?oonf[ooo]Zool0_?oonf[o@`3o
o`1Hool0o`Cooo]Zoooo0?l0o`7ooo]Zo`3ol_l0V_oo0?m@ool03?oonf[oK_l0oookJ_ooY03o01Wo
oookJ_nLo`000_oonfX01Ooo04;ooo]ZoookJ_oonf[o0:Co00;ooo]Z00GoWOl0oookJ_oonf[oo`2C
o`2do`02oookJP03o`0@oooonf[ooo]Z00Cooo]Z00?oFol0oookJ_oonfX03?oonfX00ol07?oooo]Z
oookJP0_oookJPCo00001OoonfX00ondo`3ooo]ZoookJP0UoookJP03o`07oooonf[ooo]Z02[ooo]Z
00?oojL0oookJ_l0ol801ooonfX00olo0?oooo]ZoookJP1<oookJP03oolP0?oonf[ooo]Z01Oooo]Z
00?oo`1CoookJ_oonfX09ooonfX007;ooo]Z1Ooob@03oookJP04ooo90?l0o`3ooo]Zool060?ooo]Z
00?ooil0oookJ_oonfX00_oonfX7oiCo00;ooo]Z1?nDo`003Ol0o`CoU?l0oiCo0?nDo`3o0?obool0
Eol0oe3o083ooookJ_oo00cooo]Zofko0?oonfX01OnDo`001Ooo04;ooo]ZoookJ_oonf[o0:Co00;o
oo]Z00KoWOl0oookJ_oonf[oo`2Co`2doooonfX4onGo00Cooo]Z00?oFol0oookJ_oonfX02ooonfX0
0ol07?oooo]ZoookJP0`oookJPCo00000ooonfX00ondo`3ooo]ZoookJP0WoookJP03o`07oooonf[o
oo]Z02Wooo]Z00?oojL0o`3o`_oonfX01ooonfX00olo0?oooo]ZoookJP1;oookJP03oolP0?oonf[o
oo]Z01Sooo]Z00?oo`1CoookJ_oonfX0U_oonfX2o`3bo`Kooo]Z0_l0o`02oookJP04ool06?oonf[o
oo]ZoonO00Gooo]Z00?o02GooookJ_oonfX00ooonfX00ooo053ooo]Zool0_002oookJP0Ao`1Hool0
o`Cooo]ZoookJ_ooo`3o0?l1o`3ol_l0V_oo0?m@oookJ_oo00cooo]Zofko0?oonf[o01WooookJ_nL
o`000ooonfX01ooo04;ooo]ZoookJ_oonf[o0:CooookJ_nMo`000_oonfX01_oo09?ooo]Zo`2doooo
nf[ofOl0o`0@o`Kooo]Z00?oFol0oookJ_oonfX02ooonfX00ol07?oooo]ZoookJP0_oookJPCo0000
1?oonfX00ondo`3ooo]ZoookJP0VoookJP03o`07oooonf[ooo]Z02Wooo]Z00?oojL0oookJ_l0ol80
2?oonfX00olo0?oooo]ZoookJP1;oookJP03oolP0?oonf[ooo]Z01Oooo]Z00?oo`1CoookJ_oonfX0
:?oonfX0077ooo]Z1ooob@04oookJP03o`3o0?oonf[oo`0H00?ooo]Z00?ooil0oookJ_oonfX01onD
o`001?oo053ooo]ZoookJ_oonfX4oiCo000<o`3o1?nDo`3oU?l0o`3o0Ol0oo;ob?l0o`3oD?l0ojko
o`0<oookJ_m^o`3ooo]Z1OnDo`001Ooo04;ooo]ZoookJ_oonf[o0:Co00;ooo]Z00KoWOl0oookJ_oo
nf[oo`2CoookJ_l0]?l4onGo00Cooo]Z00?oFol0oookJ_oonfX02ooonfX00ol07?oooo]ZoookJP0`
oookJPCo00000ooonfX00ondo`3ooo]ZoookJP0VoookJP03o`07oooonf[ooo]Z02[ooo]Z00?oojL0
o`3o`_oonfX01_oonfX00olo0?oooo]ZoookJP1;oookJP03oolP0?oonf[ooo]Z01Sooo]Z00?oo`1C
oookJ_oonfX0VOoonfX00ol0l_oooo]ZoookJP05oookJP04o`3o0?oonf[ooo]Zool060;ooo]Z00?o
oil0oookJ_oonfX00ooonfX00ol09Ooooo]ZoookJP02oookJP0Gool0D?oonf[ooo]Zool0_?oonf[o
@`3oo`1Hool0o`Cooo]Zo`3o^Ol0o`7ooo]Zo`3ol_l0V_oo0?m@oookJ_oo00coK_l0oookJ_ooY03o
01WooookJ_nLo`000_oonfX01Ooo04;ooo]ZoookJ_oonf[o0:Co00;ooo]Z00GoWOl0oookJ_oonf[o
o`2Co`2do`02oookJP03o`0@oooonf[ooo]Z00Cooo]Z00?oFol0oookJ_oonfX02ooonfX00ol07?oo
oo]ZoookJP0_oookJPCo00001?oonfX00ondo`3ooo]ZoookJP0VoookJP03o`07oooonf[ooo]Z02Wo
oo]Z00?oojL0oookJ_l0ol801ooonfX00olo0?oooo]ZoookJP1;oookJP03oolP0?oonf[ooo]Z01So
oo]Z00?oo`1CoookJ_oonfX0:?oonfX0073ooo]Z2Ooob@04oookJP04o`3o0?oonf[oo`0Hool060;o
oo]Z00?ooil0oiCo0?nDo`001onDo`001?oo053ooo]ZoookJ_oonfX3oiCo000=o`3o1?nDo`3oU?l0
odCo0?l0oo;oo`1Go`2Jool0oe3ooo]Zool03?oonf[oK_l0oookJP04oiCo0004oookJ_oo04;ooo]Z
oookJP;oU?l000?ooo]Zoigo0?oonfX00_oonfX00ooo09?o0;CooookJP03onGo00Cooo]Z00?oFol0
oookJ_oonfX02ooonfX00ol07?oooo]ZoookJP0`oookJPCo00000ooonfX00ondo`3ooo]ZoookJP0V
oookJP03o`07oooonf[ooo]Z02Wooo]Z00?oojL0o`3o`_oonfX01_oonfX00olo0?oooo]ZoookJP1;
oookJP03oolP0?oonf[ooo]Z01Sooo]Z00?oo`1CoookJ_oonfX0VooonfX2o`3bo`Kooo]Z00?o0?l0
oookJ_oonfX00_oo01P00ooonf[ooil0oookJP04oookJP03o`0Uoooonf[ooo]Z00;ooo]Z01Koo`1@
oookJ_oonf[oo`2loookJ_l0F?oooo]Zo`3o1?oonf[oool0o`3o0Ol0oo;o09[oo`3oD?oonf[oo`0<
oookJ_m^o`3ooo]Zo`0Ioooonf[oW?l00_oonfX01Ooo04;ooo]ZoookJ_oonf[o0:Co00;ooo]Z00Go
WOl0oookJ_oonf[oo`2Co`2do`02oookJP03o`0@oooonf[ooo]Z00Cooo]Z00?oFol0oookJ_oonfX0
2ooonfX00ol07?oooo]ZoookJP0_oookJPCo00001?oonfX00ondo`3ooo]ZoookJP0UoookJP03o`07
oooonf[ooo]Z02Wooo]Z00?oojL0oookJ_l0ol801ooonfX00olo0?oooo]ZoookJP1;oookJP03oolP
0?oonf[ooo]Z01Sooo]Z00?oo`1CoookJ_oonfX0:OoonfX006oooo]Z2ooob@04oookJP04o`3o0?oo
nf[ooo]Zool060;ooo]Z00?ooil0oookJ_nDo`001_nDo`000ooonf[oo`1@oookJP02oookJP?oU?l0
00Wo0?l4oiCo0?nDo`3oA?l0o`3ol_o8o`3o0?m@o`3o[_oo00`00_oonfX00om^o`3ooj@0oiCo0002
oiCo0003oookJ_nDo`3oU?l000?oU?l00_oonfX01_nMo`3ooo]ZoookJ_oo09?o0;CooookJP?oiOl0
1?oonfX00omKo`3ooo]ZoookJP0;oookJP03o`0Loooonf[ooo]Z033ooo]Z1?l00003oookJP03okCo
0?oonf[ooo]Z02Gooo]Z00?o00OooookJ_oonfX0:OoonfX00oooY`3ooo]Zo`3o`P07oookJP03ocl0
oooonf[ooo]Z04_ooo]Z00?oob00oookJ_oonfX06?oonfX00ooo05?ooo]ZoookJP2MoookJP03o`3b
oooonf[ooo]Z00Cooo]Z0_l0o`02oookJP03ool06?oonf[ooil000Gooo]Z00?o02GooookJ_oonfX0
0_oonfX05_oo053ooo]ZoookJ_oo0;cooo]Zo`1Hool0o`Cooo]Zo`3o^Oooo`3o0?l1o`3ol_l0V_oo
0?m@oookJ_oo00cooo]Zofko0?ooY03o01WooookJ_nLo`02oookJP07ool0@_oonf[ooo]ZoookJ_l0
Y?oooo]Zoigo0002oookJP05ool0Tooonf[o0;CooookJ_l04?l01_oonfX00omKo`3ooo]ZoookJP0;
oookJP03o`0Loooonf[ooo]Z02oooo]Z1?l00004oookJP03okCo0?oonf[ooo]Z02Gooo]Z00?o00Oo
oookJ_oonfX0:?oonfX00oooY`3ooo]Zo`3o`P08oookJP03ocl0oooonf[ooo]Z04_ooo]Z00?oob00
oookJ_oonfX05ooonfX00ooo05?ooo]ZoookJP0ZoookJP00LOoonfX9ooo900Gooo]Z00Co0?l0oook
J_oonf[oo`0H0_oonfX00oooW`3ooo]ZoiCo0006oiCo0005oookJ_oo053ooo]ZoookJ_oo0;`00onD
o`003Ol0o`CoU?l0o`3o^Ol0o`7o0?obolSo0?l0oe3ooo]Zool03?oonf[oK_l0oookJ_l06Ol02?nD
o`02oookJP05oigo0?oonf[ooo]Zool0Tol0]?l00_oonfX2onGo00Gooo]Z00?oFol0oookJ_oonfX0
2ooonfX00ol07?oooo]ZoookJP09oookJPGo001o1?oonfX3o`00O`?ooo]Z0ol007l7oookJPGo001o
2?oonfX4o`0000;ooo]Z00?o]?l0oookJ_oonfX09_oonfX00ol01ooooo]ZoookJP0YoookJP03oonW
0?l0ol;ooo]Z00Kooo]Z00?o?`3ooookJ_oonfX0BooonfX00ooo803ooo]ZoookJP0HoookJP03ool0
Dooonf[ooo]Z09oooo]Z00?o0?;ooookJ_oonfX01OoonfX01_l0o`3ooo]ZoookJ_oo01Sooo]ZoonO
00Gooo]Z00?o02GooookJ_oonfX00_oonfX00ooo053ooo]Zool0_002oookJP0@o`1Hool0o`Cooo]Z
o`3o^Ol0o`7o0?obolSo0?l0P?oo0?m@ool03?oonf[oK_l0oookJ_l06Ooooo]Zoico00;ooo]Z00Go
o`12oookJ_oonf[ooo]Zo`2To`02oookJP08oigo0?oonf[ooo]Zool0Tol0]?oooo]ZomWo0?l04?l5
oookJP03oe_o0?oonf[ooo]Z00cooo]Z00?o01cooookJ_oonfX02?oonfX5o`00O`Cooo]Z0ol007l3
oookJP?o001o1ooonfX5o`00O`Sooo]Z1?l00003oookJP03okCo0?oonf[ooo]Z02Gooo]Z00?o00Oo
oookJ_oonfX0:OoonfX00oooY`3ooo]Zo`3o`P07oookJP03ocl0oooonf[ooo]Z04_ooo]Z00?oob00
oookJ_oonfX05ooonfX00ooo05?ooo]ZoookJP0[oookJP00M?oonfX7ooo900Gooo]Z00Co0?l0oook
J_oonf[oo`0H0_oonfX00oooW`3ooo]ZoookJP06oiCo0006oookJ_oo053ooo]ZoookJ_oo0;cooo]Z
0_nDo`002?l0o`Cooo]Zoooo0?l0oo;oo`1Go`2Jool0oe3oo`0<0_oonfX00om^o`3oiOl0oiCo0008
oiCo0003oookJ_nMo`3ooo]Z00;ooo]Z00Goo`2Co`2doooonf[ooo]ZonGo0005oookJP03oe_o0?oo
nf[ooo]Z00_ooo]Z00?o01cooookJ_oonfX02?oonfX7o`00O`?ooo]Z0ol007l3oookJP?o001o1_oo
nfX7o`00O`Oooo]Z1?l00002oookJP03okCo0?oonf[ooo]Z02Gooo]Z00?o00OooookJ_oonfX0:Ooo
nfX00ooob@3o0?o2oookJP07oookJP03ocl0oooonf[ooo]Z04[ooo]Z00?oob00oookJ_oonfX06?oo
nfX00ooo05?ooo]ZoookJP2QoookJP;o0?;o1_oonfX01_l0o`3ooo]ZoookJ_oo01Sooo]ZoonO00Go
oo]Z00?o02GooookJ_oonfX00_oonfX00ooo053ooo]Zool0_002oookJP0?o`1Hool0o`Cooo]Zoooo
0?l0o`7o0?obo`2Jool0oe3ooo]Zool03?oonf[oK_l0oookJ_l06OooW?l000?ooo]Z00Ooo`12oook
J_oonf[ooo]Zo`2Toooonf[oWOl000;ooo]Z00Goo`2Co`2doooonf[ooo]Zo`0@o`06oookJP03oe_o
0?oonf[ooo]Z00_ooo]Z00?o01cooookJ_oonfX01ooonfX7o`00O`?ooo]Z0ol007l3oookJP?o001o
1_oonfX7o`00O`Oooo]Z1?l00003oookJP03okCo0?oonf[ooo]Z02Gooo]Z00?o00OooookJ_oonfX0
:?oonfX00oooY`3ooo]Zo`3o`P08oookJP03ocl0oooonf[ooo]Z04[ooo]Z00?oob00oookJ_oonfX0
6?oonfX00ooo05?ooo]ZoookJP0[oookJP00M_oonfX6ooo900Gooo]Z00Co0?l0oookJ_oonf[oo`0H
0_oonfX01?ooW`3ooo]ZoookJ_oonfX4oiCo0003oookJ_oo053ooo]Z00;ooo]Z00ooo`2loookJ_nD
o`3o0?l4oiCo0?l0okWoool0o`3ol_o8o`3o0?m@oookJ_oo00coiOl0ofko0?oUo`002OnDo`02oook
JP05oigo0?oonf[ooo]Zool0Tol0]?l00_oonfX00ol04?oooo]ZoookJP03oookJP03oe_o0?oonf[o
oo]Z00_ooo]Z00?o01cooookJ_oonfX02?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol0
07l3oookJP?o001o1OoonfX4o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l00002oookJP03okCo
0?oonf[ooo]Z02Gooo]Z00?o00OooookJ_oonfX0:OoonfX00ooob@3o0?o2oookJP06oookJP03ocl0
oooonf[ooo]Z04[ooo]Z00?oob00oookJ_oonfX06?oonfX00ooo05?ooo]ZoookJP2ToookJP03o`3b
oooonf[ooo]Z00Cooo]Z00Ko0?l0oookJ_oonf[oo`0HoookJ_ooW`05oookJP05o`0Uoooonf[ooo]Z
oookJ_oo05000_oonfX04_oo0;cooo]ZoookJ_l0o`Cooo]Zo`3o^Oooo`3oo`1Go`3ol_l0P?oo0?m@
oookJ_oo00coK_l0oookJ_l06Ooooo]Zoico00;ooo]Z00Ooo`12oookJ_oonf[ooo]Zo`2Toooonf[o
WOl000;ooo]Z00Goo`2CoookJ_l0]?oooo]Zo`0@o`06oookJP03oe_o0?oonf[ooo]Z00_ooo]Z00?o
01cooookJ_oonfX01ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l3oookJP?o001o
1OoonfX4o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l00003oookJP03okCo0?oonf[ooo]Z02Co
oo]Z00?o00OooookJ_oonfX0:OoonfX00oooY`3ooo]Zo`3o`P07oookJP03ocl0oooonf[ooo]Z04[o
oo]Z00?oob00oookJ_oonfX06?oonfX00ooo05?ooo]ZoookJP0/oookJP00NOoonfX4ooo900Gooo]Z
0_l0o`001Ooonf[oo`0HoookJ_oonf[ooil000?ooo]Z1?nDo`000ooonf[oo`1@oookJP02oookJP0;
ool0_?oonf[oU?l0o`3o1?oonf[o0?nio`3o0Ol0oo;o09[oo`3oD?oo00`00_oUo`000om^o`3oiOl0
oiCo0007oiCo00;ooo]Z00GoWOl0oookJ_oonf[oo`2Co`2do`02oookJP03o`0@oooonf[ooo]Z00Co
oo]Z00?oFol0oookJ_oonfX02?oonfX2o`00O`03o`0Lool007oo001o00Go001o0_oonfX3o`00O`?o
oo]Z0ol007l9oookJP;o001o1OoonfX3o`00O`?ooo]Z0ol007l6oookJPCo00000_oonfX00ondo`3o
oo]ZoookJP0ToookJP03o`07oooonf[ooo]Z02Wooo]Z00?oolT0o`3o`_oonfX01ooonfX00olo0?oo
oo]ZoookJP1:oookJP03oolP0?oonf[ooo]Z01Sooo]Z00?oo`1CoookJ_oonfX0YOoonfX00ol0l_oo
o`2/oookJP04oookJP;o0?l000Cooo]Zool06?oonf[ooil01OoonfX01Ol09Ooooo]ZoookJ_oonf[o
o`1@00;ooo]Z017oo`2loookJ_oonf[o0?l4oookJ_l0okWo0?l1o`3ol_l0V_oo0?m@oookJ_oo00co
oo]Zofko0?oonf[o01Wooico0002oookJP07ool0@_oonf[ooo]ZoookJ_l0Y?oooo]Zoigo0003oook
JP04ool0Tol0]?oooo]Zo`0@o`Kooo]Z00?oFol0oookJ_oonfX02?oonfX3o`00O`03o`0Lool007oo
001o00Co001o0_oonfX3o`00O`?ooo]Z0ol007l9oookJP;o001o1OoonfX3o`00O`?ooo]Z0ol007l6
oookJPCo00000_oonfX00ondo`3ooo]ZoookJP0UoookJP03o`07oooonf[ooo]Z02Sooo]Z00?oojL0
oookJ_l0ol802?oonfX00olo0?oooo]ZoookJP1:oookJP03oolP0?oonf[ooo]Z01Oooo]Z00?oo`1C
oookJ_oonfX0;OoonfX007_ooo]Z0ooob@06oookJP03o`3o0?oonf[oo`0H00;ooo]Z00?ooil0oook
J_oonfX00_oonfX2oiCo00;ooo]Z00Coo`1@oookJ_oonf[oo`2l0_oonfX03OnDo`3o0?l4o`3o^Ooo
o`3o0?obolSo0?l0P?oo0?m@ool03?oUo`3oK_l0onGo0?l06Ol01onDo`000ol0Y?oooo]Zoigo0003
oookJP05ool0Tol0]?oooo]ZoookJ_l04?l01OoonfX00omKo`3ooo]ZoookJP08oookJP;o001o00?o
01coo`00Ool007l01Ol007l2oookJP?o001o0ooonfX3o`00O`Wooo]Z0ol007l:oookJP?o001o1_oo
nfX5o`000003okCo0?oonf[ooo]Z02Gooo]Z00?o00OooookJ_oonfX0:OoonfX00ooob@3o0?o2oook
JP06oookJP03ocl0oooonf[ooo]Z04[ooo]Z00?oob00oookJ_oonfX06?oonfX00ooo05?ooo]Zoook
JP2WoookJP03o`3boooo0:cooo]Z00Gooo]Z00Go0?l0oookJ_oo01Sooo]ZoonO0005oookJP07o`0U
oooonf[ooo]ZoookJ_oo053ooo]Zool0_003oookJP0>o`3o1?l0okWoool0ool0Eol0oo;o083oo`3o
D?oonf[oo`0<ofko0?oonf[ooj@0o`0IoonLo`02oookJP07ool0@_oonf[ooo]ZoookJ_l0Y?oooo]Z
oigo0002oookJP05ool0Tol0]?oooo]ZoookJ_l04?l01OoonfX00omKo`3ooo]ZoookJP08oookJP?o
001o00?o01coo`00Ool007l01?l007l2oookJP?o001o0ooonfX3o`00O`Wooo]Z0ol007l:oookJP?o
001o1_oonfX6o`000003okCo0?oonf[ooo]Z02Gooo]Z00?o00OooookJ_oonfX0:?oonfX00oooY`3o
oo]Zo`3o`P07oookJP03ocl0oooonf[ooo]Z04[ooo]Z00?oob00oookJ_oonfX05ooonfX00ooo05?o
oo]ZoookJP0^oookJP00O_oonfX00ooob@3o0?;ooookJP04oookJP06o`3o0?oonf[oo`0Hool06?oo
nf[ooil01OoonfX01?nDo`3ooo]ZoookJ_oo0502oookJP0;ool0_?oonf[o@`3ooiCo0?l0o`Co0?ni
oooo0?l0oo;o09[oo`3oD?oo00`00_oUo`000om^o`3o01WoonGo0006oiCo0004o`2Toooonf[ooo]Z
oigo00;ooo]Z00Goo`2Co`2doooonf[ooo]Zo`0@o`05oookJP03oe_o0?oonf[ooo]Z00[ooo]Z00?o
01cooookJ_oonfX01ooonfX3o`00O`?ooo]Z0ol007l9oookJP?o001o2_oonfX3o`00O`Kooo]Z1?l0
00000ooonf[o]?l0oookJP0VoookJP03o`07oooonf[ooo]Z02Sooo]Z00?oolT0o`3o`_oonfX01_oo
nfX00olo0?oooo]ZoookJP1:oookJP03oolP0?oonf[ooo]Z01Sooo]Z00?oo`1CoookJ_oonfX0ZOoo
nfX2o`3bo`Kooo]Z00Go0?l0oookJ_oo01Sooo]ZoonO0005oookJP07o`0Uoooonf[ooo]ZoookJ_oo
053ooo]Zool0_002oookJP0>ooo^0?l0o`Co0?nioooo0?l0oo;o09[oo`3oD?l0ojkoo`0<oookJ_m^
o`3ooo]Zo`0IoonLo`02oookJP07ool0@_oonf[ooo]ZoookJ_l0Y?oooo]Zoigo0002oookJP05ool0
Tooonf[o0;CooookJ_l04?l01OoonfX00omKo`3ooo]ZoookJP0;oookJP03o`0Loooonf[ooo]Z00Ko
oo]Z0ol007l3oookJP?o001o2OoonfX3o`00O`[ooo]Z0ol007l6oookJPCo00000_oonfX00ondo`3o
oo]ZoookJP0ToookJP03o`07oooonf[ooo]Z02Sooo]Z00?oojL0oookJ_l0ol801ooonfX00olo0?oo
oo]ZoookJP1:oookJP03oolP0?oonf[ooo]Z01Oooo]Z00?oo`1CoookJ_oonfX0;ooonfX0083ooo]Z
00?o0?;ooookJ_oonfX00ooonfX01_l0o`3ooo]ZoookJ_oo01Sooo]ZoonO00Cooo]Z0_nDo`000ooo
nf[oo`1@oookJP02oookJP0>ool0_?oonf[o05Soo`3o1?oonf[o0?nio`3o0Ol0oo;o083oo`3oD?oo
00coiOl0ofko0?oUo`02odCo00KoU?l000?o0:CooookJ_nMo`000_oonfX01Ooo09?o0;CooookJ_oo
nf[o013o00Gooo]Z00?oFol0oookJ_oonfX02_oonfX00ol07?oooo]ZoookJP07oookJP?o001o0ooo
nfX3o`00O`[ooo]Z0_l007l5oookJP;o001o0_oonfX4o`00O`Kooo]Z1?l000000ooonf[o]?l0oook
JP0UoookJP03o`07oooonf[ooo]Z02Sooo]Z00?oolT0oookJ_l0ol801ooonfX00olo0?oooo]Zoook
JP19oookJP03oolP0?oonf[ooo]Z01Sooo]Z00?oo`1CoookJ_oonfX0[?oonfX00ol0l_ooo`2/oook
JP04oookJP05o`3o0?oonf[oo`0HoookJ_ooW`001OoonfX01?l09Ooooo]ZoookJ_oo0502oookJP0A
ool0_?oonf[ooo]Zo`3o1?oonf[o0?nio`3o0Ol0oo;o09[oo`3oD?oonf[oo`0<ofko0?oonf[ooj@0
o`0IoonLo`000_oonfX01_oo04;ooo]ZoookJ_oonf[o0:Cooigo00?ooo]Z00Coo`2Co`2doooonf[o
013o1_oonfX00omKo`3ooo]ZoookJP0:oookJP03o`0Loooonf[ooo]Z00Kooo]Z0ol007l3oookJP?o
001o2_oonfX2o`00O`Gooo]Z0_l007l2oookJPCo001o1_oonfX4o`000003oookJ_ndo`3ooo]Z02Ko
oo]Z00?o00OooookJ_oonfX09ooonfX01?ooY`3ooo]ZoookJ_l0ol87oookJP03ocl0oooonf[ooo]Z
04Wooo]Z00?oob00oookJ_oonfX06?oonfX00ooo05?ooo]ZoookJP0_oookJP009OoonfXGo`3oETGo
oo]Z00?o0?;oool0[?oonfX00ooonfX01_l0o`3ooo]ZoookJ_oo01Sooo]ZoonO00;ooo]Z0_nDo`00
1?l09Ooooo]ZoookJ_oo0503oookJP0=ool0_?oonf[o05Soo`3o1?m4o`3oool0o`3ol_o8o`3o0?m@
ool03?oUo`3oA?l0ofko0002odCo0003onGo0?nDo`3oU?l000?oU?l000_o0:CooookJ_oonf[oWOl0
oookJ_oo09?ooo]Zo`2doooonf[ofOl0o`0@o`05oookJP03oe_o0?oonf[ooo]Z00Wooo]Z00?o01co
oookJ_oonfX01ooonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o1?oonfX7o`00O`Oooo]Z1?l00000
0ooonf[o]?l0oookJP0UoookJP03o`07oooonf[ooo]Z02?ooo]Z0_oob@03oookJP03ooo90?l0ol;o
oo]Z00Kooo]Z00?o?`3ooookJ_oonfX0B_oonfX00ooo803ooo]ZoookJP0HoookJP03ool0Dooonf[o
oo]Z057ooo]Z5ol0oeI5oookJP03o`3boooo0:cooo]Z00Cooo]Z00Go0?l0oookJ_oo01Sooo]ZoonO
0004oookJP05o`0Uoooonf[ooo]ZoookJ_oo05000_oonfX04ooo0;cooo]Zod<0ool0o`Cooo]Zoooo
0?l0oo;oo`1Go`3oD?l0ojkoo`0<oookJ_m^o`3ooo]Zo`0Ioooonf[oW?l0oookJ_oo04800ooonfX0
0ol0Y?oooo]Zoigo0002oookJP05ool0Tol0]?oooo]ZomWo0?l04?l01OoonfX00omKo`3ooo]Zoook
JP0:oookJP03o`0Loooonf[ooo]Z00Kooo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`Cooo]Z1ol0
07l7oookJPCo000000?ooo]ZokCo0?oonfX09OoonfX00ol01ooooo]ZoookJP0XoookJP03oonW0?oo
nf[o0?o200Oooo]Z00?o?`3ooookJ_oonfX0B_oonfX00ooo803ooo]ZoookJP0GoookJP03ool0Dooo
nf[ooo]Z033ooo]Z000loookJP_o0?mF>ooonfX2o`3bo`Cooo]Z00Ko0?l0oookJ_oonf[oo`0Hoook
J_ooW`04oiCo0004o`0Uoooonf[ooo]Zool0D0;ooo]Z00[oo`2loookJ_m30?oo05Soo`3o1?m4o`3o
ool0o`3ol_nDo`3o0?m@0om4o`000om^o`3oA?l0onGo0005oiCo0004o`2Toooonf[ooo]Zoigo00;o
oo]Z00Goo`2Co`2doooonf[ooo]Zo`0@o`05oookJP03oe_o0?oonf[ooo]Z00Wooo]Z00?o01cooook
J_oonfX01ooonfX3o`00O`?ooo]Z0ol007l;oookJP;o001o1?oonfX6o`00O`Sooo]Z1?l000000ond
o`3ooo]ZoookJP0ToookJP03o`07oooonf[ooo]Z02Cooo]Z1Ooob@000ol0ol;ooo]ZoookJP06oook
JP03ocl0oooonf[ooo]Z04Wooo]Z00?oob00oookJ_oonfX06?oonfX00ooo05?ooo]ZoookJP1Yoook
JPco0?mF>_oonfX2o`3bo`Gooo]Z00Go0?l0oookJ_oo01Sooo]ZoonO0004oookJP07o`0Uoooonf[o
oo]ZoookJ_oo053ooo]Zool0_002oookJP0>o`1Hool0o`Co0?nioooo0?l0oo;o09[oo`3oD?l0ojko
o`0<oookJ_m^o`3ooj@0o`0IoonLo`02oookJP06ool0@_oonf[ooo]Zo`2Toooonf[oWOl00_oonfX0
1Ooo09?ooo]Zo`2doooonf[o013o00Gooo]Z00?oFol0oookJ_oonfX02_oonfX00ol07?oooo]Zoook
JP06oookJP?o001o0ooonfX3o`00O`_ooo]Z0_l007l4oookJPKo001o2?oonfX4o`000003oookJ_nd
o`3ooo]Z02Gooo]Z00?o00OooookJ_oonfX09ooonfX00oooY`3ooo]Zo`3o`P08oookJP03ocl0oooo
nf[ooo]Z04Wooo]Z00?oob00oookJ_oonfX05ooonfX00ooo05?ooo]ZoookJP0aoookJP00AooonfX7
o`3oESKooo]Z00?o0?;oool0[?oonfX00_oonfX01?l0o`3ooo]ZoookJ_oo01P6oiCo0004o`0Uoooo
nf[ooo]Zool0D0;ooo]Z00[oo`2lodCo0?l0F?ooonh0o`3o1?m4o`3o0?obodCo0?l0P?oo0?m@0_m4
o`001?m^o`3oA?l0odCo0?oUo`04oiCo0005oookJ_l0Y?oooo]Zoigo0?oonfX00ooUo`000ol0]?oo
oo]Zo`0@o`05oookJP03oe_o0?oonf[ooo]Z00Wooo]Z00?o01cooookJ_oonfX01ooonfX3o`00O`?o
oo]Z0ol007l<oookJP;o001o0ooonfX2o`00O`cooo]Z1?l000000ondo`3ooo]ZoookJP0ToookJP03
o`07oooonf[ooo]Z02Cooo]Z1Ooob@000ol0ol;ooo]ZoookJP05oookJP03ocl0oooonf[ooo]Z04Wo
oo]Z00?oob00oookJ_oonfX06?oonfX00ooo05?ooo]ZoookJP1foookJPOo0?mF=OoonfX00ol0l_oo
o`2/oookJP03oookJP05o`3o0?oonf[oo`0HoookJ_ooW`001?oonfX01ol09Ooooo]ZoookJ_oonf[o
o`1@oookJ_oo0;`00_oonfX04?l0F?oo0?l4o`3o^Ol0o`7o0?obo`2Jool0oe3ooo]Zool03?m^o`3o
oo]Zo`0Ioooonf[oW?l0oookJ_oo0483oookJP03o`2ToonMo`3ooo]Z00;ooo]Z00Coo`2Co`2doooo
nf[o013o1OoonfX00omKo`3ooo]ZoookJP0:oookJP03o`0Loooonf[ooo]Z00Kooo]Z0ol007l3oook
JP?o001o3?oonfX2o`00O`?ooo]Z0_l007l<oookJPCo000000?o]?l0oookJ_oonfX09?oonfX00ol0
1ooooo]ZoookJP0XoookJP03oonW0?oonf[o0?o200Oooo]Z00?o?`3ooookJ_oonfX0BOoonfX00ooo
803ooo]ZoookJP0GoookJP03ool0Dooonf[ooo]Z03;ooo]Z001>oookJPGo0?mF<_oonfX00ol0l_oo
o`2/oookJP02oookJP;o0?l000?oU?l0ool06?nDo`001?nDo`001Ooonf[o02GooookJ_oonf[oo`1@
00;ooo]Z00Goo`2loookJ_l0F?oo0?l4oiCo0003odCo0008o`3oD?m4o`3oA?l0odCo0?m^o`3oA?l0
onGo0?nLo`03oiCo0003oookJ_l0Y?ooiOl000GoiOl000?o0;CooookJ_l04?l01OoonfX00omKo`3o
oo]ZoookJP0:oookJP03o`0Loooonf[ooo]Z00Oooo]Z0ol007l01?oonf[o001oo`00Ool007l=oook
JP;o001o0ooonfX2o`00O`cooo]Z1?l000000ondo`3ooo]ZoookJP0SoookJP03o`07oooonf[ooo]Z
02Cooo]Z1Ooob@000ol0ol;oolT0ooo90005oookJP03ocl0oooonf[ooo]Z04Wooo]Z00?oob00oook
J_oonfX06?oonfX00ooo05?ooo]ZoookJP1noookJPGo0?mF<OoonfX00ol0l_ooo`2/oookJP03oook
JP05o`3o0?oonf[oo`0HoookJ_ooW`001?oonfX01?l09Ooooo]ZoookJ_oo0502oookJP0Bool0_?oo
nf[o@`3oo`3o1?oonf[oool0o`3ol_oo05Oo0?m@o`3o[_oo00cooo]Zofko0?ooY03o01Wooico0?oo
nf[oo`120ooonfX00ol0Y?oooo]Zoigo0002oookJP04ool0Tol0]?oooo]Zo`0@o`Gooo]Z00?oFol0
oookJ_oonfX02_oonfX00ol07?oooo]ZoookJP07oookJP?o001o00Cooo]Zo`00Ool007oo001o3Ooo
nfX2o`00O`?ooo]Z0_l007l<oookJPCo000000?o]?l0oookJ_oonfX09?oonfX00ol01ooooo]Zoook
JP0WoookJP03oonW0?oonf[o0?o200Oooo]Z00?o?`3ooookJ_oonfX0BOoonfX00ooo803ooo]Zoook
JP0HoookJP03ool0Dooonf[ooo]Z03;ooo]Z001CoookJPGo0?mF;_oonfX2o`3bo`?ooo]Z00CoU?l0
o`3o0?nDo`3oo`0H1OnDo`001Ol09Ooooo]ZoookJ_oonf[oo`1@00;ooo]Z00Goo`2loiCo0?l0F?oo
0?l4oiCo0002odCo0006o`20ool0oe3oA?l0odCo0?m^o`3oA?l00_oUo`001?nLo`3oU?l0oiCo0?nD
o`07onGo0004o`2doooonf[ofOl0o`0@o`Cooo]Z00?oFol0oookJ_oonfX02_oonfX00ol07?oooo]Z
oookJP07oookJPOo001o1ooonfX9o`00O`?ooo]Z1ol007l6oookJPCo000000?o]?l0oookJ_oonfX0
8ooonfX00ol01ooooo]ZoookJP0ToookJPGoolT000Co0?o2ooo90?oob@3oolT01?oonfX00olo0?oo
oo]ZoookJP19oookJP03oolP0?oonf[ooo]Z01Sooo]Z00?oo`1CoookJ_oonfX0PooonfX4o`3oERko
oo]Z0_l0l_l4oookJP05o`3o0?oonf[oo`0HoookJ_ooW`001?oonfX01?l09Ooooo]ZoookJ_oo0502
oookJP0Bool0_?oonf[o05Soo`3o1?oonf[o0?l1o`3ol_oo05Oo0?m@oookJ_oo00coK_l0oookJ_l0
6Ooooo]Zoico0?oonf[oo`120ooonfX02Ol0Y?ooWOl0oookJ_oonf[oo`2CoookJ_l0]?oooo]Zo`0@
o`05oookJP03oe_o0?oonf[ooo]Z00Wooo]Z00?o01cooookJ_oonfX01ooonfX7o`00O`Oooo]Z2Ol0
07l3oookJPOo001o1_oonfX4o`000003okCo0?oonf[ooo]Z02Cooo]Z00?o00OooookJ_oonfX09ooo
nfX00oooY`3ooo]Zo`3o`P07oookJP03ocl0oooonf[ooo]Z04Wooo]Z00?oob00oookJ_oonfX05ooo
nfX00ooo05?ooo]ZoookJP0coookJP00F?oonfX4o`3oERcooo]Z00?o0?;ooookJ_oonfX00_oonfX0
0ol0o`3oU?l0ool06004oiCo0003oookJ_l09Ooooo]Z00;ooo]Z00Soo`1@oookJ_oo0;coU?l0o`1H
oonDo`3o0?l4oiCo00;oA?l000Wo0?m@odCo0?m4o`3oA?l0ofko0?l06OooiOl0oico0?oonfX00_nD
o`07onGo0004oookJ_l0]?oooo]Zo`0@o`Gooo]Z00?oFol0oookJ_oonfX02OoonfX00ol07?oooo]Z
oookJP08oookJPGo001o2?oonfX9o`00O`?ooo]Z1ol007l5oookJP?oolT000?o0000okCo0?oonfX0
9?oonfX00ol01ooooo]ZoookJP0UoookJPCoolT000Co0?o2ooo90?oob@3oolT01?oonfX00olo0?oo
oo]ZoookJP19oookJP03oolP0?oonf[ooo]Z01Sooo]Z00?oo`1CoookJ_oonfX0R?oonfX4o`3oERco
oo]Z00?o0?;ooookJ_oonfX00_oonfX01Ol0o`3ooo]Zool06?oonf[ooil000Cooo]Z01Oo02Gooook
J_oonf[oo`1@oookJ_oo0;cooo]Zod<0ool0F?oo0?l4o`3o^Ol0o`7o0?obo`3oD?l0P?ooo`0<oook
J_m^o`3ooj@0o`0IoonLo`3ooo]Zool0@P03oookJP03o`2Toooonf[oWOl000;ooo]Z00Coo`2Co`2d
oooonf[o013o1OoonfX00omKo`3ooo]ZoookJP09oookJP03o`0Loooonf[ooo]Z00Sooo]Z1Ol007l8
oookJPWo001o0ooonfX7o`00O`Kooo]Z0ol000000ondo`3ooo]ZoookJP0ToookJP03o`07oooonf[o
oo]Z02Oooo]Z00?oojL0oookJ_l0ol801ooonfX00olo0?oooo]ZoookJP19oookJP03oolP0?oonf[o
oo]Z01Oooo]Z00?oo`1CoookJ_oonfX0=?oonfX005cooo]Z1?l0oeHYoookJP03o`3boooonf[ooo]Z
00;ooo]Z00?o0?l0oiCo0?oo01P01?nDo`000ooonf[o02GooookJP02oookJP06ool0D?nDo`3oo`2l
oiCo0?l0F?oo0?l40_nDo`000om4o`3o083oo`3oD002odCo0007ofko0?m4o`3o01WooookJ_nLo`3o
oo]ZoiCo0007onGo0004oookJ_l0]?oooo]Zo`0@o`Gooo]Z00?oFol0oookJ_oUo`000_oUo`07oook
JP03o`0Loooonf[ooo]Z02gooo]Z1_oob@0ToookJP03o`07oooonf[ooo]Z02Gooo]Z1?oob@000ol0
ol;oolT0ooo90005oookJP03ocl0oooonf[ooo]Z04Sooo]Z00?oob00oookJ_oonfX06?oonfX00ooo
05?ooo]ZoookJP2=oookJPCo0?mF:OoonfX00ol0l_oooo]ZoookJP02oookJP05o`3o0?oonf[oo`0H
oookJ_ooW`001?oonfX05ol09Ooooo]ZoookJ_oo053ooo]Zool0_?oonf[o05Soooo^0?l0o`Coool0
o`3ol_oo05Oo0?m@o`3o[_oo00coK_l0oookJ_l06Ooooo]Zoico0?oonf[oo`1200;ooo]Z00?o0:Co
oookJ_nMo`000_oonfX01?oo09?o0;CooookJ_l04?l5oookJP03oe_o0?oonf[ooo]Z00[ooo]Z00?o
01cooookJ_oonfX0;OoonfX3o`000003okCo0?oonf[ooo]Z02Cooo]Z00?o00OooookJ_oonfX09_oo
nfX01?ooY`3ooo]ZoookJ_l0ol87oookJP03ocl0oooonf[ooo]Z04Sooo]Z00?oob00oookJ_oonfX0
5ooonfX00ooo05?ooo]ZoookJP0eoookJP00H?oonfX3o`3oEROooo]Z00?o0?;ooookJ_oonfX00_oo
nfX00ol0o`3oU?l0ool06004oiCo000?oookJ_l09Ooooo]ZoookJ_oo053ooo]ZoiCo0?oo0;coU?l0
o`1Hool0o`CoU?l0o`3ol_m4o`3o0?m@00?oA?l000OoK_l0o`0IoooUo`3oW?l0oookJ_oo04;ooo]Z
00OoiOl000?o0;CooookJ_l04?l00ooonfX7onGo00Oooo]Z00?o01cooookJ_oonfX0;OoonfX8ooo9
027ooo]Z00?o00OooookJ_oonfX09OoonfX4ooo90003o`3o`_oob@3oolT000Gooo]Z00?o?`3ooook
J_oonfX0B?oonfX00ooo803ooo]ZoookJP0HoookJP03oolX0?oonf[ooo]Z09;ooo]Z0ol0oeHWoook
JP03o`3boooonf[ooo]Z00;ooo]Z00Go0?l0oookJ_oo01Sooo]ZoonO0004oookJP03o`0Uoooonf[o
o`1@00;ooo]Z017oo`2lod<0ool0F?oo0?l4oookJ_l0o`7o0?obo`3oD?l0P?ooo`0<oookJ_m^o`3o
01WooookJ_nLo`3ooo]Zool0@P03oookJP09o`2ToonMo`3ooo]ZoookJ_oo09?o0;CooookJ_l04?oo
fOl000Gooo]Z00?oFol0oookJ_oonfX02OoonfX00ol07?oooo]ZoookJP0]oookJP?o000000?o]?l0
o`000?oonfX08ooonfX00ol01ooooo]ZoookJP0WoookJP03oonW0?oonf[o0?o200Oooo]Z00?o?`3o
oookJ_oonfX0B?oonfX00ooo803ooo]ZoookJP0GoookJP03ool0Dooonf[ooo]Z03Kooo]Z001Soook
JP?o0?mF9OoonfX00ol0l_oooo]ZoookJP02oookJP03o`3o0?oUo`3oo`0H00?oU?l000?ooo]Zo`0U
oooonfX00_oonfX01_oo053ooo]ZoiCo0?oo0;co05Soo`3o10;oU?l000?o0?obodCo0?l0oe000_m4
o`001om^o`3ooo]Zo`0Ioooonf[oW?l0oookJ_oo04801ooUo`001?oonf[o0;CooookJ_l04?l9onGo
00Oooo]Z00?o01cooookJ_oonfX0;OoonfX8ooo9027ooo]Z00?o00OooookJ_oonfX09OoonfX3ooo9
0003o`3o`_oob@3oolT000Gooo]Z00?o?`3ooookJ_oonfX0BOoonfX00ooo803ooo]ZoookJP0Hoook
JP03oolX0?oonf[ooo]Z09Gooo]Z0ol0oeHUoookJP03o`3boooonf[ooo]Z00;ooo]Z00Go0?l0oook
J_oo01Sooo]ZoonO0003oookJP04o`0Uoooonf[ooo]Zool0D0;ooo]Z017oo`2lo`1Hoooonf[o0?l4
oooo0?l0o`7o0?obo`3oD?l0P?ooo`0<ofko0?oonf[o01WooookJ_nLo`3ooo]Zool0@P02oookJP03
o`2Toooonf[oWOl000;ooo]Z00Coo`2Co`2doooonf[o013o1OoonfX00omKo`3ooo]ZoookJP09oook
JP03o`0Loooonf[ooo]Z02gooo]Z0ol000000ondo`3ooo]ZoookJP0SoookJP03o`07oooonf[ooo]Z
02Kooo]Z00?oojL0oookJ_l0ol801ooonfX00olo0?oooo]ZoookJP19oookJP03oolP0?oonf[ooo]Z
01Oooo]Z00?oo`1CoookJ_oonfX0=_oonfX002Gooo]Z8?n0o`0QoookJP?o0?mF8ooonfX00ol0l_oo
o`2/oookJP02oookJP03o`3o0?oonf[oo`0H00?oU?l000?ooo]Zo`0UoooonfX00_oonfX02ooo053o
oo]Zool0_?nDo`3o05Soo`3o1?nDo`3o0?oboiCo0?l0P?oo0?m@00;oA?l000OoK_l0o`0Ioooonf[o
W?l0oookJ_oo04;ooo]Z00KoiOl000Coo`2Co`2doooonf[o013o2OoUo`08oookJP03o`0Loooonf[o
oo]Z02cooo]Z1ooob@0RoookJP03o`07oooonf[ooo]Z02Gooo]Z0ooob@000ol0ol;oolT0oookJP05
oookJP03ocl0oooonf[ooo]Z04Sooo]Z00?oob00oookJ_oonfX06?oonfX00ooo:03ooo]ZoookJP1H
oookJR7oP?l08?oonfX3o`3oER?ooo]Z00?o0?;oool0[?oonfX00_oonfX01Ol0o`3ooo]Zool06?oo
nf[ooil000?ooo]Z01Ko02GooookJ_oonf[oo`1@oookJ_oo0;cooo]Zo`1HooookP3o0?l4o`3o0Ol0
oo;oo`1Go`3oD?oonf[oo`0<ofko0?l06Ooooo]Zoico0?oonf[oo`120ooonfX02Ol0Y?ooWOl0oook
J_oonf[oo`2Co`2doooonf[o013oomWo0004oookJP03oe_o0?oonf[ooo]Z00Wooo]Z00?o01cooook
J_oonfX0;OoonfX2o`000003okCo0?l0003ooo]Z02Cooo]Z00?o00OooookJ_oonfX09_oonfX00ooo
Y`3ooo]Zo`3o`P07oookJP03ocl0oooonf[ooo]Z04Sooo]Z00?oob00oookJ_oonfX05ooonfX00ooo
05?ooo]ZoookJP0goookJP00AOoonfX;oh3o01Wooo]Z0_l0oeHRoookJP03o`3boooo0:cooo]Z00;o
iOl000?o0?l0oookJ_oo01P00_nDo`02oookJP0>o`0Uoooonf[ooo]ZoookJ_oo053ooo]Zool0_?nD
o`3o05Soo`3o1?nDo`3o0?obool0Eol0oe02odCo0004ofko0?oonf[o01Wooico00;ooo]Z00?oo`12
oookJ_oUo`001?oUo`001Ooo09?o0;CooookJ_l04?oooo]Z00SoiOl02?oonfX00ol07?oooo]Zoook
JP0/oookJPOoolT08OoonfX00ol01ooooo]ZoookJP0UoookJP?oolT000?o0?o2ooo90?oonfX01Ooo
nfX00olo0?oooo]ZoookJP18oookJP03oolP0?oonf[ooo]Z01Sooo]Z00?oobP0oookJ_oonfX0N_oo
nfX:oh3o01Wooo]Z0_l0oeHRoookJP03o`3boooo0:cooo]Z00;ooo]Z00Go0?l0oookJ_oo01Sooo]Z
oonO0003oookJP0Co`0Uoooonf[ooo]Zool0D?oonf[oo`2loookJ_l0F?ooonh0o`3o1?l0o`7o0?ob
o`3oD?l0P?ooo`0<oookJ_m^o`3o01Wooico0002oookJP0<ool0@_oonf[ooo]Zo`2Toooonf[oWOl0
oookJ_oo09?o0;CooookJ_l04?oofOl01?oonfX00omKo`3ooo]ZoookJP09oookJP03o`0Loooonf[o
oo]Z02gooo]Z0_l000000ondo`3o0000oookJP0SoookJP03o`07oooonf[ooo]Z02Kooo]Z00?oojL0
oookJ_l0ol801ooonfX00olo0?oooo]ZoookJP18oookJP03oolP0?oonf[ooo]Z01Oooo]Z00?oo`1C
oookJ_oonfX0>?oonfX0053ooo]Z1on0o`0DoookJP?o0?mF8?oonfX2o`3bo`;oiOl000Ko0?l0onGo
0?oonf[oo`0HoookJ_nDo`02oookJP04o`0Uoooonf[ooo]Zool0D0;ooo]Z00?oo`2lo`1Hool0o`@0
0_nDo`002ol0oo;o083oo`3oD?m4o`3oK_l0oookJ_l06Ooooo]Zoico0?oonf[oo`1200;ooo]Z1?oU
o`001_oo09?ooo]Zo`2doooonf[o013ooookJPOoiOl02?oonfX00ol07?oooo]ZoookJP0/oookJPKo
olT08_oonfX00ol01ooooo]ZoookJP0UoookJP?oolT000?o0?o2oookJ_oonfX01OoonfX00olo0?oo
oo]ZoookJP17oookJP03oolP0?oonf[ooo]Z01Sooo]Z00?oobP0oookJ_oonfX0QOoonfX7oh3o01Co
oo]Z0ol0oeHPoookJP;o0?;o0ooonfX01Ol0o`3ooo]Zool06?oonf[ooil000?ooo]Z01Go02Gooook
J_oonf[oo`1@oookJ_oo0;co@`3oo`1Hool0o`Co0?l1oookJ_l0oo;o0?m@oookJ_oo00coK_l0o`0I
oooonf[oW?l0oookJ_oo04800ooonfX02?l0Y?ooWOl0oookJ_oonf[oo`2Co`2doooonf[o013o1Ooo
nfX00omKo`3ooo]ZoookJP08oookJP03o`0Loooonf[ooo]Z02gooo]Z0_l000000ondo`3o0000oook
JP0SoookJP03o`07oooonf[ooo]Z02Kooo]Z00?oojL0oookJ_l0ol801ooonfX00olo0?oooo]Zoook
JP17oookJP03oolP0?oonf[ooo]Z01Oooo]Z00?oo`1CoookJ_oonfX0>OoonfX002_ooo]Z7_oo074>
oookJPKoP?l04OoonfX2o`3oEQkooo]Z0_oUo`001?l0l_ooiOl0onGo0?l0o`02oookJP05ool06?oo
nf[oU?l0oookJ_l09Ol00ooonfX02_oo053ooo]Zool0_?oonf[o05Soo`3o1?nDo`3o0?obool0Eol0
oe02odCo0006ofko0?oonf[o01Wooico0?oonf[oo`120_oonfX4onGo0006oookJ_oo09?o0;Cooook
J_l04?oooo]Z1ooUo`08oookJP03o`0Loooonf[ooo]Z02cooo]Z1_oob@0QoookJP03o`07oooonf[o
oo]Z02Kooo]Z0_oob@000ol0ol;ooo]ZoookJP05oookJP03ocl0oooonf[ooo]Z04Sooo]Z00?oob00
oookJ_oonfX05ooonfX00ooo:03ooo]ZoookJP1QoookJQkoo`1a3_oonfX6oh3o017ooo]Z0ol0oeHO
oookJP09o`3boooonf[ooo]ZoookJ_l0o`3ooo]Zool06?oonf[ooil000;ooo]Z01Go02GooookJ_oo
nf[ooo]Zool0D?oonf[oo`2lo`1HooookP3o0?l4o`3o0Ol0oo;o0?m@o`20oooo00cooo]Zofko0?l0
6OooW?l0oookJ_oo04800ooonfX02Ol0Y?oooo]Zoigo0?oonf[oo`2Co`2doooonf[o013oomWo0004
oookJP03oe_o0?oonf[ooo]Z00Sooo]Z00?o01cooookJ_oonfX0;OoonfX2o`000003okCo0?l0003o
oo]Z02;ooo]Z00?o00OooookJ_oonfX09_oonfX00oooY`3ooo]Zo`3o`P07oookJP03ocl0oooonf[o
oo]Z04Sooo]Z00?oob00oookJ_oonfX05_oonfX00ooo05?ooo]ZoookJP0joookJP009OoonfX6ool0
LAkooo]Z2_oo074:oookJPKoP?l00ooonfX2onGo00Gooo]Z0_oUo`001?oonf[o0?mFo`3oE_l0oeH7
oookJP;oiOl04OoonfX4onGo0008o`3boooUo`3oiOl0o`3o0?oonf[oo`0HoookJ_ooW`02oookJP0H
o`0Uoooonf[ooo]ZoookJ_oo053ooo]Zool0_?l0F?ooU?l0o`3o1?nDo`3o0?obool0Eol0oe3oA?l0
ofko0?oonf[o01WooookJ_nLo`3ooo]Zool0@_oonf[o0:Co0ooUo`001Ooonf[oo`2Co`2doooonf[o
013o00;ooo]Z1_oUo`08oookJP03o`0Loooonf[ooo]Z02cooo]Z1Ooob@0RoookJP03o`07oooonf[o
oo]Z02Kooo]Z0_oob@000ol0ol;ooo]ZoookJP04oookJP03ocl0oooonf[ooo]Z04Sooo]Z00?oob00
oookJ_oonfX06?oonfX00ooo:03ooo]ZoookJP0IoookJP03ooll0?oonf[ooo]Z03oooo]Z1_oo074N
oookJP_oo`1a2OoonfX6oh3o00kooo]Z0ol0oeHMoookJP08o`3boooonf[ooo]ZoookJ_l0o`3oo`0H
oookJ_ooW`03oookJP0Eo`0Uoooonf[ooo]ZoookJ_oo053oo`2loookJ_l0F?ooonh0o`3o1?l0o`7o
0?obo`3oD?l0P?ooo`0<ofko0?l06Ooooo]Zoico0?oonf[oo`1200;ooo]Z00Wo0:CooookJ_nMo`3o
oo]Zool0Tol0]?oooo]Zo`0@oooIo`001?oonfX00omKo`3ooo]ZoookJP08oookJP03o`0Loooonf[o
oo]Z02gooo]Z0_l000000ondo`3o0000oookJP0RoookJP03o`07oooonf[ooo]Z02Gooo]Z00CoojL0
oookJ_oonf[o0?o21_oonfX00olo0?oooo]ZoookJP18oookJP03oolP0?oonf[ooo]Z01Oooo]Z00?o
o`1CoookJ_oonfX06_oonfX00ooo?03ooo]ZoookJP0MoookJP00DooonfX7ool0L@Wooo]Z1?n0o`02
onGo00Cooo]Z0ooUo`03oookJP;o0?mF1OoonfX3onGo00oooo]Z1_oUo`002?l0l_ooiOl0onGo0?l0
o`3ooo]Zool06?oonf[ooil00_oonfX05Ol09Ooooo]ZoookJ_oo053ooo]Zool0_?oonf[o05Soo`3o
1?nDo`3o0?obool0Eol0P?oo0?m@odCo0?m^o`3ooo]Zo`0IoonLo`3ooo]Zool0@P02oookJP0:o`2T
oooUo`3oiOl0onGo0?oonf[oo`2Co`2doooIo`3o013ooookJPKoiOl02?oonfX00ol07?oooo]Zoook
JP0/oookJPGoolT08OoonfX00ol01ooooo]ZoookJP0VoookJP;oolT000?o0?o2oookJ_oonfX01Ooo
nfX00olo0?oooo]ZoookJP17oookJP03oolP0?oonf[ooo]Z01Sooo]Z00?oobP0oookJ_oonfX06_oo
nfX00ooo?03ooo]ZoookJP1^oookJPOoo`1a2?oonfX4oh3o00gooo]Z0_l0oeHLoookJP08o`3boooo
nf[ooo]ZoookJ_l0o`3oo`0HoookJ_ooW`03oookJP0Do`0Uoooonf[ooo]Zool0D?oonf[oo`2loook
J_l0F?oo0?l4o`3o0Ol0oo;o09[oo`3oD?oonf[oo`0<ofko0?l06OooW?l0oookJ_oo0483oookJP08
o`2ToonMo`3ooo]ZoookJ_oo09?o0;CooookJ_l04?l4oookJP03oe_o0?oonf[ooo]Z00Sooo]Z00?o
01cooookJ_oonfX0;OoonfX01?l0003o]?l0o`000?l0000RoookJP03o`07oooonf[ooo]Z02Kooo]Z
00?oojL0oookJ_l0ol801ooonfX00olo0?oooo]ZoookJP17oookJP03oolP0?oonf[ooo]Z01Oooo]Z
00?oo`1CoookJ_oonfX06ooonfX00ooo?03ooo]ZoookJP0MoookJP00F_oonfX5ool0L@Kooo]Z0_oU
o`03oh3o0003onGo0?oonf[ooo]Z00GoiOl00ooonfX3o`3oEP03oookJ_oUo`3oiOl000?oiOl04?oo
nfX5onGo0008o`3boooUo`3oiOl0o`3o0?oonf[oo`0HoookJ_ooW`02oookJP0Bo`0Uoooonf[ooo]Z
ool0D?oonf[oo`2lodCo0?l0F?oo0?l4oiCo0?l0oo;oo`1Go`3oD?oo00coK_l0oookJ_l06Ooooo]Z
0_nDo`000ooo04;ooo]Zo`2To`03onGo0005oookJ_oo09?o0;CooookJ_l04?l00_oonfX5onGo00So
oo]Z00?o01cooookJ_oUo`000_oUo`0ZoookJPCoolT000?o0000oookJ_oonfX07ooonfX00ol01ooo
oo]ZoookJP0VoookJP03ooo90?l0ol;ooo]Z00Kooo]Z00?o?`3ooookJ_oonfX0AooonfX00ooo803o
oo]ZoookJP0HoookJP03oolX0?oonf[ooo]Z01[ooo]Z00?ooc`0oookJ_oonfX0M_oonfX5ool0L@Oo
oo]Z0on0o`0<oookJP;o0?mF6ooonfX02?l0l_ooo`2/oookJ_oonf[o0?l0ool06?oonf[ooil00ooo
nfX05?l09Ooooo]ZoookJ_oo053ooo]Zool0_?m30?oo05Soo`3o1?l0o`7o0?obo`3oD?l0P?ooo`0<
ofko0?ooY03o01Wooico0?oonf[oo`120_oonfX02Ol0Y?oooo]Zoigo0?oonf[oo`2Co`2doooonf[o
013oomWo0004oookJP03oe_o0?oonf[ooo]Z00Oooo]Z00?o01cooookJ_oonfX0;OoonfX01?l0003o
]?l0o`000?l0000RoookJP03o`07oooonf[ooo]Z02Gooo]Z00?oojL0oookJ_l0ol801ooonfX00olo
0?oooo]ZoookJP17oookJP03oolP0?oonf[ooo]Z01Oooo]Z00?oo`1CoookJ_oonfX06ooonfX00ooo
?03ooo]ZoookJP0NoookJP00GooonfX4ool0L@;ooo]Z1OoUo`02oh3o00SoiOl01?oonfX00ol0oeKo
iOl0onGo0004onGo017ooo]Z1?oUo`002_l0l_ooiOl0onGo0?l0o`3ooo]Zool06?oonf[ooil0oook
J_l09Ol3oookJP0<ool0D?oonf[oo`2lo`1Hool0o`CoU?l0odCo0?l0oo;oA?l0o`3oD?oo00coK_l0
1?nDo`001?oo04;ooo]ZoookJ_l0Y?l2onGo0005oookJ_oo09?o0;CooookJ_l04?l00ooonfX4onGo
00Oooo]Z1_oUo`0ZoookJPCoolT000?o0000oookJ_oonfX07ooonfX00ol01ooooo]ZoookJP0Voook
JP03oonW0?l0ol;ooo]Z00Kooo]Z00?o?`3ooookJ_oonfX0AooonfX00ooo803ooo]ZoookJP0Goook
JP03oolX0?oonf[ooo]Z01[ooo]Z00?ooc`0oookJ_oonfX0O?oonfX4ool0L@Kooo]Z0on0o`0;oook
JP?o0?mF6OoonfX02?l0l_ooo`2/oookJ_oonf[o0?l0ool06?oonf[ooil00_oonfX05?l09Ooooo]Z
oookJ_oonf[oo`1@oookJ_oo0;co05Soo`3o1?l0o`7oool0o`3ol_l0oe3ooo]Zool03?m^o`3o01Wo
oico0?oonf[oo`120ooonfX02?l0Y?ooWOl0oookJ_oo09?o0;CooookJ_l04?oofOl01?oonfX00omK
o`3ooo]ZoookJP07oookJP03o`0Loooonf[ooo]Z02gooo]Z00Co0000okCo0?l0003o00008_oonfX0
0ol01ooooo]ZoookJP0UoookJP03oonW0?oonf[o0?o200Oooo]Z00?o?`3ooookJ_oonfX0AooonfX0
0ooo803ooo]ZoookJP0FoookJP03ool0Dooonf[ooo]Z01_ooo]Z00?ooc`0oookJ_oonfX07ooonfX0
06?ooo]Z00?oo`1aonGo0?oUo`003ooUo`03oookJPSoiOl04_oonfX3onGo0003o`3boooUo`3oiOl0
00;o0?l000Goo`0HoookJ_ooW`3ooo]Zo`0Uo`03oookJP0:ool0D?oo0;cooo]Zo`1Hool0o`CoA?l0
o`3ol_oo05Oo083oo`3oD0GoU?l000Kooo]Zool0@_oonf[o0:CooookJ_oUo`02oookJP04ool0Tol0
]?oofOl0o`0@o`;ooo]Z1?oUo`05oookJPSoiOl0:_oonfX3ooo900;o00008?oonfX00ol01ooooo]Z
oookJP0VoookJP03oonW0?l0ol;ooo]Z00Kooo]Z00?o?`3ooookJ_oonfX0AooonfX00ooo803ooo]Z
oookJP0GoookJP03oolX0?oonf[ooo]Z01[ooo]Z00?ooc`0oookJ_oonfX0POoonfX4ool0L@Gooo]Z
0on0o`0;oookJP;o0?mF6?oonfX2o`3bo`;ooo]Z00Co0?l0ool06?oonf[ooil00_oonfX05?l09Ooo
oo]ZoookJ_oo053ooo]Zool0_?oonf[o05Soo`3o1?l0o`7o0?obo`2Jool0oe3oo`0<ofko0?ooY03o
01Wooico0?oonf[oo`120_oonfX02?l0Y?oooo]Zoigo0?oonf[oo`2Co`2doooonf[o013o1?oonfX0
0omKo`3ooo]ZoookJP08oookJP03o`0Loooonf[ooo]Z02cooo]Z00Co0000okCo0?l0003o00008Ooo
nfX00ol01ooooo]ZoookJP0UoookJP03oonW0?oonf[o0?o200Oooo]Z00?o?`3ooookJ_oonfX0Aooo
nfX00ooo803ooo]ZoookJP0GoookJP03ool0Dooonf[ooo]Z01[ooo]Z00?ooc`0oookJ_oonfX08?oo
nfX006Cooo]Z4ooUo`000ooonf[oiOl0onGo0008onGo01;ooo]Z0_oUo`002_l0l_ooiOl0onGo0?oo
nf[o0?l0ool06?oonf[ooil0oookJ_l09Ol2oiCo0008ool0D?oonf[oo`2loookJ_l0F?oo0?l4odCo
0?l0oo88oiCo0005ool0@_oonf[ooo]Zo`2ToonMo`000_oonfX01?oo09?o0;CooookJ_l04?l3oook
JP?oiOl01OoonfX8onGo02[ooo]Z0ooob@03o`0001oooo]Z00?o00OooookJ_oonfX09_oonfX00ooo
Y`3o0?o2oookJP06oookJP03ocl0oooonf[ooo]Z04Kooo]Z00?oob00oookJ_oonfX05ooonfX00ooo
:03ooo]ZoookJP0JoookJP03ooll0?oonf[ooo]Z08Kooo]Z1?oo0744oookJP?oP?l02_oonfX2o`3o
EQSooo]Z00Oo0?;ooookJ_oonf[o0?l0ool06?oonf[ooil000;ooo]Z01?o02GooookJ_oonf[oo`1@
oookJ_oo0;cooo]Zo`1Hool0o`Co0?l1o`3ol_l0oe3o0?n^ool03?m^o`3o01WooookJ_nLo`3oo`12
00?ooo]Z00So0:Cooigo0?oonf[oo`2Co`2doooonf[o013oomWo00?ooo]Z00?oFol0oookJ_oonfX0
2?oonfX00ol07?oooo]ZoookJP0/oookJP03o`000?ndo`3o000000;o00008?oonfX00ol01ooooo]Z
oookJP0UoookJP03oonW0?oonf[o0?o200Kooo]Z00?o?`3ooookJ_oonfX0AooonfX00ooo803ooo]Z
oookJP0GoookJP03ool0Dooonf[ooo]Z01[ooo]Z00?ooc`0oookJ_oonfX08OoonfX006Cooo]Z7ooU
o`0CoookJP03onGo0?l0l_ooiOl000;ooo]Z00Co0?l0ool06?oonf[ooil00onDo`001ooonf[oo`1@
oookJ_oo0;cooo]Zo`3o1?ookP002OnDo`002ooonf[oo`12oookJ_l0Y?oooo]Zoigo0?oonf[oo`2C
o`2doooonf[o013o00?ooo]Z0ooUo`06oookJPOoiOl0:_oonfX2ooo900?o00007ooonfX00ol01ooo
oo]ZoookJP0VoookJP03oonW0?l0ol;ooo]Z00Kooo]Z00?o?`3ooookJ_oonfX0A_oonfX00ooo803o
oo]ZoookJP0HoookJP03oolX0?oonf[ooo]Z01Wooo]Z00?ooc`0oookJ_oonfX0RooonfX3ool0L@Co
oo]Z1?n0o`08oookJP;o0?mF5ooonfX01ol0l_oooo]ZoookJ_l0o`3oo`0HoookJ_ooW`000_oonfX0
0ol09Ooooo]Zool0D002oookJP0>ool0_?m30?oo0?l4o`3o0Ol0oo;o09[oo`3oD?oo00coK_l0oook
J_l06OooW?l0oookJ_oo0482oookJP08o`2Toooonf[oWOl0ool0Tooonf[o0;Coo`0@oooIo`03oook
JP03oe_o0?oonf[ooo]Z00Sooo]Z00?o01cooookJ_oonfX0;?oonfX01?ndo`3o0000o`000?l0000P
oookJP03o`07oooonf[ooo]Z02Gooo]Z00?oojL0oookJ_l0ol801ooonfX00olo0?oooo]ZoookJP16
oookJP03oolP0?oonf[ooo]Z01Oooo]Z00?oo`1CoookJ_oonfX06_oonfX00ooo?03ooo]ZoookJP0R
oookJP00HooonfXQonGo01Cooo]Z00Ko0?;oonGo0?oonf[ooo]Zo`3o0?oonfX5oiCo0007oookJ_oo
053ooo]Zool0_?oonf[o0?l4odCo0008oiCo0006oookJ_oo04;ooo]ZoookJ_l0Y?ooWOl00_oonfX0
1?oo09?o0;CoomWo0?l04?l3oookJP;oiOl01_oonfX7onGo02[ooo]Z0_oob@03o`0001oooo]Z00?o
00OooookJ_oonfX09_oonfX00oooY`3o0?o2oookJP06oookJP03ocl0oooonf[ooo]Z04Kooo]Z00?o
ob00oookJ_oonfX04_oonfX00ooo:03ooo]ZoookJP02oookJP03oolX0?oonf[ooo]Z01Wooo]Z00?o
oc`0oookJ_oonfX0SooonfX3ool0L@Gooo]Z0on0o`07oookJP;o0?mF5_oonfX01_l0l_oooo]Zoook
J_l0o`3ooo]ZoonO00;ooo]Z01?o02GooookJ_oonf[oo`1@oookJ_oo0;cooo]Zo`1Hool0o`Co0?l1
o`3ol_l0oe3o0?n^ool03?m^o`3o01WooookJ_nLo`3oo`1200;ooo]Z00So0:CooookJ_nMo`3ooo]Z
ool0Tol0]?oooo]Zo`0@o`Cooo]Z00?oFol0oookJ_oonfX01ooonfX00ol07?oooo]ZoookJP0/oook
JP04okCo0?l0003o0000o`00023ooo]Z00?o00OooookJ_oonfX09OoonfX00oooY`3ooo]Zo`3o`P06
oookJP03ocl0oooonf[ooo]Z04Oooo]Z00?oob00oookJ_oonfX05_oonfX00ooo05?ooo]ZoookJP0J
oookJP03ooll0?oonf[ooo]Z02?ooo]Z001/oookJPooiOl000?oP?l0oookJ_oonfX01ooUo`0Doook
JP05o`3boooUo`3ooo]ZoookJ_l0o`001OnDo`02oookJP06ool0D?oo0;cooo]ZoookJ_l0o`CoA?l0
1onDo`003?oonf[oo`12oookJ_oonf[o0:CooookJ_nMo`3ooo]Zool0Tol0]?oooo]Zo`0@o`Cooo]Z
00?oiOl0oookJ_oonfX01OoonfX6onGo02[ooo]Z00?oolT0o`000?l000000_l0000OoookJP03o`07
oooonf[ooo]Z02Gooo]Z00?oojL0o`3o`_oonfX01_oonfX00olo0?oooo]ZoookJP16oookJP03oolP
0?oonf[ooo]Z01?ooo]Z0_oo:002oookJP03oolX0?oonf[ooo]Z01[ooo]Z00?ooc`0oookJ_oonfX0
T_oonfX3ool0L@Gooo]Z0on0o`06oookJP03o`3oE_oonf[ooo]Z01Cooo]Z00Ko0?;ooookJ_oonf[o
0?l0oookJ_ooW`02oookJP0Bo`0Uoooonf[ooo]Zool0D?oonf[oo`2loookJ_l0F?oo0?l4o`3o0Ol0
oo;o0?m@ool03?m^o`3ooo]Zo`0IoonLo`3oo`120ooonfX02?l0Y?ooWOl0oookJ_oo09?o0;Cooook
J_l04?oofOl00ooonfX00omKo`3ooo]ZoookJP07oookJP03o`0Loooonf[ooo]Z02cooo]Z00Co]?l0
o`000?l0003o00008?oonfX00ol01ooooo]ZoookJP0ToookJP03oonW0?oonf[o0?o200Oooo]Z00?o
?`3ooookJ_oonfX0A_oonfX00ooo803ooo]ZoookJP0FoookJP03ool0Dooonf[ooo]Z01_ooo]Z00?o
oc`0oookJ_oonfX08ooonfX007Gooo]Z0ooo0744oookJP;oP?l00ooonfX5onGo01Cooo]Z00Go0?;o
oookJ_nDo`3oU?l0o`3o0005oiCo0008oookJ_oo053ooo]Zool0_?oonf[o0?l4o`1Hoooo05L7oiCo
000;oookJ_oo04;ooo]Zo`2Toooonf[oWOl0oookJ_oo09?o0;CooookJ_l04?l01?oonfX00omKo`3o
oo]ZoookJP05oookJPKoiOl0:_oonfX00ondo`3o0000o`000002o`0001kooo]Z00?o00OooookJ_oo
nfX09_oonfX00oooY`3o0?o2oookJP05oookJP03ocl0oooonf[ooo]Z04Kooo]Z00?oob00oookJ_oo
nfX04ooonfX5oolX01cooo]Z00?ooc`0oookJ_oonfX0U_oonfX3ool0L@Gooo]Z0_n0o`05oookJP;o
0?mF5?oonfX01ooo0:co0?;ooookJ_oonf[o0?l0oookJ_ooW`000_oonfX04_l09Ooooo]Zool0D?oo
nf[oo`2loookJ_ookP3o0?l4o`3o^Ol0oo;o083oo`3oD?oo00coK_l0o`0Ioooonf[oW?l0ool0@P;o
oo]Z00So0:CooookJ_nMo`3oo`2CoookJ_l0]?oo013oomWo00?ooo]Z00?oFol0oookJ_oonfX01ooo
nfX00ol07?oooo]ZoookJP0/oookJP04okCo0?l0003o0000o`0001oooo]Z00?o00OooookJ_oonfX0
9OoonfX00oooY`3o0?o2oookJP06oookJP03ocl0oooonf[ooo]Z04Kooo]Z00?oob00oookJ_oonfX0
5ooonfX00ooo05?ooo]ZoookJP0JoookJP03ooll0?oonf[ooo]Z02Cooo]Z001hoookJP;oo`1a1?oo
nfX2oh3o00Gooo]Z0_oUo`000ol0oeKooo]ZoookJP0AoookJP05o`3boonDo`3oU?l0oiCo0?l0o`00
1?nDo`02oookJP07ool0D?oonf[oo`2lodCo0?l0o`CoA?l0ool0E`06oiCo0006oookJ_oo04;ooo]Z
oookJ_l0Y?ooWOl00_oonfX01?oo09?o0;CoomWo0?l04?l3oookJP03oe_o0?oonf[ooo]Z00Gooo]Z
1_oUo`0ZoookJP03okCo0?l0003o000000;o00007_oonfX00ol01ooooo]ZoookJP0UoookJP03oonW
0?l0ol;ooo]Z00Kooo]Z00?o?`3ooookJ_oonfX0A_oonfX00ooo803ooo]ZoookJP0CoookJPGoobP0
6ooonfX00ooo?03ooo]ZoookJP2JoookJP;oo`1a1OoonfX2oh3o00Gooo]Z0_l0oeHCoookJP07ool0
[?l0l_oooo]ZoookJ_l0o`3ooo]ZoonO0002oookJP0Ao`0Uoooonf[oo`1@oookJ_oo0;cooo]Zo`1H
ool0o`Co0?l1o`3ol_l0oe3oo`0<ofko0?oonf[o01Wooico0?oo04800_oonfX02?l0Y?oooo]Zoigo
0?oonf[oo`2Co`2doooonf[o013o1?oonfX00omKo`3ooo]ZoookJP06oookJP03o`0Loooonf[ooo]Z
02cooo]Z00Co]?l0o`000?l0003o00007ooonfX00ol01ooooo]ZoookJP0ToookJP03oonW0?oonf[o
0?o200Kooo]Z00?o?`3ooookJ_oonfX0A_oonfX00ooo803ooo]ZoookJP0GoookJP03ool0Dooonf[o
oo]Z01[ooo]Z00?ooc`0oookJ_oonfX09OoonfX007[ooo]Z0ooo0743oookJP03oh3o0?oonf[ooo]Z
00Gooo]Z00?o0?mFoookJ_oonfX04OoonfX01?l0l_ooU?l0oiCo0?l0o`05oiCo00;ooo]Z00Ooo`1@
odCo0?oo0;co0?l4o`1Hooooo`3o0?ob00GoU?l000coW?l0oookJ_oo04;ooo]Zo`2Toooonf[oWOl0
oookJ_oo09?o0;CooookJ_l04?l4oookJP03oe_o0?oonf[ooo]Z00Gooo]Z1?oUo`0ZoookJP03okCo
0?oonf[o000000?o00007OoonfX00ol01ooooo]ZoookJP0VoookJP03oonW0?l0ol;ooo]Z00Gooo]Z
00?o?`3ooookJ_oonfX0A_oonfX00ooo803ooo]ZoookJP0CoookJPOoobP06OoonfX00ooo?03ooo]Z
oookJP2MoookJP?oo`1a1?oonfX00on0o`3ooo]ZoookJP04oookJP03o`3oE_oonf[ooo]Z017ooo]Z
00Oo0?;ooookJ_oonf[o0?l0ool06?oonf[ooil000;ooo]Z017o02GooookJ_oo053ooo]Zool0_?oo
nf[o0?l4o`3o^Ol0oo;o09[oo`3oD?oo00coK_l0o`0IooooY03oW?l0ool0@P02oookJP07o`2ToonM
o`3ooo]Zool0Tooonf[o0;Coo`0@o`04oookJP03oe_o0?oonf[ooo]Z00Oooo]Z00?o01cooookJ_oo
nfX0:_oonfX00ondo`3o0000o`000002o`0001kooo]Z00?o00OooookJ_oonfX09OoonfX00oooY`3o
0?o2oookJP06oookJP03ocl0oooonf[ooo]Z04Kooo]Z00?oob00oookJ_oonfX05_oonfX00ooo05?o
oo]ZoookJP0JoookJP03ooll0?oonf[ooo]Z02Kooo]Z001moookJP;oo`1a0_oonfX2oh3o00Kooo]Z
0_l0oeHBoookJP04o`3boonDo`3oU?l0o`3o00CoU?l000Oo02GooookJ_m4o`3oo`1@ool0_?m4o`3o
0?l400?o0?l<1OnDo`002ol0o`coo`12oookJ_oonf[o0:Cooigo0?oonf[oo`2Co`2doooonf[o013o
00Cooo]Z00?oFol0oookJ_oonfX01OoonfX4onGo02[ooo]Z00?o]?l0oookJ_l000000ol0000Moook
JP03o`07oooonf[ooo]Z02Gooo]Z00?oojL0o`3o`_oonfX01_oonfX00olo0?oooo]ZoookJP15oook
JP03oolP0?oonf[ooo]Z01Cooo]Z2?oo:00GoookJP03ooll0?oonf[ooo]Z0:7ooo]Z0_oo0743oook
JP;oP?l01OoonfX2o`3oEQ;ooo]Z00Oo0?;ooookJ_oonf[o0?l0ool06?oonf[ooil000;ooo]Z013o
02GooookJ_oo053oo`2loookJ_ookP3o0?l4oooo0?l0oo;o0?m@ool03?m^o`3ooo]Zo`0IoonLo`3o
o`120_oonfX02?l0Y?oooo]Zoigo0?oonf[oo`2Co`2dool04?oofOl00ooonfX00omKo`3ooo]Zoook
JP07oookJP03o`0Loooonf[ooo]Z02[ooo]Z00?o]?l0o`000?l000000_l0000NoookJP03o`07oooo
nf[ooo]Z02Cooo]Z00?oojL0oookJ_l0ol801_oonfX00olo0?oooo]ZoookJP16oookJP03oolP0?oo
nf[ooo]Z01Kooo]Z00?oo`1CoookJ_oonfX06_oonfX00ooo?03ooo]ZoookJP0WoookJP00OooonfX2
ool0L@;ooo]Z0_n0o`06oookJP;o0?mF4OoonfX01?l0l_oooo]ZoiCo0?l0o`04oiCo0008o`0Uoooo
nf[oo`1@odCo0?oo0;co0?l<o`3o1?l0o``6oiCo000<oico0?oonf[oo`12oookJ_l0Y?oooo]Zoigo
0?oonf[oo`2Co`2doooIo`3o013o0ooonfX00omKo`3ooo]ZoookJP06oookJP?oiOl0:_oonfX00ond
o`3ooo]Zo`000003o`0001gooo]Z00?o00OooookJ_oonfX09?oonfX00oooY`3ooo]Zo`3o`P06oook
JP03ocl0oooonf[ooo]Z04Gooo]Z00?oob00oookJ_oonfX05?oonfX7oolX01Sooo]Z00?ooc`0oook
J_oonfX0Y?oonfX2ool0L@?ooo]Z0_n0o`05oookJP;o0?mF4OoonfX01ol0l_oooo]ZoookJ_l0o`3o
o`0HoookJ_ooW`000_oonfX06Ol09Ooooo]Zool0D?oo0;cooo]Zo`1Hool0o`Co0?l1o`3ol_l0oe3o
o`0<ofko0?l06OooW?l0oookJ_oo04;ooo]Zo`2Toooonf[oWOl0oookJ_oo09?ooo]Zo`2dool04?l0
1?oonfX00omKo`3ooo]ZoookJP06oookJP03o`0Loooonf[ooo]Z02[ooo]Z00?o]?l0o`000?l00000
0_l0000MoookJP03o`07oooonf[ooo]Z02Cooo]Z00?oojL0oookJ_l0ol801ooonfX00olo0?oooo]Z
oookJP15oookJP03oolP0?oonf[ooo]Z01Oooo]Z00?oo`1CoookJ_oonfX06OoonfX00ooo?03ooo]Z
oookJP0XoookJP00POoonfX3ool0L@03oookJ_n0o`3oP?l000Kooo]Z00?o0?mFoookJ_oonfX03ooo
nfX01?l0l_oooo]ZoiCo0?l0o`03oiCo0006oookJ_l09Ooooo]Zool0D?m4o`3oo`2l2?nDo`000onL
o`3ooo]Zool0@P02oookJP07o`2ToonMo`3ooo]Zool0Tol0]?oooo]Zo`0@o`03oookJP03oe_o0?oo
nf[ooo]Z00Kooo]Z0ooUo`0ZoookJP03okCo0?oonf[o000000?o00007?oonfX00ol01ooooo]Zoook
JP0UoookJP03oonW0?l0ol;ooo]Z00Kooo]Z00?o?`3ooookJ_oonfX0AOoonfX00ooo803ooo]Zoook
JP0DoookJPKoobP06OoonfX00ooo?03ooo]ZoookJP2VoookJP?oo`1a0_oonfX2oh3o00Gooo]Z00?o
0?mFoookJ_oonfX03ooonfX01ol0l_oooo]ZoookJ_l0o`3oo`0HoookJ_ooW`000_oonfX03ol09Ooo
oo]Zool0D?oo0;co@`3oo`3o1?ooo`3o0?obo`3oD?oo00coK_l0oookJ_l06OooW?l0ool0@P02oook
JP07o`2ToonMo`3ooo]ZoookJ_oo09?o0;Coo`0@o`04oookJP03oe_o0?oonf[ooo]Z00Kooo]Z00?o
01cooookJ_oonfX0:_oonfX00ondo`3o0000o`000002o`0001gooo]Z00?o00OooookJ_oonfX09?oo
nfX00oooY`3o0?o2oookJP06oookJP03ocl0oooonf[ooo]Z04Gooo]Z00?oob00oookJ_oonfX05ooo
nfX00ooo05?ooo]ZoookJP0JoookJP03ooll0?oonf[ooo]Z02Sooo]Z000moookJQ_o0>_o;?oonfX2
ool0L@04oookJ_n0o`3oP?l0oh3o00Cooo]Z0_l0oeH@oookJP03o`3boooonf[o0?l000CoU?l00_oU
o`000ooonf[oo`1@oiCo0008oiCo000<o`3o3?nLo`3ooo]Zool0@_oonf[o0:CooookJ_nMo`3oo`2C
o`2doooonf[o013o0ooonfX00omKo`3ooo]ZoookJP07oookJP;oiOl0:OoonfX00ondo`3ooo]Zoook
JP04o`0001cooo]Z00?o00OooookJ_oonfX09?oonfX00oooY`3o0?o2oookJP06oookJP03ocl0oooo
nf[ooo]Z04Gooo]Z00?oob00oookJ_oonfX05?oonfX6oolX01Wooo]Z00?ooc`0oookJ_oonfX0Hooo
nfXKo`3[obcooo]Z0_oo0742oookJP;oP?l01?oonfX2o`3oEQ3ooo]Z00Oo0?;ooookJ_oonf[o0?l0
ool06?oonf[ooil000;ooo]Z01Oo02GooookJ_oo053oo`2lo`1Hool0o`Coool0o`3ol_l0oe3oo`0<
ofko0?l06OooW?l0oookJ_oo04;ooo]Zo`2Toooonf[oWOl0oookJ_oo09?o0;Coo`0@o`04oookJP03
oe_o0?oonf[ooo]Z00Kooo]Z00?o01cooookJ_oonfX0:OoonfX00ondo`3ooo]Zo`000003o`0001co
oo]Z00?o00OooookJ_oonfX09?oonfX00oooY`3ooo]Zo`3o`P06oookJP03ocl0oooonf[ooo]Z04Go
oo]Z00?oob00oookJ_oonfX05ooonfX00ooo05?ooo]ZoookJP0JoookJP03ooll0?oonf[ooo]Z02Wo
oo]Z000UoookJPGoolT02ooonfX8o`3[oa_ooo]Z3?l0jolRoookJP;oo`1a0_oonfX2oh3o00Cooo]Z
0_l0oeH?oookJP03o`3boooonf[o0?l000;oU?l00ooUo`000ooonf[oU?l0oiCo0006oiCo0004o`3o
3?nDo`3oU?l0oico00;ooo]Z00Woo`12o`2Toooonf[oWOl0oookJ_oo09?o0;CoomWo0?l04?l00ooo
nfX00omKo`3ooo]ZoookJP06oookJP;oiOl0:OoonfX00ondo`3ooo]ZoookJP05o`0001[ooo]Z00?o
00OooookJ_oonfX09OoonfX00oooY`3o0?o2oookJP06oookJP03ocl0oooonf[ooo]Z04Cooo]Z00?o
ob00oookJ_oonfX05OoonfX4oolX01[ooo]Z00?ooc`0oookJ_oonfX0G?oonfX8o`3[oa_ooo]Z3Ol0
jolQoookJP;oo`1a0_oonfX2oh3o00Cooo]Z0_l0oeH?oookJP0Eo`3boooonf[ooo]Zo`3o0?oo01So
oo]ZoonO0?oonf[o02GooookJ_oo053oo`2loookJ_l0o`Co0?nio`3ol_l0oe3o083oofko0?oonf[o
W?l000;ooo]Z00Coo`12oookJ_l0Y?ooWOl00_oonfX00ooo09?o0;Coo`0@o`04oookJP03oe_o0?oo
nf[ooo]Z00Kooo]Z00?o01cooookJ_oonfX0:?oonfX00ondo`3ooo]Zo`000004o`0001_ooo]Z00?o
00OooookJ_oonfX09?oonfX00oooY`3o0?o2oookJP06oookJP03ocl0oooonf[ooo]Z04Gooo]Z00?o
ob00oookJ_oonfX05_oonfX00ooo05?ooo]ZoookJP0JoookJP03ooll0?oonf[ooo]Z02[ooo]Z000U
oookJPgoolT00ol0jol_oookJPWo0>_o6ooonfX2ool0L@;ooo]Z0_n0o`04oookJP;o0?mF3_oonfX0
0ol0l_oooo]Zo`3o0005onGo0003oookJ_nDo`3oU?l000KoU?l000ko0?l<oiCo0?l0o`coW?l0oook
J_oo04;ooo]Zo`2ToonMo`3ooo]Zool0Tol0]?oooo]Zo`0@o`?ooo]Z00?oFol0oookJ_oonfX01_oo
nfX2onGo02Wooo]Z00?o]?l0oookJ_oonfX01?l0000KoookJP03o`07oooonf[ooo]Z02Cooo]Z00?o
ojL0o`3o`_oonfX01_oonfX00olo0?oooo]ZoookJP15oookJP03oolP0?oonf[ooo]Z01Cooo]Z1?oo
:00JoookJP03ooll0?oonf[ooo]Z05Kooo]Z1ol0jol`oookJPWo0>_o6_oonfX2ool0L@;ooo]Z0_n0
o`04oookJP;o0?mF3_oonfX06_l0l_oooo]ZoookJ_l0o`3oo`0HoookJ_ooW`3ooo]Zo`0Uoooonf[o
o`1@ool0_?m30?oo0?l4o`3o^Ol0oo;o0?m@ool03?m^o`3o01Wooico0?oonf[oo`12oookJ_l0Y?oo
WOl00_oonfX00ooo09?o0;Coo`0@o`04oookJP03oe_o0?oonf[ooo]Z00Kooo]Z00?o01cooookJ_oo
nfX0:?oonfX00ondo`3ooo]Zo`000003o`0001_ooo]Z00?o00OooookJ_oonfX09?oonfX00oooY`3o
oo]Zo`3o`P06oookJP03ocl0oooonf[ooo]Z04Gooo]Z00?oob00oookJ_oonfX05_oonfX00ooo05?o
oo]ZoookJP0JoookJP03ooll0?oonf[ooo]Z02_ooo]Z000UoookJP_oolT0?OoonfX5o`3[oaSooo]Z
0_oo0742oookJP;oP?l01?oonfX2o`3oEPcooo]Z00?o0?;oool0[?oUo`001OoUo`000ol09Ooooo]Z
oiCo0006oiCo0004o`3o3?m^o`3o0?l<oico00;ooo]Z00Soo`12o`2Toooonf[oWOl0oookJ_l0]?oo
oo]Zo`0@o`?ooo]Z00?oFol0oookJ_oonfX01ooonfX00ooUo`3ooo]ZoookJP0WoookJP03okCo0?oo
nf[ooo]Z00Co00006ooonfX00ol01ooooo]ZoookJP0ToookJP03oonW0?l0ol;ooo]Z00Gooo]Z00?o
?`3ooookJ_oonfX0AOoonfX00ooo803ooo]ZoookJP0EoookJP?oobP06_oonfX00ooo?03ooo]Zoook
JP1AoookJPKo0>_o@?oonfX5o`3[oaOooo]Z0ooo07400ooonf[oP?l0oh3o0004oookJP;o0?mF3Ooo
nfX05?l0l_oooo]Zo`3o0?oonf[oo`0HoookJ_ooW`3ooo]Zo`0Uoooonf[oo`1@ool0_?l0F?oo0?l4
o`3o0Ol0oe3o083oofko0?oonf[oW?l00_oonfX01?oo04;ooo]Zo`2ToonMo`02oookJP03o`2dool0
4?oooo]Z00?ooo]Z00?oFol0oookJ_oonfX01_oonfX00ol07?oooo]ZoookJP0XoookJP03okCo0?oo
nf[o000000?o00006ooonfX00ol01ooooo]ZoookJP0ToookJP03oonW0?l0ol;ooo]Z00Kooo]Z00?o
?`3ooookJ_oonfX0A?oonfX00ooo803ooo]ZoookJP0GoookJP03ool0Dooonf[ooo]Z01Wooo]Z00?o
oc`0oookJ_oonfX0;?oonfX002Gooo]Z2Ooob@14oookJPGo0>_o3?oonfX2onGo00Oooo]Z0_oo0742
oookJP;oP?l01?oonfX2o`3oEP_ooo]Z00?o0?;oonGo0?oUo`001OoUo`000ol09OooA?l0oiCo0005
oiCo00;o0?l<00goK_l0o`3o3?nLo`3ooo]Zool0@_l0Y?oooo]Zoigo0?oonf[oo`2Co`2doooonf[o
013o00;oU?l000?ooo]Zoe_o0?oonfX01ooonfX00ol07?oooo]ZoookJP0VoookJP04okCo0?oonf[o
oo]ZoookJPCo00006_oonfX00ol01ooooo]ZoookJP0ToookJP03oonW0?l0ol;ooo]Z00Kooo]Z00?o
?`3ooookJ_oonfX0A?oonfX00ooo803ooo]ZoookJP0EoookJP;oobP06ooonfX00ooo?03ooo]Zoook
JP1?oookJP?o0>_oBooonfX5o`3[oaGooo]Z0_oo07400ooonf[oP?l0oh3o0004oookJP;o0?mF3?oo
nfX06Ol0l_oooo]Zo`3o0?oonf[oo`0HoookJ_ooW`3ooo]Zo`0Uoooo053oo`2lod<0ool0o`Co0?ni
o`3ol_l0oe3oo`0<ofko0?oonf[oW?l0oookJ_oo04;ooo]Zo`2ToonMo`000_oonfX00ooo09?o0;Co
o`0@o`03oookJP03oe_o0?oonf[ooo]Z00Kooo]Z00?o01cooookJ_oonfX09ooonfX00ondo`3ooo]Z
oookJP04o`0001_ooo]Z00?o00OooookJ_oonfX08ooonfX00oooY`3ooo]Zo`3o`P06oookJP03ocl0
oooonf[ooo]Z04Cooo]Z00?oob00oookJ_oonfX05ooonfX00ooo05?ooo]ZoookJP0IoookJP03ooll
0?oonf[ooo]Z02gooo]Z000UoookJPOoolT0BooonfX3o`3[o`Wooo]Z0ooUo`08oookJP;oo`1a0_oo
nfX2oh3o00Cooo]Z00?o0?mFoookJ_oonfX01ooonfX2onGo0003o`3boooUo`3oiOl000CoiOl00om4
o`06oiCo000;o`3o3?m^o`3o0?l<oico0?l0o`cooo]Zool0@_l0Y?ooWOl0oookJ_oo09<00_nDo`00
1Ol04?ooU?l0oiCo0?oonf[oFol000Sooo]Z00?o01cooookJ_oonfX09_oonfX01?ndo`3ooo]Zoook
J_oonfX4o`0001[ooo]Z00?o00OooookJ_oonfX09?oonfX00oooY`3o0?o2oookJP05oookJP03ocl0
oooonf[ooo]Z04Cooo]Z00?oob00oookJ_oonfX05_oonfX00ooo:03ooo]ZoookJP0IoookJP03ooll
0?oonf[ooo]Z0:?ooo]Z0ol0jolDoookJP;oo`1a00?ooo]Zoh3o0?n0o`001?oonfX00ol0oeKooo]Z
oookJP0:oookJP0Co`3boooonf[o0?l0ool06?oonf[ooil0oookJ_l09Ooooo]Zool0D?oo0;co@`3o
o`3o1?l0okWo0?obo`3oD?m^o`3ooo]Zoico0002oookJP03ool0@_oonf[oWOl000;ooo]Z00?oo`2C
o`2dool04?l01?oonfX00omKo`3ooo]ZoookJP05oookJP03o`0Loooonf[ooo]Z02Oooo]Z00?o]?l0
oookJ_oonfX01?l0000JoookJP03o`07oooonf[ooo]Z02Cooo]Z00?oojL0o`3o`_oonfX01OoonfX0
0olo0?oooo]ZoookJP15oookJP03oolP0?oonf[ooo]Z01Kooo]Z00?oo`1CoookJ_oonfX06OoonfX0
0ooo?03ooo]ZoookJP0^oookJP009OoonfX4ooo9057ooo]Z0ol0jol5oookJPKoiOl02?oonfX2ool0
L@;ooo]Z0_n0o`03oookJP03o`3oE_oonf[ooo]Z00Sooo]Z00?oiOl0o`3boooUo`001OoUo`03odCo
00GoU?l00_l0o``02?m^o`3o01WoodCo0?m4o`3oo`12o`2Toooonf[oWOl00onDo`001OoIo`3o013o
oiCo0?oonf[oFol000Sooo]Z00?o01cooookJ_oonfX09_oonfX01?ndo`3ooo]ZoookJ_oonfX4o`00
01Wooo]Z00?o00OooookJ_oonfX09?oonfX00oooY`3o0?o2oookJP06oookJP03ocl0oooonf[ooo]Z
04Cooo]Z00?oob00oookJ_oonfX05OoonfX00ooo:03ooo]ZoookJP0JoookJP03ooll0?oonf[ooo]Z
0:Kooo]Z0ol0jolCoookJP;oo`1a00?ooo]Zoh3o0?n0o`000ooonfX2o`3oEP_ooo]Z01So0?;ooook
J_l0o`3oo`0HoookJ_ooW`3ooo]Zo`0Uoooonf[oo`1@ool0_?l0o`Co0?nio`3ol_oo05Oo0?m@ofko
0?oonf[oW?l0oookJ_oo04;ooo]Zo`2ToonMo`02oookJP03ool0TooIo`3o013o00?ooo]Z00?oFol0
oookJ_oonfX01_oonfX00ol07?oooo]ZoookJP0VoookJP03okCo0?oonf[ooo]Z00Co00006_oonfX0
0ol01ooooo]ZoookJP0SoookJP03oonW0?l0ol;ooo]Z00Kooo]Z00?o?`3ooookJ_oonfX0A?oonfX0
0ooo803ooo]ZoookJP0FoookJP03ool0Dooonf[ooo]Z01[ooo]Z00?ooc`0oookJ_oonfX0;_oonfX0
02Gooo]Z0_oob@1FoookJPCo0>_o00?ooo]ZonGo0?oUo`001OoUo`09oookJP;oo`1a0_oonfX01On0
o`3ooo]ZoookJ_oonf[o0?mF00[ooo]Z00?oiOl0o`3boooUo`001?oUo`001?oonf[oA?l0odCo0?m4
o`04oiCo00;o0?l<00SoA?l0ofko0?m4o`3oA?l0ool0@_nDo`3o0:Cooigo00CoU?l000Go013ooiCo
0?oonf[ooo]Zoe_o0007oookJP03o`0Loooonf[ooo]Z02Kooo]Z00Co]?l0oookJ_oonf[ooo]Z1?l0
000IoookJP03o`07oooonf[ooo]Z02Cooo]Z00?oojL0o`3o`_oonfX01OoonfX00olo0?oooo]Zoook
JP14oookJP03oolP0?oonf[ooo]Z01Kooo]Z00?oo`1CoookJ_oonfX06OoonfX00ooo?03ooo]Zoook
JP2ZoookJPCo0>_o4OoonfX01?oo077ooo]ZoookJ_n0o`04oookJP03o`3oE_oonf[ooo]Z00Wooo]Z
01Oo0?;ooookJ_l0o`3oo`0HoookJ_ooW`3ooo]Zo`0Uoooo053ooo]Zool0_?l0o`Co0?nio`3ol_l0
oe3oo`0<ofko0?l06OooW?l0oookJ_oo04;ooo]Zoigo0002oookJP03ool0Tol0]?oo013o00?ooo]Z
00?oFol0oookJ_oonfX01_oonfX00ol07?oooo]ZoookJP0VoookJP03okCo0?oonf[ooo]Z00Co0000
6OoonfX00ol01ooooo]ZoookJP0ToookJP03oonW0?l0ol;ooo]Z00Gooo]Z00?o?`3ooookJ_oonfX0
A?oonfX00ooo803ooo]ZoookJP0GoookJP03ool0Dooonf[ooo]Z01Wooo]Z00?ooc`0oookJ_oonfX0
;ooonfX0087ooo]Z2_oUo`09oookJP;oo`1a00?ooo]Zoh3o0?n0o`000_oonfX00ol0oeKooo]Zoook
JP09oookJPKoiOl01?m4o`04oiCo00;o0?l<00SoK_l0odCo0?m4o`3oU?l0ool0@_l0Y?ooU?l0oigo
00?oU?l000Go013ooiCo0?nDo`3ooo]Zoe_o0008oookJP03o`0Loooonf[ooo]Z02Gooo]Z00Co]?l0
oookJ_oonf[ooo]Z1?l0000IoookJP03o`07oooonf[ooo]Z02?ooo]Z00?oojL0o`3o`_oonfX01_oo
nfX00olo0?oooo]ZoookJP13oookJP03oolP0?oonf[ooo]Z01Kooo]Z00?oo`1CoookJ_oonfX06Ooo
nfX00ooo?03ooo]ZoookJP2_oookJP?o0>_o3ooonfX2ool0L@03oookJ_n0o`3oP?l000?ooo]Z00?o
0?mFoookJ_oonfX02OoonfX06ol0l_oooo]Zo`3o0?oo01Sooo]ZoonO0?l09Ooooo]Zool0D?oonf[o
o`2lo`3o1?ooo`3o0?obo`3oD?m^o`3ooo]Zoico0?oonf[oo`12oookJ_l0Y?ooWOl0oookJ_oo09?o
0;Coo`0@o`03oookJP03oe_o0?oonf[ooo]Z00Kooo]Z00?o01cooookJ_oonfX09_oonfX00ondo`3o
oo]ZoookJP04o`0001Wooo]Z00?o00OooookJ_oonfX08ooonfX00oooY`3o0?o2oookJP06oookJP03
ocl0oooonf[ooo]Z04?ooo]Z00?oob00oookJ_oonfX05ooonfX00ooo05?ooo]ZoookJP0IoookJP03
ooll0?oonf[ooo]Z033ooo]Z0021oookJP_oiOl02_oonfX2ool0L@04oookJ_n0o`3ooo]ZoookJP;o
0?mF2?oonfX6onGo00KoA?l00onDo`001?m4o`3o0?l<odCo0?m^o`02odCo0004ool0@_nDo`3o0:Co
oigo00?oU?l000GofOl0o`0@oonDo`3ooo]Zoe_o0008oookJP03o`0Loooonf[ooo]Z02Cooo]Z00?o
]?l0oookJ_oonfX00_oonfX4o`0001Sooo]Z00?o00OooookJ_oonfX09?oonfX00oooY`3o0?o2oook
JP05oookJP03ocl0oooonf[ooo]Z04Cooo]Z00?oob00oookJ_oonfX05OoonfX00ooo05?ooo]Zoook
JP0IoookJP03ooll0?oonf[ooo]Z0;?ooo]Z0ol0jol>oookJP;oo`1a00?ooo]Zoh3o0?oonfX00_oo
nfX2o`3oEP[ooo]Z01Ko0?;oo`3o0?oonf[oo`0HoonO0?oonf[o02GooookJ_oo053o@`3oo`1Hool0
o`Co0?obo`20ool0oe3oK_l0o`0IoonLo`3ooo]Zool0@_oonf[oWOl00_oonfX00ooo09?ofOl0o`0@
o`02oookJP03oe_o0?oonf[ooo]Z00Kooo]Z00?o01cooookJ_oonfX09OoonfX01?ndo`3ooo]Zoook
J_oonfX4o`0001Sooo]Z00?o00OooookJ_oonfX09?oonfX00oooY`3o0?o2oookJP05oookJP03ocl0
oooonf[ooo]Z04Cooo]Z00?oob00oookJ_oonfX05_oonfX00ooo05?ooo]ZoookJP0IoookJP03ooll
0?oonf[ooo]Z037ooo]Z0021oookJPcoiOl02ooonfX00ooo077ooo]Zoh3o0003oookJP03o`3oE_oo
nf[ooo]Z00Cooo]Z2OoUo`05odCo00;oU?l000CoA?l0o`3oD?m4o`3oK_l00_m4o`001Ooo04;oU?l0
oookJ_l0Y?ooWOl000?oU?l000Go013ooiCo0?oonf[ooo]Zoe_o0007oookJP03o`0Loooonf[ooo]Z
02Cooo]Z00?o]?l0oookJ_oonfX00_oonfX4o`0001Sooo]Z00?o00OooookJ_oonfX08ooonfX00ooo
Y`3o0?o2oookJP05oookJP03ocl0oooonf[ooo]Z04Cooo]Z00?oob00oookJ_oonfX05OoonfX00ooo
05?ooo]ZoookJP0IoookJP03ooll0?oonf[ooo]Z0;Oooo]Z0_l0jol>oookJP03ool0LOoonf[oP?l0
00Cooo]Z00?o0?mFoookJ_oonfX02?oonfX06_l0l_oo0?l0oookJ_oo01Sooil0oookJ_l09Ooooo]Z
ool0D?oo0;co0?l4o`3o^Ol0oo;o0?m@ofko0?ooY03oW?l0oookJ_oo04;ooo]Zo`2ToonMo`3ooo]Z
ool0Tol0]?oo013o0ooonfX00omKo`3ooo]ZoookJP05oookJP03o`0Loooonf[ooo]Z02Gooo]Z00Co
]?l0oookJ_oonf[ooo]Z1?l0000HoookJP03o`07oooonf[ooo]Z02?ooo]Z00?oojL0o`3o`_oonfX0
1OoonfX00olo0?oooo]ZoookJP14oookJP03oolP0?oonf[ooo]Z01Kooo]Z00?oo`1CoookJ_oonfX0
6OoonfX00ooo?03ooo]ZoookJP0boookJP00P?oonfX?onGo00[ooo]Z0_oo0742oh3o00;ooo]Z0_l0
oeH6oookJPOoiOl000?ooil0odCo0?m4o`000om4o`02oiCo000:odCo0?l0oe3oA?l0ofko0?m4o`3o
W?l0ool0@_nDo`3o0:Cooigo00?oU?l000Go013ooiCo0?oonf[ooo]Zoe_o0007oookJP03o`0Loooo
nf[ooo]Z02Cooo]Z00?o]?l0oookJ_oonfX00_oonfX4o`0001Oooo]Z00?o00OooookJ_oonfX08ooo
nfX00oooY`3ooo]Zo`3o`P06oookJP03ocl0oooonf[ooo]Z04?ooo]Z00?oob00oookJ_oonfX05Ooo
nfX00ooo05?ooo]ZoookJP0IoookJP03ooll0?oonf[ooo]Z0;[ooo]Z0ol0jol<oookJP;oo`1a0_n0
o`03oookJP03o`3oE_oonf[ooo]Z00Sooo]Z01Wo0?;oo`3o0?oo01Sooo]ZoonO0?oonf[o02Goool0
D?oonf[o05Soo`3o1?l0oo;oo`1Go`3oD?m^o`3ooj@0oico0?oonf[oo`12o`2Toooonf[oWOl0oook
J_l0]?oo013o00?ooo]Z00?oFol0oookJ_oonfX01_oonfX00ol07?oooo]ZoookJP0ToookJP04okCo
0?oonf[ooo]ZoookJPCo00005ooonfX00ol01ooooo]ZoookJP0SoookJP03oonW0?oonf[o0?o200Ko
oo]Z00?o?`3ooookJ_oonfX0@ooonfX00ooo803ooo]ZoookJP0FoookJP03ool0Dooonf[ooo]Z01Wo
oo]Z00?ooc`0oookJ_oonfX0<ooonfX008Gooo]Z2ooUo`0;oookJP03ool0LOoonf[oP?l000?ooo]Z
00?o0?mFoookJ_oonfX01?oonfX7onGo0003oookJ_m4o`3oA?l000?oA?l000SoU?l0odCo0?l0oe3o
A?l0ofko0?m4o`3oW?l0ool0@P;oU?l000?oWOl0oiCo0?nDo`000_nDo`001?l04?oooo]ZoookJ_mK
o`07oookJP03o`0Loooonf[ooo]Z02Cooo]Z00?o]?l0oookJ_oonfX00_oonfX5o`0001Kooo]Z00?o
00OooookJ_oonfX08ooonfX00oooY`3o0?o2oookJP05oookJP03ocl0oooonf[ooo]Z04?ooo]Z00?o
ob00oookJ_oonfX05OoonfX00ooo05?ooo]ZoookJP0JoookJP03ooll0?oonf[ooo]Z0;gooo]Z0ol0
jol;oookJP03ool0LOoonf[oP?l000?ooo]Z00?o0?mFoookJ_oonfX02?oonfX01?l0l_oo0?l0ool0
6?ooW`02oookJP0Co`0Uoooo053oo`2lo`1Hool0o`Co0?obo`3oD?m^o`3ooj@0oico0?oonf[oo`12
oookJ_l0Y?ooWOl0oookJ_oo09?o0;Coo`0@o`02oookJP03oe_o0?oonf[ooo]Z00Kooo]Z00?o01co
oookJ_oonfX09?oonfX01?ndo`3ooo]ZoookJ_oonfX5o`0001Kooo]Z00?o00OooookJ_oonfX08ooo
nfX00oooY`3o0?o2oookJP05oookJP03ocl0oooonf[ooo]Z04?ooo]Z00?oob00oookJ_oonfX05_oo
nfX00ooo05?ooo]ZoookJP0JoookJP03ooll0?oonf[ooo]Z03?ooo]Z002=oookJPCoiOl000?o0>_o
oookJ_oonfX02?oonfX00ooo077ooo]Zoh3o0003oookJP03o`3oE_oonf[ooo]Z00Gooo]Z1OoUo`00
0ooo01Sooo]ZodCo0003odCo0003o`3o1?l0F?ooA?l000;oA?l000CoK_l0odCo0?nDo`3oo`120_nD
o`002?nMo`3oU?l0oiCo0?nDo`3o013ooiCo0?oonf[oFol01ooonfX00ol07?oooo]ZoookJP0Toook
JP03okCo0?oonf[ooo]Z00;ooo]Z1?l0000GoookJP03o`07oooonf[ooo]Z02;ooo]Z00?oojL0o`3o
`_oonfX01_oonfX00olo0?oooo]ZoookJP13oookJP03oolP0?oonf[ooo]Z01Gooo]Z00?oo`1Coook
J_oonfX06OoonfX00ooo?03ooo]ZoookJP31oookJP;o0>_o2_oonfX01?oo077ooo]Zoh3o0?n0o`02
oookJP03o`3oE_oonf[ooo]Z00Sooo]Z00Co0?;oo`3o0?oo01Sooil00_oonfX04_l09Oooo`1@ool0
_?l0o`Coool0o`3ol_l0oe3oK_l0oonT0?nLo`3ooo]Zool0@_l0Y?oooo]Zoigo0?oonf[o0;Coo`0@
o`?ooo]Z00?oFol0oookJ_oonfX01OoonfX00ol07?oooo]ZoookJP0ToookJP04okCo0?oonf[ooo]Z
oookJPCo00005ooonfX00ol01ooooo]ZoookJP0RoookJP03oonW0?l0ol;ooo]Z00Kooo]Z00?o?`3o
oookJ_oonfX0@ooonfX00ooo803ooo]ZoookJP0FoookJP03ool0Dooonf[ooo]Z01Wooo]Z00?ooc`0
oookJ_oonfX0=?oonfX009;ooo]Z0_l0jol9oookJP;oo`1a00CoP?l0oookJ_oonf[ooo]Z0_l0oeH6
oookJPGoiOl000?oo`0HodCo0?m4o`000om4o`000ol0o`CoA?l0odCo0002odCo0003ofko0?nDo`3o
o`1200;oU?l000KoWOl0oiCo0?nDo`3oU?l0o`0@oonDo`02oookJP03oe_o0?oonf[ooo]Z00Cooo]Z
00?o01cooookJ_oonfX09?oonfX00ondo`3ooo]ZoookJP02oookJPCo00005_oonfX00ol01ooooo]Z
oookJP0SoookJP03oonW0?l0ol;ooo]Z00Gooo]Z00?o?`3ooookJ_oonfX0@ooonfX00ooo803ooo]Z
oookJP0EoookJP03ool0Dooonf[ooo]Z01Wooo]Z00?ooc`0oookJ_oonfX0a?oonfX2o`3[o`Wooo]Z
0_oo07401?oonf[oP?l0oookJ_oonfX2o`3oEPSooo]Z01Wo0?;oool0[?l0o`3oo`0HoonO0?oonf[o
02Goool0D?oonf[o05Soo`3o1?l0oo;o0?m@o`20oom^o`3o01Wooico0?oo04;ooo]Zo`2ToonMo`3o
oo]Zo`2doooIo`3o013o00;ooo]Z00?oFol0oookJ_oonfX01OoonfX00ol07?oooo]ZoookJP0Toook
JP04okCo0?oonf[ooo]ZoookJPCo00005_oonfX00ol01ooooo]ZoookJP0SoookJP03oonW0?l0ol;o
oo]Z00Gooo]Z00?o?`3ooookJ_oonfX0@ooonfX00ooo803ooo]ZoookJP0FoookJP03ool0Dooonf[o
oo]Z01Wooo]Z00?ooc`0oookJ_oonfX0=OoonfX009Cooo]Z00?o0>_ooookJ_oonfX02?oonfX00ooo
077oP?l0oookJP03oookJP03oiCo0?oonf[ooo]Z00Gooo]Z0ooUo`000om4o`3oo`0HodCo0004odCo
0005o`3o1?m4o`3oA?l0odCo0?m^o`000_nDo`001?oo04;oU?l0oiCo0?nMo`03oiCo0004o`0@oooo
nf[ooo]Zoe_o00Oooo]Z00?o01cooookJ_oonfX08_oonfX00ondo`3ooo]ZoookJP03oookJPCo0000
5_oonfX00ol01ooooo]ZoookJP0RoookJP03oonW0?l0ol;ooo]Z00Gooo]Z00?o?`3ooookJ_oonfX0
@ooonfX00ooo803ooo]ZoookJP0EoookJP03ool0Dooonf[ooo]Z01Wooo]Z00?ooc`0oookJ_oonfX0
aooonfX2o`3[o`Wooo]Z0_oo07401On0o`3ooo]ZoookJ_oonf[o0?mF00Sooo]Z00Co0?;oo`3o0?oo
nf[oo`0H0_oonfX04_l09Oooo`1@ool0_?l0F?oo0?l4o`3oD?l0P?ooK_l0oonT0?nLo`3ooo]Zool0
@_l0Y?oooo]Zoigo0?oo09?o0;Coo`0@o`?ooo]Z00?oFol0oookJ_oonfX01?oonfX00ol07?oooo]Z
oookJP0SoookJP03okCo0?oonf[ooo]Z00;ooo]Z1?l0000FoookJP03o`07oooonf[ooo]Z02;ooo]Z
00?oojL0o`3o`_oonfX01OoonfX00olo0?oooo]ZoookJP13oookJP03oolP0?oonf[ooo]Z01Kooo]Z
00?oo`1CoookJ_oonfX06OoonfX00ooo?03ooo]ZoookJP0foookJP00UOoonfX2o`3[o`Wooo]Z00?o
o`1aoh3o0?n0o`000_oonfX00onDo`3o0?mFoookJP06oookJP?oiOl000?oA?l0ool06?m4o`000om4
o`000ol0o`CoA?l0odCo0002odCo0006ofko0?nDo`3oU?l0ool0@_nDo`3oWOl00onDo`001Ol04?oo
oo]ZoiCo0?mKo`3oU?l000Kooo]Z00?o01cooookJ_oonfX08_oonfX00ondo`3ooo]ZoookJP03oook
JPCo00005_oonfX00ol01ooooo]ZoookJP0RoookJP03oonW0?l0ol;ooo]Z00Gooo]Z00?o?`3ooook
J_oonfX0@_oonfX00ooo803ooo]ZoookJP0EoookJP03ool0Dooonf[ooo]Z01Wooo]Z00?ooc`0oook
J_oonfX0b_oonfX2o`3[o`Wooo]Z00?oo`1aoh3o0?n0o`000_oonfX00ol0oeKooo]ZoookJP06oook
JP04o`3bool0o`3ooo]Zool060;ooo]Z01;o02Goool0D?l0F?oo0?l4oooo0?l0oe3o083oofko0?l0
6OooW?l0ool0@_oonf[o0:Cooigo0?oonf[o0;CoomWo0?l04?l2oookJP03oe_o0?oonf[ooo]Z00Co
oo]Z00?o01cooookJ_oonfX08ooonfX00ondo`3ooo]ZoookJP02oookJPCo00005_oonfX00ol01ooo
oo]ZoookJP0RoookJP03oonW0?l0ol;ooo]Z00Gooo]Z00?o?`3ooookJ_oonfX0@_oonfX00ooo803o
oo]ZoookJP0FoookJP03ool0Dooonf[ooo]Z01Wooo]Z00?ooc`0oookJ_oonfX0=ooonfX009Oooo]Z
0_l0jol9oookJP03ool0LOn0o`3oU?l000;oU?l000?o0?mFoookJ_nDo`001OoonfX3onGo0003ool0
6?ooW`3oA?l000?oA?l000Go0?l4odCo0?m4o`3oA?l0ofko0002oiCo0004ool0@_nDo`3oU?l0oigo
00;oU?l000Go013ooiCo0?nDo`3oU?l0oe_o0006oookJP03o`0Loooonf[ooo]Z02;ooo]Z00?o]?l0
oookJ_oonfX00ooonfX4o`0001Gooo]Z00?o00OooookJ_oonfX08_oonfX00oooY`3o0?o2oookJP05
oookJP03ocl0oooonf[ooo]Z04?ooo]Z00?oob00oookJ_oonfX05?oonfX00ooo05?ooo]ZoookJP0I
oookJP03ooll0?oonf[ooo]Z0<gooo]Z0_l0jol8oookJP;oo`1a00CoP?l0oookJ_oonf[o0?mF2?oo
nfX05ol0l_oo0?l0ool06?ooW`3ooo]Zo`0Uoooo053oo`2lo`1Hool0o`Co0?m@o`20oom^o`3ooj@0
oico0?oo04;ooo]Zo`2Toooonf[oWOl0o`2doooIo`3o013o00;ooo]Z00?oFol0oookJ_oonfX01Ooo
nfX00ol07?oooo]ZoookJP0RoookJP03okCo0?oonf[ooo]Z00;ooo]Z1?l0000EoookJP03o`07oooo
nf[ooo]Z02;ooo]Z00?oojL0o`3o`_oonfX01OoonfX00olo0?oooo]ZoookJP13oookJP03oolP0?oo
nf[ooo]Z01Gooo]Z00?oo`1CoookJ_oonfX06OoonfX00ooo?03ooo]ZoookJP0hoookJP00VOoonfX2
o`3[o`Sooo]Z00?oU?l0oh3o0?n0o`001?nDo`06oookJP04ool0[?oUo`3o0?l0ool060GoA?l000Go
0?l4odCo0?m4o`3oA?l0ofko0002oiCo0003ool0@_nDo`3oWOl000KoU?l000?oFol0oookJ_oonfX0
1?oonfX00ol07?oooo]ZoookJP0RoookJP03okCo0?oonf[ooo]Z00?ooo]Z1?l0000EoookJP03o`07
oooonf[ooo]Z02;ooo]Z00?oojL0o`3o`_oonfX01?oonfX00olo0?oooo]ZoookJP13oookJP03oolP
0?oonf[ooo]Z01Cooo]Z00?oo`1CoookJ_oonfX06_oonfX00ooo?03ooo]ZoookJP3?oookJP;o0>_o
2?oonfX01Ooo077oP?l0oh3o0?oonf[o0?mF00Sooo]Z01Ko0?;oo`3o0?oo01Sooil0oookJ_l09Ooo
o`1@ool0_?l0F?oo0?l4o`3oD?l0P?ooK_l0o`0IoonLo`3oo`12o`2Toooonf[oWOl0oookJ_l0]?oo
013o0ooonfX00omKo`3ooo]ZoookJP04oookJP03o`0Loooonf[ooo]Z02;ooo]Z00?o]?l0oookJ_oo
nfX00_oonfX4o`0001Gooo]Z00?o00OooookJ_oonfX08_oonfX00oooY`3o0?o2oookJP04oookJP03
ocl0oooonf[ooo]Z04?ooo]Z00?oob00oookJ_oonfX05OoonfX00ooo05?ooo]ZoookJP0JoookJP03
ooll0?oonf[ooo]Z03Sooo]Z002KoookJP03o`3[oooonf[ooo]Z00Gooo]Z0onDo`000on0o`3oU?l0
oiCo0002oiCo00Kooo]Z00Coo`2/onGo0?l0o`3oo`0H1?m4o`002_l0o`CoA?l0odCo0?m4o`3oK_l0
odCo0?nDo`3oo`12oiCo0?nMo`06oiCo0003oe_o0?oonf[ooo]Z00Gooo]Z00?o01cooookJ_oonfX0
2ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX00ondo`3ooo]ZoookJP03oookJPCo0000
4?oonfX2ooo900?ooo]Z00?o00OooookJ_oonfX08OoonfX00oooY`3o0?o2oookJP05oookJP03ocl0
oooonf[ooo]Z04;ooo]Z00?oob00oookJ_oonfX05OoonfX00ooo05?ooo]ZoookJP0IoookJP03ooll
0?oonf[ooo]Z0=;ooo]Z00?o0>_ooookJ_oonfX01ooonfX00ooo077oP?l0oookJP02o`3oEPOooo]Z
01Ko0?;oo`3o0?oo01Sooil0oookJ_l09Oooo`1@o`1Hool0o`Co0?obo`3oD?l0P?ooK_l0oico0?oo
04;ooo]Zo`2ToonMo`3ooo]Zo`2doooIo`3o013o0_oonfX00omKo`3ooo]ZoookJP04oookJP03o`0L
oooonf[ooo]Z00_ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`?ooo]Z00?o]?l0oookJ_oonfX0
0_oonfX4o`0001Gooo]Z00?o00OooookJ_oonfX08OoonfX00oooY`3o0?o2oookJP05oookJP03ocl0
oooonf[ooo]Z04;ooo]Z00?oob00oookJ_oonfX05_oonfX00ooo05?ooo]ZoookJP0IoookJP03ooll
0?oonf[ooo]Z03Wooo]Z002LoookJP;o0>_o1?oonfX:oiCo00?ooo]Z0_nDo`001Ooonf[o0?;ooook
J_l0o`3ooil000CoA?l000[o0?l4odCo0?m4o`3oA?l0ofko0?m4o`3oU?l0ool0@_nDo`3oWOl01_nD
o`000omKo`3ooo]ZoookJP04oookJP03o`0Loooonf[ooo]Z00[ooo]Z1ol007l3oookJP?o001o0_oo
nfX7o`00O`03okCo0?oonf[ooo]Z00Cooo]Z1?l0000@oookJPGoolT08ooonfX00oooY`3ooo]Zo`3o
`P05oookJP03ocl0oooonf[ooo]Z04;ooo]Z00?oob00oookJ_oonfX05OoonfX00ooo05?ooo]Zoook
JP0IoookJP03ooll0?oonf[ooo]Z0=Cooo]Z0_l0jol8oookJP05ool0LOn0o`3ooo]ZoookJ_l0oeH0
1_oonfX05_l0l_ooo`2/o`3o0?oo01Sooil0o`0Uoooo053oo`2lo`1Hool0o`Co0?m@o`20oom^o`3o
01Wooico0?oo04;o0:CooookJ_nMo`3o0;Coool0Tol04?l2oookJP03oe_o0?oonf[ooo]Z00Cooo]Z
00?o01cooookJ_oonfX02_oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o00?ooo]ZokCo0?oonfX0
1?oonfX4o`0001Cooo]Z00?o00OooookJ_oonfX08OoonfX00oooY`3ooo]Zo`3o`P05oookJP03ocl0
oooonf[ooo]Z04;ooo]Z00?oob00oookJ_oonfX05_oonfX00ooo05?ooo]ZoookJP0IoookJP03ooll
0?oonf[ooo]Z03[ooo]Z002NoookJP;o0>_o00?ooo]ZoiCo0?nDo`002_nDo`001?oonf[oU?l0oiCo
0?nDo`02oookJP03o`3bool0o`3oo`0H00GoA?l000Wo0?l4odCo0?m4o`3oK_l0odCo0?nDo`3oo`12
oiCo0?nMo`000_m4o`04oiCo0003oe_o0?oonf[ooo]Z00Cooo]Z00?o01cooookJ_oonfX02_oonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`05oookJ_l0
07oo001oo`00Oondo`001_oonfX4o`00013ooo]Z1ooob@0QoookJP03oonW0?l0ol;ooo]Z00Gooo]Z
00?o?`3ooookJ_oonfX0@_oonfX00ooo803ooo]ZoookJP0DoookJP03ool0Dooonf[ooo]Z01Wooo]Z
00?ooc`0oookJ_oonfX06ooonfX00omFo`3ooo]ZoookJP2ioookJP;o0>_o1ooonfX01Ooo077oP?l0
oookJ_oonf[o0?mF00Kooo]Z01Go0?;oo`3o0?oonf[oo`0HoonO0?l09Oooo`1@ool0_?l0o`Co0?l1
o`3oD?l0P?ooK_l0oico0?oo04;ooo]Zo`2ToonMo`3ooo]Zo`2dool04?l00ooonfX00omKo`3ooo]Z
oookJP03oookJP03o`0Loooonf[ooo]Z00[ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o00?ooo]Zo`00Ool007l00_l007l01_oonf[o001oo`00Ool007oooo]ZokCo00Gooo]Z1?l0000D
oookJP03o`07oooonf[ooo]Z027ooo]Z00?oojL0o`3o`_oonfX01OoonfX00olo0?oooo]ZoookJP12
oookJP03oolP0?oonf[ooo]Z01Gooo]Z00?oo`1CoookJ_oonfX06OoonfX00ooo?03ooo]ZoookJP0K
oookJP03oeKo0?oonf[ooo]Z01gooo]Z002PoookJP;o0>_o00?ooo]ZoiCo0?nDo`003OnDo`02oook
JP03o`3bool0o`3oo`0H00CoA?l000So0?l4odCo0?m4o`3o0?m@ofko0?m4o`3oU?l0ool0@P?oA?l0
1OnDo`000omKo`3ooo]ZoookJP03oookJP03o`0Lool007oo001o00Oo001o0_oonfX3o`00O`?ooo]Z
0ol007l6oookJP?o001o0ooonfX2o`00O`03okCo0?oonf[ooo]Z00Cooo]Z1?l0000@oookJPSoolT0
7ooonfX00oooY`3o0?o2oookJP05oookJP03ocl0oooonf[ooo]Z04;ooo]Z00?oob00oookJ_oonfX0
5?oonfX00ooo05?ooo]ZoookJP0IoookJP03ooll0?oonf[ooo]Z01cooo]Z00?oE_l0oookJ_oonfX0
^ooonfX00ol0jooooo]ZoookJP05oookJP05ool0LOn0o`3ooo]ZoookJ_l0oeH01_oonfX05Ol0l_oo
0?l0oookJ_oo01Sooil0o`0Uoooo053o05Soo`3o1?l0oo;o0?m@ool03?m^o`3oW?l0ool0@_l0Y?oo
oo]Zoigo0?l0]?oooo]Zo`0@o`02oookJP03oe_o0?oonf[ooo]Z00?ooo]Z00?o01coo`00Ool007l0
1ol007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o00?o]?l0oookJ_oonfX0
0ooonfX4o`0001Cooo]Z00?o00OooookJ_oonfX08?oonfX00oooY`3o0?o2oookJP05oookJP03ocl0
oooonf[ooo]Z04;ooo]Z00?oob00oookJ_oonfX05OoonfX00ooo05?ooo]ZoookJP0IoookJP03ooll
0?oonf[ooo]Z01cooo]Z00?oE_l0oookJ_oonfX07OoonfX00:;ooo]Z00Co0>_ooookJ_oonf[ooo]Z
3OnDo`02odCo0003o`3bool0o`3oA?l000;oA?l000?oo`1@odCo0?l0o`@00_m4o`000om^o`3oA?l0
odCo0004odCo00GoU?l000?oFol0oookJ_oonfX00ooonfX00ol07?oo001oo`00O`07o`00O`;ooo]Z
0ol007l3oookJP?o001o3?oonfX2o`00O`03okCo0?oonf[ooo]Z00Cooo]Z1_l0000>oookJPSoolT0
6ooonfX2ooo900;ooo]Z00?oojL0o`3o`_oonfX01?oonfX00olo0?oooo]ZoookJP12oookJP03oolP
0?oonf[ooo]Z01Cooo]Z00?oo`1CoookJ_oonfX06OoonfX00ooo?03ooo]ZoookJP0LoookJP03oeKo
0?oonf[ooo]Z0;gooo]Z0_l0jol6oookJP05ool0LOn0o`3ooo]ZoookJ_l0oeH01_oonfX05?l0l_oo
0?l0ool06?ooW`3o02Goool0D?oo0;co0?l4o`3o0Ol0oe3o083oofko0?nLo`3oo`12oookJ_l0Y?oo
WOl0oookJ_l0]?oo013o0_oonfX00omKo`3ooo]ZoookJP03oookJP03o`00Ool07?oo001o00Oo001o
0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o00?o]?l0oookJ_oonfX00ooonfX6o`00017ooo]Z
00?o00OooookJ_oonfX08OoonfX00oooY`3o0?o2oookJP04oookJP03ocl0oooonf[ooo]Z04;ooo]Z
00?oob00oookJ_oonfX05OoonfX00ooo05?ooo]ZoookJP0IoookJP03ooll0?oonf[ooo]Z01cooo]Z
00?oE_l0oookJ_oonfX07_oonfX00:?ooo]Z0_l0jol3oookJP_oU?l00_oonfX00om4o`3o0?;oo`3o
0003odCo0006ool0D?m4o`3o0?l4odCo0?l0oe3oK_l01_m4o`04oiCo0003oe_o0?oonf[ooo]Z00Co
oo]Z00?o01cooookJ_oonfX02?oonfX3o`00O`?ooo]Z0ol007l<oookJP;o001o00?o]?l0oookJ_oo
nfX01?oonfX4o`0000oooo]Z2?oob@0LoookJPGoolT01_oonfX00olo0?oooo]ZoookJP11oookJP03
oolP0?oonf[ooo]Z01Gooo]Z00?oo`1CoookJ_oonfX06?oonfX00ooo?03ooo]ZoookJP0LoookJP03
oeKo0?oonf[ooo]Z0<3ooo]Z00?o0>_ooookJ_oonfX01OoonfX01?n0o`3ooo]ZoookJ_l0oeH6oook
JP0Co`3bool0o`3oo`0HoonO0?l09Oooo`1@ool0_?l0o`Co0?obo`3oD?oo00coK_l0oico0?oo04;o
0:CooookJ_nMo`3o0;Coo`0@o`03oookJP03oe_o0?oonf[ooo]Z00?ooo]Z00?o01cooookJ_oonfX0
2?oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o00?o]?l0oookJ_oonfX00ooonfX4o`0001?ooo]Z
00?o00OooookJ_oonfX08?oonfX00oooY`3o0?o2oookJP05oookJP03ocl0oooonf[ooo]Z047ooo]Z
00?oob00oookJ_oonfX05_oonfX00ooo05?ooo]ZoookJP0HoookJP03ooll0?oonf[ooo]Z01cooo]Z
00?oE_l0oookJ_oonfX07ooonfX00:Gooo]Z0_l0jol3oookJP[oU?l00_oonfX00ol0l_ooA?l0o`3o
0003odCo0003ool0D?l0o`CoA?l000;oA?l000?oK_l0odCo0?m4o`000om4o`04oiCo0003oookJ_mK
o`3ooo]Z00Cooo]Z00?o01cooookJ_oonfX02?oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oo
nfX2o`00O`03okCo0?l007oooo]Z00Gooo]Z1?l0000?oookJPOoolT07OoonfX5ooo900Gooo]Z00?o
?`3ooookJ_oonfX0@OoonfX00ooo803ooo]ZoookJP0EoookJP03ool0Dooonf[ooo]Z01Wooo]Z00?o
oc`0oookJ_oonfX06ooonfX00omFo`3ooo]ZoookJP32oookJP;o0>_o1_oonfX2oh3o0003oookJ_l0
oeKooo]Z00Cooo]Z01Co0?;oool0[?l0o`3oo`0HoonO0?l09Oooo`1@o`3o1?ookP3o0?obo`3oD?m^
o`3oW?l0ool0@_l0Y?oooo]Zoigo0?l0]?oooo]Zo`0@o`;ooo]Z00?oFol0oookJ_oonfX00ooonfX0
0ol07?oooo]ZoookJP08oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJP?o001o00?o]?l0
oookJ_oonfX01?oonfX4o`0001;ooo]Z00?o00OooookJ_oonfX08OoonfX00oooY`3o0?o2oookJP04
oookJP03ocl0oooonf[ooo]Z047ooo]Z00?oob00oookJ_oonfX05_oonfX00ooo05?ooo]ZoookJP0I
oookJP03ooll0?oonf[ooo]Z01_ooo]Z00?oE_l0oookJ_oonfX08?oonfX00:Oooo]Z00?o0>_ooook
J_oonfX00_oonfX8oiCo00?ooo]Z00?o0?;oo`3o0?oo01P00_m4o`000ooo053oo`2lo`3o1002odCo
0003ofko0?m4o`3oA?l000?oA?l01OnDo`000omKo`3ooo]ZoookJP03oookJP03o`0Loooonf[ooo]Z
00Sooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`03okCo0?oonf[ooo]Z00Gooo]Z1?l0000?oook
JPKoolT07OoonfX8ooo900?ooo]Z00?o?`3ooookJ_oonfX0@OoonfX00ooo803ooo]ZoookJP0Doook
JP03ool0Dooonf[ooo]Z01Wooo]Z00?ooc`0oookJ_oonfX06ooonfX00omFo`3ooo]ZoookJP35oook
JP03o`3[oooonf[ooo]Z00Cooo]Z00Coo`1aoh3o0?oonf[o0?mF1OoonfX04ol0l_ooo`2/o`3o0?oo
01So02Goool0D?oonf[o0?l4o`3o0Ol0oe3oo`0<ofko0?nLo`3oo`12o`2ToonMo`3ooo]Zo`2dool0
4?l00_oonfX00omKo`3ooo]ZoookJP04oookJP03o`0Loooonf[ooo]Z00Oooo]Z0ol007l3oookJP?o
001o1ooonfX7o`00O`03okCo0?oonf[ooo]Z00Cooo]Z1?l0000BoookJP03o`07oooonf[ooo]Z023o
oo]Z00?oojL0o`3o`_oonfX01OoonfX00olo0?oooo]ZoookJP11oookJP03oolP0?oonf[ooo]Z01Go
oo]Z00?oo`1CoookJ_oonfX06OoonfX00ooo?03ooo]ZoookJP0KoookJP03oeKo0?oonf[ooo]Z027o
oo]Z002XoookJP;o0>_o1?oonfX7oiCo00;ooo]Z00CoU?l0o`3bool0o`3oo`0H0_m4o`000ooo053o
o`2lo`3o1002odCo0003ofko0?m4o`3oA?l000;oA?l01OnDo`000omKo`3ooo]ZoookJP03oookJP03
o`0Loooonf[ooo]Z00Sooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`03okCo0?oonf[ooo]Z00Go
oo]Z1?l0000?oookJPKoolT07OoonfX9ooo90003oookJ_lo0?oooo]Z04;ooo]Z00?oob00oookJ_oo
nfX05?oonfX00ooo05?ooo]ZoookJP0IoookJP03ooll0?oonf[ooo]Z01_ooo]Z00?oE_l0oookJ_oo
nfX0aooonfX2o`3[o`Gooo]Z00Coo`1aoh3o0?oonf[o0?mF1OoonfX05Ol0l_ooo`2/o`3o0?oo01So
02Goool0D?oonf[o0?l4o`3ol_l0oe3oK_l0oico0?oo04;o0:CooookJ_nMo`3o0;Coo`0@oooIo`3o
oo]Zoe_o0006oookJP03o`0Loooonf[ooo]Z00Oooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`03
oookJ_ndo`3ooo]Z00Gooo]Z1?l0000BoookJP03o`07oooonf[ooo]Z01oooo]Z00?oojL0oookJ_l0
ol801OoonfX00olo0?oooo]ZoookJP11oookJP03oolP0?oonf[ooo]Z01Gooo]Z00?oo`1CoookJ_oo
nfX06OoonfX00ooo?03ooo]ZoookJP0KoookJP03oeKo0?oonf[ooo]Z02;ooo]Z002ZoookJP03o`3[
oooonf[ooo]Z00;ooo]Z2OnDo`000ol0l_ooA?l0o`3o0003odCo0003o`3o3?l0o`Co0?l<00;oA?l0
00?oK_l0odCo0?m4o`000_m4o`04oiCo0003oookJ_mKo`3ooo]Z00?ooo]Z00?o01cooookJ_oonfX0
2?oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o1?oonfX00ondo`3ooo]ZoookJP05oookJPCo0000
3ooonfX5ooo901kooo]Z2?oob@02oookJP03ocl0oooonf[ooo]Z043ooo]Z00?oob00oookJ_oonfX0
5?oonfX00ooo05?ooo]ZoookJP0IoookJP03ooll0?oonf[ooo]Z01_ooo]Z00?oE_l0oookJ_oonfX0
b_oonfX00ol0jooooo]ZoookJP03oookJP04ool0LOn0o`3ooo]Zo`3oEPGooo]Z01;o0?;oool0[?l0
o`3ooil0o`0Uoooo053o0?l4ooo^0?l0P?oo0?m@ofko0?l06Oooo`12o`2ToonMo`3oo`2Co`2dool0
4?l2oookJP03oe_o0?oonf[ooo]Z00?ooo]Z00?o01cooookJ_oonfX01ooonfX3o`00O`?ooo]Z0ol0
07l7oookJP;o001o1OoonfX00ondo`3ooo]ZoookJP04oookJPCo00004OoonfX00ol01ooooo]Zoook
JP0PoookJP03oonW0?l0ol;ooo]Z00Gooo]Z00?o?`3ooookJ_oonfX0@?oonfX00ooo803ooo]Zoook
JP0EoookJP03ool0Dooonf[ooo]Z01Wooo]Z00?ooc`0oookJ_oonfX06ooonfX00omFo`3ooo]Zoook
JP0SoookJP00ZooonfX2o`3[o`Cooo]Z00?oo`1aoiCo0?nDo`001OnDo`000ol0l_ooU?l0o`3o0002
odCo00;o0?l<00Co0?l4o`3oD?m4o`3oK_l01?m4o`001_oo09?oU?l0oiCo0?nDo`3ooo]Zoe_o00Co
oo]Z00?o01cooookJ_oonfX02OoonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l4oook
JP03okCo0?oonf[ooo]Z00Gooo]Z1?l0000?oookJPCoolT07ooonfX7ooo900;ooo]Z00?o?`3ooook
J_oonfX0@?oonfX00ooo803ooo]ZoookJP0DoookJP03ool0Dooonf[ooo]Z01Wooo]Z00?ooc`0oook
J_oonfX06ooonfX00omFo`3ooo]ZoookJP3<oookJP;o0>_o1?oonfX01?oo077oP?l0oookJ_l0oeH5
oookJP0Ao`3boooonf[o0?l0o`0Uoooonf[oo`1@o`3o1?l0oo;o0?m@ofko0?nLo`3oo`12o`2Toooo
nf[oWOl0o`2dool04?l00_oonfX00omKo`3ooo]ZoookJP03oookJP03o`0Loooonf[ooo]Z00Sooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o1OoonfX00ondo`3ooo]ZoookJP04oookJPCo
00004OoonfX00ol01ooooo]ZoookJP0OoookJP03oonW0?l0ol;ooo]Z00Gooo]Z00?o?`3ooookJ_oo
nfX0@?oonfX00ooo803ooo]ZoookJP0EoookJP03ool0Dooonf[ooo]Z01Wooo]Z00?ooc`0oookJ_oo
nfX06ooonfX00omFo`3ooo]ZoookJP0ToookJP00[OoonfX00ol0jooooo]ZoookJP02oookJP03ool0
LOn0o`3oU?l000GoU?l000?o0?;ooiCo0?l0o`000_m4o`001_l0o`co05Soo`3o1?l0oe3oA?l0ofko
00?oA?l01?nDo`000ooonf[oFol0oookJP04oookJP03o`0Loooonf[ooo]Z00Sooo]Z1ol007l9oook
JPGo001o00?o]?l0o`00OooonfX01OoonfX4o`0000oooo]Z0ooob@0OoookJPOoolT00ooonfX00olo
0?oooo]ZoookJP10oookJP03oolP0?oonf[ooo]Z01Cooo]Z00?oo`1CoookJ_oonfX06?oonfX00ooo
?03ooo]ZoookJP0KoookJP03oeKo0?oonf[ooo]Z0<oooo]Z00?o0>_ooookJ_oonfX00_oonfX01?oo
077oP?l0oookJ_l0oeH5oookJP0Co`3boooonf[o0?l0o`0Uoooonf[oo`1@o`3o1?l0P?oo0?m@ofko
0?l06Oooo`12o`2ToonMo`3oo`2Co`2dool04?oooo]Zoe_o0005oookJP03o`0Loooonf[ooo]Z00So
oo]Z1ol007l9oookJPGo001o00?o]?l0o`00OooonfX01OoonfX4o`00017ooo]Z00?o00OooookJ_oo
nfX07ooonfX00oooY`3o0?o2oookJP05oookJP03ocl0oooonf[ooo]Z043ooo]Z00?oob00oookJ_oo
nfX05OoonfX00ooo05?ooo]ZoookJP0HoookJP03ooll0?oonf[ooo]Z01_ooo]Z00?oE_l0oookJ_oo
nfX09OoonfX00:kooo]Z00?o0>_ooookJ_oonfX00_oonfX01Ooo077oP?l0oiCo0?nDo`3ooo]Z00;o
U?l000?o0?;ooiCo0?l0o`000om4o`001Ol0o`co0?l4o`3o3?l0oe3oK_l000CoA?l01?nDo`000ooo
nf[oFol0oookJP03oookJP03o`0Loooonf[ooo]Z00Wooo]Z1Ol007l:oookJPGo001o00?o]?l0o`00
OooonfX01OoonfX4o`0000kooo]Z1?oob@0OoookJPKoolT00ooonfX00olo0?oooo]ZoookJP10oook
JP03oolP0?oonf[ooo]Z01Cooo]Z00?oo`1CoookJ_oonfX06OoonfX00ooo?03ooo]ZoookJP0Joook
JP03oeKo0?oonf[ooo]Z0=7ooo]Z0_l0jol3oookJP04ool0LOn0o`3ooo]Zo`3oEPCooo]Z017o0?;o
ool0[?l0o`3ooil0o`0Uoooo053o0?l4ooo^0?l0oe3oK_l0oico0?oo04;o0:Cooigo0?oo09?o0;Co
o`0@o`02oookJP03oe_o0?oonf[ooo]Z00?ooo]Z00?o01cooookJ_oonfX02?oonfX5o`00O`[ooo]Z
1Ol007l00ondo`3o001ooookJP05oookJPCo00004?oonfX00ol01ooooo]ZoookJP0OoookJP03oonW
0?l0ol;ooo]Z00Gooo]Z00?o?`3ooookJ_oonfX0@?oonfX00ooo803ooo]ZoookJP0EoookJP03ool0
Dooonf[ooo]Z01Wooo]Z00?ooc`0oookJ_oonfX06_oonfX00omFo`3ooo]ZoookJP0VoookJP00[ooo
nfX00ol0jooooo]ZoookJP02oookJP05ool0LOn0o`3oU?l0oiCo0?oonfX00_nDo`000ol0l_ooU?l0
o`3o0003odCo0005o`1Hool0o`Co0?m@o`3o3?m^o`000om4o`04oiCo0003oookJ_mKo`3ooo]Z00?o
oo]Z00?o01cooookJ_oonfX07?oonfX00ondo`3ooo]ZoookJP06oookJPCo00003_oonfX3ooo9023o
oo]Z1Ooob@03oookJP03ocl0oooonf[ooo]Z043ooo]Z00?oob00oookJ_oonfX05?oonfX00ooo05?o
oo]ZoookJP0IoookJP03ooll0?oonf[ooo]Z01_ooo]Z00?oE_l0oookJ_oonfX0dooonfX02?l0jooo
oo]ZoookJ_oonf[oo`1aoh3o0?oonf[o0?mF1?oonfX04?l0l_ooo`2/o`3o0?ooW`3ooo]Zool0D?l0
o`Co083oo`3oD?m^o`3oW?l0ool0@_l0Y?ooWOl0ool0Tol04?l2oookJP03oe_o0?oonf[ooo]Z00?o
oo]Z00?o01cooookJ_oonfX07?oonfX00ondo`3ooo]ZoookJP05oookJPCo00004?oonfX00ol01ooo
oo]ZoookJP0OoookJP03oonW0?l0ol;ooo]Z00Cooo]Z00?o?`3ooookJ_oonfX0@?oonfX00ooo803o
oo]ZoookJP0EoookJP03ool0Dooonf[ooo]Z01Wooo]Z00?ooc`0oookJ_oonfX06ooonfX00omFo`3o
oo]ZoookJP0VoookJP00/?oonfX2o`3[o`?ooo]Z00CoU?l0oh3o0?oonf[oU?l00_oonfX01?nDo`3o
0?;ooiCo0?l0o`02odCo0005ool0D?l0F?oo0?l4o`3oD?m^o`000om4o`04oiCo0003oookJ_mKo`3o
oo]Z00Cooo]Z00?o01cooookJ_oonfX06ooonfX00ondo`3ooo]ZoookJP06oookJPCo00003_oonfX2
ooo9023ooo]Z1Ooob@04oookJP03ocl0oooonf[ooo]Z03oooo]Z00?oob00oookJ_oonfX05?oonfX0
0ooo05?ooo]ZoookJP0IoookJP03ooll0?oonf[ooo]Z01_ooo]Z00?oE_l0oookJ_oonfX0eOoonfX2
o`3[o`?ooo]Z00?oP?l0oookJ_l0oeH01?oonfX04_l0l_ooo`2/o`3o0?ooW`3oo`1@ool0_?l0o`Co
0?m@ofko0?nLo`3oo`12o`2ToonMo`3oo`2Co`2dool04?oooo]Zoe_o00Gooo]Z00?o01cooookJ_oo
nfX07?oonfX00ondo`3ooo]ZoookJP05oookJPCo00004?oonfX00ol01ooooo]ZoookJP0NoookJP03
oonW0?l0ol;ooo]Z00Gooo]Z00?o?`3ooookJ_oonfX0?ooonfX00ooo803ooo]ZoookJP0EoookJP03
ool0Dooonf[ooo]Z01Wooo]Z00?ooc`0oookJ_oonfX06ooonfX00omFo`3ooo]ZoookJP0WoookJP00
/_oonfX00ol0jooooo]ZoiCo0002oiCo0003oh3o0?l0oeKooo]Z00;ooo]Z00_oU?l0o`3boooo01So
0?l0oookJ_m4o`3o05Soo`3o1?l0P?oo0?m@ofko0004odCo00;oU?l00_oonfX01_mKo`3oU?l0oiCo
0?nDo`3ooo]Zo`0Loagooo]Z00?o]?l0oookJ_oonfX01_oonfX5o`0000gooo]Z00?oolT0oookJ_oo
nfX07ooonfX4ooo900Cooo]Z00?o?`3ooookJ_oonfX0@?oonfX00ooo803ooo]ZoookJP0CoookJP03
ool0Dooonf[ooo]Z01Wooo]Z00?ooc`0oookJ_oonfX06ooonfX00omFo`3ooo]ZoookJP3HoookJP04
o`3[oooonf[ooo]ZoookJP;oP?l01OoonfX03ol0l_oo0?l0oonO0?l09Oooo`1@o`3o1?l0P?oo0?m@
ofko0?nLo`3oo`12oigo0?oonf[oo`2Co`0@o`02oookJP03oe_o0?oonf[ooo]Z00;ooo]Z00?o01co
oookJ_oonfX07?oonfX00ondo`3ooo]ZoookJP05oookJPGo00003_oonfX00ol01ooooo]ZoookJP0N
oookJP03oonW0?oonf[o0?o200Gooo]Z00?o?`3ooookJ_oonfX0@?oonfX00ooo803ooo]ZoookJP0D
oookJP03ool0Dooonf[ooo]Z01Wooo]Z00?ooc`0oookJ_oonfX06ooonfX00omFo`3ooo]ZoookJP0X
oookJP00/ooonfX5oiCo0003oh3o0?l0oeKooo]Z00;ooo]Z00_oU?l0o`3boom4o`3o0?l0o`3o3?oo
053o05Soo`3o1?l0oe3oK_l0oiCo0003odCo00SoU?l000?ooo]Zo`0LoooonfX07?oonfX00ondo`3o
oo]ZoookJP06oookJPCo00003_oonfX00ol01ooooo]ZoookJP0OoookJP?oolT01OoonfX00olo0?oo
oo]ZoookJP0ooookJP03oolP0?oonf[ooo]Z01Cooo]Z00?oo`1CoookJ_oonfX06?oonfX00ooo?03o
oo]ZoookJP0KoookJP03oeKo0?oonf[ooo]Z0=[ooo]Z00Ko0>_ooookJ_oonf[ooo]Zool0LOn0o`05
oookJP0Ao`3bool0o`3ooil0ool0D?oo0;co0?l4o`3oD?m^o`3oW?l0ool0@_oonf[oWOl0ool0Tol0
]?oo013ooookJ_mKo`001?oonfX00ol07?oooo]ZoookJP0KoookJP03okCo0?oonf[ooo]Z00Kooo]Z
1?l0000?oookJP03o`07oooonf[ooo]Z01kooo]Z00?oojL0o`3o`_oonfX01OoonfX00olo0?oooo]Z
oookJP0ooookJP03oolP0?oonf[ooo]Z01Cooo]Z00?oo`1CoookJ_oonfX06OoonfX00ooo?03ooo]Z
oookJP0KoookJP03oeKo0?oonf[ooo]Z02Wooo]Z001ooookJP?oiOl0<?oonfX7oiCo0003oh3o0?l0
oeKooo]Z00;ooo]Z00So0?;oodCo0?l0o`3oA?l0o`3o3?oo053o0?l4o`3o30GoA?l02?nDo`02oook
JP03o`0Loooonf[ooo]Z01[ooo]Z00?o]?l0oookJ_oonfX01_oonfX4o`0000kooo]Z00?o00Oooook
J_oonfX07_oonfX00oooY`3oolT0ooo90005oookJP03ocl0oooonf[ooo]Z03oooo]Z00?oob00oook
J_oonfX05?oonfX00ooo05?ooo]ZoookJP0HoookJP03ooll0?oonf[ooo]Z01_ooo]Z00?oE_l0oook
J_oonfX0g?oonfX01_l0jooooo]ZoookJ_oonf[oo`1aoh3o00Cooo]Z017o0?;oo`3o0?oo01Sooil0
ool0D?l0o`Co05Soo`3oD?m^o`3oW?l0ool0@_l0Y?ooWOl0o`2dool04?oooo]Zoe_o0005oookJP03
o`0Loooonf[ooo]Z01[ooo]Z00?o]?l0oookJ_oonfX01_oonfX4o`0000kooo]Z00?o00OooookJ_oo
nfX07_oonfX00oooY`3o0?o2oookJP05oookJP03ocl0oooonf[ooo]Z03oooo]Z00?oob00oookJ_oo
nfX05?oonfX00ooo05?ooo]ZoookJP0IoookJP03ooll0?oonf[ooo]Z01_ooo]Z00?oE_l0oookJ_oo
nfX0:_oonfX007oooo]Z1ooUo`0[oookJPWoU?l000?oP?l0o`3oE_oonfX00_m4o`001_l0l_ooA?l0
o`3o0?m4o`3oo`1@ool0_0OoA?l01onDo`02oookJP03o`0Loooonf[ooo]Z01[ooo]Z00?o]?l0oook
J_oonfX01_oonfX4o`0000gooo]Z00?o00OooookJ_oonfX07ooonfX2ooo900Kooo]Z00?o?`3ooook
J_oonfX0?_oonfX00ooo803ooo]ZoookJP0DoookJP03ool0Dooonf[ooo]Z01Wooo]Z00?ooc`0oook
J_oonfX06_oonfX00omFo`3ooo]ZoookJP3NoookJP06o`3[oooonf[ooo]ZoookJ_oo077oP?l01?oo
nfX04Ol0l_oo0?l0oonO0?oo053ooo]Zo`3o1?ookP3o0?m@ofko0?oo04;ooo]Zoigo0?oo09?o013o
omWo0?oonf[oFol000Cooo]Z00?o01cooookJ_oonfX06_oonfX00ondo`3ooo]ZoookJP06oookJPCo
00003_oonfX00ol01ooooo]ZoookJP0NoookJP03oonW0?l0ol;ooo]Z00Gooo]Z00?o?`3ooookJ_oo
nfX0?_oonfX00ooo803ooo]ZoookJP0EoookJP03ool0Dooonf[ooo]Z01Wooo]Z00?ooc`0oookJ_oo
nfX06_oonfX00omFo`3ooo]ZoookJP0[oookJP00OooonfX:onGo02[ooo]Z1onDo`000ooonf[oP?l0
o`3oEP02oookJP04odCo0?l0l_ooA?l0o`3o00WoA?l01onDo`02oookJP03o`0Loooonf[ooo]Z01[o
oo]Z00?o]?l0oookJ_oonfX01_oonfX4o`0000gooo]Z00?o00OooookJ_oonfX07_oonfX00oooY`3o
olT0oookJP05oookJP03ocl0oooonf[ooo]Z03kooo]Z00?oob00oookJ_oonfX05?oonfX00ooo05?o
oo]ZoookJP0IoookJP03ooll0?oonf[ooo]Z01[ooo]Z00?oE_l0oookJ_oonfX0h?oonfX01ol0jooo
oo]ZoookJ_oonf[oo`1aoh3o0?l0oeH00ooonfX04?l0l_oo0?l0oonO0?oo053o@`3oo`3o1?l0oe3o
K_l0oico0?oo04;o0:Cooigo0?l0]?oo013ooookJ_mKo`04oookJP03o`0Loooonf[ooo]Z01[ooo]Z
00?o]?l0oookJ_oonfX01_oonfX4o`0000kooo]Z00?o00OooookJ_oonfX07OoonfX00oooY`3o0?o2
oookJP05oookJP03ocl0oooonf[ooo]Z03kooo]Z00?oob00oookJ_oonfX05OoonfX00ooo05?ooo]Z
oookJP0IoookJP03ooll0?oonf[ooo]Z01[ooo]Z00?oE_l0oookJ_oonfX0;?oonfX007oooo]Z3_oU
o`0WoookJPOoU?l000?oP?l0ool0LOl0oeH00_oonfX01?m4o`3o0?;oodCo0?l0o`08odCo00SoU?l0
0_oonfX00ol07?oooo]ZoookJP0IoookJP03okCo0?oonf[ooo]Z00Kooo]Z1?l0000=oookJP03o`07
oooonf[ooo]Z01kooo]Z00?oojL0o`3o`_oonfX01OoonfX00olo0?oooo]ZoookJP0moookJP03oolP
0?oonf[ooo]Z01Cooo]Z00?oo`1CoookJ_oonfX06OoonfX00ooo?03ooo]ZoookJP0JoookJP03oeKo
0?oonf[ooo]Z0>;ooo]Z00Oo0>_ooookJ_oonf[ooo]Zoh3o0?oonf[o0?mF00;ooo]Z013o0?;ooook
J_l0o`3ooo]Zool0D?l0F?oo0?l4o`3oD?m^o`3oo`12oookJ_nMo`3o0;Coo`0@oooIo`3oFol01Ooo
nfX00ol07?oooo]ZoookJP0IoookJP03okCo0?oonf[ooo]Z00Kooo]Z1?l0000=oookJP03o`07oooo
nf[ooo]Z01kooo]Z00?oojL0o`3o`_oonfX01OoonfX00olo0?oooo]ZoookJP0moookJP03oolP0?oo
nf[ooo]Z01Gooo]Z00?oo`1CoookJ_oonfX06OoonfX00ooo?03ooo]ZoookJP0JoookJP03oeKo0?oo
nf[ooo]Z02gooo]Z001eoookJP[od_l04?oUo`05om;o02;ooo]Z1_nDo`000on0o`3oo`1ao`3oEP02
oookJP04odCo0?l0l_ooA?l0o`3o00OoA?l02?nDo`02oookJP03o`0Loooonf[ooo]Z01Wooo]Z00?o
]?l0oookJ_oonfX01_oonfX4o`0000cooo]Z00?o00OooookJ_oonfX07_oonfX00oooY`3o0?o2oook
JP05oookJP03ocl0oooonf[ooo]Z03kooo]Z00?oob00oookJ_oonfX05?oonfX00ooo05?ooo]Zoook
JP0HoookJP03ooll0?oonf[ooo]Z01_ooo]Z00?oE_l0oookJ_oonfX0X?oonfXNom;o02Gooo]Z00Oo
0>_ooookJ_oonf[ooo]Zoh3o0?oonf[o0?mF00;ooo]Z013o0?;ooookJ_l0o`3o02Goool0D?l0F?oo
0?l4ofko0?nLo`3oo`12o`2ToonMo`3o0;Coo`0@oooonf[oFol01?oonfX00ol07?oooo]ZoookJP0I
oookJP03okCo0?oonf[ooo]Z00Kooo]Z1?l0000=oookJP03o`07oooonf[ooo]Z01gooo]Z00?oojL0
o`3o`_oonfX01OoonfX00olo0?oooo]ZoookJP0noookJP03oolP0?oonf[ooo]Z01Cooo]Z00?oo`1C
oookJ_oonfX06OoonfX00ooo?03ooo]ZoookJP0JoookJP03oeKo0?oonf[ooo]Z02kooo]Z001]oook
JPSod_l02_oonfX=onGo00Sooo]Z1_oBo`0NoookJPCoU?l000Cooo]Zoh3o0?oo077o0?mF0_oonfX0
1?m4o`3o0?;ooiCo0?nDo`07odCo00OoU?l00_oonfX00ol07?oooo]ZoookJP02oiCo01Kooo]Z00?o
]?l0oookJ_oonfX01ooonfX4o`0000cooo]Z00?o00OooookJ_oonfX07OoonfX00oooY`3ooo]Zo`3o
`P05oookJP03ocl0oooonf[ooo]Z03kooo]Z00?oob00oookJ_oonfX05?oonfX00ooo05?ooo]Zoook
JP0HoookJP03ooll0?oonf[ooo]Z01_ooo]Z00?oE_l0oookJ_oonfX0VOoonfX8om;o01kooo]Z1_oB
o`0PoookJP;o0>_o0_oonfX00on0o`3ooo]Zo`3oEP02oookJP0?o`3bool0o`3oo`0Ho`0Uoooo053o
0?l4o`3oD?m^o`3oo`12oookJ_nMo`3o0;Coo`0@oooonf[oFol000Cooo]Z00?o01cooookJ_oonfX0
6?oonfX00ondo`3ooo]ZoookJP07oookJPCo00003OoonfX00ol01ooooo]ZoookJP0LoookJP03oonW
0?oonf[o0?o200Kooo]Z00?o?`3ooookJ_oonfX0?OoonfX00ooo803ooo]ZoookJP0DoookJP03ool0
Dooonf[ooo]Z01Wooo]Z00?ooc`0oookJ_oonfX06_oonfX00omFo`3ooo]ZoookJP0_oookJP00JOoo
nfX4om;o01;ooo]Z2?oUo`001?oonf[oiOl0onGo0?oUo`0?oookJP?od_l07?oonfX4oiCo0004oook
J_n0o`3oo`1ao`3oEP;ooo]Z00?oU?l0o`3bool0oed01om4o`07oiCo00;ooo]Z1OnDo`0FoookJP03
okCo0?oonf[ooo]Z00Oooo]Z1?l0000<oookJP03o`07oooonf[ooo]Z01gooo]Z00?oojL0o`3o`_oo
nfX01OoonfX00olo0?oooo]ZoookJP0moookJP03oolP0?oonf[ooo]Z01Cooo]Z00?oo`1CoookJ_oo
nfX06?oonfX00ooo?03ooo]ZoookJP0KoookJP03oeKo0?oonf[ooo]Z09Gooo]Z1OoBo`0/oookJPCo
d_l07_oonfX01_l0jooooo]ZoookJ_n0o`3ooo]Zo`3oEP;ooo]Z00oo0?;oo`3o0?oo01Soo`1@o`1H
ool0o`Co0?m@ofko0?oo04;o0:Cooigo0?l0]?oo013ooookJ_mKo`001?oonfX00ol07?oooo]Zoook
JP0GoookJP03okCo0?oonf[ooo]Z00Oooo]Z1?l0000<oookJP03o`07oooonf[ooo]Z01gooo]Z00?o
ojL0o`3o`_oonfX01OoonfX00olo0?oooo]ZoookJP0moookJP03oolP0?oonf[ooo]Z01Cooo]Z00?o
o`1CoookJ_oonfX06OoonfX00ooo?03ooo]ZoookJP0JoookJP03oeKo0?oonf[ooo]Z033ooo]Z001U
oookJPCod_l05_oonfX3onGo00Kooo]Z1_oUo`0?oookJPCod_l06_oonfX2oiCo00;ooo]Z00?oP?l0
ool0LOl0oeH00onDo`08odCo00;oU?l000?o0;CooiCo0?nDo`002OnDo`0FoookJP03okCo0?oonf[o
oo]Z00Oooo]Z1?l0000<oookJP03o`07oooonf[ooo]Z01cooo]Z00?oojL0o`3o`_oonfX01OoonfX0
0olo0?oooo]ZoookJP0moookJP03oolP0?oonf[ooo]Z01Cooo]Z00?oo`1CoookJ_oonfX06?oonfX0
0ooo?03ooo]ZoookJP0KoookJP03oeKo0?oonf[ooo]Z09;ooo]Z1?oBo`0eoookJPCod_l06ooonfX0
1Ol0jooooo]ZoookJ_n0o`3o0?mF00?ooo]Z00ko0?;oo`3o0?ooW`3oo`1@o`1Hool0o`CoK_l0ool0
@_oonf[oWOl0o`2dool04?oooo]Zoe_o00Cooo]Z00?o01cooookJ_oonfX05ooonfX00ondo`3ooo]Z
oookJP07oookJPCo00003?oonfX00ol01ooooo]ZoookJP0LoookJP03oonW0?oonf[o0?o200Gooo]Z
00?o?`3ooookJ_oonfX0?OoonfX00ooo803ooo]ZoookJP0EoookJP03ool0Dooonf[ooo]Z01Sooo]Z
00?ooc`0oookJ_oonfX06_oonfX00omFo`3ooo]ZoookJP0aoookJP00HOoonfX4om;o02?ooo]Z2_oU
o`0?oookJP?od_l06OoonfX01?nDo`3ooo]ZoookJ_n0o`05oiCo00SoA?l000?oU?l0o`2doonDo`00
2_nDo`0FoookJP03okCo0?oonf[ooo]Z00Oooo]Z1Ol0000:oookJP03o`07oooonf[ooo]Z01gooo]Z
00?oojL0o`3o`_oonfX01?oonfX00olo0?oooo]ZoookJP0moookJP03oolP0?oonf[ooo]Z01Cooo]Z
00?oo`1CoookJ_oonfX06OoonfX00ooo?03ooo]ZoookJP0JoookJP03oeKo0?oonf[ooo]Z08oooo]Z
1?oBo`0moookJP?od_l06OoonfX01Ol0jooooo]ZoookJ_n0o`3o0?mF00;ooo]Z00ooo`2/o`3boooo
01So02Goo`1Hool0o`Co0?m@ofko0?oo04;o0:Cooigo0?oIo`3o013ooookJ_mKo`000ooonfX00ol0
7?oooo]ZoookJP0GoookJP03okCo0?oonf[ooo]Z00Oooo]Z1Ol0000;oookJP03o`07oooonf[ooo]Z
01cooo]Z00?oojL0o`3o`_oonfX01OoonfX00olo0?oooo]ZoookJP0loookJP03oolP0?oonf[ooo]Z
01Gooo]Z00?oo`1CoookJ_oonfX06?oonfX00ooo?03ooo]ZoookJP0KoookJP03oeKo0?oonf[ooo]Z
037ooo]Z001LoookJPGod_l09ooonfX=onGo00oooo]Z1?oBo`0FoookJP05oiCo0?oonf[ooo]Zoh3o
0?oonfX01?nDo`07odCo0003oigo0?l0oego013o00[oU?l05_oonfX00ondo`3ooo]ZoookJP07oook
JPCo00002ooonfX00ol01ooooo]ZoookJP0LoookJP03oonW0?l0ol;ooo]Z00Gooo]Z00?o?`3ooook
J_oonfX0?OoonfX00ooo803ooo]ZoookJP0DoookJP03ool0Dooonf[ooo]Z01Sooo]Z00?ooc`0oook
J_oonfX06_oonfX00omFo`3ooo]ZoookJP0BoookJP03o`1hoooonf[ooo]Z07Kooo]Z1OoBo`14oook
JPCod_l05_oonfX01Ol0jooooo]Zool0LOn0o`3o0?mF00;ooo]Z00ko0?;oo`3o0?oo01Soo`1@o`1H
ool0o`CoK_l0oico0?oo04;oWOl0o`2dool04?oooo]Zoe_o00Cooo]Z00?o01cooookJ_oonfX05_oo
nfX00ondo`3ooo]ZoookJP07oookJPCo00002ooonfX00ol01ooooo]ZoookJP0LoookJP03oonW0?oo
nf[o0?o200Gooo]Z00?o?`3ooookJ_oonfX0?OoonfX00ooo803ooo]ZoookJP0DoookJP03ool0Dooo
nf[ooo]Z01Sooo]Z00?ooc`0oookJ_oonfX06ooonfX00omFo`3ooo]ZoookJP0BoookJP03o`1hoooo
nf[ooo]Z01gooo]Z001GoookJPGod_l08ooonfX8oolK013oiOl01?oo6`0=oookJP?od_l02_oonfX0
0onDo`3ooo]ZoookJP07oookJP05o`3[oooonf[ooo]Zoh3o0?oonfX00_nDo`02o`3o30KoA?l000Co
0?mMoigo0?l0o`co013o2OnDo`0FoookJP03okCo0?oonf[ooo]Z00Oooo]Z1?l0000;oookJP03o`07
oooonf[ooo]Z01_ooo]Z00?oojL0oookJ_l0ol800_ooN@03oookJP03ocl0oooonf[ooo]Z03gooo]Z
00?oob00oookJ_oonfX05?oonfX00ooo05?ooo]ZoookJP0HoookJP03ooll0?oonf[ooo]Z01[ooo]Z
00?oE_l0oookJ_oonfX04_oonfX00ol0N?oooo]ZoookJP1boookJPGod_l09?oonfXLoolK00gooo]Z
0ooBo`0DoookJP05o`3[oooonf[oo`1aoh3o0?l0oeH00_oonfX03_l0l_ooo`0HoonO0?oo053o0?l4
o`3oD?m^o`3oo`12o`2ToonMo`3ofOl0o`0@oooonf[oFol00ooonfX00ol07?oooo]ZoookJP0Foook
JP03okCo0?oonf[ooo]Z00Oooo]Z1?l0000;oookJP03o`07oooonf[ooo]Z01_ooo]Z00?oojL0oook
J_l0ol801_oonfX00olo0?oooo]ZoookJP0loookJP03oolP0?oonf[ooo]Z01Cooo]Z00?oo`1Coook
J_oonfX06?oonfX00ooo?03ooo]ZoookJP0KoookJP03oeKo0?oonf[ooo]Z01;ooo]Z00?o07Sooook
J_oonfX07_oonfX005?ooo]Z1?oBo`0PoookJPSooa/02?oonfX=onGo00Oooo]Z1_oo6`0:oookJP?o
d_l01ooonfX2oiCo00Wooo]Z00Co0>_ooookJ_oonf[oP?l00onDo`02o`3o30GoA?l000Coo`12o`3o
3?nMo`3oA?l02OnDo`0FoookJP03okCo0?oonf[ooo]Z00Oooo]Z1?l0000:oookJP03o`07oooonf[o
oo]Z01cooo]Z00?oojL0o`3o`_oonfX01?ooN@000olo0?oooo]ZoookJP0moookJP03oolP0?oonf[o
oo]Z01Cooo]Z00?oo`1CoookJ_oonfX06?oonfX00ooo?03ooo]ZoookJP0JoookJP03oeKo0?oonf[o
oo]Z01;ooo]Z00?o07SooookJ_oonfX0L?oonfX3om;o023ooo]Z2Ooo6`0LoookJPGooa/02ooonfX3
om;o01;ooo]Z00Go0>_ooookJ_oo077oP?l0o`3oEP02oookJP0=o`3boooo01Soo`1@o`1Hool0o`Co
0?m@ofko0?oo04;oWOl0omWo0?l04?oooo]Zoe_o0003oookJP03o`0Loooonf[ooo]Z01Kooo]Z00?o
]?l0oookJ_oonfX01ooonfX4o`0000[ooo]Z00?o00OooookJ_oonfX07?oonfX00oooY`3ooo]Zo`3o
`P05oookJP03ocl0oooonf[ooo]Z03cooo]Z00?oob00oookJ_oonfX05?oonfX00ooo05?ooo]Zoook
JP0HoookJP03ooll0?oonf[ooo]Z01_ooo]Z00?oE_l0oookJ_oonfX04_oonfX00ol0N?oooo]Zoook
JP0OoookJP00D?oonfX3om;o01kooo]Z1_oo6`0@oookJPSoiOl04_oonfX3oolK00[ooo]Z0ooBo`03
oookJPCoU?l02OoonfX01?l0jooooo]Zool0LOn0o`02oiCo00;o0?l<1_m4o`001?l0oegoWOl0o`3o
3?l04?l8oiCo01Kooo]Z00?o]?l0oookJ_oonfX01ooonfX4o`0000[ooo]Z00?o00OooookJ_oonfX0
6ooonfX01?ooY`3o0?o2oookJ_oonfX5oomi03kooo]Z00?oob00oookJ_oonfX05?oonfX00ooo05?o
oo]ZoookJP0HoookJP03ooll0?oonf[ooo]Z01_ooo]Z00?oE_l0oookJ_oonfX04OoonfX00ol0N?oo
oo]ZoookJP1^oookJP?od_l07_oonfX5oolK02[ooo]Z1?oo6`0:oookJP?od_l04?oonfX04ol0jooo
oo]Zoh3o0?oonf[o0?mFoookJ_l0l_oo0?l0oonO0?oo053o05Soo`3o1?m^o`3oo`12oigo0?l0]?oo
013ooookJ_mKo`000ooonfX00ol07?oooo]ZoookJP0FoookJP03okCo0?oonf[ooo]Z00Oooo]Z1?l0
000:oookJP03o`07oooonf[ooo]Z01_ooo]Z00?oojL0oookJ_l0ol801OoonfX00olo0?oooo]Zoook
JP0loookJP03oolP0?oonf[ooo]Z01Cooo]Z00?oo`1CoookJ_oonfX06OoonfX00ooo?03ooo]Zoook
JP0JoookJP03oeKo0?oonf[ooo]Z01;ooo]Z00?o07SooookJ_oonfX08?oonfX004gooo]Z0ooBo`0L
oookJPGooa/05_oonfX3onGo01[ooo]Z1?oo6`09oookJP;od_l000?ooo]ZoiCo0?nDo`000onDo`09
oookJP;o0>_o00CoA?l0oh3o0?nDo`3oU?l00_m4o`000ol0o`coA?l0odCo0002odCo0007ool0@_l0
o`co0?l<odCo0?l04?ooU?l0odCo0005oiCo017ooo]Z1OoUo`0:oookJPCo00002_oonfX00ol01ooo
oo]ZoookJP0KoookJP03oonW0?l0ol;ooo]Z00SoogT0>ooonfX00ooo803ooo]ZoookJP0DoookJP03
ool0Dooonf[ooo]Z01Sooo]Z00?ooc`0oookJ_oonfX06ooonfX00omFo`3ooo]ZoookJP0AoookJP03
o`1hoooonf[ooo]Z06cooo]Z0ooBo`0LoookJPGooa/0<ooonfX4oolK00Wooo]Z0_oBo`0?oookJP0C
o`3[oooonf[oP?l0oookJ_l0oeKooo]Zo`3bool0o`3o02Goo`1Hool0o`Co0?m@ofko0?oo04;oWOl0
omWo0?l04?oooo]Zoe_o0002oookJP03o`0Loooonf[ooo]Z01Gooo]Z00?o]?l0oookJ_oonfX02?oo
nfX4o`0000[ooo]Z00?o00OooookJ_oonfX06ooonfX00oooY`3ooo]Zo`3o`P05oookJP03ocl0oooo
nf[ooo]Z03_ooo]Z00?oob00oookJ_oonfX05?oonfX00ooo05?ooo]ZoookJP0IoookJP03ooll0?oo
nf[ooo]Z01[ooo]Z00?oE_l0oookJ_oonfX04_oonfX00ol0N?oooo]ZoookJP0QoookJP00B_oonfX3
om;o01[ooo]Z1Ooo6`0loookJP?ooa/02?oonfX7oiCo00Wooo]Z00CoA?l0o`3[oom4o`3oP?l00om4
o`02o`3o30;oA?l000SoK_l0o`3o3?l0o`co0?l<odCo0?l04?ooFol0odCo00KoU?l04?oonfX9onGo
00Kooo]Z1?l00009oookJP03o`07oooonf[ooo]Z01_ooo]Z00CoojL0o`3o`_oonf[ooo]Z2OooN@0i
oookJP03oolP0?oonf[ooo]Z01Gooo]Z00?oo`1CoookJ_oonfX05ooonfX00ooo?03ooo]ZoookJP0K
oookJP03oeKo0?oonf[ooo]Z017ooo]Z00?o07SooookJ_oonfX0J_oonfX3om;o01[ooo]Z1Ooo6`0l
oookJP?ooa/02?oonfX2om;o00kooo]Z01;o0>_ooookJ_n0o`3ooo]Zo`3oE_l0l_oo0?l0ool06?l0
9Ooo05Soo`3o1?m^o`3oo`12oigo0?l0]?oo013ooookJ_mKo`03oookJP03o`0Loooonf[ooo]Z01Co
oo]Z00?o]?l0oookJ_oonfX02?oonfX4o`0000Wooo]Z00?o00OooookJ_oonfX06ooonfX00oooY`3o
oo]Zo`3o`P05oookJP03ocl0oooonf[ooo]Z03_ooo]Z00?oob00oookJ_oonfX05OoonfX00ooo05?o
oo]ZoookJP0HoookJP03ooll0?oonf[ooo]Z01[ooo]Z00?oE_l0oookJ_oonfX04_oonfX00ol0N?oo
oo]ZoookJP0RoookJP00AooonfX3om;o01Wooo]Z1?oo6`14oookJP?ooa/01?oonfX9oiCo00Oooo]Z
0om4o`000ol0joooA?l0odCo0003odCo00;o0?l<0_m4o`001?m^o`3o0?l<o`3o3?l0o``2odCo0003
oe_o0?m4o`3oU?l000CoU?l04?oonfX9onGo00Kooo]Z1?l00009oookJP03o`07oooonf[ooo]Z01_o
oo]Z00CoojL0o`3o`_oonf[ooo]Z2?ooN@0joookJP03oolP0?oonf[ooo]Z01Cooo]Z00?oo`1Coook
J_oonfX06?oonfX00ooo?03ooo]ZoookJP0JoookJP03oeKo0?oonf[ooo]Z017ooo]Z00?o07Sooook
J_oonfX0J?oonfX3om;o01Wooo]Z1?oo6`14oookJP?ooa/01ooonfX00ooBo`3ooo]ZoookJP0<oook
JP0Bo`3[oooonf[oP?l0o`3oE_oonf[o0?;oo`3o0?oo01Soo`1@o`3o1?l0oe3oK_l0ool0@_nMo`3o
0;Coo`0@oooonf[oFol00_oonfX00ol07?oooo]ZoookJP0DoookJP03okCo0?oonf[ooo]Z00Sooo]Z
1?l00009oookJP03o`07oooonf[ooo]Z01_ooo]Z00?oojL0oookJ_l0ol801OoonfX00olo0?oooo]Z
oookJP0koookJP03oolP0?oonf[ooo]Z01Cooo]Z00?oo`1CoookJ_oonfX06?oonfX00ooo?03ooo]Z
oookJP0JoookJP03oeKo0?oonf[ooo]Z01;ooo]Z00?o07SooookJ_oonfX08ooonfX004Cooo]Z0ooB
o`0IoookJP?ooa/0BooonfX3oolK0003oookJ_nDo`3oU?l000SoU?l02?oonfX8odCo00;o0?l<0_m4
o`000om^o`3o0?l<o`3o3002odCo0003oe_o0?m4o`3ooo]Z00CoU?l04OoonfX7onGo00Oooo]Z1?l0
0009oookJP03o`07oooonf[ooo]Z01[ooo]Z00?oojL0o`3o`_oonfX00_oonfX7oomi03[ooo]Z00?o
ob00oookJ_oonfX05?oonfX00ooo05?ooo]ZoookJP0HoookJP03ooll0?oonf[ooo]Z01[ooo]Z00?o
E_l0oookJ_oonfX04OoonfX00ol0N?oooo]ZoookJP1VoookJP?od_l06OoonfX3oolK04_ooo]Z0ooo
6`05oookJP;od_l03OoonfX04Ol0joooP?l0ool0LOl0oeKooo]Zo`3bool0o`3ooil0ool0D?l0o`Co
K_l0ool0@_nMo`3o0;Coo`0@oooonf[oFol000;ooo]Z00?o01cooookJ_oonfX05?oonfX00ondo`3o
oo]ZoookJP08oookJPCo00002OoonfX00ol01ooooo]ZoookJP0JoookJP03oonW0?oonf[o0?o200Go
oo]Z00?o?`3ooookJ_oonfX0>ooonfX00ooo803ooo]ZoookJP0DoookJP03ool0Dooonf[ooo]Z01So
oo]Z00?ooc`0oookJ_oonfX06_oonfX00omFo`3ooo]ZoookJP0BoookJP03o`1hoooonf[ooo]Z02Co
oo]Z0011oookJP?od_l06OoonfX3oolK057ooo]Z3?nDo`07oookJPOoA?l01?l0o``01?m4o`3oK_l0
o`3o3?l0o``2odCo0003oe_o0?m4o`3oA?l000CoU?l04OoonfX7onGo00Oooo]Z1?l00008oookJP03
o`07oooonf[ooo]Z01_ooo]Z00CoojL0o`3o`_oonf[ooo]Z1oooN@0joookJP03oolP0?oonf[ooo]Z
01Cooo]Z00?oo`1CoookJ_oonfX06?oonfX00ooo?03ooo]ZoookJP0JoookJP03oeKo0?oonf[ooo]Z
017ooo]Z00?o07SooookJ_oonfX0I?oonfX3om;o01Wooo]Z0ooo6`1AoookJP;ooa/01OoonfX3om;o
00_ooo]Z013o0>_ooh3o0?oo077o0?mFool0[?l0l_ooo`0Ho`0Uool0o`CoK_l0oico0?oo04;o0:Co
o`0@oooIo`3oFol00_oonfX00ol07?oooo]ZoookJP0DoookJP03okCo0?oonf[ooo]Z00Sooo]Z1?l0
0008oookJP03o`07oooonf[ooo]Z01_ooo]Z00?oojL0oookJ_l0ol801?oonfX00olo0?oooo]Zoook
JP0koookJP03oolP0?oonf[ooo]Z01Cooo]Z00?oo`1CoookJ_oonfX06?oonfX00ooo?03ooo]Zoook
JP0JoookJP03oeKo0?oonf[ooo]Z01;ooo]Z00?o07SooookJ_oonfX09OoonfX003oooo]Z0_oBo`0I
oookJP?ooa/0EooonfX:oiCo00Sooo]Z1_m4o`04o`3o3004odCo0?m^o`3o0?l<o`3o30;oA?l000?o
Fol0odCo0?m4o`000onDo`0AoookJPOoiOl01ooonfX4o`0000Sooo]Z00?o00OooookJ_oonfX06_oo
nfX00oooY`3o0?o2oookJP02oookJPKoogT0>_oonfX00ooo803ooo]ZoookJP0DoookJP03ool0Dooo
nf[ooo]Z01Sooo]Z00?ooc`0oookJ_oonfX06_oonfX00omFo`3ooo]ZoookJP0AoookJP03o`1hoooo
nf[ooo]Z06?ooo]Z0_oBo`0IoookJP?ooa/0E_oonfX3oolK00Gooo]Z0_oBo`0:oookJP0@o`3[oon0
o`3oo`1ao`3oE_l0l_oo0?l0ool06?ookP3o0?l4ofko0?nLo`3oo`12o`2dool04?oooo]Zoe_o00;o
oo]Z00?o01cooookJ_oonfX04ooonfX00ondo`3ooo]ZoookJP08oookJPCo00002?oonfX00ol01ooo
oo]ZoookJP0JoookJP03oonW0?oonf[o0?o200Gooo]Z00?o?`3ooookJ_oonfX0>_oonfX00ooo803o
oo]ZoookJP0DoookJP03ool0Dooonf[ooo]Z01Sooo]Z00?ooc`0oookJ_oonfX06_oonfX00omFo`3o
oo]ZoookJP0BoookJP03o`1hoooonf[ooo]Z02Kooo]Z000loookJP?od_l06?oonfX3oolK05gooo]Z
00?ooa/0oiCo0?nDo`001OnDo`08oookJPKoA?l00ol0o``01?l0o`CoK_l0o`3o3?l0o``2odCo0003
oe_o0?m4o`3oA?l000?oU?l04OoonfX6onGo00Sooo]Z1Ol00007oookJP03o`07oooonf[ooo]Z01Wo
oo]Z00?oojL0oookJ_l0ol800ooonfX5oomi03_ooo]Z00?oob00oookJ_oonfX04ooonfX00ooo05?o
oo]ZoookJP0HoookJP03ooll0?oonf[ooo]Z01Wooo]Z0_mFo`0CoookJP03o`1hoooonf[ooo]Z067o
oo]Z0ooBo`0HoookJP?ooa/0G?oonfX2oolK00Gooo]Z00?od_l0oookJ_oonfX02?oonfX03ol0jooo
P?l0ool0LOoonf[o0?;ooookJ_oo01So0?l4ofko0?nLo`3oo`12o`2Tool04?oofOl0oe_o0002oook
JP03o`0Loooonf[ooo]Z01?ooo]Z00?o]?l0oookJ_oonfX02?oonfX5o`0000Oooo]Z00?o00Oooook
J_oonfX06_oonfX00oooY`3ooo]Zo`3o`P04oookJP03ocl0oooonf[ooo]Z03_ooo]Z00?oob00oook
J_oonfX04ooonfX00ooo05?ooo]ZoookJP0HoookJP03ooll0?oonf[ooo]Z01[ooo]Z00?oE_l0oook
J_oonfX04_oonfX00ol0N?oooo]ZoookJP0WoookJP00>_oonfX2om;o01Sooo]Z0ooo6`1PoookJPWo
U?l01ooonfX7odCo00?o0?l<00Go0?l4ofko0?l0o`coWOl0odCo0002o`3o30;oA?l00_nDo`0Aoook
JPKoiOl02?oonfX4o`0000Oooo]Z00?o00OooookJ_oonfX06_oonfX00oooY`3o0?o2oookJP02oook
JPGoogT0>ooonfX00ooo803ooo]ZoookJP0CoookJP03ool0Dooonf[ooo]Z01Sooo]Z00?ooc`0oook
J_oonfX06OoonfX00omFo`3ooo]ZoookJP0BoookJP03o`1hoooonf[ooo]Z05oooo]Z0ooBo`0Hoook
JP?ooa/0HOoonfX3oolK00?ooo]Z00?od_l0oookJ_oonfX02?oonfX04Ol0joooP?l0ool0LOoonf[o
0?;oool06?oo0;co0?l4ofko0?nLo`3oo`12o`2dool04?oooo]Zoe_o0?oonf[o01co01Gooo]Z00?o
]?l0oookJ_oonfX02?oonfX4o`0000Oooo]Z00?o00OooookJ_oonfX06ooonfX00oooY`3o0?o2oook
JP03oookJP03ocl0oooonf[ooo]Z03_ooo]Z00?oob00oookJ_oonfX05?oonfX00ooo05?ooo]Zoook
JP0GoookJP03ooll0?oonf[ooo]Z01[ooo]Z00?oE_l0oookJ_oonfX04_oonfX00ol0N?oooo]Zoook
JP0XoookJP00>?oonfX2om;o01Sooo]Z0_oo6`1RoookJP_oU?l000?od_l0oookJ_oonfX01OoonfX0
0ol0joooA?l0odCo0003odCo00;o0?l<00?o0?l4ofko0?l0o``01?l0o``3odCo0003oiCo0?oonf[o
oo]Z013ooo]Z1OoUo`08oookJPCo00001ooonfX00ol01ooooo]ZoookJP0IoookJP03oonW0?l0ol;o
oo]Z00?ooo]Z1?ooN@0koookJP03oolP0?oonf[ooo]Z01?ooo]Z00?oo`1CoookJ_oonfX06?oonfX0
0ooo?03ooo]ZoookJP0IoookJP03oeKo0?oonf[ooo]Z01;ooo]Z00?o07SooookJ_oonfX0G_oonfX2
om;o01Sooo]Z0ooo6`1WoookJP;ooa/00_oonfX2om;o00Sooo]Z00oo0>_ooookJ_n0o`3o0?mFoook
J_l0l_ooo`0Ho`1Hool0o`CoK_l0ool0@_nMo`3o013oomWo0?mKo`000_oonfX00ol07?oooo]Zoook
JP0BoookJP03okCo0?oonf[ooo]Z00Sooo]Z1?l00007oookJP03o`07oooonf[ooo]Z01[ooo]Z00?o
ojL0o`3o`_oonfX01?oonfX00olo0?oooo]ZoookJP0joookJP03oolP0?oonf[ooo]Z01Cooo]Z00?o
o`1CoookJ_oonfX05ooonfX00ooo?03ooo]ZoookJP0JoookJP03oeKo0?oonf[ooo]Z01;ooo]Z00?o
07SooookJ_oonfX0:OoonfX003Gooo]Z0ooBo`0GoookJP?ooa/0I_oonfX9oiCo0003oookJ_oBo`3o
oo]Z00Kooo]Z00?o0>_oodCo0?m4o`000_m4o`001Ol0l_oo0?l<o`3o3?l0o`CoK_l000Co0?l<0om4
o`000ol07?oooo]ZoookJP0@oookJPCoiOl02OoonfX4o`0000Kooo]Z00?o00OooookJ_oonfX06_oo
nfX00oooY`3o0?o2oookJP03oookJP?oogT0>ooonfX00ooo803ooo]ZoookJP0CoookJP03ool0Dooo
nf[ooo]Z01Sooo]Z00?ooc`0oookJ_oonfX06OoonfX00omFo`3ooo]ZoookJP0BoookJP03o`1hoooo
nf[ooo]Z05cooo]Z0ooBo`0GoookJP?ooa/0K?oonfX2oolK00;ooo]Z00?od_l0oookJ_oonfX01_oo
nfX03_l0jooooo]Zoh3o0?l0oeKo0?;oo`3o0?oo053o05Soo`3o1?m^o`3oo`12oigo0?l04?ooFol0
0_oonfX00ol07?oooo]ZoookJP0BoookJP03okCo0?oonf[ooo]Z00Sooo]Z1?l00006oookJP03o`07
oooonf[ooo]Z01_ooo]Z00?oojL0o`3o`_oonfX00ooonfX00olo0?oooo]ZoookJP0joookJP03oolP
0?oonf[ooo]Z01Cooo]Z00?oo`1CoookJ_oonfX06?oonfX00ooo?03ooo]ZoookJP0IoookJP03oeKo
0?oonf[ooo]Z01;ooo]Z00?o07SooookJ_oonfX0:_oonfX003?ooo]Z0_oBo`0GoookJP?ooa/0K?oo
nfX7oiCo0003oookJ_oBo`3ooo]Z00Kooo]Z00?o0>_oodCo0?m4o`000_m4o`001?l0l_oo0?l<o`3o
1?m^o`05o`3o30;oA?l000?o01cooookJ_oonfX04?oonfX4onGo00Wooo]Z1?l00006oookJP03o`07
oooonf[ooo]Z01Wooo]Z00?oojL0o`3o`_oonfX01?oonfX2oomi03cooo]Z00?oob00oookJ_oonfX0
4ooonfX00ooo05?ooo]ZoookJP0GoookJP03ooll0?oonf[ooo]Z01Wooo]Z00?oE_l0oookJ_oonfX0
4_oonfX00ol0N?oooo]ZoookJP1KoookJP;od_l05ooonfX3oolK077ooo]Z00Cooa/0oookJ_oonf[o
d_l02?oonfX03_l0joooP?l0ool0LOoonf[o0?;oo`3o0?oo053o0?l4ofko0?oo04;oWOl0o`0@oooI
o`3oFol00_oonfX00ol07?oooo]ZoookJP0AoookJP03okCo0?oonf[ooo]Z00Sooo]Z1?l00006oook
JP03o`07oooonf[ooo]Z01[ooo]Z00?oojL0o`3o`_oonfX01?oonfX00olo0?oooo]ZoookJP0joook
JP03oolP0?oonf[ooo]Z01?ooo]Z00?oo`1CoookJ_oonfX06?oonfX00ooo?03ooo]ZoookJP0Ioook
JP03oeKo0?oonf[ooo]Z01;ooo]Z00?o07SooookJ_oonfX0:ooonfX0037ooo]Z0_oBo`0GoookJP;o
oa/0L_oonfX5oiCo0003oookJ_oBo`3od_l000Kooo]Z00Go0>_oodCo0?m4o`3oA?l0o`3bo`02o`3o
3003o`3o1?m^o`3o0?l<00?o0?l<0_m4o`000ooonf[o01cooookJP0@oookJPCoiOl02OoonfX4o`00
00Kooo]Z00?o00OooookJ_oonfX06OoonfX00oooY`3o0?o2oookJP03oookJP;oogT0??oonfX00ooo
803ooo]ZoookJP0CoookJP03ool0Dooonf[ooo]Z01Oooo]Z00?ooc`0oookJ_oonfX06OoonfX00omF
o`3ooo]ZoookJP0CoookJP03o`1hoooonf[ooo]Z05Wooo]Z0_oBo`0GoookJP;ooa/0MOoonfX2oolK
0003oookJ_oBo`3od_l000Oooo]Z00go0>_ooh3o0?oo077ooo]Zo`3bool0o`3oo`1@o`3o1?m^o`3o
o`12oigo0?l04?ooFol000;ooo]Z00?o01cooookJ_oonfX04OoonfX00ondo`3ooo]ZoookJP08oook
JPCo00001_oonfX00ol01ooooo]ZoookJP0JoookJP03oonW0?l0ol;ooo]Z00?ooo]Z00?o?`3ooook
J_oonfX0>_oonfX00ooo803ooo]ZoookJP0CoookJP03ool0Dooonf[ooo]Z01Sooo]Z00?ooc`0oook
J_oonfX06OoonfX00omFo`3ooo]ZoookJP0BoookJP03o`1hoooonf[ooo]Z02cooo]Z000_oookJP;o
d_l05_oonfX3oolK07Oooo]Z0onDo`02oookJP03om;o0?oonf[ooo]Z00Cooo]Z0om4o`04o`3o3003
o`3o1?m^o`3o0?l<00;o0?l<00CoFol0odCo0?m4o`3o01co4OoonfX3onGo00[ooo]Z1?l00005oook
JP03o`07oooonf[ooo]Z01Wooo]Z00?oojL0o`3o`_oonfX01?oonfX00oooN@3ooo]ZoookJP0joook
JP03oolP0?oonf[ooo]Z01?ooo]Z00?oo`1CoookJ_oonfX05ooonfX00ooo?03ooo]ZoookJP0Ioook
JP03oeKo0?oonf[ooo]Z01?ooo]Z00?o07SooookJ_oonfX0F?oonfX2om;o01Kooo]Z0ooo6`1ioook
JP;ooa/000?ooo]Zom;o0?oonfX01_oonfX03?l0joooP?l0o`3oE_oonf[o0?;oo`3o0?l0o`CoK_l0
ool0@_nMo`3o013ooe_o00?ooo]Z00?o01cooookJ_oonfX04?oonfX00ondo`3ooo]ZoookJP08oook
JPCo00001OoonfX00ol01ooooo]ZoookJP0JoookJP03oonW0?l0ol;ooo]Z00?ooo]Z00?o?`3ooook
J_oonfX0>_oonfX00ooo803ooo]ZoookJP0DoookJP03ool0Dooonf[ooo]Z01Oooo]Z00?ooc`0oook
J_oonfX06OoonfX00omFo`3ooo]ZoookJP0BoookJP03o`1hoooonf[ooo]Z02gooo]Z000/oookJP?o
d_l05OoonfX3oolK07gooo]Z00CoU?l0oolK0?oonf[od_l01?oonfX5odCo0006o`3oGOl0o`co0?l<
o`3o3?l0o`CoK_l00_l0o``3odCo0003o`0Loooonf[ooo]Z013ooo]Z0_oUo`0:oookJPCo00001Ooo
nfX00ol01ooooo]ZoookJP0IoookJP03oonW0?l0ol;ooo]Z00Cooo]Z00?o?`3ooookJ_oonfX0>Ooo
nfX00ooo803ooo]ZoookJP0CoookJP03ool0Dooonf[ooo]Z01Oooo]Z00?ooc`0oookJ_oonfX06Ooo
nfX00omFo`3ooo]ZoookJP0CoookJP03o`1hoooonf[ooo]Z05Kooo]Z0ooBo`0EoookJP?ooa/0O_oo
nfX2oolK0003om;o0?oonf[ooo]Z00Gooo]Z00co0>_ooh3o0?l0oeKo0?;oo`3o0?oo0;co0?l4ofko
0?oo04;oWOl0omWo0?mKo`02oookJP03o`0Loooonf[ooo]Z00oooo]Z00?o]?l0oookJ_oonfX02Ooo
nfX4o`0000Gooo]Z00?o00OooookJ_oonfX06_oonfX00oooY`3o0?o2oookJP03oookJP03ocl0oooo
nf[ooo]Z03Wooo]Z00?oob00oookJ_oonfX05?oonfX00ooo05?ooo]ZoookJP0GoookJP03ooll0?oo
nf[ooo]Z01Wooo]Z00?oE_l0oookJ_oonfX04_oonfX00ol0N?oooo]ZoookJP0^oookJP00:_oonfX2
om;o01Kooo]Z0_oo6`22oookJP03oolK0?oonf[od_l000;ooo]Z1_m4o`001_n0o`3o0?mMo`3o3?l0
o`co0?l4ofko00?o0?l<0_m4o`000ooonf[o01cooookJP0@oookJP;oiOl02_oonfX4o`0000Gooo]Z
00?o00OooookJ_oonfX06?oonfX00oooY`3o0?o2oookJP04oookJP03ocl0oooonf[ooo]Z03[ooo]Z
00?oob00oookJ_oonfX04_oonfX00ooo05?ooo]ZoookJP0GoookJP03ooll0?oonf[ooo]Z01Wooo]Z
00?oE_l0oookJ_oonfX04ooonfX00ol0N?oooo]ZoookJP1EoookJP;od_l05_oonfX2oolK08?ooo]Z
00?ooa/0om;o0?oBo`001_oonfX02ol0joooP?l0oookJ_l0l_oo0?l0o`3o1?m^o`3oo`12oigo0?l0
4?ooFol000;ooo]Z00?o01cooookJ_oonfX03ooonfX00ondo`3ooo]ZoookJP09oookJPCo00001Ooo
nfX00ol01ooooo]ZoookJP0IoookJP03oonW0?l0ol;ooo]Z00?ooo]Z00?o?`3ooookJ_oonfX0>_oo
nfX00ooo803ooo]ZoookJP0CoookJP03ool0Dooonf[ooo]Z01Oooo]Z00?ooc`0oookJ_oonfX06Ooo
nfX00omFo`3ooo]ZoookJP0BoookJP03o`1hoooonf[ooo]Z02oooo]Z000XoookJP;od_l05_oonfX2
oolK05Wooo]Z0ooob@02oookJP?oiOl09?oonfX00ooo6`3ooo]Zom;o0003oookJPGoA?l000KoP?l0
o`3oGOl0o`co0?l<o`3o1?m^o`04o`3o3003odCo0?l07?oooo]Z013ooo]Z00?oiOl0oookJ_oonfX0
2OoonfX4o`0000Cooo]Z00?o00OooookJ_oonfX06?oonfX00oooY`3ooo]Zo`3o`P04oookJP03ocl0
oooonf[ooo]Z03[ooo]Z00?oob00oookJ_oonfX04_oonfX00ooo05?ooo]ZoookJP0GoookJP03ooll
0?oonf[ooo]Z01Wooo]Z00?oE_l0oookJ_oonfX04ooonfX00ol0N?oooo]ZoookJP1DoookJP;od_l0
5_oonfX2oolK08Kooo]Z00?ooa/0oookJ_oBo`001_oonfX02_l0joooP?l0oookJ_l0l_oooil0o`3o
1?m^o`3oo`12oigo0?mKo`03oookJP03o`0Loooonf[ooo]Z00kooo]Z00?o]?l0oookJ_oonfX02Ooo
nfX4o`0000Cooo]Z00?o00OooookJ_oonfX06OoonfX00oooY`3ooo]Zo`3o`P04oookJP03ocl0oooo
nf[ooo]Z03Wooo]Z00?oob00oookJ_oonfX04ooonfX00ooo05?ooo]ZoookJP0GoookJP03ooll0?oo
nf[ooo]Z01Wooo]Z00?oE_l0oookJ_oonfX04_oonfX00ol0N?oooo]ZoookJP0`oookJP009_oonfX2
om;o01Gooo]Z0ooo6`1KoookJPGoolT01ooUo`0QoookJP;ooa/000Cod_l0oookJ_oonf[ooo]Z1Om4
o`001On0o`3o0?mMo`3o3?l0o`CoK_l000Co0?l<00?oA?l0o`0LoooonfX04?oonfX00ondo`3ooo]Z
oookJP09oookJPCo00001?oonfX00ol01ooooo]ZoookJP0HoookJP03oonW0?l0ol;ooo]Z00Cooo]Z
00?o?`3ooookJ_oonfX0>OoonfX00ooo803ooo]ZoookJP0BoookJP03ool0Dooonf[ooo]Z01Oooo]Z
00?ooc`0oookJ_oonfX06OoonfX00omFo`3ooo]ZoookJP0CoookJP03o`1hoooonf[ooo]Z05?ooo]Z
0_oBo`0EoookJP?ooa/0ROoonfX00ooo6`3ooo]Zom;o0006oookJP0:o`3[oon0o`3o0?;oo`3o0?l0
o`CoK_l0ool0@_nMo`3o013ooe_o00;ooo]Z00?o01cooookJ_oonfX03_oonfX00ondo`3ooo]Zoook
JP09oookJPCo00001?oonfX00ol01ooooo]ZoookJP0IoookJP03oonW0?l0ol;ooo]Z00?ooo]Z00?o
?`3ooookJ_oonfX0>OoonfX00ooo803ooo]ZoookJP0CoookJP03ool0Dooonf[ooo]Z01Oooo]Z00?o
oc`0oookJ_oonfX06OoonfX00omFo`3ooo]ZoookJP0BoookJP03o`1hoooonf[ooo]Z037ooo]Z000U
oookJP03om;o0?oonf[ooo]Z01?ooo]Z0_oo6`1NoookJPGoolT02_oUo`0PoookJP03oolK0?oBo`3o
d_l000;ooo]Z1?m4o`000on0o`3o0?mModCo0006o`3o3004odCo0?oonf[oA?l0odCo00oooo]Z00?o
]?l0oookJ_oonfX02OoonfX5o`0000?ooo]Z00?o00OooookJ_oonfX05ooonfX00oooY`3o0?o2oook
JP04oookJP03ocl0oooonf[ooo]Z03Wooo]Z00?oob00oookJ_oonfX04_oonfX00ooo05?ooo]Zoook
JP0GoookJP03ooll0?oonf[ooo]Z01Wooo]Z00?oE_l0oookJ_oonfX04ooonfX00ol0N?oooo]Zoook
JP1CoookJP03om;o0?oonf[ooo]Z01?ooo]Z0_oo6`2=oookJP04oolK0?oonf[od_l0om;o00Gooo]Z
00WoP?l0oookJ_l0l_ooo`0Ho`3o1?m^o`3oo`12oigo0?mKo`000_oonfX00ol07?oooo]ZoookJP0>
oookJP03okCo0?oonf[ooo]Z00Wooo]Z1Ol00003oookJP03o`07oooonf[ooo]Z01Sooo]Z00?oojL0
o`3o`_oonfX01?oonfX00olo0?oooo]ZoookJP0hoookJP03oolP0?oonf[ooo]Z01?ooo]Z00?oo`1C
oookJ_oonfX05ooonfX00ooo?03ooo]ZoookJP0IoookJP03oeKo0?oonf[ooo]Z01;ooo]Z00?o07So
oookJ_oonfX0<_oonfX003Wooo]Z0_oo6`1PoookJPGoolT03_oUo`0FoookJP;oiOl01OoonfX00ooo
6`3ooo]Zom;o0002oookJPCoA?l000?oP?l0o`3bool0o``01_l0o``3odCo00oooo]Z00?o]?l0oook
J_oonfX02OoonfX4o`0000?ooo]Z00?o00OooookJ_oonfX06?oonfX00oooY`3o0?o2oookJP04oook
JP03ocl0oooonf[ooo]Z03Wooo]Z00?oob00oookJ_oonfX04_oonfX00ooo05?ooo]ZoookJP0Foook
JP03ooll0?oonf[ooo]Z01Wooo]Z00?oE_l0oookJ_oonfX04ooonfX00ol0N?oooo]ZoookJP1Xoook
JP;ooa/0J_oonfX8ool0;Akooo]Z00Cooa/0oookJ_oonf[od_l01?oonfX03?l0joooP?l0oookJ_l0
l_oo0?l4ofko0?oo04;oWOl0o`0@oomKo`3ooo]Zo`0Loa3ooo]Z00?o]?l0oookJ_oonfX02OoonfX4
o`0000?ooo]Z00?o00OooookJ_oonfX06OoonfX00oooY`3o0?o2oookJP03oookJP03ocl0oooonf[o
oo]Z03Wooo]Z00?oob00oookJ_oonfX04ooonfX00ooo05?ooo]ZoookJP0FoookJP03ooll0?oonf[o
oo]Z01Wooo]Z00?oE_l0oookJ_oonfX04_oonfX00ol0N?oooo]ZoookJP0coookJP00=ooonfX2oolK
06;ooo]Z0_oob@03ool0;A3oiOl02Ooo02d;oookJP?oiOl000?oU?l0oookJ_oonfX00_oonfX2oolK
0003om;o0?m4o`3oA?l000?oA?l000?oP?l0o`3o3?l0o``01_l0o``3odCo00oooo]Z00?o]?l0oook
J_oonfX02OoonfX4o`0000?ooo]Z00?o00OooookJ_oonfX04ooonfX2onGo00;ooo]Z00?oojL0o`3o
`_oonfX01?oonfX00olo0?oooo]ZoookJP0ioookJP03oolP0?oonf[ooo]Z01;ooo]Z00?oo`1Coook
J_oonfX05_oonfX00ooo?03ooo]ZoookJP0IoookJP03oeKo0?oonf[ooo]Z01?ooo]Z00?o07Sooook
J_oonfX0IooonfX2oolK06Cooo]Z2?oo02d8o`3okPcoo`0]4ooonfX2oolK0003oookJ_oBo`3ooo]Z
00?ooo]Z00Wo0>_ooh3o0?oo0:co0?;oo`3o1?m^o`3oo`12oigo0?mKo`000_oonfX00ol07?oooo]Z
oookJP0=oookJP03okCo0?oonf[ooo]Z00Wooo]Z1?l00003oookJP03o`07oooonf[ooo]Z01Sooo]Z
00?oojL0o`3o`_oonfX01?oonfX00olo0?oooo]ZoookJP0hoookJP03oolP0?oonf[ooo]Z01?ooo]Z
00?oo`1CoookJ_oonfX05_oonfX00ooo?03ooo]ZoookJP0IoookJP03oeKo0?oonf[ooo]Z01;ooo]Z
00?o07SooookJ_oonfX0=?oonfX003Cooo]Z0ooo6`1NoookJPSoo`0]0ooob@0=onGo00Sooo]Z1?l0
onh3ool0;@Oooo]Z1?oUo`02oiCo00Gooo]Z1om4o`08o`3o30CoA?l03_oonfX00ondo`3ooo]Zoook
JP09oookJPCo00000ooonfX00ol01ooooo]ZoookJP0CoookJP?oiOl000?ooo]ZoonW0?l0ol801?oo
nfX00olo0?oooo]ZoookJP0ioookJP03oolP0?oonf[ooo]Z01;ooo]Z00?oo`1CoookJ_oonfX05_oo
nfX00ooo?03ooo]ZoookJP0IoookJP03oeKo0?oonf[ooo]Z01?ooo]Z00?o07SooookJ_oonfX0IOoo
nfX3oolK05kooo]Z2?oo02d3o`3okQGooo]Z1?l0onh3ool0;A;ooo]Z00?ooa/0oookJ_oBo`001?oo
nfX02ol0joooP?l0o`3bool0F?oo0?l4ofko0?nMo`3o013ooe_o0?oonf[o01co00oooo]Z00?o]?l0
oookJ_oonfX02OoonfX4o`0000?ooo]Z00?o00OooookJ_oonfX06?oonfX00oooY`3o0?o2oookJP03
oookJP03ocl0oooonf[ooo]Z03Sooo]Z00?oob00oookJ_oonfX04ooonfX00ooo05?ooo]ZoookJP0F
oookJP03ooll0?oonf[ooo]Z01Wooo]Z00?oE_l0oookJ_oonfX04_oonfX00ol0N?oooo]ZoookJP0e
oookJP00<_oonfX2oolK05[ooo]Z1ooo02d2o`3okPCooo]Z1Ooob@08onGo01;ooo]Z0_l0onh3ool0
;@Cooo]Z0ooUo`04oiCo00?ooo]Z2Om4o`08o`3o30?oA?l03_oonfX00ondo`3ooo]ZoookJP09oook
JPCo00000ooonfX00ol01ooooo]ZoookJP0CoookJPCoiOl000?o0?o2oookJ_oonfX00ooonfX00olo
0?oooo]ZoookJP0hoookJP03oolP0?oonf[ooo]Z01;ooo]Z00?oo`1CoookJ_oonfX05_oonfX00ooo
?03ooo]ZoookJP0IoookJP03oeKo0?oonf[ooo]Z01?ooo]Z00?o07SooookJ_oonfX0I?oonfX2oolK
05[ooo]Z1ooo02d3o`3okR?ooo]Z00Go0?o^ool0;Ooo02goo`0]o`3okP0?oookJP03oolK0?oonf[o
d_l000?ooo]Z00Wo0>_ooh3o0?oonf[o0?;oo`1Hoom^o`3oo`12oigo0?mKo`000_oonfX00ol07?oo
oo]ZoookJP0<oookJP03okCo0?oonf[ooo]Z00Wooo]Z1?l00003oookJP03o`07oooonf[ooo]Z01Oo
oo]Z00?oojL0o`3o`_oonfX01?oonfX00olo0?oooo]ZoookJP0goookJP03oolP0?oonf[ooo]Z01?o
oo]Z00?oo`1CoookJ_oonfX05_oonfX00ooo?03ooo]ZoookJP0IoookJP03oeKo0?oonf[ooo]Z01;o
oo]Z00?o07SooookJ_oonfX0=_oonfX002oooo]Z0ooob@1IoookJP?oo`0]0ol0onh:oookJPGoolT0
0ooUo`0LoookJP?oo`0]1?oUo`05oiCo0003oookJ_m4o`3oA?l000SoA?l02?l0o``3odCo0003oook
J_m4o`3oA?l000_ooo]Z00?o]?l0oookJ_oonfX02OoonfX4o`0000;ooo]Z00?o00OooookJ_oonfX0
4ooonfX5onGo0003o`3o`_oUo`3ooo]Z00;ooo]Z00?o?`3ooookJ_oonfX0>?oonfX00ooo803ooo]Z
oookJP0BoookJP03ool0Dooonf[ooo]Z01Kooo]Z00?ooc`0oookJ_oonfX06OoonfX00omFo`3ooo]Z
oookJP0CoookJP03o`1hoooonf[ooo]Z06?ooo]Z0_oo6`1IoookJP?oo`0]0ol0onh^oookJPCoo`0]
3OoonfX00ooo6`3ooo]Zom;o0003oookJP0;o`3[oon0o`3oo`2/ool0D?l0o`CoK_l0ool0@_l04?oo
Fol0oookJ_l07?l03_oonfX00ondo`3ooo]ZoookJP09oookJPCo00000_oonfX00ol01ooooo]Zoook
JP0GoookJP03oonW0?oonf[o0?o200Cooo]Z00?o?`3ooookJ_oonfX0=ooonfX00ooo803ooo]Zoook
JP0CoookJP03ool0Dooonf[ooo]Z01Kooo]Z00?ooc`0oookJ_oonfX06OoonfX00omFo`3ooo]Zoook
JP0BoookJP03o`1hoooonf[ooo]Z03Oooo]Z000[oookJPGoolT0F?oonfX3ool0;@?o0?o^3OoonfX2
ooo902Gooo]Z0ooo02d7oiCo00;ooo]Z2?m4o`08o`3o30KoA?l02ooonfX00ondo`3ooo]ZoookJP09
oookJPCo00000_oonfX00ol01ooooo]ZoookJP0CoookJPCoiOl000Co0?o2onGo0?oUo`3oiOl00_oo
nfX00olo0?oooo]ZoookJP0goookJP03oolP0?oonf[ooo]Z01;ooo]Z00?oo`1CoookJ_oonfX05_oo
nfX00ooo?03ooo]ZoookJP0IoookJP03oeKo0?oonf[ooo]Z01?ooo]Z00?o07SooookJ_oonfX0H_oo
nfX2oolK05Sooo]Z0ooo02d3o`3okSGooo]Z0ooo02d;oookJP03oolK0?oonf[od_l000?ooo]Z00[o
0>_ooh3o0?l0l_oo05Soofko0?oo04;oWOl0oe_o0?oonf[o01co3_oonfX00ondo`3ooo]ZoookJP09
oookJPCo00000_oonfX00ol01ooooo]ZoookJP0GoookJP03oonW0?l0ol;ooo]Z00Cooo]Z00?o?`3o
oookJ_oonfX0=_oonfX00ooo803ooo]ZoookJP0CoookJP03ool0Dooonf[ooo]Z01Kooo]Z00?ooc`0
oookJ_oonfX06OoonfX00omFo`3ooo]ZoookJP0BoookJP03o`1hoooonf[ooo]Z03Sooo]Z000Xoook
JPOoolT0E_oonfX3ool0;@?o0?o^=ooonfX2onGo00WoU?l00_oonfX8odCo00Oo0?l<00?oA?l0o`3o
GOl0oed00om4o`07o`00O`?ooo]Z00?o001ookCo0?l007l00_l007l8oookJPCo00000_oonfX00ol0
1ooooo]ZoookJP0CoookJPCoiOl000Ko0?o2onGo0?oUo`3oiOl0oookJ_lo0?lioookJP03oolP0?oo
nf[ooo]Z01;ooo]Z00?oo`1CoookJ_oonfX05_oonfX00ooo?03ooo]ZoookJP0IoookJP03oeKo0?oo
nf[ooo]Z01?ooo]Z00?o07SooookJ_oonfX0H_oonfX00ooo6`3ooo]ZoookJP1EoookJP?oo`0]0ol0
onhjoookJP03o`3ok_oo02goo`0]00[ooo]Z0_oo6`003_oBo`3o001oo`00Ool007ooP?l0ool0LOl0
l_oo0?l4ofko0?oo04;o013ooe_o0?l007oo01co2Ol007l3oookJP03o`00Oondo`3o001o00;o001o
2?oonfX4o`0000;ooo]Z00?o00OooookJ_oonfX05_oonfX00oooY`3o0?o2oookJP04oookJP03ocl0
oooonf[ooo]Z03Kooo]Z00?oob00oookJ_oonfX04ooonfX00ooo05?ooo]ZoookJP0FoookJP03ooll
0?oonf[ooo]Z01Wooo]Z00?oE_l0oookJ_oonfX04_oonfX00ol0N?oooo]ZoookJP0ioookJP009Ooo
nfX9ooo905Cooo]Z0ooo02d2o`3okS[ooo]Z0ooUo`0:oiCo0003oookJ_m4o`3oA?l000KoA?l02?l0
o``2o`3oG@CoA?l01_l007l2oookJP;o001o00?o]?l0o`00Ool007l00_l007l7oookJP06o`000?oU
o`3oiOl0onGo0?oonf[o00Oo5_oonfX3onGo0004o`3o`_oUo`3oiOl0onGo00;ooo]Z00?o?`3ooook
J_oonfX0=_oonfX00ooo803ooo]ZoookJP0BoookJP03ool0Dooonf[ooo]Z01Kooo]Z00?oolT0oook
J_oonfX06OoonfX00omFo`3ooo]ZoookJP0CoookJP03o`1hoooonf[ooo]Z067ooo]Z0_oo6`1Eoook
JP?oo`0]0_l0oni1oookJP?oo`0]2OoonfX00ooo6`3od_l0o`00O`02o`00O`09oh3o0?oo0:co0?l4
ofko0?oo04;o0:Cooe_o0?l007oo01co00Wo001o0_oonfX2o`00O`03okCo0?l007oo001o00;o001o
1ooonfX4o`000003oookJ_l01ooooo]Z01Sooo]Z00?oojL0o`3o`_oonfX00ooonfX00olo0?oooo]Z
oookJP0foookJP03oolP0?oonf[ooo]Z01?ooo]Z00?oo`1CoookJ_oonfX05_oonfX00ooo?03ooo]Z
oookJP0IoookJP03oeKo0?oonf[ooo]Z01;ooo]Z00?o07SooookJ_oonfX0>_oonfX002Gooo]Z2?oo
b@1BoookJP?oo`0]00?o0?o^oookJ_oonfX0?_oonfX<oiCo00;ooo]Z1Om4o`09o`3o30;o0?mM00Go
A?l0o`3o3?m4o`3oA?l0o`00O`06oookJP?o001o00?o]?l0oookJ_l007l00_l007l7oookJP03o`00
0?oUo`3oiOl000CoiOl05?oonfX4onGo0003o`3o`_oUo`3oiOl000;ooo]Z00?o?`3ooookJ_oonfX0
=_oonfX00ooo803ooo]ZoookJP0BoookJP03ool0Dooonf[ooo]Z01Oooo]Z00?oolT0oookJ_oonfX0
6?oonfX00omFo`3ooo]ZoookJP0CoookJP03o`1hoooonf[ooo]Z063ooo]Z0_oo6`1DoookJP?oo`0]
0_l0oni7oookJP?oo`0]1_oonfX01?l007oooa/0om;o0?oonfX2o`00O`08oh3o0?l0l_oo0?l4ofko
0?oo04;oFol0o`00Ool07?l4o`00O`Kooo]Z0ol007l00ondo`3ooo]Zo`00O`02o`00O`Oooo]Z1?l0
00000ooonf[o00OooookJP0GoookJP03oonW0?l0ol;ooo]Z00Cooo]Z00?o?`3ooookJ_oonfX0=Ooo
nfX00ooo803ooo]ZoookJP0CoookJP03ool0Dooonf[ooo]Z01Kooo]Z00?ooc`0oookJ_oonfX06Ooo
nfX00omFo`3ooo]ZoookJP0BoookJP03o`1hoooonf[ooo]Z03_ooo]Z000UoookJPOoolT0D?oonfX3
ool0;@03o`3ok_oonf[ooo]Z04Cooo]Z2_nDo`000ol007oooo]ZodCo0004odCo00;o0?l<00?o0?mM
o`3o3?l0o``00ol0o``3o`3oG@03o`3o3?m4o`3oA?l000;o001o1OoonfX3o`00O`03okCo0?oonf[o
oo]Z00?o001o1_oonfX00ol0003oiOl0onGo0006onGo01;ooo]Z0ooUo`000ol0ol;oiOl0onGo0003
oookJP03ocl0oooonf[ooo]Z037ooo]Z0_oob@02oookJP03oolP0?oonf[ooo]Z01;ooo]Z00?oo`1C
oookJ_oonfX04_oonfX00ooob@3ooo]ZoookJP02oookJP03ooo90?oonf[ooo]Z01Sooo]Z00?oE_l0
oookJ_oonfX04ooonfX00ol0N?oooo]ZoookJP1PoookJP03oolK0?oonf[ooo]Z057ooo]Z0ooo02d2
o`3okTKooo]Z1_l007l01?l0onkoo`0]o`00Ool007l2oookJP?o001o00gooa/0om;o0?oonf[o001o
oh3o0?oo077o05Soo`3o1?m^o`3o0:Cooe_o0?oonf[o01co00Co001o1OoonfX3o`00O`03okCo0?oo
nf[ooo]Z00?o001o1_oonfX4o`000003oookJ_l01ooooo]Z01Kooo]Z00?oojL0oookJ_l0ol801?oo
nfX00olo0?oooo]ZoookJP0eoookJP03oolP0?oonf[ooo]Z01?ooo]Z00?oo`1CoookJ_oonfX05_oo
nfX00ooo?03ooo]ZoookJP0IoookJP03oeKo0?oonf[ooo]Z01;ooo]Z00?o07SooookJ_oonfX0??oo
nfX002Gooo]Z1_oob@1?oookJP;oo`0]00?o0?o^oookJ_oonfX0B?oonfX3o`00O`OoU?l00_oonfX0
0ol007ooA?l0odCo0002odCo0003o`3o3?l0oego0?mM00Go0?l<0_l0oed00ol0o`coA?l0odCo0004
o`00O`Kooo]Z00?o]?l0oookJ_oonfX00ol007l6oookJP03o`000?oUo`3oiOl000KoiOl04_oonfX3
onGo0003o`3o`_oUo`3ooo]Z00;ooo]Z00?o?`3ooookJ_oonfX0<_oonfX3ooo90003oolP0?oonf[o
oo]Z01;ooo]Z00?oo`1CoookJ_oonfX04ooonfX2ooo900;ooo]Z00?oolT0oookJ_oonfX06?oonfX0
0omFo`3ooo]ZoookJP0CoookJP03o`1hoooonf[ooo]Z05oooo]Z0_oo6`1BoookJP;oo`0]0_l0oni9
oookJPSo001o0_oo02d2oookJP?o001o00?ooo]ZoolK0?oBo`000_l007l02On0o`3oo`2/o`3o1?m^
o`3oo`12oe_o0?oonf[o01cooookJP05o`00O`Kooo]Z00?o]?l0oookJ_oonfX00ol007l6oookJPGo
000000?o00OooookJ_oonfX05OoonfX00oooY`3o0?o2oookJP04oookJP03ocl0oooonf[ooo]Z03Co
oo]Z00?oob00oookJ_oonfX04ooonfX00ooo05?ooo]ZoookJP0FoookJP03ooll0?oonf[ooo]Z01Wo
oo]Z00?oE_l0oookJ_oonfX04_oonfX00ol0N?oooo]ZoookJP0moookJP009OoonfX5ooo904gooo]Z
0ooo02eCoookJPGoU?l000?ooo]Zo`00Ool007l01?m4o`000ol0o`co0?mMo`3oG@04o`3o30;o0?mM
00Co0?l<o`3oGOl0oegooo]Z1?l007l5oookJP03okCo0?oonf[ooo]Z00?o001o1_oonfX00ol0003o
iOl0onGo0005onGo01;ooo]Z0ooUo`000ol0ol;oiOl0oookJP03oookJP03ocl0oooonf[ooo]Z037o
oo]Z1Ooob@0CoookJP03ool0Dooonf[ooo]Z01?ooo]Z1Ooob@0JoookJP03oeKo0?oonf[ooo]Z01?o
oo]Z00?o07SooookJ_oonfX0GooonfX00ooo6`3ooo]ZoookJP1?oookJP?oo`0]00?o0?o^oookJ_oo
nfX0DooonfX00ol0onkoo`0]oookJP03o`00O`;ooo]Z00_ooa/0om;o0?l007oo001ooh3o0?l0l_oo
0?l4ofko0?l0Y?ooFol0o`0Lo`03oookJPCo001o1OoonfX00ondo`3ooo]ZoookJP03o`00O`Kooo]Z
1?l000000ol01ooooo]ZoookJP0EoookJP03oonW0?l0ol;ooo]Z00Cooo]Z00?o?`3ooookJ_oonfX0
=?oonfX00ooo803ooo]ZoookJP0CoookJP03ool0Dooonf[ooo]Z01Kooo]Z00?ooc`0oookJ_oonfX0
6OoonfX00omFo`3ooo]ZoookJP0BoookJP03o`1hoooonf[ooo]Z03kooo]Z000UoookJPCoolT0C?oo
nfX2ool0;@03o`3ok_oonf[ooo]Z05Oooo]Z0_nDo`001?oo02go001oo`00OooonfX3odCo0003o`3o
3?l0oego0?mM00?o0?l<1Ol0oed00om4o`3ooo]Zo`00O`02o`00O`?ooo]Z0_l007l00ondo`3ooo]Z
o`00O`03o`00O`Kooo]Z00?o0000onGo0?oUo`001OoUo`0BoookJP?oiOl000?o0?o2oookJ_oonfX0
0_oonfX00olo0?oooo]ZoookJP0boookJPKoolT04OoonfX00ooo05?ooo]ZoookJP0CoookJPKoolT0
6OoonfX00omFo`3ooo]ZoookJP0CoookJP03o`1hoooonf[ooo]Z0;3ooo]Z0_oo02d2o`3okUWooo]Z
0_oo02d2o`00O`?ooo]Z00_ooa/0om;o0?l007oo0>_ooh3o0?oo0;co0?l4ofko0?mKo`3ooo]Zo`0L
o`03oookJP?o001o0ooonfX2o`00O`03okCo0?oonf[o001o00?o001o1_oonfX4o`000003o`07oooo
nf[ooo]Z01Gooo]Z00?oojL0o`3o`_oonfX00ooonfX00olo0?oooo]ZoookJP0eoookJP03oolP0?oo
nf[ooo]Z01;ooo]Z00?oo`1CoookJ_oonfX05_oonfX00ooo?03ooo]ZoookJP0IoookJP03oeKo0?oo
nf[ooo]Z01;ooo]Z00?o07SooookJ_oonfX0?ooonfX002Gooo]Z0ooob@1;oookJP;oo`0]00?o0?o^
oookJ_oonfX0FooonfX00ol0onkoo`0]o`00O`02oookJP;oA?l000Kod_l0o`3o3?l0oego0?mMo`3o
3?m^o`05o`3oG@03odCo0?oonf[ooo]Z00?o001o0_oonfX00ol007ooU?l0oiCo0003oiCo0003o`00
Oooonf[ooo]Z00Gooo]Z00?o0000onGo0?oUo`001?oUo`0CoookJP;oiOl000?o0?o2oookJ_oonfX0
0ooonfX00olo0?oooo]ZoookJP0aoookJPSoolT03ooonfX00ooo05?ooo]ZoookJP0DoookJPOoolT0
5ooonfX00omFo`3ooo]ZoookJP0BoookJP;o07So/OoonfX2ool0;@;o0?o^G?oonfX00ol0onkoo`0]
o`00O`03oookJP0<o`00Oooo6`3od_l0oookJ_l0joooP?l0o`3o1?m^o`3oWOl0oe_o0?oonf[o01co
0ooonfX3o`00O`;ooo]Z0_l007l00ondo`3o001oo`00O`02o`00O`Oooo]Z1?l000000ol01ooooo]Z
oookJP0DoookJP03oonW0?l0ol;ooo]Z00Cooo]Z00?o?`3ooookJ_oonfX0=?oonfX00ooo803ooo]Z
oookJP0BoookJP03ool0Dooonf[ooo]Z01Kooo]Z00?ooc`0oookJ_oonfX06OoonfX00omFo`3ooo]Z
oookJP0AoookJP;o07So@_oonfX002Gooo]Z0_oob@19oookJP?oo`0]H?oonfX2o`00O`04ool0;Ooo
nf[ooo]ZoookJP;oA?l000Kod_l0odCo0?l0oego0?mMo`3o3?m^o`05o`3oG@;ooo]Z0_l007l9oiCo
00Sooo]Z00?o0000onGo0?oUo`001?oUo`0CoookJP03onGo0?l0ol;ooo]Z00Cooo]Z00?o?`3ooook
J_oonfX0<_oonfX6ooo9017ooo]Z00?oo`1CoookJ_oonfX04ooonfX9ooo901Gooo]Z00?oE_l0oook
J_oonfX04_oonfX00ol0N?oooo]ZoookJP2^oookJP?oo`0]00?o0?o^oookJ_oonfX0GOoonfX2o`00
O`;oo`0]0_oonfX03?l007oooa/0o`00OooBo`3ooo]Zoh3o0?l0l_oo0?l4ofko0?mKo`3o001oo`0L
o`?ooo]Z0ol007l2oookJP;o001o00Co]?l0o`00Ool007oo001o2?oonfX4o`000003o`07oooonf[o
oo]Z01?ooo]Z00?oojL0oookJ_l0ol801?oonfX00olo0?oooo]ZoookJP0doookJP03oolP0?oonf[o
oo]Z01?ooo]Z00?oo`1CoookJ_oonfX05OoonfX00ooo?03ooo]ZoookJP0IoookJP03oeKo0?oonf[o
oo]Z017ooo]Z00?o07SooookJ_oonfX0@_oonfX002Gooo]Z00?oolT0oookJ_oonfX0A_oonfX2ool0
;@03o`3ok_oonf[ooo]Z063ooo]Z0ol007l01Ooo02gooo]ZoiCo0?nDo`3o0?l<00;oA?l00ol0oed0
0ol0o`coK_l0o`3oG@03o`3oG@04o`3o3?oonf[o001oo`00O`WoU?l02?oonfX00ol0003oiOl0onGo
0003onGo01?ooo]Z0_oUo`000ol0ol;ooo]ZoookJP02oookJP03ocl0oooonf[ooo]Z03;ooo]Z1_oo
b@0AoookJP03ool0Dooonf[ooo]Z01Cooo]Z1ooob@0FoookJP03oeKo0?oonf[ooo]Z01;ooo]Z00?o
07SooookJ_oonfX0[OoonfX2ool0;@;o0?o^HOoonfX3o`00O`03o`3ok_oo02gooo]Z00;o001o00_o
oa/0om;o0?oonf[o0>_ooh3o0?ookP3oK_l0oigo0?l04?oo001oo`0Lo`02oookJP?o001o0_oonfX2
o`00O`03okCo0?oonf[ooo]Z00Wooo]Z0ol000000ol01ooooo]ZoookJP0DoookJP03oonW0?l0ol;o
oo]Z00Cooo]Z00?o?`3ooookJ_oonfX0<ooonfX00ooo803ooo]ZoookJP0CoookJP03ool0Dooonf[o
oo]Z01Gooo]Z00?ooc`0oookJ_oonfX06OoonfX00omFo`3ooo]ZoookJP0AoookJP03o`1hoooonf[o
oo]Z04?ooo]Z001[oookJP?oo`0]00?o0?o^oookJ_oonfX0HooonfX3o`00O`;oo`0]00?oU?l0odCo
0?m4o`000_m4o`02o`3oG@03o`3o1?m^o`3o0?mM00Co0?mM00Cooo]Zo`00Ool007oo001o2?nDo`08
oookJP03o`000?oUo`3oiOl000;oiOl05?oonfX00ooUo`3o0?o2oookJP03oookJP03ocl0oooonf[o
oo]Z03;ooo]Z1_oob@0AoookJP03ool0Dooonf[ooo]Z01Cooo]Z1ooob@0FoookJP03oeKo0?oonf[o
oo]Z01;ooo]Z00?o07SooookJ_oonfX0ZooonfX3ool0;@03o`3ok_oonf[ooo]Z06?ooo]Z0ol007l0
3ooonf[oo`0]o`00Ool007oooo]ZoolK0?oBo`3ooo]Zo`3[oon0o`3oK_l0o`1HoomKo`3o001oo`0L
o`02oookJP?o001o0_oonfX2o`00O`03okCo0?oonf[ooo]Z00Wooo]Z0ol000000ol01ooooo]Zoook
JP0CoookJP03oonW0?oonf[o0?o200Cooo]Z00?o?`3ooookJ_oonfX0<ooonfX00ooo803ooo]Zoook
JP0CoookJP03ool0Dooonf[ooo]Z01Gooo]Z00?ooc`0oookJ_oonfX06OoonfX00omFo`3ooo]Zoook
JP0AoookJP03o`1hoooonf[ooo]Z04Cooo]Z001YoookJP;oo`0]0_l0oniWoookJP;o001o0onDo`06
odCo00;o0?mM00?o0?l4ofko0?l0oed00ol0oed3o`00O`03oookJ_nDo`3oU?l000KoU?l00_l007l6
oookJP03o`000?oUo`3oiOl000;oiOl05?oonfX00ol0ol;ooo]ZoookJP03oookJP03ocl0oooonf[o
oo]Z03;ooo]Z1?oob@0BoookJP03ool0Dooonf[ooo]Z01Cooo]Z1_oob@0GoookJP03oeKo0?oonf[o
oo]Z01;ooo]Z00?o07SooookJ_oonfX0Z_oonfX2ool0;@;o0?o^IooonfX5o`00O`0=ool0;Ol007oo
oo]ZoookJ_oo6`3od_l0oookJ_n0o`3o0?;oofko0?oo04;oFol0o`0Lo`04o`00O`Cooo]Z00?o001o
okCo0?l007l01?l007l6oookJP?o000000?o00OooookJ_oonfX04ooonfX00oooY`3o0?o2oookJP03
oookJP03ocl0oooonf[ooo]Z03?ooo]Z00?oob00oookJ_oonfX04ooonfX00ooo05?ooo]ZoookJP0E
oookJP03ooll0?oonf[ooo]Z01Wooo]Z00?oE_l0oookJ_oonfX04OoonfX00ol0N?oooo]ZoookJP15
oookJP00IooonfX2ool0;@03o`3ok_oonf[ooo]Z06Wooo]Z0onDo`07odCo0003o`3o3?l0oego0?mM
00Ko0?mM00Co0?l<oookJ_oonf[ooo]Z1_nDo`03o`00O`Kooo]Z00Co0000onGo0?oUo`3oiOl04Ooo
nfX2onGo0003oookJ_ooY`3o0?o200Cooo]Z00?o?`3ooookJ_oonfX0<_oonfX4ooo901;ooo]Z00?o
o`1CoookJ_oonfX05OoonfX4ooo901Sooo]Z00?oE_l0oookJ_oonfX04_oonfX00ol0N?oooo]Zoook
JP2YoookJP;oo`0]0_l0oniZoookJPGo001o0_oo02d2oookJP09oolK0?oBo`3o0>_ooh3o0?l0o`Co
K_l0oigo0?l007oo01co00;o001o1OoonfX2o`00O`03okCo0?l007oo001o00;o001o1_oonfX2o`00
0003o`07ool0003ooo]Z01?ooo]Z00?oojL0oookJ_l0ol801?oonfX00olo0?oooo]ZoookJP0coook
JP03oolP0?oonf[ooo]Z01;ooo]Z00?oo`1CoookJ_oonfX05OoonfX00ooo?03ooo]ZoookJP0Ioook
JP03oeKo0?oonf[ooo]Z017ooo]Z00?o07SooookJ_oonfX0A_oonfX006Cooo]Z0ooo02d00ol0onko
oo]ZoookJP1]oookJPSoA?l00_l0o``7o`3oG@04o`3o3?oonf[ooo]ZoookJPKoU?l02OoonfX01?l0
003oiOl0onGo0?oUo`0AoookJP?oiOl000?o0?o2oookJ_oonfX00_oonfX00olo0?oooo]ZoookJP0c
oookJP?oolT04_oonfX00ooo05?ooo]ZoookJP0EoookJPCoolT06?oonfX00omFo`3ooo]ZoookJP0B
oookJP03o`1hoooonf[ooo]Z0:Oooo]Z0ooo02d00ol0onkooo]ZoookJP1aoookJP0<o`3ok_oo02go
oo]ZoookJ_oo6`3od_l0o`3[oon0o`3oK_l0ool0@_mKo`3o01co2OoonfX00ondo`3ooo]ZoookJP08
oookJP;o000000?o00Ooo`000?oonfX04ooonfX00oooY`3o0?o2oookJP03oookJP03ocl0oooonf[o
oo]Z03?ooo]Z00?oob00oookJ_oonfX04_oonfX00ooo05?ooo]ZoookJP0EoookJP03ooll0?oonf[o
oo]Z01Wooo]Z00?oE_l0oookJ_oonfX04OoonfX00ol0N?oooo]ZoookJP17oookJP00H_oonfX2ool0
;@;o0?o^LooonfX7odCo00So0?mM00Co0?l<oookJ_oonf[ooo]Z1_nDo`09oookJP04o`000?oUo`3o
iOl0o`00017ooo]Z1OoUo`03oookJP03ocl0oooonf[ooo]Z03;ooo]Z0_oob@0CoookJP03ool0Dooo
nf[ooo]Z01Kooo]Z0_oob@0IoookJP03oeKo0?oonf[ooo]Z01;ooo]Z00?o07SooookJ_oonfX0Y_oo
nfX2ool0;@;o0?o^M_oonfX02ol0onkoo`0]oookJ_oonf[od_l0oookJ_n0o`3oonh0ofko0?nMo`3o
01co00Wooo]Z00?o]?l0oookJ_oonfX02?oonfX2o`000003o`07ool0003ooo]Z01;ooo]Z00?oojL0
o`3o`_oonfX01?oonfX00olo0?oooo]ZoookJP0boookJP03oolP0?oonf[ooo]Z01;ooo]Z00?oo`1C
oookJ_oonfX05OoonfX00ooo?03ooo]ZoookJP0IoookJP03oeKo0?oonf[ooo]Z017ooo]Z00?o07So
oookJ_oonfX0B?oonfX005oooo]Z0ooob@02o`3okWKooo]Z1_m4o`09o`3oG@;o0?l<0_oonfX5oiCo
00Wooo]Z00?o0000onGo0?oUo`000_l0000?oookJPOoiOl000?ooo]Zocl0oooonfX0=?oonfX00ooo
b@3ooo]ZoookJP0AoookJP03ool0Dooonf[ooo]Z01Kooo]Z00?oolT0oookJ_oonfX06?oonfX00omF
o`3ooo]ZoookJP0AoookJP;o07SoYooonfX2ool0;@;o0?o^NOoonfX02ol0onkoo`0]oookJ_oonf[o
d_l0oookJ_n0o`3oK_l0o`1HoomKo`3o01co00Sooo]Z00?o]?l0oookJ_oonfX02?oonfX00ol0003o
00Ooo`000002o`0001;ooo]Z00?oojL0o`3o`_oonfX00ooonfX00olo0?oooo]ZoookJP0boookJP03
oolP0?oonf[ooo]Z01;ooo]Z00?oo`1CoookJ_oonfX05OoonfX00ooo?03ooo]ZoookJP0IoookJP03
oeKo0?oonf[ooo]Z017ooo]Z00?o07SooookJ_oonfX0BOoonfX005_ooo]Z1_oob@000ol0onkooo]Z
oookJP1hoookJPCoA?l02Ol0oed01?l0ojgo0?l<oookJ_oonfX5oiCo00Wooo]Z00Co0000onGo0?l0
003o00004?oonfX8onGo0003ocl0oooonf[ooo]Z03;ooo]Z00?oolT0oookJ_oonfX04OoonfX00ooo
05?ooo]ZoookJP0EoookJP03ooll0?oob@3ooo]Z01Wooo]Z00?oE_l0oookJ_oonfX04OoonfX00ol0
N?oooo]ZoookJP2UoookJP;oo`0]0_l0oniloookJP0:o`3ok_oo02gooo]ZoookJ_oBo`3o0>_ooh3o
0?m^o`3oFol0o`0Lo`Sooo]Z00?o]?l0oookJ_oonfX02?oonfX01?l0003o00Ooo`000?l0000Boook
JP03oonW0?l0ol;ooo]Z00?ooo]Z00?o?`3ooookJ_oonfX0<_oonfX00ooo803ooo]ZoookJP0Boook
JP03ool0Dooonf[ooo]Z01Gooo]Z00?ooc`0oookJ_oonfX06OoonfX00omFo`3ooo]ZoookJP0Aoook
JP03o`1hoooonf[ooo]Z04[ooo]Z001HoookJPSoolT0O_oonfX3odCo00So0?mM00?o0?n]o`3oGOoo
nfX00_oonfX4oiCo00Wooo]Z00Co0000o`07ool0003o00004?oonfX7onGo0003ocl0oooonf[ooo]Z
03?ooo]Z00?oob00oookJ_oonfX04?oonfX00ooo05?ooo]ZoookJP0EoookJP03ooll0?oonf[ooo]Z
01Wooo]Z00?oE_l0oookJ_oonfX04OoonfX00ol0N?oooo]ZoookJP2UoookJP03ool0;Ol0onko0?o^
07oooo]Z00[o0?o^ool0;Ooonf[ooa/0om;o0?l0jooo0?l4ofko0?mKo`3o01co1ooonfX00ondo`3o
oo]ZoookJP08oookJP04o`000?l01ooo0000o`0001;ooo]Z00?o0?o2oookJ_oonfX00ooonfX00olo
0?oooo]ZoookJP0boookJP03oolP0?oonf[ooo]Z017ooo]Z00?oo`1CoookJ_oonfX05OoonfX00ooo
?03ooo]ZoookJP0IoookJP03oeKo0?oonf[ooo]Z017ooo]Z00?o07SooookJ_oonfX0BooonfX005Co
oo]Z2ooob@20oookJP?oA?l01ol0oed00ol0ojgo0?mMo`3o3002oookJPCoU?l02OoonfX01?l0003o
00Ooo`000?l0000@oookJPOoiOl000?o?`3ooookJ_oonfX0<_oonfX00ooo803ooo]ZoookJP0@oook
JP03ool0Dooonf[ooo]Z01Gooo]Z00?ooc`0oookJ_oonfX06?oonfX2oeKo01?ooo]Z00?o07Sooook
J_oonfX0Y?oonfX2ool0;@03o`3ok_oonf[ooo]Z087ooo]Z00Woo`0]oookJ_oo6`3od_l0oh3o0?m^
o`3oo`12oe_o0?l07?l01_oonfX00ondo`3ooo]ZoookJP08oookJP04o`000?l01ooo0000o`00017o
oo]Z00?oojL0o`3o`_oonfX00ooonfX00olo0?oooo]ZoookJP0boookJP03oolP0?oonf[ooo]Z017o
oo]Z00?oo`1CoookJ_oonfX05OoonfX00ooo?03ooo]ZoookJP0HoookJP;oE_l04ooonfX00ol0N?oo
oo]ZoookJP1<oookJP00D_oonfX<ooo908?ooo]Z00?oA?l0o`3o[Ol0oed01_l0oed2o`3o[@?ooo]Z
0_nDo`0:oookJP04o`07ool0003o0000o`0000oooo]Z1ooUo`000olo0?oooo]ZoookJP0boookJP03
oolP0?oonf[ooo]Z013ooo]Z00?oo`1CoookJ_oonfX05OoonfX00ooo?03ooo]ZoookJP0HoookJP03
oeKo0?oonf[ooo]Z01;ooo]Z00?o07SooookJ_oonfX0XooonfX2ool0;@;o0?o^Q?oonfX02Ooo02go
0?o^oookJ_oo6`3od_l0o`1Hoom^o`3oWOl0o`0Lo`06oookJP03okCo0?oonf[ooo]Z00Sooo]Z00Co
0000o`07ool0003o00004OoonfX00ol0ol;ooo]ZoookJP02oookJP03ocl0oooonf[ooo]Z03;ooo]Z
00?oob00oookJ_oonfX04OoonfX00ooo05?ooo]ZoookJP0EoookJP03ooll0?oonf[ooo]Z01Sooo]Z
00?oE_l0oookJ_oonfX04_oonfX00ol0N?oooo]ZoookJP1=oookJP00D_oonfX;ooo908Gooo]Z00?o
A?l0o`3o[Ol0oed01Ol0oed2o`3o[@?ooo]Z0_nDo`0:oookJP04o`07ool0003o0000o`0000oooo]Z
1_oUo`000ooonf[o?`3ooookJP0boookJP03oolP0?oonf[ooo]Z013ooo]Z00?oo`1CoookJ_oonfX0
5OoonfX00ooo?03ooo]ZoookJP0HoookJP03oeKo0?oonf[ooo]Z01;ooo]Z00?o07SooookJ_oonfX0
XooonfX00ooo02go0?o^o`3okP27oookJP;oo`0]00Oooo]Zom;o0?n0o`3oK_l0ool0@_mKo`3o01co
00Gooo]Z00?o]?l0oookJ_oonfX02?oonfX01?l0003o00Ooo`000?l0000@oookJP03oonW0?l0ol;o
oo]Z00?ooo]Z00?o?`3ooookJ_oonfX0<OoonfX00ooo803ooo]ZoookJP0AoookJP03ool0Dooonf[o
oo]Z01Gooo]Z00?ooc`0oookJ_oonfX06?oonfX00omFo`3ooo]ZoookJP0BoookJP03o`1hoooonf[o
oo]Z04kooo]Z001CoookJPWoolT0QooonfX00ol0oego0?n]o`3oG@04o`3oG@;o0?n]00?o0?mMoook
J_oonfX00_nDo`0:oookJP04o`07ool0003o0000o`0000oooo]Z00?oiOl0ooo90?oob@000_oUo`00
0ooonf[o?`3ooookJP0boookJP03oolP0?oonf[ooo]Z013ooo]Z00?oo`1CoookJ_oonfX05OoonfX0
0ooo?03ooo]ZoookJP0HoookJP03oeKo0?oonf[ooo]Z01;ooo]Z00?o07SooookJ_oonfX0X_oonfX2
ool0;@03o`3ok_oonf[ooo]Z08Wooo]Z00Ooo`0]oolK0?oBo`3oP?l0ofko0?nMo`3o01co00Gooo]Z
00?o]?l0oookJ_oonfX02?oonfX01?l0003o00Ooo`000?l0000@oookJP03oonW0?l0ol;ooo]Z00;o
oo]Z00?o?`3ooookJ_oonfX0<OoonfX00ooo803ooo]ZoookJP0AoookJP03ool0Dooonf[ooo]Z01Go
oo]Z00?ooc`0oookJ_oonfX06?oonfX00omFo`3ooo]ZoookJP0BoookJP03o`1hoooonf[ooo]Z04oo
oo]Z001CoookJPSoolT0QooonfX01?m4o`3o0?mMo`3o3?l0ojd5o`3oG@?o0?n]0_oonfX01?nDo`3o
A?l0odCo0?m4o`07oookJP04o`07ool0003o0000o`0000kooo]Z0_oUo`04ooo90003ocl0oooonf[o
oo]Z037ooo]Z00?oob00oookJ_oonfX04?oonfX00ooo05?ooo]ZoookJP0EoookJP03ooll0?oonf[o
oo]Z01Sooo]Z00?oE_l0oookJ_oonfX04_oonfX00ol0N?oooo]ZoookJP2QoookJP;oo`0]00?o0?o^
oookJ_oonfX0S?oonfX01_oo02gooa/0om;o0?m^o`3o05Soo`0Lo`Kooo]Z00?o]?l0oookJ_oonfX0
1ooonfX01?l0003o00Ooo`000?l0000?oookJP03oonW0?l0ol;ooo]Z00;ooo]Z00?o?`3ooookJ_oo
nfX0<_oonfX00ooo803ooo]ZoookJP0@oookJP03ool0Dooonf[ooo]Z01Gooo]Z00?ooc`0oookJ_oo
nfX06?oonfX00omFo`3ooo]ZoookJP0BoookJP03o`1hoooonf[ooo]Z053ooo]Z001@oookJP;oogT0
2?oob@27oookJP;oA?l00_l0o``2o`3o[@?o0?mM1?l0ojd00ol0oegoA?l0odCo0003odCo00;ooo]Z
2?nDo`000ol0003ooo]ZoookJP0<oookJP;oiOl01Ooob@0boookJP03oolP0?oonf[ooo]Z013ooo]Z
00?oo`1CoookJ_oonfX05OoonfX00ooo?03ooo]ZoookJP0HoookJP03oeKo0?oonf[ooo]Z01;ooo]Z
00?o07SooookJ_oonfX0XOoonfX00ooo02go0?o^oookJP2?oookJP07o`3ok_oo02gooa/0om;o0?m^
o`3oFol0o`0Lo`05oookJP03okCo0?oonf[ooo]Z00Oooo]Z00Co00Ooo`000?l0003o00003ooonfX0
0oooY`3o0?o2oookJP02oookJP03ocl0oooonf[ooo]Z037ooo]Z00?oob00oookJ_oonfX04?oonfX0
0ooo05?ooo]ZoookJP0EoookJP03ooll0?oonf[ooo]Z01Sooo]Z00?oE_l0oookJ_oonfX04_oonfX0
0ol0N?oooo]ZoookJP1AoookJP00COoonfX3oomi0003ool0;Ooob@3oogT000;oogT01?oob@29oook
JP?o0?l<0ol0ojd00ol0oego0?n]o`3o[@03o`3o[@03o`3oGOm4o`3oA?l000?oA?l00_oonfX8oiCo
0003o`000?oonf[ooo]Z00cooo]Z00?oiOl0ooo90?oob@001_oob@0_oookJP03oolP0?oonf[ooo]Z
013ooo]Z00?oo`1CoookJ_oonfX05OoonfX00ooo?03ooo]ZoookJP0HoookJP03oeKo0?oonf[ooo]Z
017ooo]Z0_l0N?nRoookJP;oo`0]00?o0?o^oookJ_oonfX0T?oonfX01_oo02go0?o^om;o0?m^o`3o
05Soo`0Lo`Gooo]Z00?o]?l0oookJ_oonfX01ooonfX01?l01ooo0000o`000?l0000>oookJP03oonW
0?oonf[o0?o200;ooo]Z00?o?`3ooookJ_oonfX0<OoonfX00ooo803ooo]ZoookJP0@oookJP03ool0
Dooonf[ooo]Z01Gooo]Z00?ooc`0oookJ_oonfX06?oonfX00omFo`3ooo]ZoookJP0AoookJP;o07So
E?oonfX004Wooo]Z1OooN@02ool0;@CoogT000Cooo]Zooo90?oob@3oolT0S?oonfX2o`3o30Wo0?n]
1Om4o`02oookJPSoU?l00_l0000=oookJP03onGo0?oob@3oolT000OoolT0;OoonfX00ooo803ooo]Z
oookJP0@oookJP03ool0Dooonf[ooo]Z01Gooo]Z00?ooc`0oookJ_oonfX06?oonfX00omFo`3ooo]Z
oookJP0AoookJP03o`1hoooonf[ooo]Z0:3ooo]Z0_oo02d00ol0onkooo]ZoookJP2CoookJP06ool0
;Ooo6`3od_l0ofko0?mKo`3o01co1?oonfX00ondo`3ooo]ZoookJP07oookJP03o`07ool0003o0000
00;o00003OoonfX00oooY`3o0?o2oookJP02oookJP03ocl0oooonf[ooo]Z033ooo]Z00?oob00oook
J_oonfX04?oonfX00ooo05?ooo]ZoookJP0EoookJP03ooll0?oonf[ooo]Z01Sooo]Z00?oE_l0oook
J_oonfX04OoonfX00ol0N?oooo]ZoookJP1DoookJP00AooonfX6oomi0003ool0;OooN@3oogT000?o
ogT00ooonfX00ooob@3ooo]ZoookJP2<oookJP03o`3o3?l0ojgo0?n]00Oo0?n]00?o0?onodCo0?m4
o`000_m4o`03oookJPKoU?l00_l00008oookJP;oU?l00ooonfX2onGo00SoolT0;OoonfX00ooo803o
oo]ZoookJP0@oookJP03ool0Dooonf[ooo]Z01Gooo]Z00?ooc`0oookJ_oonfX06?oonfX00omFo`3o
oo]ZoookJP0AoookJP03o`1hoooonf[ooo]Z0:3ooo]Z00?oo`0]o`3ok_oonfX0UooonfX01Ooo02go
d_l0o`3o1?m^o`3o01co00Cooo]Z00?o]?l0oookJ_oonfX01_oonfX00ol01ooo0000o`000002o`00
00gooo]Z00?oojL0o`3o`_oonfX00_oonfX00olo0?oooo]ZoookJP0_oookJP;oob004_oonfX00ooo
05?ooo]ZoookJP0EoookJP03ooll0?oonf[ooo]Z01Sooo]Z00?oE_l0oookJ_oonfX04OoonfX00ol0
N?oooo]ZoookJP1EoookJP00AooonfX4oomi00;oo`0]1OooN@2DoookJP03o`2`ool0ojgo0?n]00Ko
0?n]00?o0?onodCo0?m4o`000_m4o`03oookJPKoU?l00_l00008oookJPCoU?l000?ooo]ZonGo0?oo
nfX01ooob@0]oookJP03oolP0?oonf[ooo]Z013ooo]Z00?oo`1CoookJ_oonfX05OoonfX00ooo?03o
oo]ZoookJP0HoookJP03oeKo0?oonf[ooo]Z017ooo]Z00?o07SooookJ_oonfX0WooonfX2ool0;@03
o`3ok_oonf[ooo]Z09Sooo]Z00Goo`0]om;o0?l0o`CoK_l0o`0Lo`03oookJP03okCo0?oonf[ooo]Z
00Kooo]Z00?o00Ooo`000?l000000_l0000=oookJP05o`3o`_oonf[ooo]ZoookJ_lo0?l0<OoonfX0
0ooo803ooo]ZoookJP0AoookJP03ool0Dooonf[ooo]Z01Gooo]Z00?ooc`0oookJ_oonfX06?oonfX0
0omFo`3ooo]ZoookJP0AoookJP03o`1hoooonf[ooo]Z05Kooo]Z0018oookJP03oomi0?oo02goo`0]
00KoogT0UOoonfX00ol0ojgo0?l<o`3o[@07o`3o[@04o`3oo_m4o`3oA?l0odCo00?ooo]Z1_nDo`02
o`0000Sooo]Z1OnDo`000ol0ol;oolT0ooo90005ooo902gooo]Z00?oob00oookJ_oonfX04?oonfX0
0ooo05?ooo]ZoookJP0EoookJP03ooll0?oonf[ooo]Z01Sooo]Z00?oE_l0oookJ_oonfX04OoonfX0
0ol0N?oooo]ZoookJP2NoookJP;oo`0]00?o0?o^oookJ_oonfX0VooonfX01?oo02goP?l0ofko0?mK
o`03oookJP03okCo0?oonf[ooo]Z00Kooo]Z00?o00Ooo`000?l000000_l0000<oookJP03oonW0?l0
ol;ooo]Z00;ooo]Z00?o?`3ooookJ_oonfX0;_oonfX00ooo803ooo]ZoookJP0AoookJP03ool0Dooo
nf[ooo]Z01Gooo]Z00?ooc`0oookJ_oonfX06?oonfX00omFo`3ooo]ZoookJP0AoookJP03o`1hoooo
nf[ooo]Z05Oooo]Z0018oookJP03ool0;OooN@3oogT000GoogT0V?oonfX00ol0ooko0?n]o`3o[@05
o`3o[@04o`3oo_l0/?ooA?l0odCo00?ooo]Z1_nDo`02o`0000Sooo]Z1?nDo`000ol0ol;oU?l0ooo9
0005ooo902gooo]Z00?oob00oookJ_oonfX04?oonfX00ooo05?ooo]ZoookJP0EoookJP03ooll0?oo
nf[ooo]Z01Sooo]Z00?oE_l0oookJ_oonfX04OoonfX00ol0N?oooo]ZoookJP2NoookJP03ool0;Ol0
onko0?o^09kooo]Z00Co0?o^ool0;Ol0o`CoK_l01?oonfX00ondo`3ooo]ZoookJP05oookJP03o`07
ool0003o000000;o00003?oonfX01Ol0ol;ooo]ZoookJ_oonf[o?`3o033ooo]Z00?oob00oookJ_oo
nfX04OoonfX00ooo05?ooo]ZoookJP0EoookJP03ooll0?oonf[ooo]Z01Sooo]Z00?oE_l0oookJ_oo
nfX04OoonfX00ol0N?oooo]ZoookJP1HoookJP00A_oonfX2ool0;@OoogT0VOoonfX2o`3ooPGo0?n]
0_l0ooh2o`3o[@04odCo0?l0o`co0?l<oookJPGoU?l00ol00007oookJPGoU?l000?o0?o2oiCo0?oo
b@001?oob@0]oookJP03oolP0?oonf[ooo]Z013ooo]Z00?oo`1CoookJ_oonfX05OoonfX00ooo?03o
oo]ZoookJP0HoookJP03oeKo0?oonf[ooo]Z017ooo]Z00?o07SooookJ_oonfX0WOoonfX2ool0;@03
o`3ok_oonf[ooo]Z09oooo]Z00Coo`0]om;o0?m^o`3oFol00ooonfX00ondo`3ooo]ZoookJP05oook
JP03o`07ool0003o000000;o00002ooonfX00oooY`3o0?o2oookJP02oookJP03ocl0oooonf[ooo]Z
02gooo]Z00?oob00oookJ_oonfX04OoonfX00ooo05?ooo]ZoookJP0EoookJP03ooll0?oonf[ooo]Z
01Sooo]Z00?oE_l0oookJ_oonfX04OoonfX00ol0N?oooo]ZoookJP1IoookJP00A?oonfX2ool0;@;o
ogT00_oonfX4oomi09Wooo]Z00Co0?l<o`3oGOl0ooko0?on0ol0ojd4o`3ooP04o`1Oool0/?oo0?l<
o`3o30;ooo]Z1?nDo`03o`0000Oooo]Z1?nDo`000ol0ol;oU?l0ooo90004ooo902gooo]Z00?oob00
oookJ_oonfX04?oonfX00ooo05?ooo]ZoookJP0EoookJP03ooll0?oonf[ooo]Z01?ooo]Z00?oolT0
oookJ_oonfX00_oonfX00omFo`3ooo]ZoookJP0@oookJP;o07SoW_oonfX2ool0;@03o`3ok_oonf[o
oo]Z0:;ooo]Z00?oo`0]ofko0?l0F?l00ooonfX00ondo`3ooo]ZoookJP05oookJP03o`07ool0003o
000000;o00002ooonfX01Ol0ol;ooo]ZoookJ_oonf[o?`3o02oooo]Z00?oob00oookJ_oonfX04Ooo
nfX00ooo05?ooo]ZoookJP0EoookJP03ooll0?oonf[ooo]Z01Sooo]Z00?oE_l0oookJ_oonfX04?oo
nfX2o`1hoecooo]Z0013oookJP03ool0;Ol0onkoogT000Cooo]Z0oooN@2LoookJP03o`3oGOl0ooko
0?on00Ko0?on0ol0/?l00ol0o`cooo]ZodCo0004odCo00?o00001_oonfX5oiCo0003o`3o`_nDo`3o
olT000?oolT0;OoonfX00ooo803ooo]ZoookJP0;oookJP03oomi0?oonf[ooo]Z00;ooo]Z00?oo`1C
oookJ_oonfX05OoonfX00ooo?03ooo]ZoookJP0DoookJP03ooo90?oonf[ooo]Z00;oolT04_oonfX0
0ol0N?oooo]ZoookJP2MoookJP03ool0;Ol0onko0?o^0:Gooo]Z00Co0?o^ool0;Om^o`3o05So0_oo
nfX00ondo`3ooo]ZoookJP05oookJP03o`07ool0003o000000;o00002_oonfX00oooY`3o0?o2oook
JP02oookJP03ocl0oooonf[ooo]Z02cooo]Z00?oob00oookJ_oonfX04OoonfX00ooo05?ooo]Zoook
JP0EoookJP03ooll0?oonf[ooo]Z01Oooo]Z0_mFo`0BoookJP03o`1hoooonf[ooo]Z05cooo]Z0011
oookJP;oo`0]00?o0?o^oookJ_oonfX01OoonfX00oooN@3ooo]ZoookJP2LoookJPWo0?on0_l0/?l0
0ol0o`coA?l0odCo0004odCo00?o00001_oonfX4oiCo0003o`3o`_nDo`3oU?l000?oolT0;OoonfX0
0ooo803ooo]ZoookJP0<oookJP05oomi0?oonf[ooo]ZoookJ_oo05<05ooonfX00ooo?03ooo]Zoook
JP0DoookJPCoolT04ooonfX00ol0N?oooo]ZoookJP2LoookJP;oo`0]00?o0?o^oookJ_oonfX0Y_oo
nfX01?oo02god_l0ofko0?l07?l2oookJP03okCo0?oonf[ooo]Z00Cooo]Z00?o00Ooo`000?l00000
0_l0000:oookJP05o`3o`_oonf[ooo]ZoookJ_lo0?l0;_oonfX00ooo803ooo]ZoookJP0AoookJP03
ool0Dooonf[ooo]Z01Gooo]Z00?ooc`0oookJ_oonfX05ooonfX00omFo`3ooo]ZoookJP0AoookJP03
o`1hoooonf[ooo]Z05gooo]Z000ooookJP;oo`0]0_l0onjWoookJPWo0?on0_l0/?l00ol0o`coA?l0
odCo0004odCo00?o00001_oonfX7oiCo00;oolT0;OoonfX00ooo803ooo]ZoookJP0<oookJP?oogT0
00?ooo]Zool0DooonfX05_oonfX00ooo?03ooo]ZoookJP0DoookJPGoolT04_oonfX00ol0N?oooo]Z
oookJP2KoookJP;oo`0]0_l0onjZoookJP03ool0;Ol0F?ooK_l000;ooo]Z00?o]?l0oookJ_oonfX0
0ooonfX00ol01ooooo]Zo`000003o`0000Wooo]Z00?o0?o2oookJ_oonfX00_oonfX00olo0?oooo]Z
oookJP0/oookJP03oolP0?oonf[ooo]Z013ooo]Z00?oo`1CoookJ_oonfX05OoonfX00ooo?03ooo]Z
oookJP0GoookJP03oeKo0?oonf[ooo]Z017ooo]Z00?o07SooookJ_oonfX0G_oonfX003kooo]Z00?o
o`0]oookJ_l0onh0ZOoonfX9o`3ooP?o0;3o00?o0?mModCo0?m4o`000om4o`03o`0000Gooo]Z1onD
o`02ooo902gooo]Z00?oob00oookJ_oonfX03?oonfX5oomi01Oooo]Z00?ooc`0oookJ_oonfX05Ooo
nfX6ooo9013ooo]Z00?o07SooookJ_oonfX0VooonfX00ooo02go0?o^o`3okP2]oookJP05ool0;Om^
o`3o01cooookJ_ndo`001OoonfX00ol01ooooo]Zo`000003o`0000Wooo]Z00Go0?o2oookJ_oonf[o
oo]Zocl0o`0^oookJP03oolP0?oonf[ooo]Z013ooo]Z00?oo`1CoookJ_oonfX05OoonfX00ooo?03o
oo]ZoookJP0GoookJP03oeKo0?oonf[ooo]Z017ooo]Z00?o07SooookJ_oonfX0GooonfX003gooo]Z
00?oo`0]o`3ok_l0onh0XooonfX2odCo00Kooo]Z00?o0;3oo`3oo_l0ooh00_l0ooh5o`2`o`;o05oo
00GoA?l0o`3o3?l0o`co0?l<odCo0004o`0000Cooo]Z0_nDo`02onGo00?oU?l000?oolT0oiCo0?oo
nfX0:ooonfX00ooo803ooo]ZoookJP0=oookJPKoogT05OoonfX00ooo?03ooo]ZoookJP0EoookJPSo
olT03_oonfX00ol0N?oooo]ZoookJP2JoookJP;oo`0]00?o0?o^oookJ_oonfX0[_oonfX01Ooo04;o
K_l0oookJ_oonf[o]?l000Cooo]Z00?o00OooookJ_l000001?l00007oookJP05o`3o`_oonf[ooo]Z
oookJ_lo0?l0;_oonfX00ooo803ooo]ZoookJP0@oookJP03ool0Dooonf[ooo]Z01Gooo]Z00?ooc`0
oookJ_oonfX05ooonfX00omFo`3ooo]ZoookJP0AoookJP03o`1hoooonf[ooo]Z063ooo]Z000koook
JP;oo`0]00?o0?o^oookJ_oonfX0XooonfX3odCo00Kooo]Z00?o0?n]o`3oo_l0/?l01_l0/?l4o`1O
o`;o0?l<1?l00003oookJP;oA?l00_nDo`03onGo00;oU?l000?o?`3ooookJ_oonfX0:_oonfX00ooo
803ooo]ZoookJP0=oookJPSoogT04ooonfX00ooo?03ooo]ZoookJP0EoookJP[oolT03?oonfX00ol0
N?oooo]ZoookJP2JoookJP03ool0;Ol0onko0?o^0;;ooo]Z00CoK_l0o`1Hoooonf[o]?l01?oonfX0
0ol01ooooo]Zo`000003o`0000Oooo]Z00?oojL0o`3o`_oonfX00_oonfX00olo0?oooo]ZoookJP0[
oookJP03oolP0?oonf[ooo]Z013ooo]Z00?oo`1CoookJ_oonfX05OoonfX00ooo?03ooo]ZoookJP0G
oookJP03oeKo0?oonf[ooo]Z017ooo]Z00?o07SooookJ_oonfX0HOoonfX002[ooo]Z0ol007l=oook
JP03ool0;Ol0onko0?o^01Gooo]Z1Ol007l4oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol007lMoook
JPGo001o1?oonfX3o`00O`?ooo]Z1Ol007lMoookJPGo001o1?oonfX3o`00O`03oookJ_l007oo001o
00Oo001o0ooonfX5o`00O`Oooo]Z1Om4o`03oookJP03o`3o3?l0ooko0;3o00Ko0;3o1Ol0Gol2o`3o
30Co00000ooonfX2odCo00;oU?l01OoUo`0IoookJPGo001o1?oonfX3o`00O`03oookJ_l007oo001o
00Co001o00?oob00o`00Ool007l00ooonfX5o`00O`Kooo]Z2OooN@0>oookJP?o001o00?ooc`0o`00
OooonfX00ooonfX3o`00O`?ooo]Z1Ol007l7oookJPWoolT03?oonfX2o`1ho`Co001o1?oonfX3o`00
O`?ooo]Z0ol007l7oookJPGo001o9_oonfX3o`00OdKooo]Z0ol007l=oookJP03ool0;Ol0onkooo]Z
01Cooo]Z1Ol007l4oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol007lMoookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007lMoookJPGo001o1?oonfX3o`00O`03oookJ_l007oo001o00Oo001o0ooonfX5o`00
OaGooo]Z00Coo`0]ofko0?oonf[o]?l01?oonfX00ol01ooooo]Zo`000003o`0000Oooo]Z00GoojL0
o`3o`_oonf[ooo]Zocl0o`0IoookJPGo001o1?oonfX3o`00O`03oookJ_l007oo001o00Go001o00?o
ob00o`00OooonfX00_oonfX5o`00O`Sooo]Z0_oo05<CoookJPCo001o00?ooc`0oookJ_oonfX00_oo
nfX3o`00O`?ooo]Z1Ol007l:oookJP03oeKo0?oonf[ooo]Z013ooo]Z0_l0N?l3o`00O`Cooo]Z0ol0
07l3oookJP?o001o1ooonfX5o`00ObOooo]Z0ol007lNoookJP00:_oonfX3o`00O`cooo]Z00?oo`0]
o`3ok_oonfX05OoonfX7o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX7o`00Oa_ooo]Z1ol007l3
oookJP?o001o0_oonfX7o`00Oa_ooo]Z1ol007l3oookJP?o001o00?ooo]Zo`00Ool007l01ol007l2
oookJPOo001o1OoonfX8odCo00?o0?l<1Ol0/?l6o`1Oo`?o00oo1?l000001?oonf[oA?l0odCo0?m4
o`02oiCo00OoiOl05ooonfX7o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`03o`00O`04oolP0?l0
07oo001oo`00O`;ooo]Z1ol007l4oookJPSoogT03ooonfX2o`00O`;ooc`00ol007l3oookJP?o001o
0_oonfX7o`00O`Kooo]Z1ooob@0=oookJP03o`1hool007oo001o00Go001o0ooonfX3o`00O`?ooo]Z
0ol007l6oookJPOo001o9OoonfX3o`00OdKooo]Z0ol007l;oookJP;oo`0]00?o0?o^oookJ_oonfX0
4ooonfX7o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX7o`00Oa_ooo]Z1ol007l3oookJP?o001o
0_oonfX7o`00Oa_ooo]Z1ol007l3oookJP?o001o00?ooo]Zo`00Ool007l01ol007l2oookJPOo001o
5OoonfX00ol0F?ooK_l0okCo0004oookJP03o`07oooonf[o000000?o00001_oonfX01OooY`3o0?o2
oookJ_oonf[o?`3o01Wooo]Z1ol007l3oookJP?o001o00?ooo]Zo`00Ool007l01?l007l00ooo803o
001oo`00O`02oookJPOo001o1_oonfX00ooo05?ooo]ZoookJP0BoookJP?o001o0_oo?002o`00O`?o
oo]Z0ol007l2oookJPOo001o2?oonfX00omFo`3ooo]ZoookJP0@oookJP03o`1hool007oo001o00Co
001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPOo001o9_oonfX3o`00Oakooo]Z000ZoookJP?o001o
2_oonfX2ool0;@03o`3ok_oonf[ooo]Z01Gooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o0ooonfX3o`00O`Gooo]Z1?l007l01?oonf[o001oo`00Ool007lKoookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o6ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`Kooo]Z
1?l007l01?oonf[o001oo`00Ool007l5oookJPOoA?l01?l0o``01?l03ooo0;3oo`2`ool0/?l4o`1O
o`Ko00oo0_l00003o`3o30GoA?l02?oUo`0FoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`03oookJ_l007oo001o00;o001o00?oob00oookJ_oonfX00ooonfX4o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z1oooN@0AoookJP04o`00Oooo?03o001ooookJP?o001o0ooonfX3o`00O`03oook
J_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1OoonfX6ooo900kooo]Z00?o07SooookJ_l0
07l00_l007l01?oonf[o001oo`00Ool007l3oookJP?o001o0ooonfX3o`00O`Gooo]Z1?l007l01?oo
nf[o001oo`00Ool007lUoookJP?o001oA_oonfX3o`00O`[ooo]Z00?oo`0]o`3ok_oonfX05_oonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l3oookJP?o001o1OoonfX4o`00O`04oookJ_l0
07oo001oo`00Oa_ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool0
07l00_l007l01?oonf[o001oo`00Ool007lKoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`03oookJ_l007oo001o00;o001o1_oonfX4o`00O`04oookJ_l007oo001oo`00OaGooo]Z00Co
0?o^ofko0?l07?oo]?l00ooonfX00ol01ooooo]Zo`000003o`0000Kooo]Z00Go0?o2oookJ_oonf[o
oo]Zocl0o`0IoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o
00;o001o0_oo8004oookJPCo001o00Cooo]Zo`00Ool007oo001o1OoonfX00ooo05?ooo]ZoookJP0C
oookJP;o001o00?ooc`0oookJ_l007l00_l007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l0
1?oonf[o001oo`00Ool007l7oookJP03oeKo0?oonf[ooo]Z013ooo]Z00Go07Soo`00Ool007oo001o
oookJP03o`00O`?ooo]Z0ol007l3oookJP?o001o1OoonfX4o`00O`04oookJ_l007oo001oo`00ObKo
oo]Z0ol007lNoookJP006_oonfX:o`00O`Kooo]Z0ol007l9oookJP03ool0;Ol0onkooo]Z00_ooo]Z
2_l007l2oookJP?o001o0ooonfX3o`00O`Wooo]Z0_l007l5oookJP?o001o0ooonfX3o`00O`gooo]Z
2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o3OoonfX:o`00O`;ooo]Z
0ol007l3oookJP?o001o1ooonfX4o`00O`Gooo]Z0ol007l3oookJP?o001o1?oonfX6odCo00Go0?l<
00Co0?mMo`1Oool0/?oo0;3o0_l0Gol8o`0?o`;o00001?l0o``4odCo00SoiOl05OoonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o00?oob00o`00OooonfX01?oonfX3o`00O`?ooo]Z0ol007l2oookJPGo
ogT04_oonfX00ol007oooc`0o`00O`03oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l3oookJPGo
olT03ooonfX00ol0N?oooo]Zo`00O`02o`00O`?ooo]Z0ol007l9oookJP;o001o1OoonfX3o`00O`?o
oo]Z0ol007lToookJP?o001o=_oonfX:o`00O`Kooo]Z0ol007l8oookJP;oo`0]00?o0?o^oookJ_oo
nfX02OoonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o2OoonfX2o`00O`Gooo]Z0ol007l3oookJP?o
001o3OoonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l=oookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l7oookJPCo001o1OoonfX3o`00O`?ooo]Z0ol007lEoookJP03
o`1Hoom^o`3o]?l000?ooo]Z00?o00OooookJ_l000000ol00005oookJP05oonW0?l0ol;ooo]Zoook
J_lo0?l06OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o00?oob00o`00OooonfX01?oonfX3o`00
O`?ooo]Z0ol007l3oookJP03ool0Dooonf[ooo]Z01?ooo]Z0_l007l01?oo?03ooo]ZoookJ_oonfX3
o`00O`Kooo]Z0ol007l3oookJP?o001o1OoonfX00omFo`3ooo]ZoookJP0@oookJP04o`1hool007oo
001oo`00O`?ooo]Z0ol007l9oookJP;o001o1OoonfX3o`00O`?ooo]Z0ol007lUoookJP?o001o7_oo
nfX001[ooo]Z2_l007l6oookJP?o001o1ooonfX2ool0;@03o`3ok_oonf[ooo]Z00_ooo]Z2_l007l2
oookJP?o001o0ooonfX3o`00O`Wooo]Z0ol007l:oookJP?o001o3OoonfX:o`00O`;ooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`gooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol007l9
oookJP?o001o1?oonfX8odCo00;o0?l<0_l0oed01Ol03ooo05ooo`1Oool0/?oo05oo00So00oo1ol0
oed2o`3o3003odCo0?nDo`3oU?l000GoiOl05_oonfX3o`00O`?ooo]Z0ol007l8oookJP03oolP0?l0
07oo001o00;o001o2OoonfX3o`00O`03oookJ_ooN@3oogT000;oogT05?oonfX00ooo?03o001oo`00
O`03oookJP?o001o3?oonfX3o`00O`?ooo]Z0ooob@0@oookJP03o`1hoooonf[ooo]Z00?o001o0ooo
nfX3o`00O`Wooo]Z0ol007l:oookJP?o001o9?oonfX3o`00OcKooo]Z2_l007l6oookJP?o001o1ooo
nfX00ooo02go0?o^oookJP0<oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l9oookJP?o001o2_oo
nfX3o`00O`gooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l=oookJP[o001o0_oo
nfX3o`00O`?ooo]Z0ol007l8oookJPGo001o2OoonfX3o`00OaKooo]Z00?oK_l0oigo0?ndo`000_oo
nfX00ol01ooooo]Zo`000003o`0000Gooo]Z00Go0?o2oookJ_oonf[ooo]Zocl0o`0IoookJP?o001o
0ooonfX3o`00O`Sooo]Z00?oob00o`00Ool007l00_l007l9oookJP?o001o0_oonfX00ooo05?ooo]Z
oookJP0DoookJP03o`00Oooo?03o001o00?ooo]Z0ol007l<oookJP?o001o1?oonfX00omFo`3ooo]Z
oookJP0?oookJP;o07So00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Wooo]Z0ol007l:oookJP?o
001o9OoonfX3o`00Oakooo]Z000ZoookJP?o001o1_oonfX00ooo02go0?o^oookJP0JoookJP?o001o
0ooonfX3o`00O`Wooo]Z0ol007l:oookJP?o001o6OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
6OoonfX3o`00O`?ooo]Z0ol007l:oookJPCo001o2?oonfX3o`00O`?ooo]Z2om4o`02o`3o3006o`3o
GOl0ojgo05ooo`0?ool0/?oo05oo1ol03ol7o`3oG@;o0?l<00CoiOl0oiCo0?nDo`3oU?l00ooUo`0G
oookJP?o001o0ooonfX3o`00O`Oooo]Z00?oob00oookJ_oonfX01?l007l8oookJP?o001o00Cooo]Z
oomi0?ooN@3oogT04ooonfX2ooll00?o001o0ooonfX3o`00O`cooo]Z0ol007l2oookJP;oolT04Ooo
nfX01?l0N?oooo]ZoookJ_oonfX3o`00O`?ooo]Z0ol007l9oookJP?o001o2_oonfX3o`00ObCooo]Z
0ol007m6oookJP?o001o1OoonfX2ool0;A_ooo]Z0ol007l3oookJP?o001o2OoonfX3o`00O`[ooo]Z
0ol007lIoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lIoookJP?o001o0ooonfX3o`00O`[ooo]Z
1?l007l8oookJP?o001o2_oonfX5od;o00Oooo]Z00?oo`0]ofko0?ndo`000_oonfX00ol01ooooo]Z
o`000003o`0000Cooo]Z00GoojL0o`3o`_oonf[ooo]Zocl0o`0JoookJP?o001o0ooonfX3o`00O`Oo
oo]Z00?oob00oookJ_oonfX01?l007l8oookJP?o001o00?ooo]Zool0DooonfX05OoonfX2ooll00;o
001o0ooonfX3o`00O`cooo]Z0ol007l3oookJP03oeKo0?oonf[ooo]Z00oooo]Z00Co07SooookJ_oo
nf[ooo]Z0ol007l3oookJP?o001o2OoonfX3o`00O`[ooo]Z0ol007lUoookJP?o001o7_oonfX002[o
oo]Z0ol007l5oookJP03ool0;Ol0onkooo]Z01_ooo]Z0ol007l3oookJP?o001o2_oonfX2o`00O`Go
oo]Z0_l007l2oookJPCo001o6OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00OaWo
oo]Z0ol007l3oookJP?o001o2ooonfX3o`00O`;ooo]Z3?nDo`0=odCo0003o`3o[Ol0Gooo00oo00;o
00oo0_l0Gol6o`0?o`Oo0?mM0_l0o``2oiCo0004odCo0?nDo`3oU?l0onGo01Sooo]Z0ol007l3oook
JP?o001o1_oonfX00ooo803ooo]ZoookJP02oookJP?o001o0ooonfX2o`00O`;ooo]Z1?l007l2oomi
01Cooo]Z00?ooc`0oookJ_oonfX00ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l00omF
o`3oolT0oookJP0@oookJP;o07So1?oonfX3o`00O`?ooo]Z0ol007l:oookJP;o001o1OoonfX2o`00
O`;ooo]Z1?l007lToookJP?o001oA_oonfX3o`00O`Cooo]Z00?oo`0]o`3ok_oonfX06ooonfX3o`00
O`?ooo]Z0ol007l:oookJP;o001o1OoonfX2o`00O`;ooo]Z1?l007lIoookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007l2oookJPCo001o6OoonfX3o`00O`?ooo]Z0ol007l;oookJP?o001o0ooonfX2o`00
O`;ooo]Z1?l007l6oookJPCo@_l01OoonfX4od;o00Cooo]Z00KoK_l0ool0@_oonf[ooo]Zo`07oooo
nfX4o`0000Cooo]Z00Co0?o2oookJ_oonf[o?`3o6ooonfX3o`00O`?ooo]Z0ol007l6oookJP03oolP
0?oonf[ooo]Z00;ooo]Z0ol007l3oookJP;o001o0_oonfX4o`00O`03ool0Dooonf[ooo]Z01Cooo]Z
00?ooc`0oookJ_l007l00_l007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l00ooonf[oE_l0
oeKo000AoookJP03o`1hoooonf[ooo]Z00;ooo]Z0ol007l3oookJP?o001o2_oonfX2o`00O`Gooo]Z
0_l007l2oookJPCo001o9OoonfX3o`00Oakooo]Z000ZoookJP?o001o0ooonfX2ool0;Akooo]Z0ol0
07l3oookJP?o001o2_oonfX3o`00O`Cooo]Z1ol007lJoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0
07lJoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l00ooonf[oU?l0oiCo000<oiCo0003oookJ_m4
o`3oA?l000?oA?l00ol0o``01?l0oego0?n]o`3o[Ol0ojd4o`0?o`03o`1Oool03ooo00oo00Co00oo
1_l0oed3o`3o3004oiCo0?l0o`coA?l0odCo00;oU?l06?oonfX3o`00O`?ooo]Z0ol007l5oookJP03
oolP0?oonf[ooo]Z00Cooo]Z0ol007l2oookJPKo001o00?oo`1Coomi0?oonfX05?oonfX01?oo?03o
oo]ZoookJ_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o00?oE_l0oookJ_oonfX04?oonfX00ol0
N?oooo]ZoookJP04oookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l4oookJPOo001o9OoonfX3o`00
OdKooo]Z0ol007l3oookJP03ool0;Ooonf[ooo]Z01cooo]Z0ol007l3oookJP?o001o2_oonfX3o`00
O`Cooo]Z1ol007lJoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lJoookJP?o001o0ooonfX3o`00
O`cooo]Z0ol007l2oookJPOo001o0_oonfX5od;o00gooo]Z0_m2o`03oookJP05ofko0?ndo`3ooo]Z
o`07oooonfX01?l00003oookJP05oonW0?l0ol;ooo]ZoookJ_lo0?l06ooonfX3o`00O`?ooo]Z0ol0
07l5oookJP03oolP0?oonf[ooo]Z00Cooo]Z0ol007l2oookJPKo001o0_oo05<FoookJP03ooll0?oo
nf[ooo]Z00?o001o0ooonfX3o`00O`Oooo]Z1ol007l00ooonf[oE_l0oookJP0AoookJP03o`1hoooo
nf[ooo]Z00?ooo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`Cooo]Z1ol007lVoookJP?o001o7_oo
nfX002[ooo]Z0ol007l2oookJP03ool0;Ol0onkooo]Z01kooo]Z0ol007l3oookJP?o001o2ooonfX2
o`00O`Cooo]Z1_l007lKoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lKoookJP?o001o0ooonfX3
o`00O`Kooo]Z0ol007l3oookJP?o001o00?ooo]ZoiCo0?nDo`002_nDo`03oookJPOoA?l00ol0o``0
0ol0oego0?n]o`0?o`04o`0?o`03o`1Oool03ooo00oo00?o00oo1_l0oed2o`3o30;oU?l00_l0o``2
odCo00;oU?l05ooonfX3o`00O`?ooo]Z0ol007l4oookJP03oolP0?oonf[o001o00;o001o0ooonfX3
o`00O`;ooo]Z1Ol007l00ooo05?ooo]ZoookJP0DoookJP03ooll0?oonf[ooo]Z00;ooo]Z0ol007l3
oookJP?o001o1ooonfX6o`00O`03oeKo0?oonf[ooo]Z013ooo]Z00?o07SooookJ_oonfX01OoonfX3
o`00O`?ooo]Z0ol007l;oookJP;o001o1?oonfX6o`00ObKooo]Z0ol007m6oookJP?o001o00?ooo]Z
ool0;Ooo02d07ooonfX3o`00O`?ooo]Z0ol007l;oookJP;o001o1?oonfX6o`00Oa_ooo]Z0ol007l3
oookJP?o001o1ooonfX6o`00Oa_ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l2
oookJPKo001o0om2o`0DoookJP;o@_l000Kooo]Zo`1Hoom^o`3ooo]Zo`07oooonfX4o`0000?ooo]Z
00Co0?o2oookJ_oonf[o?`3o7?oonfX3o`00O`?ooo]Z0ol007l4oookJP03oolP0?oonf[o001o00;o
001o0ooonfX3o`00O`;ooo]Z1Ol007l00ooo05?ooo]ZoookJP0EoookJP04ooll0?oonf[ooo]Zoook
JP?o001o0ooonfX3o`00O`Oooo]Z1_l007l00ooonf[oE_l0oookJP0@oookJP;o07So1_oonfX3o`00
O`?ooo]Z0ol007l;oookJP;o001o1?oonfX6o`00ObOooo]Z0ol007lNoookJP009ooonfX6o`00O`03
oookJ_oo02gooo]Z023ooo]Z0ol007l3oookJP?o001o3?oonfX2o`00O`?ooo]Z0_l007lOoookJP?o
001o0ooonfX3o`00O`Oooo]Z0_l007lOoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o
001o0_oonfX9oiCo00Gooo]Z2_m4o`000ol0ojgo00ooo`0?o`0;o`0?o`Go0?mM0_l0o``00onDo`3o
0?l<o`3o3002o`3o30;oA?l00_nDo`0FoookJP?o001o0ooonfX3o`00O`?ooo]Z00?oob00oookJ_oo
nfX00ol007l3oookJP?o001o0_oonfX2o`00O`;ooo]Z00?oo`1CoookJ_oonfX04ooonfX2ooll00Go
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z0_mFo`0BoookJP03o`1hoooonf[ooo]Z00Ko
oo]Z0ol007l3oookJP?o001o3?oonfX2o`00O`?ooo]Z0_l007lWoookJPKo001o@ooonfX6o`00O`03
ool0;Ooonf[ooo]Z01oooo]Z0ol007l3oookJP?o001o3?oonfX2o`00O`?ooo]Z0_l007lOoookJP?o
001o0ooonfX3o`00O`Oooo]Z0_l007lOoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o
001o0_oonfX2o`00O`?ooo]Z00?o@_l0oookJ_oonfX05_oonfX2od;o0005oookJ_m^o`3o]?l0oook
J_l01ol01Ol000000ooonf[oojL0o`3o`P02oookJP03ocl0oooonf[ooo]Z01[ooo]Z0ol007l3oook
JP?o001o0ooonfX00ooo803ooo]ZoookJP03o`00O`?ooo]Z0ol007l2oookJP;o001o0_oonfX00ooo
05?ooo]ZoookJP0DoookJP;ooc`01?oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0ooonfX2oeKo
017ooo]Z00?o07SooookJ_oonfX01_oonfX3o`00O`?ooo]Z0ol007l<oookJP;o001o0ooonfX2o`00
ObSooo]Z1_l007lNoookJP009ooonfX5o`00O`;oo`0]8ooonfX3o`00O`04oookJ_l007oo001oo`00
O`gooo]Z0_l007l3oookJP;o001o8?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lP
oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`00O`;ooo]Z0ol007l2oookJPOoU?l01ooo
nfX:odCo00So00oo00?o05ooo`0?ool03ol00ol03ol5o`3oG@So0?l<0_m4o`0HoookJP?o001o00Co
oo]Zo`00OooUo`3o001o0ooonfX01?oo803ooo]ZoookJ_oonfX4o`00O`;ooo]Z0ol007l2oookJP;o
001o00?ooo]Zool0DooonfX05?oonfX00ooo?03ooo]ZoookJP06oookJP?o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX2o`00O`03oookJ_mFo`3ooo]Z01;ooo]Z00?o07SooookJ_oonfX02?oonfX3o`00
O`04oookJ_l007oo001oo`00O`gooo]Z0_l007l3oookJP;o001o9ooonfX6o`00Od?ooo]Z1?l007l2
ool0;B?ooo]Z0ol007l01?oonf[o001oo`00Ool007l=oookJP;o001o0ooonfX2o`00Ob3ooo]Z0ol0
07l01?oonf[o001oo`00Ool007l8oookJP;o001o8?oonfX3o`00O`04oookJ_l007oo001oo`00O`Oo
oo]Z1?l007l2oookJP?o001o0_oonfX2o`00O`03oookJ_m2o`3o@_l001_ooo]Z00Go@_l0oigo0?m^
o`3ooo]Zo`07o`04o`0000;ooo]Z00CoojL0o`3o`_oonf[o?`3o7_oonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z00Coob00oookJ_oonf[ooo]Z1?l007l2oookJP?o001o0_oonfX2o`00O`03oook
J_oo05?ooo]Z01Gooo]Z00?ooc`0oookJ_oonfX01OoonfX3o`00O`04oookJ_l007oo001oo`00O`So
oo]Z0_l007l2oookJP03oeKo0?oonf[ooo]Z013ooo]Z00?o07SooookJ_oonfX02?oonfX3o`00O`04
oookJ_l007oo001oo`00O`gooo]Z0_l007l3oookJP;o001o:?oonfX6o`00Oakooo]Z000YoookJP;o
001o00?oo`0]o`3ok_oonfX08ooonfX7o`00O`Oooo]Z2Ol007l3oookJPOo001o6_oonfX7o`00O`Wo
oo]Z1ol007lJoookJPOo001o2?oonfX7o`00O`?ooo]Z1_nDo`02o`00O`Kooo]Z2om4o`08o`0?o`03
o`1Oool03ooo00oo00;o00oo1?l0oed2o`3o3003oiCo0?l0o`co0?l<00Go0?l<0_m4o`0GoookJPGo
001o00GoiOl0o`00Oooonf[ooo]ZoolP0005oookJPOo001o1?oonfX00ol007ooo`1Co`00O`04o`00
Oa3ooo]Z00?ooc`0oookJ_oonfX01ooonfX7o`00O`Wooo]Z00?o001ooeKo0?l007l01?l007l>oook
JP03o`1hoooonf[ooo]Z00Wooo]Z1ol007l7oookJPWo001o0ooonfX7o`00Ob?ooo]Z1?l007m5oook
JP04o`00Oooo02go0?o^o`00Ob?ooo]Z1ol007l7oookJPWo001o0ooonfX7o`00Oa[ooo]Z1ol007l9
oookJPOo001o6_oonfX7o`00O`Sooo]Z1ol007l4oookJP03o`00Oom2o`3o001o00Co001o4?oonfX8
omX0o`05oookJ_m2o`3oK_l0ofko0?l01ol01?l000001Ooonf[oojL0o`3o`_oonf[o?`3o01oooo]Z
1ol007l2oookJP03oolP0?oonf[ooo]Z00?ooo]Z1ol007l4oookJP03o`00Oooo05?o001o00Co001o
4OoonfX00ooo?03ooo]ZoookJP06oookJPOo001o2OoonfX2o`00O`03oeKo0?l007oo001o00;o001o
3_oonfX00ol0N?oooo]ZoookJP09oookJPOo001o1ooonfX9o`00O`?ooo]Z1ol007lToookJPCo001o
7_oonfX002[ooo]Z00?oo`0]o`00Ool007l09OoonfX5o`00O`Sooo]Z2Ol007l3oookJPOo001o6ooo
nfX5o`00O`[ooo]Z1ol007lKoookJPGo001o2_oonfX5o`00O`?ooo]Z0_m2o`03oiCo00Co001o1_oo
nfX:odCo00?o0?on2ol03ol4o`3oG@_o0?l<6OoonfX3o`00O`?oiOl00_oo8007oookJPGo001o1Ooo
nfX00ooo05?o001oo`00O`04o`00O`oooo]Z00?ooc`0oookJ_oonfX02OoonfX5o`00O`Wooo]Z0_mF
o`06o`00O`cooo]Z0_l0N?l=oookJPGo001o2?oonfX9o`00O`?ooo]Z1ol007lToookJP?o001oAOoo
nfX01?oo02go001oo`00Ool007lToookJPGo001o2?oonfX9o`00O`?ooo]Z1ol007lKoookJPGo001o
2_oonfX7o`00Oa_ooo]Z1Ol007l:oookJPGo001o1?oonfX2od;o00Ko001o3OoonfX3omX0o`Oooo]Z
0ooJ0?l00om2o`3oK_l0o`07o`04o`000005oookJ_l0ol;ooo]ZoookJ_lo0?l08?oonfX5o`00O`03
oookJ_oo803oob0000Oooo]Z1Ol007l5oookJP03ool0Dol007oo001o00Co001o3ooonfX2ooll00[o
oo]Z1Ol007l:oookJP;oE_l01Ol007l<oookJP;o07So3OoonfX5o`00O`Sooo]Z2Ol007l3oookJPOo
001o9OoonfX3o`00Oakooo]Z000XoookJP;oo`0]ZOoonfX2od;o00;ooo]Z00?oU?l0oookJ_oonfX0
2_oonfX8odCo00;ooo]Z1?l0ooh00ol0Gooo00ooo`0?o`03o`0?o`04o`1Oool03ooo00ooo`0?o`Co
0?mM00?o0?l<oiCo0?l0o``01_l0o``MoookJPGoiOl04?oonfX2ool0DaGooo]Z00?ooc`0oookJ_oo
nfX05ooonfX00omFo`3ooo]ZoookJP0AoookJP03o`1hoooonf[ooo]Z09Oooo]Z0_oo02fZoookJP;o
@_l04ooonfX2omX0o`cooo]Z0_oJ0?l2ofko00Co000000CoojL0o`3o`_oonf[o?`3o9_oonfX00ooo
803ooo]ZoookJP0?oookJP;oo`1C5OoonfX00ooo?03ooo]ZoookJP0HoookJP03oeKo0?oonf[ooo]Z
013ooo]Z00?o07SooookJ_oonfX0LooonfX002Oooo]Z00?oo`0]oookJ_oonfX0YooonfX2od;o00oo
oo]Z0_nDo`03odCo0003oiCo0?oonf[ooo]Z00?ooo]Z1ol0ooh8o`0?o`?o0?mM2Ol0o``MoookJPOo
iOl03_oonfX00ooo05?ooo]ZoookJP0DoookJP03ooll0?oonf[ooo]Z01Oooo]Z00?oE_l0oookJ_oo
nfX04OoonfX00ol0N?oooo]ZoookJP2GoookJP03ool0;Ooonf[ooo]Z0:Sooo]Z0_m2o`0CoookJP;o
fP3o4?oonfX00om2o`3oK_l0o`07o`03o`000003o`3o`_oonf[o?`3o02Kooo]Z00?oob00oookJ_oo
nfX03ooonfX00ooo05?ooo]ZoookJP0DoookJP03ooll0?oonf[ooo]Z01Sooo]Z00?oE_l0oookJ_oo
nfX04?oonfX00ol0N?oooo]ZoookJP1doookJP009_oonfX00ooo02gooo]ZoookJP2WoookJP03od;o
0?oonf[ooo]Z00[ooo]Z2_nDo`09oookJPKo0?on1_l03ol3o`3oG@Oo0?l<7ooonfX8onGo00cooo]Z
00?oo`1CoookJ_oonfX05?oonfX00ooo?03ooo]ZoookJP0FoookJP;oE_l04_oonfX2o`1hoiWooo]Z
00?oo`0]oookJ_oonfX0YooonfX2od;o01?ooo]Z0_oJ0?lCoookJP;oK_l00ol000000ol0ol;ooo]Z
ocl0o`0UoookJP03oolP0?oonf[ooo]Z00oooo]Z00?oo`1CoookJ_oonfX05?oonfX00ooo?03ooo]Z
oookJP0GoookJP;oE_l04_oonfX00ol0N?oooo]ZoookJP1eoookJP009OoonfX00ooo02gooo]Zoook
JP2WoookJP03od;o0?oonf[ooo]Z00Sooo]Z3?nDo`08oookJP?o0?on00?o00oooookJ_oonfX00ol0
ooh00ol0Gooo00ooo`0?o`03o`0?o`;o0?mM1Ol0o``6oookJP?o0?mM5ooonfX:onGo00[ooo]Z00?o
o`1CoookJ_oonfX04ooonfX2ooll01Sooo]Z00?oE_l0oookJ_oonfX04OoonfX00ol0N?oooo]Zoook
JP2HoookJP03ool0;Ooonf[ooo]Z0:Oooo]Z00?o@_l0oookJ_oonfX04?oonfX3omX0oaKooo]Z00Ko
K_l0o`07ool0003o0?o2oookJ_lo0?lUoookJP03oolP0?oonf[ooo]Z00oooo]Z00?oo`1CoookJ_oo
nfX04ooonfX2ooll01Wooo]Z00?oE_l0oookJ_oonfX04OoonfX00ol0N?oooo]ZoookJP1foookJP00
cOoonfX2od;o00_ooo]Z2_nDo`0:oookJPOo0?on0_l03ol2o`3ooP04o`1Oool03oooK_l0ofko00;o
0?mM1?l0o``3oookJPOo0?mM5_oonfX9onGo00_ooo]Z00?oo`1CoookJ_oonfX04ooonfX00ooo?03o
oo]ZoookJP0GoookJP03oeKo0?oonf[ooo]Z017ooo]Z00?o07SooookJ_oonfX0oooonfY2oookJP;o
@_l04_oonfX00ooJ0?oooo]ZoookJP0GoookJP04o`1Hoom^o`3o0000o`3o`P;o?`3o9?oonfX00ooo
803ooo]ZoookJP0?oookJP03ool0Dooonf[ooo]Z01?ooo]Z00?ooc`0oookJ_oonfX06?oonfX00omF
o`3ooo]ZoookJP0@oookJP;o07SoNOoonfX00<cooo]Z00?o@_l0oookJ_oonfX03?oonfX8oiCo00_o
oo]Z2_l0ooh4o`0?o`03ofko0?l0oego?`3o00;o0?l<0_oonfX:o`3oGAGooo]Z1ooUo`0<oookJP;o
o`1C5OoonfX00ooo?03ooo]ZoookJP0GoookJP03oeKo0?oonf[ooo]Z017ooo]Z00?o07SooookJ_oo
nfX0oooonfY2oookJP03od;o0?oonf[ooo]Z013ooo]Z0_oJ0?lJoookJP05o`000?m^o`3oK_l0o`3o
`_lo0?l09?oonfX00ooo803ooo]ZoookJP0>oookJP;oo`1C5OoonfX00ooo?03ooo]ZoookJP0Goook
JP;oE_l04_oonfX00ol0N?oooo]ZoookJP1ioookJP008ooonfZXo`000003od;o0?l0003o000000go
00001onDo`0<o`0000ko0?on0_m^o`000ol0o`co0?mMo`3oG@0<o`3oGAGo00001OoUo`0=o`000003
ool0Dol0003o000001?o00000_oo?00Ho`0000;oE_l04_l00002o`1hoego0000?_oonfZXo`000003
od;o0?l0003o0000013o000000?ofP3oo`000?l000007?l00002ofko02?o00000_oo800@o`000003
ool0Dol0003o000001?o00000_oo?00Io`000003oeKo0?l0003o0000017o000000?o07Soo`000?l0
0000G?l0000NoookJP008ooonfZWo`000003od;o0?l0003o000000oo00001?nDo`0>o`0000oo0?on
0_oo?00>o`3oGACo00001?oUo`0=o`0000;oo`1C5Ol000000ooo?03o0000o`00000Go`000003oeKo
0?l0003o0000017o000000?o07Soo`000?l00000GOl0000noookJZOo000000?o@_l0o`000?l00000
4?l000000ooJ0?oo0000o`00000Mo`0000;ooc`08_l000000ooo803o0000o`00000?o`000003ool0
Dol0003o000001?o000000?ooc`0o`000?l000005ol00002oeKo01?o000000?o07Soo`000?l00000
GOl0000NoookJP008ooonfZUo`0000;oiOl04_l00003oiCo00oo00003Ol0ooh2o`3oG@03ooll0?l0
3ooo00oo00go0?mM4ol00002onGo00oo000000?oo`1Co`000?l000005?l000000ooo?03o0000o`00
000Go`000003oeKo0?l0003o0000017o000000?o07Soo`000?l00000G_l0000noookJZGo00000_m2
o`0Bo`000003omX0ool0003o000001go00000_l04?l00ooo?03o0000o`00000Oo`000003oolP0?l0
003o000000oo000000?oo`1Co`000?l000004ol000000ooo?03o0000o`00000Go`000003oeKo0?l0
003o000001;o000000?o07Soo`000?l00000G_l0000NoookJP008ooonfZRo`0000GoiOl04Ol00000
0ooJ0?oo0000oiCo000@o`0000So0?on00?o0?n]o`000?l000001?l0oed5o`0?o`;o05oo2Ol0oedA
o`000003oolP0?oUo`3o000000ko00000_oo05<Eo`0000;ooc`06Ol000000omFo`3o0000o`00000@
o`0000;o07SoHOl0000noookJZCo000000?o@_l0o`000?l000004Ol000000ooJ0?oo0000o`00000N
o`000004o`0@ool0003ooc`0ooll01ko00000_oo800@o`0000;oo`1C5?l00002ooll01Wo000000?o
E_l0o`000?l000004Ol00002o`1hof7o00007_oonfX002Gooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z02oooo]Z1_oUo`0@oookJP;ofP3o4ooonfX3
o`3ooP?o0?n]0ooonfX5o`3oG@;o00oo00?o05ooo`0?ool03ol00ol03ol2oookJP03o`1Oool0oego
0?mM00Co0?mM3ooonfX2oolP013ooo]Z00?oo`1CoookJ_oonfX00_oonfX00ol0003ooo]ZoookJP09
oookJP;oiOl01?oonfX00ooo?03ooo]ZoookJP0GoookJP;oE_l02?oonfX00ol0003ooo]ZoookJP07
oookJP03o`1hoooonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0o
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0b
oookJP03od;o0?l0003ooo]Z013ooo]Z0_oJ0?lPoookJP;o013o0_l00002ooll01cooo]Z00?oob00
oookJ_oonfX03_oonfX2ool0D`?ooo]Z00?o0000oookJ_oonfX03ooonfX00ooo?03ooo]ZoookJP0G
oookJP;oE_l02OoonfX00ol0003ooo]ZoookJP07oookJP03o`1hoooonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0MoookJP00`OoonfX7onGo013ooo]Z00?ofP3ooook
J_oonfX04ooonfX2o`3o[@Kooo]Z1_l0oed2o`0?o`03o`2`ool03ooo00oo00Go00oo1OoonfX2o`3o
G@gooo]Z0_nDo`0<oookJP;oolT00ooonfX00ooo05?ooo]ZoookJP0>oookJP?oiOl00_oonfX2ooll
01Wooo]Z00?oE_l0oookJ_oonfX04OoonfX00ol0N?oooo]ZoookJP3ooookJT?ooo]Z00?o@_l0oook
J_oonfX04?oonfX00ooJ0?oooo]ZoookJP0PoookJP06o`0@ool0003o0000o`000?l0odKooc`06_oo
nfX2oolP013ooo]Z00?oo`1CoookJ_oonfX04ooonfX2ooll01Wooo]Z00?oE_l0oookJ_oonfX04Ooo
nfX2o`1hoh;ooo]Z002noookJPWoiOl04?oonfX00ooJ0?oooo]ZoookJP0JoookJPOo0?mM00Go0000
o`0?ool03ooo0;3oo`1Oo`08o`0?o`oooo]Z1OnDo`0;oookJP?oolT000?ooo]Zool0Dooo05<04?oo
nfX5onGo0003ooll0?oonf[ooo]Z01Oooo]Z0_mFo`0<oookJP03ooo90?oonf[ooo]Z00?ooo]Z0_l0
N?oooookJTCooo]Z0_m2o`0BoookJP03omX0oooonf[ooo]Z023ooo]Z00?o013oo`000?l000000_l0
00000ooonf[ooc`0ooll000GoookJP;oob004?oonfX2ool0DaGooo]Z00?ooc`0oookJ_oonfX05ooo
nfX2oeKo01?ooo]Z00?o07SooookJ_oonfX0P_oonfX00;cooo]Z2ooUo`0>oookJP;ofP3o6ooonfX9
o`3oG@05o`000?l03ooo00ooo`2`ool0Gol02Ol03ol<oookJPOoU?l02_oonfX5ooo9017ooo]Z1_oU
o`0IoookJP03oeKo0?oonf[ooo]Z00cooo]Z00?oolT0oookJ_oonfX00_oonfX00ol0N?oooo]Zoook
JP3ooookJT?ooo]Z00?o@_l0oookJ_oonfX04OoonfX00ooJ0?oooo]ZoookJP0QoookJP03o`0@ool0
003o000000;o00000_oonfX00ooo?03oob00oookJP0DoookJP03oolP0?oonf[ooo]Z00oooo]Z00?o
o`1CoookJ_oonfX05?oonfX00ooo?03ooo]ZoookJP0GoookJP03oeKo0?oonf[ooo]Z017ooo]Z0_l0
N?n5oookJP00^ooonfX;onGo00kooo]Z00?ofP3ooookJ_oonfX06_oonfX9o`3oG@03oookJ_l03ooo
00oo00;o00oo0_l0Gol:o`0?o`Sooo]Z2_nDo`07oookJPOoolT04?oonfX8onGo01Kooo]Z0_mFo`0>
oookJP?oolT000?ooo]Zo`1hool0N?l0oooonfY5oookJP03od;o0?oonf[ooo]Z017ooo]Z00?ofP3o
oookJ_oonfX08OoonfX00ol04?oooo]Zo`000003o`0000;ooo]Z00?oe?l0ooll0?oo80004_oonfX2
oolP017ooo]Z00?oo`1CoookJ_oonfX04ooonfX2ooll01Sooo]Z0_mFo`0CoookJP03o`1hoooonf[o
oo]Z08Gooo]Z002koookJP[oiOl03_oonfX00ooJ0?oooo]ZoookJP0JoookJPWo0?mM00?oA?l0oook
J_l03ol00ol03ol3o`1Oo`[o00oo1?oonfX=oiCo00Kooo]Z2Ooob@0>oookJPWoiOl05OoonfX00omF
o`3ooo]ZoookJP0=oookJPGoolT0oooonfY6oookJP03od;o0?oonf[ooo]Z017ooo]Z00?ofP3ooook
J_oonfX08OoonfX00ol04?oooo]ZoookJP04o`0000?ooo]Z0_oo?0000ooo803ooo]ZoookJP0<oook
JP?oob004OoonfX2ool0DaGooo]Z00?ooc`0oookJ_oonfX05ooonfX00omFo`3ooo]ZoookJP0Aoook
JP;o07SoR?oonfX00;cooo]Z2?oUo`0>oookJP03omX0oooonf[ooo]Z01[ooo]Z0_l0o``8o`3oG@03
odCo0?oonf[o00oo00?o00oo00?o0;3oo`1Oool0Gol02_l03ol2oookJPooU?l01OoonfX:ooo900go
oo]Z2_oUo`0CoookJP;oE_l03ooonfX7ooo90?oooo]ZA?oonfX00om2o`3ooo]ZoookJP0AoookJP03
omX0oooonf[ooo]Z02;ooo]Z00?o013ooookJ_oonfX01?l00003oookJP03omCo0?oo?03ooc`000?o
ob002?oonfX3oolP01;ooo]Z0_oo05<EoookJP;ooc`06?oonfX2oeKo01?ooo]Z00?o07SooookJ_oo
nfX0R?oonfX00;gooo]Z1ooUo`0<oookJP;oiOl07_oonfX2o`3o30Ko0?mM00?oA?l0oookJ_l03ol0
1?l03ol01?l0/?oo05ooo`1Oool0Gol:o`0?o`GoA?l03?nDo`02oookJPcoolT03?oonfX<onGo017o
oo]Z00?oE_l0oookJ_oonfX03_oonfX9ooo90?oooo]Z@_oonfX00om2o`3ooo]ZoookJP0AoookJP03
omX0oooonf[ooo]Z02?ooo]Z00?o013ooookJ_oonfX01?l00004oookJP04omCo0?oo?03oo`1Coook
JPWoob004ooonfX2ool0DaKooo]Z00?ooc`0oookJ_oonfX05ooonfX00omFo`3ooo]ZoookJP0Aoook
JP;o07SoRooonfX00;cooo]Z00?o@_l0oookJ_oUo`001?oUo`0<oookJP?oiOl07ooonfX2o`3o30Go
0?mM00?oA?l0oookJ_l03ol01?l03ol01?l0/?oo05ooo`1Oool0Gol9o`0?o`03o`1Oool0o`coA?l0
00OoA?l02?nDo`000ooonf[oolT0ooo9000<ooo900[ooo]Z2_oUo`0CoookJP03oeKo0?oonf[ooo]Z
00kooo]Z2ooob@3ooookJT3ooo]Z00?o@_l0oookJ_oonfX04OoonfX00ooJ0?oooo]ZoookJP0Soook
JP04o`0@oooonf[ooo]ZoookJPGo00000ooonfX01?oo]03oe?l0ooll0?oo05<JoookJP;oo`1C5_oo
nfX2ooll01Wooo]Z00?oE_l0oookJ_oonfX04?oonfX2o`1hohgooo]Z002koookJP04od;o0?oonf[o
oo]ZoookJP?oiOl02ooonfX4onGo023ooo]Z00?oA?l0o`3o3?l0o``00ol0oed2odCo0003oookJ_l0
3ooo00oo00?o00oo00?o0;3oo`1Oool0Gol00_l0Gol4o`0?o`;o0?on00Co00ooo`1Oool0oego0?mM
0_l0o``6odCo00Sooo]Z2_oob@0>oookJPOoiOl05OoonfX2oeKo013ooo]Z2_oob@3ooookJT7ooo]Z
00?o@_l0oookJ_oonfX04OoonfX00ooJ0?oooo]ZoookJP0SoookJP03o`0@oooonf[ooo]Z00;ooo]Z
1?l00005oookJP;oe?l000?ooc`0ool0Dooo05<05_oonfX2ool0DaKooo]Z0_oo?00IoookJP;oE_l0
4_oonfX00ol0N?oooo]ZoookJP2=oookJP00^_oonfX00om2o`3ooo]ZoookJP03oookJP03onGo0?oo
nf[ooo]Z00Sooo]Z1OoUo`0PoookJP?oA?l00_l0o``00ol0oegoA?l0odCo0002oookJPGo00oo00?o
0;3oo`1Oool0Gol00_l0Gol3o`0?o`;o05oo0_l0ooh00ol03ooo0?mMo`3oG@03o`3o30CoA?l01ooo
nfX00ooo05?oolT0ooo90002ooo901Cooo]Z1OoUo`0GoookJP03oeKo0?oonf[ooo]Z00oooo]Z2?oo
b@3ooookJT?ooo]Z00?o@_l0oookJ_oonfX04OoonfX00ooJ0?oooo]ZoookJP0ToookJP03o`0@oooo
nf[ooo]Z00;ooo]Z1?l00005oookJP05oond0?oDo`3ooc`0ooll0?oonfX00_oo05<AoookJP?oo`1C
5ooonfX00ooo?03ooo]ZoookJP0HoookJP03oeKo0?oonf[ooo]Z013ooo]Z0_l0N?n@oookJP00^Ooo
nfX00om2o`3ooo]ZoookJP0>oookJPKoiOl08_oonfX2odCo0005o`3o3?m4o`3oA?l0odCo0?oonfX0
1_l03ol2o`2`o`Co05oo00?o00ooo`1Oool0ooh01?l0ooh00ol03ooo0?l<o`3o3002o`3o30CoA?l0
2OoUo`0EoookJP03ooll0?oUo`3oiOl001[ooo]Z00?oE_l0oookJ_oonfX03ooonfX6ooo90?oooo]Z
AOoonfX00om2o`3ooo]ZoookJP0AoookJP03omX0oooonf[ooo]Z02Cooo]Z00?o013ooookJ_oonfX0
0ooonfX4o`0000Gooo]Z00Gook@0omCo0?n8o`3oE_l0ooll0002oookJP;oo`1C3OoonfX2ool0DaSo
oo]Z0_oo?00JoookJP03oeKo0?oonf[ooo]Z00oooo]Z0_l0N?nBoookJP00^?oonfX00om2o`3ooo]Z
oookJP0=oookJPOoiOl08_oonfX2oiCo00GoA?l000?ooo]Zo`0?ool03ol01Ol03ol01?l0/?oo05oo
o`1Oool0Gol4o`2`o`;o0?on00Co0?n]o`3oGOl0oego0?mM0_l0o``4odCo00[oiOl04_oonfX3ooll
01_ooo]Z0_mFo`0AoookJPCoolT0oooonfY7oookJP03od;o0?oonf[ooo]Z017ooo]Z00?ofP3ooook
J_oonfX09?oonfX00ol04?oooo]ZoookJP04oookJPCo00001_oonfX00ooo]03oe?l0oeKo0002ooll
00?ooo]Z3Ooo05<GoookJP?ooc`06_oonfX2oeKo017ooo]Z00?o07SooookJ_oonfX0T_oonfX00;Oo
oo]Z00?o@_l0oookJ_oonfX03?oonfX9onGo027ooo]Z1OnDo`02odCo00?ooo]Z1_l03ol00ol0/?oo
05ooo`2`o`03o`2`o`;o0?on1?l0ojd3o`3oG@GoA?l000?oU?l0onGo0?oUo`001ooUo`0@oookJP;o
oc`07?oonfX2oeKo017ooo]Z00?o07Soooo90?oob@00oooonfY9oookJP03od;o0?oonf[ooo]Z017o
oo]Z00?ofP3ooookJ_oonfX09?oonfX00ol04?oooo]ZoookJP05oookJPCo00001ooonfX01Ol0odGo
e?l0o`1hoomFo`3ooc`002Cooo]Z0_oo?00KoookJP;oE_l04OoonfX2o`1hoiGooo]Z002eoookJP;o
@_l03_oonfX9onGo027ooo]Z1onDo`000om4o`3ooo]ZoookJP02oookJPCo000000Gooo]Zo`2`ool0
/?oo0;3oo`0?o`03o`3ooP?o0?n]1_l0oed01?nDo`3oA?l0odCo0?m4o`02oiCo00SoiOl03_oonfX2
ooll01cooo]Z0_mFo`0AoookJP;o07SooooonfY:oookJP;o@_l04ooonfX00ooJ0?oooo]ZoookJP0U
oookJP03o`0@oooonf[ooo]Z00Gooo]Z1?l00007oookJP05oond0?oDo`3oK_l0oeKo0?oonfX00_oo
?00OoookJP?ooc`07?oonfX00omFo`3ooo]ZoookJP0?oookJP;o07SoUooonfX00;Cooo]Z00?o@_l0
oookJ_oonfX03OoonfX9onGo027ooo]Z2?nDo`05oookJPCo000000?ooo]Zo`2`ool03ol00_l03ol0
0ol0ooko0?n]o`3o[@02o`3o[@Go0?mM1?l0o``01?m4o`3oU?l0oiCo0?nDo`07onGo00Wooo]Z0onD
o`000ooonf[ooc`0ooll000EoookJP;oiOl01OoonfX2oeKo017ooo]Z0_l0N?oooookJT_ooo]Z00?o
@_l0oookJ_oonfX04_oonfX00ooJ0?oooo]ZoookJP0UoookJP03o`0@oooonf[ooo]Z00Kooo]Z1?l0
0007oookJP05oond0?l0odGoe?l0o`1hoomFo`000_oonfX00ooo?03ooo]ZoookJP0JoookJP;ooc`0
7OoonfX2oeKo013ooo]Z0_l0N?nIoookJP00/ooonfX00om2o`3ooo]ZoookJP0?oookJPSoiOl08?oo
nfX9oiCo00Gooo]Z1?l000000ooonf[o00oooookJP03o`0?o`;o0?n]1_l0oed7o`3o3003oiCo0?oo
nf[ooo]Z00KoiOl01OoonfX7oiCo0003ooll0?oonf[ooo]Z01Cooo]Z0ooUo`03oookJP;oE_l04_oo
nfX00ol0N?oooo]ZoookJP3ooookJT[ooo]Z00?o@_l0oookJ_oonfX04_oonfX00ooJ0?oooo]Zoook
JP0VoookJP03o`0@oooonf[ooo]Z00Kooo]Z1?l00007oookJP06oond0?l0odKoR?l0omCo0?l0N?oo
E_l00_oonfX2ooll01Sooo]Z0_oo?00MoookJP;oE_l04OoonfX00ol0N?oooo]ZoookJP2IoookJP00
/_oonfX00om2o`3ooo]ZoookJP0AoookJPKoiOl08ooonfX7oiCo00Gooo]Z1?l00003oookJP?o00oo
00?o0?n]o`1Oool0Gol01?l0oed9o`3o3004odCo0?oonf[ooo]ZoookJPCoiOl00_oonfX:oiCo01Go
oo]Z1_oUo`02oeKo01;ooo]Z0_l0N?oooookJTcooo]Z00?o@_l0oookJ_oonfX04_oonfX00ooJ0?oo
oo]ZoookJP0WoookJP03o`0@oooonf[ooo]Z00Kooo]Z1?l00008oookJP05oond0?oonf[oe?l0ooo?
0?oonfX00_mFo`02oookJP?ooc`04ooonfX2ooll01cooo]Z0omFo`0AoookJP;o07SoW?oonfX00;7o
oo]Z00?o@_l0oookJ_oonfX04ooonfX5onGo02Cooo]Z00?o013ooiCo0?nDo`000onDo`05oookJPGo
00000_oonfX00ol0o`cooo]Zo`0?o`03o`1Oo`?o0?mM2_l0o``5odCo0003oookJ_nDo`3oU?l000co
U?l04ooonfX8onGo01;ooo]Z0_l0N?oooookJTgooo]Z00?o@_l0oookJ_oonfX04_oonfX00ooJ0?oo
oo]ZoookJP0WoookJP03o`0@oooonf[ooo]Z00Oooo]Z1Ol00007oookJP04oond0?oonf[oe?l0ohSo
00;ooo]Z00?o07SooeKo0?oonfX00ooonfX4ooll00Wooo]Z1_oo?00LoookJP;oE_l04_oonfX2o`1h
oikooo]Z002`oookJP03od;o0?oonf[ooo]Z01?ooo]Z00?ofP3ooookJ_oUo`000_oUo`0UoookJP03
o`0@oooonf[oU?l000;oU?l01_oonfX4o`0000Gooo]Z00?o0?ono`1Oool0Gol00_l0/?l00ol0oego
0;3oo`2`o`08o`3o30SoA?l03OnDo`0BoookJP[oiOl04?oonfX00ol0N?oooo]ZoookJP3ooookJTco
oo]Z00?o@_l0oookJ_oonfX04_oonfX00ooJ0?oooo]ZoookJP0WoookJP03o`0@oooonf[ooo]Z00So
oo]Z1?l00008oookJP05oond0?l0odKooo]ZomCo0?ooQ`000_oonfX00ol0N?ooE_l0oookJP06oook
JPWooc`08?oonfX2oeKo01?ooo]Z00?o07SooookJ_oonfX0W_oonfX00:oooo]Z00?o@_l0oookJ_oo
nfX04ooonfX01OoJ0?oooo]ZoookJ_oonf[oiOl002Kooo]Z00Go013ooookJ_oonf[ooo]ZoiCo0006
oookJPCo00001_oonfX2o`1Oo`Ko0;3o1_l0o``9odCo00goU?l04?oonfX<onGo00kooo]Z0_l0N?oo
oookJTkooo]Z00?o@_l0oookJ_oonfX04_oonfX00ooJ0?oooo]ZoookJP0XoookJP03o`0@oooonf[o
oo]Z00Sooo]Z1?l00009oookJP04oond0?oonf[oY`3oomCo00;ooo]Z00Co07SooookJ_mFo`3oE_l0
:ooonfX3oeKo01?ooo]Z0_l0N?nQoookJP00[_oonfX00om2o`3ooo]ZoookJP0CoookJP03omX0oooo
nf[ooo]Z02Sooo]Z00?o013ooookJ_oonfX02OoonfX4o`0000Kooo]Z00?o00ooo`1Oool0/?l01Ol0
/?l6o`3o30SoA?l01OoonfX9oiCo00kooo]Z3_oUo`0<oookJP;o07SooooonfY?oookJP03od;o0?oo
nf[ooo]Z01;ooo]Z00?ofP3ooookJ_oonfX0:?oonfX00ol04?oooo]ZoookJP09oookJPCo00002Ooo
nfX01Ooo]03ooo]ZoookJ_n8o`3oe?l000;ooo]Z00Co07SooookJ_oonf[oE_l09ooonfX3oeKo01Co
oo]Z0_l0N?nSoookJP00[_oonfX00om2o`3ooo]ZoookJP0BoookJP03omX0oooonf[ooo]Z02Sooo]Z
00?oiOl0oookJ_oonfX02_oonfX4o`0000Kooo]Z00?o0?l<o`3oo_l0/?l01?l0/?l2o`3ooPGo0?l<
1om4o`09oookJPKoU?l03OoonfX@onGo00[ooo]Z00?o07SooookJ_oonfX0oooonfY?oookJP03od;o
0?oonf[ooo]Z017ooo]Z00?ofP3ooookJ_oonfX0:?oonfX00ol04?oooo]ZoookJP0:oookJPCo0000
2OoonfX01_oo]03o0?m6oookJ_oo07ooe?l0ocP0o`;ooo]Z00?o07SooookJ_oonfX00_mFo`0Roook
JP?oE_l05_oonfX00ol0N?oooo]ZoookJP2SoookJP00[OoonfX00om2o`3ooo]ZoookJP0BoookJP03
omX0oooonf[ooo]Z02Wooo]Z00?oiOl0oookJ_oonfX02_oonfX4o`0000Kooo]Z00?o0?l<o`3oo_l0
ojd00_l0/?l5o`3ooP?o0?l<2?m4o`0=oookJP;oU?l02ooonfX00omFo`3oiOl0onGo0006onGo017o
oo]Z0_l0N?oooookJU7ooo]Z00?o@_l0oookJ_oonfX04OoonfX00ooJ0?oooo]ZoookJP0YoookJP03
o`0@oooonf[ooo]Z00[ooo]Z1?l0000:oookJP05oond0?oonf[o0?m5omCo0?nW0?l00ooonfX2o`1h
o`;ooo]Z0_mFo`0NoookJP;oE_l05ooonfX2o`1hojKooo]Z002/oookJP03od;o0?oonf[ooo]Z01;o
oo]Z00?ofP3ooookJ_oonfX0:OoonfX00ooUo`3ooo]ZoookJP0;oookJPCo00002?oonfX00onDo`3o
0;3oo`2`o`07o`3ooP03o`3o[Om4o`3oA?l000SoA?l05_oonfX2oeKo01Oooo]Z0ol0N?oooookJU;o
oo]Z00?o@_l0oookJ_oonfX04OoonfX00ooJ0?oooo]ZoookJP0YoookJP03o`0@oooonf[ooo]Z00_o
oo]Z1?l0000:oookJP06oond0?oonf[ooo]Zo`3oAOoDo`3o>03o1?oonfX01?l0N?oooo]ZoookJ_oo
nfX4oeKo01Oooo]Z0omFo`0FoookJP?o07SoZ?oonfX00:_ooo]Z00?o@_l0oookJ_oonfX04_oonfX0
0ooJ0?oooo]ZoookJP0YoookJP;oiOl03OoonfX4o`0000Sooo]Z00CoU?l0o`2`ool0Gooo0;3o1ol0
ooh00ol0ojgoA?l0odCo0008odCo00koU?l01?oonfX3oeKo01Oooo]Z0_l0N?oooookJUCooo]Z00?o
@_l0oookJ_oonfX04_oonfX00ooJ0?oooo]ZoookJP0YoookJP03o`0@oooonf[ooo]Z00_ooo]Z1?l0
000:oookJP07oond0?oonf[ooo]ZoookJ_oDo`3oR?l0ocP0o`04oookJP;o07So1OoonfX2oeKo01;o
oo]Z0omFo`0GoookJP;o07SoZooonfX00:[ooo]Z00?o@_l0oookJ_oonfX04_oonfX00ooJ0?oooo]Z
oookJP0YoookJP?oiOl03OoonfX4o`0000Sooo]Z00CoU?l0onGo0?l0ooko0;3o2?l0ooh:odCo00ko
U?l01?mFo`0GoookJP?o07SooooonfYEoookJP03od;o0?oonf[ooo]Z01;ooo]Z00?ofP3ooookJ_oo
nfX0:OoonfX00ol04?oooo]ZoookJP0<oookJPCo00002_oonfX01ooo]03o0?m6oookJ_oonf[o0?m5
omCo0?lh0?l01_oonfX2o`1ho`Gooo]Z4_mFo`0HoookJP;o07So[OoonfX00:Wooo]Z00?o@_l0oook
J_oonfX04_oonfX00ooJ0?oooo]ZoookJP0YoookJP?oiOl03_oonfX4o`0000Sooo]Z0ooUo`000ol0
/?oo0?ono`3ooP07o`3ooPSoA?l00_oonfX=oiCo013ooo]Z0_oUo`06oookJP?o07SooooonfYGoook
JP03od;o0?oonf[ooo]Z01;ooo]Z00?ofP3ooookJ_oonfX0:_oonfX00ol04?oooo]ZoookJP0<oook
JPCo00002ooonfX01ooo]03ooo]ZoookJ_oonf[oe?l0ohSo0?lh0?l01ooonfX2o`1hob[ooo]Z0ol0
N?n_oookJP00Z?oonfX00om2o`3ooo]ZoookJP0BoookJP03omX0oooonf[ooo]Z02Wooo]Z1?oUo`0>
oookJPCo00002OoonfX3onGo00Wo0?on00?o0?mModCo0?m4o`001?m4o`0?oiCo00kooo]Z1OoUo`03
oookJP?o07SooooonfYIoookJP03od;o0?oonf[ooo]Z01;ooo]Z00?ofP3ooookJ_oonfX0:_oonfX0
0ol04?oooo]ZoookJP0=oookJPCo00002ooonfX01ooo]03ooo]ZoookJ_oonf[o0?m5omCo0?nW0?l0
2OoonfX2o`1hobGooo]Z0ol0N?nboookJP00YooonfX00om2o`3ooo]ZoookJP0BoookJP03omX0oooo
nf[ooo]Z02Wooo]Z1OoUo`0>oookJPGo00002?oonfX3onGo00Co0?on0_l0ojd4o`3ooPGoA?l04?nD
o`0;oookJPSoiOl00ol0N?oooookJU_ooo]Z00?o@_l0oookJ_oonfX04_oonfX00ooJ0?oooo]Zoook
JP0ZoookJP03o`0@oooonf[ooo]Z00kooo]Z1Ol0000:oookJP03oond0?oonf[ooo]Z00;ooo]Z00?o
K_l0omCo0?lh0?l02_oonfX2o`1hob3ooo]Z0ol0N?neoookJP00Y_oonfX00om2o`3ooo]ZoookJP0B
oookJP03omX0oooonf[ooo]Z02Wooo]Z1OoUo`0?oookJPCo00002OoonfX3onGo00Co0?on0ol0ojd4
o`3ooP?oA?l00_oonfX?oiCo00Sooo]Z2ooUo`3ooookJUgooo]Z00?o@_l0oookJ_oonfX04_oonfX0
0ooJ0?oooo]ZoookJP0[oookJP03o`0@oooonf[ooo]Z00kooo]Z1?l0000;oookJP03oond0?l0odKo
oo]Z00;ooo]Z00Co0?m5omCo0?nW0?oo>03o2ooonfX3o`1hoaWooo]Z1?l0N?nhoookJP00YOoonfX0
0om2o`3ooo]ZoookJP0BoookJP03omX0oooonf[ooo]Z02Wooo]Z1_oUo`0?oookJPCo00002OoonfX4
onGo00?o0?on1?l0ojd01Ol0ooko0?mMo`3oGOoonf[oA?l000Cooo]Z3OnDo`06oookJPkoiOl0oooo
nfYKoookJP;o@_l05?oonfX00ooJ0?oooo]ZoookJP0[oookJP03o`0@oooonf[ooo]Z00oooo]Z1?l0
000<oookJP03oond0?oonf[ooo]Z00;ooo]Z00Co0?m5omCo0?lh0?oooll03OoonfX6o`1ho`kooo]Z
1Ol0N?nloookJP00Y?oonfX00om2o`3ooo]ZoookJP0BoookJP03omX0oooonf[ooo]Z02Wooo]Z1ooU
o`0?oookJPCo00002OoonfX4onGo0003o`3oo_l0/?oo0?on00Ko0?n]0_l0oed6oookJPWoU?l00_l0
N?l00onDo`3o07Soo`1ho`03o`1hoa3oiOl0oooonfYIoookJP03od;o0?oonf[ooo]Z01?ooo]Z00?o
fP3ooookJ_oonfX0;?oonfX00ol04?oooo]ZoookJP0?oookJPCo00003?oonfX00ooo]03o0?m6oook
JP02oookJP05o`3oAOoDo`3oY`3oocP0ooooc`004_oonfX>o`1hol7ooo]Z002SoookJP03od;o0?oo
nf[ooo]Z01?ooo]Z00?ofP3ooookJ_oonfX0:?oonfX7onGo013ooo]Z1?l00009oookJPGoiOl000?o
0;3oo`3oo_l0ooh01_l0ojd00ol0oego0?n]oookJP06oookJPOoU?l03?oonfX<onGo0?oooo]ZF?oo
nfX00om2o`3ooo]ZoookJP0DoookJP03omX0oooonf[ooo]Z02_ooo]Z00?o013ooookJ_oonfX04?oo
nfX4o`0000cooo]Z00?ook@0o`3oA_oonfX00ooonfX01?l0odGoe?l0ocP0ooooc`3QoookJP00X_oo
nfX00om2o`3ooo]ZoookJP0CoookJP03omX0oooonf[ooo]Z02Sooo]Z2?oUo`0@oookJPCo00002Ooo
nfX5onGo0003oiCo0?l0ooko0?on00Oo0?n]0_l0oed7oookJPGoU?l04_oonfX7onGo0?oooo]ZEooo
nfX00om2o`3ooo]ZoookJP0DoookJP03omX0oooonf[ooo]Z02_ooo]Z00?o013ooookJ_oonfX04Ooo
nfX4o`0000cooo]Z00?ook@0o`3oA_oonfX00ooonfX01Ol0odGoR?l0omCo0?lh0?oooll00>3ooo]Z
002QoookJP03od;o0?oonf[ooo]Z01?ooo]Z00?ofP3ooookJ_oonfX0:ooonfX6onGo013ooo]Z1?l0
0009oookJP;oiOl000?oU?l0oond0?nDo`000_nDo`000om4o`3o0?n]o`3o[@06o`3o[@03o`3oGOl0
o`cooo]Z00Kooo]Z1?nDo`0GoookJP;oiOl0oooonfYFoookJP03od;o0?oonf[ooo]Z01Cooo]Z00?o
fP3ooookJ_oonfX0;?oonfX00ol04?oooo]ZoookJP0AoookJPCo00003?oonfX00ooo]03o0?m6oook
JP04oookJP05o`3oAOn8o`3oe?l0ocP0ooooc`00gooonfX00:3ooo]Z00?o@_l0oookJ_oonfX04ooo
nfX00ooJ0?oooo]ZoookJP0]oookJP04o`0@oooUo`3oiOl0onGo017ooo]Z1?l0000;oookJP03oiCo
0?oo]03oU?l000;oU?l000?oA?l0o`3o[Ol0ojd01ol0ojd00ol0oego0?l<oookJP06oookJP?oU?l0
oooonfY^oookJP03od;o0?oonf[ooo]Z01Cooo]Z00?ofP3ooookJ_oonfX0;?oonfX00ol04?oooo]Z
oookJP0BoookJPCo00003OoonfX00ooo]03ooo]ZoookJP03oookJP06o`3oAOoo>@3oe?l0oh@0oolh
0?oooll0g_oonfX009oooo]Z00?o@_l0oookJ_oonfX04ooonfX00ooJ0?oooo]ZoookJP0^oookJP04
o`0@oooonf[ooo]ZonGo017ooo]Z1?l0000;oookJP03oiCo0?oob@3oU?l000?oU?l02Ol0ojd3o`3o
30Oooo]Z00?oU?l0oookJ_oonfX0oooonfY/oookJP03od;o0?oonf[ooo]Z01Cooo]Z00?ofP3ooook
J_oonfX0;OoonfX00ol04?oooo]ZoookJP0BoookJPCo00003OoonfX00ooo]03o0?m6oookJP04oook
JP05o`3oAOnW0?ooe?l0ocP0ooooc`00g_oonfX009kooo]Z00?o@_l0oookJ_oonfX05?oonfX00ooJ
0?oooo]ZoookJP0]oookJP03o`0@oooonf[ooo]Z01?ooo]Z1?l0000;oookJP03oiCo0?oob@3oU?l0
00?oU?l02_l0ojd3o`3o3?oooo]ZM?oonfX00om2o`3ooo]ZoookJP0EoookJP03omX0oooonf[ooo]Z
02cooo]Z00?o013ooookJ_oonfX04ooonfX4o`0000gooo]Z00?ook@0o`3oA_oonfX01?oonfX01_l0
odGoocT0omCo0?n40?oo>03oooo?0=gooo]Z002MoookJP03od;o0?oonf[ooo]Z01Cooo]Z00?ofP3o
oookJ_oonfX0;_oonfX00ol04?oooo]ZoookJP0CoookJPCo00002ooonfX00onDo`3oolT0ooo90003
oiCo0003odCo0?l0ojgo0?n]00So0?n]0ol0o`cooookJW;ooo]Z00?o@_l0oookJ_oonfX05OoonfX0
0ooJ0?oooo]ZoookJP0]oookJP03o`0@oooonf[ooo]Z01?ooo]Z1?l0000=oookJP03oond0?l0odKo
oo]Z00Cooo]Z00Oo0?m5oookJ_oDo`3oR?l0ocP0oooonf[ooll00=cooo]Z002LoookJP03od;o0?oo
nf[ooo]Z01Cooo]Z00?ofP3ooookJ_oonfX0;_oonfX00ol04?oooo]ZoookJP0DoookJPGo00002_oo
nfX00onDo`3oolT0ooo90002oiCo0003oookJ_m4o`3o0?n]00Co0?n]00?oe?l0o`3o[Ol0ojd00_l0
ojd4o`3o3?oooo]ZL?oonfX00om2o`3ooo]ZoookJP0EoookJP03omX0oooonf[ooo]Z02gooo]Z00?o
013ooookJ_oonfX05?oonfX5o`0000cooo]Z00?ook@0o`3oA_oonfX01OoonfX01ol0odGoocT0omCo
0?m^o`3o>03ooookJ_ooc`00fooonfX009_ooo]Z00?o@_l0oookJ_oonfX05?oonfX00ooJ0?oooo]Z
oookJP0^oookJP03o`0@oooonf[ooo]Z01Gooo]Z1?l0000;oookJP04oiCo0?oob@3oolT0ooo900;o
oo]Z0_m4o`04o`3o[@03omCo0?l0ojgo0?n]00?o0?n]00?o0?l<oookJ_oonfX0oooonfY_oookJP03
od;o0?oonf[ooo]Z01Gooo]Z00?ofP3ooookJ_oonfX0;OoonfX00ol04?oooo]ZoookJP0EoookJPCo
00003OoonfX00ooo]03o0?m6oookJP05oookJP08o`3oAOoonf[oe?l0ohSo0?oo08So>03ooookJ_oo
c`3JoookJP00VooonfX00om2o`3ooo]ZoookJP0CoookJP03omX0oooonf[ooo]Z02oooo]Z00?o013o
oookJ_oonfX05OoonfX4o`0000_ooo]Z1?oob@03oookJP;oA?l01?l0ojd00ooDo`3o0?n]o`3o[@02
o`3o[@03o`3o3?oonf[ooo]Z0?oooo]ZKooonfX00om2o`3ooo]ZoookJP0DoookJP03omX0oooonf[o
oo]Z02kooo]Z00?o013ooookJ_oonfX05OoonfX4o`0000gooo]Z00?ook@0o`3oA_oonfX01_oonfX0
2?l0odGooo]ZomCo0?m^o`3oQ03oocP0oooonf[ooll0fOoonfX009[ooo]Z00?o@_l0oookJ_oonfX0
5?oonfX00ooJ0?oooo]ZoookJP0^oookJP03o`0@oooonf[ooo]Z01Kooo]Z1?l0000;oookJPCoolT0
0ooonfX2odCo00Co0?n]00?o0?mMo`3o[Ol0ojd00ol0ojd00ol0o`cooo]ZoookJP3ooookJVgooo]Z
00?o@_l0oookJ_oonfX05OoonfX00ooJ0?oooo]ZoookJP0]oookJP03o`0@oooonf[ooo]Z01Kooo]Z
1?l0000=oookJP03oond0?l0odKooo]Z00Kooo]Z00So0?m5oookJ_oo>@3oe?l0ool0R?n40?oo>03o
ooo?0=Wooo]Z002IoookJP03od;o0?oonf[ooo]Z01Cooo]Z00?ofP3ooookJ_oonfX0;ooonfX00ol0
4?oooo]ZoookJP0FoookJPCo00002ooonfX5ooo900;ooo]Z00CoA?l0oookJ_oonf[o0?mM0_l0ojd2
o`3oG@Go0?n]00?o0?l<oookJ_oonfX0oooonfY[oookJP03od;o0?oonf[ooo]Z01Gooo]Z00?ofP3o
oookJ_oonfX0;_oonfX00ol04?oooo]ZoookJP0FoookJPCo00003OoonfX00ooo]03o0?m6oookJP06
oookJP09o`3oAOoonf[ooo]ZomCo0?n8o`3oQ03oocP0oooonf[ooll00=Sooo]Z002HoookJP03od;o
0?oonf[ooo]Z01Cooo]Z00?ofP3ooookJ_oonfX0;ooonfX00ol04?oooo]ZoookJP0GoookJPCo0000
2ooonfX5ooo900Gooo]Z00Co0?mMo`3o[Ol0ojgo0?n]0_l0oed2o`3o[@Co0?l<oooonfY[oookJP03
od;o0?oonf[ooo]Z01Gooo]Z00?ofP3ooookJ_oonfX0;_oonfX00ol04?oooo]ZoookJP0GoookJPCo
00003OoonfX00ooo]03o0?m6oookJP07oookJP09o`3oAOoonf[oocT0omCo0?m^o`3oQ03oocP0oooo
nf[ooll00=Oooo]Z002GoookJP03od;o0?oonf[ooo]Z01Cooo]Z00?ofP3ooookJ_oonfX0<?oonfX0
0ol04?oooo]ZoookJP0GoookJPCo00002ooonfX6ooo900Cooo]Z00Co0?mMo`3oo_l0ojgo0?n]1?l0
oed5o`3o3?oooo]ZJOoonfX00om2o`3ooo]ZoookJP0EoookJP03omX0oooonf[ooo]Z02oooo]Z00?o
013ooookJ_oonfX05ooonfX4o`0000kooo]Z00?ook@0oookJ_oonfX01_oonfX02_l0odGooo]Zoook
J_oDo`3oR?l0ool0R?lh0?ooo`2FoookJ_ooc`3FoookJP00U_oonfX00om2o`3ooo]ZoookJP0Doook
JP03omX0oooonf[ooo]Z02Gooo]Z1Ol007l4oookJP;o001o00?o013ooookJ_l007l02?l007l3oook
JPGo001o2?oonfX4o`0000_ooo]Z1_oob@06oookJP03o`3o[Om4o`3o0?mM00Co0?mM1Ol0o`cooook
JVOooo]Z00?o@_l0oookJ_oonfX05OoonfX00ooJ0?oooo]ZoookJP0ToookJPGo001o1?oonfX2o`00
O`03o`0@oooonf[o001o00So001o0ooonfX5o`00O`Sooo]Z1?l0000>oookJP03oond0?l0odKooo]Z
00Kooo]Z00So0?m5oookJ_oonf[ooo]ZomCo0?n8o`3oQ03oocP0o`;ooo]Z00?ooll0oookJ_oonfX0
dooonfX009Gooo]Z00?o@_l0oookJ_oonfX05?oonfX00ooJ0?oooo]ZoookJP0UoookJPOo001o0ooo
nfX01?l007oo013oo`00OooonfX9o`00O`;ooo]Z1ol007l7oookJPCo00002ooonfX7ooo900Gooo]Z
00?o0?mMo`3oAOl0oed01Ol0oed5o`3o3?oooo]ZIOoonfX00om2o`3ooo]ZoookJP0EoookJP03omX0
oooonf[ooo]Z02Cooo]Z1ol007l3oookJP04o`00Ool04?oo001ooookJPWo001o0_oonfX7o`00O`Oo
oo]Z1?l0000>oookJP03oond0?l0odKooo]Z00Oooo]Z00[o0?m5oookJ_oonf[oocT0omCo0?m^o`3o
Q03oocP0oooonf[ooll0eOoonfX009Cooo]Z00?o@_l0oookJ_oonfX05OoonfX00ooJ0?oooo]Zoook
JP0UoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX01?l007oo013oo`00OooonfX4o`00O`Ko
oo]Z1?l007l01?oonf[o001oo`00Ool007l7oookJPCo00002_oonfX8ooo900Kooo]Z00?oU?l0o`3o
[Ol0oed01Ol0oed4o`3o3003odCo0?oonf[ooo]Z0?oooo]ZH_oonfX00om2o`3ooo]ZoookJP0Doook
JP03omX0oooonf[ooo]Z02Gooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP04o`00Ool04?oo
001ooookJPCo001o1_oonfX4o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l0000>oookJP03oond
0?l0odKooo]Z00Sooo]Z00[o0?m5oookJ_nbo`3oe?l0ohSo0?oo08So>03oool0U_oonf[ooll0e?oo
nfX009?ooo]Z00?o@_l0oookJ_oonfX05OoonfX00ooJ0?oooo]ZoookJP0UoookJP?o001o0ooonfX3
o`00O`;ooo]Z00?o013ooookJ_oonfX00_oonfX4o`00O`Gooo]Z0ol007l3oookJP?o001o1_oonfX4
o`0000[ooo]Z2?oob@06oookJP03oiCo0?m4o`3o0?mM00Ko0?mM1?l0o``2odCo0?oooo]ZHOoonfX0
0om2o`3ooo]ZoookJP0DoookJP03omX0oooonf[ooo]Z02Gooo]Z0ol007l3oookJP?o001o0_oonfX0
0ol04?oooo]ZoookJP02oookJPCo001o1OoonfX3o`00O`?ooo]Z0ol007l6oookJPCo00003_oonfX0
0ooo]03o0?m6oookJP08oookJP0:o`3oAOoonf[ooo]Zo`1HoooDo`3oK_l0oh@0oolh0?ooo`2Foook
JP;ooll0d_oonfX009;ooo]Z00?o@_l0oookJ_oonfX05OoonfX00ooJ0?oooo]ZoookJP0VoookJP?o
001o0ooonfX3o`00O`;ooo]Z00?o013ooookJ_oonfX00ooonfX5o`00O`Wooo]Z0ol007l6oookJPKo
00002?oonfX9ooo900Gooo]Z0_nDo`08o`3oG@Co0?l<0_m4o`3ooookJUoooo]Z00?o@_l0oookJ_oo
nfX05?oonfX00ooJ0?oooo]ZoookJP0VoookJP?o001o0ooonfX3o`00O`;ooo]Z00?o013ooookJ_oo
nfX00ooonfX5o`00O`Wooo]Z0ol007l6oookJPKo00003?oonfX00ooo]03o0?m6oookJP08oookJP0:
o`3oAOoonf[ooo]Zooli0?n8o`3oe?l0of?o0?n40?oo>03oool0UP;ooo]Z00?ooll0oookJ_oonfX0
cooonfX0097ooo]Z00?o@_l0oookJ_oonfX05OoonfX00ooJ0?oooo]ZoookJP0WoookJP?o001o0ooo
nfX3o`00O`03oookJ_l04?oooo]Z00Oooo]Z1?l007l8oookJP?o001o1_oonfX4o`0000[ooo]Z1?oo
b@000ooo]03oiOl0onGo0007oookJP;oU?l000?o0?n]o`3oGOl0oed01_l0oed00ol0o`coA?l0odCo
0004odCo0?oooo]ZG?oonfX00om2o`3ooo]ZoookJP0DoookJP03omX0oooonf[ooo]Z02Oooo]Z0ol0
07l3oookJP?o001o00?ooo]Zo`0@oooonfX01ooonfX4o`00O`Sooo]Z0ol007l6oookJPCo00003_oo
nfX00ooo]03o0?m6oookJP09oookJP09o`3oAOoonf[ooo]Zooli0?oDo`3ok03oool0R?n40?oo>03o
00?ooo]Z00?ooll0oookJ_oonfX0c_oonfX0093ooo]Z00?o@_l0oookJ_oonfX05OoonfX00ooJ0?oo
oo]ZoookJP0XoookJP?o001o0ooonfX3o`00O`03o`0@oooonf[ooo]Z00Sooo]Z0ol007l3oookJP;o
001o0_oonfX4o`00O`Kooo]Z1?l0000>oookJP04oond0?oUo`3oiOl0onGo00Kooo]Z0_nDo`000ol0
ojgo0?mMo`3oG@06o`3oG@WoA?l0oooonfYIoookJP03od;o0?oonf[ooo]Z01Cooo]Z00?ofP3ooook
J_oonfX0:?oonfX3o`00O`?ooo]Z0ol007l00ol04?oooo]ZoookJP08oookJP?o001o0ooonfX2o`00
O`;ooo]Z1?l007l6oookJPCo00003_oonfX00ooo]03o0?m6oookJP09oookJP0:o`3oAOoonf[ooo]Z
oookJ_nW0?ooe?l0of?o0?n40?oocP3oocP0o`;ooo]Z00?ooll0oookJ_oonfX0c_oonfX008oooo]Z
00?o@_l0oookJ_oonfX05_oonfX00ooJ0?oooo]ZoookJP0XoookJP?o001o0ooonfX3o`00O`03o`0@
oooonf[ooo]Z00Wooo]Z0ol007l2oookJPOo001o1ooonfX4o`0000kooo]Z00Cook@0onGo0?oUo`3o
iOl01ooonfX2oiCo00Wo0?mM2Om4o`3ooookJUOooo]Z00?o@_l0oookJ_oonfX05OoonfX00ooJ0?oo
oo]ZoookJP0XoookJP?o001o0ooonfX3o`00O`03o`0@oooonf[ooo]Z00Wooo]Z0ol007l2oookJPOo
001o1ooonfX4o`0000kooo]Z00?ook@0o`3oA_oonfX02OoonfX02ol0odGooo]ZoookJ_oonf[oocT0
omCo0?m^o`3oo`28oh@0ooo>0?oo>03o00;ooo]Z00?ooll0oookJ_oonfX0cOoonfX008oooo]Z00?o
@_l0oookJ_oonfX05OoonfX00ooJ0?oooo]ZoookJP0YoookJP?o001o0ooonfX2o`00O`03o`0@oooo
nf[ooo]Z00Cooo]Z0ol007l3oookJP?o001o0_oonfX6o`00O`Sooo]Z1?l0000>oookJP04oond0?oU
o`3oiOl0onGo00Oooo]Z0_nDo`000ol0ojgo0?mMo`3oG@06o`3oG@03ocP0oom4o`3oA?l000OoA?l0
oooonfYFoookJP03od;o0?oonf[ooo]Z01Cooo]Z00?ofP3ooookJ_oonfX0:OoonfX3o`00O`?ooo]Z
0_l007l00ol04?oooo]ZoookJP04oookJP?o001o0ooonfX3o`00O`;ooo]Z1_l007l8oookJPCo0000
3_oonfX00ooo]03ooo]Zo`3oAP0:oookJP0:o`3oAOoonf[ooo]ZoookJ_oDo`3oR?l0o`3o7?oo08So
Q03oocP0o`?ooo]Z0_ooc`3=oookJP00S_oonfX00om2o`3ooo]ZoookJP0EoookJP03omX0oooonf[o
oo]Z02[ooo]Z0ol007l3oookJP;o001o00?o013ooookJ_oonfX01?oonfX3o`00O`?ooo]Z0ol007l2
oookJP;o001o3?oonfX4o`0000gooo]Z00?oiOl0oond0?oUo`000ooUo`06oookJP?oU?l01?l0oed0
0ooDo`3o0?mMo`3oG@02o`3oG@03ocP0oom4o`3oA?l000KoA?l0oooonfYEoookJP03od;o0?oonf[o
oo]Z01Cooo]Z00?ofP3ooookJ_oonfX0:_oonfX3o`00O`?ooo]Z0_l007l00ol04?oooo]ZoookJP04
oookJP?o001o0ooonfX3o`00O`;ooo]Z0_l007l<oookJPCo00003_oonfX00ooo]03ooo]Zo`3oAP0:
oookJP0;o`3oAOoonf[ooo]ZoookJ_oo>@3oe?l0ohSo0?l0oacoQ03ooookJ_lh0?l01?oonfX00ooo
c`3ooo]ZoookJP3:oookJP00SOoonfX00om2o`3ooo]ZoookJP0EoookJP03omX0oooonf[ooo]Z02co
oo]Z0ol007l01?oonf[o001oo`00Ool04?l7oookJPCo001o0_oonfX3o`00O`;ooo]Z0_l007l<oook
JPCo00003OoonfX00ooUo`3ook@0onGo0003onGo00Kooo]Z1?nDo`03o`3oG@03omCo0?l0oego0?mM
00?o0?mM00?o>03oodCo0?m4o`001?m4o`3ooookJUGooo]Z00?o@_l0oookJ_oonfX05?oonfX00ooJ
0?oooo]ZoookJP0/oookJP?o001o00Cooo]Zo`00Ool007oo013o1ooonfX4o`00O`;ooo]Z0ol007l2
oookJP;o001o3?oonfX4o`0000kooo]Z00?ook@0oookJ_l0odH02_oonfX00ol0odGooo]ZoookJP02
oookJP07omCo0?n8o`3oHol0oon70?n40?oocP3oocP0o`04oookJP03ooo?0?oonf[ooo]Z0<Wooo]Z
002<oookJP03od;o0?oonf[ooo]Z01Gooo]Z00?ofP3ooookJ_oonfX0;OoonfX5o`00O`03o`0@ool0
07oooo]Z00Oooo]Z1ol007l4oookJPOo001o1_oonfX4o`0000gooo]Z00?oiOl0oond0?oUo`000ooU
o`06oookJPGoU?l00ol0oed00ooDo`3o0?mMo`3oG@03o`3oG@GoA?l000?ooll0oookJ_oonfX0Yooo
nfX00ooob@3ooo]ZoookJP2WoookJP03od;o0?oonf[ooo]Z01Gooo]Z00?ofP3ooookJ_oonfX0;?oo
nfX5o`00O`03o`0@ool007oooo]Z00Oooo]Z1ol007l4oookJPOo001o1_oonfX4o`0000kooo]Z00?o
ok@0oookJ_l0odH02ooonfX03?l0odGooo]ZoookJ_oonf[oocT0omCo0?n8o`3o0?lLoon70?n40?oo
cP3oocP0o`Cooo]Z00?ooll0oookJ_oonfX0b?oonfX008_ooo]Z00?o@_l0oookJ_oonfX05OoonfX0
0ooJ0?oooo]ZoookJP0_oookJPCo001o00?o013ooookJ_oonfX02?oonfX5o`00O`Gooo]Z1ol007l6
oookJPCo00003OoonfX00ooUo`3ook@0onGo0004onGo00Gooo]Z1OnDo`03o`3oG@03omCo0?l0oego
0?mM00Co0?mM0om4o`02oookJP03ooo?0?oonf[ooo]Z0:Cooo]Z0ooob@2XoookJP03od;o0?oonf[o
oo]Z01Gooo]Z00?ofP3ooookJ_oonfX0;_oonfX4o`00O`03o`0@oooonf[ooo]Z00Sooo]Z1Ol007l5
oookJPOo001o1_oonfX4o`0000kooo]Z00?ook@0oookJ_l0odH02ooonfX00ol0odGooo]ZoookJP02
oookJP08omCo0?n8o`3oHol0oon70?oonf[oQ03oolh0oolh0?l4oookJP03ooo?0?oonf[ooo]Z0<Oo
oo]Z002:oookJP03od;o0?oonf[ooo]Z01Gooo]Z00?ofP3ooookJ_oonfX0<ooonfX00ol04?oooo]Z
oookJP0PoookJPCo00003OoonfX00ooUo`3ook@0onGo0004onGo00Gooo]Z1_nDo`03o`3oG@03omCo
0?l0oego0?mM00;o0?mM00Co0?n]ocP0oom4o`3oA?l00ooonfX00oooc`3ooo]ZoookJP2RoookJPCo
olT0YooonfX00om2o`3ooo]ZoookJP0EoookJP03omX0oooonf[ooo]Z03;ooo]Z00?o013ooookJ_oo
nfX08?oonfX4o`0000kooo]Z00?ook@0oookJ_l0odH03?oonfX03Ol0odGooo]ZoookJ_oonf[oocT0
omCo0?n8o`3oHol0oon70?oo08SoQ03oolh0oolh0?l01?oonfX00oooc`3ooo]ZoookJP2UoookJP;o
oll07ooonfX008Wooo]Z00?o@_l0oookJ_oonfX05_oonfX00ooJ0?oooo]ZoookJP0coookJP03o`0@
oooonf[ooo]Z023ooo]Z1?l0000<oookJP;oiOl000?ook@0onGo0?oUo`000ooUo`05oookJPKoU?l0
1?l0oed00ooDo`3o0?mMo`3oG@02o`3oG@03odCo0?lh0?ooA?l000;oA?l00_oonfX00oooc`3ooo]Z
oookJP2PoookJPGoolT0Y_oonfX00om2o`3ooo]ZoookJP0EoookJP03omX0oooonf[ooo]Z03?ooo]Z
00?o013ooookJ_oonfX08?oonfX4o`0000kooo]Z00?ook@0oookJ_l0odH03?oonfX03_l0odGooo]Z
oookJ_oonf[oocT0oookJ_oDo`3oK_l0of?o0?ooQ`3oo`28oh@0oolh0?ooo`2F1?oonfX00oooc`3o
oo]ZoookJP2RoookJP;ooll08OoonfX008Sooo]Z00?o@_l0oookJ_oonfX05_oonfX00ooJ0?oooo]Z
oookJP0coookJP03o`0@oooonf[ooo]Z027ooo]Z1Ol0000;oookJP;oiOl000?ook@0onGo0?oUo`00
1?oUo`05oookJPKoU?l000Co0?n]o`3oGOl0oegoe?l01Ol0oed00om4o`3o>03oodCo0002odCo00;o
oo]Z00?ooll0oookJ_oonfX0W_oonfX6ooo90:Gooo]Z00?o@_l0oookJ_oonfX05OoonfX00ooJ0?oo
oo]ZoookJP0coookJP03o`0@oooonf[ooo]Z027ooo]Z1Ol0000=oookJP03oond0?oonf[o0?m600co
oo]Z00?o0?m5oookJ_oonfX00_oonfX02_oo>@3oe?l0ohSo0?mSo`3oohL0oookJ_oo08SoQ03oocP0
oooo09H4oookJP03ooo?0?oonf[ooo]Z09oooo]Z0_ooc`0SoookJP00R?oonfX00om2o`3ooo]Zoook
JP0EoookJP03omX0oooonf[ooo]Z03?ooo]Z00?o013ooookJ_oonfX08_oonfX4o`0000cooo]Z0_oU
o`000ooo]03oiOl0oookJP09oookJPKoU?l000Go0?l<o`3oGOl0oego0?mMomCo0005o`3oG@GoA?l0
0_oonfX2ooo?09gooo]Z1Ooob@2VoookJP03od;o0?oonf[ooo]Z01Kooo]Z00?ofP3ooookJ_oonfX0
<_oonfX00ol04?oooo]ZoookJP0RoookJPCo00003_oonfX00ooo]03ooo]Zo`3oAP0=oookJP0?o`3o
AOoonf[ooo]ZoookJ_oo>@3ooo]ZomCo0?m^o`3oHol0oon70?oo08Sooo]Zoh@0oolh0?ooo`2F00Co
oo]Z0_ooc`2MoookJP;ooll09OoonfX008Oooo]Z00?o@_l0oookJ_oonfX05OoonfX00ooJ0?oooo]Z
oookJP0doookJP03o`0@oooonf[ooo]Z02;ooo]Z1?l0000>oookJP03oond0?l0odKooo]Z00Wooo]Z
0onDo`001Ooonf[o0?m5oookJ_l0o`co0?n]00;o0?mM00?oe?l0o`3oGOl0oed01?l0oed5odCo00?o
oo]Z00?ooll0oookJ_oonfX0V?oonfX00oooc`3oolT0ooo9002YoookJP03od;o0?oonf[ooo]Z01Ko
oo]Z00?ofP3ooookJ_oonfX0<ooonfX00ol04?oooo]ZoookJP0RoookJPCo00003_oonfX00ooo]03o
oo]Zo`3oAP0=oookJP03o`3oAOoonf[ooo]Z00;ooo]Z00[oocT0ojL0oooDo`3oK_l0of?o0?oonf[o
o`28oookJ_n40?oo>03o1_oonfX00oooc`3ooo]ZoookJP2HoookJP;ooll09ooonfX008Kooo]Z00?o
@_l0oookJ_oonfX05OoonfX00ooJ0?oooo]ZoookJP0doookJP03o`0@oooonf[ooo]Z02?ooo]Z1?l0
000>oookJP03oond0?l0odKooo]Z00Wooo]Z00KoU?l0oookJ_oonf[ooo]Zo`3oAOoonfX2o`3o30?o
0?mM00Coe?l0o`3oGOl0oego0?mM1om4o`04oookJP03ooo?0?oonf[ooo]Z09Gooo]Z0_ooc`2[oook
JP03od;o0?oonf[ooo]Z01Kooo]Z00?ofP3ooookJ_oonfX0<ooonfX00ol04?oooo]ZoookJP0Soook
JPCo00003_oonfX00ooo]03ooo]Zo`3oAP0=oookJP03o`3oAOoonf[ooo]Z00;ooo]Z00_oocT0oook
J_n8o`3oe?l0ofko0?ooQ`3ooo]Zool0R?n40?oooo]ZocP0o`06oookJP03ooo?0?oonf[ooo]Z09Go
oo]Z0_ooc`0YoookJP00QOoonfX00om2o`3ooo]ZoookJP0EoookJP03omX0oooonf[ooo]Z03Gooo]Z
00?o013ooookJ_oonfX08ooonfX4o`0000kooo]Z00?ook@0o`3oA_oonfX03OoonfX01?l0odGooo]Z
o`3o3?oonfX3o`3oG@03omCo0?l0oego0?mM00WoA?l01?oonfX2ooo?09;ooo]Z0oooc`2/oookJP03
od;o0?oonf[ooo]Z01Kooo]Z00?ofP3ooookJ_oonfX0=?oonfX00ol04?oooo]ZoookJP0SoookJPCo
00003_oonfX00ooo]03ooo]Zo`3oAP0>oookJP03o`3oAOoonf[ooo]Z00;ooo]Z00_oocT0ojL0oooD
o`3oK_l0of?o0?ooQ`3ooo]Zool0R?n40?ooo`2FocP0o`06oookJP;ooll0T_oonfX3ooo?02_ooo]Z
0024oookJP03od;o0?oonf[ooo]Z01Kooo]Z00?ofP3ooookJ_oonfX0=?oonfX00ol04?oooo]Zoook
JP0ToookJPCo00003_oonfX00ooo]03o0?m6oookJP0>oookJP04o`3oAOoonf[ooo]ZoookJP?o0?mM
00?oe?l0ohSo0?l0oed00om4o`000on40?ooA?l0odCo0004odCo00Cooo]Z0_ooc`2>oookJP;ooll0
[_oonfX00om2o`3ooo]ZoookJP0GoookJP03omX0oooonf[ooo]Z03?ooo]Z00?o013ooookJ_oonfX0
9?oonfX4o`0000kooo]Z00?ook@0oookJ_l0odH03_oonfX00ol0odGooo]ZoookJP02oookJP0<ooli
0?oonf[oY`3oomCo0?m^o`3oo`3Qoon70?oonf[oQ03oolh0oolh0?ooo`2F1ooonfX2ooo?08kooo]Z
0_ooc`0^oookJP00PooonfX00om2o`3ooo]ZoookJP0FoookJP03omX0oooonf[ooo]Z03Gooo]Z00?o
013ooookJ_oonfX09?oonfX4o`0000kooo]Z00?ook@0o`3oA_oonfX03_oonfX01Ol0odGooo]Zoook
J_oonf[o0?mM00;oU?l000Coe?l0ohSo0?m^o`3o0?mM2_m4o`05oookJP;oU?l0R_oonfX2ooo?0:oo
oo]Z00?o@_l0oookJ_oonfX05ooonfX00ooJ0?oooo]ZoookJP0doookJP03o`0@oooonf[ooo]Z02Co
oo]Z1?l0000>oookJP03oond0?oonf[o0?m600kooo]Z00?o0?m5oookJ_oonfX00ooonfX03?oo>@3o
Y`3oomCo0?m^o`3oHol0ool0hOooQ`3ooo]Zoh@0ooo>0?oo>03oool0UPSooo]Z0_ooc`2:oookJP;o
oll0<?oonfX0087ooo]Z0_oob@0HoookJP03omX0oooonf[ooo]Z03Gooo]Z00?o013ooookJ_oonfX0
9OoonfX4o`0000kooo]Z00?ook@0o`3oA_oonfX03_oonfX01Ol0odGooo]ZoookJ_oonf[o0?l<00;o
U?l00_l0o``00on8o`3oK_l0o`3oG@0:odCo00Cooo]Z1OnDo`25oookJP;ooll0/?oonfX00om2o`3o
oo]ZoookJP0GoookJP03omX0oooonf[ooo]Z03Cooo]Z00?o013ooookJ_oonfX09OoonfX4o`0000ko
oo]Z00?ook@0oookJ_l0odH03ooonfX00ol0odGooo]ZoookJP02oookJP07ooli0?oonf[oY`3oomCo
0?m^o`3oo`3Qoon70002oookJP04oh@0ooo>0?oo>03oool0UPWooo]Z00?ooll0oookJ_oonfX0QOoo
nfX2ooo?03;ooo]Z0020oookJP?oolT05ooonfX00ooJ0?oooo]ZoookJP0eoookJP03o`0@oooonf[o
oo]Z02Kooo]Z1?l0000>oookJP03oond0?l0odKooo]Z00kooo]Z00?o0?m5oookJ_oonfX00_oonfX2
oiCo0004o`3oGOl0o`co0?l<o`3o30;o0?mM2om4o`03oookJPOoU?l0OooonfX3ooo?0;;ooo]Z00?o
@_l0oookJ_oonfX05_oonfX00ooJ0?oooo]ZoookJP0eoookJP03o`0@oooonf[ooo]Z02Gooo]Z1?l0
000>oookJP03oond0?oonf[o0?m600oooo]Z00?o0?m5oookJ_oonfX00ooonfX02ooo>@3o/_l0omCo
0?n8o`3oHol0ool0hOooQ`3ooo]Zool0R?n40?oocP3o00;o>03o2OoonfX00oooc`3ooo]ZoookJP21
oookJP?ooll0=?oonfX007oooo]Z0ooob@0GoookJP03omX0oooonf[ooo]Z03Kooo]Z00?o013ooook
J_oonfX09_oonfX4o`0000kooo]Z00?oogT0o`3oA_oonfX03ooonfX01?l0odGooo]ZoookJ_oonfX3
oiCo00Co0?l<0_l0oed;odCo00?ooo]Z2OnDo`1joookJP;ooll0]?oonfX00om2o`3ooo]ZoookJP0F
oookJP03omX0oooonf[ooo]Z03Gooo]Z00?o013ooookJ_oonfX09_oonfX4o`0000kooo]Z00?ook@0
oookJ_l0odH03ooonfX00ol0odGooo]ZoookJP04oookJP0=ooli0?nbo`3oe?l0ohSo0?mSo`3ooo]Z
oon70?oonf[oo`28oh@0ooo>0?oooo]ZocP0o`09oookJP;ooll0OooonfX2ooo?03Oooo]Z001noook
JPCoolT05ooonfX00ooJ0?oooo]ZoookJP0eoookJP03o`0@oooonf[ooo]Z02Oooo]Z1?l0000>oook
JP03oomi0?l0odKooo]Z00oooo]Z00?o0?m5oookJ_oonfX00_oonfX2oiCo00Go0?l<0_l0oed;odCo
00?ooo]Z2onDo`1doookJP?ooll0]OoonfX00om2o`3ooo]ZoookJP0GoookJP03omX0oooonf[ooo]Z
03Gooo]Z00?o013ooookJ_oonfX09_oonfX4o`0000kooo]Z00?ook@0oookJ_l0odH04?oonfX00ol0
odGooo]ZoookJP03oookJP0>ooli0?nbo`3oe?l0ohSo0?m^o`3oHol0oookJ_ooQ`3ooo]Zool0R?n4
0?oocP3ooookJ_lh0?l:oookJP;ooll0N_oonfX3ooo?03Wooo]Z001moookJPCoolT05ooonfX00ooJ
0?oooo]ZoookJP0eoookJP03o`0@oooonf[ooo]Z02Sooo]Z1Ol0000<oookJP;oogT000?o0?m6oook
J_oonfX03_oonfX00ol0odGooo]ZoookJP02oookJP;oU?l01_l0o``3o`3oG@OoA?l01_oonfX;oiCo
073ooo]Z0oooc`2goookJP03od;o0?oonf[ooo]Z01Oooo]Z00?ofP3ooookJ_oonfX0=OoonfX00ol0
4?oooo]ZoookJP0WoookJPGo00003OoonfX00ooo]03ooo]Zo`3oAP0@oookJP03o`3oAOoonf[ooo]Z
00Cooo]Z00OoocT0ool0A?oDo`3oR?l0ofko0?oo0>7oohL000;ooo]Z00Goo`28oh@0ooo>0?oooo]Z
ocP0o`0;oookJP03ooo?0?oonf[ooo]Z07Cooo]Z0oooc`0loookJP00NooonfX6ooo901Kooo]Z00?o
fP3ooookJ_oonfX0=_oonfX00ol04?oooo]ZoookJP0XoookJPCo00003OoonfX2oomi0003o`3oA_oo
nf[ooo]Z00oooo]Z00Co0?m5oookJ_oonf[ooo]Z0onDo`06o`3o30;o0?mM1_m4o`08oookJP[oU?l0
K?oonfX4ooo?0;Wooo]Z00?o@_l0oookJ_oonfX05ooonfX00ooJ0?oooo]ZoookJP0eoookJP03o`0@
oooonf[ooo]Z02Sooo]Z1?l0000>oookJP03oond0?oonf[o0?m6013ooo]Z00?o0?m5oookJ_oonfX0
1?oonfX03ooo>@3o/_l0omCo0?n8o`3oK_l0of?o0?oo0>7oohL0oookJ_oo08Sooo]Zoh@0ooo>0?oo
>03oool0UP0;oookJP;ooll0LOoonfX3ooo?03oooo]Z001joookJPKoolT05_oonfX00ooJ0?oooo]Z
oookJP0foookJP03o`0@oooonf[ooo]Z02Wooo]Z1?l0000=oookJP;oogT000?o0?m6oookJ_oonfX0
3ooonfX01?l0odGooo]ZoookJ_oonfX3oiCo00Oo0?l<0_l0oed4odCo0003olh0oolh0?oooo]Z00Ko
oo]Z2OnDo`1ZoookJP?ooll0_?oonfX00om2o`3ooo]ZoookJP0GoookJP03omX0oooonf[ooo]Z03Ko
oo]Z00?o013ooookJ_oonfX0:?oonfX4o`0000kooo]Z00?ook@0oookJ_l0odH04?oonfX00ol0odGo
oo]ZoookJP05oookJP0?ooli0?oonf[oe?l0ool0Oom^o`3oHol0oookJ_ooQ`3ooo]Zool0R?oonf[o
Q03oolh0oolh0?ooo`2F00cooo]Z0_ooc`1/oookJP?ooll0@_oonfX007Wooo]Z1ooob@0EoookJP03
omX0oooonf[ooo]Z03Oooo]Z00?o013ooookJ_oonfX0:OoonfX4o`0000cooo]Z1?ooN@0AoookJP04
o`3oAOoonf[ooo]ZoookJP?oU?l02?l0o``02?nDo`3oA?l0odCo0?m4o`3oQ03oodCo0?o>0?oo>03o
1ooonfX8oiCo06Oooo]Z0oooc`2ooookJP03od;o0?oonf[ooo]Z01Kooo]Z00?ofP3ooookJ_oonfX0
=_oonfX00ol04?oooo]ZoookJP0YoookJPCo00003_oonfX00ooo]03o0?m6oookJP0AoookJP03o`3o
AOoonf[ooo]Z00Cooo]Z013oocT0ok;o0?nW0?ooe?l0ofko0?l0oacoHol0oookJ_ooQ`3ooo]Zool0
R?n40?oooo]Zolh0oolh0?ooo`2F3OoonfX00oooc`3ooo]ZoookJP1VoookJP?ooll0AOoonfX007So
oo]Z1ooob@0FoookJP03omX0oooonf[ooo]Z03Kooo]Z00?o013ooookJ_oonfX0:_oonfX4o`0000co
oo]Z1?ooN@0BoookJP04o`3oAOoonf[ooo]ZoookJP;oU?l000?o0?mMo`3o3?l0o``01_l0o``02?l0
oegoA?l0odCo0?m4o`3oQ03oodCo0?oonf[o>03o1ooonfX6oiCo00?ooll0H_oonfX3ooo?0<7ooo]Z
00?o@_l0oookJ_oonfX05ooonfX00ooJ0?oooo]ZoookJP0foookJP03o`0@oooonf[ooo]Z02Wooo]Z
1?l0000>oookJP03oond0?l0odKooo]Z017ooo]Z00?o0?m5oookJ_oonfX01OoonfX02?oo>@3o/_l0
ohSo0?oDo`3oK_l0of?o0?oo0>7oohL00_oonfX01_oo08SoQ03ooookJ_o>0?oo>03oool0UPgooo]Z
0_ooc`1SoookJP?ooll0B?oonfX007Oooo]Z2?oob@0EoookJP03omX0oooonf[ooo]Z03Kooo]Z00?o
olT0oookJ_oonfX0:ooonfX4o`0000cooo]Z1?ooN@0BoookJP04o`3oAOoonf[ooo]ZoookJP?oU?l0
2Ol0o``4odCo0004oh@0oom4o`3ooo]ZocP0o`Oooo]Z1?nDo`04oookJP?ooll0G?oonfX3ooo?0<?o
oo]Z00?o@_l0oookJ_oonfX05ooonfX00ooJ0?oooo]ZoookJP0foookJP03o`0@oooonf[ooo]Z02[o
oo]Z1?l0000>oookJP03oond0?l0odKooo]Z017ooo]Z00?o0?m5oookJ_oonfX01OoonfX04Ooo>@3o
oo]Zok;o0?oDo`3oK_l0o`3o7?mSo`3ooo]Zoon70?oonf[oo`28oookJ_n40?oooo]Zolh0oolh0?oo
o`2F00kooo]Z0oooc`1MoookJP?ooll0BooonfX007Kooo]Z2?oob@0EoookJP03omX0oooonf[ooo]Z
03Kooo]Z0_oob@0]oookJPCo00002ooonfX5oomi01;ooo]Z00Go0?m5oookJ_oonf[ooo]ZoiCo0002
oookJPWo0?l<1Om4o`001?n40?ooA?l0odCo0?lh0?l7oookJP?oU?l01ooonfX3ooo?05Kooo]Z0ooo
c`35oookJP03od;o0?oonf[ooo]Z01Oooo]Z00?ofP3ooookJ_oonfX0=ooonfX00ol04?oooo]Zoook
JP0ZoookJPCo00003_oonfX00ooo]03o0?m6oookJP0BoookJP03o`3oAOoonf[ooo]Z00Gooo]Z017o
ocT0ok;o0?nW0?ooe?l0ofko0?l0V?ooHol0oookJ_ooQ`3ooo]Zool0R?oonf[oQ03ooookJ_o>0?oo
>03oool0UP0@oookJP?ooll0EooonfX3ooo?04kooo]Z001hoookJPKoolT05?oonfX00ooJ0?oooo]Z
oookJP0foookJP?oolT0;OoonfX4o`0000_ooo]Z1OooN@0BoookJP03o`3oAOoonf[ooo]Z00Cooo]Z
2_l0o``5odCo0004oh@0oom4o`3oA?l0ocP0o`Oooo]Z00?oU?l0oookJ_oonfX02OoonfX3ooo?053o
oo]Z0oooc`37oookJP03od;o0?oonf[ooo]Z01Oooo]Z00?ofP3ooookJ_oonfX0=ooonfX00ol04?oo
oo]ZoookJP0[oookJPCo00003_oonfX00ooo]03o0?m6oookJP0BoookJP03o`3oAOoonf[ooo]Z00Go
oo]Z00WoocT0oookJ_nbo`3oY`3oomCo0?m^o`3oHol0oookJ_ooQ`000_oonfX01ooo08Sooo]Zoh@0
oooonf[ocP3oocP0oooo09H04_oonfX3ooo?057ooo]Z0oooc`1AoookJP00N?oonfX5ooo901?ooo]Z
0_oob@0hoookJP?oolT0;_oonfX4o`0000_ooo]Z1OooN@0CoookJP03o`3oAOoonf[ooo]Z00Cooo]Z
2_l0o``5odCo0005oh@0oom4o`3oA?l0ocP0oooo09H05?oonfX3ooo?04[ooo]Z0oooc`39oookJP03
od;o0?oonf[ooo]Z01Oooo]Z00?ofP3ooookJ_oonfX0=ooonfX00ol04?oooo]ZoookJP0/oookJPCo
00003_oonfX00ooo]03o0?m6oookJP0BoookJP03o`3oAOoonf[ooo]Z00Gooo]Z00[oocT0oookJ_nb
o`3oY`3oomCo0?m^o`3o09Soof?o0?oonf[oohL00_oonfX01Ooo08Sooo]Zoh@0oooonf[ocP3o00;o
>03o5?oonfX3ooo?04_ooo]Z0oooc`1DoookJP00N?oonfX00ooob@3ooo]Zooo90002ooo901;ooo]Z
0ooob@0goookJPCoolT0;_oonfX4o`0000[ooo]Z1_ooN@0CoookJP03o`3oAOoonf[ooo]Z00Cooo]Z
1_l0o``01?n8o`3o0?l<o`3o3?l0o``6odCo0005oh@0oom4o`3oA?l0ocP0oooo09H05_oonfX3ooo?
04Cooo]Z0oooc`3<oookJP03od;o0?oonf[ooo]Z01Oooo]Z00?ofP3ooookJ_oonfX0=ooonfX00ol0
4?oooo]ZoookJP0/oookJPCo00003OoonfX00ooo]03ooo]Zo`3oAP0CoookJP03o`3oAOoonf[ooo]Z
00Kooo]Z00WoocT0ok;o0?oo04CoY`3oomCo0?m^o`3oHol0ool0hOooQ`000ooonfX01ooo08Sooo]Z
oh@0oooonf[ocP3ooookJ_lh0?l05_oonfX3ooo?04Cooo]Z1?ooc`1GoookJP00MooonfX01Ooob@3o
oo]ZoookJ_oonf[oolT001;ooo]Z0ooob@0goookJPGoolT0;_oonfX5o`0000Wooo]Z1oooN@0Boook
JP03o`3oAOoonf[ooo]Z00Gooo]Z1?l0o``00ooDo`3oR?l0o`3o3003o`3o30KoA?l00_nDo`000ooo
nf[o>03oool0UP0HoookJPCooll0>ooonfX5ooo?0<kooo]Z00?o@_l0oookJ_oonfX05ooonfX00ooJ
0?oooo]ZoookJP0goookJP03o`0@oooonf[ooo]Z02gooo]Z1Ol0000<oookJP03oond0?oonf[o0?m6
01Cooo]Z00?o0?m5oookJ_oonfX01OoonfX02_oo>@3ooo]Zok;o0?oo04Koe?l0ohSo0?l0oacoHol0
ool0hOooQ`03oookJP07ool0R?oonf[oQ03ooookJ_o>0?oooo]ZocP0o`0HoookJPCooll0>ooonfX5
ooo?05_ooo]Z001foookJP03ooo90?oonf[ooo]Z01Cooo]Z1?oob@0foookJPKoolT0;_oonfX4o`00
00[ooo]Z1oooN@0CoookJP03o`3oAOoonf[ooo]Z00Gooo]Z00Go0?l<ooli0?l0o`co0?l<omCo0005
o`3o30GoA?l00onDo`000oo>0?oo>03oool0UP0KoookJP?ooll05?oonfX5onGo01_ooo]Z1?ooc`3B
oookJP03od;o0?oonf[ooo]Z01Oooo]Z00?ofP3ooookJ_oonfX0>?oonfX00ol04?oooo]ZoookJP0]
oookJPCo00003OoonfX00ooo]03ooo]Zo`3oAP0DoookJP03o`3oAOoonf[ooo]Z00Kooo]Z00[oocT0
ok;o0?oonf[o05SoomCo0?m^o`3o0?lLof?o0?oonf[oohL00ooonfX01ooo08Sooo]Zoh@0oooonf[o
cP3ooookJ_lh0?l06ooonfX3ooo?03Cooo]Z1?ooc`1PoookJP00MOoonfX00ooob@3ooo]ZoookJP0D
oookJPCoolT0=_oonfX6ooo902oooo]Z1?l00009oookJPSoogT04ooonfX00ooUo`3ooo]ZoookJP05
oookJP06o`3o3?oo>@3o0?l<o`3o3?nW0?ooe?l01Ol0o``3odCo0003oookJ_oo08SoU?l000?oU?l0
0_lh0?l00ooo09Kooo]ZoookJP0JoookJPKooll01ooonfX<onGo01?ooo]Z2?ooc`3EoookJP03od;o
0?oonf[ooo]Z01Oooo]Z00?ofP3ooookJ_oonfX0>?oonfX00ol04?oooo]ZoookJP0^oookJPCo0000
3OoonfX00ooo]03ooo]Zo`3oAP0DoookJP03o`3oAOoonf[ooo]Z00Kooo]Z00_oocT0oookJ_nbo`3o
o`16omCo0?n8o`3oK_l0o`2HoomSo`3ooo]Zoon70003oookJP06ool0R?oonf[oQ03ooookJ_o>0?oo
oo]Z0_lh0?lLoookJPKooll09_oonfX8ooo?06Cooo]Z001doookJP03ooo90?oonf[ooo]Z01?ooo]Z
1_oob@0eoookJPOoolT0;ooonfX4o`0000Wooo]Z2?ooN@0CoookJP03onGo0?oonf[ooo]Z00Kooo]Z
00GoocT0o`3o3?l0o`co0?l<omCo0006o`3o3004odCo0?oonf[ooo]Zool0R0KoU?l00_lh0?lQoook
JP?ooll04?oUo`08oookJP_ooll0g?oonfX00om2o`3ooo]ZoookJP0GoookJP03omX0oooonf[ooo]Z
03Sooo]Z00?o013ooookJ_oonfX0;ooonfX4o`0000gooo]Z00?ook@0oookJ_l0odH05?oonfX00ol0
odGooo]ZoookJP07oookJP0:ooli0?oonf[o/_l0omCo0?n8o`3oK_l0o`3o7?mSo`3oo`3Qoon700Co
oo]Z00Goo`28oookJ_n40?oooo]Zolh0o`02oookJP03ocP0oooo09Kooo]Z01oooo]Z2Oooc`0Boook
JP_ooll0K?oonfX007?ooo]Z00?oolT0oookJ_oonfX04ooonfX7ooo903Cooo]Z2?oob@0_oookJPCo
00003OoonfX00ooo]03ooo]Zo`3oAP0DoookJP;oiOl02?oonfX3o`3o3003ojL0oooDo`3o0?l<00Go
0?l<00CoA?l0oookJ_oonf[oo`281_nDo`000ooonf[o>03ooookJP0ToookJPkoiOl02?ooc`3Voook
JP03od;o0?oonf[ooo]Z01Sooo]Z00?ofP3ooookJ_oonfX0>?oonfX00ol04?oooo]ZoookJP0_oook
JPCo00003OoonfX00ooo]03ooo]Zo`3oAP0EoookJP03o`3oAOoonf[ooo]Z00Kooo]Z00_oocT0oook
J_nbo`3oo`14omCo0?n8o`3oK_l0o`3o7?mSo`3ooo]Zoon70004oookJP05ool0R?oonf[oQ03ooook
J_o>0?l00_oonfX00olh0?ooo`2FoookJP0WoookJQ;ooll0MooonfX007?ooo]Z00?o@_l0oookJ_oo
nfX04_oonfX7ooo903Cooo]Z2?oob@0`oookJPCo00003OoonfX00ooo]03ooo]Zo`3oAP0DoookJP?o
iOl01ooonfX01Ooo>@3o0?l<o`3o3?l0o`coe?l000Oo0?l<00?oA?l0oookJ_oonfX02?nDo`02ocP0
obKooo]Z2_oUo`3_oookJP03od;o0?oonf[ooo]Z01Oooo]Z00?ofP3ooookJ_oonfX0>?oonfX00ol0
4?oooo]ZoookJP0`oookJPCo00003OoonfX00ooo]03ooo]Zo`3oAP0EoookJP03o`3oAOoonf[ooo]Z
00Oooo]Z00_oocT0oookJ_nbo`3oe?l0o`1Hoon8o`3o0?mUo`3o7?mSo`3ooo]Zoon70004oookJP04
ool0R?oonf[oQ03ooookJP;ocP3o00Cooo]ZocP0oolh0?ooo`2F[ooonfX007;ooo]Z00?o@_l0oook
J_oonfX04_oonfX8ooo903?ooo]Z2Ooob@0`oookJPCo00003OoonfX00ooo]03ooo]Zo`3oAP0Doook
JP?oiOl01ooonfX00ooo>@3o0?l<odCo0002o`3o3003omCo0?l0o`co0?l<00;o0?l<00Co0?mModCo
0?m4o`3oA?l00_oonfX9oiCo0003ocP0oooonf[ooo]Z02Kooo]Z1ooUo`3^oookJP03od;o0?oonf[o
oo]Z01Oooo]Z00?ofP3ooookJ_oonfX0>OoonfX00ol04?oooo]ZoookJP0`oookJPCo00003OoonfX0
0ooo]03ooo]Zo`3oAP0EoookJP03o`3oAOoonf[ooo]Z00Oooo]Z00WoocT0oookJ_nbo`3ooo]ZomCo
0?n8o`3oK_l0o`3oIOmSo`000_oonfX00oooQ`3ooo]ZoookJP02oookJP03ool0R?oonf[oQ03o00;o
oo]Z00GocP3ooookJ_oonf[o>03oool0UP2^oookJP00LOoonfX00om2o`3ooo]ZoookJP0BoookJPSo
olT0=_oonfX7ooo9033ooo]Z1?l0000<oookJP04oond0?oonf[ooo]Zo`3oAQCooo]Z1?oUo`07oook
JP03ooli0?m4o`3o0?l<00;o0?l<00?oe?l0o`3o3?l0o``00ol0oed3odCo00;ooo]Z2OnDo`000olh
0?oooo]ZoookJP0XoookJPCoiOl0kOoonfX00om2o`3ooo]ZoookJP0GoookJP03omX0oooonf[ooo]Z
03Wooo]Z00?o013ooookJ_oonfX0<OoonfX4o`0000cooo]Z00Cook@0oookJ_oonf[o0?m65_oonfX0
0ol0odGooo]ZoookJP07oookJP09ooli0?oonf[o/_l0ojL0oooDo`3oR?l0ofko0?l0oacoHol000;o
oo]Z00GoohL0oookJ_oonf[ooo]Zool0R002oookJP04oh@0oooonf[ooo]Zolh0o`;ooo]Z00?o>03o
ool0U_oonfX0[?oonfX0073ooo]Z00?o@_l0oookJ_oonfX04_oonfX9ooo903Sooo]Z1Ooob@0`oook
JPCo00003?oonfX00ooo]03ooo]Zo`3oAP0EoookJPCoiOl02?oonfX01Ooo>@3o0?mMo`3o3?l0o`co
e?l000?o0?l<00?oHol0odCo0?ooQ`000om4o`000ooonf[oU?l0oiCo0008oiCo0003ocP0oooonf[o
oo]Z02[ooo]Z00?oiOl0oookJ_oonfX0j_oonfX00om2o`3ooo]ZoookJP0HoookJP03omX0oooonf[o
oo]Z03Sooo]Z00?o013ooookJ_oonfX0<_oonfX4o`0000cooo]Z00?ook@0oookJ_l0odH05ooonfX0
0ol0odGooo]ZoookJP07oookJP0<ooli0?oonf[o/_l0ojL0oooDo`3oR?l0ofko0?l0ofGoHol0ool0
hOoonf[oohL01?oonfX01?oo08Sooo]ZoookJ_n40?l2oookJP05olh0oooonf[ooo]ZocP0oooo09H0
[?oonfX006oooo]Z00?o@_l0oookJ_oonfX05OoonfX6ooo903Wooo]Z00Co013oooo90?oob@3oolT0
<OoonfX4o`0000cooo]Z00?ook@0oookJ_l0odH05OoonfX5onGo00Oooo]Z00?oocT0o`3oGOl0o``0
0_l0o``01ooDo`3o0?l<o`3o3?l0o`coHol0odCo0?ooQ`000om4o`000ooonf[oU?l0oiCo000:oiCo
0?oooo]Z5ooonfX00om2o`3ooo]ZoookJP0HoookJP03omX0oooonf[ooo]Z03Wooo]Z00?o013ooook
J_oonfX0<_oonfX4o`0000cooo]Z00?ook@0oookJ_l0odH05ooonfX00ol0odGooo]ZoookJP07oook
JP0=ooli0?oonf[ooo]Zok;o0?nW0?ooe?l0ohSo0?m^o`3o0?mUof?o0?oo0>7ooo]Zoon70004oook
JP04ool0R?oonf[ooo]Zoh@0o`;ooo]Z0_o>0?l01?oonf[o>03oocP0oooo09JZoookJP00KooonfX0
0om2o`3ooo]ZoookJP0FoookJPGoolT0>?oonfX01Ol04?oooo]ZoookJ_oonf[oolT0037ooo]Z1?l0
000<oookJP03oond0?oonf[o0?m601Gooo]Z1_oUo`06oookJP06odCo0?oo>@3o0?mMo`3oGOl0o`co
e?l01?l0o``00omSo`3oA?l0oon70003odCo00ooU?l0oooonfXDoookJP03od;o0?oonf[ooo]Z01Oo
oo]Z00?ofP3ooookJ_oonfX0>OoonfX00ol04?oooo]ZoookJP0coookJPCo00003?oonfX00ooo]03o
oo]Zo`3oAP0GoookJP03o`3oAOoonf[ooo]Z00Sooo]Z00goocT0oookJ_nbo`3ooo]ZomCo0?n8o`3o
K_l0o`3oIOl0oacoHol0ool0hOoonf[oohL000Cooo]Z00Coo`28oookJ_oonf[oQ03o0ooonfX01Oo>
0?oooo]ZoookJ_lh0?ooo`2F0:Wooo]Z001^oookJP03od;o0?oonf[ooo]Z01Oooo]Z00?oolT0oook
J_oob@000_oob@0hoookJP03o`0@oooonf[ooo]Z03?ooo]Z1Ol0000;oookJP03oond0?oonf[oolT0
01Gooo]Z1_oUo`06oookJP04odCo0?oo>@3o0?mModCo00;o0?l<00?oe?l0o`3o3?l0o``00_l0o``3
odCo00?ooo]Z1?nDo`000ooonf[oQ03ooiCo0009oiCo0?oooo]Z4OoonfX00om2o`3ooo]ZoookJP0G
oookJP03omX0oooonf[ooo]Z03[ooo]Z00?o013ooookJ_oonfX0<ooonfX5o`0000_ooo]Z00?ook@0
oookJ_l0odH06?oonfX00ol0odGooo]ZoookJP07oookJP0;ooli0?oonf[ooo]Zok;o0?nW0?ooe?l0
ohSo0?m^o`3o0?mUo`3o7?mSo`000_oonfX00oooQ`3ooo]ZoookJP02oookJP04ool0R?oonf[ooo]Z
oh@0o`?ooo]Z00?ocP3ooookJ_oonfX00_lh0?nXoookJP00KOoonfX00om2o`3ooo]ZoookJP0Goook
JP05ooo90?oonf[ooo]ZoookJ_oob@00>?oonfX00ol04?oooo]ZoookJP0doookJPCo00003?oonfX0
0ooo]03ooo]Zooo9000EoookJPOoiOl01OoonfX2odCo0005ooli0?m4o`3o0?l<o`3o3?oDo`001Ol0
o``00onDo`3oA?l0odCo0002oookJP?oU?l00ooonfX00on40?ooU?l0oiCo000:oiCo0?oooo]Z3Ooo
nfX00om2o`3ooo]ZoookJP0GoookJP03omX0oooonf[ooo]Z03[ooo]Z00?o013ooookJ_oonfX0=?oo
nfX4o`0000cooo]Z00?ook@0oookJ_l0odH06?oonfX00ol0odGooo]ZoookJP08oookJP0;ooli0?oo
nf[o/_l0oookJ_nW0?ooe?l0oon00?m^o`3o0?lLoookJ_mSo`000_oonfX00oooQ`3ooo]ZoookJP02
oookJP04ool0R?oonf[ooo]Zoh@0o`?ooo]Z00GocP3ooookJ_oonf[ooo]ZocP0o`2WoookJP00K?oo
nfX00om2o`3ooo]ZoookJP0HoookJP03ooo90?oonf[ooo]Z03Wooo]Z00?o013ooookJ_oonfX0=Ooo
nfX4o`0000_ooo]Z00Cook@0oookJ_oob@3oolT05OoonfX7onGo00Kooo]Z00CoA?l0ooli0?m4o`3o
A?l00_l0o``00ooDo`3o0?l<o`3o3003o`3o3003oiCo0?m4o`3oA?l000;ooo]Z00?oU?l0oookJ_oo
08P00_oonfX00onDo`3oQ03ooh@0o`0<oiCo0?oooo]Z2_oonfX00om2o`3ooo]ZoookJP0HoookJP03
omX0oooonf[ooo]Z03Wooo]Z00?o013ooookJ_oonfX0=OoonfX4o`0000cooo]Z00?ook@0oookJ_l0
odH06?oonfX00ol0odGooo]ZoookJP08oookJP0>ooli0?oonf[ooo]Zok;o0?nW0?ooe?l0ohSo0?oo
04_oK_l0o`3o7?mSo`3oo`3QoookJ_ooQ`05oookJP03ool0R?oonf[ooo]Z00;oQ03o0_oonfX01?o>
0?oooo]ZoookJ_oonfX2ocP0ojGooo]Z001[oookJP03od;o0?oonf[ooo]Z01Sooo]Z00?oolT0oook
J_oonfX0>_oonfX00ol04?oooo]ZoookJP0eoookJPCo00002ooonfX01?oo]03ooo]Zooo90?oob@0E
oookJPSoiOl01OoonfX2odCo0005ooli0?nbo`3o0?l<o`3o3?oDo`001?l0o``3oiCo00;oA?l01?oo
nfX00ooo08Sooo]ZoookJP02oiCo0003oh@0oonDo`3oU?l000coU?l0oooonfX6oookJP03od;o0?oo
nf[ooo]Z01Sooo]Z00?ofP3ooookJ_oonfX0>_oonfX00ol04?oooo]ZoookJP0eoookJPCo00003?oo
nfX00ooo]03ooo]Zo`3oAP0IoookJP03o`3oAOoonf[ooo]Z00Sooo]Z00koocT0oookJ_nbo`3ooo]Z
ojL0oooDo`3oo`1ooookJ_m^o`3o0?lLof?o0?oo0>7ooo]Zoon700Gooo]Z00Goo`28oookJ_oonf[o
oo]Zoh@0o`02oookJP03olh0oooonf[ooo]Z00;ooo]Z00?o>03ooookJ_oonfX0X_oonfX006[ooo]Z
00?o@_l0oookJ_oonfX06?oonfX00ooob@3ooo]ZoookJP0joookJP03o`0@oooonf[ooo]Z03Kooo]Z
1?l0000;oookJP04oond0?oonf[oolT0ooo901Gooo]Z2OoUo`04oookJP04odCo0?oonf[oocT0oook
JP?o0?l<00Coe?l0o`3o3?m^o`3o0?l<1?nDo`02odCo00Cooo]Z00?oo`28oookJ_oonfX00_nDo`00
0on40?ooU?l0oiCo000<oiCo0?oooo]Z1?oonfX00om2o`3ooo]ZoookJP0HoookJP03omX0oooonf[o
oo]Z03[ooo]Z00?o013ooookJ_oonfX0=_oonfX4o`0000_ooo]Z00Cook@0oookJ_oonf[o0?m66Ooo
nfX00ol0odGooo]ZoookJP08oookJP0?ooli0?oonf[ooo]Zok;o0?oo04CoY`3oomCo0?oo04_oK_l0
o`3o7?l0V?ooHol0ool0hOoonf[oohL000Gooo]Z00Goo`28oookJ_oonf[ooo]Zoh@0o`02oookJP03
olh0oooonf[ooo]Z00;ooo]Z0_lh0?nRoookJP00J_oonfX00om2o`3ooo]ZoookJP0GoookJP03ooo9
0?oonf[ooo]Z03_ooo]Z00?o013ooookJ_oonfX0=_oonfX4o`0000_ooo]Z00?ook@0ooo90?oob@00
0_oob@0DoookJPKoiOl02_oonfX02?oo>@3o/_l0o`3o3?l0o`coe?l0ohSo0?l0o`coK_l01OnDo`02
odCo00Cooo]Z0_oo08P3oiCo0003oh@0oonDo`3ooo]Z00_oU?l0oooonfX4oookJP03od;o0?oonf[o
oo]Z01Oooo]Z00?ofP3ooookJ_oonfX0>ooonfX00ol04?oooo]ZoookJP0foookJPCo00002ooonfX0
0ooo]03ooo]Zo`3oAP0JoookJP03o`3oAOoonf[ooo]Z00Wooo]Z00coocT0oookJ_nbo`3ooo]ZojL0
oooDo`3o05Soo`3aoom^o`3o0?lLo`2HoomSo`02oookJP03oon70?oonf[ooo]Z00?ooo]Z0_oo08P2
oookJP04oh@0oooonf[ooo]Zolh0o`Gooo]Z00?o>03ooookJ_oonfX0WooonfX006Wooo]Z00?o@_l0
oookJ_oonfX06?oonfX00ooJ0?oooo]ZoookJP0joookJP03o`0@oooonf[ooo]Z03Oooo]Z1?l0000;
oookJP03oond0?oob@3oolT000;oolT05?oonfX2onGo0003oookJ_l0odGooo]Z00_ooo]Z00WoocT0
oookJ_l0o`coA?l0ojL0oooDo`3oR?l0o`3o3?m^o`001_nDo`06oookJP04ool0R?nDo`3oU?l0oiCo
00;oQ03o00?ooo]ZoiCo0?nDo`001onDo`3ooookJPCooo]Z00?o@_l0oookJ_oonfX06?oonfX00ooJ
0?oooo]ZoookJP0joookJP03o`0@oooonf[ooo]Z03Oooo]Z1?l0000;oookJP03oond0?oonf[o0?m6
01[ooo]Z00?o0?m5oookJ_oonfX02OoonfX03Ooo>@3ooo]ZoookJ_nbo`3oo`14ojL0oooDo`3ooh00
ofko0?l0ofGo0?lLoookJ_mSo`000_oonfX00oooQ`3ooo]ZoookJP04oookJP03ool0R?oonf[ooo]Z
00;oQ03o00?ooo]Zolh0oooonfX01?oonfX2ocP0oioooo]Z001XoookJP03od;o0?oonf[ooo]Z01So
oo]Z00?ofP3ooookJ_oonfX0>ooonfX00ol04?oooo]ZoookJP0KoookJPGo001o1?oonfX3o`00O`?o
oo]Z1Ol007l8oookJPCo00002_oonfX00ooo]03ooo]Zooo90003ooo901Sooo]Z00?o0?m5oookJ_oo
nfX02_oonfX02?oo>@3o/_l0odCo0?l0o`coY`3oomCo0?l0o`coK_l01onDo`06oookJP03ool0R?nD
o`3ooo]Z00;ooo]Z00?oQ03ooookJ_nDo`001OnDo`02ocP0o`03ool0U_oonf[ooo]Z0?oooo]Z00?o
@_l0oookJ_oonfX06?oonfX00ooJ0?oooo]ZoookJP0koookJP03o`0@oooonf[ooo]Z01_ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00O`Sooo]Z1?l0000;oookJP03oond0?oonf[o0?m601[ooo]Z00?o
0?m5oookJ_oonfX02_oonfX03ooo>@3ooo]Zok;o0?oonf[oo`14omCo0?l0F?ooo`1;ofko0?l0oaco
09Soof?o0?oo0>7ooo]Zoon70007oookJP06ool0R?oonf[ooo]ZoookJ_n40?oooo]Z0_o>0?l5oook
JP03ocP0oooo09Koo`2F09cooo]Z001WoookJP03od;o0?oonf[ooo]Z01Sooo]Z00?ofP3ooookJ_oo
nfX0>ooonfX00ol04?oooo]ZoookJP0KoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPCo
00002_oonfX00ooo]03oolT0ooo90003ooo901Sooo]Z00?o0?m5oookJ_oonfX02_oonfX02Ooo>@3o
oo]Zok;o0?m4o`3oY`3oomCo0?n8o`3o0?l<ofko0007oiCo00Kooo]Z00?oo`28oookJ_oonfX00_oo
nfX00on40?oooo]ZoiCo0005oiCo0004oookJ_lh0?ooo`2Fool0U_kooo]Z00?o@_l0oookJ_oonfX0
6?oonfX00ooJ0?oooo]ZoookJP0koookJP03o`0@oooonf[ooo]Z01_ooo]Z1ol007l3oookJP?o001o
0_oonfX7o`00O`Oooo]Z1?l0000;oookJP03oond0?oonf[o0?m601_ooo]Z00?o0?m5oookJ_oonfX0
2OoonfX04?oo>@3ooo]ZoookJ_nbo`3oo`14ojL0oooDo`3ooh00ofko0?l0O?oo0?lLo`2HoomSo`3o
o`3QoookJ_ooQ`07oookJP04ool0R?oonf[ooo]ZoookJP;oQ03o00?ooo]Zolh0oooonfX01?oonfX2
ocP0o`;oo`2FV_oonfX006Kooo]Z00?o@_l0oookJ_oonfX06?oonfX00ooJ0?oooo]ZoookJP0koook
JP03o`0@oooonf[ooo]Z01cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Z
o`00Ool007l00_l007l01?oonf[o001oo`00Ool007l7oookJPCo00002_oonfX00ooo]03oolT0ooo9
0003ooo901Sooo]Z00?o0?m5oookJ_oonfX02ooonfX01_oo>@3o/_l0odCo0?l0o`coY`3oomCo00;o
0?l<00?oK_l0oiCo0?nDo`001OnDo`06oookJP;oo`280ooonfX00on40?oooo]ZoiCo0003oiCo00?o
oo]Z0_lh0?l2ool0U__ooo]Z00?o@_l0oookJ_oonfX06?oonfX00ooJ0?oooo]ZoookJP0koookJP03
o`0@oooonf[ooo]Z01cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00
Ool007l00_l007l01?oonf[o001oo`00Ool007l7oookJPCo00002ooonfX00ooo]03ooo]Zo`3oAP0K
oookJP03o`3oAOoonf[ooo]Z00[ooo]Z013oocT0oookJ_nbo`3ooo]Zool0A?oDo`3o05Sooon00?m^
o`3o0?mUo`3o7?oonf[oHol0ool0hOoonf[oohL01ooonfX00ooo08Sooo]ZoookJP02oookJP04oh@0
oooonf[ocP3oolh0o`Gooo]Z00Co>03ooookJ_oo09Koo`2FV?oonfX006Kooo]Z00?o@_l0oookJ_oo
nfX06?oonfX00ooJ0?oooo]ZoookJP0koookJP03o`0@oooonf[ooo]Z01_ooo]Z0ol007l3oookJP?o
001o1_oonfX3o`00O`?ooo]Z0ol007l6oookJPCo00002_oonfX00ooo]03oolT0ooo90003ooo901Wo
oo]Z00?o0?m5oookJ_oonfX02_oonfX00ooo>@3oA?l0ok;o0002o`3o3004ojL0oooDo`3o0?l<ofko
00SoU?l01ooonfX01?oo08Sooo]ZoookJ_oonfX2oh@0o`;oU?l000?ocP3ooookJ_oonfX00ooonfX2
ocP0o`;oo`2FnOoonfX00om2o`3ooo]ZoookJP0HoookJP03omX0oooonf[ooo]Z03_ooo]Z00?o013o
oookJ_oonfX06ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0000;
oookJP03oond0?oonf[o0?m601_ooo]Z00?o0?m5oookJ_oonfX02_oonfX03_oo>@3ooo]ZoookJ_nb
o`3oo`14ojL0oooDo`3ooh00ofko0?oonf[o0?mUo`3o7?mSo`3oo`3Q0_oonfX00oooQ`3ooo]Zoook
JP05oookJP03ool0R?oonf[ooo]Z00;ooo]Z0_n40?l00ooonf[ocP3ooookJP04oookJP;o>03o00?o
oo]Zool0U_oo09H0U_oonfX006Gooo]Z00?o@_l0oookJ_oonfX06?oonfX00ooJ0?oooo]ZoookJP0k
oookJP03o`0@oooonf[ooo]Z01cooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z1_l00008
oookJP03oond0?oob@3oolT000?oolT06OoonfX00ol0odGooo]ZoookJP0:oookJP0:ooli0?oonf[o
/_l0odCo0?l0o`coY`3oomCo0?n8o`3ooh00ofko00SoU?l01ooonfX00ooo08Sooo]ZoookJP02oook
JP03oh@0oooonf[ooo]Z00;ocP3o1OoonfX3ocP0ooOooo]Z00?o@_l0oookJ_oonfX06?oonfX00ooJ
0?oooo]ZoookJP0koookJP03o`0@oooonf[ooo]Z01cooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`Kooo]Z1_l00009oookJP03oond0?oonf[o0?m601_ooo]Z00?o0?m5oookJ_oonfX02_oonfX03ooo
>@3ooo]ZoookJ_nbo`3ooo]Zool0A?oDo`3oR?l0oon00?m^o`3o07coo`3oIOl0oacoHol0ool0h@02
oookJP03oon70?oonf[ooo]Z00Gooo]Z00?oo`28oookJ_oonfX00ooonfX01?n40?oooo]Zolh0ooo>
0?l5oookJP?o>03o00?oo`2FoookJ_oonfX0TooonfX006Cooo]Z00?o@_l0oookJ_oonfX06?oonfX0
0ooJ0?oooo]ZoookJP0loookJP03o`0@oooonf[ooo]Z01cooo]Z0ol007l3oookJP?o001o3?oonfX3
o`00O`Kooo]Z1?l0000:oookJP03oond0?oob@3oolT000CoolT06?oonfX00ol0odGooo]ZoookJP0;
oookJP0:onGo0?m4o`3o/_l0o`3o3?oo04CoY`3oomCo0?l0o`coU?l0ofko00GoU?l000?ooo]Zoon7
0?oonfX01ooonfX00ooo08Sooo]ZoookJP02oookJP05oh@0oooonf[ooo]ZoookJ_o>0?l01ooonfX2
ocP0ooCooo]Z00?o@_l0oookJ_oonfX06?oonfX00ooJ0?oooo]ZoookJP0loookJP03o`0@oooonf[o
oo]Z01cooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z1?l0000:oookJP04oond0?oonf[o
oo]Zo`3oAQ_ooo]Z00?o0?m5oookJ_oonfX02ooonfX03ooo>@3ooo]ZoookJ_nbo`3ooo]ZojL0oooD
o`3oo`1ooon00?m^o`3o0?mUo`3o7?oonf[oHol0ool0h@02oookJP03oon70?oonf[ooo]Z00Gooo]Z
00?oo`28oookJ_oonfX00ooonfX00on40?oooo]ZoookJP02olh0o`Kooo]Z0_lh0?l00ooo09Kooo]Z
oookJP2AoookJP00HooonfX00om2o`3ooo]ZoookJP0HoookJP03omX0oooonf[ooo]Z03cooo]Z00?o
013ooookJ_oonfX07OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Kooo]Z1?l0
000:oookJP03oond0?oob@3oolT000CoolT06?oonfX00ol0odGooo]ZoookJP0;oookJP04onGo0?oo
nf[o/_l0oookJP;o0?l<00Coe?l0ohSo0?l0o`coK_l01?nDo`001?m4o`3ooo]ZoookJ_ooQ`08oook
JP03ool0R?oonf[ooo]Z00;ooo]Z00CoQ03ooookJ_oonf[ooo]Z0_o>0?l7oookJP;o>03olOoonfX0
0om2o`3ooo]ZoookJP0HoookJP03omX0oooonf[ooo]Z03cooo]Z00?o013ooookJ_oonfX07OoonfX3
o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Kooo]Z1?l0000:oookJP04oond0?oonf[o
oo]Zo`3oAQ_ooo]Z00?o0?m5oookJ_oonfX02ooonfX03ooo>@3ooo]ZoookJ_nbo`3ooo]Zool0A?nW
0?ooe?l0oon00?m^o`3ooo]Zo`3oIOl0oacoHol0ool0h@03oookJP03oon70?oonf[ooo]Z00Gooo]Z
00?oo`28oookJ_oonfX00ooonfX01On40?oooo]ZoookJ_oonf[ocP3o00Oooo]Z0_lh0?l00ooo09Ko
oo]ZoookJP2?oookJP00H_oonfX00om2o`3ooo]ZoookJP0IoookJP03omX0oooonf[ooo]Z03cooo]Z
00?o013ooookJ_oonfX07OoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX4o`0000Wooo]Z
00?ook@0ooo90?oob@001Ooob@0IoookJP03o`3oAOoonf[ooo]Z00[ooo]Z0_oUo`002Ooonf[o/_l0
oookJ_l0o`coA?l0omCo0?n8o`3o0?l<ofko0002oiCo0003of?o0?m4o`3oA?l000;ooo]Z00?oohL0
oookJ_oonfX01_oonfX2oiCo00?ooo]Z00?oQ03ooookJ_oonfX00_oonfX00oo>0?oooo]ZoookJP06
oookJP;o>03o00?oo`2FoookJ_oonfX0jooonfX00om2o`3ooo]ZoookJP0IoookJP03omX0oooonf[o
oo]Z03cooo]Z00?o013ooookJ_oonfX07OoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX4
o`0000[ooo]Z00Cook@0oookJ_oonf[o0?m67?oonfX00ol0odGooo]ZoookJP0;oookJP0?ooli0?oo
nf[ooo]Zok;o0?oonf[oY`3oomCo0?n8o`3ooh00ofko0?l0O?oo0?mUo`3o7?mSo`3oo`3Q00?ooo]Z
00?oohL0oookJ_oonfX01OoonfX2ool0R0Cooo]Z00CoQ03ooookJ_oonf[ooo]Z0_o>0?l7oookJP;o
>03o0_oo09J>oookJP00H_oonfX00om2o`3ooo]ZoookJP0HoookJP03omX0oooonf[ooo]Z03cooo]Z
00?o013ooookJ_oonfX07_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX4o`0000Wooo]Z
00Gook@0oookJ_oonf[o0?m6oookJP03ooo901Wooo]Z00?o0?m5oookJ_oonfX02_oonfX3onGo0006
ok;o0?oonf[o0?l<odCo0?oDo`3oR?l00_l0o``01?m^o`3o0?lLo`2HoomSo`02odCo00;ooo]Z00?o
ohL0oookJ_oonfX01OoonfX4oiCo00;ooo]Z0_n40?l3oookJP;ocP3o2?oonfX01?lh0?ooo`2Fool0
U_oo09KZoookJP03od;o0?oonf[ooo]Z01Sooo]Z00?ofP3ooookJ_oonfX0??oonfX00ol04?oooo]Z
oookJP0NoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPCo00002_oonfX00ooo]03ooo]Z
o`3oAP0MoookJP03o`3oAOoonf[ooo]Z00_ooo]Z013oocT0oookJ_oonf[o/_l0oookJ_oo^03oY`3o
omCo0?oo07oooh00ofko0?l0ofGo0?lLoookJ_mSo`3oo`3Q0ooonfX00oooQ`3ooo]ZoookJP06oook
JP03ool0R?oonf[ooo]Z00;ooo]Z0_n40?l3oookJP;ocP3o1ooonfX2ocP0o`?oo`2FRooonfX0067o
oo]Z00?o@_l0oookJ_oonfX06?oonfX00ooJ0?oooo]ZoookJP0loookJP03o`0@oooonf[ooo]Z01oo
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1?l00009oookJP04oond0?oonf[ooo]Zo`3o
AQgooo]Z00?o0?m5oookJ_oonfX02_oonfX4onGo0003ok;o0?oonf[oiOl000;oA?l000OoR?l0o`3o
3?m^o`3o0?l<o`3o7?l0V?ooHol000;oA?l00_oonfX2oiCo00Kooo]Z1OnDo`02oookJP;oQ03o0ooo
nfX2olh0o`Oooo]Z0_lh0?l01?oonf[oo`2Fool0U_oo09KVoookJP03od;o0?oonf[ooo]Z01Sooo]Z
00?ofP3ooookJ_oonfX0??oonfX00ol04?oooo]ZoookJP0OoookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007l<oookJPCo00002_oonfX00ooo]03ooo]Zo`3oAP0MoookJP03o`3oAOoonf[ooo]Z00cooo]Z
00ooocT0oookJ_oonf[o/_l0oookJ_nW0?ooo`16omCo0?ooP03oK_l0oookJ_l0ofGo0?lLof?o0?oo
0>401?oonfX00oooQ`3ooo]ZoookJP06oookJP03ool0R?oonf[ooo]Z00?ooo]Z00?oQ03ooookJ_oo
nfX00_oonfX2olh0o`Oooo]Z0_lh0?l00ooonf[oo`2Fool0UP29oookJP00H?oonfX00om2o`3ooo]Z
oookJP0HoookJP03omX0oooonf[ooo]Z03gooo]Z00?o013ooookJ_oonfX08?oonfX3o`00O`04oook
J_l007oo001oo`00O`Sooo]Z0_l007l<oookJPCo00002OoonfX01?oo]03ooo]ZoookJ_l0odHMoook
JP03o`3oAOoonf[ooo]Z00_ooo]Z0ooUo`000ooonf[o/_l0o`3o3003odCo0007ohSo0?l0o`coK_l0
o`3o3?l0oaco09Soof?o0002odCo0004oookJ_nDo`3oU?l0oiCo00Kooo]Z1_nDo`02oookJP03oh@0
oooonf[ooo]Z00;ooo]Z00?ocP3ooookJ_oonfX01_oonfX2ocP0o`;ooo]Z0ooo09KRoookJP03od;o
0?oonf[ooo]Z01Sooo]Z00?ofP3ooookJ_oonfX0?OoonfX00ol04?oooo]ZoookJP0PoookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1?l00009oookJP04oond0?oonf[ooo]Zo`3o
AQgooo]Z00?o0?m5oookJ_oonfX03?oonfX01?oo>@3ooo]ZoookJ_nbo`02oookJP0:ojL0oooDo`3o
R?l0oon00?m^o`3o07coo`3oIOl0oacoHol0ool0h@?ooo]Z00?oohL0oookJ_oonfX01ooonfX00ooo
08Sooo]ZoookJP03oookJP;oQ03o1?oonfX00oo>0?oooo]ZoookJP06oookJP;o>03o00Cooo]Zool0
U_oo09Koo`2FQ_oonfX005oooo]Z00?o@_l0oookJ_oonfX06?oonfX00ooJ0?oooo]ZoookJP0moook
JP03o`0@oooonf[ooo]Z027ooo]Z1ol007l9oookJPOo001o1_oonfX4o`0000Wooo]Z00Cook@0oook
J_oonf[o0?m67_oonfX00ol0odGooo]ZoookJP0:oookJPCoiOl000?o/_l0oookJ_m4o`000om4o`02
o`3o3006ofko0?l0oaco09SoodCo0?mSo`3oo`3Q0_oonfX4oiCo00Cooo]Z2?nDo`000ooonf[oQ03o
oh@0o`03oookJP;ocP3o2?oonfX3ocP0o`;ooo]Z0ooo09KNoookJP03od;o0?oonf[ooo]Z01Sooo]Z
00?ofP3ooookJ_oonfX0?OoonfX00ol04?oooo]ZoookJP0QoookJPOo001o2OoonfX7o`00O`Kooo]Z
1?l00009oookJP04oond0?oonf[ooo]Zo`3oAQkooo]Z00?o0?m5oookJ_oonfX03?oonfX00ooo>@3o
oo]Zok;o0002oookJP0;ool0A?nW0?ooe?l0on`0ooooP03oK_l0o`3oIOl0oacooo]Zof?o0?oo0>40
0ooonfX00oooQ`3ooo]ZoookJP07oookJP03ool0R?oonf[ooo]Z00Cooo]Z00?oQ03ooookJ_oonfX0
0_oonfX2olh0o`Sooo]Z0olh0?l01?oonf[oo`2Fool0U_oo09J3oookJP00G_oonfX00om2o`3ooo]Z
oookJP0IoookJP03omX0oooonf[ooo]Z03gooo]Z00?o013ooookJ_oonfX08_oonfX5o`00O`[ooo]Z
1ol007l6oookJPCo00002OoonfX01?oo]03ooo]ZoookJ_l0odHNoookJP03o`3oAOoonf[ooo]Z00[o
oo]Z1OoUo`000onbo`3oA?l0odCo0003odCo0007o`3o3?m^o`3o0?l<o`3o7?l0V?ooHol0ool0h@02
oookJPGoU?l01?oonfX9oiCo0003oookJ_n40?ooQ03o00?ooo]Z0_o>0?l9oookJP?o>03o0_oonfX3
ool0UUgooo]Z0ooo09IkoookJP03od;o0?oonf[ooo]Z01Sooo]Z00?ofP3ooookJ_oonfX0?OoonfX0
0ol04?oooo]ZoookJP0RoookJPGo001o2_oonfX7o`00O`Kooo]Z1?l00009oookJP04oond0?oonf[o
oo]Zo`3oAQkooo]Z00?o0?m5oookJ_oonfX03?oonfX01?oo>@3ooo]ZoookJ_nbo`02oookJP0;ojL0
oooDo`3oR?l0oon00?m^o`3ooo]Zo`3oIOl0oacoHol0oookJ_oo0>400ooonfX00oooQ`3ooo]Zoook
JP07oookJP;oo`281OoonfX2oh@0o`Cooo]Z0_o>0?l9oookJP?o>03o00Cooo]Zool0U_oo09Koo`2F
G_oonfX3ool0UQoooo]Z001NoookJP03od;o0?oonf[ooo]Z01Sooo]Z00?ofP3ooookJ_oonfX0?Ooo
nfX00ol04?oooo]ZoookJP0ooookJPCo00002OoonfX01?oo]03ooo]ZoookJ_l0odHNoookJP03o`3o
AOoonf[ooo]Z00[ooo]Z1_oUo`000ol0o`coA?l0odCo0003odCo0007o`3o3?m^o`3o0?l<o`3o7?l0
V?ooHol0ool0h@02oookJPKoU?l00ooonfX:oiCo0003oookJ_n40?ooQ03o00?ooo]Z0_o>0?l:oook
JP?o>03o0_oonfX3ool0UUGooo]Z1Ooo09ImoookJP03od;o0?oonf[ooo]Z01Sooo]Z00?ofP3ooook
J_oonfX0?OoonfX00ol04?oooo]ZoookJP0ooookJPCo00002OoonfX01?oo]03ooo]ZoookJ_l0odHN
oookJP03o`3oAOoonf[ooo]Z00gooo]Z00?oocT0oookJ_nbo`000_oonfX03?oo04CoY`3oomCo0?n8
o`3ooh00ofko0?l0O?oo0?mUo`3o7?mSo`3ooo]Zool0h@?ooo]Z00?oohL0oookJ_oonfX02?oonfX0
0ooo08Sooo]ZoookJP04oookJP;oQ03o1?oonfX2olh0o`[ooo]Z0olh0?l01?oonf[oo`2Fool0U_oo
09IFoookJPGoo`2F8_oonfX005gooo]Z00?o@_l0oookJ_oonfX06?oonfX00ooJ0?oooo]ZoookJP0m
oookJP03o`0@oooonf[ooo]Z043ooo]Z1?l00009oookJP04oond0?oonf[ooo]Zo`3oAQkooo]Z00?o
0?m5oookJ_oonfX02_oonfX6onGo0003ok;o0?m4o`3oA?l000CoA?l000OoiOl0ofko0?l0ofGo0?lL
oookJ_mSo`3oo`3Q00;ooo]Z1_nDo`03oookJP[oU?l00_oonfX00on40?oooo]ZoookJP02oookJP;o
cP3o2ooonfX3ocP0o`;ooo]Z0ooo09I<oookJPKoo`2F1OoonfX3ocP0ogWooo]Z00?o@_l0oookJ_oo
nfX06?oonfX00ooJ0?oooo]ZoookJP0moookJP03o`0@oooonf[ooo]Z043ooo]Z1?l00009oookJP04
oond0?oonf[ooo]Zo`3oAQkooo]Z00?o0?m5oookJ_oonfX03OoonfX01?oo>@3ooo]ZoookJ_nbo`02
oookJP0<ojL0oooDo`3oR?l0ool0moooP03oK_l0o`3oIOl0oaco09Soof?o0?oonf[oo`3Q0ooonfX0
0oooQ`3ooo]ZoookJP08oookJP03ool0R?oonf[ooo]Z00Gooo]Z00?oQ03ooookJ_oonfX00ooonfX2
olh0o`_ooo]Z0olh0?l01?oonf[oo`2Fool0U_oo09I=oookJPKoo`2F1OoonfX3ocP0oaoooo]Z001L
oookJP03od;o0?oonf[ooo]Z01Sooo]Z00?ofP3ooookJ_oonfX0?_oonfX00ol04?oooo]ZoookJP10
oookJPGo00002?oonfX01?oo]03ooo]ZoookJ_l0odHNoookJP03o`3oAOoonf[ooo]Z00[ooo]Z1ooU
o`07odCo0006ofko0?l0o`co0?mUo`3o7?mSo`3oo`3Q0_oonfX7oiCo00;ooo]Z2_nDo`03oookJP;o
Q03o1?oonfX2olh0o`cooo]Z0olh0?l2oookJPCoo`2F4OoonfX5onGo02cooo]Z1_oo09H7oookJPCo
>03oNooonfX00om2o`3ooo]ZoookJP0HoookJP03omX0oooonf[ooo]Z03kooo]Z00?o013ooookJ_oo
nfX0@?oonfX5o`0000Sooo]Z00Cook@0oookJ_oonf[o0?m67_oonfX00ol0odGooo]ZoookJP0=oook
JP04ooli0?oonf[ooo]Zok;o00;ooo]Z00coo`14omCo0?oo07ooR?l0oon00?m^o`3ooo]Zo`3oIOl0
oaco09Soof?o0?oo0>44oookJP03oon70?oonf[ooo]Z00Sooo]Z00?oo`28oookJ_oonfX01OoonfX2
oh@0o`Gooo]Z0_o>0?l<oookJP?o>03o00?ooo]Zool0U_oo09H00_oo09I3oookJPKoo`2F1_oonfX5
ocP0ob;ooo]Z001KoookJP03od;o0?oonf[ooo]Z01Wooo]Z00?ofP3ooookJ_oonfX0?OoonfX00ol0
4?oooo]ZoookJP11oookJPCo00002?oonfX01?oo]03ooo]ZoookJ_l0odHOoookJP03o`3oAOoonf[o
oo]Z00[ooo]Z2?oUo`07odCo0006ofko0?l0o`co0?mUo`3o7?mSo`3oo`3Q0_oonfX8oiCo0003oook
J_nDo`3oU?l000KoU?l01_oonfX3onGo00?ooo]Z0oo>0?l<oookJPGo>03o00?ooo]Zool0U_oo09H0
0ooo09H5oookJPcoiOl09ooonfX5ool0UPWooo]Z1?lh0?mooookJP03od;o0?oonf[ooo]Z01Sooo]Z
00?ofP3ooookJ_oonfX0?OoonfX00ol04?oooo]ZoookJP11oookJPCo00002?oonfX01?oo]03ooo]Z
oookJ_l0odHOoookJP03o`3oAOoonf[ooo]Z00kooo]Z00CoocT0oookJ_oonf[o/_l00_oonfX03?oo
04Coe?l0ohSo0?o/0?oooh00ofko0?l0O?oo0?mUo`3o7?l0V?ooHol0ool0h@?ooo]Z00?oohL0oook
J_oonfX02OoonfX00ooo08Sooo]ZoookJP06oookJP;oQ03o1OoonfX2olh0o`gooo]Z1?lh0?l00ooo
nf[oo`2Fool0UP03ool0USWooo]Z1Ooo09H8oookJPCo>03o9ooonfX005[ooo]Z00?o@_l0oookJ_oo
nfX06OoonfX00ooJ0?oooo]ZoookJP0noookJP03o`0@oooonf[ooo]Z047ooo]Z1?l00008oookJP04
oond0?oonf[ooo]Zo`3oAR3ooo]Z00?o0?m5oookJ_oonfX02_oonfX7onGo00SoA?l000OoK_l0o`3o
IOl0oacooo]Zof?o0?oo0>7ooo]Z00WoU?l000?ooo]ZoiCo0?nDo`001?nDo`000ooo08Sooo]Zoook
JP05oookJPKoiOl00_oonfX3olh0o`kooo]Z1Olh0?l00ooonf[oo`2FonGo000?onGo01gooo]Z2_oo
09H9oookJPGo>03oP_oonfX00om2o`3ooo]ZoookJP0HoookJP03omX0oooonf[ooo]Z03kooo]Z00?o
013ooookJ_oonfX0@OoonfX4o`0000Sooo]Z00Cook@0oookJ_oonf[o0?m68?oonfX00ol0odGooo]Z
oookJP0=oookJP0Cooli0?oonf[ooo]ZoookJ_nbo`3ooo]Zool0A?oDo`3oo`1oohSo0?ooP03ooo]Z
ofko0?l0ofGo0?lLo`2Hoooonf[oHol0ool0h@03oookJP03oon70?oonf[ooo]Z00Wooo]Z0_oo08P8
oookJP03oh@0oooonf[ooo]Z00Cooo]Z0oo>0?l>oookJPGo>03o00?ooo]Zool0U_oo09H01_oo09HW
oookJP[oo`2F2?oonfX5ocP0ob_ooo]Z001JoookJP03od;o0?oonf[ooo]Z01Sooo]Z00?ofP3ooook
J_oonfX0?_oonfX00ol04?oooo]ZoookJP12oookJPCo00002?oonfX01?oo]03ooo]ZoookJ_l0odHP
oookJP03o`3oAOoonf[ooo]Z00[ooo]Z1_oUo`000onbo`3oA?l0odCo0007odCo0007oookJ_l0ofGo
0?lLof?o0?oonf[oo`3QoookJP0>oiCo00;ooo]Z00?oo`28oookJ_oonfX01OoonfX8onGo00;ooo]Z
0oo>0?l@oookJP03ocP0oooUo`3oiOl000ooiOl00ooo09H<oookJPkoo`2F3OoonfX6ocP0ohKooo]Z
00?o@_l0oookJ_oonfX06?oonfX00ooJ0?oooo]ZoookJP0noookJP03o`0@oooonf[ooo]Z04;ooo]Z
1?l00008oookJP04oond0?oonf[ooo]Zo`3oAR3ooo]Z00?o0?m5oookJ_oonfX03OoonfX01Ooo>@3o
oo]ZoookJ_oonf[o/_l000;ooo]Z00goo`14omCo0?l0F?ooR?l0oon00?oonf[oK_l0o`3oIOl0oaco
09Soof?o0?oonf[oo`3Q00?ooo]Z00?oohL0oookJ_oonfX02_oonfX00ooo08Sooo]ZoookJP06oook
JP;oQ03o1ooonfX3olh0oa3ooo]Z1Olh0?l4oookJPcoo`2F3?oonfX?ool0UPgooo]Z1Olh0?l`oook
JP00FOoonfX00om2o`3ooo]ZoookJP0HoookJP03omX0oooonf[ooo]Z03kooo]Z00?o013ooookJ_oo
nfX0@ooonfX4o`0000Sooo]Z00Cook@0oookJ_oonf[o0?m68?oonfX00ol0odGooo]ZoookJP0:oook
JP?oiOl000Cooo]Zooli0?oonf[ooo]Z2_m4o`001_l0ofGooo]Zo`3o7?mSo`3ooo]Zool0h@SoU?l0
0_oonfX3oiCo00Cooo]Z0_oo08P6oookJP_oiOl000?ooo]ZonGo0?oUo`000ooUo`0>oookJPkoiOl0
1?oonfX<ool0UQKooo]Z1Olh0?n;oookJP03od;o0?oonf[ooo]Z01Sooo]Z00?ofP3ooookJ_oonfX0
?_oonfX00ol04?oooo]ZoookJP13oookJPCo00002?oonfX01?oo]03ooo]ZoookJ_l0odHPoookJP03
o`3oAOoonf[ooo]Z00kooo]Z00GoocT0oookJ_oonf[ooo]Zok;o0002oookJP0=omCo0?nW0?ooR?l0
ool0BoooP03ooo]Zofko0?l0ofGo0?lLoookJ_mSo`3ooo]Zool0h@03oookJP03oon70?oonf[ooo]Z
00[ooo]Z0_oo08P8oookJP;oQ03o2?oonfX2olh0oa?ooo]Z1Olh0?l;oookJPcoo`2F5ooonfX5ocP0
ocGooo]Z001HoookJP03od;o0?oonf[ooo]Z01Wooo]Z00?ofP3ooookJ_oonfX0?_oonfX00ol04?oo
oo]ZoookJP13oookJPCo00002?oonfX01?oo]03ooo]ZoookJ_l0odHPoookJP03o`3oAOoonf[ooo]Z
00[ooo]Z00GoiOl0oookJ_oonf[ooo]Zooli0002oookJP03ok;o0?m4o`3oA?l000WoA?l000Gooo]Z
o`3o7?mSo`3ooo]Zool0h@06oiCo00Cooo]Z00?oU?l0oookJ_oonfX01OoonfX00ooo08Sooo]Zoook
JP04oookJPcoiOl000?ooo]ZonGo0?oUo`002?oUo`0:oookJP_oiOl03olh0?l=oookJP[o>03oSooo
nfX00om2o`3ooo]ZoookJP0IoookJP03omX0oooonf[ooo]Z03kooo]Z00?o013ooookJ_oonfX0@ooo
nfX4o`0000Sooo]Z00Cook@0oookJ_oonf[o0?m68?oonfX00ol0odGooo]ZoookJP0>oookJP05ooli
0?oonf[ooo]ZoookJ_nbo`000_oonfX01Ooo04Coe?l0o`1Hoon8o`3ooh0000;ooo]Z00OoK_l0o`3o
IOl0oacooo]Zof?o0?oonf[oo`3Q00?ooo]Z00?oohL0oookJ_oonfX02ooonfX00ooo08Sooo]Zoook
JP07oookJP03oh@0oooonf[ooo]Z00Oooo]Z0_o>0?lFoookJQKo>03o3_oonfX:ocP0oc[ooo]Z001G
oookJP03od;o0?oonf[ooo]Z01Wooo]Z00?ofP3ooookJ_oonfX0?_oonfX00ol04?oooo]ZoookJP14
oookJPCo00001ooonfX01?oo]03ooo]ZoookJ_l0odHQoookJP03o`3oAOoonf[ooo]Z00oooo]Z00?o
ocT0oookJ_oonfX03?m4o`001Ol0oacooo]Zof?o0?oo0>7ooo]Z00CoU?l000?oohL0oookJ_oonfX0
2ooonfX00ooo08Sooo]ZoookJP04oookJP_oiOl00_oonfX=onGo00Sooo]Z2OoUo`0?oookJPgo>03o
VOoonfX00om2o`3ooo]ZoookJP0HoookJP03omX0oooonf[ooo]Z03kooo]Z00?o013ooookJ_oonfX0
A?oonfX4o`0000Oooo]Z00Cook@0oookJ_oonf[o0?m68OoonfX00ol0odGooo]ZoookJP0?oookJP05
ooli0?oonf[ooo]ZoookJ_nbo`000_oonfX03Ooo04Coe?l0ohSo0?oo>@3ooh00oookJ_m^o`3o0?mU
o`3o7?l0V?oooo]Zof?o0?oo0>401?oonfX00oooQ`3ooo]ZoookJP0;oookJP03ool0R?oonf[ooo]Z
00Oooo]Z0_n40?l9oookJP?ocP3o:OoonfX>ocP0odCooo]Z001FoookJP03od;o0?oonf[ooo]Z01Wo
oo]Z00?ofP3ooookJ_oonfX0?ooonfX00ol04?oooo]ZoookJP14oookJPCo00001ooonfX01?oo]03o
oo]ZoookJ_l0odHQoookJP03o`3oAOoonf[ooo]Z00oooo]Z00CoocT0oookJ_oonf[o/_l01_m4o`00
0on8o`3oA?l0odCo0003odCo0004o`3o7?oonf[oHol0ool0h@?oU?l00_oonfX00oooQ`3ooo]Zoook
JP0;oookJP;oo`281OoonfX9onGo00Cooo]Z3?oUo`0:oookJPOoiOl0]?oonfX00om2o`3ooo]Zoook
JP0HoookJP03omX0oooonf[ooo]Z03oooo]Z00?o013ooookJ_oonfX0A?oonfX4o`0000Oooo]Z00Co
ok@0oookJ_oonf[o0?m68OoonfX00ol0odGooo]ZoookJP0?oookJP05ooli0?oonf[ooo]ZoookJ_nb
o`000_oonfX02_oo04Coe?l0ool0Oon8o`3ooh00o`3aoooonf[oK_l0o`3oIOl0oa`2oookJP03of?o
0?oo0>7ooo]Z00?ooo]Z00?oohL0oookJ_oonfX02ooonfX2ool0R0Wooo]Z0_n40?l:oookJP;ocP3o
NOoonfX005Kooo]Z00?o@_l0oookJ_oonfX06?oonfX00ooJ0?oooo]ZoookJP0ooookJP03o`0@oooo
nf[ooo]Z04Gooo]Z1?l00007oookJP04oond0?oonf[ooo]Zo`3oAR7ooo]Z00?o0?m5oookJ_oonfX0
3ooonfX01Ooo>@3ooo]ZoookJ_oonf[o/_l000?oA?l000?oY`3oomCo0?n8o`001_m4o`02oiCo0003
of?o0?oo0>7oU?l000Cooo]Z00?oohL0oookJ_oonfX03?oonfX00ooo08Sooo]ZoookJP03oookJPSo
iOl01_oonfX9onGo00kooo]Z0ooUo`2doookJP03od;o0?oonf[ooo]Z01Sooo]Z00?ofP3ooookJ_oo
nfX0?ooonfX00ol04?oooo]ZoookJP15oookJPCo00001ooonfX01?oo]03ooo]ZoookJ_l0odHRoook
JP03o`3oAOoonf[ooo]Z00kooo]Z00?oocT0oookJ_oonfX00_oonfX03Onbo`3ooo]ZoookJ_oo04Co
e?l0ohSo0?o/0?oooh00oookJ_m^o`3o07coo`3oIOl0oa`00_oonfX00omSo`3oo`3QoookJP03oook
JP03oon70?oonf[ooo]Z00cooo]Z00?oo`28oookJ_oonfX02?oonfX2oh@0o`[ooo]Z1?o>0?meoook
JP00EOoonfX00om2o`3ooo]ZoookJP0IoookJP03omX0oooonf[ooo]Z03oooo]Z00?o013ooookJ_oo
nfX0AOoonfX4o`0000Oooo]Z00Cook@0oookJ_oonf[o0?m68OoonfX00ol0odGooo]ZoookJP0@oook
JP04ooli0?oonf[ooo]ZoookJP?oA?l000CoY`3oomCo0?m4o`3oR?l01_m4o`001?nDo`3oHol0oook
J_oo0>45oookJP03oon70?oonf[ooo]Z00cooo]Z0_oo08P4oookJPKoiOl00_n40?l6oookJPSoiOl0
0oo>0?l=oookJP03onGo0?oonf[ooo]Z0;7ooo]Z00?o@_l0oookJ_oonfX06OoonfX00ooJ0?oooo]Z
oookJP0ooookJP03o`0@oooonf[ooo]Z04Gooo]Z1?l00007oookJP04oond0?oonf[ooo]Zo`3oAR;o
oo]Z00?o0?m5oookJ_oonfX03ooonfX01Ooo>@3ooo]ZoookJ_oonf[o/_l000;ooo]Z00[oo`14omCo
0?oohP3oR?l0oon00?l0lOoooo]Zofko0?l0ofGo0?lL0_oonfX00omSo`3ooo]Zool0h@04oookJP03
oon70?oonf[ooo]Z00cooo]Z0_oo08P:oookJP;oQ03o3?oonfX5olh0og3ooo]Z001DoookJP03od;o
0?oonf[ooo]Z01Wooo]Z00?ofP3ooookJ_oonfX0?ooonfX00ol04?oooo]ZoookJP16oookJPCo0000
1ooonfX01?oo]03ooo]ZoookJ_l0odHQoookJP03o`3oAOoonf[ooo]Z013ooo]Z00KoocT0oookJ_oo
nf[ooo]Zok;o0?oonfX2odCo0004ojL0oooDo`3oA?l0ohSo00KoA?l000CoU?l0of?o0?oonf[oo`3Q
1OoonfX00oooQ`3ooo]ZoookJP0=oookJP03ool0R?oonf[ooo]Z00;ooo]Z1?oUo`03oookJP?oQ03o
1?oonfX6onGo00Cooo]Z1?o>0?nmoookJP03od;o0?oonf[ooo]Z01Sooo]Z00?ofP3ooookJ_oonfX0
?ooonfX00ol04?oooo]ZoookJP16oookJPCo00001ooonfX01?oo]03ooo]ZoookJ_l0odHRoookJP03
o`3oAOoonf[ooo]Z00oooo]Z00GoocT0oookJ_oonf[ooo]Zok;o0002oookJP0;oonh0?oo04Coe?l0
o`1Hoon8o`3ooh00o`3aoooonf[oK_l0o`3oIOl0oa`00_oonfX00omSo`3ooo]Zool0h@04oookJP03
oon70?oonf[ooo]Z00gooo]Z0_oo08P:oookJP?oQ03o3_oonfX4olh0ofcooo]Z001CoookJP03od;o
0?oonf[ooo]Z01Wooo]Z00?ofP3ooookJ_oonfX0?ooonfX00ol04?oooo]ZoookJP17oookJPGo0000
1OoonfX01Ooo]03ooo]ZoookJ_oonf[o0?m602;ooo]Z00?o0?m5oookJ_oonfX03ooonfX00ooo>@3o
oo]ZoookJP02oookJP07ok;o0?m4o`3o0?l<ojL0oooDo`3oA?l0ohSo0007odCo0003oiCo0?mSo`3o
oo]Z00;oU?l01?oonfX00oooQ`3ooo]ZoookJP0=oookJP03ool0R?oonf[ooo]Z00;ooo]Z0ooUo`06
oookJP?oQ03o0ooonfX4onGo00Sooo]Z1?o>0?nhoookJP03od;o0?oonf[ooo]Z01Sooo]Z00?ofP3o
oookJ_oonfX0?ooonfX00ol04?oooo]ZoookJP17oookJPGo00001_oonfX01?oo]03ooo]ZoookJ_l0
odHRoookJP03o`3oAOoonf[ooo]Z00oooo]Z00?oocT0oookJ_oonfX00_oonfX03_nbo`3ooo]Zoook
J_oo04CoY`3oomCo0?n8o`3oo`1;oon00?oonf[oK_l0o`1lool0ofGo0?lL0_oonfX00omSo`3ooo]Z
ool0h@04oookJP03oon70?oonf[ooo]Z00kooo]Z00?oo`28oookJ_oonfX02_oonfX3oh@0o`oooo]Z
1?o>0?mXoookJP00D_oonfX00om2o`3ooo]ZoookJP0IoookJP03omX0oooonf[ooo]Z043ooo]Z00?o
013ooookJ_oonfX0AooonfX4o`0000Kooo]Z00Cook@0oookJ_oonf[o0?m68ooonfX00ol0odGooo]Z
oookJP0@oookJP05ooli0?oonf[ooo]ZoookJ_nbo`000_oonfX01Om4o`3oY`3oomCo0?m4o`3oR?l0
00OoA?l000?oU?l0of?o0?nDo`000_nDo`04oookJP03oon70?oonf[ooo]Z00gooo]Z0_oo08P3oook
JP03onGo0?oonf[ooo]Z00Sooo]Z0on40?l01?oonf[oiOl0onGo0?oUo`0<oookJP?ocP3o@_oonfX3
olh0ofoooo]Z00?o@_l0oookJ_oonfX06?oonfX00ooJ0?oooo]ZoookJP10oookJP03o`0@oooonf[o
oo]Z04Oooo]Z1?l00006oookJP04oond0?oonf[ooo]Zo`3oAR?ooo]Z00?o0?m5oookJ_oonfX04?oo
nfX01Ooo>@3ooo]ZoookJ_oonf[o/_l000;ooo]Z00cookP0ool0A?nW0?ooe?l0ohSo0?ooP03o0?7o
oookJ_m^o`3o07coo`3oIOl0oa`2oookJP03of?o0?oo0>7ooo]Z00Cooo]Z0_ooQ`0?oookJP;oo`28
3OoonfX3oh@0oa3ooo]Z0oo>0?m2oookJPCocP3o7ooonfX005;ooo]Z00?o@_l0oookJ_oonfX06Ooo
nfX00ooJ0?oooo]ZoookJP0ooookJP03o`0@oooonf[ooo]Z04Sooo]Z1?l00006oookJP04oond0?oo
nf[ooo]Zo`3oAR?ooo]Z00?o0?m5oookJ_oonfX04?oonfX00ooo>@3ooo]ZoookJP02oookJP07ok;o
0?oonf[o0?l<ojL0oom4o`3oe?l0ohSo0008odCo0003of?o0?nDo`3oU?l000?oU?l00ooonfX00ooo
Q`3ooo]ZoookJP0>oookJP;oo`283ooonfX2oh@0o`03onGo0?oonf[ooo]Z00kooo]Z2?o>0?leoook
JPGocP3oLOoonfX00om2o`3ooo]ZoookJP0IoookJP03omX0oooonf[ooo]Z03oooo]Z00?o013ooook
J_oonfX0B?oonfX4o`0000Kooo]Z00Cook@0oookJ_oonf[o0?m69?oonfX00ol0odGooo]ZoookJP0?
oookJP03ooli0?oonf[ooo]Z00;ooo]Z01?o/_l0oookJ_oonf[oo`14ojL0oooDo`3oR?l0ool0Oooo
P03ooo]Zofko0?oonf[o0?mUo`3o7?l0V?oooo]Zof?o0?oonf[oo`3Q00Kooo]Z00?oohL0oookJ_oo
nfX03_oonfX2ool0R0kooo]Z0on40?l@oookJPSocP3o=OoonfX5olh0ob?ooo]Z001AoookJP03od;o
0?oonf[ooo]Z01Wooo]Z00?ofP3ooookJ_oonfX0@?oonfX00ol04?oooo]ZoookJP18oookJPCo0000
1_oonfX01?oo]03ooo]ZoookJ_l0odHSoookJP03o`3oAOoonf[ooo]Z017ooo]Z00GoocT0oookJ_oo
nf[ooo]Zok;o0002oookJP05odCo0?nW0?ooe?l0odCo0?n8o`002?m4o`000omSo`3oU?l0oiCo0003
oiCo00?ooo]Z00?oohL0oookJ_oonfX03ooonfX2ool0R0oooo]Z0on40?lFoookJPgocP3o7OoonfX;
olh0ogKooo]Z00?o@_l0oookJ_oonfX06?oonfX00ooJ0?oooo]ZoookJP10oookJP03o`0@oooonf[o
oo]Z04Sooo]Z1?l00006oookJP04oond0?oonf[ooo]Zo`3oARCooo]Z00?o0?m5oookJ_oonfX04?oo
nfX01Ooo>@3ooo]ZoookJ_oonf[o/_l000?ooo]Z013oo`14ojL0oooDo`3oR?l0oon00?l0lOoooo]Z
ofko0?oonf[o0?mUo`3o7?l0V?oooo]Zof?o0?oonf[oo`3Q1_oonfX00oooQ`3ooo]ZoookJP0?oook
JP;oo`283ooonfX3oh@0oaGooo]Z3Oo>0?lMoookJP_ocP3o:?oonfX0053ooo]Z00?o@_l0oookJ_oo
nfX06OoonfX00ooJ0?oooo]ZoookJP10oookJP03o`0@oooonf[ooo]Z04Wooo]Z1?l00005oookJP05
oond0?oonf[ooo]ZoookJ_l0odH08ooonfX00ol0odGooo]ZoookJP0AoookJP03ooli0?oonf[ooo]Z
00;ooo]Z00So/_l0oookJ_m4o`3oA?l0ojL0oooDo`3oR?l0o`3o30SoA?l000?oHol0oiCo0?nDo`00
1?nDo`02oookJP03oon70?oonf[ooo]Z013ooo]Z0_oo08P@oookJP;oQ03o8OoonfXMolh0oh3ooo]Z
00?o@_l0oookJ_oonfX06?oonfX00ooJ0?oooo]ZoookJP10oookJP03o`0@oooonf[ooo]Z04Wooo]Z
1?l00006oookJP04oond0?oonf[ooo]Zo`3oARCooo]Z00?o0?m5oookJ_oonfX04?oonfX00ooo>@3o
oo]ZoookJP02oookJP0?ok;o0?oonf[ooo]Zool0A?nW0?ooo`16omCo0?n8o`3ooh00o`3aoooonf[o
K_l0o`1lool0ofGo0?lL00;ooo]Z00?oHol0oookJ_oo0>401_oonfX00oooQ`3ooo]ZoookJP0@oook
JP;oo`284?oonfX2oh@0ob3ooo]Z7Oo>0?lcoookJP00CooonfX00om2o`3ooo]ZoookJP0IoookJP03
omX0oooonf[ooo]Z043ooo]Z00?o013ooookJ_oonfX0B_oonfX4o`0000Gooo]Z00Gook@0oookJ_oo
nf[ooo]Zo`3oAP0SoookJP03o`3oAOoonf[ooo]Z01;ooo]Z00OoocT0oookJ_oonf[ooo]Zok;o0?oo
nf[oU?l000;oA?l000?oe?l0o`3o3?n8o`002Om4o`07oiCo00;ooo]Z00?oohL0oookJ_oonfX04Ooo
nfX2ool0R13ooo]Z0on40?njoookJP03od;o0?oonf[ooo]Z01Sooo]Z00?ofP3ooookJ_oonfX0@?oo
nfX00ol04?oooo]ZoookJP1:oookJPCo00001_oonfX01?oo]03ooo]ZoookJ_l0odHToookJP03o`3o
AOoonf[ooo]Z017ooo]Z00GoocT0oookJ_oonf[ooo]Zok;o0003oookJP0>ool0A?nW0?ooe?l0o`1H
oon8o`3ooh00oookJ_m^o`3ooo]Zo`3oIOl0oaco09SooookJ_mSo`02oookJP03ool0hOoonf[ooo]Z
00Cooo]Z00?oohL0oookJ_oonfX04OoonfX2ool0R13ooo]Z0on40?m]oookJP00C_oonfX00om2o`3o
oo]ZoookJP0JoookJP03omX0oooonf[ooo]Z043ooo]Z00?o013ooookJ_oonfX0B_oonfX4o`0000Go
oo]Z00Gook@0oookJ_oonf[ooo]Zo`3oAP0SoookJP03o`3oAOoonf[ooo]Z01;ooo]Z00?oocT0oook
J_oonfX00_oonfX02?nbo`3oU?l0odCo0?oo04CoY`3oomCo0?l0F?ooR?l01_m4o`02oiCo0003of?o
0?nDo`3oU?l000GoU?l00_oonfX00oooQ`3ooo]ZoookJP0BoookJP;oo`284OoonfX3oh@0okKooo]Z
00?o@_l0oookJ_oonfX06OoonfX00ooJ0?oooo]ZoookJP10oookJP03o`0@oooonf[ooo]Z04[ooo]Z
1?l00006oookJP04oond0?oonf[ooo]Zo`3oARCooo]Z00?o0?m5oookJ_oonfX04OoonfX00ooo>@3o
oo]ZoookJP02oookJP0Bok;o0?oonf[ooo]Zoonh0?oo04CoY`3oomCo0?n8o`3ooh00ool0mooonf[o
K_l0oookJ_l0ofGo0?lLo`2Hoooonf[oHol00_oonfX00ooo0>7ooo]ZoookJP04oookJP03oon70?oo
nf[ooo]Z01;ooo]Z00?oo`28oookJ_oonfX04?oonfX3oh@0of[ooo]Z001>oookJP03od;o0?oonf[o
oo]Z01Wooo]Z00?ofP3ooookJ_oonfX0@?oonfX00ol04?oooo]ZoookJP1;oookJPCo00001OoonfX0
1Ooo]03ooo]ZoookJ_oonf[o0?m602Cooo]Z00?o0?m5oookJ_oonfX04_oonfX01_oo>@3ooo]Zoook
J_oonf[o/_l0oookJP;oU?l000Coo`14ojL0oooDo`3oR?l01Om4o`04oiCo0003of?o0?nDo`3oU?l0
00KoU?l000?ooo]Zoon70?ooQ`005?oonfX2ool0R1;ooo]Z1?n40?nboookJP03od;o0?oonf[ooo]Z
01Sooo]Z00?ofP3ooookJ_oonfX0@?oonfX00ol04?oooo]ZoookJP1;oookJPCo00001_oonfX01?oo
]03ooo]ZoookJ_l0odHToookJP03o`3oAOoonf[ooo]Z01;ooo]Z00GoocT0oookJ_oonf[ooo]Zok;o
0003oookJP0?ool0A?nW0?ooe?l0o`1Hoon8o`3ooh00oookJ_m^o`3ooo]Zo`1lool0ofGo0?lLo`2H
oooonf[oHol000;ooo]Z00?oo`3QoookJ_oonfX01?oonfX00oooQ`3ooo]ZoookJP0BoookJP;oo`28
4ooonfX4oh@0ofKooo]Z001=oookJP03od;o0?oonf[ooo]Z01Wooo]Z00?ofP3ooookJ_oonfX0@Ooo
nfX00ol04?oooo]ZoookJP1;oookJPCo00001OoonfX01?oo]03ooo]ZoookJ_l0odHUoookJP03o`3o
AOoonf[ooo]Z01;ooo]Z00?oocT0oookJ_oonfX00_oonfX3oiCo0004ool0A?l0o`coe?l0ool0O`?o
A?l000?o0?l<ofko0?nDo`001?nDo`000omSo`3oU?l0oiCo0006oiCo00;ooo]Z00?oohL0oookJ_oo
nfX04ooonfX00ooo08Sooo]ZoookJP0CoookJP?oQ03o[_oonfX00om2o`3ooo]ZoookJP0HoookJP03
omX0oooonf[ooo]Z047ooo]Z00?o013ooookJ_oonfX0BooonfX4o`0000Gooo]Z00Cook@0oookJ_oo
nf[o0?m69OoonfX00ol0odGooo]ZoookJP0BoookJP03ooli0?oonf[ooo]Z00;ooo]Z01Go/_l0oook
J_oonf[ooo]Zool0A?nW0?ooe?l0o`1Hoon8o`3oo`1;oookJ_m^o`3ooo]Zo`1lool0ofGo0?lLo`2H
oooonf[oHol0oookJ_oo0>401ooonfX00oooQ`3ooo]ZoookJP0CoookJP;oo`285OoonfX3oh@0of?o
oo]Z001<oookJP03od;o0?oonf[ooo]Z01Wooo]Z00?ofP3ooookJ_oonfX0@OoonfX00ol04?oooo]Z
oookJP1<oookJPCo00001?oonfX01Ooo]03ooo]ZoookJ_oonf[o0?m602Gooo]Z00?o0?m5oookJ_oo
nfX04ooonfX01?oo>@3ooo]ZoookJ_oonfX4oiCo0003ool0A?nW0?ooe?l000;oA?l00ol0o``00om^
o`3oU?l0oiCo0003oiCo0003of?o0?nDo`3oU?l000KoU?l00_oonfX00oooQ`3ooo]ZoookJP0Coook
JP;oo`285_oonfX5oh@0oc7ooo]Z0ooob@1doookJP03od;o0?oonf[ooo]Z01Sooo]Z00?ofP3ooook
J_oonfX0@OoonfX00ol04?oooo]ZoookJP1<oookJPCo00001OoonfX01?oo]03ooo]ZoookJ_l0odHU
oookJP03o`3oAOoonf[ooo]Z01?ooo]Z00GoocT0oookJ_oonf[ooo]Zok;o0003oookJP0Bool0A?nW
0?ooe?l0o`1Hoon8o`3ooh00ool0mooonf[oK_l0oookJ_l0ofGo0?lLoookJ_l0V?oooo]Zof?o0?oo
nf[oo`3Q1ooonfX00oooQ`3ooo]ZoookJP0DoookJP03ool0R?oonf[ooo]Z01Gooo]Z1On40?mNoook
JP00BooonfX00om2o`3ooo]ZoookJP0JoookJP03omX0oooonf[ooo]Z047ooo]Z00?o013ooookJ_oo
nfX0C?oonfX5o`0000?ooo]Z00Gook@0oookJ_oonf[ooo]Zo`3oAP0UoookJP03o`3oAOoonf[ooo]Z
01?ooo]Z00CoocT0oookJ_oonf[ooo]Z1?nDo`001?oo04Co0?l<omCo0?l0o``2odCo00;o0?l<00Go
K_l0oiCo0?nDo`3o07coo`3o7002oiCo0003of?o0?nDo`3oU?l000?oU?l01OoonfX00oooQ`3ooo]Z
oookJP0DoookJP;oo`286OoonfX6oh@0obOooo]Z1ooob@1coookJP03od;o0?oonf[ooo]Z01Wooo]Z
00?ofP3ooookJ_oonfX0@OoonfX00ol04?oooo]ZoookJP1<oookJPGo00001?oonfX01?oo]03ooo]Z
oookJ_l0odHVoookJP03o`3oAOoonf[ooo]Z01;ooo]Z00?oocT0oookJ_oonfX00_oonfX03?nbo`3o
oo]ZoookJ_oonf[oo`14ojL0oooDo`3o05SoohSo0?ooP03ooo]Zofko00;ooo]Z00So0?mUo`3o7?oo
nf[o09SooookJ_mSo`3ooo]Zool0h@Oooo]Z00?oohL0oookJ_oonfX05?oonfX2ool0R1[ooo]Z1_n4
0?mHoookJP00BooonfX00om2o`3ooo]ZoookJP0IoookJP03omX0oooonf[ooo]Z047ooo]Z00?o013o
oookJ_oonfX0COoonfX4o`0000Cooo]Z00Gook@0oookJ_oonf[ooo]Zo`3oAP0UoookJP03o`3oAOoo
nf[ooo]Z01Cooo]Z00?oocT0oookJ_oonfX01?nDo`001?m4o`3o0?l<ojL0oooDo`03odCo0007oiCo
0?l0o`coK_l0oookJ_l0ofGooo]Zo`3o7002oiCo0004of?o0?nDo`3oU?l0oiCo00Oooo]Z00?oohL0
oookJ_oonfX05OoonfX3ool0R1cooo]Z1on40?lMoookJP[oolT0L_oonfX00om2o`3ooo]ZoookJP0I
oookJP03omX0oooonf[ooo]Z047ooo]Z00?o013ooookJ_oonfX0COoonfX4o`0000Gooo]Z00Cook@0
oookJ_oonf[o0?m69_oonfX00ol0odGooo]ZoookJP0CoookJP05ooli0?oonf[ooo]ZoookJ_nbo`00
0ooonfX03_oo^03oY`3oomCo0?l0F?ook03oohSo0?oo04_ooo]Zofko0?oonf[o07coo`3oIOl0oaco
09So0_oonfX00omSo`3ooo]Zool0h@07oookJP03oon70?oonf[ooo]Z01Gooo]Z0ooo08PMoookJPKo
Q03oD_oonfX004[ooo]Z00?o@_l0oookJ_oonfX06OoonfX00ooJ0?oooo]ZoookJP11oookJP03o`0@
oooonf[ooo]Z04kooo]Z1?l00004oookJP05oond0?oonf[ooo]ZoookJ_l0odH09_oonfX00ol0odGo
oo]ZoookJP0CoookJP03ooli0?oonf[ooo]Z00CoU?l000GoA?l0o`3o3?l0o`coY`3oomCo0003odCo
0006oiCo0?l0o`coK_l0o`3oIOl0O?oo0?lL0_nDo`001?mSo`3oU?l0oiCo0?oo0>48oookJP03oon7
0?oonf[ooo]Z01Oooo]Z0_oo08PQoookJPOoQ03o4_oonfX>ooo900Kooo]Z1On40?mWoookJP03od;o
0?oonf[ooo]Z01Sooo]Z00?ofP3ooookJ_oonfX0@OoonfX00ol04?oooo]ZoookJP1>oookJPCo0000
1OoonfX01?oo]03ooo]ZoookJ_l0odHVoookJP03o`3oAOoonf[ooo]Z01?ooo]Z00?oocT0oookJ_oo
nfX00_oonfX05?nbo`3ooo]ZoookJ_oonf[oo`14ojL0oooDo`3o05SoohSo0?ooP03oo`3goookJ_m^
o`3ooo]Zo`3oIOl0oacooo]Zo`2Hoooonf[oHol00_oonfX00ooo0>7ooo]ZoookJP05oookJP03oon7
0?oonf[ooo]Z01Oooo]Z0_oo08PQoookJPOoQ03o9_oonfX6oh@0oaoooo]Z0019oookJP03od;o0?oo
nf[ooo]Z01Wooo]Z00?ofP3ooookJ_oonfX0@_oonfX00ol04?oooo]ZoookJP1>oookJPCo00000ooo
nfX01Ooo]03ooo]ZoookJ_oonf[o0?m602Oooo]Z00?o0?m5oookJ_oonfX04ooonfX01?oo>@3ooo]Z
oookJ_oonfX4oiCo0004odCo0?l0o`coY`3oomCo00CoA?l000KoU?l0oookJ_m^o`3o0?mUo`1lool0
oa`2oiCo0004of?o0?nDo`3ooo]Zool0h@Sooo]Z0_ooQ`0IoookJP?oo`289OoonfX@oh@0oa;oolT0
1?n40?m[oookJP03od;o0?oonf[ooo]Z01Sooo]Z00?ofP3ooookJ_oonfX0@_oonfX00ol04?oooo]Z
oookJP1>oookJPCo00001?oonfX01?oo]03ooo]ZoookJ_l0odHWoookJP03o`3oAOoonf[ooo]Z01?o
oo]Z00?oocT0oookJ_oonfX00_oonfX02onbo`3ooo]ZoookJ_oonf[ookP0ojL0oooDo`3oon80o`1H
oon8o`3ooh0000;ooo]Z00SoK_l0oookJ_l0ofGo0?lLoookJ_l0V?oooo]Zof?o00;ooo]Z00?oo`3Q
oookJ_oonfX01OoonfX2oon701Wooo]Z0ooo08PUoookJRKoQ03o9OoonfX004Sooo]Z00?o@_l0oook
J_oonfX06_oonfX00ooJ0?oooo]ZoookJP11oookJP03o`0@oooonf[ooo]Z04oooo]Z1?l00003oook
JP05oond0?oonf[ooo]ZoookJ_l0odH09ooonfX00ol0odGooo]ZoookJP0DoookJP03ooli0?oonf[o
oo]Z00CoU?l000GoA?l0o`3o3?nW0?ooo`16omCo0004odCo0006oiCo0?m^o`3ooo]Zo`3oIOoonf[o
0?lL0_nDo`001?mSo`3oU?l0oookJ_oo0>49oookJP03oon70?oonf[ooo]Z01Wooo]Z0_oo08Pgoook
JPcoolT0L?oonfX00om2o`3ooo]ZoookJP0IoookJP03omX0oooonf[ooo]Z047ooo]Z00?o013ooook
J_oonfX0CooonfX4o`0000Cooo]Z00Cook@0oookJ_oonf[o0?m69ooonfX00ol0odGooo]ZoookJP0D
oookJP05ooli0?oonf[ooo]ZoookJ_nbo`001?oonfX01onW0?oooo]ZomCo0?l0F?ooR?l0oon00?oo
04/00_oonfX02?m^o`3o07coo`3oIOl0oacooo]Zo`2Hoooonf[oHol00_oonfX00ooo0>7ooo]Zoook
JP06oookJP03oon70?oonf[ooo]Z01Wooo]Z0_oo08Q^oookJP00B?oonfX00om2o`3ooo]ZoookJP0I
oookJP03omX0oooonf[ooo]Z04;ooo]Z00?o013ooookJ_oonfX0CooonfX4o`0000?ooo]Z00Gook@0
oookJ_oonf[ooo]Zo`3oAP0WoookJP03o`3oAOoonf[ooo]Z01Cooo]Z00?oocT0oookJ_oonfX01OnD
o`001?oonf[oo`14ojL0oooDo`05odCo0006oiCo0?m^o`3ooo]Zo`3oIOnDo`3o0?lL0_nDo`001?mS
o`3oU?l0oookJ_oo0>49oookJP03oon70?oonf[ooo]Z01[ooo]Z0ooo08PioookJPOoolT0KooonfX0
0om2o`3ooo]ZoookJP0IoookJP03omX0oooonf[ooo]Z04;ooo]Z00?o013ooookJ_oonfX0CooonfX4
o`0000Cooo]Z00Cook@0oookJ_oonf[o0?m69ooonfX00ol0odGooo]ZoookJP0DoookJP03ooli0?oo
nf[ooo]Z00;ooo]Z00_o/_l0oookJ_oonf[ooo]Zoonh0?nW0?ooe?l0o`1Rool0F?ooR?l0oon00003
oookJP05ofko0?l0ofGooo]Zo`3o7?l0V?l00_oonfX00omSo`3ooo]Zool0h@09oookJP03oon70?oo
nf[ooo]Z01[ooo]Z0ooo08Q[oookJP00AooonfX00om2o`3ooo]ZoookJP0IoookJP03omX0oooonf[o
oo]Z04;ooo]Z00?o013ooookJ_oonfX0D?oonfX4o`0000?ooo]Z00Gook@0oookJ_oonf[ooo]Zo`3o
AP0WoookJP03o`3oAOoonf[ooo]Z01Cooo]Z00?oocT0oookJ_oonfX01_nDo`001?l0o`coY`3oool0
A_oDo`05odCo0006oiCo0?m^o`3o0?mUo`1loonDo`3o0?lL0_nDo`001?mSo`3oU?l0oookJ_oo0>49
oookJP03oon70?oonf[ooo]Z01cooo]Z0_oo08PloookJP;oolT0K_oonfX00om2o`3ooo]ZoookJP0I
oookJP03omX0oooonf[ooo]Z04;ooo]Z00?o013ooookJ_oonfX0D?oonfX4o`0000?ooo]Z00Gook@0
oookJ_oonf[ooo]Zo`3oAP0WoookJP03o`3oAOoonf[ooo]Z01Cooo]Z00?oocT0oookJ_oonfX00_oo
nfX00onbo`3ooo]ZoookJP02oookJP07ojL0oooonf[oe?l0o`1Hooo/0?ooR?l0ool0B`03oookJP05
ofko0?l0ofGooo]Zo`3o7?l0V?l00_oonfX00omSo`3ooo]Zool0h@09oookJP;oohL07OoonfX3ool0
R6Sooo]Z0016oookJP03od;o0?oonf[ooo]Z01Wooo]Z00?ofP3ooookJ_oonfX0@ooonfX00ol04?oo
oo]ZoookJP1@oookJPCo00000ooonfX01Ooo]03ooo]ZoookJ_oonf[o0?m602Oooo]Z00?o0?m5oook
J_oonfX05OoonfX00ooo>@3ooo]ZoiCo0005oiCo0004oookJ_oo04CoY`3oomCo00KoA?l000?oK_l0
oookJ_l0ofD00_nDo`001?l0oacoU?l0oiCo0?mSo`02oiCo0003ool0hOoonf[ooo]Z00Oooo]Z00?o
ohL0oookJ_oonfX07OoonfX3ool0R:Wooo]Z00?o@_l0oookJ_oonfX06?oonfX00ooJ0?oooo]Zoook
JP13oookJP03o`0@oooonf[ooo]Z053ooo]Z1?l00003oookJP05oond0?oonf[ooo]ZoookJ_l0odH0
9ooonfX00ol0odGooo]ZoookJP0EoookJP03ooli0?oonf[ooo]Z00;ooo]Z00co/_l0oookJ_oonf[o
oo]Zoonh0?nW0?oooo]ZomCo0?l0F?ooR?l0oon00?oo0?L2oookJP06ofko0?l0ofGo07cooookJ_l0
oaco09So0_oonfX00omSo`3ooo]Zool0h@0:oookJP03oon70?oonf[ooo]Z01gooo]Z0ooo08QUoook
JP00AOoonfX00om2o`3ooo]ZoookJP0JoookJP03omX0oooonf[ooo]Z04;ooo]Z00?o013ooookJ_oo
nfX0DOoonfX4o`0000;ooo]Z00Gook@0oookJ_oonf[ooo]Zo`3oAP0XoookJP03o`3oAOoonf[ooo]Z
01Gooo]Z00?oocT0oookJ_nDo`001_nDo`000ooonf[oY`3oomCo0007odCo0003ofko0?oonf[o0?mU
00;oU?l000?o0?lLoiCo0?nDo`000_oUo`000onDo`3oo`3QoookJP08oookJP03oon70?oonf[ooo]Z
01oooo]Z2OoUo`2OoookJP03od;o0?oonf[ooo]Z01Wooo]Z00?ofP3ooookJ_oonfX0@_oonfX00ol0
4?oooo]ZoookJP1AoookJPCo00000ooonfX01?oo]03ooo]ZoookJ_l0odHXoookJP03o`3oAOoonf[o
oo]Z01Gooo]Z00?oocT0oookJ_oonfX00_oonfX00onbo`3ooo]ZoookJP02oookJP07ojL0oooonf[o
e?l0oooR0?l0F?ooR?l0oon00003oookJP06ofko0?l0ofGooo]ZoookJ_l0oaco09So0_oonfX00omS
o`3ooo]Zool0h@0:oookJP03oon70?oonf[ooo]Z01oooo]Z0_oo08QSoookJP00AOoonfX00om2o`3o
oo]ZoookJP0IoookJP03omX0oooonf[ooo]Z04;ooo]Z00?o013ooookJ_oonfX0D_oonfX4o`0000;o
oo]Z00Gook@0oookJ_oonf[ooo]Zo`3oAP0XoookJP03o`3oAOoonf[ooo]Z01Gooo]Z00?oocT0oook
J_nDo`001onDo`000ooo^03oY`3oomCo0007odCo0005ofko0?oonf[oU?l0oiCo0?l0oa`00_nDo`03
onGo0003oiCo0?oo0>7ooo]Z00Sooo]Z0_ooQ`0QoookJPooiOl0U_oonfX00om2o`3ooo]ZoookJP0I
oookJP03omX0oooonf[ooo]Z04;ooo]Z00?o013ooookJ_oonfX0D_oonfX4o`0000?ooo]Z00Cook@0
oookJ_oonf[o0?m6:?oonfX00ol0odGooo]ZoookJP0EoookJP03ooli0?oonf[ooo]Z00?ooo]Z00?o
/_l0oookJ_oonfX00_oonfX01onW0?oooo]ZomCo0?l0F?ooR?l0oon00?oo04/00ooonfX01Om^o`3o
0?mUoookJ_l0oaco09So00;ooo]Z00CoHol0oookJ_oonf[oo`3Q2_oonfX2oon7027ooo]Z0ooo08QP
oookJP00A?oonfX00om2o`3ooo]ZoookJP0IoookJP03omX0oooonf[ooo]Z04?ooo]Z00?o013ooook
J_oonfX0D_oonfX4o`0000;ooo]Z00Gook@0oookJ_oonf[ooo]Zo`3oAP0YoookJP03o`3oAOoonf[o
oo]Z01Gooo]Z00?oocT0oookJ_nDo`002?nDo`000ooDo`3oA?l0odCo0005odCo0003oiCo0?m^o`3o
U?l000;oU?l000?o0?lLoiCo0?nDo`001?oUo`000ooo0>7ooo]ZoookJP08oookJP03oon70?oonf[o
oo]Z01oooo]Z3_oUo`2EoookJP03od;o0?oonf[ooo]Z01Wooo]Z00?ofP3ooookJ_oonfX0@ooonfX0
0ol04?oooo]ZoookJP1BoookJPCo00000_oonfX01Ooo]03ooo]ZoookJ_oonf[o0?m602Wooo]Z00?o
0?m5oookJ_oonfX05OoonfX00ooo>@3ooo]ZoookJP02oookJP03ok;o0?oonf[ooo]Z00;ooo]Z00So
o`14ojL0oooDo`3o06;oo`1Hoon8o`3ooh00ool0m`;ooo]Z00KoK_l0o`3oIOl0O?oooo]Zo`3o7?l0
V?l2oookJP04of?o0?oonf[ooo]Zool0h@_ooo]Z00?oohL0oookJ_oonfX08OoonfX3ool0R5gooo]Z
0013oookJP03od;o0?oonf[ooo]Z01Wooo]Z00?ofP3ooookJ_oonfX0@ooonfX00ol04?oooo]Zoook
JP1CoookJPGo000000?ooo]Zoond0?oonfX00_oonfX00ol0odKooo]ZoookJP0WoookJP03o`3oAOoo
nf[ooo]Z01Gooo]Z00?oocT0oookJ_nDo`001OnDo`02oookJP03oiCo0?m4o`3oe?l000OoA?l000?o
K_l0oiCo0?nDo`000_nDo`000ol0oacoU?l0onGo0004onGo0003ool0hOoonf[ooo]Z00Sooo]Z00?o
ohL0oookJ_oonfX08?oonfX;onGo09Gooo]Z00?o@_l0oookJ_oonfX06_oonfX00ooJ0?oooo]Zoook
JP12oookJP03o`0@oooonf[ooo]Z05?ooo]Z1Ol000000ooonf[ook@0oookJP02oookJP03o`3oA_oo
nf[ooo]Z02Oooo]Z00?o0?m5oookJ_oonfX05OoonfX00ooo>@3ooo]ZoookJP03oookJP03ok;o0?oo
nf[ooo]Z00;ooo]Z00OoY`3ooookJ_oDo`3o05Soon`0oon8o`3ooh0000?ooo]Z00KoK_l0o`3oIOl0
O?oooo]Zo`3o7?l0V?l2oookJP04of?o0?oonf[ooo]Zool0h@_ooo]Z00?oohL0oookJ_oonfX08ooo
nfX3ool0R5[ooo]Z0012oookJP03od;o0?oonf[ooo]Z01[ooo]Z00?ofP3ooookJ_oonfX0@ooonfX0
0ol04?oooo]ZoookJP1CoookJPCo00000_oonfX01Ooo]03ooo]ZoookJ_oonf[o0?m602Wooo]Z00?o
0?m5oookJ_oonfX05OoonfX00ooo>@3ooo]ZoiCo0002oiCo0003oookJ_nbo`3ooo]Z00?ooo]Z00Go
U?l0omCo0?m4o`3o05SoohSo0005odCo0003ofko0?nDo`3oU?l000;oU?l000?o0?lLoiCo0?oUo`00
1OoUo`0:oookJP03oon70?oonf[ooo]Z023ooo]Z2_oUo`2EoookJP03od;o0?oonf[ooo]Z01Wooo]Z
00?ofP3ooookJ_oonfX0@ooonfX00ol04?oooo]ZoookJP1CoookJPCo00000_oonfX01Ooo]03ooo]Z
oookJ_oonf[o0?m602Wooo]Z00?o0?m5oookJ_oonfX05OoonfX00ooo>@3ooo]ZoookJP03oookJP03
ok;o0?oonf[ooo]Z00;ooo]Z00Soo`14ojL0oooDo`3o06;oo`1Hoon8o`3ooh00ool0B`;ooo]Z00?o
K_l0oookJ_l0ofD00_oonfX01Ol0oaco09SooookJ_oonf[oHol000;ooo]Z00?oo`3QoookJ_oonfX0
2OoonfX00oooQ`3ooo]ZoookJP0UoookJP?oo`28EooonfX0047ooo]Z00?o@_l0oookJ_oonfX06_oo
nfX00ooJ0?oooo]ZoookJP13oookJP03o`0@oooonf[ooo]Z05Cooo]Z1?l000000ooonf[ook@0oook
JP02oookJP03o`3oA_oonf[ooo]Z02Sooo]Z00?o0?m5oookJ_oonfX05_oonfX00ooo>@3oU?l0oook
JP02oookJP03ok;o0?oonf[ooo]Z00;ooo]Z00KoU?l0odCo0?oDo`3o05SooiCo0?n8o`05odCo0006
ofko0?nDo`3oU?l0oiCo0?l0oacoU?l01ooUo`0:oookJP03oon70?oonf[ooo]Z027ooo]Z2?oUo`03
ool0R97ooo]Z00?o@_l0oookJ_oonfX06OoonfX00ooJ0?oooo]ZoookJP13oookJP03o`0@oooonf[o
oo]Z05Cooo]Z1?l000000ooonf[ook@0oookJP02oookJP03o`3oA_oonf[ooo]Z02Sooo]Z00?o0?m5
oookJ_oonfX05_oonfX00ooo>@3ooo]ZoookJP02oookJP03ok;o0?oonf[ooo]Z00?ooo]Z00OoY`3o
oookJ_oDo`3o05Soool0Oon8o`3ooh0000?ooo]Z00WoK_l0oookJ_l0ofGooo]Zo`3o7?oonf[o09So
oookJ_mSo`000ooonfX00ooo0>7ooo]ZoookJP09oookJP03oon70?oonf[ooo]Z02Oooo]Z1Ooo08QB
oookJP00@OoonfX00om2o`3ooo]ZoookJP0IoookJP03omX0oooonf[ooo]Z04Cooo]Z00?o013ooook
J_oonfX0E?oonfX4o`000003oookJ_oo:03ooo]Z00;ooo]Z00?o0?m6oookJ_oonfX0:?oonfX00ol0
odGooo]ZoookJP0FoookJP03ooli0?oonf[ooo]Z00?ooo]Z00Co/_l0oookJ_oonf[ooo]Z0_nDo`00
1?nW0?ooe?l0o`1Hoon8o`06odCo0006ofko0?nDo`3oU?l0oiCo0?l0oacoU?l01ooUo`0:oookJP03
oon70?oonf[ooo]Z027ooo]Z1_oUo`04oookJPCoo`28S?oonfX00om2o`3ooo]ZoookJP0JoookJP03
omX0oooonf[ooo]Z04?ooo]Z00?o013ooookJ_oonfX0E?oonfX4o`000003oookJ_oo]03ooo]Z00;o
oo]Z00?o0?m6oookJ_oonfX0:?oonfX00ol0odGooo]ZoookJP0FoookJP03ooli0?oonf[ooo]Z00?o
oo]Z00?o/_l0oookJ_oonfX00ooonfX01onW0?oooo]ZomCo0?l0F?ooR?l0oon00?oo04/00ooonfX0
2Om^o`3o0?mUo`1loooonf[o0?lLoookJ_l0V?oooo]Zof?o0003oookJP03ool0hOoonf[ooo]Z00Wo
oo]Z00?oohL0oookJ_oonfX0:ooonfX4ool0R4kooo]Z0010oookJP03od;o0?oonf[ooo]Z01[ooo]Z
00?ofP3ooookJ_oonfX0@ooonfX00ol04?oooo]ZoookJP1EoookJPCo000000?ooo]ZoolX0?oonfX0
0_oonfX00ol0odKooo]ZoookJP0XoookJP03ooo90?oonf[ooo]Z01Oooo]Z00?oocT0oookJ_oonfX0
0_oonfX01?nbo`3ooo]ZoookJ_oonfX3oiCo0004omCo0?oohP3o05SoohSo00GoA?l000?oK_l0oiCo
0?nDo`000_nDo`000ol0oacoiOl0onGo0007onGo00Wooo]Z00?oohL0oookJ_oonfX08OoonfX5onGo
00Sooo]Z1_oo08R5oookJP03od;o0?oonf[ooo]Z01[ooo]Z00?ofP3ooookJ_oonfX0@ooonfX00ol0
4?oooo]ZoookJP1EoookJPCo000000?ooo]Zoond0?oonfX00_oonfX00ol0odKooo]ZoookJP0Xoook
JP03o`3oAOoonf[ooo]Z01Oooo]Z00?oocT0oookJ_oonfX00_oonfX00onbo`3ooo]ZoookJP03oook
JP08ool0A?nW0?ooe?l0o`1Rool0F?ooR?l0oon00?oo04/2oookJP0:ofko0?oonf[o0?mUo`1loooo
nf[o0?lLoookJ_l0V?oooo]Zof?o00?ooo]Z00?oo`3QoookJ_oonfX02OoonfX00oooQ`3ooo]Zoook
JP0^oookJPKoo`28B?oonfX003oooo]Z00?o@_l0oookJ_oonfX06_oonfX00ooJ0?oooo]ZoookJP13
oookJP03o`0@oooonf[ooo]Z05Kooo]Z1?l00002oolX00?ooo]Z00?o0?m6oookJ_oonfX0:?oonfX0
0ooob@3ooo]ZoookJP0GoookJP03ooli0?oonf[ooo]Z00?ooo]Z00Co/_l0oookJ_oonf[ooo]Z0_nD
o`001?nW0?ooe?l0o`1Roon8o`06odCo0003ofko0?nDo`3oU?l000;oU?l000?o0?lLonGo0?oUo`00
1ooUo`09oookJP;oohL08ooonfX3onGo00kooo]Z1ooo08QnoookJP03od;o0?oonf[ooo]Z01Wooo]Z
00?ofP3ooookJ_oonfX0@ooonfX00ol04?oooo]ZoookJP1FoookJPCo000000?ooo]Zoond0?oonfX0
0_oonfX00ol0odKooo]ZoookJP0XoookJP03o`3oAOoonf[ooo]Z01Oooo]Z00?oocT0oookJ_oonfX0
0ooonfX00onbo`3ooo]ZoookJP03oookJP08ojL0oooonf[oe?l0o`1Hoon8o`3oocT0oon00?l0lOl2
oookJP03ofko0?oonf[o0?mU00;ooo]Z00Go0?lLo`2Hoooonf[ooo]Zof?o0003oookJP03ool0hOoo
nf[ooo]Z00Wooo]Z0_ooQ`0doookJPOoo`28@OoonfX003kooo]Z00?o@_l0oookJ_oonfX06_oonfX0
0ooJ0?oooo]ZoookJP14oookJP03o`0@oooonf[ooo]Z05Kooo]Z1?l00002oolX00;ooo]Z00?o0?m6
oookJ_oonfX0:OoonfX2ooo901Sooo]Z00?oocT0oookJ_oonfX00ooonfX01?nbo`3ooo]ZoookJ_oo
nfX3oiCo0004omCo0?oohP3o05SoohSo00KoA?l000GoK_l0oiCo0?nDo`3oU?l0o`3o700:onGo00[o
oo]Z00?oohL0oookJ_oonfX08OoonfX00ooUo`3ooo]ZoookJP0DoookJPOoo`28M_oonfX00om2o`3o
oo]ZoookJP0IoookJP03omX0oooonf[ooo]Z04Cooo]Z00?o013ooookJ_oonfX0E_oonfX4o`000003
oond0?oonf[ooo]Z00;ooo]Z00?o0?m6oookJ_oonfX0:?oonfX00ol0odGooo]ZoookJP0GoookJP03
ooli0?oonf[ooo]Z00?ooo]Z00?o/_l0oookJ_oonfX00ooonfX02?oo04CoY`3oomCo0?l0H_oo05So
ohSo0?ooP03oo`1;0ooonfX01om^o`3ooo]Zo`3oIOoonf[o0?lLoookJ_l0V?l00_oonfX01OmSo`3o
oo]ZoookJ_oonf[oo`3Q00cooo]Z00?oohL0oookJ_oonfX0>?oonfX7ool0R3[ooo]Z000noookJP03
od;o0?oonf[ooo]Z01Wooo]Z00?ofP3ooookJ_oonfX0A?oonfX00ol04?oooo]ZoookJP0aoookJPGo
001o1?oonfX3o`00O`?ooo]Z0ol007l7oookJPGo001o2?oonfX3o`0000?oobP00_oonfX00ol0odKo
oo]ZoookJP0YoookJP;oolT06OoonfX00ooo>@3ooo]ZoookJP03oookJP03ok;o0?oonf[ooo]Z00?o
U?l000GoY`3oomCo0?l0H_oo05SoohSo0005odCo0003ofko0?m4o`3oU?l000;oU?l000?o0?lLonGo
0?oUo`001OoUo`000ooonf[oo`3Qool0h@0:oookJP;oohL0?ooonfX8ool0R6gooo]Z00?o@_l0oook
J_oonfX06_oonfX00ooJ0?oooo]ZoookJP13oookJP03o`0@oooonf[ooo]Z037ooo]Z1Ol007l4oook
JP?o001o0ooonfX3o`00O`Oooo]Z1Ol007l8oookJPCo000000Gook@0oookJ_oonf[ooo]Zo`3oAP0[
oookJP03o`3oAOoonf[ooo]Z01Sooo]Z00?oocT0oookJ_oonfX00ooonfX00onbo`3ooo]ZoookJP03
oookJP08ojL0oooonf[oe?l0o`1Hoon8o`3oocT0oon00?oo04/2oookJP08ofko0?oonf[o0?mUo`1l
oooonf[o0?lLoookJ_l0V?l2oookJP04of?o0?oonf[ooo]ZoookJP;oo`3Q2ooonfX2oon703oooo]Z
1ooo08PcoookJP00?OoonfX00om2o`3ooo]ZoookJP0JoookJP03omX0oooonf[ooo]Z04Cooo]Z00?o
013ooookJ_oonfX0<?oonfX7o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX7o`00O`Oooo]Z0ol0
0003oolX00;ooo]Z00?o0?m6oookJ_oonfX0:?oonfX3ooo901Wooo]Z00?oocT0oookJ_oonfX00ooo
nfX01?nbo`3ooo]ZoookJ_oonfX3oiCo0004ojL0oooDo`3o06;oohSo00GoA?l000?oU?l0ofko0?nD
o`000onDo`06onGo00Cooo]Z00?oo`3QoookJ_oonfX02OoonfX00oooQ`3ooo]ZoookJP14oookJQ?o
o`28FOoonfX00om2o`3ooo]ZoookJP0JoookJP03omX0oooonf[ooo]Z04Cooo]Z00?o013ooookJ_oo
nfX0<?oonfX7o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX7o`00O`Oooo]Z1?l000001Ooo]03o
oo]ZoookJ_oonf[o0?m602_ooo]Z00?o0?m5oookJ_oonfX06?oonfX00ooo>@3ooo]ZoookJP03oook
JP03ok;o0?oonf[ooo]Z00?ooo]Z00Woo`14ojL0oooonf[oe?l0o`1Hoon8o`3oocT0oon00?l0lOl0
0_oonfX02?m^o`3ooo]Zo`3oIOl0O?oooo]Zo`3o7?oonf[o09So0_oonfX00omSo`3ooo]ZoookJP02
oookJP03ool0hOoonf[ooo]Z00[ooo]Z00?oohL0oookJ_oonfX0@ooonfXDool0R1oooo]Z000loook
JP03od;o0?oonf[ooo]Z01[ooo]Z00?ofP3ooookJ_oonfX0A?oonfX00ol04?oooo]ZoookJP0aoook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`?ooo]Z0ol007l5oookJPCo001o00Cooo]Z
o`00Ool007oo001o1ooonfX2o`0000CoobP00_oonfX00ol0odKooo]ZoookJP0XoookJPCoolT06Ooo
nfX00ooo>@3ooo]ZoookJP02oookJP04ok;o0?oonf[ooo]ZoookJP?oU?l000GoY`3oomCo0?l0H_oo
o`1oohSo0005odCo0003oiCo0?m^o`3oU?l000?oU?l01?oUo`000ooonf[oHol0oookJP03oookJP03
ool0hOoonf[ooo]Z00Wooo]Z0_ooQ`2_oookJP03od;o0?oonf[ooo]Z01[ooo]Z00?ofP3ooookJ_oo
nfX0A?oonfX00ol04?oooo]ZoookJP0aoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`?ooo]Z0ol007l5oookJPCo001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`000005oond0?oonf[o
oo]ZoookJ_l0odH0:ooonfX00ol0odGooo]ZoookJP0IoookJP03ooli0?oonf[ooo]Z00;ooo]Z00?o
/_l0oookJ_oonfX01?oonfX02OnW0?oooo]ZomCo0?oo04Ko05SoohSo0?ooP03oo`1;o`3ao`02oook
JP03ofko0?oonf[o0?mU00;ooo]Z00?o0?lLoookJ_l0V?l00_oonfX00omSo`3ooo]ZoookJP02oook
JP03ool0hOoonf[ooo]Z00[ooo]Z0_ooQ`1foookJP00>ooonfX00om2o`3ooo]ZoookJP0JoookJP03
omX0oooonf[ooo]Z04Gooo]Z00?o013ooookJ_oonfX0<?oonfX3o`00O`?ooo]Z0ol007l9oookJP;o
001o1OoonfX3o`00O`?ooo]Z0ol007l6oookJP;o00001?oo:0000ooonf[o0?m6oookJP0ZoookJPCo
olT06OoonfX00ooo>@3ooo]ZoookJP03oookJP03ok;o0?oonf[ooo]Z00CoU?l000OoY`3oomCo0?l0
H_oo05SoohSo0?m4o`3ooh0000;oA?l000KoU?l0ofko0?nDo`3oU?l0o`3oIOnDo`03onGo00?ooo]Z
00?oHol0oookJ_oonfX00_oonfX00ooo0>7ooo]ZoookJP0:oookJP03oon70?oonf[ooo]Z0:cooo]Z
00?o@_l0oookJ_oonfX06_oonfX00ooJ0?oooo]ZoookJP14oookJP03o`0@oooonf[ooo]Z033ooo]Z
0ol007l3oookJP?o001o2OoonfX2o`00O`Gooo]Z0ol007l3oookJP?o001o1_oonfX3o`000003oond
0?oonf[ooo]Z00;ooo]Z00?o0?m6oookJ_oonfX0:OoonfX00ol0odGooo]ZoookJP0IoookJP03ooli
0?oonf[ooo]Z00?ooo]Z00?o/_l0oookJ_oonfX00ooonfX02Ooo04CoY`3ooookJ_oDo`3o05SoohSo
0?oo>@3ooh00ool0B`02oookJP04ofko0?oonf[ooo]Zo`3oI@;ooo]Z00?o0?lLoookJ_l0V?l00_oo
nfX00omSo`3ooo]ZoookJP02oookJP03ool0hOoonf[ooo]Z00_ooo]Z00?oohL0oookJ_oonfX0Looo
nfX003_ooo]Z00?o@_l0oookJ_oonfX06OoonfX00ooJ0?oooo]ZoookJP15oookJP03o`0@oooonf[o
oo]Z037ooo]Z0ol007l3oookJP?o001o2OoonfX3o`00O`[ooo]Z0ol007l6oookJP03o`000?oo:03o
obP000?oobP000?ooo]Zo`3oA_oonfX0:_oonfX4ooo901Wooo]Z00?oocT0oookJ_oonfX00ooonfX0
0onbo`3ooo]ZoookJP04oiCo0009ojL0oonDo`3oe?l0od<0oon8o`3oA?l0ool0BoooP03oA?l000;o
U?l000?oK_l0odCo0?l0ofD00_nDo`000ooUo`3o0?lLo`2Ho`03oookJP03of?o0?oonf[ooo]Z00;o
oo]Z00?oo`3QoookJ_oonfX02_oonfX2onGo0:_ooo]Z00?o@_l0oookJ_oonfX06_oonfX00ooJ0?oo
oo]ZoookJP14oookJP03o`0@oooonf[ooo]Z037ooo]Z0ol007l3oookJP?o001o2OoonfX3o`00O`[o
oo]Z0ol007l6oookJP?o000000?ook@0o`000?l000000_oonfX00ol0odKooo]ZoookJP0ZoookJP03
o`3oAOoonf[ooo]Z01Sooo]Z00?oocT0oookJ_oonfX00ooonfX00onbo`3ooo]ZoookJP04oookJP09
ojL0oooonf[oe?l0o`1Rool0F?ooR?l0oookJ_ooP03o0?7o00;ooo]Z00CoK_l0oookJ_oonf[o0?mU
0_oonfX00ol0oacooo]Zo`2Ho`02oookJP03of?o0?oonf[ooo]Z00;ooo]Z00?oo`3QoookJ_oonfX0
2ooonfX2oon707?ooo]Z000joookJP03od;o0?oonf[ooo]Z01[ooo]Z00?ofP3ooookJ_oonfX0AOoo
nfX00ol04?oooo]ZoookJP0aoookJP?o001o0ooonfX3o`00O`Wooo]Z0ol007l:oookJP?o001o1_oo
nfX00ol0003oobP0oolX0003oolX0003oookJ_l0odKooo]Z02[ooo]Z1Ooob@0IoookJP03ooli0?oo
nf[ooo]Z00?ooo]Z00?o/_l0oookJ_oonfX00onDo`002?oo04CoY`3oomCo0?l0H_oo05SoohSo0?m4
o`3ooh000_m4o`001OnDo`3oA?l0ofko0?oonf[o0?mU00?oU?l000?o0?lLo`2HoooonfX00_oonfX0
0omSo`3ooo]ZoookJP02oookJP03ool0hOoonf[ooo]Z00Wooo]Z1OoUo`2WoookJP03od;o0?oonf[o
oo]Z01[ooo]Z00?ofP3ooookJ_oonfX0AOoonfX00ol04?oooo]ZoookJP0aoookJP?o001o0ooonfX3
o`00O`Wooo]Z0ol007l:oookJP?o001o1_oonfX3o`000005oond0?oonf[ooo]ZoookJ_l0odH0;Ooo
nfX00ol0odGooo]ZoookJP0IoookJP03ooli0?oonf[ooo]Z00?ooo]Z00?o/_l0oookJ_oonfX00ooo
nfX02_oo04CoY`3ooookJ_oDo`3ok03oohSo0?oo>@3ooh00ool0Bol0lOl2oookJP04ofko0?oonf[o
oo]Zo`3oI@;ooo]Z00?o0?lLoookJ_l0V?l00_oonfX00omSo`3ooo]ZoookJP02oookJP03ool0hOoo
nf[ooo]Z00cooo]Z00?oohL0oookJ_oonfX0L?oonfX003Wooo]Z00?o@_l0oookJ_oonfX06_oonfX0
0ooJ0?oooo]ZoookJP15oookJP03o`0@oooonf[ooo]Z03;ooo]Z0ol007l3oookJP?o001o2_oonfX2
o`00O`Gooo]Z0_l007l2oookJPCo001o1_oonfX6oolX0003oookJ_l0odKooo]Z02Wooo]Z1_oob@0I
oookJP03ooli0?oonf[ooo]Z00?ooo]Z00Co/_l0oookJ_oonf[oU?l00_oonfX02Ooo^03oY`3ooook
J_oDo`3o06;oo`1Hoon8o`3oA?l0oon00003odCo0004ofko0?oonf[oU?l0o`3oI@?oU?l000Go0?lL
oookJ_oonf[ooo]Zof?o0005oookJP03ool0hOoonf[ooo]Z00Wooo]Z1_oUo`2ToookJP03od;o0?oo
nf[ooo]Z01_ooo]Z00?ofP3ooookJ_oonfX0A?oonfX00ol04?oooo]ZoookJP0boookJP?o001o0ooo
nfX3o`00O`[ooo]Z0_l007l5oookJP;o001o0_oonfX4o`00O`Kooo]Z0ol000001Ooo]03ooo]Zoook
J_oonf[o0?m602gooo]Z00?o0?m5oookJ_oonfX06OoonfX00ooo>@3ooo]ZoookJP03oookJP03ok;o
0?oonf[ooo]Z00Cooo]Z00WoY`3ooookJ_oDo`3o06;oo`1Hoon8o`3oocT0oon00?oo04/00_oonfX0
1Om^o`3ooo]ZoookJ_l0O?oo0?mU00;ooo]Z00?o0?lLo`2HoooonfX00_oonfX00omSo`3ooo]Zoook
JP02oookJP03ool0hOoonf[ooo]Z00cooo]Z00?oohL0oookJ_oonfX0KooonfX003Sooo]Z00?o@_l0
oookJ_oonfX06_oonfX00ooJ0?oooo]ZoookJP15oookJP03o`0@oooonf[ooo]Z03?ooo]Z0ol007l3
oookJP?o001o2_oonfX3o`00O`Cooo]Z1ol007l7oookJPKoobP000?o0?m6oookJ_oonfX0:OoonfX6
ooo901[ooo]Z00?oocT0oookJ_oonfX00_oonfX00onbo`3ooo]ZoookJP03oookJP0:oonh0?oo04Co
Y`3oomCo0?l0H_oo05SoohSo0?m4o`3oo`1;oon000?oA?l000CoK_l0oiCo0?nDo`3o0?mU0_nDo`00
0ol0oaco09SooookJP02oookJP03of?o0?oonf[ooo]Z00?ooo]Z00?oo`3QoookJ_oonfX02OoonfX8
onGo0:3ooo]Z00?o@_l0oookJ_oonfX06ooonfX00ooJ0?oooo]ZoookJP14oookJP03o`0@oooonf[o
oo]Z03?ooo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`Cooo]Z1ol007l7oookJP;o000000?ook@0
o`000?oonfX00_oonfX00ol0odKooo]ZoookJP0[oookJP03o`3oAOoonf[ooo]Z01[ooo]Z00?oocT0
oookJ_oonfX00_oonfX00onbo`3ooo]ZoookJP04oookJP0:ool0A?nW0?oooo]ZomCo0?l0H_ooR?l0
ooli0?oonf[ooh00o`3ao`;ooo]Z00WoK_l0oookJ_oonf[o07coo`3oIOoonf[o0?lLoookJ_l0V?l0
0ooonfX00omSo`3ooo]ZoookJP02oookJP03ool0hOoonf[ooo]Z00cooo]Z0_ooQ`1_oookJP00>?oo
nfX00om2o`3ooo]ZoookJP0JoookJP03omX0oooonf[ooo]Z04Gooo]Z00?o013ooookJ_oonfX0<ooo
nfX3o`00O`?ooo]Z0ol007l;oookJP;o001o1?oonfX6o`00O`Oooo]Z1ooo:0000ol0odKooo]Zoook
JP0YoookJPOoolT06OoonfX00ooo>@3ooo]ZoookJP03oookJP03ok;o0?oonf[ooo]Z00?ooo]Z00Wo
okP0ojL0oooonf[oe?l0o`1Rool0F?ooR?l0odCo0?ooP0001?m4o`000om^o`3oU?l0o`3oI@03oiCo
0003o`3o7?l0V?oooo]Z00;ooo]Z00?oHol0oookJ_oonfX00ooonfX00ooo0>7ooo]ZoookJP09oook
JPWoiOl0W_oonfX00om2o`3ooo]ZoookJP0JoookJP03omX0oooonf[ooo]Z04Gooo]Z00?o013ooook
J_oonfX0<ooonfX3o`00O`?ooo]Z0ol007l;oookJP;o001o1?oonfX6o`00O`Sooo]Z0_l000000ooo
]03o0000oookJP02oookJP03o`3oA_oonf[ooo]Z02_ooo]Z00?o0?m5oookJ_oonfX06_oonfX00ooo
>@3ooo]ZoookJP03oookJP03ok;o0?oonf[ooo]Z00Cooo]Z00[oY`3ooookJ_oDo`3o06;oo`1Hoon8
o`3oocT0oon00?oo04_o0?7o0_oonfX01?m^o`3ooo]ZoookJ_l0ofD2oookJP03o`3o7?oonf[o09So
00?ooo]Z00?oHol0oookJ_oonfX00_oonfX00ooo0>7ooo]ZoookJP0=oookJP03oon70?oonf[ooo]Z
06cooo]Z000goookJP03od;o0?oonf[ooo]Z01[ooo]Z00?ofP3ooookJ_oonfX0AOoonfX00ol04?oo
oo]ZoookJP0doookJP?o001o0ooonfX3o`00O`cooo]Z0_l007l3oookJP;o001o2ooonfX7oolX0003
o`3oA_oonf[ooo]Z02Wooo]Z1ooob@0IoookJP03ooli0?oonf[ooo]Z00?ooo]Z00?o/_l0oookJ_oo
nfX00ooonfX01ooo^03oo`14ojL0oooonf[oe?l0o`1Hoon8o`000_m4o`002?ooP03oA?l0odCo0?m4
o`3ooo]Zofko0?nDo`3o0?mU0onDo`000ol0oaco09SooookJP02oookJP03of?o0?oonf[ooo]Z00?o
oo]Z00?oo`3QoookJ_oonfX02OoonfX;onGo09[ooo]Z00?o@_l0oookJ_oonfX06ooonfX00ooJ0?oo
oo]ZoookJP14oookJP03o`0@oooonf[ooo]Z03Cooo]Z0ol007l3oookJP?o001o3?oonfX2o`00O`?o
oo]Z0_l007l<oookJP;o000000?ook@0o`000?oonfX00_oonfX00ol0odKooo]ZoookJP0[oookJP03
o`3oAOoonf[ooo]Z01[ooo]Z00?oocT0oookJ_oonfX00ooonfX00onbo`3ooo]ZoookJP04oookJP0:
ool0A?nW0?oooo]ZomCo0?l0H_oo05SoohSo0?oonf[ooh00ool0B`?ooo]Z00CoK_l0oookJ_oonf[o
0?mU0_oonfX00ol0oacooo]Zo`2Ho`03oookJP03of?o0?oonf[ooo]Z00;ooo]Z00?oo`3QoookJ_oo
nfX03OoonfX00oooQ`3ooo]ZoookJP1[oookJP00=_oonfX00om2o`3ooo]ZoookJP0JoookJP03omX0
oooonf[ooo]Z04Kooo]Z00?o013ooookJ_oonfX0=OoonfX3o`00O`04oookJ_l007oo001oo`00O`go
oo]Z0_l007l3oookJP;o001o2_oonfX8oolX0003o`3oA_oonf[ooo]Z02Wooo]Z1ooob@0JoookJP03
ooli0?oonf[ooo]Z00?ooo]Z00?o/_l0oookJ_oonfX00ooonfX02_oo^03oY`3ooookJ_oDo`3oolT0
o`1Hoon8o`3oA?l0ool0BoooP003odCo0004ofko0?nDo`3oU?l0o`3oI@?oU?l000?o0?lLo`2Hoooo
nfX00_oonfX00omSo`3ooo]ZoookJP03oookJP03ool0hOoonf[ooo]Z00Wooo]Z2ooUo`2HoookJP03
od;o0?oonf[ooo]Z01_ooo]Z00?ofP3ooookJ_oonfX0AOoonfX00ol04?oooo]ZoookJP0eoookJP?o
001o00Cooo]Zo`00Ool007oo001o3OoonfX2o`00O`?ooo]Z0_l007l<oookJP;o000000Gook@0o`00
0?oonf[ooo]Zo`3oAP0^oookJP03o`3oAOoonf[ooo]Z01_ooo]Z00?oocT0oookJ_oonfX00ooonfX0
0onbo`3ooo]ZoookJP04oookJP0:ool0A?nW0?ooe?l0oooR0?l0H_ooR?l0ooli0?n3o`3ooh00o`3a
o`?ooo]Z00CoK_l0oookJ_l0O?oo0?mU0_oonfX00ol0oacooo]Zo`2Ho`03oookJP03of?o0?oonf[o
oo]Z00;ooo]Z00?oo`3QoookJ_oonfX03OoonfX00oooQ`3ooo]ZoookJP1ZoookJP00=OoonfX00om2
o`3ooo]ZoookJP0JoookJP03omX0oooonf[ooo]Z04Kooo]Z00?o013ooookJ_oonfX0=_oonfX7o`00
O`Oooo]Z2Ol007l3oookJPOo001o1_oonfX00ol0003oobP0oolX0003oolX02_ooo]Z2Ooob@0Ioook
JP03ooli0?oonf[ooo]Z00?ooo]Z00?o/_l0oookJ_oonfX00ooonfX02_oo^03oo`14ojL0oooonf[o
e?l0o`1Hoom4o`3oR?l0odCo0?ooP004odCo0004ofko0?nDo`3oU?l0o`3oI@?oU?l000?o0?lLoiCo
0?oonfX00_oonfX00omSo`3ooo]ZoookJP03oookJP03ool0hOoonf[ooo]Z00Sooo]Z2ooUo`2Goook
JP03od;o0?oonf[ooo]Z01_ooo]Z00?ofP3ooookJ_oonfX0AOoonfX00ol04?oooo]ZoookJP0foook
JPOo001o1ooonfX9o`00O`?ooo]Z1ol007l6oookJP04o`000?oo]03o0000o`0000;ooo]Z00?o0?m6
oookJ_oonfX0;?oonfX00ol0odGooo]ZoookJP0KoookJP03ooli0?oonf[ooo]Z00?ooo]Z00?o/_l0
oookJ_oonfX01?oonfX02ooo04CoY`3ooookJ_oDo`3o06;oo`1Hoon8o`3ooo]Zoon00?oo04_o0?7o
00?ooo]Z00CoK_l0oookJ_l0O?oo0?mU0_oonfX00ol0oaco09SooookJP03oookJP03of?o0?oonf[o
oo]Z00;ooo]Z00?oo`3QoookJ_oonfX03OoonfX2oon706[ooo]Z000eoookJP03od;o0?oonf[ooo]Z
01[ooo]Z00?ofP3ooookJ_oonfX0A_oonfX00ol04?oooo]ZoookJP0goookJPGo001o2?oonfX9o`00
O`?ooo]Z1ol007l6oookJP04o`000?oo:03o0000o`0000;oobP0:ooonfX9ooo901Wooo]Z00?oocT0
oookJ_oonfX01?oonfX00onbo`3ooo]ZoookJP03oookJP07oonh0?oo04CoY`3oomCo0?m4o`3o05So
ohSo0002odCo0003oon00?m4o`3oU?l000;ooo]Z00CoK_l0oiCo0?nDo`3o0?mU0_nDo`000ol0oaco
09SooookJP03oookJP03of?o0?oonf[ooo]Z00?ooo]Z00?oo`3QoookJ_oonfX02?oonfX9onGo09So
oo]Z00?o@_l0oookJ_oonfX06_oonfX00ooJ0?oooo]ZoookJP16oookJP03o`0@oooonf[ooo]Z03Oo
oo]Z1Ol007l8oookJPWo001o0ooonfX7o`00O`Kooo]Z00Co0000oond0?l0003o00000_oonfX00ol0
odKooo]ZoookJP0/oookJP03o`3oAOoonf[ooo]Z01cooo]Z00?oocT0oookJ_oonfX00ooonfX00onb
o`3ooo]ZoookJP04oookJP0:ool0A?nW0?ooe?l0oooR0?l0H_oo05SoohSo0?oonf[ooh00ool0B`Co
oo]Z00SoK_l0oookJ_l0O?oo0?mUoookJ_l0oacooo]Zo`2Ho`Cooo]Z00?oHol0oookJ_oonfX00_oo
nfX00ooo0>7ooo]ZoookJP0>oookJP;oohL0J?oonfX003Cooo]Z00?o@_l0oookJ_oonfX06_oonfX0
0ooJ0?oooo]ZoookJP16oookJP03o`0@oooonf[ooo]Z05kooo]Z00Ko0000oond0?l0003o0000oook
J_l0odH[oookJPCoolT000?o0?m5oookJ_oonfX07?oonfX00ooo>@3ooo]ZoookJP03oookJP03ok;o
0?oonf[ooo]Z00?ooo]Z00_ookP0ool0A?nW0?ooA?l0omCo0?l0F?ooA?l0ohSo0?m4o`3oo`1;oon0
0003oookJP05oiCo0?m^o`3oU?l0oiCo0?l0ofD00_oonfX00ol0oaco09SooookJP03oookJP03of?o
0?oonf[ooo]Z00?ooo]Z00?oo`3QoookJ_oonfX02?oonfX7onGo0003oon70?oonf[ooo]Z09Gooo]Z
00?o@_l0oookJ_oonfX06ooonfX00ooJ0?oooo]ZoookJP15oookJP03o`0@oooonf[ooo]Z05kooo]Z
00Co0000oond0?l0003o00000_oonfX00ol0odKooo]ZoookJP0/oookJP03o`3oAOoonf[ooo]Z01co
oo]Z00?oocT0oookJ_oonfX00ooonfX00onbo`3ooo]ZoookJP04oookJP0;ool0A?oonf[oY`3oomCo
0?l0H_oo05SoohSo0?oo>@3oPol0oon00?l0lOl01?oonfX02?m^o`3ooo]Zo`1lool0ofGooo]Zo`3o
7?oonf[o09So1?oonfX00omSo`3ooo]ZoookJP02oookJP03ool0hOoonf[ooo]Z00oooo]Z00?oohL0
oookJ_oonfX0IOoonfX003?ooo]Z00?o@_l0oookJ_oonfX06_oonfX00ooJ0?oooo]ZoookJP16oook
JP03o`0@oooonf[ooo]Z05oooo]Z00Ko0000oond0?l0003o0000oookJ_l0odH_oookJP03o`3oAOoo
nf[ooo]Z01cooo]Z00?oocT0oookJ_oonfX01?oonfX00onbo`3ooo]ZoookJP03oookJP07oonh0?oo
04CoY`3oomCo0?m4o`3o05SoohSo0002odCo0007oon00?m4o`3ooo]ZoookJ_nDo`3oK_l0oiCo0002
oookJP05o`3oIOoonf[ooo]Zo`3o7?l0V?l01?oonfX00omSo`3ooo]ZoookJP03oookJP03ool0hOoo
nf[ooo]Z00Sooo]Z1OoUo`02oookJP;oohL0U?oonfX00om2o`3ooo]ZoookJP0KoookJP03omX0oooo
nf[ooo]Z04Gooo]Z00?o013ooookJ_oonfX0GooonfX01?l0003ook@0o`000?l00002oookJP03o`3o
A_oonf[ooo]Z02cooo]Z00?o0?m5oookJ_oonfX07?oonfX00ooo>@3ooo]ZoookJP04oookJP03ok;o
0?oonf[ooo]Z00Cooo]Z00_oo`14ojL0oooonf[oe?l0o`1Rool0F?ooR?l0oookJ_ooP03oo`1;o`3a
o`03oookJP09ofko0?oonf[ooo]Zo`1lool0ofGooo]Zo`3o7?oonf[o09So00?ooo]Z00?oHol0oook
J_oonfX00ooonfX00ooo0>7ooo]ZoookJP0?oookJP;oohL0IOoonfX003?ooo]Z00?o@_l0oookJ_oo
nfX06_oonfX00ooJ0?oooo]ZoookJP16oookJP03o`0@oooonf[ooo]Z05oooo]Z00Gook@0o`000?l0
003o0000o`3oAP0`oookJP03o`3oAOoonf[ooo]Z01cooo]Z00?oocT0oookJ_oonfX01?oonfX00onb
o`3ooo]ZoookJP03oookJP08oonh0?oo04CoY`3oooo90?oDo`3oA?l0o`1Hoon8o`02odCo0006oon0
0?m4o`3ooo]ZoookJ_nDo`3oK_l00_oonfX01_l0O?oo0?mUoookJ_oonf[o0?lLo`2Ho`Cooo]Z00?o
Hol0oookJ_oonfX00ooonfX2ool0h@Wooo]Z0ooUo`05oookJP;oohL0T_oonfX00om2o`3ooo]Zoook
JP0JoookJP03omX0oooonf[ooo]Z04Kooo]Z00?o013ooookJ_oonfX0GooonfX00ooo]03o0000o`00
0002o`000003o`3oA_oonf[ooo]Z02gooo]Z00?o0?m5oookJ_oonfX07OoonfX00ooo>@3ooo]Zoook
JP03oookJP03ok;o0?oonf[ooo]Z00Cooo]Z00_oo`14oookJ_nW0?ooe?l0o`1Rool0F?ooo`1oohSo
0?oonf[ooh00ool0B`04oookJP09ofko0?oonf[o07cooookJ_l0ofGooo]Zo`3o7?oonf[o09So00?o
oo]Z00?oHol0oookJ_oonfX00ooonfX2ool0hA7ooo]Z0_ooQ`1SoookJP00<_oonfX00om2o`3ooo]Z
oookJP0JoookJP03omX0oooonf[ooo]Z04Kooo]Z00?o013ooookJ_oonfX0H?oonfX01Ooo]03o0000
o`000?l0003o0?m6033ooo]Z00?o0?m5oookJ_oonfX07OoonfX00ooo>@3ooo]ZoookJP04oookJP03
ok;o0?oonf[ooo]Z00?ooo]Z00OookP0ool0A?nDo`3oe?l0odCo0?l0F?ooR?l000?oA?l000?ooh00
odCo0?oonfX00_oonfX01?m^o`3ooo]ZoookJ_l0ofD2oookJP03o`3o7?oonf[o09So00Cooo]Z00?o
Hol0oookJ_oonfX01?oonfX00ooo0>7ooo]ZoookJP07oookJP03onGo0?oonf[ooo]Z00Kooo]Z00?o
ohL0oookJ_oonfX0S_oonfX00om2o`3ooo]ZoookJP0KoookJP03omX0oooonf[ooo]Z04Gooo]Z00?o
013ooookJ_oonfX0H?oonfX01_oo]03o0000o`000?l0003ooo]Zo`3oARoooo]Z00?o0?m5oookJ_oo
nfX07OoonfX00ooo>@3ooo]ZoookJP04oookJP03ok;o0?oonf[ooo]Z00Cooo]Z00_oo`14oookJ_nW
0?ooe?l0o`1Rool0F?ooR?l0ooli0?n3o`3ooh00o`3ao`04oookJP04ofko0?oonf[o07coo`3oI@;o
oo]Z00?o0?lLoookJ_l0V?l00ooonfX00omSo`3ooo]ZoookJP04oookJP03ool0hOoonf[ooo]Z013o
oo]Z00?oohL0oookJ_oonfX0H?oonfX0037ooo]Z00?o@_l0oookJ_oonfX06_oonfX00ooJ0?oooo]Z
oookJP17oookJP03o`0@oooonf[ooo]Z063ooo]Z00Gook@0o`000?l0003o0000o`3oAP0aoookJP03
o`3oAOoonf[ooo]Z01cooo]Z00?oocT0oookJ_oonfX01?oonfX00onbo`3ooo]ZoookJP03oookJP08
oonh0?oo04CoU?l0ooo90?oDo`3oA?l0o`1Hoon8o`03odCo0003o`3aoooonf[ooo]Z00;ooo]Z00Co
K_l0oookJ_oonf[o0?mU0_oonfX00ol0oacooo]Zo`2Ho`04oookJP03of?o0?oonf[ooo]Z00Cooo]Z
00?oo`3QoookJ_oonfX04?oonfX2oon708gooo]Z00?o@_l0oookJ_oonfX06ooonfX00ooJ0?oooo]Z
oookJP16oookJP03o`0@oooonf[ooo]Z063ooo]Z00Kook@0o`000?l0003o0000oookJ_l0odH`oook
JP03o`3oAOoonf[ooo]Z01cooo]Z00?oocT0oookJ_oonfX01?oonfX00onbo`3ooo]ZoookJP04oook
JP0;ool0A?oonf[oY`3oomCo0?l0H_oo05Soool0Oon8o`3ooo]Zoon00?oo04/01OoonfX01?m^o`3o
oo]Zo`1lool0ofD2oookJP03o`3o7?oonf[o09So00?ooo]Z00?oHol0oookJ_oonfX01?oonfX00ooo
0>7ooo]ZoookJP0@oookJP;oohL0H?oonfX0033ooo]Z00?o@_l0oookJ_oonfX06_oonfX00ooJ0?oo
oo]ZoookJP17oookJP03o`0@oooonf[ooo]Z067ooo]Z00Gook@0o`000?l0003o0000o`3oAP0aoook
JP03o`3oAOoonf[ooo]Z01cooo]Z00?oocT0oookJ_oonfX01OoonfX00onbo`3ooo]ZoookJP03oook
JP08oonh0?nDo`3oU?l0omCo0?m4o`3o05SoodCo0?n8o`03odCo0003o`3aoooonf[ooo]Z00;ooo]Z
00CoK_l0oookJ_oonf[o0?mU0_oonfX00ol0oacooo]Zo`2Ho`04oookJP03of?o0?oonf[ooo]Z00Co
oo]Z00?oo`3QoookJ_oonfX04OoonfX2oon708[ooo]Z00?o@_l0oookJ_oonfX06ooonfX00ooJ0?oo
oo]ZoookJP16oookJP03o`0@oooonf[ooo]Z067ooo]Z00Gook@0o`000?l0003o0000o`3oAP0aoook
JP03o`3oAOoonf[ooo]Z01gooo]Z00?oocT0oookJ_oonfX01?oonfX00onbo`3ooo]ZoookJP04oook
JP0;ool0A?oonf[oY`3oomCo0?l0H_oo05Soon`0oon8o`3ooo]Zoon00?oo04/01OoonfX01?m^o`3o
oo]Zo`1lool0ofD2oookJP03o`3o7?oonf[o09So00?ooo]Z00?oHol0oookJ_oonfX01?oonfX00ooo
0>7ooo]ZoookJP0AoookJP;oohL0G_oonfX0033ooo]Z00?o@_l0oookJ_oonfX06_oonfX00ooJ0?oo
oo]ZoookJP17oookJP03o`0@oooonf[ooo]Z063ooo]Z00Gook@0o`000?l0003o0000o`3oAP0boook
JP03o`3oAOoonf[ooo]Z01cooo]Z00?oocT0oookJ_oonfX01OoonfX00onbo`3ooo]ZoookJP04oook
JP07ool0A?nDo`3oU?l0omCo0?m4o`3o05SoohSo0004odCo00Cooo]Z00GoK_l0oookJ_oonf[o07co
o`3oI@02oookJP03o`3o7?oonf[o09So00Cooo]Z00?oHol0oookJ_oonfX01?oonfX00ooo0>7ooo]Z
oookJP0BoookJP;oohL0R?oonfX00om2o`3ooo]ZoookJP0KoookJP03omX0oooonf[ooo]Z04Kooo]Z
00?o013ooookJ_oonfX0HOoonfX01Ooo]03o0000o`000?l0003o0?m6037ooo]Z00?o0?m5oookJ_oo
nfX07OoonfX00ooo>@3ooo]ZoookJP04oookJP03ok;o0?oonf[ooo]Z00Cooo]Z00coo`14oookJ_nW
0?oooo]ZomCo0?l0F?ooo`1oohSo0?oo>@3oPol0oon00?l0lOl4oookJP05ofko0?oonf[o07cooook
J_l0ofD00_oonfX00ol0oacooo]Zo`2Ho`03oookJP03of?o0?oonf[ooo]Z00Cooo]Z00?oo`3Qoook
J_oonfX04_oonfX2oon705cooo]Z000_oookJP03od;o0?oonf[ooo]Z01[ooo]Z00?ofP3ooookJ_oo
nfX0AooonfX00ol04?oooo]ZoookJP1QoookJP05oond0?l0003o0000o`000?l0odH0<_oonfX00ol0
odGooo]ZoookJP0MoookJP03ooli0?oonf[ooo]Z00Gooo]Z00?o/_l0oookJ_oonfX00ooonfX01?oo
^03oU?l0oiCo0?oDo`02odCo0006o`1Hoon8o`3oA?l0ooo90?ooP03o0?7o1?oonfX01Om^o`3ooo]Z
oookJ_l0O?oo0?mU00;ooo]Z00?o0?lLoookJ_l0V?l01?oonfX00omSo`3ooo]ZoookJP04oookJP03
ool0hOoonf[ooo]Z01?ooo]Z00?oohL0oookJ_oonfX0Q?oonfX00om2o`3ooo]ZoookJP0KoookJP03
omX0oooonf[ooo]Z04Kooo]Z00?o013ooookJ_oonfX0HOoonfX00ooo]03o0000o`000002o`000003
o`3oA_oonf[ooo]Z02oooo]Z00?o0?m5oookJ_oonfX07OoonfX00ooo>@3ooo]ZoookJP05oookJP03
ok;o0?oonf[ooo]Z00Cooo]Z00_oo`14oookJ_nW0?ooe?l0o`1Rool0F?ooo`1oohSo0?oonf[ooh00
ool0B`05oookJP05ofko0?oonf[o07cooookJ_l0ofD00_oonfX00ol0oacooo]Zo`2Ho`03oookJP03
of?o0?oonf[ooo]Z00Cooo]Z00?oo`3QoookJ_oonfX04ooonfX00oooQ`3ooo]ZoookJP1IoookJP00
;_oonfX00om2o`3ooo]ZoookJP0JoookJP03omX0oooonf[ooo]Z04Oooo]Z00?o013ooookJ_oonfX0
H_oonfX01Ooo]03o0000o`000?l0003o0?m603;ooo]Z00?o0?m5oookJ_oonfX07OoonfX00ooob@3o
oo]ZoookJP05oookJP03ok;o0?oonf[ooo]Z00Cooo]Z1?nDo`001?m4o`3o05SoodCo0?n8o`02ooo9
0003oon00?l0lOoooo]Z00?ooo]Z00GoK_l0oookJ_oonf[o07coo`3oI@02oookJP03o`3o7?oonf[o
09So00Cooo]Z00?oHol0oookJ_oonfX01?oonfX00ooo0>7ooo]ZoookJP0CoookJP;oohL0PooonfX0
0om2o`3ooo]ZoookJP0KoookJP03omX0oooonf[ooo]Z04Kooo]Z00?o013ooookJ_oonfX0H_oonfX0
1Ooo]03o0000o`000?l0003o0?m603;ooo]Z00?o0?m5oookJ_oonfX07_oonfX00ooo>@3ooo]Zoook
JP04oookJP03ok;o0?oonf[ooo]Z00Cooo]Z00coo`14oookJ_nW0?oooo]ZomCo0?l0F?ooo`1oohSo
0?oo>@3ooo]Zoon00?oo04/5oookJP04ofko0?oonf[o07coo`3oI@?ooo]Z00?o0?lLoookJ_l0V?l0
0ooonfX00omSo`3ooo]ZoookJP04oookJP03ool0hOoonf[ooo]Z01?ooo]Z0_ooQ`1IoookJP00;Ooo
nfX00om2o`3ooo]ZoookJP0KoookJP03omX0oooonf[ooo]Z04Oooo]Z00?o013ooookJ_oonfX0HOoo
nfX00ooo]03ooo]Zo`000002o`000003o`3oA_oonf[ooo]Z033ooo]Z00?o0?m5oookJ_oonfX07Ooo
nfX00ooob@3ooo]ZoookJP05oookJP03ok;o0?oonf[ooo]Z00Cooo]Z1OnDo`001ooob@3o05Soooo9
0?n8o`3oA?l0oon00?oo0?L01OoonfX01Om^o`3ooo]ZoookJ_l0O?oo0?mU00;ooo]Z00?o0?lLoook
J_l0V?l01?oonfX00omSo`3ooo]ZoookJP04oookJP03ool0hOoonf[ooo]Z01Cooo]Z0_ooQ`20oook
JP03od;o0?oonf[ooo]Z01_ooo]Z00?ofP3ooookJ_oonfX0AooonfX00ol04?oooo]ZoookJP1Roook
JP05oond0?l0003o0000o`000?l0odH0<_oonfX00ol0odGooo]ZoookJP0NoookJP03ooli0?oonf[o
oo]Z00Cooo]Z00?o/_l0oookJ_oonfX01OoonfX02ooo04Cooo]ZojL0oooDo`3o06;oo`1Hoooo07oo
R?l0oookJ_ooP03oo`1;00Kooo]Z00CoK_l0oookJ_l0O?oo0?mU0ooonfX00ol0oacooo]Zo`2Ho`03
oookJP;oHol01OoonfX00ooo0>7ooo]ZoookJP0DoookJP;oohL0EooonfX002gooo]Z00?o@_l0oook
J_oonfX06_oonfX00ooJ0?oooo]ZoookJP17oookJP03o`0@oooonf[ooo]Z06;ooo]Z00?ook@0oook
J_l000000_l000000ol0odKooo]ZoookJP0`oookJP03o`3oAOoonf[ooo]Z01gooo]Z0_oob@07oook
JP03ok;o0?oonf[ooo]Z00Cooo]Z1OnDo`000ol0F?ooo`1oohSo0002odCo0003oon00?l0lOoooo]Z
00?ooo]Z00KoK_l0oookJ_oonf[ooo]Zo`1lool0ofD2oookJP03o`3o7?l0V?oooo]Z00Cooo]Z00?o
Hol0oookJ_oonfX01?oonfX2ool0hAKooo]Z0_ooQ`1noookJP03od;o0?oonf[ooo]Z01_ooo]Z00?o
fP3ooookJ_oonfX0A_oonfX00ol04?oooo]ZoookJP1SoookJP05oond0?l0003o0000o`000?l0odH0
<_oonfX00ol0odGooo]ZoookJP0OoookJP03ooli0?oonf[ooo]Z00Cooo]Z00?o/_l0oookJ_oonfX0
1?oonfX03?oo^03oo`14ojL0oooonf[oe?l0o`1Hool[o`3oo`1oohSo0?oonf[ooh00ool0B`Gooo]Z
00GoK_l0oookJ_oonf[o07coo`3oI@03oookJP03o`3o7?l0V?oooo]Z00Cooo]Z00?oHol0oookJ_oo
nfX00ooonfX2ool0hAKooo]Z0_ooQ`1EoookJP00;?oonfX00om2o`3ooo]ZoookJP0JoookJP03omX0
oooonf[ooo]Z04Sooo]Z00?o013ooookJ_oonfX0H_oonfX01_oo]03ooo]Zo`000?l0003o0?m6o`00
03;ooo]Z00?o0?m5oookJ_oonfX07OoonfX3ooo900Kooo]Z00?o/_l0oookJ_oonfX01?oonfX6oiCo
0003o`1Hoooo07ooR?l000;oA?l000?ooh00o`3aoooonfX00ooonfX01_m^o`3ooo]ZoookJ_oonf[o
07coo`3oI@;ooo]Z00?o0?lLo`2HoooonfX01?oonfX00omSo`3ooo]ZoookJP05oookJP03ool0hOoo
nf[ooo]Z01Gooo]Z0_ooQ`1koookJP03od;o0?oonf[ooo]Z01_ooo]Z00?ofP3ooookJ_oonfX0Aooo
nfX00ol04?oooo]ZoookJP1SoookJP05oond0?l0003o0000o`000?l0odH0<_oonfX00ol0odGooo]Z
oookJP0OoookJP03ooli0?oonf[ooo]Z00Cooo]Z00?o/_l0oookJ_oonfX01OoonfX02?oo04CoY`3o
oookJ_oonf[oe?l0o`1Hoooo07ooR?l00_oonfX00oooP03o0?7ooookJP04oookJP05ofko0?oonf[o
oo]Zo`1lool0ofD00_oonfX00ol0oacooo]Zo`2Ho`05oookJP03of?o0?oonf[ooo]Z00Cooo]Z00?o
o`3QoookJ_oonfX05OoonfX2oon705?ooo]Z000[oookJP03od;o0?oonf[ooo]Z01[ooo]Z00?ofP3o
oookJ_oonfX0B?oonfX00ol04?oooo]ZoookJP1SoookJP06oond0?oonf[o0000o`000?l0odKo0000
<_oonfX00ol0odGooo]ZoookJP0MoookJP?oolT01_oonfX00onbo`3ooo]ZoookJP04oookJPOoU?l0
00Ko05Soool0f_n8o`3ooo]Zoon00?oo04/5oookJP05ofko0?oonf[ooo]ZoookJ_l0ofD00ooonfX0
0ol0oaco09SooookJP04oookJP03of?o0?oonf[ooo]Z00Gooo]Z00?oo`3QoookJ_oonfX05_oonfX2
oon707Sooo]Z00?o@_l0oookJ_oonfX06ooonfX00ooJ0?oooo]ZoookJP17oookJP03o`0@oooonf[o
oo]Z06?ooo]Z00Kook@0oookJ_l0003o0000o`3oA_l0000boookJP03o`3oAOoonf[ooo]Z01oooo]Z
00?oocT0oookJ_oonfX01OoonfX00onbo`3ooo]ZoookJP04oookJP0<oonh0?oo04CoY`3ooookJ_oD
o`3o06;oo`1Hoooo07ooR?l0oookJ_ooP03oo`1;1_oonfX01?m^o`3ooo]ZoookJ_l0ofD3oookJP03
o`3o7?oonf[o09So00Gooo]Z00?oHol0oookJ_oonfX01?oonfX2ool0hAOooo]Z0_ooQ`1AoookJP00
:_oonfX00om2o`3ooo]ZoookJP0KoookJP03omX0oooonf[ooo]Z04Oooo]Z00?o013ooookJ_oonfX0
HooonfX00ooo]03ooo]ZoookJP02o`000003o`3oA_l0003o0000037ooo]Z00?o0?m5oookJ_oonfX0
7_oonfX3ooo900Kooo]Z00?o/_l0oookJ_oonfX01?oonfX7oiCo0006ool0Oon8o`3oocT0oookJ_oo
P03o0?7o1OoonfX01Om^o`3ooo]ZoookJ_oonf[o0?mU00?ooo]Z00?o0?lLo`2HoooonfX01?oonfX0
0omSo`3ooo]ZoookJP05oookJP;oo`3Q6?oonfX2oon707Gooo]Z00?o@_l0oookJ_oonfX07?oonfX0
0ooJ0?oooo]ZoookJP16oookJP03o`0@oooonf[ooo]Z06Cooo]Z00Gook@0oookJ_l0003o0000o`3o
AP02o`00037ooo]Z00?o0?m5oookJ_oonfX08?oonfX00ooo>@3ooo]ZoookJP04oookJP03ok;o0?oo
nf[ooo]Z00Gooo]Z00coo`14ojL0oooonf[ooo]ZomCo0?l0F?ooo`1oohSo0?oo>@3ooo]Zoon00?oo
04/5oookJP05ofko0?oonf[ooo]ZoookJ_l0ofD00ooonfX00ol0oacooo]Zo`2Ho`05oookJP03of?o
0?oonf[ooo]Z00Gooo]Z00?oo`3QoookJ_oonfX05_oonfX3oon704kooo]Z000ZoookJP03od;o0?oo
nf[ooo]Z01[ooo]Z00?ofP3ooookJ_oonfX0B?oonfX00ol04?oooo]ZoookJP1SoookJP03oond0?oo
nf[ooo]Z00;o000000?o0?m6o`000?oonfX0<OoonfX00ol0odGooo]ZoookJP0NoookJPCoolT01Ooo
nfX00onbo`3ooo]ZoookJP04oookJPSoU?l000GoA?l0ohSo0?oonf[ooh00ool0B`06oookJP05ofko
0?oonf[ooo]ZoookJ_l0ofD00ooonfX00ol0oaco09SooookJP04oookJP03of?o0?oonf[ooo]Z00Ko
oo]Z00?oo`3QoookJ_oonfX05ooonfX2oon707?ooo]Z00?o@_l0oookJ_oonfX06ooonfX00ooJ0?oo
oo]ZoookJP17oookJP03o`0@oooonf[ooo]Z06Cooo]Z00Kook@0oookJ_l0003o0000o`3oA_l0000b
oookJP03o`3oAOoonf[ooo]Z023ooo]Z00?oocT0oookJ_oonfX01OoonfX00onbo`3ooo]ZoookJP04
oookJP0=oonh0?oo04CoY`3ooookJ_oDo`3o06;oo`1Hoooo07ooR?l0oookJ_ooP03oo`1;o`3ao`05
oookJP05ofko0?oonf[ooo]ZoookJ_l0ofD00ooonfX00ol0oacooo]Zo`2Ho`05oookJP03of?o0?oo
nf[ooo]Z00Gooo]Z00?oo`3QoookJ_oonfX06?oonfX2oon704cooo]Z000YoookJP03od;o0?oonf[o
oo]Z01[ooo]Z00?ofP3ooookJ_oonfX0B?oonfX00ol04?oooo]ZoookJP1ToookJP05oond0?oonf[o
oo]Zo`000?l0odH00_l0000boookJP03o`3oAOoonf[ooo]Z01kooo]Z1Ooob@04oookJP03ok;o0?oo
nf[ooo]Z00Cooo]Z2OnDo`001Ooo0=[oR?l0oookJ_ooP03oo`1;00Gooo]Z00GoK_l0oookJ_oonf[o
oo]Zo`3oI@04oookJP03o`3o7?l0V?oooo]Z00Cooo]Z00?oHol0oookJ_oonfX01_oonfX00ooo0>7o
oo]ZoookJP0HoookJP;oohL0L?oonfX00om2o`3ooo]ZoookJP0KoookJP03omX0oooonf[ooo]Z04Oo
oo]Z00?o013ooookJ_oonfX0IOoonfX01?oo]03ooo]Zo`000?l0odH2o`0003;ooo]Z00?o0?m5oook
J_oonfX08?oonfX00ooo>@3ooo]ZoookJP05oookJP03ok;o0?oonf[ooo]Z00Gooo]Z00gookP0ojL0
oooonf[ooo]ZomCo0?l0H_oo05Soool0Oon8o`3ooo]Zoon00?oo04_o0?7o00Gooo]Z00GoK_l0oook
J_oonf[o07coo`3oI@03oookJP03o`3o7?oonf[o09So00Gooo]Z00?oHol0oookJ_oonfX01OoonfX2
ool0hA[ooo]Z0_ooQ`1:oookJP00:?oonfX00om2o`3ooo]ZoookJP0KoookJP03omX0oooonf[ooo]Z
04Sooo]Z00?o013ooookJ_oonfX0I?oonfX01Ooo]03ooo]ZoookJ_l0003o0?m600;o0000<_oonfX0
0ol0odGooo]ZoookJP0NoookJPGoolT01OoonfX00onbo`3ooo]ZoookJP03oookJP[oU?l000GoR?l0
odCo0?n3o`3ooh00o`3ao`05oookJP05ofko0?oonf[ooo]ZoookJ_l0ofD01?oonfX00ol0oaco09So
oookJP04oookJP03of?o0?oonf[ooo]Z00Kooo]Z00?oo`3QoookJ_oonfX06OoonfX2oon706gooo]Z
00?o@_l0oookJ_oonfX06ooonfX00ooJ0?oooo]ZoookJP18oookJP03o`0@oooonf[ooo]Z06Gooo]Z
00Cook@0oookJ_l0003o0?m60_l0000boookJP03o`3oAOoonf[ooo]Z027ooo]Z00?oocT0oookJ_oo
nfX01?oonfX00onbo`3ooo]ZoookJP05oookJP09oonh0?oo04CoY`3ooookJ_oohP3oe?l0od<0ool0
F?ooR?l000;ooo]Z00?ooh00o`3aoooonfX01OoonfX01Om^o`3ooo]ZoookJ_l0O?oo0?mU00?ooo]Z
00?o0?lLoookJ_l0V?l01OoonfX00omSo`3ooo]ZoookJP06oookJP03ool0hOoonf[ooo]Z01Wooo]Z
0_ooQ`18oookJP00:?oonfX00om2o`3ooo]ZoookJP0JoookJP03omX0oooonf[ooo]Z04Sooo]Z00?o
013ooookJ_oonfX0I?oonfX01_oo]03ooo]ZoookJ_oonf[o0000o`3oAP;o0000<_oonfX00ol0odGo
oo]ZoookJP0NoookJPKoolT01?oonfX00onbo`3ooo]ZoookJP04oookJP[oU?l000CoR?l0odCo0?oo
P03oo`1;1_oonfX01Om^o`3ooo]ZoookJ_oonf[o0?mU00Cooo]Z00?o0?lLo`2HoooonfX01?oonfX2
of?o00Oooo]Z0_oUo`0KoookJP?oohL0J_oonfX00om2o`3ooo]ZoookJP0KoookJP03omX0oooonf[o
oo]Z04Oooo]Z00?o013ooookJ_oonfX0IOoonfX01Ooo]03ooo]ZoookJ_l0003o0?m600;o0000<_oo
nfX00ol0odGooo]ZoookJP0QoookJP03ooli0?oonf[ooo]Z00Gooo]Z00?o/_l0oookJ_oonfX01Ooo
nfX03Ooo^03oY`3ooookJ_oonf[oe?l0o`1Rool0F?ooo`1oohSo0?oonf[ooh00ool0Bol0lOl01Ooo
nfX01Om^o`3ooo]ZoookJ_oonf[o0?mU00Cooo]Z00?o0?lLoookJ_l0V?l01OoonfX2of?o00Oooo]Z
0_oo0>4KoookJP?oohL0AOoonfX002Oooo]Z00?o@_l0oookJ_oonfX06_oonfX00ooJ0?oooo]Zoook
JP19oookJP03o`0@oooonf[ooo]Z06Cooo]Z00Koo`00oookJ_oonf[ooo]Zo`000?l0odH2o`0003;o
oo]Z00?o0?m5oookJ_oonfX07_oonfX7ooo900?ooo]Z00?o/_l0oookJ_oonfX01?oonfX00onDo`3o
oo]Zoonh0008oiCo00;oA?l000?ooh00ool0BooonfX01OoonfX01Om^o`3ooo]ZoookJ_oonf[o0?mU
00Cooo]Z00?o0?lLo`2HoooonfX01OoonfX00omSo`3ooo]ZoookJP04oookJPGoiOl06ooonfX3oon7
06Kooo]Z00?o@_l0oookJ_oonfX06ooonfX00ooJ0?oooo]ZoookJP18oookJP03o`0@oooonf[ooo]Z
06Gooo]Z00Gook@0oookJ_oonf[o0000o`3oAP02o`0003?ooo]Z00?o0?m5oookJ_oonfX08?oonfX0
0ooo>@3ooo]ZoookJP05oookJP03ok;o0?oonf[ooo]Z00Gooo]Z00?ookP0ool0A?nW0?l00_oonfX0
2OoDo`3oO_l0o`1Hoon8o`3oo`3JoookJ_ooP03oo`1;o`3ao`05oookJP05ofko0?oonf[ooo]Zoook
J_l0ofD01?oonfX00ol0oacooo]Zo`2Ho`06oookJP03of?o0?oonf[ooo]Z00Kooo]Z00?oo`3Qoook
J_oonfX06ooonfX3oon704;ooo]Z000VoookJP03od;o0?oonf[ooo]Z01_ooo]Z00?ofP3ooookJ_oo
nfX0B?oonfX00ol04?oooo]ZoookJP1UoookJP05ool00?oonf[ooo]ZoookJ_l0odH00ol0000boook
JP03o`3oAOoonf[ooo]Z01kooo]Z1ooob@04oookJP03ok;o0?oonf[ooo]Z00Kooo]Z2OnDo`02odCo
0003oon00?oonf[ooo]Z00Gooo]Z0_nDo`000ooonf[o0?mUo`1lo`04oookJP;oiOl01_oonfX00omS
o`3ooo]ZoookJP04oookJPKoiOl07?oonfX3oon706;ooo]Z00?o@_l0oookJ_oonfX06ooonfX00ooJ
0?oooo]ZoookJP18oookJP03o`0@oooonf[ooo]Z06Kooo]Z00Cook@0oookJ_oonf[o0?m60ol0000c
oookJP03o`3oAOoonf[ooo]Z027ooo]Z00?oocT0oookJ_oonfX01OoonfX00onbo`3ooo]ZoookJP05
oookJP09oonh0?nW0?oooo]ZoookJ_oDo`3o06;oob_o0?l0F?ooR?l000;ooo]Z00?ooh00ool0mooo
nfX01OoonfX01Om^o`3ooo]ZoookJ_oonf[o0?mU00Cooo]Z00?o0?lLoookJ_l0V?l01_oonfX00omS
o`3ooo]ZoookJP06oookJP03ool0hOoonf[ooo]Z01gooo]Z0_ooQ`10oookJP009OoonfX00om2o`3o
oo]ZoookJP0KoookJP03omX0oooonf[ooo]Z04Sooo]Z00?o013ooookJ_oonfX0IOoonfX2ool000?o
oo]Z00Co0?m6o`000?l0003o0000<_oonfX00ol0odGooo]ZoookJP0NoookJPSoolT00ooonfX00onb
o`3ooo]ZoookJP06oookJPSoU?l000Gok03oohSo0?m4o`3oA?l0oon00006oookJP?oU?l000?ooo]Z
o`3oIOoonfX00ooonfX3onGo00Kooo]Z00?oHol0oookJ_oonfX01?oonfX8onGo01cooo]Z0oooQ`1N
oookJP03od;o0?oonf[ooo]Z01_ooo]Z00?ofP3ooookJ_oonfX0B?oonfX00ol04?oooo]ZoookJP1W
oookJP04oond0?oonf[ooo]Zo`3oAP?o0000<ooonfX00ol0odGooo]ZoookJP0QoookJP03ooli0?oo
nf[ooo]Z00Gooo]Z00?o/_l0oookJ_oonfX01_oonfX02Ooo04CoY`3ooookJ_oonf[oe?l0o`1Rool0
F?ooo`1oohSo0002oookJP03oon00?l0lOoooo]Z00Cooo]Z00KoK_l0oookJ_oonf[ooo]Zo`1lool0
ofD4oookJP03o`3o7?oonf[o09So00Kooo]Z00?oHol0oookJ_oonfX01_oonfX00ooo0>7ooo]Zoook
JP0NoookJP?oohL0?OoonfX004;ooo]Z00?ofP3ooookJ_oonfX0BOoonfX00ol04?oooo]ZoookJP1T
oookJP?oo`000ooonfX01?l0odKo0000o`000?l0000boookJP03o`3oAOoonf[ooo]Z01oooo]Z2?oo
b@02oookJP03ok;o0?oonf[ooo]Z00Kooo]Z1OnDo`001OoohP3o06;ooiCo0?nDo`3oR?l000;oA?l0
00?ooh00ool0BooonfX01OoonfX3oiCo0003oookJ_l0ofGooo]Z00?ooo]Z1?oUo`05oookJP;oHol0
1OoonfX9onGo01gooo]Z0_ooQ`1joookJP03omX0oooonf[ooo]Z04Sooo]Z00?o013ooookJ_oonfX0
I_oonfX01Ooo]03ooo]ZoookJ_oonf[o0?m600?o0000<ooonfX00ol0odGooo]ZoookJP0QoookJP03
ooli0?oonf[ooo]Z00Gooo]Z00?o/_l0oookJ_oonfX01_oonfX03_oo^03oo`14ojL0oooonf[oe?l0
o`1Room30?oo05SoohSo0?oo0=[ooo]Zoon00?oo04_o0?7o1OoonfX01_m^o`3ooo]ZoookJ_oonf[o
07coo`3oI@Cooo]Z00?o0?lLoookJ_l0V?l01_oonfX00omSo`3ooo]ZoookJP06oookJP;oo`3Q8Ooo
nfX3oon703[ooo]Z0011oookJP03omX0oooonf[ooo]Z04Wooo]Z00?o013ooookJ_oonfX0IOoonfX3
ool000?ooo]Z00Co0?m6o`000?l0003o0000<_oonfX00ol0odGooo]ZoookJP0OoookJPKoolT01Ooo
nfX00onbo`3ooo]ZoookJP06oookJPCoU?l000?oe?l0o`1RoonDo`000_nDo`001On8o`3oA?l0odCo
0?ooP03oo`1;00Gooo]Z1OnDo`001?l0ofGooo]ZoookJ_oonfX5onGo00Kooo]Z00?oHol0oookJ_oo
nfX00ooonfX;onGo01cooo]Z0oooQ`1foookJP03omX0oooonf[ooo]Z04Sooo]Z00?o013ooookJ_oo
nfX0IooonfX01Ooo]03ooo]ZoookJ_oonf[o0?m600?o0000<ooonfX00ol0odGooo]ZoookJP0Qoook
JP03ooli0?oonf[ooo]Z00Kooo]Z00?o/_l0oookJ_oonfX01_oonfX02Ooo04CoY`3ooookJ_oonf[o
e?l0o`1Rool0F?ooo`1oohSo0002oookJP03oon00?oo04_ooo]Z00Gooo]Z00GoK_l0oookJ_oonf[o
oo]Zo`3oI@05oookJP03o`3o7?oonf[o09So00Kooo]Z00?oHol0oookJ_oonfX01ooonfX00ooo0>7o
oo]ZoookJP0QoookJP?oohL0=ooonfX0047ooo]Z00?ofP3ooookJ_oonfX0BOoonfX00ol04?oooo]Z
oookJP1ToookJPCoo`000_oonfX00ol0odKo0000o`000002o`0003;ooo]Z00?o0?m5oookJ_oonfX0
7ooonfX3ooo90003ooli0?oonf[ooo]Z00Gooo]Z00?o/_l0oookJ_oonfX01_oonfX01_nDo`3oo`14
oiCo0?nW0?ooe?l0oooR00?oU?l000KoR?l0odCo0?m4o`3oA?l0oon00?l0lOl5oookJPGoU?l000Co
0?mUoookJ_oonf[ooo]Z1_oUo`05oookJP03of?o0?oonf[ooo]Z00?ooo]Z2ooUo`0NoookJP?oohL0
L_oonfX00ooJ0?oooo]ZoookJP19oookJP03o`0@oooonf[ooo]Z06Oooo]Z00Cook@0oookJ_oonf[o
0?m61?l0000coookJP03o`3oAOoonf[ooo]Z02;ooo]Z00?oocT0oookJ_oonfX01OoonfX00onbo`3o
oo]ZoookJP06oookJP0:oonh0?oo04CoY`3ooookJ_oDo`3oon80o`1Rool0F?ooR?l0ool0fP;ooo]Z
00?ooh00o`3aoooonfX01OoonfX01Om^o`3ooo]ZoookJ_oonf[o0?mU00Gooo]Z00?o0?lLoookJ_l0
V?l01_oonfX00omSo`3ooo]ZoookJP07oookJP03ool0hOoonf[ooo]Z02?ooo]Z0oooQ`0doookJP00
@?oonfX00ooJ0?oooo]ZoookJP19oookJP03o`0@oooonf[ooo]Z06Gooo]Z1?oo0002oookJP03o`3o
A_l0003o000000?o0000<OoonfX00ol0odGooo]ZoookJP0OoookJP04ooo90?oonf[ooo]Zooli00So
oo]Z00?o/_l0oookJ_oonfX01ooonfX01OnDo`3oY`3ooiCo0?oDo`3oon8000?oU?l000GoR?l0odCo
0?n3o`3ooh00ool0B`05oookJPKoU?l000?o0?mUoookJ_oonfX01ooUo`05oookJP03of?o0?oonf[o
oo]Z00;ooo]Z2ooUo`0QoookJP?oohL0KooonfX00ooJ0?oooo]ZoookJP18oookJP03o`0@oooonf[o
oo]Z06Oooo]Z00Gook@0oookJ_oonf[ooo]Zo`3oAP05o`0003;ooo]Z00?o0?m5oookJ_oonfX08_oo
nfX00ooo>@3ooo]ZoookJP06oookJP03ok;o0?oonf[ooo]Z00Kooo]Z00koo`14ojL0oooonf[ooo]Z
omCo0?l0H_oo05Soool0Oon8o`3oocT0oookJ_ooP03oo`1;o`3ao`Kooo]Z00GoK_l0oookJ_oonf[o
oo]Zo`3oI@05oookJP03o`3o7?oonf[o09So00Kooo]Z00?oHol0oookJ_oonfX01ooonfX00ooo0>7o
oo]ZoookJP0UoookJP?oohL0<OoonfX003oooo]Z00?ofP3ooookJ_oonfX0BOoonfX00ol04?oooo]Z
oookJP1UoookJPGoo`000_oonfX00ol0odKo0000o`000002o`0003;ooo]Z00?o0?m5oookJ_oonfX0
8_oonfX00ooo>@3ooo]ZoookJP06oookJP03ok;o0?oonf[ooo]Z00Oooo]Z00Goo`14oiCo0?nW0?oo
oo]ZomCo0004oiCo0005ohSo0?m4o`3oPol0oon00?oo04/01?oonfX8oiCo00;ooo]Z1ooUo`05oook
JP;oHol00ooonfX9onGo02Gooo]Z0oooQ`1[oookJP03omX0oooonf[ooo]Z04Sooo]Z00?o013ooook
J_oonfX0J?oonfX01Ooo]03ooo]ZoookJ_oonf[o0?m600Co0000<ooonfX00ol0odGooo]ZoookJP0R
oookJP03ooli0?oonf[ooo]Z00Kooo]Z00?o/_l0oookJ_oonfX01_oonfX02_oo^03oo`14ojL0oooo
nf[oo`16omCo0?l0H_oo05Soool0Oon8o`02oookJP03oon00?oo04_o0?7o00Gooo]Z00KoK_l0oook
J_oonf[ooo]Zo`1lool0ofD5oookJP03o`3o7?oonf[o09So00Kooo]Z0_mSo`08oookJP;oo`3Q:?oo
nfX3oon702kooo]Z000ooookJP03omX0oooonf[ooo]Z04Wooo]Z00?o013ooookJ_oonfX0I?oonfX6
ool000;ooo]Z00?o0?m6o`000?l000000_l0000boookJP03o`3oAOoonf[ooo]Z02?ooo]Z00?oocT0
oookJ_oonfX01_oonfX00onbo`3ooo]ZoookJP07oookJP04oiCo0?nW0?oooo]ZomCo00CoU?l000Ko
R?l0oiCo0?m4o`3oPol0oon00?l0lOl4oookJPSoU?l000?ooo]ZonGo0?oUo`001ooUo`05oookJP04
of?o0?oonf[ooo]ZoookJPOoiOl0:OoonfX3oon706Oooo]Z00?ofP3ooookJ_oonfX0BOoonfX00ol0
4?oooo]ZoookJP1XoookJP05oond0?oonf[ooo]ZoookJ_l0odH01?l0000coookJP03o`3oAOoonf[o
oo]Z02?ooo]Z00?oocT0oookJ_oonfX01_oonfX00onbo`3ooo]ZoookJP06oookJP0:ool0A?nW0?oo
oo]ZoookJ_oDo`3o06;oob_o0?l0F?ooR?l0ooli00;ooo]Z00?ooh00o`3aoooonfX01OoonfX01_m^
o`3ooo]ZoookJ_oonf[o07coo`3oI@Gooo]Z00?o0?lLoookJ_l0V?l01ooonfX00omSo`3ooo]Zoook
JP07oookJP03ool0hOoonf[ooo]Z02Sooo]Z0oooQ`0[oookJP00?_oonfX00ooJ0?oooo]ZoookJP19
oookJP03o`0@oooonf[ooo]Z06Gooo]Z1_oo00000ooonf[o0?m6oookJP04o`0003;ooo]Z00?o0?m5
oookJ_oonfX08ooonfX00ooo>@3ooo]ZoookJP06oookJP03ok;o0?oonf[ooo]Z00Oooo]Z00Goo`14
oookJ_nW0?oooo]ZomCo0004oiCo0006ohSo0?nDo`3oPol0oon00?oo04_o0?7o0ooonfX9oiCo0003
oookJ_oUo`3oiOl000OoiOl01OoonfX01?mSo`3ooo]ZoookJ_oonfX5onGo0003oookJ_oo0>7ooo]Z
02[ooo]Z0oooQ`1SoookJP03omX0oooonf[ooo]Z04Wooo]Z00?o013ooookJ_oonfX0J?oonfX01_oo
]03ooo]ZoookJ_oonf[o0?m6oookJPCo0000<ooonfX00ol0odGooo]ZoookJP0SoookJP03ooli0?oo
nf[ooo]Z00Kooo]Z00?o/_l0oookJ_oonfX01_oonfX03ooo^03oo`14ojL0oooonf[oo`16omCo0?l0
H_oo05Soool0Oon8o`3oocT0oookJ_ooP03oo`1;o`3ao`06oookJP06ofko0?oonf[ooo]ZoookJ_l0
O?oo0?mU1OoonfX00ol0oacooo]Zo`2Ho`07oookJP03of?o0?oonf[ooo]Z00Oooo]Z00?oo`3Qoook
J_oonfX0:_oonfX3oon702Sooo]Z000moookJP03omX0oooonf[ooo]Z04[ooo]Z00?o013ooookJ_oo
nfX0I?oonfX7ool00003oookJ_l0odKooo]Z00Co0000<_oonfX00ol0odGooo]ZoookJP0SoookJP03
ooli0?oonf[ooo]Z00Kooo]Z00?o/_l0oookJ_oonfX01ooonfX01Ooo04CookP0ojL0oooonf[oe?l0
00GoU?l000KoR?l0oiCo0?n3o`3ooh00ool0Bol0lOl3oookJPWoU?l02_oUo`05oookJP04of?o0?oo
nf[ooo]ZoookJP?oiOl00ooonfX2ool0hBcooo]Z1?ooQ`1OoookJP03omX0oooonf[ooo]Z04Wooo]Z
00?o013ooookJ_oonfX0J?oonfX01_oo]03ooo]ZoookJ_oonf[o0?m6oookJPCo0000<ooonfX00ol0
odGooo]ZoookJP0SoookJP03ooli0?oonf[ooo]Z00Kooo]Z00?o/_l0oookJ_oonfX01ooonfX02_oo
04CoY`3ooookJ_oonf[oe?l0oooR0?l0H_oo05Soon`0oon8o`02oookJP03oon00?oo04_o0?7o00Ko
oo]Z00KoK_l0oookJ_oonf[ooo]Zo`1lool0ofD5oookJP03o`3o7?oonf[o09So00Oooo]Z00?oHol0
oookJ_oonfX01ooonfX2ool0hBgooo]Z1?ooQ`0ToookJP00?OoonfX00ooJ0?oooo]ZoookJP19oook
JP03o`0@oooonf[ooo]Z06Gooo]Z1ooo00000ooonf[o0?m6oookJP04o`0003;ooo]Z00?o0?m5oook
J_oonfX09?oonfX00ooo>@3ooo]ZoookJP06oookJP03ok;o0?oonf[ooo]Z00Oooo]Z00Goo`14oook
J_nW0?oooo]ZomCo0004oiCo0006ohSo0?nDo`3oU?l0oh?o0?ooP03o0?7o0ooonfX7oiCo0003oook
J_l0O?oo0?mU00OoiOl000?o09SooookJ_oonfX01OoonfX01OmSo`3ooo]ZoookJ_oonf[oiOl000Ko
oo]Z00?oo`3QoookJ_oonfX0;OoonfX3oon705_ooo]Z00?ofP3ooookJ_oonfX0BOoonfX00ol04?oo
oo]ZoookJP1YoookJP06oond0?oonf[ooo]ZoookJ_l0odKooo]Z1?l0000coookJP03o`3oAOoonf[o
oo]Z02Cooo]Z00?oocT0oookJ_oonfX01_oonfX00onbo`3ooo]ZoookJP06oookJP03oonh0?oo04Co
Y`3o00;ooo]Z00Koe?l0o`1Rool0F?ooo`1oohSo0?oo>@02oookJP03oon00?oo04_ooo]Z00Kooo]Z
00KoK_l0oookJ_oonf[ooo]Zo`1lool0ofD4oookJP04o`3o7?oonf[ooo]Zo`2Ho`Oooo]Z00?oHol0
oookJ_oonfX02?oonfX00ooo0>7ooo]ZoookJP0^oookJP?oohL08OoonfX003cooo]Z00?ofP3ooook
J_oonfX0BOoonfX00ol04?oooo]ZoookJP1UoookJPSoo`0000?ooo]Zo`3oA_oonfX01?l0000boook
JP03o`3oAOoonf[ooo]Z02Cooo]Z00?oocT0oookJ_oonfX01_oonfX00onbo`3ooo]ZoookJP07oook
JP05ool0A?oo^03oY`3ooookJ_oDo`001OnDo`001_n8o`3oU?l0oiCo0?ooP03oo`1;o`3ao`?ooo]Z
1OnDo`03oookJP03o`1loooUo`3oiOl000CoiOl00_oonfX00ol0V?oooo]ZoookJP05oookJP03of?o
0?oonf[ooo]Z00Sooo]Z0_oo0>4`oookJP;oohL0F?oonfX00ooJ0?oooo]ZoookJP19oookJP03o`0@
oooonf[ooo]Z06[ooo]Z00Kook@0oookJ_oonf[ooo]Zo`3oA_oonfX4o`0003?ooo]Z00?o0?m5oook
J_oonfX09?oonfX00ooo>@3ooo]ZoookJP06oookJP03ok;o0?oonf[ooo]Z00Oooo]Z00ooo`14ojL0
oooonf[ooo]ZomCo0?oohP3o06;oo`1Hoooo07ooR?l0ooli0?oonf[ooh00ool0Bol0lOl01_oonfX0
0om^o`3ooo]ZoookJP02oookJP03o`1lool0ofGooo]Z00?ooo]Z00Co0?lLoookJ_oonf[o09So1ooo
nfX00omSo`3ooo]ZoookJP08oookJP;oo`3Q<OoonfX2oon701oooo]Z000koookJP03omX0oooonf[o
oo]Z04[ooo]Z00?o013ooookJ_oonfX0I?oonfX9ool00003o`3oA_oonf[ooo]Z00Co0000<_oonfX0
0ol0odGooo]ZoookJP0ToookJP03ooli0?oonf[ooo]Z00Oooo]Z00?o/_l0oookJ_oonfX01ooonfX0
1Ooo04Cooo]ZojL0oooonf[oe?l000CoU?l000OoR?l0ooli0?oonf[oPol0oon00?oo04_o0?7o00;o
oo]Z1?nDo`000om^o`3ooo]ZoookJP02oookJP03o`3oIOoUo`3oiOl000;oiOl000Gooo]Zo`3o7?oo
nf[ooo]Zo`2Ho`07oookJP03of?o0?oonf[ooo]Z00Wooo]Z00?oo`3QoookJ_oonfX0Q_oonfX00ooJ
0?oooo]ZoookJP1:oookJP03o`0@oooonf[ooo]Z06Wooo]Z00Gook@0oookJ_oonf[ooo]Zo`3oAP02
oookJPCo0000<ooonfX00ol0odGooo]ZoookJP0ToookJP03ooli0?oonf[ooo]Z00Oooo]Z00?o/_l0
oookJ_oonfX01_oonfX00ooo^03oo`14ojL0o`02oookJP06omCo0?l0H_oo05Soool0Oon8o`3oocT0
0_oonfX00oooP03oo`1;o`3ao`06oookJP03ofko0?oonf[ooo]Z00;ooo]Z00?o0?mUoookJ_oonfX0
0ooonfX01?l0oacooo]ZoookJ_l0V?l7oookJP03of?o0?oonf[ooo]Z00Wooo]Z00?oo`3QoookJ_oo
nfX0CooonfX003_ooo]Z00?ofP3ooookJ_oonfX0BOoonfX00ol04?oooo]ZoookJP1XoookJPKoo`00
00?o0?m6oookJ_oonfX01?l0000boookJP03o`3oAOoonf[ooo]Z02Gooo]Z00?oocT0oookJ_oonfX0
1_oonfX00onbo`3ooo]ZoookJP07oookJP05ool0A?oo^03oY`3ooookJ_oDo`001?nDo`001om4o`3o
R?l0ooli0?oonf[ooh00ool0Bol0lOl00_oonfX3oiCo00;ooo]Z00?oK_l0oookJ_oonfX00_oonfX3
onGo00?ooo]Z00Co0?lLoookJ_oonf[o09So1ooonfX00omSo`3ooo]ZoookJP09oookJP03ool0hOoo
nf[ooo]Z08Gooo]Z00?ofP3ooookJ_oonfX0BOoonfX00ol04?oooo]ZoookJP1ZoookJP05oond0?oo
nf[ooo]ZoookJ_l0odH00_oonfX4o`0003?ooo]Z00?o0?m5oookJ_oonfX09OoonfX00ooo>@3ooo]Z
oookJP06oookJP03ok;o0?oonf[ooo]Z00Oooo]Z013oo`14ojL0oooonf[ooo]ZomCo0?oohP3o06;o
o`1Hoooo07ooR?l0ooli0?oonf[ooh00oh?o0?oo04_o0?7o1_oonfX00om^o`3ooo]ZoookJP02oook
JP03o`3oIOoonf[ooo]Z00?ooo]Z00Co0?lLoookJ_oonf[o09So1ooonfX00omSo`3ooo]ZoookJP09
oookJP03ool0hOoonf[ooo]Z04kooo]Z000joookJP03omX0oooonf[ooo]Z04[ooo]Z00?o013ooook
J_oonfX0JOoonfX00ooo003ooo]ZoookJP02ool00003o`3oA_oonf[ooo]Z00Co0000<_oonfX00ol0
odGooo]ZoookJP0UoookJP03ooli0?oonf[ooo]Z00Kooo]Z00?o/_l0oookJ_oonfX02?oonfX04?oo
04Cooo]ZojL0oooonf[oe?l0oiCo0?l0H_oo05Soool0Oom4o`3oR?l0ooli0?oonf[ooh00ool0Bol0
lOl2oookJP03oiCo0?oonf[ooo]Z00;ooo]Z00?oK_l0oookJ_oonfX00_oonfX00ooUo`3ooo]Zoook
JP03oookJP04o`3o7?oonf[ooo]Zo`2Ho`Oooo]Z00?oHol0oookJ_oonfX02OoonfX2ool0hHCooo]Z
00?ofP3ooookJ_oonfX0B_oonfX00ol04?oooo]ZoookJP1ZoookJP05oond0?oonf[ooo]ZoookJ_l0
odH00_oonfX4o`0003?ooo]Z00?o0?m5oookJ_oonfX09OoonfX00ooo>@3ooo]ZoookJP06oookJP03
ok;o0?oonf[ooo]Z00Oooo]Z00?ookP0ool0A?nW0?l00_oonfX02ooDo`3o06;oo`1Hoooo07ook03o
ohSo0?oo>@3ooo]Zoon00?oo04_o0?7o00Oooo]Z00?oK_l0oookJ_oonfX00_oonfX00ol0ofGooo]Z
oookJP03oookJP04o`3o7?oonf[ooo]Zo`2Ho`Oooo]Z00?oHol0oookJ_oonfX02OoonfX2ool0hDko
oo]Z000ioookJP03omX0oooonf[ooo]Z04[ooo]Z00?o013ooookJ_oonfX0JOoonfX00ooo003ooo]Z
oookJP03oookJP03o`3oA_oonf[ooo]Z00Go0000<OoonfX00ol0odGooo]ZoookJP0UoookJP03ooli
0?oonf[ooo]Z00Oooo]Z00?o/_l0oookJ_oonfX02?oonfX04?oo04CoY`3ooookJ_nDo`3oe?l0o`1R
oom30?oo05SoodCo0?n8o`3oA?l0oookJ_n3o`3ooh00oookJ_l0lOl7oookJP06ofko0?oonf[ooo]Z
oookJ_l0O?oo0?mU1OoonfX01?l0oacooo]ZoookJ_l0V?l7oookJP;oHol02ooonfX00ooo0>7ooo]Z
oookJP20oookJP03omX0oooonf[ooo]Z04[ooo]Z00?o013ooookJ_oonfX0J_oonfX00ooo]03ooo]Z
oookJP02oookJP03o`3oA_oonf[ooo]Z00Go0000<_oonfX00ol0odGooo]ZoookJP0UoookJP03ooli
0?oonf[ooo]Z00Oooo]Z00?o/_l0oookJ_oonfX01ooonfX02ooo04CoY`3ooookJ_oonf[oe?l0oooR
0?l0H_oo05Soool0Oon8o`3oocT000;ooo]Z00?ooh00ool0Bol0lOl01ooonfX01_m^o`3ooo]Zoook
J_oonf[o07coo`3oI@Gooo]Z00Co0?lLoookJ_oonf[o09So1ooonfX2of?o00_ooo]Z00?oo`3Qoook
J_oonfX0BooonfX003Sooo]Z00?ofP3ooookJ_oonfX0B_oonfX00ol04?oooo]ZoookJP1ZoookJP03
ool00?oonf[ooo]Z00;ooo]Z00Co0?m6oookJ_oonf[ooo]Z1?l0000boookJP03o`3oAOoonf[ooo]Z
02Kooo]Z00?oocT0oookJ_oonfX01_oonfX00onbo`3ooo]ZoookJP08oookJP0@ool0A?oonf[oY`3o
oookJ_oDo`3oon80o`1Room4o`3o05SoodCo0?n8o`3oA?l0oookJ_ooP03oo`1;o`3ao`Oooo]Z00?o
K_l0oookJ_oonfX00_oonfX00ol0O?oo0?mUoookJP04oookJP04o`3o7?oonf[ooo]Zo`2Ho`Sooo]Z
00?oHol0oookJ_oonfX02OoonfX2ool0hH3ooo]Z00?ofP3ooookJ_oonfX0BOoonfX00ol04?oooo]Z
oookJP1[oookJP05oond0?oonf[ooo]ZoookJ_l0odH00ooonfX4o`0003?ooo]Z00?o0?m5oookJ_oo
nfX09OoonfX00ooo>@3ooo]ZoookJP07oookJP03ok;o0?oonf[ooo]Z00Oooo]Z00?ookP0ool0A?nW
0?l00_oonfX03?oDo`3o06;ood<0ool0F?ooo`1oohSo0?oo>@3ooo]Zoon00?oo0?Ooo`1;o`3ao`Ko
oo]Z00?oK_l0oookJ_oonfX00_oonfX00ol0O?oo0?mUoookJP04oookJP04o`3o7?oonf[ooo]Zo`2H
o`Sooo]Z00?oHol0oookJ_oonfX02OoonfX2ool0hD_ooo]Z000hoookJP03omX0oooonf[ooo]Z04[o
oo]Z00?o013ooookJ_oonfX0J_oonfX00ooo003ooo]ZoookJP02oookJP04oomi0?oonf[ooo]Zoook
JPCo0000<_oonfX00ol0odGooo]ZoookJP0VoookJP03ooli0?oonf[ooo]Z00Oooo]Z00?o/_l0oook
J_oonfX02?oonfX02_oo04CoY`3ooookJ_oonf[oe?l0o`1RoonDo`3o05SoodCo0?n8o`02odCo0004
oookJ_ooP03oo`1;o`3ao`Oooo]Z00?oK_l0oookJ_oonfX00_oonfX00ol0O?oo0?mUoookJP04oook
JP03o`3o7?oonf[ooo]Z00;oiOl01ooonfX00omSo`3ooo]ZoookJP0:oookJP03ool0hOoonf[ooo]Z
07cooo]Z00?ofP3ooookJ_oonfX0B_oonfX00ol04?oooo]ZoookJP1[oookJP05oond0?oonf[ooo]Z
oookJ_l0odH00ooonfX4o`0003?ooo]Z00?o0?m5oookJ_oonfX09_oonfX00ooo>@3ooo]ZoookJP07
oookJP03ok;o0?oonf[ooo]Z00Oooo]Z00_oo`14ojL0oooonf[ooo]ZomCo0?oohP3o06;oo`1Hoooo
07ooR?l0ooli0002oookJP03oon00?oo0?Ooo`1;00Oooo]Z00?oK_l0oookJ_oonfX00_oonfX00ol0
O?oo0?mUoookJP04oookJP03o`3o7?oonf[ooo]Z00;o09So1ooonfX00omSo`3ooo]ZoookJP0:oook
JP;oo`3QBOoonfX003Oooo]Z00?ofP3ooookJ_oonfX0B_oonfX00ol04?oooo]ZoookJP1ZoookJP03
ool00?oonf[ooo]Z00?ooo]Z00CoogT0oookJ_oonf[ooo]Z1?l0000boookJP03o`3oAOoonf[ooo]Z
02Kooo]Z00?oocT0oookJ_oonfX01ooonfX00onbo`3ooo]ZoookJP08oookJP0;ool0A?oonf[oY`3o
oookJ_oDo`3oo`16o`1Room4o`3o05SoodCo0?n8o`000_m4o`000ooonf[ooh00o`3ao`08oookJP03
ofko0?oonf[ooo]Z00;ooo]Z00?o07coo`3oIOoonfX01?oonfX00ol0oacooo]ZonGo0003onGo00Ko
oo]Z00?oHol0oookJ_oonfX02_oonfX2ool0hG_ooo]Z00?ofP3ooookJ_oonfX0B_oonfX00ol04?oo
oo]ZoookJP1[oookJP03oond0?oonf[ooo]Z00;ooo]Z00Co0?m6oookJ_oonf[ooo]Z1?l0000coook
JP03o`3oAOoonf[ooo]Z02Kooo]Z00?oocT0oookJ_oonfX01ooonfX00onbo`3ooo]ZoookJP07oook
JP03oonh0?oo04CoY`3o00;ooo]Z00Ooe?l0o`1Room30?oo05Soool0Oon8o`3oocT000;ooo]Z00?o
oh00ool0Bol0lOl01ooonfX00om^o`3ooo]ZoookJP02oookJP03o`1lool0ofGooo]Z00Cooo]Z00Go
0?lLoookJ_oonf[ooo]Zo`2Ho`07oookJP;oHol03?oonfX00ooo0>7ooo]ZoookJP16oookJP00=_oo
nfX00ooJ0?oooo]ZoookJP1;oookJP03o`0@oooonf[ooo]Z06[ooo]Z00?oo`00oookJ_oonfX00_oo
nfX2oomi00?ooo]Z1?l0000boookJP03o`3oAOoonf[ooo]Z02Oooo]Z00?oocT0oookJ_oonfX01_oo
nfX00onbo`3ooo]ZoookJP08oookJP03onGo0?oo04CoY`3o00;ooo]Z00Coe?l0oooR0?m4o`3o05So
0_m4o`001_n8o`3oA?l0odCo0?ooP03oo`1;o`3ao`Sooo]Z00?oK_l0oookJ_oonfX00_oonfX00ol0
O?oo0?mUoookJP04oookJP03o`3o7?oonf[oiOl000CoiOl01OoonfX2of?o00cooo]Z00?oo`3Qoook
J_oonfX0MooonfX00ooJ0?oooo]ZoookJP1;oookJP03o`0@oooonf[ooo]Z06_ooo]Z00Gook@0oook
J_oonf[ooo]Zo`3oAP04oookJPCo0000<ooonfX00ol0odGooo]ZoookJP0VoookJP03ooli0?oonf[o
oo]Z00Oooo]Z00?o/_l0oookJ_oonfX02?oonfX04Ooo04CoY`3ooookJ_oonf[oe?l0oooR0?l0H_oo
05Soool0Ooo/0?ooR?l0ooli0?oonf[oPol0oon00?oo04_o0?7o00Oooo]Z00?oK_l0oookJ_oonfX0
0_oonfX00ol0O?oo0?mUoookJP04oookJP;o0?lL0_oonfX00ol0V?oooo]ZoookJP06oookJP03of?o
0?oonf[ooo]Z00[ooo]Z0_oo0>56oookJP00=_oonfX00ooJ0?oooo]ZoookJP1:oookJP03o`0@oooo
nf[ooo]Z073ooo]Z0_ooN@03oookJPCo0000<_oonfX00ol0odGooo]ZoookJP0WoookJP03ooli0?oo
nf[ooo]Z00Oooo]Z00?o/_l0oookJ_oonfX02?oonfX00ooUo`3oo`14ojL0o`02oookJP06omCo0?l0
H_ooA?l0o`1Hoom4o`3oR?l00om4o`000oooP03oo`1;o`3ao`08oookJP03ofko0?oonf[ooo]Z00;o
oo]Z00?o07coo`3oIOoonfX01?oonfX00ol0oacooo]ZonGo0005onGo00Gooo]Z00?oHol0oookJ_oo
nfX02_oonfX2ool0hGOooo]Z00?ofP3ooookJ_oonfX0B_oonfX00ol04?oooo]ZoookJP1`oookJP03
o`3oA_oonf[ooo]Z00;ooo]Z1?l0000coookJP03o`3oAOoonf[ooo]Z02Kooo]Z00?oocT0oookJ_oo
nfX02?oonfX00onbo`3ooo]ZoookJP07oookJP03oonh0?oo04CoY`3o00;ooo]Z00Ooe?l0o`1Room3
0?oo05Soool0Oon8o`3oocT000;ooo]Z00Cooh00ool0mooo04_o0?7o1ooonfX00om^o`3ooo]Zoook
JP02oookJP03o`1lool0ofGooo]Z00Gooo]Z00Co0?lLoookJ_oonf[o09So2?oonfX00omSo`3ooo]Z
oookJP0;oookJP;oo`3QA?oonfX003Gooo]Z00?ofP3ooookJ_oonfX0B_oonfX00ol04?oooo]Zoook
JP1`oookJP?oogT00ooonfX4o`0003;ooo]Z00?o0?m5oookJ_oonfX09ooonfX00ooo>@3ooo]Zoook
JP07oookJP03ok;o0?oonf[ooo]Z00Sooo]Z00?oiOl0ool0A?nW0?l00_oonfX01ooDo`3oon80odCo
0?m4o`3o05SoodCo0?n8o`000om4o`000oooP03o0?7ooookJP07oookJP03ofko0?oonf[ooo]Z00;o
oo]Z00?o07cooookJ_l0ofD01OoonfX00ol0oacoiOl0onGo0006onGo00Cooo]Z00?oHol0oookJ_oo
nfX02ooonfX00ooo0>7ooo]ZoookJP1coookJP03omX0oooonf[ooo]Z04[ooo]Z00?o013ooookJ_oo
nfX0LOoonfX00ol0odKooo]ZoookJP02oookJPCo0000<ooonfX00ol0odGooo]ZoookJP0WoookJP03
ooli0?oonf[ooo]Z00Oooo]Z00?o/_l0oookJ_oonfX02?oonfX03?oo04Cooo]ZojL0oooonf[oe?l0
ool0A_l0H_oo@`3oo`1Hoooo07ooR?l0ooli00;ooo]Z00?ooh00ool0Bol0lOl01ooonfX00om^o`3o
oo]ZoookJP03oookJP03o`1lool0ofGooo]Z00Gooo]Z00Co0?lLoookJ_oonf[o09So2?oonfX2of?o
00gooo]Z00?oo`3QoookJ_oonfX0@OoonfX003Cooo]Z00?ofP3ooookJ_oonfX0BooonfX00ol04?oo
oo]ZoookJP1[oookJP?o001o00?ooo]Zoomi0?ooN@000_ooN@03oookJPCo0000<_oonfX00ol0odGo
oo]ZoookJP0XoookJP03ooli0?oonf[ooo]Z00Kooo]Z00?o/_l0oookJ_oonfX02?oonfX2onGo0005
ool0A?nW0?oooo]ZoiCo0?oDo`000_m4o`000ol0F?ooo`1oohSo0004odCo0003ool0Bol0lOoooo]Z
00Oooo]Z00?oK_l0oookJ_oonfX00_oonfX00ol0O?oo0?mUoookJP05oookJP03o`3o7?oUo`3oiOl0
00OoiOl00ooonfX00omSo`3ooo]ZoookJP0;oookJP;oo`3QL_oonfX00ooJ0?oooo]ZoookJP1;oook
JP03o`0@oooonf[ooo]Z06_ooo]Z0ol007l2oookJP03o`3oA_oonf[ooo]Z00?ooo]Z1?l0000coook
JP03o`3oAOoonf[ooo]Z02Oooo]Z00?oocT0oookJ_oonfX01ooonfX00onbo`3ooo]ZoookJP09oook
JP0<ool0A?nW0?oooo]ZoookJ_oDo`3o06;oogko0?l0F?ooo`1oohSo0?oo0=[oocT00_oonfX00ooo
P03oo`1;o`3ao`07oookJP03ofko0?oonf[ooo]Z00?ooo]Z00?o07coo`3oIOoonfX01OoonfX01?l0
oacooo]ZoookJ_l0V?l9oookJP03of?o0?oonf[ooo]Z00_ooo]Z0_oo0>51oookJP00<ooonfX00ooJ
0?oooo]ZoookJP1;oookJP03o`0@oooonf[ooo]Z06cooo]Z0ol007l00ooonf[oogT0oomi0002oomi
00?ooo]Z1?l0000boookJP03o`3oAOoonf[ooo]Z02Sooo]Z00?oocT0oookJ_oonfX01ooonfX00onb
o`3ooo]ZoookJP07oookJP;oiOl000Koo`14ojL0oooUo`3ooo]ZomCo0?oohP02odCo0003o`1Hoom4
o`3oR?l000CoA?l000?oo`1;o`3aoooonfX01ooonfX00om^o`3ooo]ZoookJP02oookJP03o`1lool0
ofGooo]Z00Gooo]Z00?o0?lLonGo0?oUo`002?oUo`02oookJP03of?o0?oonf[ooo]Z00cooo]Z0_oo
0>5_oookJP03omX0oooonf[ooo]Z04_ooo]Z00?o013ooookJ_oonfX0K?oonfX3o`00O`;ooo]Z00?o
0?m6oookJ_oonfX00ooonfX4o`0003?ooo]Z00?o0?m5oookJ_oonfX09ooonfX00ooo>@3ooo]Zoook
JP08oookJP03ok;o0?oonf[ooo]Z00Sooo]Z01;oo`14oookJ_nW0?oooo]ZomCo0?oo04Ko06;ood<0
ool0F?ooo`1oohSo0?oonf[oocT0oookJ_ooP03oo`3gool0Bol0lOl7oookJP03ofko0?oonf[ooo]Z
00?ooo]Z00?o07coo`3oIOoonfX01OoonfX01?l0oacooo]ZoookJ_l0V?l9oookJP03of?o0?oonf[o
oo]Z00cooo]Z0_oo0>4ooookJP00<ooonfX00ooJ0?oooo]ZoookJP1;oookJP03o`0@oooonf[ooo]Z
06cooo]Z0ol007l5oomi00?ooo]Z1?l0000boookJP03o`3oAOoonf[ooo]Z02Sooo]Z00?oocT0oook
J_oonfX01ooonfX00onbo`3ooo]ZoookJP07oookJP?oiOl000Goo`14ojL0oooonf[oU?l0omCo0002
odCo000:o`1Hoooo07ooA?l0ohSo0?m4o`3ooo]Zoon00?oo04_ooo]Zo`3ao`Sooo]Z00?oK_l0oook
J_oonfX00_oonfX00ol0O?oo0?mUoookJP05oookJP03o`3o7?oUo`3oiOl000SoiOl00_oonfX2ooo9
00kooo]Z0_oo0>5]oookJP03omX0oooonf[ooo]Z04_ooo]Z00?o013ooookJ_oonfX0K?oonfX3o`00
O`;ooo]Z00?o0?m6oookJ_oonfX00ooonfX4o`0003?ooo]Z00?o0?m5oookJ_oonfX09ooonfX00ooo
>@3ooo]ZoookJP08oookJP03ok;o0?oonf[ooo]Z00Wooo]Z00coo`14ojL0oooonf[ooo]ZomCo0?oo
hP3o06;oo`1Hoooo07ook03oohSo0?oo>@02oookJP03oon00?oo04_o0?7o00Sooo]Z00?oK_l0oook
J_oonfX00ooonfX00ol0O?oo0?mUoookJP05oookJP04o`3o7?oonf[ooo]Zo`2Ho`Wooo]Z0_mSo`0>
oookJP;oo`3Q?OoonfX003;ooo]Z00?ofP3ooookJ_oonfX0BooonfX00ol04?oooo]ZoookJP1]oook
JP?o001o1OooN@03oookJPCo0000<_oonfX00ol0odGooo]ZoookJP0YoookJP03ooli0?oonf[ooo]Z
00Oooo]Z00?o/_l0oookJ_oonfX01ooonfX2onGo0005ool0A?nW0?ooiOl0oiCo0?oDo`000om4o`00
0ol0F?ooo`1oohSo0002odCo0005oookJ_ooP03oo`1;oookJ_l0lOl02?oonfX00om^o`3ooo]Zoook
JP02oookJP03o`1lool0ofGooo]Z00Gooo]Z00?o0?lLonGo0?oUo`001ooUo`02oookJPGoolT03Ooo
nfX2ool0hF[ooo]Z00?ofP3ooookJ_oonfX0BooonfX00ol04?oooo]ZoookJP1]oookJP?o001o00?o
oo]Zo`3oA_oonfX01OoonfX4o`0003?ooo]Z00?o0?m5oookJ_oonfX0:?oonfX00ooo>@3ooo]Zoook
JP08oookJP03ok;o0?oonf[ooo]Z00Sooo]Z00?oo`14oookJ_nW0?l00_oonfX02?oDo`3oon80o`1R
ool0F?ooo`1oohSo0?oo0=[oocT00_oonfX00oooP03oo`1;o`3ao`08oookJP03ofko0?oonf[ooo]Z
00?ooo]Z00?o07coo`3oIOoonfX01OoonfX01?l0oacooo]ZoookJ_l0V?l:oookJP03of?o0?oonf[o
oo]Z00gooo]Z0_oo0>4koookJP00<OoonfX00ooJ0?oooo]ZoookJP1;oookJP03o`0@oooonf[ooo]Z
06kooo]Z0_l007l5oomi00Cooo]Z1_l0000`oookJP03o`3oAOoonf[ooo]Z02Wooo]Z00?oocT0oook
J_oonfX02?oonfX00onbo`3ooo]ZoookJP06oookJP?oiOl000Goo`14ojL0oonDo`3oU?l0omCo0003
odCo0003o`1Hoooo07ooU?l000;oA?l000Gooo]Zoon00?oo04_ooo]Zo`3ao`08oookJP03ofko0?oo
nf[ooo]Z00?ooo]Z00?o0?mUoookJ_oonfX01?oonfX00ol0oacoiOl0onGo0005onGo00Cooo]Z1ooo
b@0<oookJP03ool0hOoonf[ooo]Z06Kooo]Z00?ofP3ooookJ_oonfX0BooonfX00ol04?oooo]Zoook
JP1^oookJP?o001o00?ooo]Zo`3oA_oonfX01OoonfX6o`00037ooo]Z00?o0?m5oookJ_oonfX0:?oo
nfX00ooo>@3ooo]ZoookJP08oookJP03ok;o0?oonf[ooo]Z00Wooo]Z00?oo`14oookJ_nW0?l00_oo
nfX01OoDo`3oon80o`1Rool0F?ooo`1o00;oR?l000KoocT0oookJ_oonf[ooh00ool0Bol0lOl8oook
JP03ofko0?oonf[ooo]Z00?ooo]Z00?o07coo`3oIOoonfX01OoonfX01?l0oacooo]ZoookJ_l0V?l:
oookJP03of?o0?oonf[ooo]Z00kooo]Z00?oo`3QoookJ_oonfX0>?oonfX00?3ooo]Z0ol007l8oook
JPCo0000oooonf[ToookJP?o001o2?oonfX4o`000?Oooo]Z003`oookJP?o001o2?oonfX4o`000?oo
oo]Zi?oonfX3o`00O`Sooo]Z1?l0003goookJP00l?oonfX3o`00Oooooo]Zl?oonfX3o`00Oooooo]Z
1?oonfX00?3ooo]Z0ol007oooookJ_3ooo]Z0ol007oooookJPCooo]Z003]oookJPKo001ooooonf[]
oookJPKo001ooooonfX4oookJP00kOoonfX6o`00Oooooo]ZkOoonfX6o`00Oooooo]Z1?oonfX00>oo
oo]Z1?l007oooookJ^oooo]Z1?l007oooookJPCooo]Z003`oookJP?o001ooooonf[`oookJP?o001o
oooonfX4oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooook
J_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z
003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooook
J^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooo
nf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oo
oo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]Zjooo
nfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oo
oo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[o
oookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00
oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[
oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Z
oooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooook
J_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z
003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooook
J^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooo
nf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oo
oo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]Zjooo
nfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oo
oo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[o
oookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00
oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[
oookJP00oooonf[ooookJ_oooo]ZjooonfX00>Kooo]Z0ol007l5oookJPGo001ooooonf[VoookJP?o
001o1OoonfX5o`00Oooooo]Z1?oonfX00>Kooo]Z0ol007l4oookJPOo001ooooonf[UoookJP?o001o
1?oonfX7o`00Oooooo]Z0ooonfX00>Kooo]Z0ol007l3oookJPCo001o00Cooo]Zo`00Ool007oo001o
oooonf[UoookJP?o001o0ooonfX4o`00O`04oookJ_l007oo001oo`00Oooooo]Z0ooonfX00=Kooo]Z
2_l007l6oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000oooonf[:oookJP[o001o
1_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX4o`000?Oooo]Z003FoookJP[o001o1_oo
nfX3o`00O`Wooo]Z0ol007l6oookJPKo0000oooonf[8oookJP[o001o1_oonfX3o`00O`Wooo]Z0ol0
07l6oookJPKo0000mOoonfX00>Kooo]Z0ol007l9oookJP?o001o1_oonfX4o`000?oooo]Zf_oonfX3
o`00O`Wooo]Z0ol007l6oookJPCo0000mooonfX00>Kooo]Z0ol007l4oookJP;o001o0_oonfX4o`00
O`Kooo]Z1?l0003ooookJ][ooo]Z0ol007l4oookJP;o001o0_oonfX4o`00O`Kooo]Z1?l0003goook
JP00i_oonfX3o`00O`Cooo]Z1ol007l7oookJPCo0000oooonf[JoookJP?o001o1?oonfX7o`00O`Oo
oo]Z1?l0003goookJP00i_oonfX3o`00O`Cooo]Z1_l007l8oookJPCo0000oooonf[JoookJP?o001o
1?oonfX6o`00O`Sooo]Z1?l0003goookJP00hooonfX6o`00O`Cooo]Z0_l007l<oookJPCo0000oooo
nf[GoookJPKo001o1?oonfX2o`00O`cooo]Z1?l0003goookJP00hooonfX6o`00O`Cooo]Z0_l007l<
oookJPCo0000oooonf[GoookJPKo001o1?oonfX2o`00O`cooo]Z1?l0003goookJP00iOoonfX4o`00
O`Gooo]Z1ol007l6oookJPCo0000oooonf[IoookJPCo001o1OoonfX7o`00O`Kooo]Z1?l0003goook
JP00i_oonfX3o`00O`Gooo]Z1ol007l6oookJPCo0000oooonf[JoookJP?o001o1OoonfX7o`00O`Ko
oo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooo
nf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`00
0?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z
1Ol0003ooookJ^kooo]Z1Ol0003foookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003k
oookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goook
JP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000
mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4
o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oo
oo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooo
nf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`00
0?oooo]ZkooonfX4o`000?Oooo]Z003koookJPGo0000oooonf[^oookJPGo0000m_oonfX00?_ooo]Z
1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003k
oookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goook
JP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000
mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4
o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oo
oo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooo
nf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX5o`00
0?oooo]Zk_oonfX5o`000?Kooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z
1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003k
oookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goook
JP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000
mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4
o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oo
oo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooo
nf[_oookJPCo0000mooonfX00?_ooo]Z1Ol0003ooookJ^kooo]Z1Ol0003foookJP00nooonfX4o`00
0?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z
1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003k
oookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goook
JP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000
mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00i_oonfX3o`00O`Gooo]Z1Ol007l8
oookJPCo0000oooonf[JoookJP?o001o1OoonfX5o`00O`Sooo]Z1?l0003goookJP00i_oonfX3o`00
O`Cooo]Z1ol007l7oookJPCo0000oooonf[JoookJP?o001o1?oonfX7o`00O`Oooo]Z1?l0003goook
JP00i_oonfX3o`00O`Cooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPCo0000oooonf[Joook
JP?o001o1?oonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l0003goookJP00e_oonfX:o`00
O`Kooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0003ooookJ/[ooo]Z2_l007l6oook
JP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000mooonfX00=Kooo]Z2_l007l6oookJP?o
001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPKo0000oooonf[8oookJP[o001o1_oonfX3o`00O`?o
oo]Z0ol007l3oookJP?o001o1_oonfX6o`000?Gooo]Z003VoookJP?o001o0ooonfX3o`00O`?ooo]Z
0ol007l6oookJPCo0000oooonf[JoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000
mooonfX00>Kooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Cooo]Z0ooo0003o`000?oooo]Zf_oo
nfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX4o`000?Oooo]Z003VoookJP?o001o0ooonfX3
o`00O`?ooo]Z0ol007l4oookJPKoo`00oooonf[JoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6
oookJPCo0000mooonfX00>Kooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Cooo]Z2?oo001:oook
JP03ool00?oonf[ooo]Z0?oooo]ZRooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX2o`00
0003ool0@_l0003ooo]Z04_ooo]Z00?oojL0oookJ_oonfX0Z?oonfX00>?ooo]Z1_l007l3oookJP?o
001o0ooonfX3o`00O`Cooo]Z2?oo001:oookJP03ool00?oonf[ooo]Z0?oooo]ZR?oonfX6o`00O`?o
oo]Z0ol007l3oookJP?o001o1_oonfX2o`000003ool0@_l0003ooo]Z04_ooo]Z00?oojL0oookJ_oo
nfX0Z?oonfX00>?ooo]Z1_l007l4oookJP?o001o00Cooo]Zo`00Ool007oo001o1OoonfX7ool004[o
oo]Z00?oo`00oookJ_oonfX0oooonfZ9oookJPKo001o1?oonfX3o`00O`04oookJ_l007oo001oo`00
O`Oooo]Z0_l000000ooo04;o0000oookJP1:oookJP03oonW0?oonf[ooo]Z0:Wooo]Z003UoookJPCo
001o1?oonfX2o`00O`Goo`001OoonfX7ool004Gooo]Z0_oo0003oookJP03ool00?oonf[ooo]Z0?oo
oo]ZRooonfX4o`00O`Cooo]Z1ol007l7oookJP04o`000?oo04;o0000o`0004_ooo]Z00?oojL0oook
J_oonfX0ZOoonfX00>Kooo]Z0ol007l5oookJP03o`00Oooo003oo`0000Koo`000_oonfX6ool004Ko
oo]Z0ooo00000ooonf[oo`00oookJP3ooookJXkooo]Z0ol007l5oookJPGo001o2?oonfX01?l0003o
o`12o`000?l0001:oookJP03oonW0?oonf[ooo]Z0:[ooo]Z0039oookJP?oo`008ooonfX8ool000;o
oo]Z1_oo0016oookJPGoo`00oooonfZToookJP04o`000?oo04;o0000o`0004Wooo]Z00?oojL0oook
J_oonfX0ZooonfX00<Kooo]Z1_oo000SoookJPOoo`000ooonfX5ool00003o`000?oonf[ooo]Z04?o
oo]Z1ooo003ooookJY[ooo]Z00?oW?l0oookJ_oonfX01_oonfX01?l0003oo`12o`000?l00019oook
JP03oonW0?oonf[ooo]Z0:_ooo]Z0034oookJPSoo`008ooonfX7ool000?ooo]Z1?oo0002o`0004Go
oo]Z2?oo003ooookJYWooo]Z00?oW?l0oookJ_oonfX01_oonfX01?oo04;o0000o`000?l00018oook
JP03oonW0?oonf[ooo]Z0:cooo]Z0034oookJPSoo`008ooonfX6ool000Cooo]Z1?oo0002o`0004Go
oo]Z2?oo003ooookJYWooo]Z00?oW?l0oookJ_oonfX01_oonfX01?oo04;o0000o`000?l00018oook
JP03oonW0?oonf[ooo]Z0:cooo]Z0035oookJPOoo`008ooonfX6ool000Cooo]Z0ooo0003o`0004Go
oo]Z1ooo000joookJP03ool00?oonf[ooo]Z0?oooo]ZGOoonfX00onLo`3ooo]ZoookJP06oookJP04
ool0@_l0003o0000o`0004Oooo]Z00?oojL0oookJ_oonfX0?OoonfX00ooo09Kooo]ZoookJP1]oook
JP00aOoonfX7ool002?ooo]Z1_oo0004oookJP?oo`001?l00013oookJPOoo`00>ooonfX00ooo003o
oo]ZoookJP3ooookJUgooo]Z00?oW?l0oookJ_oonfX01_oonfX00ooo04;o0000o`000002o`0004Ko
oo]Z00?oojL0oookJ_oonfX0?OoonfX00ooo09Kooo]ZoookJP1]oookJP00a_oonfX6ool002Cooo]Z
1?oo0005oookJP;oo`001?l00014oookJPKoo`00>ooonfX00ooo003ooo]ZoookJP3ooookJUkooo]Z
00?oW?l0oookJ_oonfX01_oonfX01?oo04;o0000o`000?l00016oookJP03oonW0?oonf[ooo]Z03go
oo]Z00?oo`2FoookJ_oonfX0K_oonfX00<Kooo]Z1_oo000ToookJPCoo`001OoonfX2ool000Co0000
A?oonfX5ool003_ooo]Z00?oo`00oookJ_oonfX0oooonfYOoookJP03oico0?oonf[ooo]Z00Gooo]Z
00?oo`12o`000?l000000_l00016oookJP03oonW0?oonf[ooo]Z03cooo]Z00?oo`2FoookJ_oonfX0
KooonfX00<Oooo]Z1Ooo000ToookJP?oo`001_oonfX00ooo003ooo]Zo`000003o`0000Sooo]Z0ooo
000hoookJPGoo`00>ooonfX00ooo003ooo]ZoookJP3ooookJSOooo]Z00?oo`0<oookJ_oonfX09Ooo
nfX00onLo`3ooo]ZoookJP06oookJP03ool0@_l0003o000000;o0000AOoonfX00oooY`3ooo]Zoook
JP0loookJP03ool0U_oonf[ooo]Z073ooo]Z0037oookJPGoo`009?oonfX3ool000Kooo]Z00?oo`12
oookJ_l000000ol00008oookJPKoo`00=OoonfX4ool003cooo]Z00?oo`00oookJ_oonfX0oooonfXg
oookJP03ool03?oonf[ooo]Z02Gooo]Z00?oW?l0oookJ_oonfX01_oonfX00ooo04;o0000o`000002
o`0004Cooo]Z00?oojL0oookJ_oonfX0?OoonfX00ooo09Kooo]ZoookJP1`oookJP00b?oonfX4ool0
02Cooo]Z0_oo0007oookJP03ool0@_oonf[o000000?o00002?oonfX8ool003?ooo]Z0ooo000loook
JP;oo`00oooonfXioookJP03ool03?oonf[ooo]Z02Gooo]Z00?oW?l0oookJ_oonfX01_oonfX00ooo
04;o0000o`000002o`0004Cooo]Z00?oojL0oookJ_oonfX0??oonfX00olh0?oooo]ZoookJP1aoook
JP00V_oonfX00ooo003ooo]ZoookJP0[oookJPCoo`009?oonfX2ool000Oooo]Z00?oo`12oookJ_l0
00000ol00008oookJPSoo`00<ooonfX2ool003Oooo]Z0_oo0003oookJP03ool00?oonf[oo`000?oo
oo]Z>_oonfX00ooo00cooo]ZoookJP0ToookJP03oico0?oonf[ooo]Z00Gooo]Z00?oo`12oookJ_l0
00000ol0000<oookJP03o`2doooonf[ooo]Z03Cooo]Z00?oojL0oookJ_oonfX0??oonfX00ooo09Ko
>03ooookJP1boookJP00V_oonfX00ooo003ooo]ZoookJP0/oookJP?oo`009?oonfX2ool000Kooo]Z
00?oo`12oookJ_oonfX01?l00008oookJPOoo`00<ooonfX2ool003Sooo]Z0ooo00001?oonf[oo`00
oookJ_oo003ooookJS_ooo]Z00?oo`0<oookJ_oonfX09?oonfX00onLo`3ooo]ZoookJP05oookJP03
ool0@_oonf[o000000?o00003?oonfX00ol0]?oooo]ZoookJP0doookJP03oonW0?oonf[ooo]Z03_o
oo]Z00?oo`2FocP0oooonfX0LooonfX009Wooo]Z0ooo000]oookJP?oo`009?oonfX00ooo003ooo]Z
oookJP05oookJP03ool0@_oonf[ooo]Z00Co00002?oonfX6ool003Cooo]Z00?oo`00oookJ_oonfX0
=_oonfX7ool00?oooo]Z??oonfX00ooo00cooo]ZoookJP0ToookJP03oico0?oonf[ooo]Z00Gooo]Z
00?oo`12oookJ_l000000ol0000;oookJP03o`2doooonf[ooo]Z03Cooo]Z00?oojL0oookJ_oonfX0
??oonfX00olh0?oooo]ZoookJP1coookJP00V?oonfX5ool002gooo]Z0_oo000ToookJP03oico0?oo
nf[ooo]Z00Gooo]Z00?oo`12oookJ_oonfX01?l00008oookJPKoo`00=?oonfX00oooY`3ooo]Zoook
JP0foookJPKoo`00oooonfXmoookJP03ool03?oonf[ooo]Z02Cooo]Z00?oW?l0oookJ_oonfX01Ooo
nfX00ooo04;ooo]Zo`000003o`0000_ooo]Z00?o0;CooookJ_oonfX0=?oonfX00oooY`3ooo]Zoook
JP0koookJP03ocP0oooonf[ooo]Z07Cooo]Z002GoookJPOoo`00;?oonfX2ool000?oobP08OoonfX0
1?nLo`3ooo]ZoookJ_oonfX5oolX00;ooo]Z1?l00008oookJPGoo`00=?oonfX00oooY`3ooo]Zoook
JP0foookJPSoo`00oooonfXmoookJP03ool03?oonf[ooo]Z02?ooo]Z00?oW?l0oookJ_oonfX01?oo
nfX00ooo04;ooo]ZoookJP04o`0000_ooo]Z00?o0;CooookJ_oonfX0<ooonfX00oooY`3ooo]Zoook
JP0koookJP03ool0U_lh0?oooo]Z07Gooo]Z002FoookJPWoo`00:_oonfX6oolX027ooo]Z00CoW?l0
oookJ_oonf[ooo]Z2?oo:003o`0000Oooo]Z1_oo000doookJP03oonW0?oonf[ooo]Z03Gooo]Z2_oo
003ooookJScooo]Z00?oo`0<oookJ_oonfX08_oonfX00onLo`3ooo]ZoookJP05oookJP03ool0@_oo
nf[ooo]Z00Co00002_oonfX00ol0]?oooo]ZoookJP0doookJP03oonW0?oonf[ooo]Z03[ooo]Z00?o
o`2FocP0oooonfX0M_oonfX009Gooo]Z2ooo000WoookJPSoobP07OoonfX5oolX00?ooo]Z2?oo:003
o`0000Oooo]Z1Ooo000doookJP03oonW0?oonf[ooo]Z03Kooo]Z2?oo003ooookJSkooo]Z00?oo`0<
oookJ_oonfX08_oonfX00onLo`3ooo]ZoookJP05oookJP03ool0@_oonf[ooo]Z00Co00002_oonfX0
0ol0]?oooo]ZoookJP0coookJP03oonW0?oonf[ooo]Z03[ooo]Z00?oo`2FocP0oooonfX0MooonfX0
09Sooo]Z2Ooo000VoookJPSoobP07OoonfX?oolX00Co00000ooonfX3ool00003oookJ_oo003oo`00
00;oo`00=?oonfX00oooY`3ooo]ZoookJP0foookJPSoo`00oooonfXBoookJP;o0?n^:ooonfX00ooo
00cooo]ZoookJP0RoookJP03oico0?oonf[ooo]Z00Gooo]Z00?oo`12oookJ_oonfX01?l0000:oook
JP03o`2doooonf[ooo]Z03;ooo]Z00?oojL0oookJ_oonfX0>ooonfX00olh0?oooo]ZoookJP1goook
JP00VooonfX7ool000Cooo]Z00?oobP0oookJ_oonfX07ooonfX7oolX01gooo]Z3ooo:004o`0000?o
oo]Z2?oo000doookJP03oonW0?oonf[ooo]Z03Kooo]Z1ooo003ooookJQGooo]Z00?o0?n^oookJ_oo
nfX0:OoonfX00ooo00cooo]ZoookJP0QoookJP03oico0?oonf[ooo]Z00Cooo]Z00Coo`12oookJ_oo
nf[ooo]Z1?l00009oookJP03o`2doooonf[ooo]Z03?ooo]Z00?oojL0oookJ_oonfX0>_oonfX00ooo
09Ko>03ooookJP1hoookJP00SooonfX2ool000gooo]Z1Ooo0002oookJP;oobP08_oonfX6oolX01go
oo]Z1ooo:0000ooonf[oobP0oolX0004oolX0003oookJ_l0003o000000?o00000_oonfX8ool003?o
oo]Z00?oojL0oookJ_oonfX0=_oonfX8ool00?oooo]Z5_oonfX2o`3o[RWooo]Z00?oo`0<oookJ_oo
nfX08OoonfX00onLo`3ooo]ZoookJP04oookJP04ool0@_oonf[ooo]ZoookJPGo00002?oonfX00ol0
]?oooo]ZoookJP0boookJP03oonW0?oonf[ooo]Z03[ooo]Z00?oo`2FocP0oooonfX0NOoonfX008oo
oo]Z0ooo000?oookJP?oo`001?oo:00QoookJPKoobP07OoonfX7oolX0003oookJ_oo:03oobP000Co
obP000?ooo]Zo`000?l000000_l00003oookJP[oo`00<OoonfX00oooY`3ooo]ZoookJP0@oookJP03
ool00?oonf[ooo]Z02?ooo]Z2Ooo003ooookJQOooo]Z00?o0?n^oookJ_oonfX09_oonfX00ooo00co
oo]ZoookJP0PoookJP03oico0?oonf[ooo]Z00Gooo]Z00Coo`12oookJ_oonf[ooo]Z1?l00009oook
JP03o`2doooonf[ooo]Z03;ooo]Z00?oojL0oookJ_oonfX04?oonfX00ooo?03ooo]ZoookJP0Voook
JP03ool0U_lh0?oooo]Z07[ooo]Z002?oookJPGoo`003ooonfX6oolX027ooo]Z1Ooo:00NoookJPKo
obP000?ooo]ZoolX0?oo:0001?oo:0000ooonf[o0000o`000002o`0000?ooo]Z3?oo000^oookJP03
oonW0?oonf[ooo]Z017ooo]Z00?oo`00oookJ_oonfX08ooonfX7ool00?oooo]Z6_oonfX2o`3o[ROo
oo]Z00?oo`0<oookJ_oonfX07ooonfX00onLo`3ooo]ZoookJP05oookJP04ool0@_oonf[ooo]Zoook
JPCo00002?oonfX00ol0]?oooo]ZoookJP0boookJP03oonW0?oonf[ooo]Z017ooo]Z00?ooc`0oook
J_oonfX09_oonfX00olh0?oooo]ZoookJP1joookJP00S_oonfX7ool000gooo]Z2?oo:00PoookJPKo
obP07OoonfX5oolX00?ooo]Z1?oo:002oookJPCo00000ooonfX<ool002kooo]Z00?oojL0oookJ_oo
nfX03?oonfX2ool000;ooo]Z00?oo`00oookJ_oonfX08ooonfX7ool00?oooo]Z7OoonfX00ol0ojko
oo]ZoookJP0ToookJP03ool03?oonf[ooo]Z01oooo]Z00?oW?l0oookJ_oonfX01?oonfX00ooo04;o
oo]ZoookJP02oookJPCo00001_oonfX00ooo09?ooo]Zo`2do`0doookJP03oonW0?oonf[ooo]Z013o
oo]Z00?ooc`0oookJ_oonfX09_oonfX00ooo09Ko>03ooookJP1koookJP00S_oonfX9ool000[ooo]Z
2Ooo:00QoookJPGoobP07OoonfX5oolX00?ooo]Z1?oo:002oookJPCo00000ooonfX;ool002kooo]Z
00?oojL0oookJ_oonfX03OoonfX3ool00003oookJ_oo003ooo]Z02Cooo]Z1_oo003ooookJQoooo]Z
0_l0ojhToookJP03ool03?oonf[ooo]Z01oooo]Z00?oW?l0oookJ_oonfX01?oonfX00ooo04;ooo]Z
oookJP02oookJPCo00001_oonfX01Ooo09?ooo]Zo`2doooonf[ofOl0037ooo]Z00?oojL0oookJ_oo
nfX04OoonfX00ooo?03ooo]ZoookJP0UoookJP03ool0U_lh0?oooo]Z07cooo]Z002>oookJP[oo`00
1_oonfX2oolX00?ooo]Z2?oo:00QoookJPCoobP07OoonfX5oolX00?ooo]Z0ooo:003oookJPCo0000
0ooonfX;ool000Gooo]Z0_oo000WoookJP03oonW0?oonf[ooo]Z00cooo]Z1_oo000ToookJPGoo`00
oooonfXSoookJP03o`3o[_oonf[ooo]Z02;ooo]Z00?oo`0<oookJ_oonfX07_oonfX00onLo`3ooo]Z
oookJP04oookJP03ool0@_oonf[ooo]Z00;ooo]Z1?l00006oookJP05ool0Tol0]?oooo]ZoookJ_oI
o`00<OoonfX00oooY`3ooo]ZoookJP0@oookJP03ooll0?oonf[ooo]Z02Gooo]Z00?oo`2FocP0oooo
nfX0OOoonfX008gooo]Z3?oo0005oookJP?oobP01?oonfX7oolX023ooo]Z1?oo:00MoookJPCoobP0
1?oonfX3oolX00?ooo]Z1?l00003oookJP[oo`001_oonfX5ool002?ooo]Z00?oojL0oookJ_oonfX0
3OoonfX7ool002?ooo]Z1?oo003ooookJQ3ooo]Z0_l0oe0CoookJP;o0?n^8_oonfX00ooo00cooo]Z
oookJP0NoookJP03oico0?oonf[ooo]Z00Cooo]Z00?oo`12oookJ_oonfX00_oonfX4o`0000Gooo]Z
00Goo`2CoookJ_l0]?oooo]ZomWo000aoookJP03oonW0?oonf[ooo]Z013ooo]Z00?ooc`0oookJ_oo
nfX09_oonfX00olh0?oooo]ZoookJP1moookJP00SOoonfX>ool000;ooo]Z1Ooo:005oookJPKoobP0
8?oonfX3oolX01gooo]Z1?oo:004oookJP;oobP01?oonfX4o`0000?ooo]Z2Ooo0007oookJPOoo`00
8?oonfX00oooY`3ooo]ZoookJP0>oookJPSoo`005ooonfX00ooo003ooo]ZoookJP07oookJPCoo`00
2OoonfX00ooo003ooo]ZoookJP3ooookJPOooo]Z0ol0oe0BoookJP03o`3o[_oonf[ooo]Z023ooo]Z
00?oo`0<oookJ_oonfX07OoonfX00onLo`3ooo]ZoookJP04oookJP03ool0@_oonf[ooo]Z00;ooo]Z
1?l00005oookJP05ool0Tooonf[o0;CooookJ_l04?l0<?oonfX00oooY`3ooo]ZoookJP0AoookJP03
ooll0?oonf[ooo]Z01[ooo]Z00?ooll0oookJ_oonfX02?oonfX00ooo09Ko>03ooookJP08oookJP03
ool0R?oonf[ooo]Z07?ooo]Z002BoookJP[oo`0000?ooo]ZoolX0?oo:0001?oo:006oookJPCoobP0
8?oonfX3oolX01gooo]Z1?oo:004oookJP;oobP01?oonfX4o`0000;ooo]Z0ooo:007ool000Oooo]Z
2?oo000JoookJP;oobP00ooonfX00oooY`3ooo]ZoookJP0=oookJPSoo`006?oonfX00ooo003ooo]Z
oookJP07oookJP;oo`002ooonfX00ooo003ooo]ZoookJP3ooookJP[ooo]Z0_l0oe0AoookJP03o`3o
[_oonf[ooo]Z01oooo]Z00?oo`0<oookJ_oonfX07OoonfX00onLo`3ooo]ZoookJP03oookJP03ool0
@_oonf[ooo]Z00?ooo]Z1?l00005oookJP05ool0Tol0]?oooo]ZoookJ_l04?l0<?oonfX00oooY`3o
oo]ZoookJP0@oookJP03ooll0?oonf[ooo]Z01_ooo]Z00?ooll0oookJ_oonfX01ooonfX00ooo09Ko
>03ooookJP09oookJP03ool0R?oonf[ooo]Z07?ooo]Z002IoookJP?oo`002?oo:007oookJP?oobP0
8?oonfX2oolX01gooo]Z0ooo:005oookJP;oobP01?oonfX4o`0000;ooo]Z1?oo:005ool000Sooo]Z
2?oo000JoookJPGoobP04?oonfX7ool001Sooo]Z00?oo`00oookJ_oonfX02?oonfX00ooo003ooo]Z
oookJP09oookJP03ool00?oonf[ooo]Z0?oooo]Z3OoonfX2o`3oD13ooo]Z00?o0?n^oookJ_oonfX0
7_oonfX00ooo00cooo]ZoookJP0LoookJP03oico0?oonf[ooo]Z00Cooo]Z00?oo`12oookJ_oonfX0
0ooonfX4o`0000Cooo]Z00Koo`2CoookJ_l0]?oooo]ZomWo0?l04?l;oookJP03o`0Loooonf[ooo]Z
027ooo]Z00?oojL0oookJ_oonfX04OoonfX00ooo?03ooo]ZoookJP0JoookJP03ooo?0?oonf[ooo]Z
00Oooo]Z00?oo`2FocP0oooonfX02OoonfX00ooo08Sooo]ZoookJP1doookJP00VooonfX:oolX00So
oo]Z0_oo:00PoookJP03oolX0?oonf[ooo]Z01cooo]Z0_oo:005oookJP03oolX0?oonf[ooo]Z00?o
oo]Z1?l00002oookJP?oobP01_oo0007oookJPSoo`006ooonfX6oolX00oooo]Z1_oo000CoookJP;o
o`000ooonfX00ooo003ooo]ZoookJP08oookJP03ool00?oonf[ooo]Z00Wooo]Z00?oo`00oookJ_oo
nfX0oooonfX@oookJP?o0?m@3_oonfX00ol0ojkooo]ZoookJP0NoookJP03ool03?oonf[ooo]Z01_o
oo]Z00?oW?l0oookJ_oonfX01?oonfX00ooo04;ooo]ZoookJP03oookJPCo00001?oonfX01Ooo09?o
oo]Zo`2doooonf[o013o00cooo]Z00?o01cooookJ_oonfX08OoonfX00oooY`3ooo]ZoookJP0@oook
JP03ooll0?oonf[ooo]Z01[ooo]Z00?ooll0oookJ_oonfX02?oonfX00olh0?oooo]ZoookJP08oook
JP03ool0R?oonf[ooo]Z07Gooo]Z002KoookJP_oobP02OoonfX00ooo:03o0?n^oookJP0MoookJP03
ool03?oonf[ooo]Z01cooo]Z0_oo:005oookJP03ool0@_oonf[ooo]Z00?ooo]Z1?l00002oookJP?o
obP01Ooo0008oookJPOoo`006ooonfX8oolX00gooo]Z1_oo000DoookJP?oo`000_oonfX00ooo003o
oo]ZoookJP07oookJP03ool0U_lh0?oooo]Z00Wooo]Z00?oo`00oookJ_oonfX0oooonfXDoookJP;o
0?m@3OoonfX2o`3o[Qkooo]Z00?oo`0<oookJ_oonfX06ooonfX00onLo`3ooo]ZoookJP04oookJP03
ool0@_oonf[ooo]Z00?ooo]Z1?l00004oookJP05ool0Tol0]?oooo]ZoookJ_l04?l02ooonfX00ol0
7?oooo]ZoookJP0QoookJP03oonW0?oonf[ooo]Z013ooo]Z00?ooc`0oookJ_oonfX06_oonfX00ooo
c`3ooo]ZoookJP08oookJP03ool0U_lh0?oooo]Z00Sooo]Z00?oo`28oookJ_oonfX0M_oonfX009[o
oo]Z3Ooo:00:oookJP03o`3o[_oonf[ooo]Z01_ooo]Z00?oo`0<oookJ_oonfX07?oonfX00ooo:03o
oo]ZoookJP04oookJP03ool0@_oonf[ooo]Z00?ooo]Z1?l00002oookJP?oobP01?oo0009oookJPKo
o`007?oonfX8oolX00gooo]Z1Ooo000DoookJPKoo`002_oonfX00olh0?oooo]ZoookJP03oookJP;o
o`000ooonfX00ooo003ooo]ZoookJP3ooookJQOooo]Z0_l0oe0=oookJP03o`3o[_oonf[ooo]Z01_o
oo]Z00?oo`0<oookJ_oonfX06ooonfX00onLo`3ooo]ZoookJP04oookJP03ool0@_oonf[ooo]Z00?o
oo]Z1?l00004oookJP05ool0Tol0]?oooo]ZomWo0?l04?l02ooonfX00ol07?oooo]ZoookJP0Qoook
JP03oonW0?oonf[ooo]Z013ooo]Z00?ooc`0oookJ_oonfX06_oonfX00oooc`3ooo]ZoookJP07oook
JP03ool0U_lh0?oooo]Z00Sooo]Z00?oo`28oookJ_oonfX0MooonfX009kooo]Z2_oo:00:oookJP03
o`3o[_oonf[ooo]Z01_ooo]Z00?oo`0<oookJ_oonfX06ooonfX00ooo:03ooo]ZoookJP03oookJP03
ool0@_oonf[ooo]Z00Cooo]Z1?l00002oookJP?oobP01?oo0009oookJPKoo`007?oonfX7oolX00ko
oo]Z1?oo000EoookJPOoo`002?oonfX00olh0?oooo]ZoookJP04oookJP?oo`000_oonfX00ooo003o
oo]ZoookJP3ooookJQWooo]Z0_l0oe0<oookJP03o`3o[_oonf[ooo]Z01_ooo]Z00?oo`0<oookJ_oo
nfX06_oonfX00onLo`3ooo]ZoookJP04oookJP03ool0@_oonf[ooo]Z00?ooo]Z1?l00003oookJP05
ool0Tooonf[o0;CooookJ_l04?l03?oonfX00ol07?oooo]ZoookJP0PoookJP03oonW0?oonf[ooo]Z
013ooo]Z00?ooc`0oookJ_oonfX06_oonfX00oooc`3ooo]ZoookJP07oookJP03ool0U_lh0?oooo]Z
00Wooo]Z00?oo`28oookJ_oonfX0MooonfX00:?ooo]Z1_oo:00:oookJP03o`3o[_oonf[ooo]Z01[o
oo]Z00?oo`0<oookJ_oonfX06ooonfX00onLo`3ooo]ZoookJP03oookJP03ool0@_oonf[ooo]Z00Co
oo]Z1Ol000001?oonf[oobP0oolX0?oo:003ool000[ooo]Z1Ooo000MoookJPKoobP03_oonfX4ool0
01Kooo]Z2?oo0006oookJP03ocP0oooonf[ooo]Z00Cooo]Z1_oo003ooookJQkooo]Z0_l0oe0;oook
JP03o`3o[_oonf[ooo]Z01[ooo]Z00?oo`0<oookJ_oonfX06_oonfX00onLo`3ooo]ZoookJP04oook
JP03ool0@_oonf[ooo]Z00?ooo]Z1Ol00002oookJP05ool0Tol0]?oooo]ZoookJ_l04?l02ooonfX0
0ol07?oooo]ZoookJP0PoookJP03oonW0?oonf[ooo]Z017ooo]Z00?ooc`0oookJ_oonfX06OoonfX0
0oooc`3ooo]ZoookJP08oookJP03ocP0oooonf[ooo]Z00Sooo]Z00?oo`28oookJ_oonfX0N?oonfX0
0:Sooo]Z0_oo:0000ol0oe3ooo]ZoookJP07oookJP;o0?n^6_oonfX00ooo00cooo]ZoookJP0Koook
JP03oico0?oonf[ooo]Z00?ooo]Z00?oo`12oookJ_oonfX01?oonfX4o`0000;ooo]Z0ooo:003ool0
00[ooo]Z1?oo000MoookJPKoobP03ooonfX3ool001Kooo]Z1ooo0007oookJP03ool0U_lh0?oooo]Z
00Gooo]Z1_oo003ooookJR3ooo]Z0_l0oe0:oookJP03o`3o[_oonf[ooo]Z01Wooo]Z00?oo`0<oook
J_oonfX06_oonfX00onLo`3ooo]ZoookJP03oookJP03ool0@_oonf[ooo]Z00Cooo]Z1?l00003oook
JP05ool0Tol0]?oooo]ZomWo0?l04?l02ooonfX00ol07?oooo]ZoookJP0PoookJP03oonW0?oonf[o
oo]Z013ooo]Z00?ooc`0oookJ_oonfX06OoonfX00oooc`3ooo]ZoookJP08oookJP03ocP0oooonf[o
oo]Z00Sooo]Z00?oo`28oookJ_oonfX0NOoonfX00:_ooo]Z00?o0?m@oookJ_oonfX02?oonfX00ol0
ojkooo]ZoookJP0HoookJP03ool03?oonf[ooo]Z01[ooo]Z00?oW?l0oookJ_oonfX00ooonfX00ooo
04;ooo]ZoookJP04oookJP;o00000ooo:0001?oonf[oobP0oolX0?oo:005ool000Sooo]Z0ooo000N
oookJPGoobP04?oonfX2ool001Oooo]Z1_oo0008oookJP03ocP0oooonf[ooo]Z00Cooo]Z2?oo003o
oookJR7ooo]Z00?o0?m@oookJ_oonfX02?oonfX00ol0ojkooo]ZoookJP0IoookJP03ool03?oonf[o
oo]Z01Wooo]Z00?oW?l0oookJ_oonfX00ooonfX00ooo04;ooo]ZoookJP04oookJPCo00000_oonfX0
1Ooo09?ooo]Zo`2doooonf[o013o00cooo]Z00?o01cooookJ_oonfX07ooonfX00oooY`3ooo]Zoook
JP0@oookJP03ooll0?oonf[ooo]Z01Wooo]Z00?ooll0oookJ_oonfX02?oonfX00ooo09Ko>03ooook
JP08oookJP03ool0R?oonf[ooo]Z07[ooo]Z002/oookJP;o0?m@2OoonfX00ol0ojkooo]ZoookJP0G
oookJP03ool03?oonf[ooo]Z01[ooo]Z00?oW?l0oookJ_oonfX00ooonfX00ooo04;ooo]Zool00002
ool000;ooo]Z0_l00007oolX0003ool00?oIo`3oo`0000Goo`001?oonfX4ool001kooo]Z1?oo:00@
oookJP;oo`006?oonfX5ool000Sooo]Z00?o>03ooookJ_oonfX01OoonfX9ool00?oooo]Z8OoonfX2
o`3oD0Wooo]Z00?o0?n^oookJ_oonfX06?oonfX00ooo00cooo]ZoookJP0IoookJP03oico0?oonf[o
oo]Z00?ooo]Z00?oo`12oookJ_oonfX01?oonfX4o`0000;ooo]Z00Goo`2Co`2doooonf[ooo]Zo`0@
o`0;oookJP03o`0Loooonf[ooo]Z023ooo]Z00?oojL0oookJ_oonfX04?oonfX00ooo?03ooo]Zoook
JP0IoookJP03ooo?0?oonf[ooo]Z00Sooo]Z00?o>03ooookJ_oonfX01ooonfX00ooo08Sooo]Zoook
JP1koookJP00[_oonfX00ol0oe3ooo]ZoookJP07oookJP03o`3o[_oonf[ooo]Z01Kooo]Z00?oo`0<
oookJ_oonfX06OoonfX00onLo`3ooo]ZoookJP03oookJP03ool0@_oonf[ooo]Z00Koo`0000?o0000
oolX0?oo:0001Ooo:0000ol04?oooo]Zool00007ool000;ooo]Z0ooo000NoookJPGoobP04?oonfX0
0ooo003ooo]ZoookJP0FoookJPGoo`002?oonfX00ooo09Ko>03ooookJP06oookJPOoo`00oooonfXU
oookJP03o`3oD?oonf[ooo]Z00Oooo]Z00?o0?n^oookJ_oonfX05ooonfX00ooo00cooo]ZoookJP0H
oookJP03oico0?oonf[ooo]Z00Cooo]Z00?oo`12oookJ_oonfX01?oonfX4o`0000;ooo]Z00Goo`2C
o`2doooonf[ofOl0o`0@o`0;oookJP03o`0Loooonf[ooo]Z01oooo]Z00?oojL0oookJ_oonfX04?oo
nfX00ooo?03ooo]ZoookJP0IoookJP03ooo?0?oonf[ooo]Z00Sooo]Z00?o>03ooookJ_oonfX02?oo
nfX00ooo08Sooo]ZoookJP1koookJP00[ooonfX2o`3oD0Sooo]Z00?o0?n^oookJ_oonfX05_oonfX0
0ooo00cooo]ZoookJP0HoookJP03oico0?oonf[ooo]Z00?ooo]Z00?oo`12oookJ_oonfX02?oo0006
oolX0003o`0@oooo:03oo`0000Ooo`000_oonfX2ool001oooo]Z1?oo:00?oookJP;oo`0000?ooc`0
oookJ_oonfX05_oonfX4ool000Wooo]Z00?o>03ooookJ_oonfX01OoonfX7ool00?oooo]Z9ooonfX2
o`3oD0Sooo]Z0_l0ojhHoookJP03ool03?oonf[ooo]Z01Oooo]Z00?oW?l0oookJ_oonfX01?oonfX0
0ooo04;ooo]ZoookJP04oookJPCo000000Oooo]Zool0Tooonf[o0;CooookJ_oIo`3o013o00_ooo]Z
00?o01cooookJ_oonfX07ooonfX00oooY`3ooo]ZoookJP0@oookJP03ooll0?oonf[ooo]Z01Sooo]Z
00?ooll0oookJ_oonfX02?oonfX00olh0?oooo]ZoookJP08oookJP03ool0R?oonf[ooo]Z07cooo]Z
002aoookJP;o0?m@1ooonfX00ol0ojkooo]ZoookJP0EoookJP03ool03?oonf[ooo]Z01Sooo]Z00?o
W?l0oookJ_oonfX00ooonfX00ooo04;ooo]ZoookJP08ool000GoobP000?o013ooolX0?oo:0001ooo
0003oookJP03ool00?oonf[ooo]Z01[ooo]Z0_oo0002oookJP?oobP04?oonfX01Ooo003ooc`0ool0
0?oonf[oo`0001Kooo]Z0ooo0009oookJP03ocP0oooonf[ooo]Z00Kooo]Z1_oo003ooookJR[ooo]Z
0_l0oe08oookJP03o`3o[_oonf[ooo]Z01Gooo]Z00?oo`0<oookJ_oonfX05ooonfX00onLo`3ooo]Z
oookJP04oookJP03ool0@_oonf[ooo]Z00Cooo]Z1?l000000ooonf[oo`2Co`2do`02oookJP03o`0@
oooonf[ooo]Z00Wooo]Z00?o01cooookJ_oonfX07ooonfX00oooY`3ooo]ZoookJP0@oookJP04ooll
0?oonf[ooo]ZoeKo01Oooo]Z00?ooll0oookJ_oonfX02?oonfX00ooo09Ko>03ooookJP08oookJP03
ool0R?oonf[ooo]Z07gooo]Z002coookJP03o`3oD?oonf[ooo]Z00Gooo]Z00?o0?n^oookJ_oonfX0
5?oonfX00ooo00cooo]ZoookJP0HoookJP03oico0?oonf[ooo]Z00?ooo]Z00?oo`12oookJ_oonfX0
1ooo0009oolX00Koo`001?oonfX00ol07?oooo]ZoookJP0JoookJP?oo`0000?ooo]ZoolX0?oo:000
4?oonfX00ooo003ooc`0ool00003ool001Gooo]Z0ooo0009oookJP03ocP0oooonf[ooo]Z00Kooo]Z
1Ooo003ooookJRkooo]Z00?o0?m@oookJ_oonfX01_oonfX00ol0ojkooo]ZoookJP0DoookJP03ool0
3?oonf[ooo]Z01Oooo]Z00?oW?l0oookJ_oonfX01?oonfX00ooo04;ooo]ZoookJP04oookJPCo0000
00Kooo]Zool0Tol0]?oooo]ZomWo0?l04?l;oookJP03o`0Loooonf[ooo]Z01kooo]Z00?oojL0oook
J_oonfX04?oonfX01Ooo?03ooo]ZoookJ_oonf[oE_l001Oooo]Z00?ooll0oookJ_oonfX02?oonfX0
0olh0?oooo]ZoookJP07oookJP03ool0R?oonf[ooo]Z07kooo]Z002doookJP;o0?m@1_oonfX00ol0
ojkooo]ZoookJP0DoookJP03ool03?oonf[ooo]Z01Oooo]Z00?oW?l0oookJ_oonfX00ooonfX00ooo
04;ooo]ZoookJP07ool000WoobP01_oo0003oookJP03o`0Loooonf[ooo]Z01_ooo]Z1Ooo000Aoook
JP03ool00?oo?03oo`0000Coo`005?oonfX2ool000[ooo]Z00?o>03ooookJ_oonfX01_oonfX4ool0
0?oooo]Z<?oonfX2o`3oD0Oooo]Z00?o0?n^oookJ_oonfX05?oonfX00ooo00cooo]ZoookJP0Foook
JP03oico0?oonf[ooo]Z00?ooo]Z00?oo`12oookJ_oonfX01OoonfX4o`000006ool0Tooonf[o0;Co
oookJ_oIo`3o013o0ooonfX00omKo`3ooo]ZoookJP04oookJP03o`0Loooonf[ooo]Z01oooo]Z00?o
ojL0oookJ_oonfX04?oonfX01?oo?03ooo]ZoookJ_mFo`0GoookJP03ooo?0?oonf[ooo]Z00Sooo]Z
00?o>03ooookJ_oonfX02?oonfX00ooo08Sooo]ZoookJP1noookJP00]_oonfX00ol0oe3ooo]Zoook
JP04oookJP03o`3o[_oonf[ooo]Z01?ooo]Z00?oo`0<oookJ_oonfX05ooonfX00onLo`3ooo]Zoook
JP03oookJP03ool0@_oonf[ooo]Z00Koo`0000?o0000oolX0?oo:0001ooo:005ool000Cooo]Z00?o
01cooookJ_oonfX06_oonfX7ool0013ooo]Z00?ooc`0ool00?oo00001Ooo000CoookJP03ool00?oo
nf[ooo]Z00Sooo]Z00?o>03ooookJ_oonfX01_oonfX4ool00?oooo]Z<ooonfX00ol0oe3ooo]Zoook
JP05oookJP03o`3o[_oonf[ooo]Z01?ooo]Z00?oo`0<oookJ_oonfX05_oonfX00onLo`3ooo]Zoook
JP03oookJP03ool0@_oonf[ooo]Z00Gooo]Z1?l000001Ooo09?o0;CooookJ_oonf[o013o00Cooo]Z
00?oFol0oookJ_oonfX01?oonfX00ol07?oooo]ZoookJP0NoookJP03o`3o`_oonf[ooo]Z013ooo]Z
00Cooc`0oookJ_oonf[oE_l05ooonfX00oooc`3ooo]ZoookJP08oookJP03ocP0oooonf[ooo]Z00So
oo]Z00?oo`28oookJ_oonfX0OooonfX00;Oooo]Z00?o0?m@oookJ_oonfX00ooonfX00ol0ojkooo]Z
oookJP0CoookJP03ool03?oonf[ooo]Z01Oooo]Z00?oW?l0oookJ_oonfX00_oonfX01?oo04;ooo]Z
oookJ_oonfX6ool00003o`000?oo:03oobP000KoobP01_oo0002oolX00;ooo]Z00?o01cooookJ_oo
nfX06_oonfX8ool000kooo]Z00?ooc`0ool00?oo00001Ooo000CoookJP03ool00?oonf[ooo]Z00So
oo]Z00?o>03ooookJ_oonfX01ooonfX2ool00?oooo]Z=_oonfX00ol0oe3ooo]ZoookJP04oookJP03
o`3o[_oonf[ooo]Z01?ooo]Z00?oo`0<oookJ_oonfX05_oonfX00onLo`3ooo]ZoookJP03oookJP03
ool0@_oonf[ooo]Z00Gooo]Z1?l000001Ooo09?o0;CooookJ_oIo`3o013o00?ooo]Z00?oFol0oook
J_oonfX01OoonfX00ol07?oooo]ZoookJP0NoookJP03o`3o`_oonf[ooo]Z00oooo]Z00Gooc`0oook
J_oonf[ooo]ZoeKo000FoookJP03ooo?0?oonf[ooo]Z00Sooo]Z00?o>03ooookJ_oonfX02?oonfX0
0ooo08Sooo]ZoookJP20oookJP00^?oonfX00ol0oe3ooo]ZoookJP03oookJP03o`3o[_oonf[ooo]Z
01?ooo]Z00?oo`0<oookJ_oonfX05OoonfX00onLo`3ooo]ZoookJP03oookJP04ool0@_oonf[ooo]Z
oookJPKoo`0000?o0000oolX0?oo:0001_oo:005ool000KoobP07?oonfX8ool000gooo]Z00?ooc`0
ool00?oo00001Ooo000DoookJP03ooo?0?oonf[ooo]Z00;ooo]Z0_oo:004oookJP03ocP0oooonf[o
oo]Z00Oooo]Z00?oo`00oookJ_oonfX0oooonfXfoookJP03o`3oD?oonf[ooo]Z00Cooo]Z00?o0?n^
oookJ_oonfX04_oonfX00ooo00cooo]ZoookJP0FoookJP03oico0?oonf[ooo]Z00?ooo]Z00?oo`12
oookJ_oonfX00ooonfX00ol0Y?oooo]Zo`000003o`000005ool0Tol0]?oooo]ZomWo0?l04?l00ooo
nfX00omKo`3ooo]ZoookJP04oookJP03o`0Loooonf[ooo]Z01kooo]Z00?o0?o2oookJ_oonfX03ooo
nfX01Ooo?03ooo]ZoookJ_oonf[oE_l001Oooo]Z00?ooll0oookJ_oonfX02?oonfX00olh0?oooo]Z
oookJP07oookJP03ool0R?oonf[ooo]Z087ooo]Z002goookJP04ool00?oonf[o0?m@o`3oD0Cooo]Z
00?o0?n^oookJ_oonfX04_oonfX00ooo00cooo]ZoookJP0EoookJP03oico0?oonf[ooo]Z00?ooo]Z
00?oo`12oookJ_oonfX00_oonfX4ool000;o00002?oo:004ool00003oookJ_oo:03oobP000KoobP0
6_oonfX7ool000kooo]Z00?ooc`0ool00?oo00001?oo000DoookJP03ooo?0?oonf[ooo]Z00?ooo]Z
0ooo:002oookJP03ocP0oooonf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX0oooonfXhoookJP;o0?m@
1OoonfX00ol0ojkooo]ZoookJP0BoookJP03ool03?oonf[ooo]Z01Gooo]Z00?oW?l0oookJ_oonfX0
0_oonfX00ooo04;ooo]ZoookJP04oookJP03o`2Toooonf[o000000;o000000Goo`2CoookJ_l0]?oo
oo]Zo`0@o`04oookJP03oe_o0?oonf[ooo]Z00Cooo]Z00?o01cooookJ_oonfX07OoonfX00oooY`3o
0?o2oookJP0@oookJP04ooll0?oonf[ooo]ZoeKo01Oooo]Z00?ooll0oookJ_oonfX02?oonfX00olh
0?oooo]ZoookJP07oookJP03ool0R?oonf[ooo]Z08;ooo]Z002goookJP05ool00?oonf[ooo]Zoook
J_l0oe001?oonfX00ol0ojkooo]ZoookJP0AoookJP03ool03?oonf[ooo]Z01Gooo]Z00?oW?l0oook
J_oonfX00ooonfX00ooo04;ooo]ZoookJP02oookJPCoo`000_l00008oolX00Coo`0000?ooo]ZoolX
0?oo:0001_oo:008oookJP;oo`003ooonfX7ool000kooo]Z00?ooc`0ool00?oo00001?oo000Doook
JP03ooo?0?oonf[ooo]Z00?ooo]Z1Ooo:0000olh0?oooo]ZoookJP08oookJP03ool0R?oonf[ooo]Z
0?oooo]Z>_oonfX2o`3oD0Cooo]Z00?o0?n^oookJ_oonfX04OoonfX00ooo00cooo]ZoookJP0Eoook
JP03oico0?oonf[ooo]Z00;ooo]Z00?oo`12oookJ_oonfX01?oonfX00ol0Y?oooo]Zo`000002o`00
0005ool0Tol0]?oooo]ZoookJ_l04?l00ooonfX00omKo`3ooo]ZoookJP04oookJP03o`0Loooonf[o
oo]Z01kooo]Z00?o0?o2oookJ_oonfX03ooonfX01Ooo?03ooo]ZoookJ_oonf[oE_l001Kooo]Z00?o
oll0oookJ_oonfX02?oonfX00olh0?oooo]ZoookJP08oookJP03ool0R?oonf[ooo]Z08;ooo]Z002f
oookJP?oo`000ooonfX00ol0oe3ooo]ZoookJP02oookJP;o0?n^00?ooo]Zool00?oo00003ooonfX0
0ooo00cooo]ZoookJP0DoookJP03oico0?oonf[ooo]Z00?ooo]Z00?oo`12oookJ_oonfX00_oonfX3
ool00003oookJ_l0003o000000SoobP00ooo0002oookJPOoobP02OoonfX5ool000cooo]Z1_oo000>
oookJP03ooll0?oonf[oo`0000Coo`005?oonfX00oooc`3ooo]ZoookJP04oookJPKoobP02OoonfX0
0ooo08Sooo]ZoookJP3ooookJSgooo]Z00?o0?m@oookJ_oonfX00_oonfX00ol0ojkooo]ZoookJP0@
oookJP03ool03?oonf[ooo]Z01Gooo]Z00?oW?l0oookJ_oonfX00_oonfX00ooo04;ooo]ZoookJP03
oookJP03o`2Toooonf[ooo]Z00?o000000Goo`2Co`2doooonf[ofOl0o`0@o`03oookJP03oe_o0?oo
nf[ooo]Z00Cooo]Z00?o01cooookJ_oonfX07OoonfX00ol0ol;ooo]ZoookJP0?oookJP05ooll0?oo
nf[ooo]ZoookJ_mFo`005_oonfX00oooc`3ooo]ZoookJP08oookJP03ocP0oooonf[ooo]Z00Sooo]Z
00?oo`28oookJ_oonfX0PooonfX00;Gooo]Z1Ooo0003oookJP;o0?m@1?oonfX3ool00003oookJ_oo
N@3oogT000cooo]Z00?oo`0<oookJ_oonfX02OoonfX3ool000Sooo]Z00?oW?l0oookJ_oonfX00ooo
nfX00ooo04;ooo]ZoookJP02oookJP?oo`0000?ooo]Zo`000?l000001ooo:0001Ooonf[oo`00ool0
0?oo003ooo]Z00OoobP02_oonfX7ool000[ooo]Z1Ooo000:oookJP;oobP00ooonfX00ooo?03ooo]Z
ool00003ool001Gooo]Z00?ooll0oookJ_oonfX00ooonfX8oolX00Oooo]Z00?oo`28oookJ_oonfX0
oooonfXooookJP03o`3oD?oonf[ooo]Z00;ooo]Z00?o0?n^oookJ_oonfX03ooonfX00ooo00cooo]Z
oookJP0EoookJP03oico0?oonf[ooo]Z00;ooo]Z00?oo`12oookJ_oonfX00ooonfX00ol0Y?oooo]Z
oookJP03o`000004ool0Tol0]?oooo]Zo`0@o`Cooo]Z00?oFol0oookJ_oonfX01?oonfX00ol07?oo
oo]ZoookJP0LoookJP03oonW0?l0ol;ooo]Z013ooo]Z00Gooc`0oookJ_oonf[ooo]ZoeKo000Foook
JP03ooo?0?oonf[ooo]Z00Oooo]Z00?oo`2FocP0oooonfX02?oonfX00ooo08Sooo]ZoookJP24oook
JP00SOoonfX3ool000cooo]Z0_oo:00GoookJPKoo`001?oonfX00ol0oe3ooo]ZoookJP02ool00003
oomi0?oo003oo`0000;oogT03OoonfX00ooo00cooo]ZoookJP04oookJPOoo`002?oonfX00onLo`3o
oo]ZoookJP03oookJP03ool0@_oonf[ooo]Z00;ooo]Z0_oo0002oookJP;o00001_oo:002oookJP;o
o`000_oonfX7oolX00Wooo]Z2Ooo0008oookJPGoo`001?oonfX2ool000Gooo]Z0ooo:0000ooonf[o
oc`0oookJP04ool001Gooo]Z00?ooll0oookJ_oonfX01?oonfX9oolX00Gooo]Z00?oo`28oookJ_oo
nfX0oooonfY1oookJP03o`3oD?oonf[ooo]Z00;ooo]Z00?o0?n^oookJ_oonfX03ooonfX00ooo00co
oo]ZoookJP0DoookJP03oico0?oonf[ooo]Z00;ooo]Z00?oo`12oookJ_oonfX00ooonfX00ol0Y?oo
oo]ZoookJP03o`000004ool0Tol0]?oooo]Zo`0@o`?ooo]Z00?oFol0oookJ_oonfX01?oonfX00ol0
7?oooo]ZoookJP0MoookJP03o`3o`_oonf[ooo]Z00oooo]Z00Gooc`0oookJ_oonf[ooo]ZoeKo000F
oookJP03ooo?0?oonf[ooo]Z00Sooo]Z00?o>03ooookJ_oonfX01ooonfX00ooo08Sooo]ZoookJP25
oookJP00SOoonfX7ool000Sooo]Z1Ooo:00CoookJPSoo`001?oonfX00ol0oe3oo`00ool00002oomi
00;oo`000oooN@0<oookJP03ool03?oonf[ooo]Z00;ooo]Z2Ooo0008oookJP03oico0?oonf[ooo]Z
00;ooo]Z00?oo`12oookJ_oo:0001?oo:0000ooo003ooo]ZoookJP02o`000003oolX0?l0]?ooobP0
00CoobP000?ooo]Zool00?oonfX00_oonfX6oolX00[ooo]Z2Ooo0008oookJPCoo`001OoonfX3ool0
00?ooo]Z1_oo:0001?oonf[oo`00ool00?oo000EoookJP03ooo?0?oonf[ooo]Z00Cooo]Z2?oo:006
oookJP03ool0R?oonf[ooo]Z0?oooo]Z@ooonfX00ol0oe3ooo]ZoookJP02oookJP03o`3o[_oonf[o
oo]Z00kooo]Z00?oo`0<oookJ_oonfX05?oonfX00onLo`3ooo]ZoookJP02oookJP03ool0@_oonf[o
oo]Z00?ooo]Z00?o0:CooookJ_oonfX00_l000001Ooo09?o0;CooookJ_oonf[o013o00?ooo]Z00?o
Fol0oookJ_oonfX01?oonfX00ol07?oooo]ZoookJP0LoookJP03oonW0?l0ol;ooo]Z00oooo]Z00Go
oc`0oookJ_oonf[ooo]ZoeKo000FoookJP03ooo?0?oonf[ooo]Z00Sooo]Z00?o>03ooookJ_oonfX0
2?oonfX00ooo08Sooo]ZoookJP25oookJP00SOoonfX:ool000Gooo]Z1ooo:00@oookJP[oo`000ooo
nfX00ooo003o0?m@oomi0003oomi00;oo`000_ooN@0<oookJP03ool03?oonf[ooo]Z00;ooo]Z2Ooo
0008oookJP03oico0?oonf[ooo]Z00;ooo]Z00?oo`12oookJ_oo:0001ooo:002o`000003oolX0?l0
]?ooobP000OoobP00_oonfX5oolX00_ooo]Z2?oo0009oookJP?oo`001OoonfX6ool00003oookJ_oo
:03oobP000GoobP00_oo000EoookJP03ooo?0?oonf[ooo]Z00Gooo]Z1ooo:007oookJP03ool0R?oo
nf[ooo]Z0?oooo]ZA?oonfX00ol0oe3ooo]ZoookJP02oookJP03o`3o[_oonf[ooo]Z00gooo]Z00?o
o`0<oookJ_oonfX04ooonfX00onLo`3ooo]ZoookJP03oookJP03ool0@_oonf[ooo]Z00;ooo]Z00Co
0:CooookJ_oonf[ooo]Z0_l000001?oo09?o0;CooookJ_l04?l4oookJP03oe_o0?oonf[ooo]Z00?o
oo]Z00?o01cooookJ_oonfX03_oonfX00ondo`3ooo]ZoookJP0<oookJP03o`3o`_oonf[ooo]Z00oo
oo]Z00Gooc`0oookJ_oonf[ooo]ZoeKo000EoookJP03ooo?0?oonf[ooo]Z00Sooo]Z00?o>03ooook
J_oonfX02?oonfX00ooo08Sooo]ZoookJP26oookJP00SOoonfX>ool000[oobP04?oonfX9ool00003
oookJ_oo003oo`0000KoogT000Coo`00oomi0?ooN@3oogT03?oonfX00ooo00cooo]ZoookJP02oook
JPSoo`002?oonfX00onLo`3ooo]ZoookJP02oookJP04ool0@_oonf[oobP0oolX00Goo`0000GoobP0
o`000?l0003oo`2Co`2do`0>oolX00cooo]Z1ooo000:oookJP;oo`001_oonfX7ool000SoobP05_oo
nfX00oooc`3ooo]ZoookJP04oookJPSoobP01_oonfX00ooo08Sooo]ZoookJP3ooookJTKooo]Z0_l0
oe03oookJP03o`3o[_oonf[ooo]Z00gooo]Z00?oo`0<oookJ_oonfX04_oonfX00onLo`3ooo]Zoook
JP03oookJP03ool0@_oonf[ooo]Z00;ooo]Z00Co0:CooookJ_oonf[ooo]Z0_l000001?oo09?o0;Co
oookJ_l04?l3oookJP03oe_o0?oonf[ooo]Z00Cooo]Z00?o01cooookJ_oonfX03_oonfX00ondo`3o
oo]ZoookJP0;oookJP03o`3o`_oonf[ooo]Z00Sooo]Z00?oob00oookJ_oonfX01?oonfX01Ooo?03o
oo]ZoookJ_oonf[oE_l001Kooo]Z00?ooll0oookJ_oonfX01ooonfX00ooo09Ko>03ooookJP08oook
JP03ool0R?oonf[ooo]Z08Oooo]Z002=oookJPkoo`003Ooo:00@oookJPKoo`000_oo:007oomi00;o
o`0000?oogT0oolX0?oo:0002ooonfX00ooo00cooo]ZoookJP02oookJPSoo`002?oonfX00onLo`3o
oo]ZoookJP02oookJP04ool0@_oonf[oobP0oolX00Woo`0000?o0;CooolX0?oo:0003?oo:00<oook
JPKoo`002_oonfX2ool000Oooo]Z1_oo0007oolX0003ool00?oonf[ooo]Z01Cooo]Z00?ooll0oook
J_oonfX01OoonfX6oolX00Oooo]Z00?oo`28oookJ_oonfX0oooonfXIoookJPgo09[o7OoonfX2ok_o
00Cooo]Z00Go0?m@oookJ_oonf[ooo]Zo`3o[P0>oookJP03ool03?oonf[ooo]Z01;ooo]Z00?oW?l0
oookJ_oonfX00ooonfX00ooo04;ooo]ZoookJP02oookJP04o`2Toooonf[ooo]ZoookJP;o000000Co
o`2Co`2doooonf[o013o0ooonfX00omKo`3ooo]ZoookJP04oookJP03o`0Loooonf[ooo]Z00gooo]Z
00?o]?l0oookJ_oonfX02ooonfX00oooY`3o0?o2oookJP09oookJP03oolP0?oonf[ooo]Z00?ooo]Z
00Gooc`0oookJ_oonf[ooo]ZoeKo000FoookJP03ooo?0?oonf[ooo]Z00Oooo]Z00Goo`2FocP0oooo
nf[ooo]Zolh0o`06oookJP03ool0R?oonf[ooo]Z08Sooo]Z002=oookJPgoo`0000?ooo]ZoolX0?oo
:0003Ooo:00AoookJP;oo`000_oo:009oomi0004ool00?oo:03oobP0oolX00_ooo]Z00?oo`0<oook
J_oonfX00ooonfX?ool00003oico0?oonf[ooo]Z00;ooo]Z00Coo`12oookJ_oo:03oobP02Ooo0000
0ol0003oobP0oookJP07oolX0004oookJ_oo:03oobP0oolX00cooo]Z1_oo000;oookJP03ool00?oo
nf[ooo]Z00Gooo]Z1ooo0006oolX0003oookJ_mFo`3ooo]Z01Cooo]Z00?ooll0oookJ_oonfX01Ooo
nfX6oolX0003ool00?oonf[ooo]Z00Cooo]Z00?oo`28oookJ_oonfX0oooonfXWoookJPOo09[o6?oo
nfX00onko`3ooo]ZoookJP02oookJP05o`3oD?oonf[ooo]ZoookJ_l0ojh03OoonfX00ooo00cooo]Z
oookJP0BoookJP03oico0?oonf[ooo]Z00?ooo]Z00?oo`12oookJ_oonfX00_oonfX02_l0Y?oooo]Z
oookJ_oonf[o0000ool0Tol0]?oo0000o`0@oooIo`03oookJP03oe_o0?oonf[ooo]Z00?ooo]Z00?o
01cooookJ_oonfX03_oonfX00ondo`3ooo]ZoookJP0;oookJP03o`3o`_oonf[ooo]Z00Sooo]Z00?o
ob00oookJ_oonfX01?oonfX01Ooo?03ooo]ZoookJ_oonf[oE_l001Gooo]Z00?ooll0oookJ_oonfX0
2?oonfX01Olh0?oooo]ZoookJ_oonf[ocP3o00Kooo]Z00?oo`28oookJ_oonfX0R?oonfX008gooo]Z
2?oo0005oookJQ7oobP00ol0V_l>oookJPGoobP01oooN@05oolX00_ooo]Z00?oo`0<oookJ_oonfX0
0_ooN@0?ool00003oico0?oonf[ooo]Z00;ooo]Z00Coo`12oookJ_oonf[oobP02?oo00001?l0]?oo
fOl0o`0@oooonfX6oolX0004oookJ_oo:03oobP0oolX00gooo]Z1Ooo000;oookJP03oonW0?l0ol;o
oo]Z00Kooo]Z1ooo0005oolX0003oookJ_mFo`3ooo]Z01Gooo]Z00?ooll0oookJ_oonfX01OoonfX5
oolX0003ool00?oonf[ooo]Z00Cooo]Z00?oo`28oookJ_oonfX0oooonfX_oookJPKo09[o4ooonfX0
0onko`3ooo]ZoookJP02oookJP04o`3oD?oonf[ooo]Zo`3o[Pkooo]Z00?oo`0<oookJ_oonfX04Ooo
nfX00onLo`3ooo]ZoookJP03oookJP03ool0@_oonf[ooo]Z00;ooo]Z00Wo0:CooookJ_oonf[ooo]Z
o`000?oo09?o0;Coo`000?l04?l00ooonfX00omKo`3ooo]ZoookJP04oookJP03o`0Loooonf[ooo]Z
00gooo]Z00?o]?l0oookJ_oonfX02ooonfX00oooY`3o0?o2oookJP09oookJP03oolP0?oonf[ooo]Z
00?ooo]Z00Gooc`0oookJ_oonf[ooo]ZoeKo000FoookJP03ooo?0?oonf[ooo]Z00Oooo]Z00Go>03o
oookJ_oonf[ooo]Zolh0o`06oookJP03ool0R?oonf[ooo]Z08Wooo]Z002=oookJP?oo`002_oonfX8
oolX00cooo]Z1Ol0V_l8oookJPOoobP01oooN@04oolX00_ooo]Z1OooN@000ooonf[oo`00ool00003
ool00003oookJ_oo003oo`0000Koo`0000?oW?l0oookJ_oonfX00_oonfX01?oo04;ooo]ZoookJ_oo
:008ool00004o`2doooIo`3o013ooookJPKoobP000Cooo]ZoolX0?oo:03oobP03OoonfX6ool000[o
oo]Z00?o0?o2oookJ_oonfX01_oonfX6ool000GoobP000?ooo]ZoeKo0?oonfX03ooonfX2oolX00Co
oo]Z00?ooll0oookJ_oonfX01OoonfX5oolX00;oo`001OoonfX00ooo08Sooo]ZoookJP3ooookJSKo
oo]Z1Ol0V_l?oookJP;o^ol00_oonfX01Ol0oe3ooo]ZoookJ_oonf[o0?n^00gooo]Z00?oo`0<oook
J_oonfX04OoonfX00onLo`3ooo]ZoookJP03oookJP05ool0@_oonf[ooo]ZoookJ_l0Y?l01?oonfX0
1Ol0003oo`2Co`2dool0003o013o00?ooo]Z00?oFol0oookJ_oonfX01?oonfX00ol07?oooo]Zoook
JP0=oookJP03okCo0?oonf[ooo]Z00_ooo]Z00?o0?o2oookJ_oonfX02?oonfX00ooo803ooo]Zoook
JP03oookJP05ooll0?oonf[ooo]ZoookJ_mFo`005_oonfX00oooc`3ooo]ZoookJP07oookJP05ool0
U_lh0?oooo]ZoookJ_o>0?l01_oonfX00ooo08Sooo]ZoookJP2:oookJP00/ooonfX3o`2Jo`Oooo]Z
1ooo:006oomi00CoobP02?oonfX7oomi00;ooo]Z0ooo0003oolX00Koo`0000?ooo]Zoico0?oonfX0
0ol007l01?oo04;o001ooookJ_oo:007ool00003o`000?l0]?oo013o00;ooo]Z1Ooo:002oookJP;o
obP03_oonfX8ool000Oooo]Z00?o0?o2oookJ_oonfX01_oonfX6ool00003oookJ_oo:03oobP000;o
obP000?ooo]ZoeKo0?oonfX04?oonfX3oolX00;ooo]Z00?ooll0oookJ_oonfX01_oonfX4oolX00Co
o`001?oonfX00ooo08Sooo]ZoookJP3ooookJS_ooo]Z0ol0V_l>oookJP05ok_o0?oonf[ooo]Zo`3o
D?oonfX00_l0P?l00ol0ojkooo]ZoookJP0;oookJP03ool03?oonf[ooo]Z013ooo]Z00?oW?l0oook
J_l007l00_l007l00ooo04;o001ooookJP02oookJP03o`2Toooonf[ooo]Z00;ooo]Z00Goo`2Co`00
0?l0]?oo013oomWo0003oookJP03oe_o0?oonf[ooo]Z00?ooo]Z00?o01cooookJ_oonfX03OoonfX0
0ondo`3ooo]ZoookJP0;oookJP03o`3o`_oonf[ooo]Z00Sooo]Z00?oob00oookJ_oonfX01?oonfX0
1?oo?03ooo]ZoookJ_mFo`0FoookJP03ooo?0?oonf[ooo]Z00Oooo]Z00Goo`2FocP0oooonf[ooo]Z
olh0o`06oookJP03ool0R?oonf[ooo]Z08_ooo]Z002foookJP;o09[o2?oonfX6oolX00CoogT01?oo
:007oookJPSoogT00_oonfX6oolX00Koo`0000?ooo]Zoico0?l007l00ol007l01?oo04;o001oo`00
Oooo:007ool00004o`2dool0003o013ooookJPKoobP00_oonfX00ooo:03ooo]ZoookJP0=oookJP?o
o`0000?ooo]Zool00?oo00000ooo00000ooonf[oobP0oolX0003oookJP03o`3o`_oonf[ooo]Z00Ko
oo]Z1Ooo0002oookJP?oobP00_oonfX00omFo`3ooo]ZoookJP0>oookJPKoobP02?oonfX3oolX00Oo
o`000_oonfX00ooo08Sooo]ZoookJP3ooookJSoooo]Z0_l0V_l=oookJP04ok_o0?oonf[ooo]Zo`3o
D0;ooo]Z00?o083oo`3o[_oonfX02ooonfX00ooo00cooo]ZoookJP05oookJP03ofko0?oonf[ooo]Z
00Sooo]Z00?oW?l0o`00Ool007l00_l007l00ooo04;o001oo`00O`02oookJP03o`2Toooonf[ooo]Z
00;ooo]Z00Goo`2Co`2dool0003o013oomWo0002oookJP03oe_o0?oonf[ooo]Z00Cooo]Z00?o01co
oookJ_oonfX03OoonfX00ondo`3ooo]ZoookJP0;oookJP03o`3o`_oonf[ooo]Z00Sooo]Z00?oob00
oookJ_oonfX00ooonfX01Ooo?03ooo]ZoookJ_oonf[oE_l001Gooo]Z00?ooll0oookJ_oonfX01ooo
nfX01Ooo09Ko>03ooookJ_oonf[ocP3o00Oooo]Z00?oo`28oookJ_oonfX0RooonfX00;Sooo]Z0ol0
V_l7oookJPGoobP01?ooN@04oolX00Kooo]Z2?ooN@08oolX00Koo`0000?ooo]Zoico0?l007l00_l0
07l01Ooonf[oo`12o`00Ool007ooobP000Koo`0000Goo`2Co`2doooIo`3o013ooookJP05oolX00?o
oo]Z00?o01cooookJ_oonfX03?oonfX3ool00003oookJ_oo003oo`0000Goo`000ooo:0000ooonf[o
0?o2oookJP08oookJPCoo`000_oonfX3oolX00;ooo]Z00?oE_l0oookJ_oonfX03ooonfX6oolX00So
oo]Z0_oo:006ool000?ooo]Z00?oo`28oookJ_oonfX0oooonfY2oookJP?o09[o2ooonfX00onko`3o
oo]ZoookJP02o`3oD003oookJ_l0P?oooo]Z00cooo]Z00?oo`0<oookJ_oonfX01?oonfX00om^o`3o
oo]ZoookJP08oookJP06oico0?l007oo001oo`00Oooonf[oo`120_l007l2oookJP03o`2Toooonf[o
oo]Z00;ooo]Z00Coo`2Co`2dool0003o013o0ooonfX00omKo`3ooo]ZoookJP04oookJP03o`0Loooo
nf[ooo]Z00cooo]Z00?o]?l0oookJ_oonfX02ooonfX00ol0ol;ooo]ZoookJP08oookJP03oolP0?oo
nf[ooo]Z00?ooo]Z00Gooc`0oookJ_oonf[ooo]ZoeKo000FoookJP03ooo?0?oonf[ooo]Z00Oooo]Z
00Coo`2FocP0oooonf[ocP3o1ooonfX00ooo08Sooo]ZoookJP2<oookJP00^ooonfX2o`2Jo`Oooo]Z
00?oobP0oomi0?oo:0000_oo:002oomi00CoobP01ooonfX7oomi00SoobP01_oo00001?oonf[oW?l0
o`00Ool007l2oookJP03ool0@_l007oo001o00;oobP01Ooo00001Ooo09?o0;CoomWo0?l04?oooo]Z
00CoobP01?oonfX00ol07?oooo]ZoookJP0<oookJP;oo`000_oonfX7ool000GoobP02?oonfX4ool0
00;ooo]Z0ooo:002oookJP03oeKo0?oonf[ooo]Z013ooo]Z1ooo:006oookJP;oobP01_oo0003oook
JP03ool0R?oonf[ooo]Z0?oooo]ZA_oonfX2o`2Jo`[ooo]Z00Oo^ol0oookJ_oonf[ooo]Zo`3oD?oo
nf[o083o00cooo]Z00?oo`0<oookJ_oonfX00ooonfX00ol007ooK_l0o`00O`07o`00O`;ooo]Z00?o
W?l0o`00Ool007l00_oonfX01_oo04;o001oo`00Ool007oooo]Zo`2To`Cooo]Z00Coo`2Co`2dool0
003o013o0ooonfX00omKo`3ooo]ZoookJP03oookJP03o`0Loooonf[ooo]Z00gooo]Z00?o]?l0oook
J_oonfX02_oonfX00oooY`3o0?o2oookJP09oookJP03oolP0?oonf[ooo]Z00?ooo]Z00Cooc`0oook
J_oonf[oE_l05_oonfX00oooc`3ooo]ZoookJP07oookJP04ool0U_lh0?oooo]Zolh0o`Oooo]Z00?o
o`28oookJ_oonfX0SOoonfX00;gooo]Z0_l0V_l6oookJP07oomi0?oonf[oobP0oolX0?oonf[oobP0
oomi0004oolX00Oooo]Z1oooN@07oolX00Koo`0000?ooo]Zoico0?oonfX00ooonfX00ooo04;o001o
o`00O`02oolX00Coo`0000Coo`2Co`000?l0]?oo013o0_l00004oolX00?ooo]Z00?o01cooookJ_oo
nfX02?oonfX2oolX00?ooo]Z00Coo`00oookJ_oonf[ooo]Z1_oo0007oolX00Oooo]Z0ooo0003oook
JP?oobP00_oonfX00omFo`3ooo]ZoookJP0?oookJPWoobP01OoonfX00ooo:03oo`00ool00003ool0
00;oobP00_oonfX00ooo:03ooo]ZoookJP3ooookJTWooo]Z0ol0V_l8oookJP07ok_o0?oonf[ooo]Z
oookJ_l0oe3o083oo`3o[P0;oookJP03ool03?oonf[ooo]Z00?ooo]Z0_l007l00om^o`3o001oo`00
O`05o`00O`;ooo]Z00?oW?l0oookJ_oonfX00_oonfX02?oo04;o001oo`00Ool007oooo]Zo`2Toooo
nf[oWOl00_oonfX01?oo09?o0;Coo`0@oooIo`02o`000003oe_o0?oonf[ooo]Z00Cooo]Z00?o01co
oookJ_oonfX03?oonfX00ondo`3ooo]ZoookJP0;oookJP03o`3o`_oonf[ooo]Z00Sooo]Z00?oob00
oookJ_oonfX00ooonfX01Ooo?03ooo]ZoookJ_oonf[oE_l001Gooo]Z00?ooll0oookJ_oonfX01ooo
nfX01Ooo09Ko>03ooookJ_oonf[ocP3o00Kooo]Z00?oo`28oookJ_oonfX0S_oonfX00;oooo]Z0_l0
V_l3oookJP?oogT00_oonfX01?oo:03ooo]ZoolX0?ooN@03oolX00Sooo]Z1_ooN@07oolX0003oook
J_oo003oo`0000CoobP000?oW?l0oookJ_oonfX00_oonfX01Ooo04;o001oo`00Ool007ooobP000Co
o`0000Koo`2Co`2dool0003o013oo`000?oonfX3oolX00Cooo]Z00?o01cooookJ_oonfX02?oonfX4
oolX0003oookJ_ndo`3ooo]Z00;ooo]Z1_oo0008oolX00Kooo]Z0_oo0003oookJPKoobP04_oonfX7
oolX00Kooo]Z00?oobP0ool00?oo00000ooo00001_oonf[oobP0oolX0?oo:03ooo]ZoolX0?oooo]Z
C_oonfX2o`2Jo`Oooo]Z0_nko`02oookJP03o`3oD?l0P?oo0?n^00_ooo]Z00?oo`0<oookJ_oonfX0
1?oonfX00om^o`3ooo]ZoookJP07oookJP03oico0?oonf[ooo]Z00;ooo]Z00koo`12o`00Ool007oo
001ooookJ_l0Y?oooo]Zoigo0?oonf[oo`2Co`000?l0]?oo013oomWo00;ooo]Z00?oFol0oookJ_oo
nfX01?oonfX00ol07?oooo]ZoookJP0<oookJP03okCo0?oonf[ooo]Z00[ooo]Z00?o0?o2oookJ_oo
nfX02?oonfX00ooo803ooo]ZoookJP03oookJP05ooll0?oonf[ooo]ZoookJ_mFo`005OoonfX00ooo
c`3ooo]ZoookJP07oookJP05ool0U_lh0?oooo]ZoookJ_o>0?l01ooonfX00ooo08Sooo]ZoookJP2>
oookJP00XOoonfX3ool000Wooo]Z0_oo:00BoookJP;o09[o1OooN@02oookJP04ok_o0?oonf[ooo]Z
o`3oD0?oobP01ooonfX6oomi0003oookJ_oo:03oobP000_oobP000?oW?l0o`00Ool007l00_oonfX0
0ooo04;o001ooolX0004oolX0008ool00?oonf[oo`2Co`2dool0003o013oo`000?oonfX3oolX00Co
oo]Z00?o01cooookJ_oonfX02?oonfX5oolX00?ooo]Z1ooo0008oolX00Gooo]Z0_oo0004oookJP03
oolX0?oo?03oobP000CoobP04?oonfX7oolX00Kooo]Z00?oo`2FocP0oooo00000ooo00000ooonf[o
obP0oolX0003oolX0?oooo]ZDOoonfX00ol0V_oooo]ZoookJP06oookJP06ok_o0?oonf[ooo]Zo`3o
D?l0P?oo0?n^2_oonfX00ooo00cooo]ZoookJP04oookJP03ofko0?oonf[ooo]Z00Oooo]Z00?oW?l0
o`00Ool007l00_oonfX01Ooo04;o001oo`00Ool007oo0:Co00;ooo]Z00OoWOl0oookJ_oo09?o0;Co
o`000?l04?oo000000;ooo]Z00?oFol0oookJ_oonfX00ooonfX00ol07?oooo]ZoookJP0<oookJP03
okCo0?oonf[ooo]Z00Cooo]Z00?o00OooookJ_oonfX01?oonfX00ol0ol;ooo]ZoookJP08oookJP03
oolP0?oonf[ooo]Z00?ooo]Z00Cooc`0oookJ_oonf[oE_l05_oonfX00oooc`3ooo]ZoookJP06oook
JP05ool0U_oonf[o>03ooookJ_o>0?l01ooonfX00ooo08Sooo]ZoookJP2?oookJP00XOoonfX6ool0
00Kooo]Z1?oo:00AoookJPOoogT00_oonfX01?nko`3ooo]ZoookJ_l0oe02oolX0003o`3o[_oonf[o
oo]Z00Gooo]Z1OooN@000ooonf[oobP0oolX000;oolX00CoogT000?oo`12o`00Ool007l02Ooo:000
1?l04?oo0000o`000?oonfX2oolX00Gooo]Z00?o01cooookJ_oonfX02?oonfX7oolX0003oookJ_oo
003oo`0000Coo`0000?ooo]ZoolX0?oo:0001Ooo:006oookJP03ool00?oonf[ooo]Z00?ooo]Z00?o
oc`0oolX0?oo:0001Ooo:00?oookJPKoobP01ooonfX00olh0?ooo`00ool00002ool000;ooo]Z1_oo
:03ooookJU7ooo]Z00?o09[ooookJ_oonfX01_oonfX01_nko`3ooo]ZoookJ_l0oe3o083oo`3o[P[o
oo]Z00?oo`0<oookJ_oonfX00ooonfX00om^o`3ooo]ZoookJP03oookJP05o`0Ioooonf[ooo]Zoook
J_nLo`001?l007l01Ooo04;o001oo`00Oooonf[o0:Co00;ooo]Z00WoWOl0oookJ_oo09?o0;Coo`00
0?l04?oo0000oookJ_mKo`001_oonfX00ol07?oooo]ZoookJP0<oookJP03okCo0?oonf[ooo]Z00Co
oo]Z00?o00OooookJ_oonfX00ooonfX00ol0ol;ooo]ZoookJP08oookJP03oolP0?oonf[ooo]Z00?o
oo]Z00Cooc`0oookJ_oonf[oE_l05_oonfX00oooc`3ooo]ZoookJP07oookJP04ool0U_lh0?oooo]Z
olh0o`Oooo]Z00?oo`28oookJ_oonfX0T?oonfX00:7ooo]Z2Ooo0003oookJPKoobP03_oonfX8oomi
00?ooo]Z00Co^ol0oookJ_oonf[o0?m@0_oo:0000ol0ojkooo]ZoookJP05oookJPCoogT00_oonfX8
oolX00coogT02?oo:0001Ol04?oo0000o`000?oonf[oobP000Gooo]Z00?o01cooookJ_oonfX02?oo
nfX9oolX00Goo`0000?ooo]ZoolX0?oo:0001Ooo:007oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?o
oc`0oolX0?oo:0001Ooo:00@oookJPGoobP01ooonfX01?lh0?oooo]Zool00?oo0003oookJPSoobP0
oooonfYAoookJP;o09[o1ooonfX01_nko`3ooo]ZoookJ_l0oe3ooo]Zo`3o[PWooo]Z00?oo`0<oook
J_oonfX00ooonfX00om^o`3ooo]ZoookJP03oookJP05o`0Ioooonf[ooo]ZoookJ_nLo`001?l007l0
1ooo04;o001ooookJ_oonf[o0:CooookJ_nMo`000_oonfX01ooo09?o0;Coo`000?l04?oo0000oook
J_mKo`001_oonfX00ol07?oooo]ZoookJP0;oookJP03okCo0?oonf[ooo]Z00Cooo]Z00?o00Oooook
J_oonfX01?oonfX00ol0ol;ooo]ZoookJP08oookJP03oolP0?oonf[ooo]Z00;ooo]Z00Gooc`0oook
J_oonf[ooo]ZoeKo000EoookJP03ooo?0?oonf[ooo]Z00Oooo]Z00Coo`2FocP0oooonf[ocP3o1ooo
nfX00ooo08Sooo]ZoookJP2AoookJP00XOoonfX;ool000WoobP02ooonfX:oomi00?ooo]Z00Ko^ol0
oookJ_oonf[o0?m@oolX0?l0ojh8oookJP?oogT00ooonfX7oolX00coogT01ooo:0001_l0003o013o
o`000?l0003ooo]Zoe_o00Gooo]Z00?o01cooookJ_oonfX02?oonfX9oolX00Coo`000_oonfX6oolX
00Oooo]Z00?oob00oookJ_oonfX00ooonfX00ooo?03oobP0oolX0004oolX013ooo]Z1Ooo:007oook
JP04ocP0oooonf[ooo]Zool000Cooo]Z1_oo:03ooookJUGooo]Z0_l0V_l6oookJP05ok_o0?oonf[o
0?m@o`20ool0ojh02_oonfX00ooo00cooo]ZoookJP03oookJP03ofko0?oonf[ooo]Z00;ooo]Z00Go
01WooookJ_oonf[ooo]Zoico0002o`00O`;ooo]Z00Ooo`12oookJ_oonf[ooo]Zo`2Toooonf[oWOl0
00;ooo]Z00?oo`2Co`2dool04?l00_l000000ooonf[oFol0oookJP04oookJP03o`0Loooonf[ooo]Z
00cooo]Z00?o]?l0oookJ_oonfX01?oonfX00ol01ooooo]ZoookJP03oookJP03o`3o`_oonf[ooo]Z
00Sooo]Z00?oob00oookJ_oonfX00ooonfX01?oo?03ooo]ZoookJ_mFo`0EoookJP03ooo?0?oonf[o
oo]Z00Oooo]Z00Coo`2FocP0oooonf[ocP3o1ooonfX00ooo08Sooo]ZoookJP2BoookJP00XOoonfX;
ool000_oobP02ooonfX9oomi00?ooo]Z00Ko^ol0oookJ_oonf[o0?m@oolX0?l0ojh7oookJPCoogT0
0_oonfX8oolX00_oogT01ooo:0001_l04?oofOl0o`000?l0003ooo]Zoe_o00Gooo]Z00?o01cooook
J_oonfX02?oonfX8oolX00Coo`000ooonfX5oolX00;ooo]Z0_oo:003oookJP03oolP0?oonf[ooo]Z
00?ooo]Z00?ooc`0oolX0?oo:0001?oo:00AoookJP?oobP02?oonfX01?oo09Ko>03ooookJ_oo0004
oookJPKoobP0oooonfXjoookJPCob?l06_oonfX00ol0V_oooo]ZoookJP04oookJP05ok_o0?oonf[o
0?m@o`20ool0ojh02OoonfX00ooo00cooo]ZoookJP03oookJP03ofko0?oonf[ooo]Z00?ooo]Z00Co
01WooookJ_oonf[oW?l00_l007l2oookJP07ool0@_oonf[ooo]ZoookJ_l0Y?oooo]Zoigo0002oook
JP03ool0Tol0]?oo013o00;o000000?ooo]Zoe_o0?oonfX01?oonfX00ol07?oooo]ZoookJP0;oook
JP03okCo0?oonf[ooo]Z00Cooo]Z00?o00OooookJ_oonfX01?oonfX00ol0ol;ooo]ZoookJP07oook
JP03oolP0?oonf[ooo]Z00?ooo]Z00Cooc`0oookJ_oonf[oE_l05OoonfX00oooc`3ooo]ZoookJP07
oookJP04ool0U_lh0?oooo]Zolh0o`Oooo]Z00?oo`28oookJ_oonfX0TooonfX00:3ooo]Z3?oo000=
oolX00cooo]Z1oooN@03oookJP06ok_o0?oonf[ooo]Zo`3oD?l0P?oo0?n^1ooonfX3oomi00?ooo]Z
0ooo:0001?oo003oobP0oolX0?oo:00:oomi0003o`00Oooo:03oobP000CoobP000?o0;Coo`0@oooI
o`000_l000000omKo`3ooo]ZoookJP03oookJP03o`0Loooonf[ooo]Z00Wooo]Z1ooo:0001?oonf[o
o`00ool00?oo0003oookJPGoobP00ooonfX4oolX0003oookJ_oo803ooo]Z00?ooo]Z00?ooc`0oolX
0?oo:0001?oo:00AoookJP?oobP02OoonfX01?lh0?oooo]ZoookJ_o>0?l4oookJPGoobP0oooonfXo
oookJP[ob?l04OoonfX00ol0V_oooo]ZoookJP04oookJP05ok_o0?oonf[o0?m@o`20ool0ojh02?oo
nfX00ooo00cooo]ZoookJP03oookJP03ofko0?oonf[ooo]Z00?ooo]Z00Go01WooookJ_oonf[oW?l0
oookJP03o`00O`07ool0@_l007oo001oo`00Ool0Y?oooo]Zoigo0002oookJP03o`2dool0003o013o
00;o000000?ooo]Zoe_o0?oonfX00ooonfX00ol07?oooo]ZoookJP0<oookJP03okCo0?oonf[ooo]Z
00Cooo]Z00?o00OooookJ_oonfX00ooonfX00ol0ol;ooo]ZoookJP08oookJP03oolP0?oonf[ooo]Z
00;ooo]Z00Gooc`0oookJ_oonf[ooo]ZoeKo000EoookJP03ooo?0?oonf[ooo]Z00Oooo]Z00Co>03o
oookJ_oonf[ocP3o1_oonfX00ooo08Sooo]ZoookJP2DoookJP00X?oonfX;ool0013oobP03?oonfX5
oomi00Cooo]Z00Ko^ol0oookJ_oonf[o0?m@o`20ool0ojh7oookJP;oogT00ooonfX3oolX0004ool0
0?oo:03oobP0oolX00[oogT000?o001ooolX0?oo:0001?oo:0000ol0]?oo013oo`000002o`000003
oe_o0?oonf[ooo]Z00?ooo]Z00?o01cooookJ_oonfX02OoonfX6oolX00;ooo]Z0_oo0004oookJPCo
obP00ooonfX6oolX00Gooo]Z00?ooc`0oolX0?oo:0000ooo:00BoookJP;oobP02OoonfX01?lh0?oo
oo]ZoookJ_o>0?l4oookJPGoobP0oooonfY:oookJP?ob?l03ooonfX00ol0V_oooo]ZoookJP04oook
JP05ok_o0?oonf[o0?m@o`20ool0ojh02?oonfX00ooo00cooo]ZoookJP02oookJP03ofko0?oonf[o
oo]Z00?ooo]Z00Go01WooookJ_oonf[oW?l0oookJP02o`00O`05ool0@_l007oo001oo`00Ool0Y?l0
0_oonfX01_nMo`3ooo]Zool0Tol0]?oo0000o`0@o`;o000000?oFol0oookJ_oonfX00ooonfX00ol0
7?oooo]ZoookJP0;oookJP03okCo0?oonf[ooo]Z00Cooo]Z00?o00OooookJ_oonfX00ooonfX00ol0
ol;ooo]ZoookJP08oookJP03oolP0?oonf[ooo]Z00?ooo]Z00Cooc`0oookJ_oonf[oE_l05OoonfX0
0oooc`3ooo]ZoookJP07oookJP04ocP0oooonf[ooo]Zolh0o`Oooo]Z00?oo`28oookJ_oonfX0U?oo
nfX00:3ooo]Z2?oo0003oookJPkoobP00_ooN@001?oo:03ob?l0olSo0?o8o`0:oookJPCoogT01?oo
nfX01onko`3ooo]ZoookJ_l0oe3o083oo`3o[_ooN@001_oonfX00oooN@3ooo]ZoookJP02oookJP;o
obP000?ooo]Zool00?oo:0000_oo:009oomi0003oookJ_oo:03oobP000CoobP000?ooo]Zo`0@ool0
00000_l000000omKo`3ooo]ZoookJP02oookJP03o`0Loooonf[ooo]Z00Wooo]Z1ooo:0000ooonf[o
o`00ool00005oookJP?oobP01?oonfX8oolX00;ooo]Z00?ooc`0oookJ_oo:0000ooo:002ool0017o
oo]Z00?oobP0oookJ_oonfX01ooonfX01?lh0?oooo]ZoookJ_o>0?l5oookJPCoobP0oooonfY>oook
JPCob?l03?oonfX2o`2Jo`Gooo]Z00Go^ol0oookJ_l0oe3o083oo`3o[P07oookJP03ool03?oonf[o
oo]Z00;ooo]Z00?oK_l0oookJ_oonfX00ooonfX01?l06Ooooo]ZoookJ_nLo`03oookJP05ool0@_oo
nf[ooo]ZoookJ_l0Y?l00_oonfX01_nMo`3ooo]Zool0Tol0]?oo0000o`0@o`;o000000?oFol0oook
J_oonfX00ooonfX00ol07?oooo]ZoookJP0;oookJP03okCo0?oonf[ooo]Z00Cooo]Z00?o00Oooook
J_oonfX00ooonfX00ol0ol;ooo]ZoookJP07oookJP03oolP0?oonf[ooo]Z00?ooo]Z00Cooc`0oook
J_oonf[oE_l05OoonfX00oooc`3ooo]ZoookJP07oookJP04ool0U_lh0?oooo]Zolh0o`Oooo]Z00?o
o`28oookJ_oonfX0UOoonfX00:3ooo]Z0ooo000FoookJPCoogT00_oonfX4olSo00Wooo]Z0_ooN@04
oookJP06ok_o0?oonf[ooo]Zo`3oD?ooN@3o0?n^1?oob@02oookJP03ool03?oonf[ooo]Z00;ooo]Z
0_oo:0000ooonf[oo`00oolX0002oolX00WoogT000?ooo]ZoolX0?oo:0000ooo:0000ol0]?oooo]Z
o`0@o`02o`000003oe_o0?oonf[ooo]Z00?ooo]Z00?o01cooookJ_oonfX02OoonfX8oolX0003ool0
0?oonf[ooo]Z00Cooo]Z0_oo:005oookJPWoobP000?ooo]Zooll0?oo:0000ooo:004ool000oooo]Z
00?oobP0oookJ_oonfX01ooonfX01?lh0?oooo]ZoookJ_o>0?l5oookJP?oobP0oooonfYDoookJPCo
b?l02_oonfX2o`2Jo`Cooo]Z00Go^ol0oookJ_l0oe3ooo]Zo`3o[P06oookJP03ool03?oonf[ooo]Z
00?ooo]Z00?oK_l0oookJ_oonfX00_oonfX01?l06Ooooo]ZoookJ_nLo`03oookJP07ool0@_oonf[o
oo]ZoookJ_l0Y?oooo]Zoigo0002oookJP04o`2doooonf[ofOl0o`0@o`;o000000?oFol0oookJ_oo
nfX00_oonfX00ol07?oooo]ZoookJP0;oookJP03okCo0?oonf[ooo]Z00Cooo]Z00?o00OooookJ_oo
nfX00ooonfX00ol0ol;ooo]ZoookJP08oookJP03oolP0?oonf[ooo]Z00?ooo]Z00Cooc`0oookJ_oo
nf[oE_l05?oonfX00oooc`3ooo]ZoookJP07oookJP04ool0U_lh0?oooo]Zolh0o`Oooo]Z00?oo`28
oookJ_oonfX0U_oonfX00;Wooo]Z1_ooN@04oookJP?ob?l02?oonfX00oooN@3o09[ooookJP02oook
JP04ok_o0?ooN@3o0?m@o`20o`GoolT00_oonfX00ooo00cooo]ZoookJP03oookJP03oolX0?oonf[o
o`0000?oobP02OooN@000ooonf[oobP0oolX0003oolX0003o`2dool04?oo000000;o000000?oFol0
oookJ_oonfX00_oonfX00ol07?oooo]ZoookJP0:oookJP[oobP01?oonfX2oolX00Gooo]Z2?oo:002
oookJP03ooll0?oonf[oobP000;oobP01_oo000>oookJP03ooo?0?oonf[ooo]Z00Kooo]Z00Goo`2F
ocP0oooonf[ooo]Zolh0o`05oookJP;oobP0oooonfYIoookJP?ob?l02OoonfX2o`2Jo`;ooo]Z00Go
^ol0oookJ_l0oe3o083oo`3o[P07oookJP03ool03?oonf[ooo]Z00;ooo]Z00?oK_l0oookJ_oonfX0
0_oonfX01?l06Ooooo]ZoookJ_nLo`03oookJP07ool0@_oonf[ooo]ZoookJ_l0Y?oooo]Zoigo0002
oookJP03o`2doooonf[o013o00?o000000?oFol0oookJ_oonfX00_oonfX00ol07?oooo]ZoookJP0;
oookJP03okCo0?oonf[ooo]Z00Cooo]Z00?o00OooookJ_oonfX00ooonfX00ol0ol;ooo]ZoookJP07
oookJP03oolP0?oonf[ooo]Z00?ooo]Z00Kooc`0oookJ_oonf[oE_l0oookJ_l0N?lCoookJP03ooo?
0?oonf[ooo]Z00Kooo]Z00Goo`2FocP0oooonf[ooo]Zolh0o`06oookJP03ool0R?oonf[ooo]Z09Oo
oo]Z002hoookJPWoogT01OoonfX2olSo00Kooo]Z00?oogT0oookJ_l0V_l00_oonfX2oomi00SoolT0
0_oonfX00ooo00cooo]ZoookJP02oookJP03ofko0?oo:03oobP000CoobP01oooN@02oookJPCoobP0
00?oo`2Co`2dool04?l00ol000000omKo`3ooo]ZoookJP02oookJP03o`0Loooonf[ooo]Z00[ooo]Z
2ooo:003oookJP03oolX0?oonf[ooo]Z00Cooo]Z1ooo:002oookJP03ooll0?oonf[ooo]Z00;oobP0
1Ooo000?oookJP03ooo?0?oonf[ooo]Z00Oooo]Z00Co>03ooookJ_oonf[ocP3o1OoonfX2oolX0?oo
oo]ZGOoonfX2olSo00Wooo]Z00So09[ooookJ_oonf[o^ol0oookJ_l0oe3o083oo`3o[PKooo]Z00?o
o`0<oookJ_oonfX00_oonfX00om^o`3ooo]ZoookJP02oookJP04o`0Ioooonf[ooo]Zoico00?ooo]Z
00Ooo`12oookJ_oonf[ooo]Zo`2Toooonf[oWOl000;ooo]Z00?o0;CooookJ_l04?l00ol000000omK
o`3ooo]ZoookJP02oookJP03o`0Loooonf[ooo]Z00_ooo]Z00?o]?l0oookJ_oonfX00ooonfX00ol0
1ooooo]ZoookJP03oookJP03o`3o`_oonf[ooo]Z00Oooo]Z00?oob00oookJ_oonfX00ooonfX01ooo
?03ooo]ZoookJ_oonf[oE_l0oookJ_l0N?l04_oonfX00oooc`3ooo]ZoookJP07oookJP04ocP0oooo
nf[ooo]Zolh0o`Kooo]Z00?oo`28oookJ_oonfX0V?oonfX00:oooo]Z1ooo05L2oookJP[oogT01_oo
nfX2olSo00?ooo]Z0oooN@001?oonf[o09[ooomi0?ooN@08ooo900;oogT000?ooo]Zool03?oonfX0
0ooonfX00om^o`3oobP0oolX0004oolX00OoogT000?ooo]Zo`2Toooo:0000ooo:0000ooonf[o0;Co
o`0@o`03o`000005oe_o0?oonf[ooo]ZoookJ_l07?l03OoonfX3oolX0003oookJ_oo:03oobP000Ko
obP00_oonfX00ol0ol;ooo]ZoookJP04oookJPKoobP00ooonfX01?oo?03ooo]ZoolX0?oo:005ool0
00oooo]Z00?ooll0oookJ_oonfX01ooonfX01?lh0?oooo]ZoookJ_o>0?l6oookJP03oolX0?oonf[o
oo]Z0?oooo]ZA_oonfX7ool0Ea7ooo]Z0_o8o`08oookJP03o`2Joooonf[ooo]Z00;o^ol000?o0?m@
o`20ool0ojh01_oonfX01Ooo00cooo]ZoookJ_oonf[oK_l000Cooo]Z00Go01WooookJ_oonf[ooo]Z
oico0002oookJP0<ool0@_oonf[ooo]ZoookJ_l0Y?oooo]Zoigo0?oonf[oo`2Co`2doooonf[o013o
0_l000000omKo`3ooo]ZoookJP02oookJP03o`0Loooonf[ooo]Z00_ooo]Z00?o]?l0oookJ_oonfX0
1?oonfX00ol01ooooo]ZoookJP03oookJP03o`3o`_oonf[ooo]Z00Oooo]Z00?oob00oookJ_oonfX0
0ooonfX01_oo?03ooo]ZoookJ_mFo`3ooo]Zo`1hoa;ooo]Z00?ooll0oookJ_oonfX01ooonfX01?lh
0?oooo]ZoookJ_o>0?l6oookJP03ool0R?oonf[ooo]Z09Wooo]Z002SoookJPcoo`1G1ooonfX2ool0
E`coogT01_oonfX2olSo00KoogT000?o09[oooo90?oob@001ooob@02oomi0003oookJ_oo00cooo]Z
00Cooo]Z00?oK_l0oolX0?oo:0000ooo:007oomi0003oookJ_l0Y?ooogT000;oobP00oooN@001?l0
4?ooogT0oomi0?mKo`02o`0000;ooo]Z00?o01cooookJ_oonfX02_oonfX3oolX00;ooo]Z2?oo:000
0ooonf[o0?o2oookJP05oookJPKoobP00ooonfX01?oo?03ooo]ZoookJ_oo:005ool000oooo]Z00?o
oll0oookJ_oonfX01ooonfX01?lh0?oooo]ZoookJ_o>0?l6oookJP03oolX0?oonf[ooo]Z0?oooo]Z
>_oonfX=ool0E`Oooo]Z2_oo05L9oookJP;ob?l01ooonfX01ol0V_oooo]ZoookJ_oonf[o^ol0o`3o
D?l0P?l01_oonfX00ooo00cooo]ZoookJP02oookJP05ofko0?oonf[ooo]ZoookJ_l06Ol00ooonfX0
1?nLo`3ooo]ZoookJ_oo0483oookJP08o`2Toooonf[oWOl0oookJ_oo09?o0;CooookJ_l04?l2o`00
0003oe_o0?l0003ooo]Z00;ooo]Z00?o01cooookJ_oonfX02ooonfX00ondo`3ooo]ZoookJP03oook
JP03o`07oooonf[ooo]Z00?ooo]Z00?o0?o2oookJ_oonfX01ooonfX00ooo803ooo]ZoookJP03oook
JP06ooll0?oonf[ooo]ZoeKo0?oonf[o07So4_oonfX00oooc`3ooo]ZoookJP07oookJP04ocP0oooo
nf[ooo]Zolh0o`Kooo]Z00?oo`28oookJ_oonfX0V_oonfX009oooo]Z1?oo05L7oookJPoo0?ob3Ooo
N@05oookJPOoogT000?ooo]Zo`2JooooN@001ooob@03oomi0003oookJ_oo00cooo]Z00?ooo]Z00?o
K_l0oolX0?oo:0001?oo:002oomi0007oookJ_ooN@3oogT0oomi0?oonf[o0:Cooomi0002oolX00;o
ogT000KofOl0o`0@ooooN@3oogT0oe_o0?l00003oookJP03o`0Loooonf[ooo]Z00[ooo]Z0_oo:003
oookJPOoobP000?ooo]Zo`3o`_oonfX01_oonfX5oolX00?ooo]Z00Gooc`0oookJ_oonf[ooo]ZoeKo
0004ool000oooo]Z00?ooll0oookJ_oonfX01OoonfX2oolX0004ool0U_lh0?oooo]Zolh0o`Oooo]Z
00?oo`28oookJ_oonfX0oooonfXgoookJP?oo`1G2?oonfXCo`3olP?ooo]Z1Ooo05L6oookJP;ob?l0
1_oonfX01ol0V_oooo]ZoookJ_oonf[o^ol0o`3oD?l0P?l01_oonfX01Ooo00cooo]ZoookJ_oonf[o
K_l000Cooo]Z00Co01WooookJ_oonf[oW?l00_oonfX01_oo04;ooo]ZoookJ_oonf[o0:Cooigo00;o
oo]Z00Coo`2Co`2doooIo`3o013o0_l000000omKo`3ooo]ZoookJP02oookJP03o`0Loooonf[ooo]Z
00_ooo]Z00?o]?l0oookJ_oonfX00ooonfX00ol01ooooo]ZoookJP03oookJP03o`3o`_oonf[ooo]Z
00Oooo]Z00?oob00oookJ_oonfX00_oonfX01ooo?03ooo]ZoookJ_oonf[oE_l0oookJ_l0N?l04Ooo
nfX00oooc`3ooo]ZoookJP07oookJP04ool0U_lh0?oooo]Zolh0o`Oooo]Z00?oo`28oookJ_oonfX0
V_oonfX009_ooo]Z1?oo05L4oookJPOo0?ob3OoonfX@oomi0003ool0Eooonf[ooo]Z00WoogT000?o
oo]Zo`2Jool0V_l01_oob@03oomi00;ooo]Z00Koo`0<oookJ_oonf[ooo]Zofko0?oonfX5oolX00;o
ogT000Oooo]Zoomi0?ooN@3oogT0oookJ_l0Y?ooogT000;oobP00_ooN@001_l04?ooogT0oomi0?l0
003oFol0o`0000;ooo]Z00?o01cooookJ_oonfX02ooonfX01?oo:03ooo]ZoookJ_oonfX7oolX0003
oookJ_ooY`3o0?o200Oooo]Z1?oo:003oookJP05ooll0?oonf[ooo]ZoookJ_mFo`001?oo000?oook
JP03ooo?0?oonf[ooo]Z00Kooo]Z0_oo:0001?lh0?oooo]ZoookJ_o>0?l6oookJP03ool0R?oonf[o
oo]Z0?oooo]Z=?oonfX4ool0E`?ooo]Z2?l0oo8CoookJPCo0?ob1?oonfX3ool0E`Gooo]Z0_o8o`05
oookJP07o`2Joooonf[ooo]Zok_o0?oonf[o0?m@o`3o[P05oookJP05ool03?oonf[ooo]ZoookJ_m^
o`001?oonfX01?l06Ooooo]ZoookJ_nLo`02oookJP06ool0@_oonf[ooo]ZoookJ_l0Y?ooWOl00_oo
nfX00ooo09?o0;Coo`0@o`02o`000003oe_o0?l0003ooo]Z00;ooo]Z00?o01cooookJ_oonfX02ooo
nfX00ondo`3ooo]ZoookJP03oookJP03o`07oooonf[ooo]Z00?ooo]Z00?o0?o2oookJ_oonfX01ooo
nfX00ooo803ooo]ZoookJP02oookJP07ooll0?oonf[ooo]ZoookJ_mFo`3ooo]Zo`1ho`0BoookJP03
ooo?0?oonf[ooo]Z00Kooo]Z00Goo`2FocP0oooonf[ooo]Zolh0o`06oookJP03ool0R?oonf[ooo]Z
09_ooo]Z002GoookJPCoo`1G0ooonfX5o`3olQGooo]Z3oooN@000ooonf[oo`1Gool0E`0:oomi0003
oookJ_oob@3o09[o00KoolT00_ooN@02oookJP06ool03?oonf[ooo]Zooo90?m^o`3ooo]Z1Ooo:002
oomi0003oookJ_ooN@3oogT000;ooo]Z00?o0:Cooomi0?oo:0000oooN@001_l04?ooogT0oomi0?l0
003oFol0o`0000;ooo]Z00?o01cooookJ_oonfX02ooonfX01?ndo`3ooo]ZoookJ_oonfX6oolX00;o
oo]Z00?o0?o2oookJ_oonfX01OoonfX4oolX00Cooo]Z00Cooc`0oookJ_oonf[oE_l00ooo000@oook
JP03ooo?0?oonf[ooo]Z00Kooo]Z0_oo:0001?lh0?ooobP0oolX0?o>0?l6oookJP03ool0R?oonf[o
oo]Z0?oooo]Z<?oonfX5ool0E`;ooo]Z1Ol0oo8OoookJPGo0?ob0_oonfX2ool0E`Gooo]Z0_o8o`04
oookJP06o`2Joooonf[ooo]Zok_o0?l0oe3o083o1OoonfX01Ooo00cooo]ZoookJ_oonf[oK_l000Co
oo]Z00Co01WooookJ_oonf[oW?l00_oonfX01_oo04;ooo]ZoookJ_oonf[o0:Cooigo00;ooo]Z00?o
o`2Co`2dool04?l00_l000000omKo`3o0000oookJP02oookJP03o`0Loooonf[ooo]Z00_ooo]Z00?o
]?l0oookJ_oonfX00ooonfX00ol01ooooo]ZoookJP02oookJP03oonW0?l0ol;ooo]Z00Oooo]Z00?o
ob00oookJ_oonfX00ooonfX01?oo?03ooo]ZoookJ_mFo`02oookJP03o`1hoooonf[ooo]Z00oooo]Z
00?ooll0oookJ_oonfX01_oonfX01Ooo09Ko>03ooookJ_oonf[ocP3o00Kooo]Z00?oo`28oookJ_oo
nfX0W?oonfX008gooo]Z2Ooo:0000ooo05Oooo]ZoookJP02oookJP?o0?ob6_oonfX@oomi00;o0?ob
0ooo05L7oomi0004oookJ_oob@3ooo]Zoomi00GoolT00oooN@02oookJPCoolT000GoK_l0oolX0?oo
:03oobP0o`0Io`02oolX0004oomi0?oonf[ooo]Zoomi00;ooo]Z00?o0:Cooomi0?nMo`000oooN@00
1_l04?ooogT0oomi0?l0003oFol0o`0000;ooo]Z00?o01cooookJ_oonfX02_oonfX00ondo`3ooo]Z
oookJP02oookJPGoobP00_oonfX00oooY`3o0?o2oookJP06oookJP?oobP01?oonfX01?oo?03ooo]Z
oookJ_mFo`03ool0013ooo]Z00?ooll0oookJ_oonfX01ooonfX00ooo:03o>03ooolX0003oolX00Go
oo]Z00?oo`28oookJ_oonfX0oooonfX]oookJPCoo`1G1?oonfX3o`3olRWooo]Z1?l0oo83ool0E`Co
oo]Z00?ob?l0oookJ_oonfX00_oonfX2o`2Jo`04oookJ_nko`3o0?m@o`20o`Gooo]Z00Goo`0<oook
J_oonf[ooo]Zofko0003oookJP04o`0Ioooonf[ooo]Zoico00;ooo]Z00_oo`12oookJ_oonf[o0:Co
oookJ_nMo`3ooo]Zool0Tooonf[o0;Coo`0@o`02o`000003oe_o0?l0003ooo]Z00;ooo]Z00?o01co
oookJ_oonfX02_oonfX00ondo`3ooo]ZoookJP03oookJP03o`07oooonf[ooo]Z00?ooo]Z00?o0?o2
oookJ_oonfX01ooonfX00ooo803ooo]ZoookJP02oookJP04ooll0?oonf[ooo]ZoeKo00;ooo]Z00?o
07SooookJ_oonfX03ooonfX00oooc`3ooo]ZoookJP07oookJP04ocP0oooonf[ooo]Zolh0o`Kooo]Z
00?oo`28oookJ_oonfX0WOoonfX008Gooo]Z3ooo:004oookJP?o0?ob;ooonfX3o`3olP?oo`1G1?oo
N@0:ooo900;oogT000?ooo]Zooo90?oob@000ooob@002?m^o`3ooo]ZoolX0?oo:03o01WooolX0?oo
nf[oW?l00_oonfX01_ooN@3ooo]ZoookJ_l0Y?ooogT0oigo00KoogT000?oFol0o`000?l000000_oo
nfX00ol07?oooo]ZoookJP0:oookJP04okCo0?oonf[ooo]ZoookJPGoobP00_oonfX00oooY`3o0?o2
oookJP07oookJP;oobP01?oonfX01Ooo?03ooo]ZoookJ_oonf[oE_l000;oo`004?oonfX00oooc`3o
oo]ZoookJP07oookJP03oolX0?lh0?ooo`0000GoobP00ooonfX00ooo08Sooo]ZoookJP3ooookJR_o
oo]Z0ooo05L5oookJP?o0?ob<?oonfX3o`3olP;oo`1G0ooonfX2olSo00Cooo]Z00Go09[ook_o0?oo
nf[o0?m@o`20o`05oookJP04ool03?oonf[ooo]Zofko00?ooo]Z00Cooj@0o`0Ioooonf[oW?l00_oo
nfX03Ooo04;ooo]ZoookJ_l0Y?oooo]Zoigo0?oonf[oo`2Co`2doooonf[o013oo`000?mKo`000_l0
0002oookJP03o`0Loooonf[ooo]Z00_ooo]Z00?o]?l0oookJ_oonfX00ooonfX00ol01ooooo]Zoook
JP02oookJP03oonW0?l0ol;ooo]Z00Oooo]Z00?oob00oookJ_oonfX00_oonfX01ooo?03ooo]Zoook
J_oonf[oE_l0oookJ_l0N?l04OoonfX00oooc`3ooo]ZoookJP07oookJP04ocP0oooonf[ooo]Zolh0
o`Kooo]Z00?oo`28oookJ_oonfX0W_oonfX008Gooo]Z4_oo:0000ol0oo;ooo]ZoookJP0`oookJP?o
ogT00_l0oo801?oonf[oo`1Goomi0?ooN@07ooo90004oomi0?oob@3oolT0ooo900?oogT01Ooob@00
0om^o`3ooo]ZoolX0002oomi0003oolX0?oonf[oW?l000;ooo]Z00Koo`12oookJ_oonf[o0:Cooomi
0?nMo`06oomi0003oe_o0?l0003o000000;ooo]Z00?o01cooookJ_oonfX02OoonfX00ondo`3ooo]Z
oookJP02oookJPCoobP00ooonfX00ol0ol;ooo]ZoookJP06oookJP;oobP01?oonfX01ooo?03ooo]Z
oookJ_oonf[oE_l0oookJ_oo00004?oonfX00oooc`3ooo]ZoookJP08oookJP04ocP0oooo003oo`00
ool000GoobP000?ooo]Zool0R?oonfX0oooonfXZoookJP?oo`1G1OoonfX3o`3olSKooo]Z00Co0?ob
oookJ_oo05Ooo`1G0ooonfX00oo8o`3ooo]ZoookJP02oookJP05o`2Joonko`3ooo]Zo`3oD?l0P?l0
1?oonfX01?oo00cooo]ZoookJ_m^o`03oookJP04oonT0?l06Ooooo]Zoico00;ooo]Z00goo`12oook
J_oonf[o0:CooookJ_nMo`3ooo]Zool0Tol0]?oofOl0o`0@ool0003oFol000;o00000_oonfX00ol0
7?oooo]ZoookJP0:oookJP03okCo0?oonf[ooo]Z00?ooo]Z00?o00OooookJ_oonfX00ooonfX00ol0
ol;ooo]ZoookJP07oookJP05oolP0?oonf[ooo]ZoookJ_oo?0000ooonfX01?mFo`3ooo]ZoookJ_l0
N?l@oookJP03ooo?0?oonf[ooo]Z00Oooo]Z00Go>03ooookJ_oonf[ooo]Zolh0o`05oookJP03ool0
R?oonf[ooo]Z09oooo]Z0025oookJQ3oobP09OoonfX2oomi00gooo]Z1_ooN@03o`3olPWoolT000Co
ogT0ooo90?oob@3oolT00_ooN@05ooo900GoogT000?oobP0oookJ_nLo`000_ooN@000ooo04;oogT0
oomi0002oomi0003oigo0?ooN@3oogT000CoogT000GoFol0o`000?l0003ooo]Zo`0Lo`0<oookJP03
okCo0?oonf[ooo]Z00;ooo]Z0ooo:003oookJP03oonW0?l0ol;ooo]Z00Oooo]Z00?oobP0oookJ_oo
nfX00ooonfX01_oo?03oobP0oookJ_mFo`3ooo]Zool0017ooo]Z00?ooll0oookJ_oonfX01ooonfX0
0ooo:03o>03oool00003ool000;oobP00_oonfX00ooo08Sooo]ZoookJP3ooookJROooo]Z0ooo05L5
oookJP?o0?ob>_oonfX3o`3olP;oo`1G0_oonfX02Oo8o`3ooo]ZoookJ_oonf[o09[ooookJ_nko`3o
oo]Zo`3oD005oookJP04ool03?oonf[ooo]Zofko00?ooo]Z00?o01WooookJ_nLo`000_oonfX03Ooo
04;ooo]ZoookJ_l0Y?oooo]Zoigo0?oonf[oo`2Co`2dool04?oooo]Zo`000?mKo`000_l00002oook
JP03o`0Loooonf[ooo]Z00[ooo]Z00?o]?l0oookJ_oonfX00_oonfX00ol01ooooo]ZoookJP03oook
JP03oonW0?l0ol;ooo]Z00Oooo]Z00?oob00oookJ_oonfX00_oonfX01?oo?03ooo]ZoookJ_mFo`02
oookJP03o`1hoooonf[ooo]Z00oooo]Z00?ooll0oookJ_oonfX01_oonfX01Ooo09Ko>03ooookJ_oo
nf[ocP3o00Gooo]Z00?oo`28oookJ_oonfX0X?oonfX008Kooo]Z3_oo:00BoookJPGoobP03ooonfX5
oomi00[ooo]Z1oooN@000ooonf[oolT0o`3olP09ooo90003oomi0?oob@3oolT000;oogT00ooob@07
oomi0003oolX0?oonf[oW?l000;oogT000?oo`12oomi0?ooN@000_ooN@000onMo`3oogT0oomi0004
oomi0005oe_o0?l0003o0000oookJ_l07?l02ooonfX00ondo`3ooo]ZoookJP03oookJP;oobP01?oo
nfX00ol0ol;ooo]ZoookJP07oookJP03oolP0?oonf[ooo]Z00;ooo]Z00Cooc`0oolX0?oo:03oE_l0
0_oonfX00ol0N?oooo]ZoookJP0>oookJP03ooo?0?oonf[ooo]Z00Oooo]Z00?oo`2FocP0oooo0000
1Ooo0002oookJP03ool0R?oonf[ooo]Z0?oooo]Z9OoonfX3ool0E`Gooo]Z0ol0oo90oookJP;o0?ob
00Coo`1GoookJ_oonf[ob?l00ooonfX01Ol0V_oooo]Zok_o0?l0oe3o083o00Cooo]Z00Coo`0<oook
J_oonf[oK_l00ooonfX00ol06Ooooo]Zoico0002oookJP0=ool0@_oonf[ooo]Zo`2Toooonf[oWOl0
oookJ_oo09?o0;Coo`0@oooonf[o0000oe_o0002o`000003oookJ_l07?oooo]Z00_ooo]Z00?o]?l0
oookJ_oonfX00ooonfX00ol01ooooo]ZoookJP03oookJP03o`3o`_oonf[ooo]Z00Oooo]Z00Goob00
oookJ_oonf[ooo]Zooll0002oookJP05oeKo0?oonf[ooo]ZoookJ_l0N?l04?oonfX00oooc`3ooo]Z
oookJP06oookJP05ool0U_lh0?oooo]ZoookJ_o>0?l01OoonfX00ooo08Sooo]ZoookJP2QoookJP00
Q?oonfX2ool0E`coobP05?oonfX=oolX00Kooo]Z3ol0o`48oomi00goolT000?oogT0ooo90?oob@00
0_ooN@000ooob@3oogT0oomi0006oomi0006o`0Ioooonf[oW?l0oookJ_ooN@3oo`121?ooN@000onM
o`3oogT0oomi0004oomi0005oe_o0?ooN@3o0000oookJ_l07?l02ooonfX00ondo`3ooo]ZoookJP02
oookJP;oobP01?oonfX00oooY`3o0?o2oookJP07oookJP03oolP0?oonf[ooo]Z00;ooo]Z00Oooc`0
oolX0?oo:03oobP0oeKo0?oo:03o07So013ooo]Z00?ooll0oookJ_oonfX02?oonfX00olh0?ooo`00
ool00006ool00003ool0R?oonf[ooo]Z0?oooo]Z9?oonfX2ool0E`Gooo]Z0ol0oo8ZoookJQ3o0?l1
2ooonfX01?l0oo;oo`1Gool0EooonfX2olSo00;ooo]Z00Go09[ooookJ_nko`3o0?m@o`20o`03oook
JP04ool03?oonf[ooo]Zofko00?ooo]Z00?o01WooookJ_nLo`000_oonfX03Ooo04;ooo]ZoookJ_l0
Y?oooo]Zoigo0?oonf[oo`2Co`2dool04?oooo]Zo`000?mKo`000_l000000ooonf[o01cooookJP0;
oookJP03okCo0?oonf[ooo]Z00;ooo]Z00?o00OooookJ_oonfX00ooonfX00oooY`3o0?o2oookJP07
oookJP05oolP0?oonf[ooo]ZoookJ_oo?0000ooonfX01?mFo`3ooo]ZoookJ_l0N?l@oookJP03ooo?
0?oonf[ooo]Z00Oooo]Z00Ko>03ooookJ_oonf[ocP3ooookJ_n40?l3oookJP03ool0R?oonf[ooo]Z
0:;ooo]Z0021oookJP?oo`1G0_oonfX:oolX01Kooo]Z4Ooo:002o`3o0@03oookJ_ooN@3oogT000Wo
ogT00ooonfX9oomi00ooolT00_ooN@000ooob@3oogT0oomi0006oomi0003o`0IooooN@3oW?l000;o
ogT000Goo`12oomi0?ooN@3oogT0oigo000=oomi00Wooo]Z00?o]?l0oookJ_oonfX00ooonfX00ooo
:03ooo]ZoookJP03oookJP03o`3o`_oonf[ooo]Z00Oooo]Z00?oob00oookJ_oonfX00_oonfX01?oo
?03oobP0oolX0?mFo`03oolX013ooo]Z00?ooll0oookJ_oonfX01ooonfX00olh0?ooobP0ool00008
ool00?oooo]Z8ooonfX3ool0E`Cooo]Z0ol0oo8WoookJPKo0?l14?oonfX4o`3o0@Sooo]Z0ol0oo80
0ooo05Oooo]ZolSo0002oookJP05o`2Joooonf[o^ol0o`3oD?l0ojh00ooonfX01?oo00cooo]Zoook
J_m^o`02oookJP03o`0Ioooonf[oW?l000;ooo]Z00coo`12oookJ_oonf[o0:CooookJ_nMo`3ooo]Z
o`2doooonf[o013ooookJ_mKo`03o`000003oookJ_l07?oooo]Z00[ooo]Z00?o]?l0oookJ_oonfX0
0_oonfX00ol01ooooo]ZoookJP03oookJP03oonW0?l0ol;ooo]Z00Oooo]Z00?oob00oookJ_oonfX0
0_oonfX01?oo?03ooo]ZoookJ_mFo`02oookJP03o`1hoooonf[ooo]Z00kooo]Z00?ooll0oookJ_oo
nfX01ooonfX01?lh0?oooo]ZoookJ_o>0?l2oookJP04oh@0oooonf[ooo]Zool0R:Gooo]Z001noook
JP?oo`001OoonfX2o`3olPOoobP05ooonfX?oolX00Gooo]Z6OooN@08ooo90003oookJ_oob@3oolT0
00;oolT000Co0?m@oomi0?ooN@3oolT02OooN@001?nLo`3oogT0oomi0?oo0483oomi0003oigo0?oo
N@3oogT000googT01ooonfX00ondo`3ooo]ZoookJP03oookJP03o`07oooonf[ooo]Z00?ooo]Z00?o
0?o2oookJ_oonfX01_oonfX00ooo803ooo]ZoookJP02oookJP04ooll0?oonf[oobP0oeKo00GoobP0
3_oonfX00oooc`3ooo]ZoookJP07oookJP03ocP0oooo:03oo`0000Ooo`001ooonfX2ool00?oooo]Z
6_oonfX2ool0E`Cooo]Z0ol0oo8ToookJPKo0?l16_oonfX4o`3o0@Oooo]Z0_l0oo802?oonf[ob?l0
oookJ_oonf[o09[ooookJ_l0oe3o083o0ooonfX01?oo00cooo]ZoookJ_m^o`02oookJP06o`0Ioooo
Y03ooo]Zoico0?oonf[oo`120_oonfX02Ol0Y?oooo]Zoigo0?oonf[o0;CoomWo0?l04?oooo]Zoe_o
0003o`000003oookJ_l07?oooo]Z00[ooo]Z00?o]?l0oookJ_oonfX00_oonfX00ol01ooooo]Zoook
JP03oookJP03o`3o`_oonf[ooo]Z00Kooo]Z00?oob00oookJ_oonfX00_oonfX01?oo?03ooo]Zoook
J_mFo`02oookJP03o`1hoooonf[ooo]Z00kooo]Z00?ooll0oookJ_oonfX01ooonfX01?lh0?oooo]Z
oookJ_o>0?l2oookJP04oh@0oooonf[ooo]Zool0R:Kooo]Z001ioookJPKoo`001?oonfX3o`3olP03
oookJ_oo:03oobP000CoobP05?oonfX5ool000coobP01OoonfX2oooo01googT01_oob@000ooonf[o
olT0ooo90002ooo90004o`3oD?ooN@3oiOl0onGo00SoogT00ooob@001Ooo04;oogT0oomi0?ooN@3o
WOl000ooogT01ooonfX00ondo`3ooo]ZoookJP02oookJP03o`07oooonf[ooo]Z00?ooo]Z00?oojL0
o`3o`_oonfX01_oonfX00ooo803ooo]ZoookJP03oookJP03ooll0?oo:03oE_l000OoobP03?oonfX0
0oooc`3ooo]ZoookJP07oookJP03ool0U_lh0?ooobP000Ooo`0000?oo`28oookJ_oonfX01OoonfX3
ool00?oooo]Z5ooonfX2ool0E`?ooo]Z0ol0oo8QoookJPKo0?l12_oonfXEoooo00Gooo]Z0ol0o`46
oookJP03o`3ol_oonf[ob?l000;ooo]Z00Co09[ook_o0?l0oe3o0?n^0_oonfX01?oo00cooo]Zoook
J_m^o`03oookJP05o`0Ioooonf[oW?l0oookJ_oo04800_oonfX01_l0Y?oooo]Zoigo0?oonf[o0;Co
o`0@o`;ooo]Z00GoFol0o`000?l0003o0000o`0Lo`0;oookJP03okCo0?oonf[ooo]Z00;ooo]Z00?o
00OooookJ_oonfX00ooonfX00oooY`3o0?o2oookJP07oookJP03oolP0?oonf[ooo]Z00;ooo]Z00Co
oc`0oookJ_oonf[oE_l00_oonfX00ol0N?oooo]ZoookJP0>oookJP03ooo?0?oonf[ooo]Z00Kooo]Z
00Coo`2FocP0oooonf[ocP3o0_oonfX01On40?oooo]ZoookJ_oonf[oo`280:Kooo]Z001doookJP[o
o`000_oonfX3ool000Kooo]Z0_oo:00>oookJPkoo`002Ooo:002oookJPGoool00_oonfX@oomi00;o
oo]Z00?oool0oomi0?ooN@002OooN@0;ooo900CoiOl01_ooN@08ooo900ooogT01ooonfX00ondo`3o
oo]ZoookJP03oookJP03o`07ooooN@3oogT000?ooo]Z00?o0?o2oookJ_oonfX01_oonfX00ooo803o
oo]ZoookJP02oookJP04ooll0?oonf[oobP0oeKo00GoobP03OoonfX00oooc`3ooo]ZoookJP07oook
JP03ool0U_lh0?ooobP000Koo`0000?ooo]Zool0R?oonfX01_oonfX5ool00?oooo]Z5?oonfX2ool0
E`?ooo]Z0_l0oo8PoookJPCo0?l13?oonfX4oooo01Gooo]Z1oooo`001?oonf[o0?l1o`3o0Ol0o`44
oookJP09o`3ol_oonf[ob?l0olSo0?oonf[o09[ook_o0?l0oe3o0?n^00;ooo]Z00Coo`0<oookJ_oo
nf[oK_l00_oonfX01Ol06Ooooo]Zoico0?oonf[oo`1200;ooo]Z00Ko0:CooookJ_nMo`3oo`2Co`2d
ool04?l2oookJP05oe_o0?l0003o0000o`000?l07?l02ooonfX00ondo`3ooo]ZoookJP02oookJP03
o`07oooonf[ooo]Z00?ooo]Z00?o0?o2oookJ_oonfX01_oonfX00ooo803ooo]ZoookJP02oookJP04
ooll0?oonf[ooo]ZoeKo00;ooo]Z00?o07SooookJ_oonfX03_oonfX00oooc`3ooo]ZoookJP06oook
JP04ool0U_lh0?oooo]Zolh0o`;ooo]Z00GoQ03ooookJ_oonf[ooo]Zool0R02WoookJP00LOoonfX@
ool000Sooo]Z00?oobP0oookJ_oonfX03OoonfX=ool00003oookJ_oo:03oobP000CoobP00_oonfX3
oooo00Oooo]Z4oooN@06oookJP;oolT01?ooN@08ooo900KoiOl01_ooN@08ooo900ooogT01ooonfX0
0ondo`3ooo]ZoookJP02oookJP03o`07oooonf[oogT000CoogT000?o0?o2oookJ_oonfX01OoonfX0
0ooo803ooo]ZoookJP02oookJP04ooll0?oonf[ooo]ZoeKo00GoobP03_oonfX00oooc`3ooo]Zoook
JP07oookJP03ocP0oooonf[oobP000Goo`0000?ooo]Zool0R?oonfX01ooonfX6ool00?oooo]Z4Ooo
nfX2ool0E`?ooo]Z0_l0oo8PoookJP;o0?l13OoonfX3oooo023ooo]Z0oooo`000ooonf[o0?l1o`3o
0@03oookJP08o`3ol_oonf[ooo]ZolSo0?oonf[o09[ook_o0?l0oe03oookJP03ool03?oonf[oK_l0
00;ooo]Z00Go01WooookJ_nLo`3ooo]Zool0@P02oookJP06o`2ToonMo`3ooo]Zool0Tol0]?oo013o
0_oonfX01OmKo`3o0000o`000?l0003o01co00[ooo]Z00?o]?l0oookJ_oonfX00ooonfX00ol01ooo
oo]ZoookJP02oookJP03oonW0?l0ol;ooo]Z00Kooo]Z00?oob00oookJ_oonfX00_oonfX01ooo?03o
oo]ZoookJ_oonf[oE_l0oookJ_l0N?l04?oonfX00oooc`3ooo]ZoookJP07oookJP03ocP0oooonf[o
cP3o00;ooo]Z00GoQ03ooookJ_oonf[ooo]Zool0R00<oookJP03oon70?oonf[ooo]Z09Wooo]Z001a
oookJPooo`006OoonfX;ool000?ooo]Z1?oo:004oooo00[ooo]Z0oooN@04oookJPooogT00ooonfX6
ooo90003o`3o0Ooob@3oolT000CoolT02?oUo`05oomi00SoolT03_ooN@08oookJP03okCo0?oonf[o
oo]Z00;ooo]Z00?o00OooookJ_ooN@000oooN@000ol0ol;oogT0oomi0006oookJP03oolP0?oonf[o
oo]Z00;ooo]Z00?ooc`0oookJ_mFo`001Ooo:00>oookJP03ooo?0?oonf[ooo]Z00Oooo]Z00?o>03o
oookJ_oo:0001?oo0002oookJP03ool0R?oonf[ooo]Z00Kooo]Z2?oo003ooookJPkooo]Z0_oo05L3
oookJP;o0?ob;OoonfX4oooo02Kooo]Z00Coool0oookJ_oonf[o0?l10ooonfX2o`3olP06oookJ_o8
o`3ooo]Zo`2Jool0oe3o083o0_oonfX00ooo00cooo]Zofko0002oookJP03oonT0?l06OooW?l000;o
oo]Z00[oo`12oookJ_l0Y?ooWOl0oookJ_oo09?o0;Coo`0@oooonf[oFol01?l000000ol07?oooo]Z
oookJP08oookJP03okCo0?oonf[ooo]Z00;ooo]Z00?o00OooookJ_oonfX00ooonfX00ol0ol;ooo]Z
oookJP06oookJP03oolP0?oonf[ooo]Z00;ooo]Z00Kooc`0oookJ_oonf[oE_l0oookJ_l0N?l@oook
JP03ooo?0?oonf[ooo]Z00Oooo]Z00?o>03ooookJ_o>0?l00_oonfX01On40?oooo]ZoookJ_oonf[o
o`2800cooo]Z00?oohL0oookJ_oonfX0V_oonfX007;ooo]Z3Ooo000KoookJPSoo`001OoonfX01?oo
:03oool0oooo0?ooo`0EoookJQ3oogT000?o0?niooo90?oob@001_oob@02o`3o0@KoolT01ooUo`04
oomi00SoolT03_ooN@07oookJP03okCo0?oonf[ooo]Z00;ooo]Z00?o00OooookJ_ooN@000oooN@00
0ol0ol;oogT0oomi0002oomi00Cooo]Z00?oob00oookJ_oonfX00_oonfX00ooo?03ooo]ZoeKo0005
oolX00kooo]Z00?ooll0oookJ_oonfX01ooonfX01?lh0?oooo]ZoookJ_o>0?l3ool000;ooo]Z00?o
o`28oookJ_oonfX01ooonfX9ool00?oooo]Z2ooonfX2ool0E`?ooo]Z0_l0oo8[oookJPCoool05Ooo
nfXAo`3o^@Gooo]Z0_ooo`000ooonf[o0?l1o`3o0@02oookJP08ool0Eol0oo;ooo]ZolSo0?l0V_oo
oo]Zo`3oD?l0P?l2oookJP07ool03?oonf[oK_l0oookJ_ooY03o01Wooico0002oookJP0:ool0@_oo
nf[o0:Cooigo0?oonf[oo`2Co`2dool04?oooo]Zoe_o00?o000000?o01cooookJ_oonfX02?oonfX0
0ondo`3ooo]ZoookJP03oookJP03o`07oooonf[ooo]Z00;ooo]Z00?o0?o2oookJ_oonfX01_oonfX0
0ooo803ooo]ZoookJP02oookJP04ooll0?oonf[ooo]ZoeKo00;ooo]Z00?o07SooookJ_oonfX03Ooo
nfX00oooc`3ooo]ZoookJP07oookJP06ocP0oooonf[ooo]Zolh0oooonf[oQ03o0ooonfX00ooo08So
oo]ZoookJP0:oookJP03oon70?oonf[ooo]Z09_ooo]Z001boookJPcoo`007?oonfX7ool000Cooo]Z
0oooo`0CoookJPGo0?ni2oooN@07oookJP;o0?ni0ooob@02oomi00OoolT000?o0?obonGo0?oUo`00
1_oUo`03oomi00SoolT03OooN@08oookJP03okCo0?oonf[ooo]Z00;ooo]Z00?o00OooookJ_ooN@00
0_ooN@000ol0ol;oogT0oomi0002oomi00Cooo]Z00?oob00oookJ_oonfX00_oonfX01?oo?03ooo]Z
oookJ_mFo`03oolX013ooo]Z00?ooll0oookJ_oonfX01_oonfX01?lh0?oooo]ZoookJ_o>0?l3ool0
00;ooo]Z00?oo`28oookJ_oonfX01ooonfX8ool00003oookJ_oo003oo`000?oooo]Z2OoonfX01?oo
05Oooo]ZoookJ_oonfX2o`3olR[ooo]Z0oooo`0CoookJPKo0?ni4OoonfX4o`3o^@?ooo]Z0oooo`00
3ol0o`7ooo]ZoookJ_oonf[o0?oboookJ_o8o`3o09[ook_o0?l0oe3o0?n^oookJ_oo00cooo]Zofko
0002oookJP0>o`0Ioooonf[oW?l0oookJ_oo04;ooo]Zo`2ToonMo`3ooo]Zo`2doooonf[o013ooook
J_mKo`03o`000003o`0Loooonf[ooo]Z00Sooo]Z00?o]?l0oookJ_oonfX00ooonfX00ol01ooooo]Z
oookJP02oookJP03o`3o`_oonf[ooo]Z00Gooo]Z00?oob00oookJ_oonfX00ooonfX01_oo?03ooo]Z
oookJ_mFo`3ooo]Zo`1hoa3ooo]Z00?ooll0oookJ_oonfX01_oonfX01_oo09Ko>03ooookJ_o>0?oo
oo]Zoh@0o`Cooo]Z00?oo`28oookJ_oonfX02OoonfX00oooQ`3ooo]ZoookJP2LoookJP00LooonfX:
ool001gooo]Z1Ooo0003oookJP?oool04?oonfX6o`3o^@Gooo]Z1?ooN@05oookJP;oobP02_oonfX0
0ol0okWoolT0oomi0002oomi00GoolT00_oUo`02ooo900KoiOl01?ooN@07ooo900coogT02?oonfX0
0ondo`3ooo]ZoookJP02oookJP03o`07oooonf[ooo]Z00;oogT000?o0?o2oomi0?ooN@000_ooN@05
oookJP05oolP0?oonf[ooo]ZoookJ_oo?0000_oonfX01?mFo`3oobP0oolX0?oo:00@oookJP03ooo?
0?oonf[ooo]Z00Kooo]Z00Ko>03ooookJ_oonf[ocP3ooookJ_oo0003oookJP03ool0R?oonf[ooo]Z
00Oooo]Z2?oo00000ooonf[oo`00ool00002ool00?oooo]Z2_oonfX2o`3olRWooo]Z0oooo`0@oook
JPKo0?ni6ooonfX3o`3o^@?ooo]Z00?oool0o`3o0OoonfX00_oonfX01_l0oo;ooo]ZolSo0?l0V_oo
0?m@o`20o`;ooo]Z01;oo`0<ofko0?oonf[ooo]Zo`0Ioooonf[oW?l0oookJ_oo04;ooo]Zo`2ToonM
o`3ooo]Zo`2doooIo`3o013ooookJ_mKo`03o`000003o`0Loooonf[ooo]Z00Oooo]Z00?o]?l0oook
J_oonfX00ooonfX00ol01ooooo]ZoookJP02oookJP03o`3o`_oonf[ooo]Z00Kooo]Z00?oob00oook
J_oonfX00_oonfX01_oo?03ooo]ZoookJ_mFo`3ooo]Zo`1hoa3ooo]Z00?ooll0oookJ_oonfX01_oo
nfX01_oo09Ko>03ooookJ_o>0?oooo]Zoh@0o`Cooo]Z00?oo`28oookJ_oonfX02OoonfX00oooQ`3o
oo]ZoookJP2MoookJP00LooonfX8ool0023ooo]Z0_oo0002oookJP?oool03_oonfX5o`3o^ACooo]Z
1Ooo:007oookJP03ooo90?ooN@3oogT000?oogT00ooob@000oooN@3oiOl0onGo0002onGo0003ooo9
0?oUo`3oiOl000CoiOl00oooN@07ooo900coogT02?oonfX00ondo`3ooo]ZoookJP02oookJP03o`07
oooonf[oogT000;oogT000Co0?o2oomi0?ooN@3oogT01OoonfX00ooo803ooo]ZoookJP02oookJP04
ooll0?oonf[oE_l0oookJP;oobP04?oonfX00oooc`3ooo]ZoookJP06oookJP06ocP0oooonf[ooo]Z
olh0oooonf[oo`000ooonfX00ooo08Sooo]ZoookJP08oookJPKoo`000ooonfX5ool00?oooo]Z2?oo
nfX00ol0oo;ooo]ZoookJP0VoookJP?oool03ooonfX4o`3o^BCooo]Z0_l0okT3oookJP?o0?l101Oo
oo]Zo`3ol_o8o`3ooo]Zo`2Jool0oe3o0?n^oookJ_oo00cooo]Zofko0?oonf[o01WooonT0?nLo`3o
oo]Zool0@_oonf[o0:Cooigo0?oonf[o0;Coo`0@o`02oookJP05oe_o0?l0003o0000o`000?l07?l0
2OoonfX00ondo`3ooo]ZoookJP02oookJP03o`07oooonf[ooo]Z00?ooo]Z00?o0?o2oookJ_oonfX0
1OoonfX00ooo803ooo]ZoookJP02oookJP06ooll0?oonf[ooo]ZoeKo0?oonf[o07So4?oonfX00ooo
c`3ooo]ZoookJP07oookJP05ocP0oooonf[ocP3ooookJ_n40?l01?oonfX00ooo08Sooo]ZoookJP09
oookJP03oon70?oonf[ooo]Z00Sooo]Z00?oo`3QoookJ_oonfX0TooonfX007?ooo]Z1ooo000Qoook
JP04ool00?oonf[oool0oooo00kooo]Z0ol0okTBoookJPCoo`000ooonfX7oolX0003oomi0?oonf[o
oo]Z00?ooo]Z1_ooN@02ooo90003oomi0?oUo`3oiOl000?oiOl000?oolT0onGo0?oUo`000ooUo`00
0ooob@3oogT0oomi0007ooo900_oogT00ooonfX3oomi00;ooo]Z00?o]?l0oookJ_oonfX00ooonfX0
1Ol01ooooo]Zoomi0?ooN@3o0?o200?oogT01OoonfX00ooo803ooo]ZoookJP02oookJP06ooll0?oo
nf[ooo]ZoeKo0?oonf[oobP04?oonfX00oooc`3ooo]ZoookJP06oookJP06ocP0oooonf[ooo]Zolh0
oooonf[oQ03o0ooonfX00ooo08Sooo]ZoookJP08oookJPGoo`001?oonfX7ool00?oooo]Z;_oonfX2
oooo00oooo]Z0ol0okTZoookJP?o0?ni00kooo]Zoooo0?oonf[o0?l1oookJ_l0oo;ob?l0o`2Jool0
oe3o083ooookJ_oo00cooo]Zofko00;ooo]Z00[o01Wooico0?oonf[oo`12oookJ_l0Y?ooWOl0oook
J_l0]?oo013o0_oonfX01OmKo`3o0000o`000?l07?oo000000Sooo]Z00?o]?l0oookJ_oonfX00ooo
nfX00ol01ooooo]ZoookJP02oookJP03o`3o`_oonf[ooo]Z00Gooo]Z00?oob00oookJ_oonfX00ooo
nfX01Ooo?03ooo]ZoeKo0?oonf[o07So013ooo]Z00?ooll0oookJ_oonfX01ooonfX00olh0?oooo]Z
olh0o`02oookJP05oh@0oooonf[ooo]ZoookJ_oo08P02ooonfX00oooQ`3ooo]ZoookJP09oookJP03
ool0hOoonf[ooo]Z09?ooo]Z001doookJPGoo`008_oonfX2oooo00kooo]Z0_l0okTEoookJPOoo`00
2_oo:002oookJP_oogT000?oiOl0ooo90?oUo`000_oUo`000ooob@3oiOl0onGo0002onGo00WoolT0
1?ooN@001Ol04?ooogT0oomi0?ooN@3o000000?oogT00ooonfX6oomi00Cooo]Z00Go00OooookJ_oo
nf[oogT0o`3o`P03oomi00Kooo]Z00Goob00oookJ_oonf[ooo]Zooll0002oookJP03oeKo0?oonf[o
obP0013ooo]Z00?ooll0oookJ_oonfX01_oonfX01_oo:03o>03ooookJ_o>0?oooo]Zoh@0o`?ooo]Z
00?oo`28oookJ_oonfX02OoonfX4ool000Cooo]Z2Ooo003ooookJR_ooo]Z0_ooo`0?oookJP;o0?ni
<?oonfX2o`3o^@;oool000Go0?l1oookJ_l0oo;oo`1Go`2Jo`02o`3oD00?oookJ_oo00cooo]Zofko
0?oonf[o01Wooico0?oonf[oo`12oookJ_l0Y?ooWOl0oookJ_l0]?oo013o00;ooo]Z00GoFol0o`00
0?l0003o01coo`000008oookJP03okCo0?oonf[ooo]Z00;ooo]Z00?o00OooookJ_oonfX00_oonfX0
0ol0ol;ooo]ZoookJP06oookJP03oolP0?oonf[ooo]Z00;ooo]Z00Gooc`0oookJ_mFo`3ooo]Zo`1h
o`0@oookJP03ooo?0?oonf[ooo]Z00Oooo]Z00Koo`2FocP0oooonf[ocP3ooookJ_n40?l3oookJP03
ool0R?oonf[ooo]Z00Wooo]Z00?oohL0oookJ_oonfX02OoonfX00ooo0>7ooo]ZoookJP2DoookJP00
MOoonfX3ool0023ooo]Z0oooo`0>oookJP;o0?ni4_oonfX5oolX00Ooo`003?oo:00<oomi0003ooo9
0?oUo`3oiOl000;oiOl000?oolT0onGo0?oUo`002_oob@03oomi00;oolT00oooN@001?l0003oogT0
oomi0?l00003oookJPSoogT00_oonfX01Ol01oooo`00ool00?ooN@3o0?o200;oogT01_oonfX00ooo
803ooo]ZoookJP02oookJP03ooll0?oonf[oE_l000;ooo]Z00?o07SooookJ_oonfX03OoonfX00ooo
c`3ooo]ZoookJP06oookJP06ool0U_lh0?ooobP0oolX0?oonf[oQ03o0ooonfX00ooo08Sooo]Zoook
JP09oookJP?oo`001_oonfX:ool00?oooo]Z9ooonfX3oooo00oooo]Z0_l0okTdoookJP;o0?ni01Wo
ool0o`3o0Ooonf[o0?obool0Eol0V_oo0?n^o`3oD?oo00cooo]Zofko0?oonf[o01WooookJ_nLo`3o
o`12oookJ_l0Y?ooWOl0oookJ_l0]?oo013ooookJ_mKo`3ooo]Z00;o000000?o01coo`000?oonfX0
1ooonfX00ondo`3ooo]ZoookJP02oookJP03o`07oooonf[ooo]Z00;ooo]Z00?o0?o2oookJ_oonfX0
1OoonfX00ooo803ooo]ZoookJP03oookJP05ooll0?mFo`3ooo]ZoookJ_l0N?l03ooonfX00oooc`3o
oo]ZoookJP07oookJP06ool0U_lh0?oooo]Zolh0oooonf[oQ03o0ooonfX00ooo08Sooo]ZoookJP09
oookJP03oon70?oonf[ooo]Z00Wooo]Z00?oo`3QoookJ_oonfX0UOoonfX007Kooo]Z00?oo`00oook
J_oonfX07OoonfX2oooo00kooo]Z0ol0okTDoookJPGoobP01_oo000@oolX00[oogT000?oolT0onGo
0?oUo`000_oUo`0<ooo900?oogT00_oob@02oomi0005oookJ_l0003oogT0oomi0?l000000ooonfX8
oomi0003oookJ_l01oooogT000?oo`000_ooN@06oookJP03oolP0?oonf[ooo]Z00;ooo]Z00Kooc`0
oookJ_oonf[oE_l0oookJ_l0N?l?oookJP03ooo?0?oonf[ooo]Z00Kooo]Z00?oo`2FocP0oooo:000
0ooo:003oookJP03ool0R?oonf[ooo]Z00[ooo]Z00?oo`00oookJ_oonfX01OoonfX9ool00?oooo]Z
9ooonfX2oooo00oooo]Z0ol0okTQoookJP?oonh02_l0o`@2ooo^00Sooo]Z01_o0?nioookJ_l0o`7o
0?l1o`3ol_o8o`3o09[oo`3oD?oonf[oo`0<oookJ_m^o`3ooj@0o`0IoonLo`3oo`12oookJ_l0Y?oo
WOl0oookJ_l0]?oo013ooookJ_mKo`3ooo]Zo`000?l07?l00_l00007oookJP03okCo0?oonf[ooo]Z
00;ooo]Z00?o00OooookJ_oonfX00_oonfX00ol0ol;ooo]ZoookJP05oookJP03oolP0?oonf[ooo]Z
00?ooo]Z00Gooc`0oookJ_mFo`3ooo]Zo`1ho`0?oookJP03ooo?0?oonf[ooo]Z00Oooo]Z00Koo`2F
ocP0oooonf[ocP3ooookJ_n40?l3oookJP03ool0R?oonf[ooo]Z00Wooo]Z00?oohL0oookJ_oonfX0
2OoonfX00ooo0>7ooo]ZoookJP2FoookJP00TooonfX3oolX00gooo]Z0ol0okTGoookJPGoobP01_oo
000AoolX00;o0?l42?ooN@000ooob@3oiOl0onGo0002onGo00_oolT00_oUo`000oooN@3oolT0ooo9
0002oomi0003oookJ_l0003oogT000;o00000ooonfX7oomi0003oookJ_l01ooooo]Z00Koo`001Ooo
nfX00ooo803ooo]ZoookJP02oookJP06ooll0?oonf[ooo]ZoeKo0?oonf[o07So4?oonfX00oooc`3o
oo]ZoookJP05oookJP03ool0U_lh0?ooobP000GoobP000?ooo]Zool0R?oonfX02ooonfX00ooo003o
oo]ZoookJP06oookJPOoo`00oooonfXWoookJP;oool03_oonfX3o`3o^Aoooo]Z1OookP0=oookJPGo
0?l41_oonfX06_l0okWooo]Zoooo0?l0oo;oo`1GolSo0?l0V_oo0?m@ool03?oonf[oK_l0oookJ_l0
6OooW?l0oookJ_oo04;o0:Cooigo0?oonf[o0;Coo`0@oooonf[oFol0oookJ_l0003o01co0_l00007
oookJP03okCo0?oonf[ooo]Z00;ooo]Z00?o00OooookJ_oonfX00_oonfX00ol0ol;ooo]ZoookJP05
oookJP03oolP0?oonf[ooo]Z00;ooo]Z00Gooc`0oookJ_mFo`3ooo]Zo`1ho`0@oookJP03ooo?0?oo
nf[ooo]Z00Kooo]Z00Koo`2FocP0oooonf[ocP3ooookJ_n40?l3oookJP03ool0R?oonf[ooo]Z00Wo
oo]Z00?oohL0oookJ_oonfX02OoonfX00ooo0>7ooo]ZoookJP2GoookJP00S_oonfX6oolX00cooo]Z
0ooo:00AoookJPWoo`001Ooo:006ool000coobP04?ooN@02ooo90003onGo0?nDo`3oolT000SoolT0
1?oUo`07ooo90003o`0Lool0003o000000?ooo]Z1_ooN@001?oonf[o00OooookJ_ooN@07ool000?o
oo]Z00?oob00oomi0?ooN@000_oonfX01_oo?03ooo]ZoookJ_mFo`3ooo]Zo`1hoa3ooo]Z00?ooll0
oookJ_oonfX01OoonfX00ooo09Ko>03ooolX0007oolX00cooo]Z00?oohL0oookJ_oonfX01_oonfX7
ool00?oooo]Z9_oonfX2oooo00kooo]Z0_l0okTMoookJPGoonh03_oonfX4o`1Ho`Gooo]Z0ol0o`@0
1?ookP3ooo]ZoookJ_oonfX2o`3o^@0Go`3o0Ol0oo;o0?obo`2Jool0oe3o0?n^ool03?oonf[oK_l0
o`0IoonLo`3ooo]Zool0@_l0Y?ooWOl0oookJ_l0]?oo013ooookJ_mKo`3ooo]Zo`000?l07?l00_l0
0006oookJP03okCo0?oonf[ooo]Z00;ooo]Z00?o00OooookJ_oonfX00_oonfX00ol0ol;ooo]Zoook
JP05oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?ooc`0oookJ_mFo`000_oonfX00ol0N?oooo]Zoook
JP0=oookJP03ooo?0?oonf[ooo]Z00Kooo]Z00Koo`2FocP0oooonf[ocP3ooookJ_n40?l3oookJP03
ool0R?oonf[ooo]Z00Wooo]Z00?oohL0oookJ_oonfX02OoonfX00ooo0>7ooo]ZoookJP2HoookJP00
ROoonfX:oolX00Sooo]Z1_oo:00CoookJP[oo`001?oo:006ool000CoobP00_l0F?lGoomi0003ooo9
0?nDo`3oolT000WoolT01?oUo`0:ooo900?ooo]Z2?ooN@000ooonf[oogT0ool00007ool000;ooo]Z
00Goob00oomi0?ooN@3oogT0ooll0003oookJP03oeKo0?l0N?oooo]Z00oooo]Z00?ooll0oookJ_oo
nfX01OoonfX00ooo09Ko>03ooookJP09oolX00[ooo]Z00?oohL0oookJ_oonfX01ooonfX5ool00?oo
oo]Z9_oonfX2oooo00kooo]Z0_l0okTLoookJP?oonh02ooonfX8o`1Ho`Co@`3o1_l0F?l2oookJP;o
0?l400Goonh0oookJ_oonf[ooo]Zo`3o^@02o`3o0@0Do`3ol_l0V_oo0?m@oookJ_oo00coK_l0o`0I
oonLo`3ooo]Zool0@_l0Y?oooo]Zoigo0?l0]?oo013ooookJ_mKo`3ooo]Zo`000?l07?l2o`0000Ko
oo]Z00?o]?l0oookJ_oonfX00_oonfX01Ol01ooooo]ZoookJ_oonf[o0?o200Sooo]Z00Goob00oook
J_oonf[ooo]Zooll0002oookJP03oeKo0?oonf[o07So00oooo]Z00?ooll0oookJ_oonfX01_oonfX0
1_oo09Ko>03ooookJ_o>0?oooo]Zoh@0o`?ooo]Z00?oo`28oookJ_oonfX02OoonfX00oooQ`3ooo]Z
oookJP09oookJP03ool0hOoonf[ooo]Z09Wooo]Z0026oookJPcoobP01?oonfX:oolX01Cooo]Z2_oo
0004oolX00Goo`001Ol0F?lAoomi00;oolT01oooN@0;ooo900CoiOl02_oob@03oookJPSoogT00_oo
:007ool000;ooo]Z00?oob00oomi0?ooN@001?ooN@000ooonf[oE_l0o`1ho`0@oookJP03ooo?0?oo
nf[ooo]Z00Kooo]Z00?o>03ooookJ_oo:0001ooo:006oookJP03oolX0?oonf[ooo]Z00;ooo]Z00?o
ohL0oookJ_oonfX01ooonfX4ool00?oooo]Z9_oonfX2oooo00gooo]Z0ol0okTXoookJPCo05So0om3
0?l>oookJP03od<0ool0F?oo05So00;o05So0ol0o`@2oookJP;o0?ni01Co0?obool0Eol0oe3o083o
ool03?oonf[oK_l0o`0IoonLo`3oo`12oookJ_l0Y?ooWOl0o`2dool04?oooo]Zoe_o0?oonf[o0000
o`0Lo`;o00001_oonfX01Ondo`3ooo]ZoookJ_oonf[o00Oo00?ooo]Z00?oojL0o`3o`_oonfX01_oo
nfX00ooo803ooo]ZoookJP02oookJP05ooll0?oonf[oE_l0oookJ_l0N?l03ooonfX00oooc`3ooo]Z
oookJP07oookJP05ocP0oooonf[ocP3ooookJ_n40?l00ooonfX00ooo08Sooo]ZoookJP09oookJP03
oon70?oonf[ooo]Z00Wooo]Z00?oo`3QoookJ_oonfX0V_oonfX008Kooo]Z2ooo:002oookJPcoobP0
5_oonfX9ool000?oobP000?ooo]Zool00?oo00000ol0F?l9oomi00Wooo]Z2Ooob@03oomi00coolT0
1?oUo`0:ooo90003o`000?oonf[oogT000SoogT00ooo:005ool000;ooo]Z00?oob00oookJ_ooN@00
1_ooN@000ooonf[o07SooookJP0>oookJP03ooo?0?oonf[ooo]Z00Kooo]Z00?o>03ooookJ_oo:000
1ooo:007oookJP;oobP00_oonfX00oooQ`3ooo]ZoookJP07oookJP?oo`00oooonfXVoookJP;oool0
3OoonfX2o`3o^BKooo]Z1Ol0F?l3od<0oaOooo]Z0_l0F?l00ooonf[o0?l4o`3o1002oookJP0@oooo
0?l0oo;oo`1Go`3oD?l0ojkoo`0<ofko0?l06OooW?l0ool0@_oonf[o0:Cooigo0?l0]?oo013ooe_o
00;ooo]Z00?o0000o`0Lool000000_l00004oookJP03okCo0?oonf[ooo]Z00;ooo]Z00Go00Oooook
J_oonf[ooo]Zo`3o`P07oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?ooc`0oookJ_mFo`000_oonfX0
0ol0N?oooo]ZoookJP0<oookJP03ooo?0?oonf[ooo]Z00Kooo]Z0_lh0?l01?oonf[ocP3ooookJ_n4
0?l3oookJP03ool0R?oonf[ooo]Z00Wooo]Z00?oohL0oookJ_oonfX02OoonfX00ooo0>7ooo]Zoook
JP2KoookJP00QooonfX9oolX00?ooo]Z2ooo:00GoookJPOoo`001Ooo:002o`1Ho`;o@`3o2?ooN@0<
oookJQGoolT01ooUo`09ooo90003o`000?oonf[ooo]Z00WoogT01Ooo:002ool000;oogT000?ooo]Z
oolP0?ooN@002?ooN@0?oookJP03ooo?0?oonf[ooo]Z00Kooo]Z00?o>03ooookJ_oonfX01_oo:008
oookJPCoobP000?oohL0oookJ_oonfX02?oonfX2ool00?oooo]Z9OoonfX2oooo00gooo]Z0_l0okTT
oookJPCo05So1?m30?lMoookJP;o05So01?ooo]Zo`3o1?l0o`Co0?nio`3o0Ol0oo;o09[oo`3oD?oo
00coK_l0o`0IoonLo`3oo`12oookJ_l0Y?ooWOl0o`2dool04?ooFol000;ooo]Z00Co01coo`000?l0
003o00001OoonfX01Ondo`3ooo]ZoookJ_oonf[o00Oo00?ooo]Z00?oojL0o`3o`_oonfX01_oonfX0
1Ooo803ooo]ZoookJ_oonf[ooc`000;ooo]Z00?oE_l0oookJ_l0N?l03_oonfX00oooc`3ooo]Zoook
JP06oookJP06ocP0oooo09Kooo]Zolh0oooonf[oQ03o0ooonfX00ooo08Sooo]ZoookJP09oookJP03
oon70?oonf[ooo]Z00Wooo]Z00?oo`3QoookJ_oonfX0W?oonfX008Oooo]Z1ooo:006oookJPWoobP0
5ooonfX;oolX00?o@`3o0ooonfX9oomi00_ooo]Z4ooob@09onGo00WoolT000?o0000oookJ_oonfX0
2?ooN@07oolX00CoogT000?ooo]Zoomi0?ooN@001OooN@000ol0N?oooo]ZoookJP0=oookJP03ooo?
0?oonf[ooo]Z00Kooo]Z00?o>03ooookJ_oonfX01Ooo:0000ooonf[oo`28oookJP06oookJPKoobP0
2?oonfX00ooo0>7oo`00oookJP3ooookJRCooo]Z0_ooo`0=oookJP;o0?ni9?oonfX2o`1Ho`04oook
J_m30?oo@`3ood<0ob;ooo]Z01Co@`3oo`1Hoooonf[oonh0o`3o1?l0okWo0?l1o`3ol_l0oe3o083o
ofko0?l06OooW?l0oookJ_oo04;o0:Cooigo0?l0]?oo013ooe_o00;ooo]Z00Co01coo`000?l0003o
00001?oonfX00ondo`3ooo]ZoookJP02oookJP05o`07oooonf[ooo]ZoookJ_l0ol801ooonfX01Ooo
803ooo]ZoookJ_oonf[ooc`000;ooo]Z00?oE_l0oookJ_l0N?l03_oonfX00oooc`3ooo]ZoookJP06
oookJP06ocP0oooo09Kooo]Zolh0oooonf[oQ03o0ooonfX00ooo08Sooo]ZoookJP09oookJP03oon7
0?oonf[ooo]Z00Sooo]Z0_oo0>6OoookJP00Q_oonfX2oooo00GoobP01ooonfX7oolX01Gooo]Z3_oo
:0000om30?oooo]ZoookJP04oookJQ7oogT00_oo0;`;ooo900CoiOl01?oob@0:onGo00;oU?l01ooo
b@000ol0003ooo]ZoookJP08oomi00SoobP02_ooN@000ol0N?oooo]ZoookJP0>oookJP03ooo?0?oo
nf[ooo]Z00Gooo]Z00Co>03ooookJ_oonf[ocP3o1?oo:0000ooonf[oo`28oookJP07oookJPOoobP0
1_oonfX00ooo0>7ooo]ZoookJP3ooookJRCooo]Z00?oool0oookJ_oonfX03?oonfX00ol0okWooo]Z
oookJP0RoookJP;o05So0om30?lDoookJQ3oo`2l0ooonfX3o`1Ho`0?o`3o1?l0okWo0?obool0Eol0
oe3oo`0<ofko0?l06OooW?l0ool0@_l0Y?ooWOl0o`2dool04?ooFol000;ooo]Z00Co01coo`000?l0
003o00001?oonfX01Ondo`3ooo]ZoookJ_oonf[o00Oo00?ooo]Z00?o0?o2oookJ_oonfX01_oonfX0
1?oo803ooo]ZoookJ_oo?002oookJP03oeKo0?oonf[o07So00oooo]Z00?ooll0oookJ_oonfX01Ooo
nfX01_lh0?ooo`2FoookJ_o>0?oooo]Zoh@0o`?ooo]Z00?oo`28oookJ_oonfX02OoonfX00oooQ`3o
oo]ZoookJP08oookJP03ool0hOoonf[ooo]Z09oooo]Z0024oookJP;oool00_oonfX4oolX00Sooo]Z
00?o0?nioolX0?oo:0000ooo:00FoookJPcoobP000?o@`3ooookJ_oonfX01_oonfX?oomi00Gooo]Z
2ooob@05onGo00;oolT02OoUo`03oiCo00CoiOl01Ooob@000ooonf[oogT0oomi0006oomi00SoobP0
2_ooN@0@oookJP03ooo?0?oonf[ooo]Z00Gooo]Z00Co>03ooookJ_oonf[ocP3o0ooo:002oookJP03
ool0R?oonf[ooo]Z00Kooo]Z2Ooo:004oookJP03ool0hOoonf[ooo]Z023ooo]Z00?oo`00oookJ_oo
nfX0oooonfX2oooo00gooo]Z0_l0okTSoookJP;o05So0_m30?lCoookJPCoo`2l4?oonfX4ool0_00A
oookJ_m30?oo05Soo`3o1?l0okWo0?obool0Eol0oe3ooo]Zofko0?nLo`3oo`12o`2ToonMo`3o0;Co
o`0@oomKo`000_oonfX01?l07?oo0000o`000?l00003oookJP05okCo0?oonf[ooo]ZoookJ_l01ol0
1?oonfX00ol0ol;ooo]ZoookJP05oookJP05oolP0?oonf[ooo]ZoookJ_oo?0000_oonfX00omFo`3o
07SooookJP0>oookJP03ooo?0?oonf[ooo]Z00Gooo]Z00Ko>03oool0U_oonf[ocP3ooookJ_n40?l3
oookJP03ool0R?oonf[ooo]Z00Wooo]Z00?oohL0oookJ_oonfX02?oonfX00ooo0>7ooo]ZoookJP2P
oookJP00PooonfX00oooo`3ooo]ZoookJP02oookJP?oobP01ooonfX2o`3o^@03oookJ_oo:03oobP0
00;oobP06?oonfX:oolX00_ooo]Z3?ooN@07oookJP[oolT01ooUo`000ooob@3oiOl0onGo0005onGo
00GoU?l01_oUo`06ooo900KoogT01ooo:00<oomi00kooo]Z00?ooll0oookJ_oonfX01OoonfX01_lh
0?oooo]ZoookJ_o>0?oooo]ZoolX00?ooo]Z00?oo`28oookJ_oonfX01ooonfX7oolX0003oookJ_oo
:03ooo]Z00;ooo]Z00?oo`3QoookJ_oonfX08OoonfX2ool00?kooo]Z0_ooo`0=oookJP;o0?ni8_oo
nfX3o`1Ho`;o@`3o4OoonfX4ool0_1Sooo]Z017oo`2loookJ_oonf[o@`3oo`3o1?ooo`3o0?obo`3o
[_l0oe3oK_l0oico0?oonf[oo`12oigo0?l0]?oo013ooe_o0002oookJP04o`0Lool0003o0000o`00
00?ooo]Z00Go]?l0oookJ_oonf[ooo]Zo`07o`03oookJP03o`3o`_oonf[ooo]Z00Gooo]Z00Goob00
oookJ_oonf[ooo]Zooll0002oookJP03oeKo0?oonf[o07So00kooo]Z00?ooll0oookJ_oonfX01Ooo
nfX01_lh0?ooo`2FoookJ_o>0?oooo]Zoh@0o`?ooo]Z00?oo`28oookJ_oonfX02OoonfX00oooQ`3o
oo]ZoookJP08oookJP03ool0hOoonf[ooo]Z0:7ooo]Z0021oookJP;oool01_oonfX00ooo:03ooo]Z
oookJP05oookJP04o`3o^Ooonf[ooo]ZoookJP?oobP06OoonfX8oolX00gooo]Z2_ooN@08oookJPgo
olT03?oUo`06oiCo00KoiOl02?oob@03oomi00OoobP03_ooN@0<oookJP04ooo?0?oonf[ooo]Zoomi
00Cooo]Z00Ko>03ooookJ_oonf[ocP3ooookJ_oo:003oookJP03ool0R?oonf[ooo]Z00Oooo]Z1ooo
:0001_oonf[oobP0oolX0?oo:03ooo]Zool0hB?ooo]Z1_oo003joookJP03oooo0?oonf[ooo]Z00co
oo]Z00?o0?nioookJ_oonfX07ooonfX3o`1Ho`03oookJ_m30?oo@`3o00oooo]Z1?oo0;`=oookJPgo
o`1@0ooonfX2ool0_00@oookJ_m30?oo0?l4o`3o0Ol0oo;o0?m@ofko0?l06OooW?l0ool0@_nMo`3o
0;Coo`0@oomKo`3ooo]Zo`0Lo`Co00000ooonfX01?ndo`3ooo]ZoookJ_l01ol3oookJP03oonW0?lo
0?oooo]Z00Gooo]Z00Goob00oookJ_oonf[ooo]Zooll0003oookJP03oeKo0?l0N?oooo]Z00gooo]Z
00?ooll0oookJ_oonfX01OoonfX01_lh0?oooo]ZoookJ_o>0?oooo]Zoh@0o`?ooo]Z00?oo`28oook
J_oonfX02OoonfX00oooQ`3ooo]ZoookJP08oookJP03ool0hOoonf[ooo]Z02Cooo]Z0_m^o`1loook
JP00P?oonfX00oooo`3ooo]ZoookJP0;oookJP?oo`001OoonfX00ooo:03ooo]ZoookJP0DoookJPGo
o`001_oo:00=oookJP03ool0_?ooN@3oogT000KoogT01ooonfX3ool0D0ooolT02?oUo`06oiCo00;o
A?l01_oUo`09ooo900;oogT01_oo:00=oomi00Sooo]Z00?oogT0oookJ_oonfX00_oonfX01Oooc`3o
oo]ZoookJ_oonf[oogT000?ooo]Z00Koo`2FocP0oooonf[ocP3ooookJ_n40?l3oookJP03ool0R?oo
nf[ooo]Z00Oooo]Z1_oo:002oookJPGoobP02?oonfX00ooo003ooo]ZoookJP0HoookJPKoo`00nOoo
nfX2oooo00gooo]Z0_l0okTPoookJP;o05So0_oonfX2od<0o`kooo]Z0ooo0;`>oookJP?oo`1@3Ooo
nfX5ool0D0;oo`2l00kooo]Zo`3o1?l0o`7o0?m@o`20oom^o`3oW?l0ool0@_nMo`3o0;Coo`0@oomK
o`3ooo]Zo`0Lo`Co00000_oonfX01Ondo`3ooo]ZoookJ_oonf[o00Oo00?ooo]Z00?o0?o2ocl0oooo
nfX01OoonfX01?oo803ooo]ZoookJ_oo?003oookJP03oeKo0?l0N?oooo]Z00gooo]Z00?ooll0oook
J_oonfX01OoonfX01_oo09Ko>03ooookJ_o>0?oooo]Zoh@0o`?ooo]Z00?oo`28oookJ_oonfX02Ooo
nfX00oooQ`3ooo]ZoookJP08oookJP03ool0hOoonf[ooo]Z02Cooo]Z00?oK_l0oookJ_oonfX0O?oo
nfX007kooo]Z0_oo000:oookJPKoo`006_oonfX8ool000GoobP03?oonfX2ool0_003oookJ_ooN@3o
ogT000coogT000Coo`1@oookJ_oonf[ooo]Z2?oob@05oomi00CoiOl00_nDo`03onGo00KoU?l00om4
o`03oiCo00?oiOl02ooob@05oolX00googT02OoonfX2oomi00;ooo]Z00Cooll0oookJ_oonf[ooo]Z
0oooN@001ooonf[oo`2FocP0oooonf[ocP3ooookJ_n40?l00ooonfX00ooo08Sooo]ZoookJP08oook
JPCoobP01?oonfX6oolX00Oooo]Z0_oo000HoookJPSoo`00m_oonfX2oooo00gooo]Z0_l0okTQoook
JP03o`1Hoooonf[ooo]Z00;o@`3o3_oonfX2ool0_0gooo]Z1?oo050EoookJP0@ool0D?oonf[oo`2l
oookJ_l0o`Co0?l1o`3oD?oo00coK_l0ool0@_l0Y?ooWOl0o`0@oomKo`3ooo]Zo`0Lo`Co00000_oo
nfX01Ondo`3ooo]ZoookJ_oonf[o00Oo00;ooo]Z00?oojL0ocl0oooonfX01OoonfX01Ooo803ooo]Z
oookJ_oonf[ooc`000;ooo]Z00?oE_l0oookJ_l0N?l03OoonfX00oooc`3ooo]ZoookJP05oookJP06
ool0U_lh0?oooo]Zolh0oooonf[oQ03o0ooonfX00ooo08Sooo]ZoookJP09oookJP03oon70?oonf[o
oo]Z00Sooo]Z00?oo`3QoookJ_oonfX09?oonfX00om^o`3ooo]ZoookJP1moookJP00:_oonfX3o`00
O`Gooo]Z1Ol007ljoookJP?o001o1OoonfX2o`00O`Coo`002?oonfX8ool001Oooo]Z2ooo00001?m3
0?ooobP0oolX0?oo:005oookJPGo001o0_oonfX2ool0_003oookJ_ooN@3oogT000coogT01_oonfX7
ooo900SoogT000KoiOl0ooo90?oob@3oolT0oiCo0?oUo`06oiCo00?oA?l00_l0o``2oiCo00GoiOl0
1_oob@02oomi00GoobP000?oolT0oomi0?ooN@002_ooN@09oookJPCoogT000Cooll0oookJ_oonf[o
oo]Z1OooN@001Olh0?oooo]Zolh0oooonf[oQ03o00?ooo]Z00?oo`28oookJ_oonfX01_oonfX2o`00
O`CoobP01?oonfX8oolX00Gooo]Z1?oo000GoookJPWoo`002OoonfX3o`00O`Gooo]Z1Ol007lioook
JP?o001o1OoonfX5o`00OdKooo]Z0ol007l5oookJPGo001o>OoonfX3o`00O`Gooo]Z1?l007l00ooo
o`3ooo]ZoookJP0;oookJP;o0?ni8OoonfX2o`1Ho`03oookJ_m30?oo@`3o00Oooo]Z1Ol007l2oook
JP;oo`2l3?oonfX3ool0D0gooo]Z2ol09Ol2oookJP;oo`1@00goo`2loookJ_l0o`Coo`1Go`3oD?m^
o`3oo`12o`2ToonMo`3o013ooe_o0?oonf[o01co00Co000000?ooo]ZokCo0?oonfX00_oonfX01_l0
1ooooo]ZoookJ_oonf[o0?o2ocl0o`Gooo]Z00Goob00oookJ_oonf[ooo]Zooll0002oookJP03oeKo
0?oonf[o07So00kooo]Z00?ooll0oookJ_oonfX01?oonfX01_oo09Ko>03ooookJ_o>0?oooo]Zoh@0
o`?ooo]Z00?oo`28oookJ_oonfX01ooonfX2o`00O`03oon70?l007oo001o00Sooo]Z00?oo`3Qoook
J_oonfX09?oonfX00om^o`3ooo]ZoookJP0<oookJP?o001o1OoonfX5o`00Oc[ooo]Z0ol007l5oook
JPGo001o7_oonfX002[ooo]Z0ol007l4oookJPOo001o>OoonfX3o`00O`Cooo]Z1_oo00000ol007oo
oo]ZoookJP02oookJP_oo`005_oonfX<ool000?ooo]Z00?oobP0oookJ_oonfX00ooonfX6o`00O`;o
o`2l0ooonfX=oomi00Oooo]Z1ooob@09oomi00;oiOl00_oob@05oiCo00CoA?l00ol0o``00om4o`3o
U?l0onGo0008onGo00;oolT00oooN@03oolX0003ooo90?ooN@3oogT000?oogT000?oobP0oomi0?oo
N@000oooN@0:oookJPKoogT00ooonfX4oomi0005ocP0ooooN@3ocP3ooookJ_n40?l00ooonfX00ooo
08Sooo]ZoookJP06oookJP?o001o0_oo:002o`00O`?ooo]Z2_oo:003oookJPKoo`005OoonfX8ool0
00_ooo]Z0ol007l4oookJPOo001o>?oonfX3o`00O`Cooo]Z1ol007m5oookJP?o001o1?oonfX7o`00
OcSooo]Z0ol007l4oookJP?o001o0_ooo`02o`00O`_ooo]Z00?o0?nioookJ_oonfX08?oonfX01?l0
F?oooo]Zod<0oom30?l8oookJPOo001o00?oo`2loookJ_oonfX02_oonfX2ool0D0gooo]Z0ol09Ol;
oookJP;o02Go0_oonfX03Ooo053oo`2lod<0ool0o`Co083oo`3oD?m^o`3oo`12oigo0?l04?ooFol0
oookJ_l07?l01?l000000ooonf[o]?l0oookJP02oookJP06o`07oooonf[ooo]ZoookJ_l0ol;o?`3o
1?oonfX00ooo803ooo]ZoookJP02oookJP05ooll0?oonf[oE_l0oookJ_l0N?l03_oonfX00oooc`3o
oo]ZoookJP04oookJP06ool0U_lh0?oooo]ZoookJ_o>0?ooQ03o0ooonfX00ooo08Sooo]ZoookJP07
oookJP;o001o00?oohL0o`00Ool007l00_l007l5oookJP;oo`3Q9_oonfX00om^o`3ooo]ZoookJP0=
oookJP?o001o1?oonfX7o`00OcWooo]Z0ol007l4oookJPOo001o7OoonfX002[ooo]Z0ol007l3oook
JPCo001o00Cooo]Zo`00Ool007oo001o>OoonfX3o`00O`03oookJ_oo003oo`0000Koo`000_l007l2
oookJPcoo`005ooonfX;ool000Wooo]Z1?l007l01?oonf[oo`2lool0_?l007l4oookJP_oogT02Ooo
nfX7ooo900SoogT000CoolT0onGo0?oUo`3oiOl00_oob@000om4o`3oU?l0oiCo0004odCo00?o0?l<
0_l0oed00ol0ojgoiOl0onGo0005oiCo00?oiOl01_ooN@02ooo900?oogT00_oo:006oomi00[ooo]Z
1oooN@000ooonf[oogT0oomi0004oomi0003olh0ooooN@3oQ03o00?ooo]Z00?oo`28oookJ_oonfX0
1_oonfX3o`00O`03oolX0?oonf[o001o00;o001o0_oonfX9oolX00Cooo]Z2?oo000CoookJPOoo`00
3OoonfX3o`00O`Cooo]Z0ol007l01?oonf[o001oo`00Ool007lhoookJP?o001o0ooonfX4o`00O`04
oookJ_l007oo001oo`00OdGooo]Z0ol007l3oookJPCo001o00Cooo]Zo`00Ool007oo001o>?oonfX3
o`00O`Cooo]Z0_l007l00oooo`3ooo]Zo`00O`02o`00O`Wooo]Z0_l0okTSoookJP;o@`3o2OoonfX4
o`00O`04oookJ_l007ooo`2lool0_0_ooo]Z0_oo050<oookJP?o02Go2_oonfX3oonO00?ooo]Z0ol0
9Ol2ool0D00:o`1Hool0o`Co0?m@ofko0?oo04;oWOl0o`0@oomKo`3ooo]Zo`0Lo`Co000000?ooo]Z
okCo0?oonfX00_oonfX01Ol01ooooo]ZoookJ_l0ol;o?`3o00Cooo]Z00?oob00oookJ_oonfX00_oo
nfX01Ooo?03ooo]ZoeKo0?oonf[o07So00kooo]Z00?ooll0oookJ_oonfX01?oonfX01_oo09Ko>03o
oookJ_oonf[ocP3ooh@0o`?ooo]Z00?oo`28oookJ_oonfX01ooonfX2o`00O`03oon70?l007oooo]Z
00?o001o1?oonfX00ooo0>7ooo]ZoookJP0ToookJP;oK_l04?oonfX3o`00O`Cooo]Z0ol007l01?oo
nf[o001oo`00Ool007lioookJP?o001o0ooonfX4o`00O`04oookJ_l007oo001oo`00Oagooo]Z000J
oookJP[o001o1_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o:?oonfX:o`00O`Kooo]Z00?o001o
ool00?oo00002?oo00001Ooonf[o001oo`00Ool007oooo]Z00_oo`006OoonfX9ool000So001o0_oo
nfX3o`00O`;oo`2l00Cooo]Zo`00Ool007oo001o1?oonfX8oomi00Sooo]Z0ol09Ol2oookJPGoolT0
2?ooN@05onGo0003odCo0?nDo`3oU?l000?oA?l00ol0o``3o`3oG@Wo0?n]0_nDo`02ooo900SoogT0
00GoolT0oolX0?oo:03oobP0ooll0006oomi00Sooo]Z4?ooN@001On40?ooogT0oookJ_oonf[oo`28
00Wooo]Z00?o001ooon70?oo:0000ooonfX3o`00O`03oookJ_oo:03oobP000GoobP01_oonfX9ool0
0003oookJ_oo003ooo]Z00kooo]Z1_oo000?oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007lgoook
JP?o001o0ooonfX3o`00O`?ooo]Z0ol007ldoookJP[o001o1_oonfX3o`00O`?ooo]Z0ol007l3oook
JP?o001o9ooonfX:o`00O`Kooo]Z0ol007l3oookJP03o`00Ooooo`3oool000?ooo]Z0ol007l6oook
JP;o0?ni8ooonfX2od<0o`Wo001o0_oonfX3o`00O`?oo`2l0ol007l7oookJP?oo`1@2_oonfX4o`0U
o`Oooo]Z1_ooW`000ooonf[oo`0Hool06002ool060?ooil000gooo]Zo`0Uool09Oooo`1@o`1Hool0
o`Co0?m@ofko0?oo04;ofOl0oe_o0?oonf[o01co00Co000000Gooo]ZokCo0?oonf[ooo]Zo`07o`02
oookJP03o`3o`_lo0?oooo]Z00?ooo]Z00?oob00oookJ_oonfX00_oonfX01Ooo?03ooo]ZoeKo0?oo
nf[o07So00kooo]Z00?ooll0oookJ_oonfX01?oonfX01_oo09Ko>03ooookJ_oonf[ocP3ooh@0o`?o
oo]Z00?oo`28oookJ_oonfX02?oonfX2oon70004o`00Oooonf[ooo]ZoookJP?o001o0_oonfX00ooo
0>7ooo]ZoookJP0;oookJP;o09So5ooonfX00om^o`3ooo]ZoookJP0@oookJP?o001o0ooonfX3o`00
O`?ooo]Z0ol007lhoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007lLoookJP006_oonfX:o`00O`Ko
oo]Z0ol007l9oookJP?o001o:?oonfX:o`00O`Gooo]Z2ooo0002oookJP?o001o0_oonfX9ool001[o
oo]Z2?oo0009o`00O`?ooo]Z0_oo0;`3oookJP?o001o1?oonfX7oomi00Gooo]Z0oooN@000ol09Ooo
oo]ZoookJP02oookJP03oomi0?oob@3oolT000;oolT02OooN@05onGo00;oU?l00om4o`02o`3o30Go
0?mM2Ol0ojd00ol03oooU?l0ooo90002ooo900OoogT000CoolT0oolX0?oo:03ooc`02?ooN@07oook
JQ7oogT00_oonfX00ooo08Sooo]ZoookJP08oookJP03oon70?oonf[ooo]Z00?ooo]Z0ol007l6oolX
00Oooo]Z2?oo0003oookJP03ool00?oonf[ooo]Z00gooo]Z1?oo000AoookJP?o001o0ooonfX3o`00
O`?ooo]Z0ol007lgoookJP?o001o2OoonfX3o`00OcCooo]Z2_l007l6oookJP?o001o2OoonfX3o`00
ObOooo]Z2_l007l6oookJP?o001o0ooonfX00oooo`3o001oo`00O`03oookJP?o001o1OoonfX00ol0
okWooo]ZoookJP0QoookJP;o@`3o00?ooo]Zo`00Ool007l02?l007l3oookJP;oo`2l0ooonfX3o`00
O`Gooo]Z0_oo050:oookJP?o02Go2?oonfX3oonO0003oookJ_oo01Soo`0H00?oo`0H2?l0o`001Ooo
01Sooil0oookJ_l09Oooo`1@00;o0?l400KoK_l0ool0@_nMo`3oFol0oookJ_l07?l4o`000005okCo
0?oonf[ooo]ZoookJ_l01ol00_oonfX00ol0ol;o?`3ooookJP03oookJP09oolP0?oonf[ooo]Zoook
J_oo?03ooo]ZoeKo0?oonf[o07So00kooo]Z00?ooll0oookJ_oonfX01?oonfX01_oo09Ko>03ooook
J_oonf[ocP3ooh@0o`?ooo]Z00?oo`28oookJ_oonfX02?oonfX00oooQ`3ooo]ZoookJP04oookJP?o
001o00?ooo]Zool0hOoonfX03?oonfX00ol0V?oooo]ZoookJP0FoookJP03ofko0?oonf[ooo]Z017o
oo]Z0ol007l3oookJP?o001o0ooonfX3o`00OcSooo]Z0ol007l9oookJP?o001o7?oonfX002[ooo]Z
0ol007l9oookJP?o001o=ooonfX:ool000?ooo]Z0ol007l2oookJPSoo`007?oonfX6ool000_ooo]Z
0_oo0;`5oookJP?o001o0ooonfX00ooo053oogT0oomi0003oomi00;ooo]Z1_ooN@07oookJP03oomi
0?oob@3oolT000;oolT02?ooN@05onGo00?oU?l01?l0o``2o`3oG@;o0?on0_l0oed9o`3o[@03o`0?
oooob@3oolT000CoolT00oooN@04ooo90003ooll0?oo:03oogT000SoogT01OoonfX7oomi0003oook
J_ooN@3oogT000KoogT00_oonfX2ool0R0[ooo]Z00?oohL0oookJ_oonfX01?oonfX2o`00O`GoobP0
2?oonfX7ool000Cooo]Z0ooo000=oookJP?oo`004ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o
=ooonfX3o`00O`Wooo]Z0ol007m4oookJP?o001o2OoonfX3o`00OcOooo]Z0ol007l00ooonf[oool0
oooo0003o`00O`?ooo]Z0ol007lXoookJP03od<0oooonf[ooo]Z00cooo]Z0_oo0;`5oookJP?o001o
0ooonfX2ool0D0[ooo]Z0_l09Ol8oookJP?ooil00_oonfX2ool06003oookJ_l0o`3o0?l000;o0?l0
0_oonfX5o`3bo`0>ool0[?l0o`3o0?l0o`3o0?oo01So02Goool0D?l0o`Co0?m@ofko0?nMo`3oFol0
oookJ_l07?l4o`000004okCo0?oonf[ooo]Zo`07o`;ooo]Z00?o0?o2ocl0oooonfX00ooonfX02Ooo
803ooo]Zool0Dooonf[ooc`0oookJ_mFo`3ooo]Zo`1ho`0>oookJP03ooo?0?oonf[ooo]Z00Cooo]Z
00Koo`2FocP0oooonf[ooo]Zolh0oon40?l3oookJP03ool0R?oonf[ooo]Z00Sooo]Z00?oohL0oook
J_oonfX01OoonfX3o`00O`03ool0hOoonf[ooo]Z00_ooo]Z00?o09SooookJ_oonfX05_oonfX00om^
o`3ooo]ZoookJP0BoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007lhoookJP?o001o2OoonfX3o`00
Oacooo]Z000ZoookJP?o001o1?oonfX2o`00O`;ooo]Z1?l007lhoookJPSoo`0000Co001ooookJ_oo
nf[ooo]Z0ol007l3oookJPKoo`006_oonfX4oolX00Coo`002_oonfX2ool0_0;ooo]Z0_l007l2oook
JPCo001o00?ooo]Zool0D?oo05000_oonfX;oomi00Kooo]Z00?ooil0oolX0?oo:0001Ooo:007oomi
00CoiOl01_nDo`02o`3o3004o`3oGOl0ooko0?ono`3ooP?o0?mM1ol0ojd2o`0?o`?oolT00_oUo`02
ooo90003oomi0?oob@3oolT000CoolT02?ooN@06oookJPKoogT00_oonfX8oomi00;ooo]Z00?oo`28
oookJ_oonfX02OoonfX00oooQ`3ooo]ZoookJP02o`00O`;ooo]Z0ol007l3oolX00Wooo]Z1_oo0005
oookJPGoo`002ooonfX2ool001Gooo]Z0ol007l3oookJP?o001o0ooonfX3o`00OcOooo]Z0ol007l4
oookJP;o001o0_oonfX4o`00OdCooo]Z0ol007l4oookJP;o001o0_oonfX4o`00OcOooo]Z0ol007l0
0oooo`3ooo]ZoookJP03o`00O`?ooo]Z0ol007lWoookJP03od<0oooonf[ooo]Z00cooo]Z00?oo`2l
oookJ_oonfX00_l007l2oookJPCo001o0_oonfX00ooo053ooo]ZoookJP08oookJP;o02Go1ooonfX3
oonO00;ooo]Z0ooo01P3o`3o00;ooo]Z1?l0l_l5oookJPGo0?;o00Wo0?l0ool06?oo053o0?l4ofko
0?oo04;oWOl0oe_o0?l07?l00ol000001?ndo`3ooo]ZoookJ_l01ol3oookJP03o`3o`_lo0?oooo]Z
00?ooo]Z00Soob00ool0Dooonf[ooc`0oookJ_mFo`3ooo]Zo`1ho`kooo]Z00?ooll0oookJ_oonfX0
1?oonfX00ooo09Ko>03ooookJP02olh0o`05oh@0oooonf[ooo]ZoookJ_oo08P02_oonfX01?ooQ`3o
oo]ZoookJ_oonfX2o`00O`;ooo]Z0ol007l00ooo0>7ooo]ZoookJP0:oookJP;o09So6?oonfX00om^
o`3ooo]ZoookJP0CoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007lhoookJP?o001o1?oonfX2o`00
O`;ooo]Z1?l007lLoookJP00:_oonfX3o`00O`Cooo]Z1ol007lioookJP03o`00Oooo003oo`0000Co
o`000_l007l3oookJP?o001o1?oonfX4ool001Sooo]Z1ooo:003ool000[ooo]Z00?oo`2loookJ_oo
nfX00_oonfX7o`00O`;oo`1@0_oonfX<oomi00ooobP01oooN@06onGo00CoU?l000?o0?l<o`3oGOl0
ooh01?l0ooh2o`3oG@Oo0?n]00?o00oooiCo0?oob@000_oob@03onGo00WoolT01_ooN@07oookJPCo
ogT00ooonfX7oomi0004oh@0ooooN@3oogT0ool0R0_ooo]Z00CoohL0oookJ_oonf[ooo]Z1_l007l2
oolX00_ooo]Z1?oo0007oookJPKoo`002?oonfX00om^o`3oo`00oookJP0FoookJP?o001o0ooonfX3
o`00O`?ooo]Z0ol007lgoookJP?o001o1?oonfX7o`00OdGooo]Z0ol007l4oookJPOo001o>?oonfX2
o`00O`04oooo0?oonf[ooo]ZoookJP?o001o0ooonfX3o`00ObGooo]Z0_m30?l=oookJP;oo`2l0ooo
nfX7o`00O`03oookJ_oo053oo`1@00Wooo]Z0_l09Ol8oookJP03oonO0?oonf[ooo]Z00?oo`0H0ol0
o`02oookJP03ool0[?l0l_oo0?;o00gooo]Z00Goo`2/o`3bool0l_oo0?l0o`3o1002ofko0003oigo
0?mKo`3o01co00?o000000Co]?l0oookJ_oonf[o00Oo0_oonfX00ol0ol;o?`3ooookJP03oookJP04
oolP0?oo05?ooo]Zooll00;ooo]Z00?oE_l0oookJ_l0N?l03OoonfX00oooc`3ooo]ZoookJP04oook
JP06ool0U_lh0?oooo]Zolh0oooonf[oQ03o0ooonfX00ooo08Sooo]ZoookJP08oookJP03oon70?oo
nf[ooo]Z00;ooo]Z1_l007l00ooo0>7ooo]ZoookJP0:oookJP03o`2Hoooonf[ooo]Z01Kooo]Z0_m^
o`0FoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007lhoookJP?o001o1?oonfX7o`00Oagooo]Z000Z
oookJP?o001o1?oonfX6o`00Oc[ooo]Z00?o001oool00?oo00000ooo0003o`00O`?ooo]Z0ol007l4
oookJP?oo`005_oonfX:oolX0003oookJ_oo003ooo]Z00Sooo]Z0_oo0;`5oookJPGo001o0_oo0504
oookJPcoogT04Ooo:0001?l0l_ooolT0ooo90?oob@09onGo0003oiCo0?l0o`co0?mM00Oo0?on00?o
0?mMo`3o[Ol0ojd01Ol0ojd01?l03oooolT0ooo90?oob@06onGo00SoolT00oooN@08oookJPCoogT0
1?oonfX5oomi00;oQ03o1?ooN@0:oookJP03oon70?oonf[ooo]Z00;ooo]Z1?l007l00ooo0>7oobP0
oookJP0;oookJP?oo`002?oonfX8ool000Kooo]Z00?oK_l0oookJ_oonfX05ooonfX3o`00O`?ooo]Z
0ol007l3oookJP?o001o=ooonfX3o`00O`Cooo]Z1_l007m6oookJP?o001o1?oonfX6o`00OcWooo]Z
0ol007l3oookJP?o001o0ooonfX3o`00ObCooo]Z00?o@`3ooookJ_oonfX03?oonfX00ooo0;cooo]Z
oookJP03oookJPKo001o0_oo0509oookJP;o02Go2?oonfX2oonO0003oookJ_oo01Soo`0H00?o0?l0
0ooonfX00ooo0:co0?;oo`3bo`0BoookJP;o0?;o00Go0?l4ofko0?oo04;oFol0o`0Lo`03o`000007
okCo0?oonf[ooo]Zo`07oooonf[oojL0ocl0o`04oookJP09oolP0?oonf[oo`1CoookJ_oo?03ooo]Z
oeKo0?oonf[o07So00gooo]Z00?ooll0oookJ_oonfX01?oonfX01_oo09Ko>03ooookJ_o>0?oooo]Z
oh@0o`?ooo]Z00?oo`28oookJ_oonfX02?oonfX00oooQ`3ooo]ZoookJP03oookJPCo001o0_oo0>4<
oookJP03o`2Hoooonf[ooo]Z00[ooo]Z0_l0O?l:oookJP03ofko0?oonf[ooo]Z01Kooo]Z0ol007l3
oookJP?o001o0ooonfX3o`00OcSooo]Z0ol007l4oookJPKo001o7_oonfX002Oooo]Z1_l007l4oook
JP;o001o>ooonfX5o`00O`?oo`0000Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z00?oo`00
oookJ_oonfX04ooonfX;oolX00[ooo]Z0_oo0;`7oookJP;o001o00?ooo]Zool0D?oo05001ooonfX<
oomi00coobP02Ooob@07onGo0003oiCo0?l0o`co0?mM00So0?on00?o0?mMo`3o[Ol0ojd01Ol0ojd0
0ol03oooolT0ooo90007onGo0003ooo90?oUo`3oolT000KoolT02_oonfX2oomi00Gooo]Z1OooN@00
0on40?ooogT0oomi0005oomi00Oooo]Z0_ooQ`05oookJP;o001o00?ooo]Zool0hOoonfX03?oonfX2
ool000Wooo]Z2_oo0004oookJP03ofko0?oonf[ooo]Z01Gooo]Z1_l007l3oookJP?o001o0ooonfX3
o`00OcCooo]Z1_l007l4oookJP;o001oAooonfX6o`00O`Cooo]Z0_l007ljoookJPKo001o0ooonfX3
o`00O`?ooo]Z0ol007lSoookJP03od<0oooonf[ooo]Z00_ooo]Z0_oo0;`6oookJP;o001o0_oonfX2
ool0D0Wooo]Z0_l09Ol8oookJP;ooil000Gooo]Zool06?oo01Sooo]Zo`3o0003oookJP04ool0[?l0
l_oo0?;oo`3bo`[ooo]Z1_l0oeH2oh3o00;o0?mF00?ooo]Zo`3bool0l_l00_m^o`002?nMo`3o01co
o`000?l0003o]?l0o`000?oonf[o00Oo0_oonfX00ol0ol;o?`3ooookJP03oookJP08oolP0?oo05?o
oo]Zooll0?oonf[oE_l0oookJ_l0N?l=oookJP03ooo?0?oonf[ooo]Z00Cooo]Z00Koo`2FocP0oooo
nf[ocP3ooookJ_n40?l3oookJP03ool0R?oonf[ooo]Z00Oooo]Z0_ooQ`06oookJP;o001o00?ooo]Z
ool0hOoonfX03?oonfX00ol0V?oooo]ZoookJP0:oookJP03o`1loooonf[ooo]Z00Wooo]Z00?oK_l0
oookJ_oonfX05?oonfX6o`00O`?ooo]Z0ol007l3oookJP?o001o=OoonfX6o`00O`Cooo]Z0_l007lR
oookJP009ooonfX6o`00O`Cooo]Z0_l007lkoookJPKo001o00Coo`00oookJ_oonf[ooo]Z0ol007l0
1?oonf[o001oo`00Ool007lLoookJP[oobP02_oonfX00ooo0;cooo]ZoookJP07oookJP03o`00Oooo
053oo`1@00Wooo]Z2OooN@03ool000coobP04?oob@02oiCo00[o0?on00?o0?mMo`3o[Ol0ojd00ol0
ojd2o`0?o`;oolT01_oUo`02ooo90003onGo0?oob@3oolT000GoolT02OoonfX00oooN@3ooo]Zoook
JP04oookJPGoogT000?oQ03ooookJ_ooN@001oooN@05oookJP03oon70?oonf[ooo]Z00Gooo]Z0_l0
07l00ooo0>7ooo]ZoookJP06oookJP06oolX0?oonf[ooo]ZoookJ_l0V?ooo`002_oonfX9ool000Go
oo]Z00?oK_l0oookJ_oonfX05_oonfX6o`00O`Cooo]Z0ol007l01?oonf[o001oo`00Ool007leoook
JPKo001o1?oonfX2o`00OdOooo]Z1_l007l4oookJP;o001o>_oonfX6o`00O`Cooo]Z0ol007l01?oo
nf[o001oo`00Ool007lRoookJP;o@`3o3OoonfX00ooo0;cooo]ZoookJP06oookJP;o001o0_oo050:
oookJP03o`0Uoooonf[ooo]Z00Kooo]Z0_ooW`000ooonf[oo`0Hool06002oookJP03o`3o0?oonf[o
oo]Z00?o0?;o2ooonfX2o`3oEP03oookJ_n0o`3oP?l000?oP?l00_oo0744oh3o0005o`3bool0o`Co
K_l0ool0@_mKo`000_l000000ondo`3o0000o`07o`02oookJP03o`3o`_lo0?oooo]Z00?ooo]Z00?o
ob00ool0DooonfX00_oo?0000ooonf[oE_l0o`1ho`0=oookJP03ooo?0?oonf[ooo]Z00Cooo]Z00Ko
o`2FocP0oooonf[ocP3ooookJ_n40?l2oookJP;oo`282OoonfX00oooQ`3ooo]ZoookJP06oookJP;o
001o00?oo`3QoookJ_oonfX02_oonfX2o`2Ho`cooo]Z00?o07cooookJ_oonfX02OoonfX00om^o`3o
oo]ZoookJP0EoookJPKo001o1?oonfX3o`00O`04oookJ_l007oo001oo`00OcKooo]Z1_l007l4oook
JP;o001o8_oonfX002Wooo]Z1?l007l5oookJPOo001o=ooonfX4o`00O`Cooo]Z1ol007lMoookJPSo
obP02_oonfX00ooo0;cooo]ZoookJP08oookJP03ool0D?l007oo001o00Go001o0ooonfX00ol09Ooo
ogT0oomi0004oomi00Koo`003?oo:00<ooo900?oiOl00onDo`02o`1Oo`So0?on00?o0?mMo`3o[Ol0
ojd00ol0ojd00ol03oooolT0ooo90006onGo00;oolT00ooUo`07ooo900Oooo]Z00?oogT0oookJ_oo
nfX01?oonfX5oomi0003oh@0ooooN@3oogT000WoogT00ooonfX00oooQ`3ooo]ZoookJP07oookJP03
ool0hOl007oo001o00Co001o0ooonfX01?oo:03ooo]ZoookJ_l0V?l8oookJP04ool00?oonf[ooo]Z
oookJPOoo`0000?ooo]ZoolX0?oonfX00ooonfX00om^o`3ooo]ZoookJP0IoookJPCo001o1?oonfX7
o`00OcOooo]Z1?l007l5oookJPOo001o@ooonfX4o`00O`Gooo]Z1ol007lfoookJPCo001o1?oonfX7
o`00Ob3ooo]Z0_m30?l>oookJP03ool0_?oonf[ooo]Z00Sooo]Z00?oo`1@o`00Ool007l01?l007l4
oookJP;o02Go1_oonfX3oonO0003oookJ_oo01Soo`0H00Gooo]Z0_l0l_l00ooo0:cooo]ZoookJP09
oookJP;o0?mF0on0o`000ooo077ooo]Zo`3[o`07o`3[o`?oP?l000?o0?l4ofko0?mKo`000_l00000
0ondo`3o0000o`07o`02oookJP03ocl0oooonf[ooo]Z00;ooo]Z00Coob00ool0Dooonf[ooc`00_oo
nfX00omFo`3o07SooookJP0<oookJP03ooo?0?oonf[ooo]Z00Cooo]Z00Koo`2FocP0oooonf[ocP3o
oookJ_n40?l2oookJP03ool0R?oonf[ooo]Z00Sooo]Z00?oohL0oookJ_oonfX02?oonfX00ooo0>7o
001oo`00O`04o`00O`Kooo]Z00?o09SooookJ_oonfX02ooonfX00ol0O?oooo]ZoookJP08oookJP;o
K_l06_oonfX4o`00O`Cooo]Z1ol007lhoookJPCo001o1OoonfX7o`00Oacooo]Z000ZoookJP?o001o
1OoonfX7o`00OcSooo]Z0ol007l5oookJPGo001o7ooonfX6oolX00Wooo]Z0_oo0;`9oookJP;oo`1@
00?ooo]Zo`00Ool007l01Ol007l2oookJP03o`0Uoooonf[oogT000GoogT01ooo0009oolX0003oook
J_oob@3oolT000_oolT01OoUo`03oiCo0003o`1Oool0ojgo0?on00Ko0?on1Ol0ojd00ol03oooolT0
ooo90006onGo0003ooo90?oUo`3oiOl000?oiOl01?oob@08oookJP03ooo?0?oonf[ooo]Z00Gooo]Z
00Go>03ooomi0?ooN@3oogT0oh@0o`0:oomi00Cooo]Z00?oohL0oookJ_oonfX01ooonfX00ooo0>7o
001oo`00O`05o`00O`;ooo]Z0ooo:0000ol0V?oooo]ZoookJP07oookJP03ool00?oonf[ooo]Z00Ko
o`000ooonfX01Ooo:03ooo]ZoookJ_oonf[oK_l001gooo]Z0ol007l5oookJPGo001o>OoonfX3o`00
O`Gooo]Z1ol007m4oookJP?o001o1OoonfX7o`00OcOooo]Z0ol007l5oookJPGo001o8?oonfX00om3
0?oooo]ZoookJP0<oookJP;oo`2l2OoonfX2ool0D0Oo001o0ooonfX00ol09Ooooo]ZoookJP04oook
JP;ooil00ooonfX00ooo01Sooo]ZoookJP04oookJP03o`3boooo0:cooo]Z00[ooo]Z0_l0oeH2oh3o
00?ooo]Z0_l0jol9oookJP0=o`3[oon0o`3oP?l0ofko0?oo04;o01coo`000?ndo`3o0000o`07oooo
nf[o0?o2ocl0o`04oookJP07oolP0?oo05?ooo]Zooll0?oonf[oE_l0o`1ho`0=oookJP03ooo?0?oo
nf[ooo]Z00Cooo]Z0_lh0?l01?oonf[ocP3ooookJ_n40?l2oookJP03ool0R?oonf[ooo]Z00Sooo]Z
00?oohL0oookJ_oonfX02?oonfX00ooo0>7o001oo`00O`05o`00O`Gooo]Z00?o09SooookJ_oonfX0
2ooonfX00ol0O?oooo]ZoookJP08oookJP03ofko0?oonf[ooo]Z01_ooo]Z0ol007l5oookJPGo001o
>_oonfX3o`00O`Gooo]Z1ol007lLoookJP00W?oonfX00om30?ooobP0oolX0003oolX00Wooo]Z00?o
o`2loookJ_oonfX02?oonfX00ooo053ooo]ZoookJP08oookJP;o02Go0ooonfX6oomi00Koo`002?oo
:002oookJPcoolT02OoUo`02oiCo0003o`1Oool0ooko0?on00Go0?on0ol0ojd2o`0?o`03ooo90?oU
o`3oiOl000CoiOl000?oolT0onGo0?oUo`001?oUo`03ooo900Gooo]Z00CoolT0oookJ_oonf[ooll0
1ooonfX01Olh0?ooogT0oomi0?ooN@3oQ03o00SoogT01_oonfX00oooQ`3ooo]ZoookJP07oookJP03
ool0hOoonf[ooo]Z00Oooo]Z1Ooo:008oookJPSoo`001?oonfX3oolX0003oookJ_m^o`3ooo]Z0?oo
oo]Z:?oonfX2od<0o`kooo]Z00?oo`2loookJ_oonfX02?oonfX00ooo053ooo]ZoookJP08oookJP;o
02Go1_oonfX00oooW`3ooo]ZoookJP02oookJP03ool06?oonf[ooo]Z00?ooo]Z0_oo0:`;oookJP;o
0?mF0_n0o`02oookJP?o0>_o2OoonfX4om;o0007o`3[ool0o`CoK_l0o`0Lool0003o]?l0o`07o`02
oookJP03ocl0oooonf[ooo]Z00;ooo]Z00Coob00ool0Dooo?03ooc`00_mFo`000ol0N?oooo]Zoook
JP0;oookJP03ooo?0?oonf[ooo]Z00Cooo]Z00Ko>03ooookJ_oonf[ocP3ooookJ_n40?l2oookJP03
ool0R?oonf[ooo]Z00Sooo]Z00?oohL0oookJ_oonfX02?oonfX00ooo0>7ooo]ZoookJP0:oookJP03
o`2Hoooonf[ooo]Z00_ooo]Z00?o07cooookJ_oonfX02?oonfX00om^o`3ooo]ZoookJP2>oookJP00
V_oonfX2od<0o`;ooo]Z0ooo:009oookJP03ool0_?oonf[ooo]Z00Sooo]Z00?oo`1@oookJ_oonfX0
2?oonfX00ol09Ooooo]ZoookJP03oookJPGoogT02?oo0006oolX00Cooo]Z2Ooob@07onGo00?o0?mM
1?oUo`02o`1Oo`Go0?on0ol0ojd00ol03oooolT0onGo000>onGo00?oolT00ooonfX2ooo900;ooll0
1_oonfX00ooo09Ko>03ooomi0002oomi0003oh@0ooooN@3oogT000GoogT01_oonfX2oon700Sooo]Z
0_oo0>49oookJP03oolX0?oo003oobP000CoobP01_oonfX7ool000Gooo]Z1Ooo:03ooookJRSooo]Z
0_m30?l?oookJP03ool0_?oonf[ooo]Z00Sooo]Z00?oo`1@oookJ_oonfX02?oonfX00ol09Ooooo]Z
oookJP05oookJP04oonO0?oonf[ooo]ZoookJP;oo`0H1?oonfX2ool0[0[ooo]Z0ol0oeH01?oonf[o
P?l0oookJ_oonfX2o`3[o`Wooo]Z0ooBo`04oolK00;od_l00_m^o`001_l0003o]?l0o`07oooonf[o
0?o2ocl0o`?ooo]Z00Goob00ool0Dooo?03ooo]ZoeKo0002oookJP03o`1hoooonf[ooo]Z00Wooo]Z
0_ooc`06oookJP07ocP0oooonf[ocP3oolh0oooonf[oQ03ooookJP02ool0R0Wooo]Z0_ooQ`09oook
JP;oo`3Q3?oonfX00ol0V?oooo]ZoookJP0;oookJP03o`1loooonf[ooo]Z00Sooo]Z00?oK_l0oook
J_oonfX0SooonfX009Wooo]Z00?o@`3ooookJ_oonfX00ooonfX00ooo:03ooo]ZoookJP06oookJP;o
obP02OoonfX2ool0D0Wooo]Z0_l09Ol7oookJPCoogT02?oo0004oolX00Gooo]Z00?oogT0ooo90?oo
b@001ooob@07onGo0004o`3oGOl0Gooo05ooo`1Oo`?o0?mM0_oUo`000ol0Gooo0?n]o`3ooP03o`3o
oP;o0?n]00?o00ooooo90?oUo`003ooUo`03ooo90003oookJ_oob@3oolT000;oolT01_oonfX00ooo
09Ko>03ooomi0002oomi0003oh@0ooooN@3oogT000CoogT01ooonfX00oooQ`3ooo]ZoookJP07oook
JP03ool0hOoonf[ooo]Z00Sooo]Z0_oo:0000ooo003oobP0oolX0004oolX00Cooo]Z1_oo0006oook
JPKoobP0oooonfXWoookJP03od<0oooonf[ooo]Z00gooo]Z0_oo0;`9oookJP;oo`1@2OoonfX2o`0U
o`Oooo]Z00?ooil0oookJ_oonfX00_oo01P4oookJP;oo`2/2ooonfX00ol0oeKooo]ZoookJP02oh3o
00;ooo]Z00?o0>_ooookJ_oonfX01ooonfX2om;o0003oolK0?oonf[ooo]Z00;ooo]Z1Ooo02d01_m^
o`3o01coo`000?l01ooo0?o2ocl0o`?ooo]Z00Koob00ool0Dooonf[ooc`0oookJ_mFo`02o`1ho`_o
oo]Z00?ooll0oookJ_oonfX01OoonfX00olh0?oooo]Zolh0o`02oookJP03oh@0oooonf[oo`2800[o
oo]Z00?oohL0oookJ_oonfX02?oonfX00ooo0>7ooo]ZoookJP0;oookJP03o`2Hoooonf[ooo]Z00_o
oo]Z00?o07cooookJ_oonfX02?oonfX00om^o`3ooo]ZoookJP2@oookJP00UooonfX2ool000cooo]Z
1Ooo:008oookJP03ool0D?oonf[ooo]Z00Sooo]Z00?o02GooookJ_oonfX01_oonfX2oonO00;oogT0
00?oo`0Hoomi0?oo00001_oo0003oolX00?ooo]Z1?ooN@000ooob@3oP?l0ooo90005ooo900;ooo]Z
1_oUo`000ol0oego05ooo`1Oo`05o`1Oo`;o0?mM00?o0?l<o`1Oool0ojd00_l0ooh2o`3o[@03o`0?
oooUo`3oiOl000WoiOl00ol0oed3onGo0003ooo90?oonf[ooo]Z00GoolT00_oonfX2ooo90003oook
J_oo09Ko>03o00GoogT000?ooo]Zoomi0?ooN@002OoonfX00oooQ`3ooo]ZoookJP07oookJP03ool0
hOoonf[ooo]Z00Sooo]Z0_oo:003ool000OoobP000?ooo]Zool00?oo00001_oo0004oookJPSoobP0
oooonfXToookJP;o@`3o3ooonfX00ooo0;cooo]ZoookJP08oookJP03ool0D?oonf[ooo]Z00Sooo]Z
00?o02GooookJ_oonfX01OoonfX2oonO00;ooo]Z00?oo`0HoookJ_oonfX00ooonfX00ooo0:cooo]Z
oookJP09oookJP;o0?mF00Cooo]Zoh3o0?n0o`3oo`1a0_oonfX00ol0jooooo]ZoookJP06oookJP;o
d_l000Cooa/0oookJ_oonf[ooo]Z0ooo02d4oookJP03ool0;Om^o`3oK_l000;o00Oo00Ko?`3ooook
J_oonf[ooo]ZoolP0?oo05<2ooll0003oookJ_mFo`3o07So00_ooo]Z0_ooc`07oookJP04ocP0oooo
nf[ocP3ooookJP;oQ03o00?ooo]Zool0R?oonfX02OoonfX00oooQ`3ooo]ZoookJP08oookJP03ool0
hOoonf[ooo]Z00_ooo]Z00?o09SooookJ_oonfX02?oonfX2o`3oI@;o07co2OoonfX2ofko09?ooo]Z
002DoookJPGoo`002_oonfX6oolX00Oooo]Z0_oo050:oookJP03o`0Uoooonf[ooo]Z00Kooo]Z00?o
oil0oookJ_oonfX00_oo01P00oooN@3ooo]Zool00007ool00003oolX0?oonf[oogT000KoogT000?o
P?l0ooo90?oob@000_oob@001?l0jooooo]ZoookJ_oonfX3ooo900CoiOl000?o0?mMo`1Oool0Gol0
2?l0Gol2o`3oG@03o`1Oool0ooko0?on00;o00oo1?oUo`000onDo`3oiOl0onGo0007o`3oG@03odCo
0?nDo`3oiOl000;ooo]Z2_oob@000ooo09Ko>03ooomi0006oomi00[ooo]Z00?oohL0oookJ_oonfX0
1ooonfX00ooo0>7ooo]ZoookJP09oookJP03oolX0?oo003oo`0000;oo`001?oo:002oookJP03oolX
0?oo003oo`0000Soo`000_oonfX:oolX0?oooo]Z8_oonfX00om30?oooo]ZoookJP0=oookJP;oo`2l
2OoonfX2ool0D0Wooo]Z0_l09Ol7oookJP03oonO0?oonf[ooo]Z00;oo`0H1OoonfX00ooo0:cooo]Z
oookJP09oookJP04o`3oE_oonf[ooo]Zoh3o00;oo`1a0_oonfX00ol0jooooo]ZoookJP05oookJP;o
d_l000?ooa/0oookJ_oonfX00_oonfX00ooo02go0?o^oookJP06oookJP05o`3ok_m^o`3o]?l0o`3o
`_lo0?l00_oonfX2oolP0005ool0Dooo?03ooo]ZoeKo0?l0N?l02ooonfX00oooc`3ooo]ZoookJP05
oookJP07ool0U_lh0?oocP3oolh0oooonf[oQ03ooookJP02ool0R0[ooo]Z00?oohL0oookJ_oonfX0
2?oonfX00ooo0>7ooo]ZoookJP0:oookJP;o09So2_oonfX00ol0ofGooo]Zo`1lo`0:oookJP03ofko
0?oonf[ooo]Z09?ooo]Z000XoookJV[o00001_oo0009o`0000OoobP01ol000000ooo053o0000o`00
0009o`000003o`0Uool0003o000000Go00000_ooW`02o`000003ool06?l0003oogT000?oobP01_oo
0009oomi0004oh3o0?oo077oolT0o`0000;oogT01ooob@04onGo0003o`3oGOl0Gooo05oo00co05oo
0_l0ooh00ooUo`3oU?l0o`0?o`02o`0?o`[o0?mM00CoA?l0oiCo0?oUo`3o00002ooob@000olh0?oo
ogT0oomi0006oomi00So00000_ooQ`09o`000003ool0hOl0003o000000Wo000000?oobP0ool00?oo
00001?oo0004o`0000;oobP02?oo0004o`0000SoobP0KOl00018oookJVgo000000?o@`3oo`000?l0
00003Ol000000ooo0;co0000o`000007o`0000;oo`1@2_l000000ol09Ooo0000o`000006o`000004
oonO0?l0003o0000ool060Go00000_oo0:`:o`0000;o0?mF0_l000001?n0o`3oo`1ao`000?l00002
o`3[o`Ko00000_oBo`02oolK00?o000000?o0?o^ool0;Ol000002?l000001?m2o`3oK_l0ofko0?lo
0?l2o`000004oolP0?oo05?o0000ooll00;oE_l000?o07Soo`000?l000002Ol000000oooc`3o0000
o`000005o`0000;o>03o00KocP3oo`000?l0003oQ03oo`000?oo08P;o`000003oon70?l0003o0000
00So000000?oo`3Qo`000?l000002_l000000ol0V?oo0000o`000009o`000003o`3oIOl0O?oo07co
00Wo00000_m^o`1co`0002?ooo]Z000XoookJVSo00001ooo0007o`0000WoobP01ol000000ooo053o
0000o`000009o`000003o`0Uool0003o000000Go000000?ooil0o`000?l000000_oo01P7oolX00Co
o`002_ooN@001?oo077oogT0oomi0?ooN@09ooo900;oiOl00_oob@000ol0oego05ooo`1Oo`0=o`1O
o`03o`0?oooo?03o0?mM00go0?mM00CoA?l0oiCo0?oUo`3oiOl03?oob@08oomi00Oo000000?oohL0
o`000?l000001ol00002ool0h@_o000000?oobP0ool00?oo00001_oo0002o`0000;oobP01_oo0006
o`0000KoobP0L?l00018oookJVco000000?o@`3oo`000?l000003?l00002ool0_0Wo000000?oo`1@
o`000?l000002Ol000000ol09Ooo0000o`000006o`000004oonO0?l0003o0000ool060Go000000?o
o`2/o`000?l000002Ol000000ol0oeKo0000o`000002oh3o00?o000000?o0>_oo`000?l000001Ol0
00000ooBo`3o0000oolK0004o`0000;oo`0]2Ol00002od;o0003omX0oooo?03ooc`000;oob0000?o
o`1Cooll0?oo?0000_mFo`000ol0N?oo0000o`000009o`000003ooo?0?l0003o000000Co000000Go
o`2FocP0ooo>0?oocP3oo`000002oh@0o`03o`000?oo08So000000[o000000?oohL0o`000?l00000
1ol00002ool0h@_o00000_l0V?l:o`0000;o0?mU00?o07coo`000?l000002?l000000om^o`3o0000
o`00001co`0002?ooo]Z000XoookJVGo00002Ooo0006o`0000_oobP01Ol00002ool0D0[o00000_l0
9Ol6o`0000;ooil00_l000000ooo01SoobP0oolX0007oolX00?oo`003oooN@0=ooo90003o`3oGOl0
Gooo05oo00_o05oo00?o0000o`0@ool0Gol03ol0oed00om4o`3oU?l0ooo9000=ooo900_oogT00ol0
00000oooQ`3o0000o`000007o`000003ool0hOoo003o000000[o000000?oobP0ool00?oo00001ooo
00000ol0003oobP0oolX0005ool000Oo00001Ooo:00No`000003ool00?l0003o0000057o0000B?oo
nfYZo`0000;o@`3o3_l000000ooo0;co0000o`000007o`0000;oo`1@2_l00002o`0Uo`Oo00000_oo
W`02o`000003ool06?l0003o000000?o000000?oo`2/o`000?l000002Ol000001?l0oeKo0000oh3o
0?n0o`03o`0000;o0>_o1ol000000ooBo`3o0000oolK0004o`000003ool0;Ol0003o000000So0000
0_m2o`000ooJ0?oo0000o`0@o`05ooll0003oeKo0?l0N?oo000000[o00000_ooc`06o`0000;o>03o
00CocP3oo`000?l0003oQ03o0_l000000ooo08So0000o`000009o`000003oon70?l0003o000000Oo
000000?oo`3Qo`000?l000002_l000000ol0V?oo0000o`000009o`000003o`3oIOl0O?oo07co00[o
000000?oK_l0o`000?l00000M?l0000SoookJP00:?oonfYSo`0000[oo`001_l0000;oolX00Go0000
00?oo`1@o`000?l000002Ol000000ol09Ooo0000o`000005o`000003oonO0?l0003o000000;oo`0H
2_oo:0001?l0003oo`00o`000?l0000>oomi0003o`000?oob@3oolT000[oolT000?o0?mMo`1Oool0
Gol01ol0Gol00onDo`3oiOl0onGo0003onGo0003o`1Oool0o`co0?l<00go0?mM00?oA?l0oiCo0?oo
b@003_oob@05oomi00;o00000oooN@02o`000003oon70?l0003o000000Oo000000?oo`3Qool00?oo
00002_l00002oolX00[oo`0000?oobP0ool00?oo00000_oo0003oolX00Go00001?oo:00Po`000003
ool00?l0003o0000057o0000B?oonfYYo`000003od<0ool0003o000000co00000_oo0;`9o`000003
ool0D?l0003o000000Wo000000?o02Goo`000?l000001_l000000oooW`3o0000o`000002ool060Go
000000?oo`2/o`000?l000002Ol000001?l0oeKo0000oh3o0?oo0743o`000003o`3[ool0003o0000
00Go00000_oBo`02oolK00?o00000_oo02d:o`000004od;o0?oJ0?oofP3oo`0000;o013o00?oe?l0
ooll0?oo?0000_mFo`000ol0N?oo0000o`000009o`000003ooo?0?l0003o000000Go000000Co>03o
olh0ooo>0?oo00000_n40?l2o`000003ool0R?l0003o000000Wo000000?oohL0o`000?l000001_l0
0002ool0h@co000000Co09Soo`000?l0oaco0?lL2?l000000ol0ofGo07coo`000009o`0000;oK_l0
Mol0000SoookJP00:_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z01Oooo]Z2_oo
0007oookJP[oobP01OoonfX00ooo053ooo]ZoookJP09oookJP03o`0Uool0003ooo]Z00Gooo]Z00Co
oil0oookJ_oonf[oo`0H0_oonfX:oolX00Gooo]Z3?ooN@02oookJPcoolT000?o0?mMo`1Oool0Gol0
1?l0Gol3oiCo00GoiOl00ol0Gol4o`3o3003oiCo0?l0oego0?mM00Oo0?mM00?oA?l0oiCo0?oob@00
3_oob@000oooN@3ooo]ZoookJP03oookJPGoogT000?oohL0oookJ_oonfX01ooonfX00ooo0>7oo`00
ool00002ool000Kooo]Z00CoobP0o`2Hoooo:03ooo]Z2Ooo0002oolX00;oo`001ooo:003oookJP;o
obP08_oonfX3ool000[ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP19oookJP03
o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX07?oonfX00om30?oooo]ZoookJP0<oookJP03
ool0_?oonf[ooo]Z00Sooo]Z00?oo`1@oookJ_oonfX02OoonfX00ol09Ooo0000oookJP05oookJP;o
oil00_oonfX00ooo01Sooo]ZoookJP03oookJP;oo`2/2ooonfX01?l0oeKooo]Zoh3o0?oo0742oook
JP;o0>_o1ooonfX00ooBo`3ooo]ZoolK0004oookJP03ool0;Ol0onkooo]Z00Wooo]Z00[o@_l0omX0
oooJ0?oooo]Zo`000?l04?oo0000oond0?oDo`3ooll03?oonfX2ooo?00Kooo]Z0_lh0?l01?o>0?oo
oo]ZoookJ_n40?l3oookJP03ool0R?oonf[ooo]Z00Sooo]Z0_ooQ`08oookJP03ool0hOoonf[ooo]Z
00[ooo]Z0_l0V?l00ooonf[o0?lLo`000008oookJP03o`3oIOl0O?oooo]Z00Wooo]Z00?oK_l0oook
J_oonfX0;_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02;ooo]Z002:oookJP[o
o`002?oonfX8oolX00Cooo]Z0_oo050;oookJP03o`0Uoooonf[ooo]Z00Gooo]Z00Cooil0oookJ_oo
nf[oo`0H1?oonfX8oolX00?ooo]Z3_ooN@04oookJP_oolT000?oU?l0o`1Oool0Gol01_nDo`05onGo
0005oiCo0?l0Gooo05ooo`1Oool0ooh01Ol0o``2oiCo00Ko0?mM00?oA?l0oiCo0?oUo`000_oUo`0=
ooo900Cooo]Z1_ooN@08oookJP;oo`3Q1Ooo0005oookJP;oobP00_oonfX7ool000?oobP000?o0?mU
ool00?oo:0001_oo:003oookJP03ofko0?oo:03ooo]Z02;ooo]Z1_oo003ooookJP03od<0oooonf[o
oo]Z00cooo]Z00?oo`2loookJ_oonfX02?oonfX00ooo053ooo]ZoookJP09oookJP03o`0Uoooonf[o
oo]Z00Gooo]Z00Gooil0oookJ_oonf[ooo]Zool06005oookJP03ool0[?oonf[ooo]Z00[ooo]Z00Co
0?mFoookJ_n0o`3oo`1a0_oonfX00ol0jooooo]ZoookJP06oookJP03om;o0?oonf[ooa/000Cooo]Z
00?oo`0]o`3ok_oonfX02OoonfX00om2o`3ooo]ZomX0o`02oookJP04o`0@ool0003o0000oond00;o
e?l000?ooll0oookJ_oonfX02?oonfX00oooc`3ooo]ZoookJP04oookJP;o>03o0_o>0?l00ooonf[o
Q03ooh@0o`02oookJP;oo`282?oonfX3oon700Sooo]Z0_oo0>4;oookJP;o09So00?ooo]Zo`3o7?l0
oa`02?oonfX2o`3oI@[ooo]Z0_m^o`0WoookJP;o0?7oM?oonfX008_ooo]Z2?oo000:oookJPOoobP0
0ooonfX00ooo053ooo]ZoookJP0:oookJP03o`0Uoooonf[ooo]Z00Gooo]Z00Cooil0oookJ_oonf[o
o`0H1?oonfX2ool000KoobP00_oonfX?oomi00Gooo]Z2_oob@000ooUo`3oU?l0oiCo0006oiCo00Go
iOl00_nDo`03o`1Oo`03o`3o[Ol0o`co0?l<00Co0?l<1OnDo`02o`3oG@03odCo0?nDo`3oiOl000oo
olT00ooonfX8oomi00Gooo]Z0_oo0>400ooonf[oo`00ool00005ool000?ooo]Z1?oo:005ool00003
oookJ_oo:03oobP000WoobP01OoonfX00om^o`3ooo]ZoookJP0RoookJPOoo`00o_oonfX00om30?oo
oo]ZoookJP0<oookJP03ool0_?oonf[ooo]Z00Sooo]Z00?oo`1@oookJ_oonfX02OoonfX00ol09Ooo
oo]ZoookJP05oookJP05oonO0?oonf[ooo]ZoookJ_oo01P01OoonfX00ooo0:cooo]ZoookJP0:oook
JP04o`3oE_oonf[oP?l0ool0L@;ooo]Z00?o0>_ooookJ_oonfX01ooonfX00ooBo`3ooa/0oookJP03
oookJP03ool0;Ol0onkooo]Z00Wooo]Z00?o@_l0oookJ_oJ0?l00ooonfX02?l04?oo0000o`000?oo
]03o0?m5omCo0?m^o`3ooll01_oonfX3ooo?00Gooo]Z0_lh0?l2olh0o`03oookJ_n40?ooQ03o00;o
oo]Z0_oo08P9oookJP03oon70?oonf[ooo]Z00Oooo]Z0_oo0>4<oookJP04o`2Hoooonf[ooo]Zo`3o
70Wooo]Z00?o0?mUo`1loooonfX02OoonfX00om^o`3ooo]ZoookJP0VoookJP03o`3aoooonf[ooo]Z
07Cooo]Z002<oookJPKoo`002OoonfX2ool0_003oookJ_oo:03oobP000?oobP00ooonfX00ooo053o
oo]ZoookJP0:oookJP03o`0Uoooonf[ooo]Z00Cooo]Z0_ooW`02oookJP04ool06?oonf[ooo]Zoook
JPCoo`001Ooo:002oookJPooogT01OoonfX00ooBo`3ooa/0ooo90007ooo900?oiOl01_nDo`05onGo
00?oU?l00ol0Gol2o`3o[@Oo0?l<1_nDo`000ooUo`3oolT0ooo9000>ooo90003oookJ_ooN@3oogT0
00[oogT00_oonfX00ooo0>7oobP0oolX0009ool00003oookJ_oo:03oobP000?oobP00_oo0003oook
JPWoobP01ooonfX00om^o`3ooo]ZoookJP0RoookJPWoo`00oooonfX;oookJP;oo`2l2_oonfX00ooo
053ooo]ZoookJP09oookJP03o`0Uoooonf[ooo]Z00Cooo]Z0_ooW`03oookJP03ool06?oonf[ooo]Z
00?ooo]Z00?oo`2/oookJ_oonfX02OoonfX2o`3oEP03oookJ_n0o`3oo`1a00;ooo]Z00?o0>_ooook
J_oonfX01ooonfX00ooBo`3ooa/0oookJP03oookJP03o`3ok_oo02gooo]Z00Wooo]Z00?o@_l0oook
J_oJ0?l00ooonfX02Ol04?oo0000o`000?l0003ook@0o`3oA_nW0?ooe?l0ocP0o`06ooo?00Oooo]Z
00?o>03oolh0ooo>0?l00_oonfX01On40?oooo]ZoookJ_oonf[oo`2800[ooo]Z00?oohL0oookJ_oo
nfX01ooonfX00ooo0>7ooo]ZoookJP0:oookJP;o09So0_oonfX00ol0oacooo]ZoookJP06oookJP;o
0?mU2ooonfX00om^o`3ooo]ZoookJP0VoookJP03o`3aoooonf[ooo]Z07Gooo]Z002<oookJPGoo`00
2OoonfX00ooo0;cooo]ZoookJP02oookJP?oobP00ooonfX00ooo053ooo]ZoookJP09oookJP;o02Go
1_oonfX00oooW`3ooo]ZoookJP02ool060;ooo]Z1ooo0003oolX00?ooo]Z3_ooN@05oookJP07om;o
0?oo6`3ooo]ZoookJ_oob@3ooo]Zoomi0003ooo90004oookJ_oUo`3oiOl0onGo00GoU?l01OoUo`03
oiCo00Go05oo00?o0?n]o`3o3?l0o``01ol0o``4oiCo00SoiOl02Ooob@0=oomi00;oo`3Q0ooo:009
ool000OoobP00ooonfX9oolX00Kooo]Z0_m^o`0ToookJP_oo`00oooonfX9oookJP03ool0_?oonf[o
oo]Z00Wooo]Z00?oo`1@oookJ_oonfX02?oonfX2o`0Uo`Kooo]Z00Cooil0oookJ_oonf[ooo]Z0_oo
01P5oookJP03ool0[?oonf[ooo]Z00Wooo]Z00Go0?mFoookJ_oonf[oP?l0ool0L@02oookJP03o`3[
oooonf[ooo]Z00Kooo]Z0_oBo`000ooo6`3ooo]ZoookJP02oookJP03o`3ok_oo02gooo]Z00Wooo]Z
00?o@_l0oookJ_oJ0?l00ooonfX00ol04?oooo]Zo`000002o`000005oond0?oonf[o0?m5omCo0?n8
o`000_lh0?l8oookJP?o>03o00?ocP3ooookJ_oonfX00_n40?l2oookJP;oo`282_oonfX00oooQ`3o
oo]ZoookJP06oookJP;oo`3Q2ooonfX2o`2Ho`;ooo]Z0_l0oa`8oookJP03o`3oIOl0O?oooo]Z00Wo
oo]Z0_m^o`0WoookJP;o0?7oN?oonfX008gooo]Z0ooo0009oookJP03ool0_?oonf[ooo]Z00Cooo]Z
00?oobP0oookJ_oonfX00_oo:00;oookJP03o`0Uoooonf[ooo]Z00Gooo]Z00Cooil0oookJ_oonf[o
o`0H0_oonfX9ool00003oookJ_oo:03ooo]Z00;ooo]Z3_ooN@05oookJP03om;o0?oo6`3ooo]Z00?o
oo]Z0oooN@001?oob@3ooo]ZoookJ_oonfX3onGo00?oU?l00_oUo`000ooob@3oiOl0onGo0004oiCo
00Go05oo0_l0ojd9o`3o30?oU?l02?oUo`0:ooo900coogT000?ooo]ZoolX0?oo:0000ooo:009ool0
00OoobP000?ooo]ZoolX0?oo:0002Ooo:004oookJP03ofko0?oonf[ooo]Z02Cooo]Z2Ooo003ooook
JP[ooo]Z00?oo`2loookJ_oonfX02?oonfX2ool0D0[ooo]Z00?o02GooookJ_oonfX01OoonfX01Ooo
W`3ooo]ZoookJ_oonf[oo`0H00Kooo]Z00?oo`2/oookJ_oonfX02OoonfX01Ol0oeKooo]ZoookJ_n0
o`3oo`1a00;ooo]Z00?o0>_ooookJ_oonfX01_oonfX00ooBo`3ooo]ZoolK0004oookJP;oo`0]2ooo
nfX00om2o`3ofP3ooookJP03oookJP03o`0@oooonf[o000000;o000000Kook@0oookJ_l0odGoocT0
omCo0?n40?l9ocP0o`?ocP3o0on40?l01?oonf[oo`28ool0R?oo08P:oookJP;oohL02?oonfX00ooo
0>7ooo]ZoookJP0:oookJP05o`2Hoooonf[ooo]ZoookJ_l0oa`02OoonfX00ol0ofGo07cooookJP09
oookJP03ofko0?oonf[ooo]Z02Kooo]Z00?o0?7ooookJ_oonfX0N?oonfX008kooo]Z00?oo`00oook
J_oonfX01ooonfX00ooo0;cooo]ZoookJP06oookJPCoobP02_oonfX00ol09Ooooo]ZoookJP05oook
JP05oonO0?oonf[ooo]Zool06?oonfX02_oo0005oookJPkoogT01OoonfX00ooBo`3oogT0oookJP03
oookJP?oogT01_oonfX3onGo0004oiCo0?oUo`3oiOl0ooo900;oiOl01OnDo`05o`1Oo`;o0?n]00?o
0?ono`3o3?l0o``01ol0o``00onDo`3oiOl0onGo0007onGo00[oolT02oooN@07oolX00Koo`005?oo
:005oookJP03ofko0?oonf[ooo]Z02Cooo]Z1ooo003ooookJPcooo]Z00?oo`2loookJ_oonfX02?oo
nfX00ooo053ooo]ZoookJP09oookJP03o`0Uoooonf[ooo]Z00Gooo]Z00Gooil0oookJ_oonf[ooo]Z
ool0600BoookJP05o`3oE_oonf[ooo]Zoh3o0?oo07400_oonfX00ol0jooooo]ZoookJP06oookJP03
om;o0?oonf[ooa/000Cooo]Z00?oo`0]o`3ok_oonfX02_oonfX00om2o`3ooo]ZomX0o`04oookJP03
o`0@oooonf[o000000;o000000Cook@0oookJ_l0odGooo]Z0_oDo`000omSo`3oQ03ooh@0o`02oh@0
o`?ocP3o1?n40?l2oookJP;oo`282_oonfX3oon700Wooo]Z00?oo`3QoookJ_oonfX00_oonfX2of?o
00Kooo]Z00?o09SooookJ_oonfX00_l0oa`8oookJP;o0?mU2ooonfX00om^o`3ooo]ZoookJP0Voook
JP03o`3aoooonf[ooo]Z07Wooo]Z002FoookJP;oo`001ooonfX5oolX00[ooo]Z00?o02GooookJ_oo
nfX01OoonfX01OooW`3ooo]ZoookJ_oo01Sooo]Z00[oo`001_oonfX3oomi00;oP?l01OooN@02oook
JP03oomi0?oonf[ooo]Z00;ooo]Z1?ooN@02oookJPCoogT01ooonfX5onGo00;oolT00_oUo`04oiCo
00Oo05oo0_l0ojd8o`3o3003o`3oo_nDo`3oiOl000SoiOl00ooob@03oookJPOoogT000?ooo]Zoomi
0?ooN@001?ooN@09oolX0004ool00?oonf[o09SooookJQ;oobP01_oonfX2ofko02Kooo]Z1_oo003o
oookJPcooo]Z0_oo0;`:oookJP03ool0D?oonf[ooo]Z00Wooo]Z00?o02GooookJ_oonfX01OoonfX0
1OooW`3ooo]ZoookJ_oonf[oo`0H01;ooo]Z00Go0?mFoookJ_n0o`3oP?l0ool0L@02oookJP03o`3[
oooonf[ooo]Z00Kooo]Z00?od_l0oookJ_oo6`001?oonfX00ooo02go0?o^oookJP0;oookJP03od;o
0?oJ0?oooo]Z00?ooo]Z00?o013ooookJ_oonfX00ol000002?oo]03ooo]ZoookJ_l0odGoocT0omCo
0?m^o`3oohL00ooo08P3oh@0o`;ooo]Z1?oo08P;oookJP03oon70?oonf[ooo]Z00Sooo]Z0_oo0>43
oookJP;oHol01ooonfX01?l0V?oooo]ZoookJ_l0oa`9oookJP03o`3oIOoonf[ooo]Z00Wooo]Z0_m^
o`0WoookJP;o0?7oO?oonfX009Cooo]Z1?oo0005oookJPKoobP02_oonfX00ol09Ooooo]ZoookJP05
oookJP04oonO0?oonf[ooo]Zool060;ooo]Z2Ooo0008oookJP03oomi0?n0o`3oogT000GoogT01ooo
nfX4oomi0003oookJ_ooN@3oogT000?oogT01ooonfX2ooo900?oiOl00_oob@02onGo00GoU?l01ol0
Gol2o`3o[@03o`3oo_l0o`co0?l<00Co0?l<00Co0?ono`3oGOl0oegoU?l01ooUo`04ooo90003oook
J_ooQ`3oogT000;oogT01OoonfX6oomi00[oobP00_l0V?l00ooonf[oobP0oolX000>oolX00Sooo]Z
00?oK_l0oookJ_oonfX09OoonfX4ool00?oooo]Z3_oonfX00ooo0;cooo]ZoookJP09oookJP03ool0
D?oonf[ooo]Z00Wooo]Z00?o02GooookJ_oonfX01OoonfX01OooW`3ooo]ZoookJ_oonf[oo`0H01;o
oo]Z00Co0?mFoookJ_n0o`3oo`1a0ooonfX00ol0jooooo]ZoookJP07oookJP03om;o0?oo6`3ooo]Z
00?ooo]Z00?oo`0]o`3ok_oonfX02ooonfX00om2o`3ooo]ZomX0o`03oookJP04o`0@oooonf[ooo]Z
oookJP;o000000Kook@0o`3oA_oonf[ooo]Zo`3oAOoo>@02omCo0003ofko0?ooQ`3oohL000;ooo]Z
1?oo08P=oookJP;oohL02OoonfX2ool0h@Cooo]Z00?oHol0oookJ_oonfX01OoonfX2o`2Ho`03oook
J_l0oaco0?lL00Sooo]Z0_l0ofD;oookJP03ofko0?oonf[ooo]Z02Kooo]Z00?o0?7ooookJ_oonfX0
O?oonfX009;ooo]Z1Ooo0004oookJPSoobP02OoonfX00ol09Ooooo]ZoookJP04oookJP;ooil00_oo
nfX00ooo01Sooo]ZoookJP02oookJPOoo`002?oonfX00ol0oeKoP?l0oomi0005oomi00Kooo]Z1Ooo
N@000ooonf[oogT0oomi0004oomi00Gooo]Z1Ooob@001?oUo`3oolT0ooo90?oob@02onGo00GoU?l0
1ol0Gol3o`3o[@Go0?l<00Co0?ono`3oGOl0oego0?mM0onDo`05onGo00SoolT01OoonfX6oomi00_o
obP00_oonfX7oolX00;ooo]Z00?o07cooolX0?oo:0000_oo:009oookJP;oK_l09ooonfX3ool00?oo
oo]Z3ooonfX00ooo0;cooo]ZoookJP08oookJP;oo`1@2ooonfX00ol09Ooooo]ZoookJP04oookJP;o
oil00ooonfX00ooo01Sooo]ZoookJP0@oookJP04o`3oE_oonf[oP?l0ool0L@?ooo]Z00?o0>_ooook
J_oonfX01ooonfX00ooBo`3ooa/0oookJP03oookJP03ool0;Ol0onkooo]Z00_ooo]Z00?o@_l0oook
J_oJ0?l01?oonfX01?l04?oooo]ZoookJ_oonfX2o`00000:oond0?l0003ooo]ZoookJ_l0odGooo]Z
ooli0?oDo`3oK_l0of?o00?oohL03_oonfX3oon700Wooo]Z0_oo0>44oookJP;oHol01_oonfX2o`2H
o`03oookJ_l0oaco0?lL00Sooo]Z00?o07coo`3oIOoonfX02_oonfX2ofko02Sooo]Z00?o0?7ooook
J_oonfX0OOoonfX0093ooo]Z1_oo0003oookJPWoobP02OoonfX00ol09Ooooo]ZoookJP04oookJP03
oonO0?oonf[ooo]Z00;oobP01_oonfX6ool000Oooo]Z00?o0?mFoh3o0?oo07401?ooN@000ol0jooo
oo]ZoookJP03oookJPgoogT01OoonfX9ooo900?oiOl01OnDo`07o`1Oo`Co0?n]0ol0o``01?l0ooko
0?mMo`3oGOl0oed5oiCo00KoiOl01_oob@03oookJPKoogT04ooo:004oookJP03o`3oIOoo:03oobP0
00[ooo]Z0_m^o`0WoookJP03o`3aoooo003ooo]Z00Gooo]Z00?oo`00oookJ_oonfX0oooonfX8oook
JP03ool0_?oonf[ooo]Z00Sooo]Z00?oo`1@oookJ_oonfX02_oonfX00ol09Ooooo]ZoookJP04oook
JP04oonO0?oonf[ooo]ZoookJP;oo`0H4_oonfX01?l0oeKooo]Zoh3o0?oo0743oookJP03o`3[oooo
nf[ooo]Z00Oooo]Z00?od_l0oolK0?oonfX00ooonfX00ooo02go0?o^oookJP0;oookJP03od;o0?oo
nf[ofP3o00Cooo]Z00?o013ooookJ_oonfX00_oonfX2o`000007oond0?l0003ooo]ZoookJ_l0odGo
oo]Zooli0002omCo0004ofko0?mSo`3oo`3QoookJP?oohL01ooonfX4oon700Wooo]Z0ooo0>44oook
JP;oHol01ooonfX01?l0V?oooo]ZoookJ_l0oa`9oookJP;o0?mU2_oonfX2ofko02Sooo]Z0_l0lOn0
oookJP00S_oonfX8ool00003oookJ_oo:03oobP000SoobP02?oonfX2o`0Uo`Kooo]Z00?ooil0oook
J_oo:0000ooo:006oookJPGoo`001ooonfX00ol0oeKoP?l0ool0L@02oookJP;oogT000?o0>_ooook
J_oonfX00ooonfX>oomi00Cooo]Z2_oob@04onGo00?oU?l02Ol0Gol3o`3o[@04o`3oo_l0o`co0?on
o`3o[@?o0?mM00?o0?l<oiCo0?nDo`000_nDo`05onGo00OoolT00_oonfX6oomi00_oobP00_oonfX0
0ol0oacoobP0oolX0006oookJP;o0?mU3?oonfX00om^o`3ooo]ZoookJP0VoookJP03o`3aoooonf[o
oo]Z00Gooo]Z0_oo003ooookJPWooo]Z00?oo`2loookJ_oonfX02?oonfX00ooo053ooo]ZoookJP09
oookJP;o02Go1_oonfX01OooW`3ooo]ZoookJ_oonf[oo`0H01?ooo]Z00Co0?mFoookJ_n0o`3oo`1a
0ooonfX00ol0jooooo]ZoookJP07oookJP03om;o0?oonf[ooa/000Cooo]Z00?oo`0]oookJ_oonfX0
2ooonfX00om2o`3ofP3ooookJP04oookJP03o`0@oooonf[ooo]Z00;ooo]Z0_l000001_oo]03o0000
o`000?oonf[o0?m5oookJP;oocT000Goe?l0ohSo0?m^o`3oHol0ool0h@03oookJPOoohL02ooonfX2
ool0h@Gooo]Z0_mSo`07oookJP;o09So00?ooo]Zo`3o7?l0oa`02?oonfX2o`3oI@_ooo]Z00?oK_l0
oookJ_oonfX09ooonfX00ol0lOoooo]ZoookJP20oookJP00S?oonfX9ool00003oookJ_oo:03oobP0
00SoobP02?oonfX00ol09Ooooo]ZoookJP05oookJP03oonO0?oo:03oobP000?oobP02?oonfX3ool0
00Oooo]Z00Co0?mFoh3o0?oonf[oo`1a0_oonfX2o`3[o`Cooo]Z3oooN@07oookJP_oolT00ooUo`00
0onDo`3o05ooo`1Oo`07o`1Oo`Co0?n]00Co0?ono`3oGOl0oego0?mM1?l0o``2oiCo00KoiOl02?oo
b@04oomi00;ooo]Z1ooo:0001?ooN@3o09Soo`2HoooonfX3o`3o70Oooo]Z0_l0ofD<oookJP;oK_l0
8OoonfX2oolX00Cooo]Z0_l0lOl7oookJPCoo`00oooonfX7oookJP03ool0_?oonf[ooo]Z00Sooo]Z
00?oo`1@oookJ_oonfX02OoonfX00ol09Ooooo]ZoookJP05oookJP05oonO0?oonf[ooo]ZoookJ_oo
01P04ooonfX01?l0oeKooo]Zoh3o0?oo0743oookJP03o`3[oooonf[ooo]Z00Oooo]Z00?od_l0oook
J_oo6`001?oonfX00ooo02gooo]ZoookJP0;oookJP03od;o0?oonf[ofP3o00Cooo]Z00?o013ooook
J_oonfX00ooonfX2o`000005o`3oA_l0003ooo]ZoookJ_l0odD00_oonfX00ooo>@3oY`3oomCo0002
ofko00;oHol00_oo0>4>oookJPCoo`3Q1_oonfX00omSo`3ooo]ZoookJP04oookJP?o09So0ol0oa`8
oookJP;o0?mU2ooonfX2ofko02Sooo]Z0_l0lOn3oookJP00R_oonfX:ool000;ooo]Z2_oo:007oook
JP03o`0Uoooonf[ooo]Z00Gooo]Z1_oo:00:oookJP03ool00?oonf[ooo]Z00Gooo]Z00Co0?mFoh3o
0?oonf[oo`1a0_oonfX00ol0jooooo]ZoookJP02oookJQ3oogT02OoonfX;ooo90004onGo0?oob@3o
oo]Zo`0?o`So0;3o0_l0ojd2o`3o30?o0?mM0ol0o``00om4o`3oU?l0oiCo0007onGo00SoolT01?oo
nfX01?mSo`3oobP0oolX0?oo:006oomi0003oookJ_l0oaco0?lL00Sooo]Z0_l0ofD00ol0O?oooo]Z
oookJP08oookJP?oK_l08_oonfX3oolX00;ooo]Z0_l0lOl8oookJPGoo`00oooonfX6oookJP03ool0
_?oonf[ooo]Z00Oooo]Z0_oo050;oookJP03o`0Uoooonf[ooo]Z00Gooo]Z00Gooil0oookJ_oonf[o
oo]Zool0600CoookJP04o`3oE_oonf[oP?l0ool0L@?ooo]Z00?o0>_ooookJ_oonfX01ooonfX00ooB
o`3ooo]ZoolK0004oookJP03ool0;Ooonf[ooo]Z00_ooo]Z00?o@_l0oookJ_oJ0?l01OoonfX00ol0
4?oooo]ZoookJP03oookJP;o000000Go0?m6o`000?oonf[ooo]Zo`3oA@02oookJP05ooli0?nbo`3o
e?l0ohSo0?m^o`000_l0oa`2of?o00Coo`3Q1OoonfX5ool0h@Oooo]Z0omSo`04oookJP?o09So00?o
oo]Zo`3o7?l0oa`02OoonfX2o`3oI@03o`1loooonf[ooo]Z00Sooo]Z0_m^o`0XoookJP;o0?7oQOoo
nfX008Wooo]Z2_oo0004oookJPSoobP01ooonfX00ol09Ooooo]ZoookJP05oookJPOoobP04OoonfX0
1?l0oeKoP?l0oookJ_oo0742oookJP03o`3[oooonf[ooo]Z00;ooo]Z4OooN@0:oookJP_oolT00ooo
nfX7o`3ooP03o`3o[Ol0o`co0?l<00?o0?l<00Co0?mMo`3o3?l0o`co0?l<0om4o`07onGo00CoolT0
2?ooN@000omSo`3ooo]Zoomi0007oomi00;o0?lL1ooonfX3o`3oI@03o`1loooonf[ooo]Z00Sooo]Z
0_m^o`0ToookJPGoobP000?o0?7ooookJ_oonfX01ooonfX7ool00?oooo]Z1?oonfX00ooo0;cooo]Z
oookJP07oookJP03ool0D?oonf[ooo]Z00[ooo]Z00?o02GooookJ_oonfX01OoonfX01OooW`3ooo]Z
oookJ_oonf[oo`0H01?ooo]Z00Co0?mFoookJ_n0o`3oo`1a0ooonfX00ol0jooooo]ZoookJP07oook
JP03om;o0?oo6`3ooa/000Cooo]Z00?oo`0]oookJ_oonfX03?oonfX00om2o`3ooo]ZomX0o`04oook
JP03o`0@oooonf[ooo]Z00Cooo]Z00Co0000o`3oA_l0003o00000_oonfX03?l0odGooo]ZoookJ_oo
>@3o/_l0ool0A?oDo`3ooh00ofko0?l0ofGo0?lLo`2Ho`?oHol000?ooo]Zool0hOoo0>400ooo0>49
oookJP?oHol01?oonfX3o`2Ho`;ooo]Z0_l0oa`8oookJP?o0?mU00?o07cooookJ_oonfX02?oonfX2
ofko02Wooo]Z00?o0?7ooookJ_oonfX02_oonfX2ool0mgWooo]Z0029oookJP[oo`001OoonfX6oolX
00Kooo]Z0_l09Ol6oookJPSoobP04OoonfX01?l0oeKoP?l0oookJ_oo0742oookJP03o`3[oooonf[o
oo]Z00;ooo]Z4OooN@0:oookJP03od;o0?oonf[oolT000?oolT000?ooo]Zooo90?oob@000ooob@02
oookJP03oolX0?oob@3oolT000?oolT00om4o`000ol0ojgo0?l<o`3o3004o`3o30KoA?l00ooUo`02
ooo901CoogT00ol0oa`2oomi00Gooo]Z0_l0ofD00ol0O?oooo]ZoookJP09oookJP;oK_l09OoonfX6
oolX00Wooo]Z2Ooo003ooookJP;ooo]Z00?oo`2loookJ_oonfX01ooonfX00ooo053ooo]ZoookJP0:
oookJP03o`0Uoooonf[ooo]Z00Gooo]Z00Gooil0oookJ_oonf[ooo]Zool0600CoookJP04o`3oE_oo
nf[oP?l0ool0L@?ooo]Z00?o0>_ooookJ_oonfX01ooonfX00ooBo`3ooa/0oookJP04oookJP03o`3o
k_oo02gooo]Z00cooo]Z00?o@_l0oookJ_oJ0?l01OoonfX00ol04?oooo]ZoookJP04oookJP04o`00
0?l0odKo0000o`0000;ooo]Z00Wo0?m5oookJ_oonf[ooo]Zooli0?nbo`3oe?l0ohSo0?oo04/00_m^
o`02o`3o7003o`2Hoooonf[oHol000?oHol01?oonfX7of?o00Kooo]Z00?o09SooookJ_oonfX00ol0
oa`7oookJP?o0?mU00?o07cooookJ_oonfX02OoonfX2ofko02Wooo]Z0_l0lOl<oookJP03ool0mooo
nf[ooo]Z07Wooo]Z002:oookJPSoo`001OoonfX00ooo053ooo]ZoolX0004oolX00Gooo]Z00?o02Go
oookJ_oonfX01?oonfX:oolX013ooo]Z00Co0?mFoh3o0?oonf[oo`1a0_oonfX00ol0jooooo]Zoook
JP04oookJPWoogT00_oo:005oomi00Wooo]Z00Co@_l0oookJ_oJ0?oooo]Z0ooob@03oomi00?oolT0
0_oonfX00ooo:03oogT0oomi0003oomi00;oU?l00_oUo`03o`3o30OoA?l00_nDo`000ooUo`3oolT0
ooo90004ooo901OoogT000?ooo]Zoomi0?l0ofD00_l0ofD00ol0O?oooo]ZoookJP09oookJP;oK_l0
9_oonfX8oolX00Oooo]Z2_oo003ooookJP7ooo]Z00?oo`2loookJ_oonfX01ooonfX00ooo053ooo]Z
oookJP0:oookJP03o`0Uoooonf[ooo]Z00Gooo]Z00Gooil0oookJ_oonf[ooo]Zool0600CoookJP04
o`3oE_oonf[oP?l0ool0L@?ooo]Z00?o0>_ooookJ_oonfX01ooonfX00ooBo`3ooa/0oookJP04oook
JP03o`3ok_oo02gooo]Z00cooo]Z00?o@_l0oookJ_oJ0?l01OoonfX00ol04?oooo]ZoookJP05oook
JP04o`3oA_l0003o0000o`0000;ooo]Z00go0?m5oookJ_oonf[ooo]Zooli0?nbo`3oo`14omCo0?n8
o`3oo`3goookJ_m^o`3o0?mU00;o0?lL00Co09SooookJ_oonf[ooo]Z1?mSo`0;oookJP;o09So0ol0
oa`8oookJP;o0?mU00?o07cooookJ_oonfX02_oonfX2ofko02[ooo]Z00?o0?7ooookJ_oonfX02_oo
nfX2ool0mgcooo]Z002;oookJPKoo`001OoonfX01?oo053ooo]ZoookJ_oonfX3oolX00Gooo]Z00?o
02GooookJ_oonfX01?oonfX:oolX013ooo]Z00Co0?mFoh3o0?oonf[oo`1a0_oonfX00ol0jooooo]Z
oookJP06oookJPSoogT000?oobP0ool0;Ooo:0000oooN@0:oookJP03od;o0?oonf[ofP3o00;ooo]Z
00CoolT0oomi0?ooN@3oogT00_oonfX00ooob@3ooo]ZoookJP02oolX00GoogT000GoolT0onGo0?oU
o`3oiOl0o`3o3007odCo00GoU?l01ooob@0Goomi0003o`3oIOooN@3ooo]Z00_ooo]Z0_m^o`0Woook
JPWoobP01_oonfX<ool00?kooo]Z00?oo`2loookJ_oonfX01ooonfX00ooo053ooo]ZoookJP0:oook
JP03o`0Uoooonf[ooo]Z00Gooo]Z00Gooil0oookJ_oonf[ooo]Zool0600CoookJP04o`3oE_oonf[o
P?l0ool0L@?ooo]Z00?o0>_ooookJ_oonfX01ooonfX00ooBo`3ooa/0oookJP04oookJP03o`3ok_oo
02gooo]Z00cooo]Z00Co@_l0oookJ_oonf[ofP3o1?oonfX00ol04?oooo]ZoookJP06oookJP06o`3o
A_l0003o0000o`000?oonf[o0?m51?oonfX02Ooo>@3o/_l0oookJ_oDo`3oR?l0oon00?oo0?Oooo]Z
ofko0002o`3oI@?o0?lL1_l0V?l00ooonf[o09Soo`2Ho`06o`2Ho`?o0?lL2OoonfX2o`3oI@03o`1l
oooonf[ooo]Z00[ooo]Z0_m^o`0ZoookJP;o0?7o2ooonfX2ool0m`Cooo]Z0_n3o`1hoookJP00S?oo
nfX5ool000Cooo]Z00?oo`1@oookJ_oonfX00ooonfX00ooo:03ooo]ZoookJP03oookJP03o`0Uoooo
nf[ooo]Z00Gooo]Z2Ooo:00@oookJP04o`3oE_oonf[oP?l0ool0L@;ooo]Z00?o0>_ooookJ_oonfX0
1ooonfX00ooBo`3oogT0oomi0004oomi0003ool00?oo02goobP000;oobP000?oogT0oookJ_oonfX0
2?oonfX00om2o`3ooo]ZomX0o`03oookJPCoogT01OoonfX6oolX00;oolT00_oUo`02ooo900GoA?l0
2?nDo`000ooUo`3oolT0ooo90004ooo901SoogT01_oonfX2oomi00;ooo]Z0_m^o`0XoookJP_oobP0
1?oonfX=ool00?oooo]Z2?oonfX00ooo053ooo]ZoookJP0:oookJP03o`0Uoooonf[ooo]Z00Gooo]Z
00Gooil0oookJ_oonf[ooo]Zool0600CoookJP04o`3oE_oonf[oP?l0ool0L@?ooo]Z00?o0>_ooook
J_oonfX01ooonfX00ooBo`3ooa/0oookJP05oookJP03ool0;Ooonf[ooo]Z00_ooo]Z00Co@_l0oook
J_oonf[ofP3o1OoonfX00ol04?oooo]ZoookJP06oookJP06o`3oA_l0003o0000o`000?oonf[o0?m5
1?oonfX02ooo>@3ooo]Zok;o0?nW0?ooe?l0ohSo0?ooP03oo`3goookJ_m^o`3o07co00;o0?mU00?o
oo]Zo`3o7?l0oa`01Ol0oa`2oookJPKo0?lL2_oonfX2o`3oI@03o`1loooonf[ooo]Z00[ooo]Z0_m^
o`0ZoookJP;o0?7o3?oonfX00ooo0?Oooo]ZoookJP02oookJP;oPol0N_oonfX008gooo]Z0ooo0004
oookJP03ool0D?oonf[ooo]Z00Sooo]Z0_oo:008oookJP03oonO0?oo:03oobP000KoobP03ooonfX0
1?l0oeKooo]Zoh3o0?oo0742oookJP03o`3[oooonf[ooo]Z00Oooo]Z00?od_l0oookJ_oonfX01?oo
N@001?oo003oo`0]ool00?oo0003oolX00Sooo]Z0_ooN@02oookJP03omX0oooonf[ooo]Z00GoogT0
1?oonfX7oolX00OoolT00om4o`0:oiCo00;oiOl01_oob@0Foomi00?ooo]Z1OooN@02ofko02Wooo]Z
2Ooo:006oookJPkoo`00oooonfX7oookJP03ool0D?oonf[ooo]Z00Wooo]Z0_l09Ol7oookJP05oonO
0?oonf[ooo]ZoookJ_oo01P04ooonfX01?l0oeKooo]Zoh3o0?oo0743oookJP03o`3[oooonf[ooo]Z
00Oooo]Z00?od_l0oookJ_oo6`001OoonfX00ooo02gooo]ZoookJP0;oookJP04od;o0?oonf[ooo]Z
omX0o`Gooo]Z00?o013ooookJ_oonfX01ooonfX01_l0odKo0000o`000?l0003ooo]Zo`3oA@Cooo]Z
00SoocT0oookJ_nbo`3ooo]ZojL0oooDo`3oR?l0oon000;ooo]Z00?oK_l0oookJ_oonfX00ol0ofD5
oookJP;o0?lL3OoonfX3o`3oI@cooo]Z0om^o`0ZoookJP;o0?7o3?oonfX2ool0m`Cooo]Z00?oPol0
oookJ_oonfX0N_oonfX008kooo]Z00?oo`00oookJ_oonfX00_oonfX00ooo053ooo]ZoookJP08oook
JP?oobP01ooonfX00oooW`3ooo]ZoookJP06oolX00oooo]Z00Co0?mFoookJ_n0o`3oo`1a0_oonfX0
0ol0jooooo]ZoookJP07oookJP06om;o0?oonf[ooo]ZoolK0?oo003oogT00ooo00001Ooo02goo`00
ool00?oonf[oobP000Sooo]Z1OooN@02oookJPKoogT01?oonfX7oolX00OoolT00om4o`09oiCo00Go
iOl01ooob@0Koomi02[ooo]Z1ooo:008oookJQ3oo`00oooonfX5oookJP03ool0D?oonf[ooo]Z00Wo
oo]Z00?o02GooookJ_oonfX01_oonfX01OooW`3ooo]ZoookJ_oonf[oo`0H01?ooo]Z00Co0?mFoook
J_n0o`3oo`1a0ooonfX00ol0jooooo]ZoookJP07oookJP03om;o0?oonf[ooa/000Gooo]Z00?oo`0]
oookJ_oonfX03?oonfX00om2o`3ooo]ZomX0o`05oookJP03o`0@oooonf[ooo]Z00Oooo]Z00?o0?m6
o`000?l000000_l000000ooonf[o0?m5oookJP04oookJP08ooli0?nbo`3ooo]Zool0A?oDo`3o05So
ohSo0?oo04/2oookJP;oK_l00_oonfX00ol0O?oo0?mUo`3oI@02o`3oI@cooo]Z1?l0ofD00ol0O?oo
oo]ZoookJP09oookJP?oK_l0:ooonfX2o`3ao`gooo]Z00?oo`3goookJ_oonfX00_oonfX2oh?o07go
oo]Z002BoookJP03ool0D?oonf[ooo]Z00Oooo]Z1?oo:007oookJP05oonO0?oonf[ooo]ZoookJ_oo
01P01Ooo:00>oookJP04o`3oE_oonf[oP?l0ool0L@;ooo]Z00?o0>_ooookJ_oonfX02?oonfX00ooB
o`3ooo]ZoolK0005ool00003ool0;Ooo003oo`0000[ooo]Z1_ooN@000ooonf[oogT0oomi0004oomi
00Cooo]Z2?oo:008ooo90003odCo0?nDo`3oU?l000OoU?l02?oUo`07ooo901WoogT0:OoonfX4oolX
00?ooo]Z0_oo:005oookJP?oo`000_oonfX:ool00?oooo]Z1ooonfX00ooo053ooo]ZoookJP09oook
JP03o`0Uoooonf[ooo]Z00Kooo]Z00Gooil0oookJ_oonf[ooo]Zool0600CoookJP04o`3oE_oonf[o
P?l0ool0L@?ooo]Z00?o0>_ooookJ_oonfX02?oonfX00ooBo`3ooa/0oookJP04oookJP03ool0;Ooo
nf[ooo]Z00cooo]Z00Co@_l0oookJ_oonf[ofP3o1OoonfX00ol04?oooo]ZoookJP07oookJP03o`3o
A_l0003o000000;o000000?ooo]Zo`3oAOoonfX01?oonfX02Ooo>@3o/_l0oookJ_oo^03oe?l0o`1R
ool0F?ooR?l0ool0B`03oookJP?oK_l00_oonfX2o`1lo`co0?mU00?o07cooookJ_oonfX02_oonfX3
ofko02cooo]Z0_l0lOl=oookJP;oo`3g0ooonfX2oh?o07oooo]Z002AoookJP03ool0D?oonf[ooo]Z
00Kooo]Z1Ooo:007oookJP05oonO0?oonf[ooo]ZoookJ_oo01P00_oonfX3oolX00kooo]Z00Co0?mF
oookJ_n0o`3oo`1a0_oonfX00ol0jooooo]ZoookJP08oookJP03om;o0?oonf[ooa/000Goo`0000Co
o`0]ool00?oo003oo`002OoonfX6oomi0003oookJ_ooN@3oogT000GoogT01?oonfX3ool000GoobP0
2?oob@07oiCo0004onGo0?nDo`3oU?l0oiCo00SoiOl01ooob@000ooonf[oogT0oomi000Foomi02Ko
oo]Z00?o0?7ooolX0?oo:0001OoonfX3oolX00?ooo]Z00Coo`3gool00?oo003oo`000_oonfX7ool0
0?oooo]Z2_oonfX00ooo053ooo]ZoookJP09oookJP03o`0Uoooonf[ooo]Z00Kooo]Z00Gooil0oook
J_oonf[ooo]Zool0600CoookJP04o`3oE_oonf[oP?l0ool0L@?ooo]Z00?o0>_ooookJ_oonfX02?oo
nfX00ooBo`3ooa/0oookJP04oookJP03ool0;Ooonf[ooo]Z00gooo]Z00?o@_l0oookJ_oJ0?l01Ooo
nfX00ol04?oooo]ZoookJP07oookJP03o`3oA_oonf[o000000?o000000?ooo]Zo`3oAOoonfX01?oo
nfX02?oo>@3ooo]Zok;o0?oonf[oY`3oomCo0?l0F?ooR?l00_ooP0000ol0lOoooo]ZoookJP02oook
JP03ofko0?oonf[ooo]Z01Oooo]Z0om^o`0]oookJP;o0?7o3OoonfX2ool0m`Cooo]Z00?oPol0oook
J_oonfX0OooonfX008oooo]Z0_oo0008oookJPKoobP01_oonfX01OooW`3ooo]ZoookJ_oonf[oo`0H
00Cooo]Z00?oobP0oookJ_oonfX03?oonfX01?l0oeKooo]Zoh3o0?oo0742oookJP03o`3[oooonf[o
oo]Z00Sooo]Z00?od_l0oookJ_oo6`000_oonfX3ool00004ool0;Ooo003oo`00ool000Wooo]Z3ooo
N@03oookJPOoo`000_oo:004ooo90003oookJ_oob@3oolT000;oolT01?nDo`0>onGo00KoolT01ooo
nfXCoomi02Cooo]Z0_l0lOl7oookJPGoobP000?ooo]Zool0mooo00002Ooo003ooookJPcooo]Z00?o
o`1@oookJ_oonfX02OoonfX00ol09Ooooo]ZoookJP06oookJP05oonO0?oonf[ooo]ZoookJ_oo01P0
4ooonfX01?l0oeKooo]Zoh3o0?oo0743oookJP03o`3[oooonf[ooo]Z00Sooo]Z00?od_l0oolK0?oo
nfX01?oonfX00ooo02gooo]ZoookJP0=oookJP04od;o0?oonf[ooo]ZomX0o`Cooo]Z00?o013ooook
J_oonfX02?oonfX00ol0odKooo]Zo`000003o`000003oookJ_l0odGooo]Z00Cooo]Z00coocT0oook
J_nbo`3ooo]Zool0A?nW0?ooe?l0ohSo0?oo>@3oPol0oon00?l0lOl4oookJPGoK_l04?oonfX4ofko
02kooo]Z0_l0lOl=oookJP;oo`3g1?oonfX2oh?o08;ooo]Z002=oookJPCoo`001_oonfX7oolX00Ko
oo]Z00Gooil0oookJ_oonf[ooo]Zool0600CoookJP04o`3oE_oonf[oP?l0ool0L@?ooo]Z00?o0>_o
oookJ_oonfX01ooonfX00ooBo`3ooo]ZoolK0004oookJP03ool00?oo02goo`0000?oo`002?oonfX?
oomi00Cooo]Z0oooN@05ool00003o`000?ooN@3oogT000;oogT000?ooo]Zooo90?oob@000_ooN@03
oiCo00koiOl02_oob@05oookJP;oK_l04?ooN@0RoookJP;o0?7o2?oonfX6oolX0003ool0mooo003o
o`0000Goo`00oooonfX?oookJP03ool0D?oonf[ooo]Z00Wooo]Z00?o02GooookJ_oonfX01_oonfX0
1OooW`3ooo]ZoookJ_oonf[oo`0H01?ooo]Z00Co0?mFoookJ_n0o`3oo`1a1?oonfX00ol0jooooo]Z
oookJP07oookJP03om;o0?oo6`3ooo]Z00Cooo]Z00?oo`0]oookJ_oonfX03_oonfX00om2o`3ooo]Z
omX0o`05oookJP03o`0@oooonf[ooo]Z00Sooo]Z00?o0?m6oookJ_l000000ol000000ooonf[o0?m5
oookJP04oookJP03ooli0?oonf[o/_l000;ooo]Z00OoY`3oomCo0?oo07ooR?l0oookJ_ooP03oo`3g
00Wooo]Z1Om^o`08oookJP?oK_l0<?oonfX2o`3ao`kooo]Z00?oo`3goookJ_oonfX00_oonfX2oh?o
08Cooo]Z002<oookJPCoo`001OoonfX9oolX00Cooo]Z0_oo:003oookJP03ool06?oonf[ooo]Z013o
oo]Z0_oo:0001?oonf[oP?l0oookJ_oo0742oookJP03o`3[oooonf[ooo]Z00Sooo]Z00?od_l0oook
J_oo6`001OoonfX01?oo02goo`00ool00?oo0008oookJQ3oogT01_oonfX01?l0odKoogT0oomi0?oo
N@02ool000GoogT00_oonfX4oomi0003oiCo0?oUo`3oiOl000coiOl03_oob@02ofko00_ooo]Z1ooo
N@0QoookJP03o`3aoooonf[ooo]Z00Oooo]Z1ooo:008ool00?oooo]Z3_oonfX00ooo053ooo]Zoook
JP09oookJP03o`0Uoooonf[ooo]Z00Kooo]Z00Gooil0oookJ_oonf[ooo]Zool0600CoookJP05o`3o
E_oonf[ooo]Zoh3o0?oo07400ooonfX00ol0jooooo]ZoookJP07oookJP03om;o0?oonf[ooa/000Go
oo]Z00?oo`0]oookJ_oonfX03OoonfX01?m2o`3ooo]ZoookJ_oJ0?l4oookJP03o`0@oooonf[ooo]Z
00Sooo]Z00?o0?m6oookJ_oonfX01?l000000ol0odGooo]ZoookJP04oookJP03ooli0?oonf[o/_l0
00;ooo]Z00Soo`14ojL0oooDo`3o05SoohSo0?oonf[ooh00ool0B`gooo]Z2?m^o`0boookJP03o`3a
oooonf[ooo]Z00cooo]Z0_oo0?L3oookJP;oPol0Q_oonfX008[ooo]Z1Ooo0005oookJPWoobP00ooo
nfX4oolX0003oookJ_oo003oo`0001;ooo]Z0ooo:0000on0o`3ooo]Zool0L@02oookJP03o`3[oooo
nf[ooo]Z00Sooo]Z00?od_l0oookJ_oo6`001OoonfX00ooo02gooo]Zool00002ool000Oooo]Z2Ooo
N@000ooonf[oogT0oomi0005oomi00Kooo]Z00Co0?m6oookJ_oonf[ooo]Z1oooN@02oookJPGoogT0
3OoUo`0?ooo903?ooo]Z0_l0lOl8oookJPOoobP02_oo003ooookJPgooo]Z00?oo`1@oookJ_oonfX0
2OoonfX00ol09Ooooo]ZoookJP07oookJP04oonO0?oonf[ooo]Zool061?ooo]Z00Go0?mFoookJ_oo
nf[oP?l0ool0L@03oookJP03o`3[oooonf[ooo]Z00Oooo]Z00?od_l0oookJ_oo6`001OoonfX00ooo
02gooo]ZoookJP0=oookJP04od;o0?oonf[ooo]ZomX0o`Gooo]Z00?o013ooookJ_oonfX02?oonfX0
0ol0odKooo]ZoookJP04o`000003o`3oAOoonf[ooo]Z00Cooo]Z00ooocT0oookJ_oonf[o/_l0oook
J_oo^03oo`14ojL0oooDo`3o05SoohSo0?oo>@3ooh00ool0Bol0lOl0@ooonfX2o`3ao`gooo]Z0_oo
0?L3oookJP;oPol00_ooP026oookJP00R?oonfX7ool000Cooo]Z2Ooo:003oookJPCoobP01?oo000@
oookJPCoobP000?oP?l0oookJ_oo07400_oonfX00ol0jooooo]ZoookJP08oookJP03om;o0?oonf[o
oa/000Gooo]Z00Goo`0]oookJ_oonf[ooo]Zool00007oookJP[oogT00ooonfX5oomi00Kooo]Z00Co
0?m6oookJ_oonf[ooo]Z0_l00005oomi00;ooo]Z1OooN@0@onGo00_oolT0<_oonfX2o`3ao`Wooo]Z
1ooo:00<ool00?oooo]Z2ooonfX00ooo053ooo]ZoookJP09oookJP03o`0Uoooonf[ooo]Z00Oooo]Z
00Cooil0oookJ_oonf[oo`0H4ooonfX01Ol0oeKooo]ZoookJ_n0o`3oo`1a00?ooo]Z00?o0>_ooook
J_oonfX01ooonfX00ooBo`3ooo]ZoolK0005oookJP03ool0;Ooonf[ooo]Z00gooo]Z00Co@_l0oook
J_oonf[ofP3o1OoonfX00ol04?oooo]ZoookJP09oookJP03o`3oA_oonf[ooo]Z00Co000000?o0?m5
oookJ_oonfX01?oonfX01?oo>@3ooo]ZoookJ_nbo`02oookJP08ool0A?nW0?ooe?l0o`1Rool0F?oo
R?l0ooli0?ooP002ool0B`03o`3aoooonf[ooo]Z03gooo]Z0_l0lOl=oookJP;oo`3g0ooonfX2oh?o
00;ooh00R?oonfX008Kooo]Z2?oo0006oookJPSoobP000?ooo]ZoolX0?oo:0000ooo:004ool0013o
oo]Z1?oo:0000on0o`3ooo]Zool0L@03oookJP03o`3[oooonf[ooo]Z00Sooo]Z00?od_l0oolK0?oo
nfX01?oonfX00ooo02gooo]ZoookJP09oookJP[oogT01?oonfX01?l04?ooogT0oomi0?ooN@07oook
JP05o`3oA_oonf[ooo]ZoookJ_l000001_ooN@02oookJPGoogT04OoUo`000ooob@3ooo]Zooo90007
ooo902oooo]Z0ol0lOl:oookJPOoobP02_oo003ooookJPgooo]Z00?oo`1@oookJ_oonfX02OoonfX0
0ol09Ooooo]ZoookJP07oookJP04oonO0?oonf[ooo]Zool061?ooo]Z00Go0?mFoookJ_oonf[oP?l0
ool0L@03oookJP03o`3[oooonf[ooo]Z00Sooo]Z00?od_l0oolK0?oonfX01OoonfX00ooo02gooo]Z
oookJP0<oookJP04od;o0?oonf[ooo]ZomX0o`Kooo]Z00?o013ooookJ_oonfX02?oonfX01?l0odKo
oo]ZoookJ_oonfX4o`000003o`3oAOoonf[ooo]Z00Cooo]Z00CoocT0oookJ_oonf[o/_l00_oonfX0
3?oo04CoY`3oool0A_oDo`3o05SoohSo0?oo>@3ooo]Zoon00?oo0?Ooo`1;o`3aoc_ooo]Z0ol0lOl=
oookJP;oo`3g0ooonfX2oh?o00;ooh00R_oonfX008Gooo]Z2Ooo0007oookJP_oobP01Ooo000?oook
JPGoobP000?oP?l0oookJ_oo07400ooonfX00ol0jooooo]ZoookJP08oookJP03om;o0?oo6`3ooo]Z
00Cooo]Z00?oo`0]oookJ_oonfX02OoonfX;oomi00?ooo]Z00Go013ooookJ_oonf[ooo]Zoomi0006
oookJP03o`3oA_oonf[ooo]Z00;ooo]Z00?o0000oomi0?ooN@001OooN@000ooonf[oogT0oomi0004
oomi00GoiOl000?oolT0onGo0?oUo`002OoUo`03oookJPGoolT0;OoonfX3o`3ao`cooo]Z1ooo:007
ool00?oooo]Z4?oonfX00ooo053ooo]ZoookJP09oookJP03o`0Uoooonf[ooo]Z00Oooo]Z00Cooil0
oookJ_oonf[oo`0H4ooonfX01Ol0oeKooo]ZoookJ_n0o`3oo`1a00?ooo]Z00?o0>_ooookJ_oonfX0
2?oonfX00ooBo`3ooo]ZoolK0005oookJP03ool0;Ooonf[ooo]Z00gooo]Z00Co@_l0oookJ_oonf[o
fP3o1OoonfX00ol04?oooo]ZoookJP09oookJP04o`3oA_oonf[ooo]ZoookJPCo000000?o0?m5oook
J_oonfX01?oonfX01?oo>@3ooo]ZoookJ_nbo`03oookJP08ojL0oooonf[oe?l0o`1Rool0F?ooR?l0
ooli0?oonfX2oon00003oookJ_l0lOoooo]Z03Kooo]Z0ol0lOl=oookJP?oo`3g0ooonfX2oh?o00;o
oh00S?oonfX008?ooo]Z2_oo0008oookJP03o`0Uoooo:03oobP000KoobP01ooo000>oookJPGoobP0
00?oP?l0oookJ_oo07400ooonfX00ol0jooooo]ZoookJP08oookJP03om;o0?oo6`3ooo]Z00Cooo]Z
00?oo`0]oookJ_oonfX02OoonfX<oomi00;ooo]Z00?o013ooookJ_oonfX02OoonfX00ooo:03ooo]Z
oookJP02oookJP03o`000?ooN@3oogT000coogT01?oUo`03ooo900OoiOl01?ooN@02ooo900;ooo]Z
0ooob@0ZoookJP?o0?7o3_oonfX7oolX00Goo`000ooo:03ooookJPoooo]Z00?oo`1@oookJ_oonfX0
2OoonfX00ol09Ooooo]ZoookJP07oookJP04oonO0?oonf[ooo]Zool061?ooo]Z00Go0?mFoookJ_oo
nf[oP?l0ool0L@03oookJP03o`3[oooonf[ooo]Z00Sooo]Z00?od_l0oookJ_oo6`001OoonfX00ooo
02gooo]ZoookJP0=oookJP04od;o0?oonf[ooo]ZomX0o`Gooo]Z00?o013ooookJ_oonfX02OoonfX0
0ol0odKooo]ZoookJP02oookJP?o000000?o0?m5oookJ_oonfX01OoonfX01?oo>@3ooo]ZoookJ_nb
o`03oookJP07ool0A?nW0?ooo`16omCo0?l0F?ooo`1oohSo0003oookJP03oon00?oo04_o0?7o03?o
oo]Z0ol0lOl>oookJP;oo`3g1?oonfX2oh?o00;ooh00S_oonfX008;ooo]Z2_oo0008oookJP03o`0U
oooonf[ooo]Z00GoobP02?oo000>oookJPGoobP000?oP?l0oolX0?oo07400_oonfX2oolX00[ooo]Z
00?od_l0oolK0?oonfX01OoonfX00ooo02gooo]ZoookJP0;oookJPWoogT00ooonfX00ol04?oooo]Z
oookJP09oookJP03oolX0?oonf[ooo]Z00;ooo]Z3oooN@02onGo00KoolT00_oUo`02ooo90003onGo
0?oob@3oolT000;oolT01?ooN@03ooo902Sooo]Z0ol0lOl?oookJPOoobP000?ooh00ool00?oo0000
2?oo:03ooookJPgooo]Z00?oo`1@oookJ_oonfX02OoonfX00ol09Ooooo]ZoookJP07oookJP04oonO
0?oonf[ooo]Zool061?ooo]Z00Go0?mFoookJ_oonf[oP?l0ool0L@03oookJP03o`3[oooonf[ooo]Z
00Sooo]Z00?od_l0oookJ_oo6`001_oonfX00ooo02gooo]ZoookJP0=oookJP03od;o0?oonf[ofP3o
00Kooo]Z00?o013ooookJ_oonfX02OoonfX00ol0odKooo]ZoookJP02oookJP?o000000?o0?m5oook
J_oonfX01OoonfX01?oo>@3ooo]ZoookJ_nbo`03oookJP09oonh0?nW0?oooo]ZomCo0?oohP3o05So
ool0Oon8o`3oocT000;ooo]Z00?ooh00ool0Booo04/00_l0lOl]oookJP?o0?7o3ooonfX2ool0m`?o
oo]Z0on3o`02oon0093ooo]Z0024oookJPSoo`001ooonfX00ol09Ooooo]ZoookJP05oolX00Woo`00
3?oonfX6oolX0003oh3o0?oo:03oo`1a00;ooo]Z0ooo:009oookJP03om;o0?oonf[ooa/000Gooo]Z
00?oo`0]oookJ_oonfX03OoonfX8oomi00;ooo]Z00?o013ooookJ_oonfX02OoonfX2oolX00Cooo]Z
0_l000000ol0odGo0000oookJP0<oomi017oolT01?ooN@03ooo902?ooo]Z0ol0lOl?oookJP03ool0
mooo:03oobP000KoobP000?ooh00oolX0?oo:0001?oo:03ooookJQ7ooo]Z00?oo`1@oookJ_oonfX0
2OoonfX00ol09Ooooo]ZoookJP07oookJP04oonO0?oonf[ooo]Zool061?ooo]Z00Go0?mFoookJ_oo
nf[oP?l0ool0L@04oookJP03o`3[oooonf[ooo]Z00Oooo]Z00Cod_l0oookJ_oonf[ooa/01OoonfX0
0ooo02gooo]ZoookJP0=oookJP04od;o0?oonf[ooo]ZomX0o`Gooo]Z00?o013ooookJ_oonfX02_oo
nfX00ol0odKooo]ZoookJP02oookJP?o000000?o0?m5oookJ_oonfX01OoonfX01Ooo>@3ooo]Zoook
J_oonf[o/_l000;ooo]Z00[ookP0ool0A?nW0?oooo]ZomCo0?l0F?ooo`1oon`0oon8o`3oocT00_oo
nfX00oooP03oPol0ool0B`02ool0B`03o`3aoooonf[ooo]Z02Kooo]Z0ol0lOl?oookJP?oo`3g0ooo
nfX2oh?o0003oookJ_ooP03ooh0009;ooo]Z0025oookJPKoo`001ooonfX00ol09Ooooo]ZoookJP04
oolX00[oo`003?oonfX7oolX0003oh3o0?oo:03oo`1a00CoobP02OoonfX00ooBo`3ooo]ZoolK0005
oookJP03ool0;Ooonf[ooo]Z00kooo]Z00?o@_l0oookJ_ooN@001OooN@02oookJP03o`0@oooonf[o
oo]Z00Sooo]Z0ooo:004oookJP;o000000?o0?m5o`000?oonfX00ooonfX4oomi01SoolT01OooN@03
ooo901Cooo]Z0oooN@06oookJP?o0?7o3ooonfX3ool0m`[oobP0oooonfXFoookJP03ool0D?oonf[o
oo]Z00Wooo]Z00?o02GooookJ_oonfX01ooonfX01?ooW`3ooo]ZoookJ_oo01PCoookJP06o`3oE_oo
nf[ooo]ZoookJ_n0o`3oo`1a0ooonfX00ol0jooooo]ZoookJP07oookJP04om;o0?oonf[ooo]ZoolK
00Gooo]Z00?oo`0]oookJ_oonfX03_oonfX00om2o`3ooo]ZomX0o`06oookJP03o`0@oooonf[ooo]Z
00Wooo]Z00?o0?m6oookJ_oonfX00ooonfX3o`000003o`3oAOoonf[ooo]Z00Gooo]Z00GoocT0oook
J_oonf[ooo]Zok;o0003oookJP09ool0A?nW0?oooo]ZomCo0?oohP3o05Soool0Oon8o`3oocT000?o
oo]Z0_ooP0000on3o`3oo`3gool0B`03o`3aob;ooo]Z0ol0lOl?oookJP?oo`3g1?oonfX2oh?o00?o
oh00U?oonfX008Gooo]Z1_oo0006oookJP03o`0Uoooonf[ooo]Z00?ooo]Z00?oobP0ool00?oo0000
2?oo000<oookJPOoobP000?oP?l0oolX0?oo07401Ooo:008oookJP03om;o0?oonf[ooa/000Gooo]Z
00?oo`0]oookJ_oonfX03_oonfX01Om2o`3ooo]ZoookJ_oJ0?ooogT000;ooo]Z00CoogT0oookJ_oo
nf[o013o2_oonfX4oolX00Cooo]Z0_l000000ol0odGo0000oookJP06oookJP03oolX0?oob@3oolT0
01WoolT00oooN@03ooo900kooo]Z2?ooN@000ooonf[o0?7oo`3ao`03o`3aoa3ooo]Z0_oo0?L00ooo
nf[oobP0oolX000:oolX0?oooo]Z5OoonfX00ooo053ooo]ZoookJP09oookJP03o`0Uoooonf[ooo]Z
00Oooo]Z00Cooil0oookJ_oonf[oo`0H5?oonfX01Ol0oeKooo]ZoookJ_n0o`3oo`1a00?ooo]Z00?o
0>_ooookJ_oonfX01ooonfX01?oBo`3ooo]ZoookJ_oo6`05oookJP03ool0;Ooonf[ooo]Z00kooo]Z
00?o@_l0oookJ_oJ0?l01_oonfX00ol04?oooo]ZoookJP0:oookJP03o`3oA_oonf[ooo]Z00?ooo]Z
0_l000000ol0odGo0000oookJP06oookJP05ooli0?oonf[ooo]ZoookJ_nbo`000ooonfX02_oo^03o
o`14ojL0oooonf[oe?l0od<0ool0F?ooo`1oohSo0?oo>@04oookJP?ooh0000?oo`1;oookJ_oonfX0
0_l0lOlLoookJPCo0?7o4?oonfX2ool0m`Gooo]Z0_n3o`02oon009Oooo]Z0024oookJP03ool00?oo
nf[ooo]Z00?oo`001_oonfX00ol09Ooooo]ZoookJP05oookJP;oobP02?oo000=oookJPGoobP000?o
P?l0oolX0?oo:0001Ooo:009oookJP03om;o0?oo6`3ooo]Z00Cooo]Z00?oo`0]oookJ_oonfX03ooo
nfX01?m2o`3ooo]ZoookJ_oJ0?l5oookJP03o`0@oooonf[ooo]Z00Wooo]Z0ooo:005oookJP;o0000
00?o0?m5o`000?oonfX01_oonfX00ooo:03oolT0ooo9000Kooo90004oomi0?oob@3oolT0ooo900;o
0?7o1ooonfX=oomi0003o`3aoooonf[ooo]Z013ooo]Z0ooo0?L00ooonf[oobP0oolX000<oolX0?oo
oo]Z5?oonfX00ooo053ooo]ZoookJP09oookJP03o`0Uoooonf[ooo]Z00Oooo]Z00Cooil0oookJ_oo
nf[oo`0H5?oonfX01Ol0oeKooo]ZoookJ_n0o`3oo`1a00?ooo]Z00?o0>_ooookJ_oonfX02?oonfX0
0ooBo`3ooo]ZoolK0005oookJP03ool0;Ooonf[ooo]Z00oooo]Z00?o@_l0oookJ_oJ0?l01OoonfX0
0ol04?oooo]ZoookJP0;oookJP03o`3oA_oonf[ooo]Z00?ooo]Z0_l000000ol0odGo0000oookJP06
oookJP05ooli0?oonf[ooo]ZoookJ_nbo`001?oonfX02_oo04CoY`3ooookJ_oDo`3oon80od<0ool0
F?ooo`1oohSo0?oo>@05oookJP03oh?o0?ooP03oo`1;00;oo`1;00?ooo]Zo`3aool0lOl01?l0lOl@
oookJPKo0?7o4OoonfX3ool0m`Gooo]Z00CoPol0oon00?ooP03ooh00VOoonfX008Sooo]Z00?oo`00
oookJ_oonfX01?oonfX00ol09Ooooo]ZoookJP06oookJP?oobP01_oo000?oookJP?oobP000?oP?l0
oolX0?oo:0001_oo:008oookJP03om;o0?oonf[ooa/000Cooo]Z00?oo`0]oookJ_oonfX03ooonfX0
1?m2o`3ooo]ZoookJ_oJ0?l6oookJP03o`0@oooonf[ooo]Z00Sooo]Z1?oo:005oookJP;o000000?o
0?m5o`000?oonfX01_oonfX00ooo:03oolT0ooo9000Oooo900;ooo]Z1?l0lOl?oomi00?oo`003_oo
nfX3ool0m`?ooo]Z4?oo:03ooookJQkooo]Z00?o02GooookJ_oonfX01ooonfX01?ooW`3ooo]Zoook
J_oo01PDoookJP05o`3oE_oonf[ooo]Zoh3o0?oo07400ooonfX00ol0jooooo]ZoookJP08oookJP03
om;o0?oonf[ooa/000Gooo]Z00?oo`0]oookJ_oonfX03ooonfX00om2o`3ooo]ZomX0o`06oookJP03
o`0@oooonf[ooo]Z00[ooo]Z00?o0?m6oookJ_oonfX01?oonfX2o`000003o`3oAOl0003ooo]Z00Ko
oo]Z00GoocT0oookJ_oonf[ooo]Zok;o0004oookJP0:oonh0?nW0?oooo]Zool0A_oDo`3oO_l0o`1H
oooo07ook03oohSo00;oocT01?oonfX01?n3o`3ooh00oh?o0?oo0?L2ool0B`Gooo]Z4?l0lOlEoook
JP;oo`3g1OoonfX4oon009cooo]Z002>oookJP03o`0Uoooonf[ooo]Z00Kooo]Z00?ooil0oookJ_oo
nfX00_oo:005ool000oooo]Z00?o0?mFoolX0?n0o`002?oo:008oookJP03om;o0?oonf[ooa/000Co
oo]Z00?oo`0]oookJ_oonfX03ooonfX01?m2o`3ooo]ZoookJ_oJ0?l6oookJP03o`0@oooonf[ooo]Z
00Sooo]Z1Ooo:005oookJP04o`000?l0odGo0000o`0000Kooo]Z0ooo:004ooo90003oookJ_oob@3o
olT001KoolT00ooo04/8oookJPWoobP01ooo000;oookJP?oo`3g0ooonfX2oon000SoobP0oooonfXV
oookJP03o`0Uoooonf[ooo]Z00Oooo]Z00?ooil0oookJ_oonfX05OoonfX01Ol0oeKooo]ZoookJ_n0
o`3oo`1a00?ooo]Z00?o0>_ooookJ_oonfX02?oonfX00ooBo`3ooo]ZoolK0005oookJP03ool0;Ooo
nf[ooo]Z00oooo]Z00?o@_l0oookJ_oJ0?l01_oonfX00ol04?oooo]ZoookJP0;oookJP03o`3oA_oo
nf[ooo]Z00Cooo]Z0_l000000ol0odGo0000oookJP06oookJP05ooli0?oonf[ooo]ZoookJ_nbo`00
1?oonfX03Ooo^03oo`14ojL0oooonf[oe?l0oooR0?mno`3o05Soool0Ool0o`ooR?l0oookJ_oo>@00
1OoonfX3oon00004oh?o0?oo04_oo`1;ool0BbCooo]Z0ooo0?L3oookJPCooh0000?oPol0oookJ_oo
nfX0WOoonfX008gooo]Z00?o02GooookJ_oonfX01_oonfX00oooW`3ooo]ZoookJP02oookJP03oolX
0?oonf[oo`0000;oo`003ooonfX01?l0oeKooo]ZoookJ_n0o`08oolX00Oooo]Z00?od_l0oookJ_oo
6`001OoonfX00ooo02gooo]ZoookJP0?oookJP04od;o0?oonf[ooo]ZomX0o`Kooo]Z00?o013ooook
J_oonfX01ooonfX6oolX00Gooo]Z00Co0000o`3oAOl0003o00001_oonfX3oolX0003ooo90?oonf[o
/_l000;ooo]Z5ooob@03oon00003ooo90?oo:03oobP000ooobP01ooo0008oookJP?oo`3g0ooonfX3
oon000;oPol0oooonfX]oookJP03o`0Uoooonf[ooo]Z00Oooo]Z00?ooil0oookJ_oonfX05OoonfX0
1Ol0oeKooo]ZoookJ_n0o`3oo`1a00?ooo]Z00?o0>_ooookJ_oonfX02?oonfX00ooBo`3ooo]ZoolK
0006oookJP03ool0;Ooonf[ooo]Z00kooo]Z00Co@_l0oookJ_oonf[ofP3o1_oonfX00ol04?oooo]Z
oookJP0:oookJP03o`3oA_oonf[ooo]Z00Gooo]Z00Co0000o`3oAOl0003o00001ooonfX01Ooo>@3o
oo]ZoookJ_oonf[o/_l000Gooo]Z00gookP0ojL0oooonf[ooo]ZomCo0?oonf[o05Soob_o0?oo07oo
0?l?ohSo0?oonf[oocT000Oooo]Z0oooP0000on3o`3oo`1;ool0B`05ool0Ba[ooo]Z0ooo0?L2oook
JPCooh000_n3o`2RoookJP00S?oonfX00ol09Ooooo]ZoookJP06oookJP03oonO0?oonf[ooo]Z00Ko
oo]Z00?oo`00oookJ_oonfX03OoonfX01?l0oeKooo]ZoookJ_n0o`08oolX00Oooo]Z00?od_l0oook
J_oo6`001OoonfX00ooo02gooo]ZoookJP0?oookJP04od;o0?oonf[ooo]ZomX0o`Kooo]Z00?o013o
oookJ_oonfX02?oonfX6oolX00Gooo]Z00?oobP0o`000?l000000_l00005oookJP?oobP00_oonfX0
1?nbo`3ooo]ZoookJ_oonfXIooo900?ooh003ooo:007ool000?ooo]Z1Ooo0?L3oookJP?ooh000_n3
o`3ooookJRoooo]Z00?o02GooookJ_oonfX01ooonfX00oooW`3ooo]ZoookJP0FoookJP04o`3oE_oo
nf[oP?l0ool0L@?ooo]Z00?o0>_ooookJ_oonfX02?oonfX00ooBo`3ooo]ZoolK0006oookJP03ool0
;Ooonf[ooo]Z00kooo]Z00Co@_l0oookJ_oonf[ofP3o1_oonfX00ol04?oooo]ZoookJP0;oookJP03
o`3oA_oonf[ooo]Z00Gooo]Z00?o0000o`3oAOl000000_l00006oookJP05ooli0?oonf[ooo]Zoook
J_nbo`001OoonfX03_oo^03oo`14ojL0oooonf[oe?l0oooR0?mno`3o05Soob_o0?oo07oo0?l?ohSo
0?oonf[oocT02OoonfX3oon00005oh?o0?oo0?Ooo`3gool0mooonfX01_oo04/?oookJPGoo`3g0_oo
nfX3oon000;oPol0Y_oonfX008_ooo]Z00?o02GooookJ_oonfX01_oonfX00oooW`3ooo]ZoookJP0F
oookJP04o`3oE_oonf[ooo]Zoh3o00WoobP01_oonfX01?oBo`3ooo]ZoookJ_oo6`04oookJP03ool0
;Ooonf[ooo]Z00oooo]Z00Co@_l0oookJ_oonf[ofP3o1_oonfX00ol04?oooo]ZoookJP08oookJPOo
obP01OoonfX01?oo:03o0000o`000?l00006oookJP?oobP00_oonfX01Onbo`3ooo]ZoookJ_oonf[o
ogT000GoolT000?oe?l0ooo90?oob@003ooob@04oookJQ3oogT01_oo0003ool0m`03oookJ_n3o`3o
Pol000;oPol00oooP03ooookJS?ooo]Z00?o02GooookJ_oonfX01ooonfX00oooW`3ooo]ZoookJP0F
oookJP04o`3oE_oonf[oP?l0ool0L@?ooo]Z00?o0>_ooookJ_oonfX02?oonfX01?oBo`3ooo]Zoook
J_oo6`05oookJP03ool0;Ooonf[ooo]Z00kooo]Z00Co@_l0oookJ_oonf[ofP3o1ooonfX00ol04?oo
oo]ZoookJP0:oookJP03o`3oA_oonf[ooo]Z00Kooo]Z00Co0000o`3oAOl0003o00001ooonfX01Ooo
>@3ooo]ZoookJ_oonf[o/_l000Kooo]Z00koo`14ojL0oooonf[oe?l0oooR0?oonf[o@`3oo`1Hoooo
7P3oo`1oo`3o3on8o`3ooo]Zooli00_ooo]Z0oooP0000on3o`3oo`3gool0m`0Dool0m`CoPol00ooo
P02[oookJP00ROoonfX2ool000Sooo]Z00?ooil0oookJ_oonfX05_oonfX01_l0oeKooo]ZoookJ_n0
o`3oo`1aoookJPOoobP01_oonfX01?oBo`3ooo]ZoookJ_oo6`05oookJP03ool0;Ooonf[ooo]Z00oo
oo]Z00Co@_l0oookJ_oonf[ofP3o1_oonfX00ol04?oooo]ZoookJP07oookJPSoobP01?oonfX2oolX
00?o00001OoonfX4oolX00;ooo]Z00Go/_l0oookJ_oonf[ooo]Zoomi0003ooo90006ojL0oooo003o
olT0omCo0?oob@3oiOl03_oob@06oookJPkoogT01Ooo0004oh?o00Gooh00oooonfXeoookJP03o`0U
oooonf[ooo]Z00Oooo]Z00?ooil0oookJ_oonfX05_oonfX01?l0oeKooo]Zoh3o0?oo0744oookJP03
o`3[oooonf[ooo]Z00Oooo]Z00Cod_l0oookJ_oonf[ooa/01OoonfX00ooo02gooo]ZoookJP0?oook
JP04od;o0?oonf[ooo]ZomX0o`Kooo]Z00?o013ooookJ_oonfX02ooonfX00ol0odKooo]ZoookJP06
oookJP04o`000?l0odGo0000o`0000Oooo]Z00GoocT0oookJ_oonf[ooo]Zok;o0006oookJP0>ool0
A?nW0?oooo]ZoookJ_oDo`3oon80ogko0?m30?oo05SooolN0?oo07oo0?l?ohSo0?oonfX2ooli00co
oo]Z1?ooP0000on3o`3ooo]ZoookJP0;oookJPCoPol01OooP02^oookJP00R?oonfX3ool000Oooo]Z
00?ooil0oookJ_oonfX05_oonfX01_l0oeKooo]ZoolX0?oo:03ooo]Zool0L@;ooo]Z1_oo:005oook
JP04om;o0?oonf[ooo]ZoolK00Gooo]Z00?oo`0]oookJ_oonfX03ooonfX01?m2o`3ooo]ZoookJ_oJ
0?l6oookJP03o`0@oooonf[ooo]Z00Oooo]Z2?oo:005oookJP;oobP00ol00005oookJPGoobP000?o
oo]Zoomi0?oonfX00ooonfX01ooob@3oogT0ooo90?ooN@3oY`3oooo90?oDo`000ooUo`04ooo90003
ohSo0?oob@3oolT000GoolT02OoonfX<oomi00Wooh00oooonfXjoookJP03o`0Uoooonf[ooo]Z00Ko
oo]Z00?ooil0oookJ_oonfX05_oonfX01Ol0oeKooo]Zoh3o0?oonf[oo`1a00?ooo]Z00?o0>_ooook
J_oonfX01ooonfX01?oBo`3ooo]ZoookJ_oo6`05oookJP03ool0;Ooonf[ooo]Z00oooo]Z00Co@_l0
oookJ_oonf[ofP3o1ooonfX00ol04?oooo]ZoookJP0:oookJP03o`3oA_oonf[ooo]Z00Oooo]Z00Co
0?m5o`000?l0003o00001ooonfX01Ooo>@3ooo]ZoookJ_oonf[o/_l000Kooo]Z00koo`14oookJ_nW
0?oooo]ZomCo0?oo04Koon80ogko0?m30?oo05Soool0Ooo/0?ooo`3JohSo00;ooo]Z00?oocT0oook
J_oonfX03OoonfXBoon00;?ooo]Z0026oookJPCoo`001ooonfX00oooW`3ooo]ZoookJP0EoookJP;o
o`0000Gooo]ZoolX0?oo:03oobP0ool0L@03oookJP03o`3[oooo:03oobP000;oobP01_oonfX00ooB
o`3ooo]ZoolK0005oookJP03ool0;Ooonf[ooo]Z00oooo]Z00Co@_l0oookJ_oonf[ofP3o1_oonfX0
0ol04?oooo]ZoookJP0:oookJPKoobP01?oonfX3oolX00?o00001OoonfX5oolX0003oookJ_ooN@3o
oo]Z00?ooo]Z1?ooN@001OnW0?ooolT0ooo90?oDo`3oiOl000KoolT000?oR?l0ooo90?oob@000ooo
b@0<oookJP_oogT01?oo003ooookJSgooo]Z00?o02GooookJ_oonfX01_oonfX00oooW`3ooo]Zoook
JP0FoookJP05o`3oE_oonf[ooo]Zoh3o0?oo07400ooonfX00ol0jooooo]ZoookJP08oookJP03om;o
0?oonf[ooa/000Kooo]Z00?oo`0]oookJ_oonfX03_oonfX01Om2o`3ooo]ZoookJ_oonf[ofP3o00Ko
oo]Z00?o013ooookJ_oonfX02ooonfX00ol0odKooo]ZoookJP07oookJP04o`3oAOl0003o0000o`00
00Oooo]Z00GoocT0oookJ_oonf[ooo]Zok;o0006oookJP03ool0A?oo^03oY`3o00;ooo]Z00[oe?l0
oooR0?oonf[o@`3ooookJ_l0F?ooo`1oon`0oooo0=[oR?l00_oonfX00ooo>@3ooo]ZoookJP3Aoook
JP00Q?oonfX5ool000Oooo]Z00?ooil0oookJ_oonfX05OoonfX2ool000CoobP000Goo`1aoookJ_oo
nf[ooo]Zo`3[o`02oookJP?oobP01OoonfX00ooBo`3ooo]ZoolK0006oookJP03ool0;Ooonf[ooo]Z
00oooo]Z00?o@_l0oookJ_oJ0?l01ooonfX00ol04?oooo]ZoookJP09oookJPCoo`000ooo:004oook
JP?oobP00ol00004oookJPKoobP000?ooo]Zoomi0?oonfX00ooonfX4oomi0004ojL0ooooN@3oolT0
oomi00CoolT00_ooN@02ooo900;oR?l01?oob@0=oookJPcoogT000?oo`00oookJ_oonfX0oooonfXj
oookJP03o`0Uoooonf[ooo]Z00Kooo]Z00?ooil0oookJ_oonfX05ooonfX01?l0oeKooo]Zoh3o0?oo
0743oookJP03o`3[oooonf[ooo]Z00Sooo]Z00?od_l0oookJ_oo6`001_oonfX00ooo02gooo]Zoook
JP0?oookJP04od;o0?oonf[ooo]ZomX0o`Oooo]Z00?o013ooookJ_oonfX02_oonfX00ol0odKooo]Z
oookJP08oookJP04o`3oAOl0003o0000o`0000Oooo]Z00GoocT0oookJ_oonf[ooo]Zok;o0007oook
JP0?ool0A?nW0?oooo]ZoookJ_oDo`3oo`16oooR0?mno`3o@`3oo`1Hool[o`3oo`1oon`0oooo0=[o
R?l000;ooo]Z00?oocT0oookJ_oonfX0d?oonfX008?ooo]Z1_oo0006oookJP03oonO0?oonf[ooo]Z
01Gooo]Z0_oo0005oolX00?ooo]Z00?o0>_ooookJ_oonfX00_oonfX00ooo:03ooo]ZoookJP03oook
JP03om;o0?oonf[ooa/000Kooo]Z00?oo`0]oookJ_oonfX03ooonfX01?m2o`3ooo]ZoookJ_oJ0?l6
oookJP03o`0@oooonf[ooo]Z00Wooo]Z1Ooo0002oookJP04oolX0?oonf[ooo]ZoookJPCoobP00ol0
0004oookJPKoobP00oooN@03oookJPGoogT000?oY`3ooomi0?ooN@001?oob@03oomi00?oolT000?o
R?l0ooo90?oob@000_oo>@0>oookJP[oogT0oooonfXloookJP03o`0Uoooonf[ooo]Z00Kooo]Z00?o
oil0oookJ_oonfX05ooonfX01?l0oeKooo]Zoh3o0?oo0743oookJP03o`3[oooonf[ooo]Z00Sooo]Z
00Cod_l0oookJ_oonf[ooa/01OoonfX00ooo02gooo]ZoookJP0?oookJP04od;o0?oonf[ooo]ZomX0
o`Oooo]Z00?o013ooookJ_oonfX05OoonfX00ol0odGo0000o`000002o`0000Oooo]Z00?oocT0oook
J_oonfX00_oonfX00onbo`3ooo]ZoookJP04oookJP0@ool0A?oonf[oY`3ooookJ_oDo`3oo`16oooR
0?oonf[o@`3ooookJ_l0F?oo:ol0ool0Ool0o`oooo]ZohSo00;ooo]Z0_oo>@3@oookJP00POoonfX7
ool000Kooo]Z00?ooil0oookJ_oonfX05?oonfX2ool000KoobP00ooonfX00ol0jooooo]ZoookJP08
oookJP03om;o0?oonf[ooa/000Gooo]Z0_oo:00BoookJP03od;o0?oonf[ofP3o00Oooo]Z00?o013o
oookJ_oonfX02OoonfX5ool000Gooo]Z1Ooo:003o`0000Cooo]Z1_oo:003oomi00?ooo]Z2OooN@03
ooo900GoogT00_oob@02oomi0003ooo90?oonf[oocT000oooo]Z0oooN@000ooonf[oogT0oomi0002
oomi0?oooo]Z>ooonfX00ol09Ooooo]ZoookJP06oookJP03oonO0?oonf[ooo]Z01Oooo]Z00Co0?mF
oookJ_n0o`3oo`1a0ooonfX00ol0jooooo]ZoookJP08oookJP04om;o0?oonf[ooo]ZoolK00Gooo]Z
00?oo`0]oookJ_oonfX04?oonfX01?m2o`3ooo]ZoookJ_oJ0?l7oookJP03o`0@oooonf[ooo]Z01Go
oo]Z00?o0?m5o`000?l000000_l0000<oookJP03ok;o0?oonf[ooo]Z00Cooo]Z00?oo`14oookJ_nW
0?l00_oonfX03?oDo`3oon80oookJ_mno`3o@`3ooookJ_l0F?oo:ol0ool0Ool0o`oooo]ZohSo00?o
oo]Z00?oocT0oookJ_oonfX0cOoonfX007oooo]Z2Ooo0005oookJP03oonO0?oonf[ooo]Z01Cooo]Z
0_oo0007oolX00;ooo]Z00?o0>_ooookJ_oonfX02?oonfX00ooBo`3ooo]ZoolK0005oookJP?oobP0
4OoonfX00om2o`3ooo]ZomX0o`07oookJP03o`0@oooonf[ooo]Z00Wooo]Z1_oo0005oookJPGoobP0
0ol00004oookJPOoobP00_ooN@03oookJPOoogT000?ooo]Zoomi0?ooN@000ooob@05oomi0003ooo9
0?ooN@3oogT000?oogT00ooo>@0>oookJP03oomi0?oonf[ooo]Z00;ooo]Z00?oogT0oookJ_oonfX0
oooonfXhoookJP03o`0Uoooonf[ooo]Z00Kooo]Z00?ooil0oookJ_oonfX05ooonfX01?l0oeKooo]Z
oh3o0?oo0743oookJP03o`3[oooonf[ooo]Z00Sooo]Z00Cod_l0oookJ_oonf[ooa/01_oonfX00ooo
02gooo]ZoookJP0?oookJP04od;o0?oonf[ooo]ZomX0o`Oooo]Z00?o013ooookJ_oonfX05_oonfX0
0ol0odGo0000o`000002o`0000cooo]Z00?o/_l0oookJ_oonfX01?oonfX00ooo^03oo`14ojL0o`03
oookJP0<omCo0?oohP3ooo]Zogko0?m30?oooo]Zo`1Hoooo7P3oo`1oon`0ool0o`ooR?l00ooonfX3
ooli0<cooo]Z001noookJPWoo`001?oonfX2ool001Kooo]Z0_oo0007oolX00;ooo]Z00?o0>_ooook
J_oonfX02OoonfX00ooBo`3ooa/0oookJP04oookJP?oobP04OoonfX01?m2o`3ooo]ZoookJ_oJ0?l6
oookJP03o`0@oooonf[ooo]Z00Wooo]Z1ooo0004oookJPKoobP00ol00003oookJPSoobP00_ooN@03
oookJPOoogT000Cooo]Zoomi0?ooN@3oogT00_oob@06oomi0003ooo90?ooN@3oogT000CoogT000Co
oo]ZoolX0?oo:03oobP0oooonfY:oookJP03o`0Uoooonf[ooo]Z00Kooo]Z00?ooil0oookJ_oonfX0
5ooonfX01?l0oeKooo]Zoh3o0?oo0743oookJP03o`3[oooonf[ooo]Z00Wooo]Z00?od_l0oookJ_oo
6`001_oonfX00ooo02gooo]ZoookJP0?oookJP05od;o0?oonf[ooo]ZoookJ_oJ0?l01_oonfX00ol0
4?oooo]ZoookJP0FoookJP03o`3oAOoonf[o000000?o00003?oonfX00onbo`3ooo]ZoookJP04oook
JP04oonh0?oo04Cooo]ZojL0o`;ooo]Z00Goe?l0ool0A_oohP3ooo]Zod<0o`02oookJP05o`1Hoooo
7P3oo`1oon`0ool0o`l00_n8o`04oookJP;oocT0b_oonfX007gooo]Z2Ooo0004oookJP?oo`005?oo
nfX2ool000SoobP00_oonfX00ol0jooooo]ZoookJP09oookJP03om;o0?oonf[ooa/000?ooo]Z1Ooo
:00AoookJP03od;o0?oonf[ofP3o00Oooo]Z00?o013ooookJ_oonfX02OoonfX7ool000Cooo]Z1_oo
:003o`0000?ooo]Z2?oo:003oomi00;ooo]Z00?oogT0oookJ_ooN@002OooN@02ooo900KoogT000?o
olT0oomi0?ooN@001OooN@06oolX0?oooo]ZAOoonfX00ol09Ooooo]ZoookJP07oookJP03oonO0?oo
nf[ooo]Z01Kooo]Z00Co0?mFoookJ_oonf[oP?l00ooonfX00ol0jooooo]ZoookJP09oookJP04om;o
0?oonf[ooo]ZoolK00Gooo]Z00?oo`0]oookJ_oonfX04?oonfX01?m2o`3ooo]ZoookJ_oJ0?l7oook
JP03o`0@oooonf[ooo]Z01Kooo]Z00?o0?m5oookJ_l000000ol0000<oookJP03ok;o0?oonf[ooo]Z
00Cooo]Z00CookP0ool0A?oonf[oY`3o0ooonfX02ooDo`3oon80oookJ_mno`3o@`3ooookJ_l0F?oo
:ol0ool0Oooo7P3ok03o00;o0?l?00?oR?l0oookJ_oonfX00ooonfX00ooo>@3ooo]ZoookJP37oook
JP00O_oonfX8ool000?ooo]Z0ooo000DoookJP;oo`002Ooo:002ool000_ooo]Z00?od_l0oookJ_oo
6`000ooonfX5oolX017ooo]Z00?o@_l0oookJ_oJ0?l01ooonfX00ooo:03ooo]ZoookJP09oookJPSo
o`000ooonfX7oolX00?o00001?oonfX5ool000GoogT01?oonfX;oomi0003ooo90?ooN@3oogT000oo
ogT01_oo:03ooookJT7ooo]Z00?o02GooookJ_oonfX01ooonfX00oooW`3ooo]ZoookJP0FoookJP04
o`3oE_oonf[ooo]Zoh3o00?ooo]Z00?o0>_ooookJ_oonfX02OoonfX01?oBo`3ooo]ZoookJ_oo6`05
oookJP03ool0;Ooonf[ooo]Z013ooo]Z00Co@_l0oookJ_oonf[ofP3o1ooonfX00ol04?oooo]Zoook
JP0GoookJP03o`3oAOoonf[o000000?o00003?oonfX00onbo`3ooo]ZoookJP05oookJP03ool0A?oo
nf[oY`3o00?ooo]Z00_oe?l0ool0A_oohP3ooo]Zogko0?m30?oooo]Zo`1Hoooonf[oo`1oon`0o`02
oookJP03o`3o3on8o`3oR?l000Cooo]Z0_oo>@37oookJP00OooonfX6ool000;ooo]Z1Ooo000Coook
JP;oo`002Ooo:003ool000[ooo]Z00?od_l0oookJ_oo6`000ooonfX6oolX013ooo]Z00Co@_l0oook
J_oonf[ofP3o1ooonfX00ooo:03ooo]ZoookJP08oookJPSoo`001?oonfX7oolX00?o00001?oonfX5
ool000GoogT01?oonfX;oomi00;oolT04_ooN@08oolX0?oooo]Z??oonfX00ol09Ooooo]ZoookJP07
oookJP03oonO0?oonf[ooo]Z01Kooo]Z00Co0?mFoookJ_oonf[oP?l01?oonfX00ol0jooooo]Zoook
JP08oookJP04om;o0?oonf[ooo]ZoolK00Gooo]Z00?oo`0]oookJ_oonfX04?oonfX01?m2o`3ooo]Z
oookJ_oJ0?l8oookJP03o`0@oooonf[ooo]Z01Kooo]Z00?o0?m5oookJ_oonfX01?l0000<oookJP03
ok;o0?oonf[ooo]Z00Gooo]Z00CookP0ool0A?oonf[oY`3o0_oonfX00ooDo`3oo`16oooR0002oook
JP05od<0oooonf[ooo]Zo`1HoooonfX00_oo07l2oookJP03o`3o3ooonf[oR?l000Gooo]Z0_oo>@35
oookJP00P?oonfX5ool00003oookJ_oo003oo`0000?oo`004ooonfX5ool000OoobP00_oo000:oook
JP03om;o0?oonf[ooa/000;ooo]Z2?oo:00?oookJP04od;o0?oonf[ooo]ZomX0o`Oooo]Z0_oo:00<
oookJPKoo`000ooonfX8oolX00?o00000ooonfX6ool000KoogT00ooonfX<oomi0003ooo90?ooN@3o
ogT0017oogT02Ooo:03ooookJSWooo]Z00?o02GooookJ_oonfX01ooonfX00oooW`3ooo]ZoookJP0F
oookJP04o`3oE_oonf[ooo]Zoh3o00Cooo]Z00?o0>_ooookJ_oonfX02?oonfX01?oBo`3ooo]Zoook
J_oo6`06oookJP03ool0;Ooonf[ooo]Z013ooo]Z00Co@_l0oookJ_oonf[ofP3o1ooonfX00ol04?oo
oo]ZoookJP0GoookJP03o`3oAOoonf[ooo]Z00Co00003?oonfX00onbo`3ooo]ZoookJP05oookJP04
oonh0?oo04Cooo]ZojL0o`?ooo]Z00Soe?l0oooR0?oonf[ooo]Zogko0?m30?oooo]Zo`1Ho`;o:ol0
00Cooah0ool0Ooo/0?oo0?l?0_oonfX2ohSo00Gooo]Z0ooo>@32oookJP00OooonfX00ooo003ooo]Z
ool00002ool00003oookJ_oo003oo`0000Coo`005?oonfX5ool000GoobP00ooo000:oookJP04om;o
0?oonf[ooa/0oookJPSoobP04?oonfX01?m2o`3ooo]ZoookJ_oJ0?l6oookJP;oobP04?oonfX3ool0
00Kooo]Z1Ooo:003o`0000?ooo]Z1ooo0005oomi00?ooo]Z8?ooN@09oolX00?oo`00oooonfXeoook
JP03o`0Uoooonf[ooo]Z00Oooo]Z00?ooil0oookJ_oonfX05_oonfX01Ol0oeKooo]ZoookJ_n0o`3o
o`1a00?ooo]Z00?o0>_ooookJ_oonfX02OoonfX00ooBo`3ooo]ZoolK0006oookJP03ool0;Ooonf[o
oo]Z013ooo]Z00Co@_l0oookJ_oonf[ofP3o1ooonfX00ol04?oooo]ZoookJP0HoookJP03o`3oAOoo
nf[ooo]Z00Co00003?oonfX00onbo`3ooo]ZoookJP05oookJP04oonh0?oo04Cooo]ZojL0o`Cooo]Z
00koe?l0oooR0?oonf[ooo]Zogko0?m30?oooo]Zo`1Hoooonf[o:ol0oolN0?oo07ook03oo`3o3`?o
oo]Z00?oR?l0oookJ_oonfX01OoonfX2ooli0<3ooo]Z001noookJP04ool00?oonf[ooo]ZoookJPSo
o`005_oonfX3ool00003oolX0?n0o`3oobP000?oobP00_oo000:oookJP04om;o0?oonf[ooa/0oook
JPWoobP03ooonfX01?m2o`3ooo]ZoookJ_oJ0?l6oookJP?oobP04_oonfX00ooo003ooo]ZoookJP03
oookJPCoo`000_oo:004o`0000;ooo]Z1ooo0005oomi00?ooo]Z0_ooN@000ooonf[oo`14oomi000@
oomi0003ool0Oooob@3oogT000OoogT02Ooo:008ool00?oooo]Z<?oonfX00ol09Ooooo]ZoookJP07
oookJP03oonO0?oonf[ooo]Z01Kooo]Z00Go0?mFoookJ_oonf[ooo]Zoh3o0003oookJP03o`3[oooo
nf[ooo]Z00Wooo]Z00?od_l0oookJ_oo6`001_oonfX00ooo02gooo]ZoookJP0AoookJP03od;o0?oo
nf[ofP3o00Sooo]Z00?o013ooookJ_oonfX05ooonfX01?l0odGooo]ZoookJ_oonfX5o`0000_ooo]Z
00?o/_l0oookJ_oonfX01_oonfX00ooo04Cooo]ZojL0o`04oookJP03omCo0?oo04Koon8000;ooo]Z
00Wo@`3ooookJ_oonf[o05SooookJ_l[o`3ooah0ool0Ooo/0?l00_l0o`l2oookJP;oR?l0aooonfX0
07gooo]Z00?oo`00oookJ_oonfX00_oonfX8ool001Kooo]Z00Goo`00oolX0?oo:03oP?l0oolX0002
ool00004oolX0?oo003oo`00ool000Wooo]Z00Cod_l0oookJ_oo6`3ooo]Z2Ooo:00?oookJP04od;o
0?oonf[ooo]ZomX0o`Kooo]Z1?oo:00GoookJPGoo`0000?ooo]Zo`000?l000000_l00002oookJPSo
o`001OooN@06oookJP03oonh0?ooN@3oogT000koogT00_oob@000ooo07ooogT0oomi0005oomi00;o
R?l00_ooN@06oolX00Soo`00oooonfX_oookJP03o`0Uoooonf[ooo]Z00Oooo]Z00?ooil0oookJ_oo
nfX05_oonfX01Ol0oeKooo]ZoookJ_oonf[oP?l000Cooo]Z00?o0>_ooookJ_oonfX02?oonfX01?oB
o`3ooo]ZoookJ_oo6`05oookJP03ool0;Ooonf[ooo]Z017ooo]Z00?o@_l0oookJ_oJ0?l02?oonfX0
0ol04?oooo]ZoookJP0LoookJPCo00003?oonfX00onbo`3ooo]ZoookJP06oookJP04oonh0?oo04Co
oo]ZojL0o`?ooo]Z00?oe?l0ool0A_oohP000_oonfX01_mno`3o@`3ooookJ_l0F?oooo]Zob_o00;o
oo]Z00?oo`1oon`0oooonfX00_l0o`l2oookJP;oR?l0aOoonfX0087ooo]Z2?oo000GoookJP;oobP0
00?oP?l0oolX0?oo00001Ooo0009oookJP04om;o0?oonf[ooo]ZoolK00?ooo]Z1ooo:00>oookJP05
od;o0?oonf[ooo]ZoookJ_oJ0?l01OoonfX5oolX01Kooo]Z1_oo00000ooonf[o0000o`000002o`00
00;ooo]Z2?oo0006oomi00Gooo]Z00?ookP0oomi0?ooN@003OooN@001?l0F?ooolT0ooo90?oob@09
oomi00;oR?l00_ooN@03oolX00Soo`00oooonfXioookJP03oonO0?oonf[ooo]Z01[ooo]Z00?oP?l0
oookJ_oonfX00_oonfX00ol0jooooo]ZoookJP08oookJP04om;o0?oonf[ooo]ZoolK00Kooo]Z00?o
o`0]oookJ_oonfX04?oonfX01?m2o`3ooo]ZoookJ_oJ0?l8oookJP03o`0@oooonf[ooo]Z01cooo]Z
1?l0000<oookJP03ok;o0?oonf[ooo]Z00Kooo]Z00CookP0ool0A?oonf[oY`3o1?oonfX00ooDo`3o
o`16oooR0002oookJP06ogko0?m30?oooo]Zo`1Hoooonf[o:ol00_oonfX01?oo07ook03ooookJ_oo
nfX2o`3o3`04oookJ_oo0=[oR?l0ohSo0<?ooo]Z0020oookJPWoo`005_oonfX2oolX0003oh3o0?oo
:03oo`0000Koo`002OoonfX00ooBo`3ooo]ZoolK0005oookJPGoobP03ooonfX01?m2o`3ooo]Zoook
J_oJ0?l5oookJPGoobP05ooonfX5ool000;ooo]Z1?l00008oookJPSoogT01OoonfX00ooo^03oogT0
oomi000<oomi00;oolT000?o05Soooo90?oob@002oooN@000on8o`3oogT0oomi0002oomi00Soo`00
oooonfXhoookJP03oonO0?oonf[ooo]Z01[ooo]Z00?oP?l0ool0LOoonfX00_oonfX00ol0jooooo]Z
oookJP09oookJP03om;o0?oonf[ooa/000Kooo]Z00?oo`0]oookJ_oonfX04OoonfX00om2o`3ooo]Z
omX0o`08oookJP03o`0@oooonf[ooo]Z01gooo]Z1?l0000;oookJP03ok;o0?oonf[ooo]Z00Oooo]Z
00CookP0ool0A?oonf[oY`3o1?oonfX00ooDo`3ooo]ZoooR0003oookJP06ogko0?m30?oooo]Zo`1H
oooonf[o:ol00_oonfX00ooo07ook03oon`0o`02oookJP04o`3o3ooonf[ooo]Zool0fP;oR?l0`Ooo
nfX0087ooo]Z1ooo000EoookJP?oobP000?oP?l0oolX0?oo00001_oo0009oookJP03om;o0?oonf[o
oa/000Kooo]Z00?oo`0]oolX0?oo:0000_oo:00>oookJP04od;o0?oonf[ooo]ZomX0o`Gooo]Z1_oo
:00FoookJPKoo`000_oonfX4o`0000_ooo]Z00?o/_l0oookJ_oonfX01ooonfX00ooo^03oogT0oomi
0005oomi0004omCo0?ooN@3ooo]ZoooR00?oogT00ooob@000ol0F?ooolT0ob_o000;oomi00;oR?l0
0oooN@06ool00?oooo]Z>?oonfX00oooW`3ooo]ZoookJP0JoookJP03oh3o0?oo077ooo]Z00;ooo]Z
00?o0>_ooookJ_oonfX02OoonfX00ooBo`3ooo]ZoolK0006oookJP03ool0;Ooonf[ooo]Z017ooo]Z
00?o@_l0oookJ_oJ0?l02?oonfX00ol04?oooo]ZoookJP0NoookJPCo00002ooonfX00onbo`3ooo]Z
oookJP08oookJP03ool0A?oonf[oY`3o00Cooo]Z00Coe?l0oookJ_oo04Koon800_oonfX01omno`3o
oo]Zod<0oooonf[o05SooookJ_l[o`000_oonfX00ooo07oooo]Zon`0o`02oookJP;o0?l?00?ooo]Z
ool0f_oonfX00_n8o`2ooookJP00P_oonfX6ool001Cooo]Z0ooo:0000on0o`3oobP0ool00007ool0
00Sooo]Z00?od_l0oolX0?oo:0001_oonfX00ooo02gooo]ZoookJP03oolX00gooo]Z00Go@_l0oook
J_oonf[ooo]ZomX0o`04oookJPOoobP05OoonfX7ool000;ooo]Z1?l0000;oookJP03ok;o0?oonf[o
oo]Z00Oooo]Z00?oobP0oomi0?ooN@001_ooN@000ooDo`3oo`16oooR0003oomi00?oolT000Cooo]Z
o`1Hoooonf[o:ol03?ooN@03ohSo00;ooo]Z1?oo003ooookJSOooo]Z00?ooil0oookJ_oonfX06_oo
nfX00on0o`3oo`1aoookJP02oookJP03o`3[oooonf[ooo]Z00Wooo]Z00?od_l0oookJ_oo6`001ooo
nfX00ooo02gooo]ZoookJP0@oookJP04od;o0?oonf[ooo]ZomX0o`Sooo]Z00?o013ooookJ_oonfX0
7_oonfX4o`0000_ooo]Z00?o/_l0oookJ_oonfX02?oonfX01?oo^03oo`14oookJ_nW0?l4oookJP03
omCo0?oo04Koon8000?ooo]Z00OoO_l0oookJ_m30?oooo]Zo`1Hoooonf[o:ol000;ooo]Z0_oo07l0
1?o/0?oooo]ZoookJ_oonfX2o`3o3`?oo`3J0_n8o`2moookJP00P_oonfX5ool001Cooo]Z0ooo:000
0on0o`3oobP0ool00008ool000Oooo]Z00Cod_l0oolX0?oo:03oobP01_oonfX01Ooo02gooo]Zoook
J_oonf[oobP000kooo]Z00Co@_l0oookJ_oonf[ofP3o1?oonfX7oolX01Kooo]Z1ooo0002oookJPCo
00002ooonfX00onbo`3ooo]ZoookJP07oookJP03oolX0?ooN@3oogT000CoogT00_oonfX01?oDo`3o
o`16oookJ_oohP03oomi0006ooo90?m30?oooo]ZoookJ_l0F?oooo]Z3_ooN@001?oo0=[oR?l0ohSo
0?oonfX3ool00?oooo]Z=_oonfX00oooW`3ooo]ZoookJP0JoookJP03oh3o0?oo077ooo]Z00?ooo]Z
00?o0>_ooookJ_oonfX02?oonfX01?oBo`3ooo]ZoookJ_oo6`06oookJP03ool0;Ooonf[ooo]Z017o
oo]Z00?o@_l0oookJ_oJ0?l02?oonfX00ol04?oooo]ZoookJP0OoookJPCo00002ooonfX00onbo`3o
oo]ZoookJP08oookJP04oonh0?oo04Cooo]ZojL0o`Cooo]Z00Coe?l0oookJ_oo04Koon800ooonfX0
1omno`3o@`3ooookJ_oonf[o05SooookJ_l[o`000_oonfX00ooo7P3oo`1oon`0o`04oookJP;o0?l?
00?ooo]Zool0f_oo0=X00_n8o`2koookJP00POoonfX00ooo003ooo]ZoookJP03ool001?ooo]Z1?oo
:0000on0o`3oobP0oolX0007ool000Sooo]Z00?od_l0oolX0?oo:0001_oonfX00ooo02gooo]Zoook
JP0@oookJP05od;o0?oonf[ooo]ZoookJ_oJ0?l00ooonfX8oolX01Gooo]Z2?oo0002oookJPCo0000
2ooonfX00onbo`3ooo]ZoookJP07oookJP05oolX0?ooN@3oogT0oookJ_nW0?l01OoonfX00ooDo`3o
o`16oooR0003oomi0003ogko0?oonf[o@`3o00;ooo]Z00?o05SooookJ_ooN@003_ooN@001?oo0=[o
R?l0ohSo0?oo003ooookJSKooo]Z00?ooil0oookJ_oonfX06ooonfX00on0o`3ooo]ZoookJP02oook
JP03o`3[oooonf[ooo]Z00Wooo]Z00?od_l0oookJ_oo6`001_oonfX00ooo02gooo]ZoookJP0Aoook
JP04od;o0?oonf[ooo]ZomX0o`Sooo]Z00?o013ooookJ_oonfX07ooonfX4o`0000_ooo]Z00?o/_l0
oookJ_oonfX02?oonfX01?oo^03oo`14oookJ_nW0?l5oookJP04omCo0?oo04Kooo]ZoooR00;ooo]Z
00?oO_l0oookJ_m30?l00_oonfX00ol0F?oooo]Zob_o0002oookJP03oolN0?oo07ook03o00Gooo]Z
00Go0?l?oookJ_oonf[ooo]Zool0fP03ohSo0;Sooo]Z0020oookJP03ool00?oonf[ooo]Z00;ooo]Z
00?oo`00oookJ_oonfX04ooonfX2oolX0003oh3o0?oo:03oobP000;oobP01_oo0006oookJP03oolX
0?oBo`3oobP000;oobP01OoonfX00ooo02gooo]ZoookJP0AoookJP04od;o0?oonf[ooo]ZomX0o`Ko
oo]Z1_oo:00DoookJPWoo`000_oonfX4o`0000_ooo]Z00?o/_l0oookJ_oonfX01ooonfX2oolX0003
ool0A?oonf[oY`3o00Gooo]Z00?oe?l0ool0A_oohP000_ooN@02oookJP07ogko0?oonf[oogT0oomi
0?oonf[o05SooookJP0@oomi0003ool0f_oo:03oobP000OoobP0oooonfX]oookJP03oonO0?oonf[o
oo]Z01_ooo]Z00?oP?l0ool0LOoonfX00_oonfX00ol0jooooo]ZoookJP09oookJP03om;o0?oonf[o
oa/000Oooo]Z00?oo`0]oookJ_oonfX04?oonfX01?m2o`3ooo]ZoookJ_oJ0?l8oookJP03o`0@oooo
nf[ooo]Z023ooo]Z1?l0000;oookJP03ok;o0?oonf[ooo]Z00Wooo]Z00?oo`14oookJ_nW0?l01Ooo
nfX01?oDo`3oo`16oookJ_oohP03oookJP03ogko0?oonf[o@`3o00;ooo]Z00?o05SooookJ_l[o`00
0_oonfX01?oo7P3oo`1oon`0ooo/0?l4oookJP03o`3o3ooonf[ooo]Z00?ooo]Z00?oo`3JohSo0?n8
o`000_n8o`2doookJP00OooonfX00ooo003ooo]ZoookJP0JoookJP03oh3o0?oo:03oobP000?oobP0
1Ooo0006oookJP03oolX0?oBo`3oobP000;oobP01OoonfX00ooo02gooo]ZoookJP0AoookJP04od;o
0?oonf[ooo]ZomX0o`Sooo]Z1Ooo:00GoookJPKoo`000_oonfX4o`0000_ooo]Z00?o/_l0oookJ_oo
nfX01ooonfX2oolX0004ool0A?oonf[ooo]ZojL0o`Cooo]Z00Coe?l0oookJ_oo04Koon800ooonfX0
0omno`3ooo]Zoomi0002oomi0003oookJ_l0F?oooo]Z017oogT000?oo`3JoolX0?oo:0003Ooo:005
oookJPGoo`00oooonfXJoookJP03oonO0?oonf[ooo]Z01_ooo]Z00?oP?l0ool0LOoonfX00_oonfX0
0ol0jooooo]ZoookJP09oookJP03om;o0?oonf[ooa/000Oooo]Z00?oo`0]oookJ_oonfX04?oonfX0
1?m2o`3ooo]ZoookJ_oJ0?l9oookJP03o`0@oooonf[ooo]Z023ooo]Z1?l0000;oookJP03ok;o0?oo
nf[ooo]Z00Wooo]Z00CookP0ool0A?oonf[oY`3o1OoonfX01?oDo`3oo`16oookJ_oohP03oookJP03
ogko0?oonf[o@`3o00;ooo]Z00?o05SooookJ_l[o`000ooonfX01?oo07oooah0on`0ooo/0?l3oook
JP;o0?l?1OoonfX3ool0fP?oR?l0/OoonfX009_ooo]Z00?oP?l0oolX0?oo:0000ooo:003oookJP?o
o`001OoonfX6oolX00Gooo]Z00?oo`0]oookJ_oonfX04?oonfX01Om2o`3ooo]ZoookJ_oonf[ofP3o
00Sooo]Z00Co013ooookJ_oo:03oobP04ooonfX5o`00O`Cooo]Z0_oo0002oookJPCo00002ooonfX0
0onbo`3ooo]ZoookJP07oookJP;oobP000Coo`14oookJ_oonf[oY`3o1OoonfX00ooDo`3oo`16oooR
0004oookJP03ogko0?oonf[oogT000;oogT000?ooo]Zo`1HooooN@004OooN@000ooonf[oobP0oolX
000<oolX00[oo`003ooonfX3ool00?oooo]Z9OoonfX00on0o`3oo`1aoookJP0>oookJP04om;o0?oo
nf[ooo]ZoolK00Kooo]Z00?oo`0]oookJ_oonfX04OoonfX01?m2o`3ooo]ZoookJ_oJ0?l8oookJP03
o`0@oooonf[ooo]Z01Cooo]Z1Ol007l8oookJPCo00002ooonfX00onbo`3ooo]ZoookJP09oookJP04
oonh0?oo04Cooo]ZojL0o`Gooo]Z00Coe?l0ool0A_oonf[oon801?oonfX00omno`3ooo]Zod<0o`02
oookJP03o`1Hoooonf[o:ol000?ooo]Z0_oo07l00ooo7P3ok03oon`0o`03oookJP;o0?l?1_oonfX3
ool0fP?oR?l0[_oonfX009[ooo]Z00CoP?l0oolX0?oonf[ooo]Z0ooo:004oookJP03ool00?oonf[o
oo]Z00;ooo]Z2?oo:004oookJP03ool0;Ooonf[ooo]Z017ooo]Z00Co@_l0oookJ_oonf[ofP3o2?oo
nfX01Ol04?oooo]ZoookJ_oonf[oobP001;ooo]Z1ol007l7oookJPCo00002ooonfX00onbo`3ooo]Z
oookJP07oookJP;oobP000Coo`14oolX0?oonf[oY`3o1OoonfX01?oDo`3ooo]Zool0A_ooN@04oook
JP03ogko0?ooN@3oogT000;oogT000?ooo]Zo`1HooooN@003oooN@04oookJP_oobP02ooo0005oolX
00Kooo]Z1ooo003ooookJRCooo]Z00?oP?l0ool0LOoonfX03ooonfX00ooBo`3ooo]ZoolK0007oook
JP03ool0;Ooonf[ooo]Z013ooo]Z00Co@_l0oookJ_oonf[ofP3o2OoonfX00ol04?oooo]ZoookJP0C
oookJPOo001o1ooonfX4o`0000_ooo]Z00?o/_l0oookJ_oonfX02OoonfX01?oo^03oo`14oookJ_nW
0?l6oookJP04omCo0?oo04Kooo]ZoooR00?ooo]Z00CoO_l0oookJ_oonf[o@`3o0_oonfX00ol0F?oo
oo]Zob_o0004oookJP04ool0Oooo7P3ooo]Zon`0o`Cooo]Z0_l0o`l8oookJP;oo`3J1on8o`2Woook
JP00V?oonfX2ool00003oookJ_oo077ooo]Z00;ooo]Z00?oobP0oookJ_oonfX01ooonfX8oolX00Co
oo]Z00?oo`0]oookJ_oonfX04OoonfX01Om2o`3ooo]ZoookJ_oonf[ofP3o00Oooo]Z00?o013ooook
J_oonfX05?oonfX4o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l0000;oookJP03ok;o0?oonf[o
oo]Z00Oooo]Z0_oo:0001?oo04CoobP0oookJ_nW0?l5oookJP04omCo0?oonf[oo`16oomi00Gooo]Z
00?oO_l0oomi0?ooN@000_ooN@000ooonf[oobP0oolX0005oomi0003ool0OoooN@3oogT000GoogT0
00?ooo]Zo`3o3ol0o`l01?oonfX9oolX00_oo`001Ooo:003oookJP[oo`00oooonfXSoookJP03oh3o
0?oonf[oo`1a00oooo]Z00?od_l0oookJ_oo6`001ooonfX00ooo02gooo]ZoookJP0@oookJP05od;o
0?oonf[ooo]ZoookJ_oJ0?l02?oonfX00ol04?oooo]ZoookJP0CoookJPCo001o00Cooo]Zo`00Ool0
07oo001o1ooonfX4o`0000_ooo]Z00?o/_l0oookJ_oonfX02OoonfX01?oo^03oo`14oookJ_nW0?l6
oookJP04omCo0?oo04Kooo]ZoooR00Cooo]Z00?oO_l0oookJ_m30?l00ooonfX01?l0F?oooo]Zob_o
0?l[o`03oookJP04ool0Oooo7P3ooo]Zon`0o`Gooo]Z0ol0o`l9oookJP?oo`3JZOoonfX009Oooo]Z
0ooo00000ooo077ooo]ZoookJP0;oookJPWoobP00_oonfX2ool001Cooo]Z00Co@_l0oookJ_oonf[o
fP3o2?oonfX00ol04?oooo]ZoookJP0DoookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0000;oookJP03
ok;o0?oonf[ooo]Z00Oooo]Z0ooo:0000ooo04CoobP0ojL0o`06oookJP04omCo0?oonf[oogT0oomi
00Gooo]Z1OooN@03oolX00GoogT00_oo07l8oomi00?o0?l?0_oonfX7oolX0003oookJ_oo003oo`00
00Woo`001Ooo:00=ool000cooo]Z0_oo003ooookJQGooo]Z00?oP?l0ool0LOoonfX03_oonfX00ooB
o`3ooo]ZoolK0007oookJP03ool0;Ooonf[ooo]Z017ooo]Z00Co@_l0oookJ_oonf[ofP3o2OoonfX0
0ol04?oooo]ZoookJP0CoookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0000;oookJP03ok;o0?oonf[o
oo]Z00Wooo]Z00GookP0oookJ_oo04Cooo]ZojL0o`05oookJP05omCo0?oonf[oo`16oookJ_oohP00
1?oonfX00omno`3ooo]Zod<0o`03oookJP04o`1Hoooonf[ooo]Zob_o00?ooo]Z0_oo07l00ooo7P3o
k03oon`0o`06oookJP;o0?l?2_oonfX;ool0fPOooo]Z1Ooo0=ZBoookJP00U_oonfX3ool00003ool0
LOoonf[ooo]Z00_ooo]Z2Ooo:002oookJP?oo`004ooonfX01?m2o`3ooo]ZoookJ_oJ0?l8oookJP03
ool00?oonf[ooo]Z01_ooo]Z0ol007l6oookJPKo00002OoonfX00onbo`3ooo]ZoookJP06oookJPCo
obP000Coo`14oolX0?oonf[oY`3o1OoonfX00ooDo`3ooo]Zool0AP02oomi00Cooo]Z1_ooN@04oolX
0003oookJ_ooN@3oogT000;oogT000?oo`1ooomi0?ooN@002?ooN@03o`3o3`03oookJ_oo:03oobP0
00?oobP00ooonfX8ool000KoobP03Ooo0009oookJPGoo`00oooonfXDoookJP03oh3o0?oo077ooo]Z
00kooo]Z00Cod_l0oookJ_oonf[ooa/01ooonfX00ooo02gooo]ZoookJP0@oookJP04od;o0?oonf[o
oo]ZomX0o`Wooo]Z00?o013ooookJ_oonfX06_oonfX3o`00O`Kooo]Z1_l00009oookJP03ok;o0?oo
nf[ooo]Z00Wooo]Z00GookP0oookJ_oo04Cooo]ZojL0o`06oookJP04omCo0?oo04Kooo]ZoooR00Co
oo]Z00CoO_l0oookJ_oonf[o@`3o0ooonfX01?l0F?oooo]ZoookJ_l[o`04oookJP03ool0Oooo7P3o
oo]Z00?ok03o1OoonfX3o`3o3a;ooo]Z1ooo0=ZGoookJP00U?oonfX5ool000gooo]Z2_oo:0001?oo
nf[oo`00ool00?oo000CoookJP05od;o0?oonf[ooo]ZoookJ_oJ0?l02?oonfX00ooo003ooo]Zoook
JP0KoookJP?o001o1_oonfX4o`0000[ooo]Z00?o/_l0oookJ_oonfX01ooonfX7oolX0003ojL0oooo
nf[ooo]Z00Cooo]Z00?oe?l0oookJ_ooN@000_ooN@04oookJPKoogT01Ooo:004oomi0003ool0Oooo
N@3oogT000SoogT00_oonfX3o`3o3`?oobP01OoonfX6ool000GoobP00_oonfX<ool000Kooo]Z2?oo
003ooookJQ?ooo]Z00?oP?l0ool0LOoonfX03ooonfX00ooBo`3ooo]ZoolK0007oookJP03ool0;Ooo
nf[ooo]Z017ooo]Z00Co@_l0oookJ_oonf[ofP3o2OoonfX00ol04?oooo]ZoookJP0JoookJP?o001o
1_oonfX4o`0000_ooo]Z00?o/_l0oookJ_oonfX02OoonfX01Ooo^03ooo]Zool0A?oonf[oY`3o00Ko
oo]Z00Goe?l0oookJ_oo04Kooo]ZoooR0004oookJP04ogko0?oonf[ooo]Zod<0o`?ooo]Z00Co05So
oookJ_oonf[o:ol01?oonfX00ooo07oooah0oookJP02oookJP;ok03o1_oonfX4o`3o3jcooo]Z002C
oookJPGoo`003OoonfX:oolX0003oookJ_oo003oo`0000;oo`004ooonfX01?m2o`3ooo]ZoookJ_oJ
0?l8oookJP;oo`006?oonfX2o`00O`;ooo]Z1?l007l6oookJPCo00002_oonfX00onbo`3ooo]Zoook
JP07oookJPOoobP000?oY`3ooookJ_oonfX01?oonfX00ooDo`3ooo]Zoomi0003oomi00?ooo]Z1_oo
N@06oolX00CoogT00_oo07l8oomi00Kooo]Z00?oobP0o`3o3ol0o`l00ol0o`l4oookJP?oo`001Ooo
:005oookJP;oobP01ooo0003oookJP_oo`00oooonfXBoookJP03oh3o0?oo077ooo]Z00oooo]Z00?o
d_l0oookJ_oo6`001ooonfX00ooo02gooo]ZoookJP0AoookJP04od;o0?oonf[ooo]ZomX0o`Wooo]Z
00?o013ooookJ_oonfX05_oonfX2o`00O`;ooo]Z1?l007l6oookJPCo00002ooonfX00onbo`3ooo]Z
oookJP09oookJP03oonh0?oonf[oo`1400;ooo]Z00?oY`3ooookJ_oonfX00ooonfX01OoDo`3ooo]Z
ool0A_oonf[oon8000Gooo]Z00?oO_l0oookJ_m30?l01?oonfX01?l0F?oooo]ZoookJ_l[o`04oook
JP;oo`1o00Cooah0oookJ_oonf[ooo]Z0_o/0?l8oookJPKo0?l?Y_oonfX009;ooo]Z1_oo000<oook
JP_oobP01?oo000CoookJP04od;o0?oonf[ooo]ZomX0o`Sooo]Z0_oo000IoookJPOo001o1ooonfX4
o`0000[ooo]Z00?o/_l0oookJ_oonfX01ooonfX7oolX0003ojL0oooonf[ooo]Z00Gooo]Z00?oe?l0
oomi0?ooN@000oooN@03oookJPKoogT01ooo:004oomi00;oo`1o1OooN@000oo/0?oooo]ZoookJP0:
oookJPKo0?l?00?oo`00oookJ_oo:0003ooo:00@ool00?oooo]Z4OoonfX00on0o`3oo`1aoookJP0?
oookJP03om;o0?oonf[ooa/000Oooo]Z00?oo`0]oookJ_oonfX04OoonfX01?m2o`3ooo]ZoookJ_oJ
0?l9oookJP03o`0@oooonf[ooo]Z01Oooo]Z1ol007l7oookJPCo00002ooonfX00onbo`3ooo]Zoook
JP09oookJP03oonh0?oonf[oo`1400;ooo]Z00?oY`3ooookJ_oonfX01?oonfX01OoDo`3ooo]Zool0
A_oonf[oon8000Gooo]Z00?oO_l0oookJ_m30?l01?oonfX01?l0F?oooo]ZoookJ_l[o`05oookJP?o
o`1o0ooonfX2on`0o`cooo]Z1ol0o`nOoookJP00T?oonfX8ool000_ooo]Z2?oo:0000ooonf[oobP0
ool00005ool001;ooo]Z00Go@_l0oookJ_oonf[ooo]ZomX0o`07oookJP?oo`006OoonfX6o`00O`So
oo]Z1?l0000:oookJP03ok;o0?oonf[ooo]Z00Oooo]Z1ooo:0000onW0?oooo]ZoookJP05oookJP03
omCo0?oonf[oogT000CoogT00_oonfX6oomi00WoobP00_ooN@001?oonf[oogT0ool0Oooo07l3oomi
0003oookJ_o/0?ook03o017ooo]Z0_l0o`l@oolX013oo`00oooonfX@oookJP03oh3o0?oonf[ooo]Z
00oooo]Z00?od_l0oookJ_oo6`001ooonfX00ooo02gooo]ZoookJP0AoookJP04od;o0?oonf[ooo]Z
omX0o`Wooo]Z00?o013ooookJ_oonfX05ooonfX6o`00O`Sooo]Z1?l0000;oookJP03ok;o0?oonf[o
oo]Z00[ooo]Z00GookP0ool0A?oonf[ooo]ZojL0o`06oookJP05omCo0?oonf[oo`16oookJ_oohP00
1OoonfX01?mno`3ooo]ZoookJ_m30?l4oookJP03o`1Hoooonf[ooo]Z00;o:ol01_oonfX2ool0O`?o
oo]Z0_o/0?lAoookJPOo0?l?1ooonfX>o`3o3h?ooo]Z002?oookJPSoo`002ooonfX8oolX00;ooo]Z
1ooo000BoookJP04od;o0?oonf[ooo]ZomX0o`Oooo]Z1?oo000IoookJP;o001o3?oonfX4o`0000[o
oo]Z00?o/_l0oookJ_oonfX01ooonfX8oolX0003ojL0oooonf[ooo]Z00Cooo]Z00?oe?l0oookJ_oo
N@001OooN@02oookJPKoogT02Ooo:002oomi0003oookJ_ooN@3oogT000;oo`1o00Gooah0oookJ_oo
nf[ooo]Zon`0o`0DoookJPkoobP01?oonfX<ool00?oooo]Z3ooonfX00on0o`3ooo]ZoookJP0?oook
JP03om;o0?oonf[ooa/000Oooo]Z00?oo`0]oookJ_oonfX04OoonfX01?m2o`3ooo]ZoookJ_oJ0?l9
oookJP03o`0@oooonf[ooo]Z01Sooo]Z0_l007l<oookJPCo00002ooonfX00onbo`3ooo]ZoookJP0:
oookJP03oonh0?oo04Cooo]Z00;ooo]Z00?oY`3ooookJ_oonfX00ooonfX01OoDo`3ooo]ZoookJ_oo
04Koon8000Kooo]Z00CoO_l0oookJ_oonf[o@`3o1?oonfX01?l0F?oooo]ZoookJ_oonfX2ob_o00Ko
oo]Z00?oo`1ooolN0?oonfX00_oonfX2on`0oaKooo]Z1ol0o`nAoookJP00S_oonfX9ool000[ooo]Z
2Ooo:0000ooonf[oo`00ool00005ool001;ooo]Z00Go@_l0oookJ_oonf[ooo]ZomX0o`06oookJPCo
o`006_oonfX2o`00O`cooo]Z1?l0000:oookJP03ok;o0?oonf[ooo]Z00Oooo]Z1ooo:0000ooonf[o
Y`3ooookJP06oookJP03oolX0?ooN@3oogT000GoogT000?ooo]Zoomi0?ooN@000oooN@02oookJPWo
obP01_ooN@000ooo07oooah0oookJP02oookJP?ok03o5?oonfX:oolX00[ooo]Z1ooo0009oookJP;o
o`00oooonfX3oookJP03oh3o0?oo077ooo]Z00oooo]Z00?od_l0oookJ_oo6`001ooonfX00ooo02go
oo]ZoookJP0BoookJP04od;o0?oonf[ooo]ZomX0o`Sooo]Z00?o013ooookJ_oonfX06OoonfX2o`00
O`cooo]Z1?l0000;oookJP03ok;o0?oonf[ooo]Z00[ooo]Z00?ookP0ool0A?oonfX00_oonfX00onW
0?oooo]ZoookJP04oookJP05omCo0?oonf[oo`16oookJ_oohP001_oonfX00omno`3ooo]Zod<0o`05
oookJP03o`1Hoooonf[ooo]Z00;ooo]Z00?o:ol0oookJ_oonfX01?oonfX00ooo07oooah0oookJP03
oookJP?ok03oZooonfX008gooo]Z2Ooo000=oookJPKoobP000?ooo]Zool00?oo00001_oo000Aoook
JP05od;o0?oonf[ooo]ZoookJ_oJ0?l01_oonfX5ool001_ooo]Z1ol007l6oookJPCo00002OoonfX0
0onbo`3ooo]ZoookJP08oookJP;oobP00_oo0003oolX0003oookJ_nW0?oooo]Z00Kooo]Z00?oobP0
oookJ_ooN@002OooN@001?oo:03o@`3ooookJ_oonfX8oolX00KoogT00_oonfX2ool0O`03oolN0?oo
nf[ooo]Z00;ooo]Z0oo/0?lDoookJPOoobP03ooonfX2ool000Kooo]Z1Ooo003ooookJP;ooo]Z00?o
P?l0ool0LOoonfX03ooonfX00ooBo`3ooo]ZoolK0007oookJP03ool0;Ooonf[ooo]Z01;ooo]Z00Co
@_l0oookJ_oonf[ofP3o2?oonfX00ol04?oooo]ZoookJP0KoookJPOo001o1_oonfX4o`0000[ooo]Z
00?o/_l0oookJ_oonfX03?oonfX01Ooo04Cooo]ZoookJ_oonf[oY`3o00Kooo]Z00Goe?l0oookJ_oo
nf[oo`16oooR0007oookJP03ogko0?oonf[o@`3o00Gooo]Z00?o05SooookJ_oonfX00_oonfX00ol[
o`3ooo]ZoookJP04oookJP?oo`1o00?ooah0oookJ_oonfX00_oonfX3on`0ojSooo]Z002?oookJPOo
o`003_oonfX5oolX00Soo`004_oonfX01?m2o`3ooo]ZoookJ_oo:006oookJPKoo`006ooonfX7o`00
O`Kooo]Z1?l00009oookJP03ok;o0?oonf[ooo]Z00[ooo]Z0_oo0004oolX0003ojL0oooonf[ooo]Z
00Gooo]Z0_oo:009oomi00?oobP000?o@`3ooookJ_oonfX01_oo:002ool000KoogT00ooonfX3ool0
O`03oolN0?oonf[ooo]Z00;ooo]Z1Oo/0?lBoookJPCoobP01ooonfX3oolX00[ooo]Z2?oo003ooook
JP7ooo]Z00?oP?l0ool0LOoonfX04?oonfX00ooBo`3ooo]ZoolK0006oookJP03ool0;Ooonf[ooo]Z
01;ooo]Z00Co@_l0oookJ_oonf[ofP3o2OoonfX00ol04?oooo]ZoookJP0KoookJPOo001o1_oonfX4
o`0000[ooo]Z00?o/_l0oookJ_oonfX03?oonfX01Ooo04Cooo]ZoookJ_oonf[oY`3o00Oooo]Z00Go
e?l0oookJ_oo04Kooo]ZoooR0006oookJP04ogko0?oonf[ooo]Zod<0o`Gooo]Z00?o05SooookJ_oo
nfX00_oonfX00ol[o`3ooo]ZoookJP06oookJP?oo`1o00?ooah0oookJ_oonfX00_oonfX4on`0ojCo
oo]Z002@oookJPGoo`003ooonfX01?oo:03ooo]ZoolX0?oo:009ool0017ooo]Z00?o@_l0oookJ_oo
nfX00_oo:005oookJPOoo`00:?oonfX4o`0000Wooo]Z00?o/_l0oookJ_oonfX02_oonfX2ool000Co
obP000?oY`3ooookJ_oonfX01OoonfX3oolX00SoogT000Kooo]ZoolX0?oo:03oobP0od<0oooonfX5
oolX00Goo`001?ooN@06oookJPGoobP01OoonfX7on`0o`kooo]Z00?oobP0oookJ_oonfX02?oo:007
oookJP_oo`00oooonfX00on0o`3oo`1aoookJP0@oookJP03om;o0?oonf[ooa/000Oooo]Z00?oo`0]
oookJ_oonfX04_oonfX01?m2o`3ooo]ZoookJ_oJ0?l8oookJP03o`0@oooonf[ooo]Z02Wooo]Z1?l0
000:oookJP03ok;o0?oonf[ooo]Z00cooo]Z00Goo`14oookJ_oonf[ooo]ZojL0o`07oookJP05omCo
0?oonf[oo`16oookJ_oohP001ooonfX01?mno`3ooo]ZoookJ_m30?l:oookJP03ob_o0?oonf[ooo]Z
00Sooo]Z0_oo07l2oolN00Gooo]Z1oo/0?nMoookJP00T?oonfX5ool000kooo]Z00GoobP0oookJ_oo
6`3ooo]ZoolX0002oookJPKoo`004OoonfX00ooo:03ooo]ZoookJP02oolX00Gooo]Z1ooo000Yoook
JPCo00002OoonfX00onbo`3ooo]ZoookJP0:oookJP03ool00?oo:03oobP000?oobP000?oY`3ooook
J_oonfX01OoonfX4oolX00GoogT00ooonfX4oolX0003od<0oooonf[oobP000;oobP02?oo00000ooo
N@3ooo]ZoookJP07oookJP_oobP01?oonfX7on`0o`Gooo]Z3Ooo:004oookJPkoo`00oooonfX00on0
o`3ooo]ZoookJP0?oookJP03om;o0?oonf[ooa/000Oooo]Z00?oo`0]oookJ_oonfX04_oonfX01?m2
o`3ooo]ZoookJ_oJ0?l8oookJP03o`0@oooonf[ooo]Z02[ooo]Z1?l0000:oookJP03ok;o0?oonf[o
oo]Z00cooo]Z00Goo`14oookJ_oonf[ooo]ZojL0o`07oookJP06omCo0?oonf[ooo]Zool0A_oonf[o
on801ooonfX00omno`3ooo]Zod<0o`0;oookJP03ob_o0?oonf[ooo]Z00Wooo]Z0_oo07l3oolN00Wo
oo]Z1oo/0?lJoookJPKok03oM_oonfX0093ooo]Z00?oo`00oookJ_oo00000_oo000>oookJP03om;o
0?oo6`3ooo]Z00Gooo]Z1Ooo000@oookJP;oobP000Cooo]ZoolX0?oo:03oobP01?oonfX8ool002Wo
oo]Z1?l00009oookJP03ok;o0?oonf[ooo]Z00[ooo]Z00?oo`00oolX0?oo:0001?oo:0000onW0?oo
oo]ZoookJP05oookJP?oobP00_ooN@000ooohP3ooo]ZoookJP04oookJPCoobP000Co@`3ooookJ_oo
:03ooo]Z2_oo0009oookJPkoobP01ooonfX2on`0oa3oobP00_o/0?l@ool00?kooo]Z00?oP?l0oook
J_oonfX04?oonfX00ooBo`3ooa/0oookJP06oookJP03ool0;Ooonf[ooo]Z01?ooo]Z00?o@_l0oook
J_oJ0?l0=_oonfX4o`0000[ooo]Z00?o/_l0oookJ_oonfX03OoonfX01Ooo04Cooo]ZoookJ_oonf[o
Y`3o00Oooo]Z00Goe?l0oookJ_oo04Kooo]ZoooR0008oookJP03ogko0?oonf[o@`3o00_ooo]Z0_l[
o`0;oookJP03ool0Oooonf[ooo]Z00?ooah03OoonfX8on`0o`Sooo]Z2_o/0?mloookJP00S_oonfX2
ool000?ooo]Z00?oo`00oookJ_oonfX03?oonfX00ooBo`3ooo]ZoolK0005oookJP03ool00?oonf[o
oo]Z00?oo`003ooonfX2oolX0003oookJ_oo:03oobP000;oobP01_oonfX6ool002Wooo]Z1?l00009
oookJP03ok;o0?oonf[ooo]Z00[ooo]Z00?oo`00oolX0?oo:0001?oo:0000onW0?oooo]ZoookJP05
oookJPKoobP000?oon80oookJ_oonfX00ooonfX5oolX0004od<0oooonf[ooo]ZoookJP[oo`002_oo
nfX<oolX00cooo]Z3Ooo:007oookJP_oo`00oOoonfX00on0o`3ooo]ZoookJP0@oookJP03om;o0?oo
nf[ooa/000Kooo]Z00?oo`0]oookJ_oonfX04ooonfX01?m2o`3ooo]ZoookJ_oJ0?lfoookJPCo0000
2_oonfX00onbo`3ooo]ZoookJP0=oookJP05ool0A?oonf[ooo]ZoookJ_nW0?l01ooonfX01_oDo`3o
oo]ZoookJ_oo04Kooo]ZoooR00Oooo]Z00CoO_l0oookJ_oonf[o@`3o3?oonfX2ob_o00[ooo]Z0ooo
07l2oookJP?ooah04_oonfX8on`0ohKooo]Z002=oookJP?oo`004OoonfX00ooBo`3ooo]ZoolK000:
oookJP03ool00?oonf[ooo]Z00gooo]Z1ooo:009oookJP?oo`00:_oonfX4o`0000Wooo]Z00?o/_l0
oookJ_oonfX02OoonfX2ool000OoobP01ooonfX6oolX0003oooR0?oonf[ooo]Z00?ooo]Z1_oo:000
0om30?oooo]ZoookJP0:ool00003ob_o0?oonf[ooo]Z00Sooo]Z6?oo:002oookJP[oobP00ooo000;
oookJPCoo`00o?oonfX00on0o`3oo`1aoookJP0@oookJP03om;o0?oonf[ooa/001cooo]Z00Co@_l0
oookJ_oonf[ofP3o=ooonfX4o`0000[ooo]Z00?o/_l0oookJ_oonfX03OoonfX01Ooo04Cooo]Zoook
J_oonf[oY`3o00Sooo]Z00Koe?l0oookJ_oonf[oo`16oookJ_oohP07oookJP04ogko0?oonf[ooo]Z
od<0o`gooo]Z00?o:ol0oookJ_oonfX02_oonfX3ool0O`;ooo]Z0ooo7P2MoookJP00S?oonfX3ool0
017ooo]Z00?od_l0oookJ_oo6`006_oonfX8oolX00_ooo]Z00?oo`00oookJ_oonfX0:?oonfX5o`00
00Sooo]Z00?o/_l0oookJ_oonfX02OoonfX2ool000OoobP01ooonfX6oolX0003oooR0?oo:03ooo]Z
00Cooo]Z1_oo:0000om30?oooo]ZoookJP08ool000;ooo]Z0_l[o`0:oookJPSoobP03Ooo00000ooo
:03ooo]ZoookJP03oookJPOoobP00ooo003ooookJP_ooo]Z00?oP?l0ool0LOoonfX04?oonfX00ooB
o`3ooo]ZoolK000MoookJP04od;o0?oonf[ooo]ZomX0ocOooo]Z1Ol00009oookJP03ok;o0?oonf[o
oo]Z00gooo]Z00Goo`14oookJ_oonf[ooo]ZojL0o`08oookJP06omCo0?oonf[ooo]Zool0A_oonf[o
on802?oonfX01?mno`3ooo]ZoookJ_m30?l=oookJP;o:ol03OoonfX6ool0O`;ooah0V_oonfX008_o
oo]Z1?oo000AoookJP03om;o0?oonf[ooa/001Wooo]Z2Ooo:00foookJPCo00002?oonfX00onbo`3o
oo]ZoookJP0:oookJP;oo`002?oo:006oookJPOoobP000?oon80oolX0?oonfX00ooonfX7oolX0003
od<0oooonf[ooo]Z00Koo`001OoonfX2ob_o00Wooo]Z1_oo:00>ool00003oolX0?oonf[ooo]Z00Ko
o`001?oo:003ool00?oooo]Z2ooonfX00ooo077ooo]ZoookJP0@oookJP03om;o0?oonf[ooa/001co
oo]Z00Co@_l0oookJ_oonf[ofP3o>?oonfX4o`0000Wooo]Z00?o/_l0oookJ_oonfX03_oonfX01Ooo
04Cooo]ZoookJ_oonf[oY`3o00Sooo]Z00Ooe?l0oookJ_oonf[ooo]Zool0A_oonf[oon8000Sooo]Z
00CoO_l0oookJ_oonf[o@`3o3_oonfX2ob_o017ooo]Z0ooo07l5oolN09Cooo]Z002:oookJPGoo`00
4?oonfX00ooBo`3ooo]ZoolK000IoookJPWoobP0=ooonfX4o`0000Sooo]Z00?o/_l0oookJ_oonfX0
2_oonfX2ool000SoobP01_oonfX7oolX0003oooR0?oo:03ooo]Z00Cooo]Z1ooo:0000om30?oooo]Z
ool00004ool000Sooo]Z0_l[o`08oookJPGoobP000?ooo]Zool00?oo00002ooo00000ooo:03oo`00
ool00009ool00004oolX0?oo003oo`00ool00?oooo]Z2_oonfX00ooo077ooo]ZoookJP0@oookJP03
om;o0?oonf[ooa/001cooo]Z00Co@_l0oookJ_oonf[ofP3o>OoonfX4o`0000Wooo]Z00?o/_l0oook
J_oonfX03_oonfX01Ooo04Cooo]ZoookJ_oonf[oY`3o00Wooo]Z00Koe?l0oookJ_oonf[oo`16oook
J_oohP08oookJP05ogko0?oonf[ooo]ZoookJ_m30?l03ooonfX00ol[o`3ooo]ZoookJP0FoookJPgo
oah0QooonfX008Sooo]Z1_oo000@oookJP03om;o0?oonf[ooa/001Wooo]Z2_oo:00goookJPCo0000
2?oonfX00onbo`3ooo]ZoookJP0<oookJPCoobP000?oo`00oookJ_oo:0000_oo:005oookJPSoobP0
00?oon80oolX0?oonfX00ooonfX8oolX0003od<0oooonf[oo`0000;oo`002ooonfX2ob_o00Sooo]Z
0ooo:003oookJP[oo`0000?oobP0oookJ_oonfX03_oo003ooookJPWooo]Z00?oo`1aoookJ_oonfX0
4?oonfX00ooBo`3ooo]ZoolK000LoookJP05od;o0?oonf[ooo]ZoookJ_oJ0?l0>OoonfX4o`0000Wo
oo]Z00?o/_l0oookJ_oonfX03ooonfX01Ooo04Cooo]ZoookJ_oonf[oY`3o00Sooo]Z00Ooe?l0oook
J_oonf[ooo]Zool0A_oonf[oon8000Sooo]Z00GoO_l0oookJ_oonf[ooo]Zod<0o`0?oookJP;o:ol0
Z_oonfX008Oooo]Z1ooo000?oookJP03om;o0?oo003oo`0001Wooo]Z2ooo:00goookJPCo00002?oo
nfX00ooo:03ooo]ZoookJP0>oookJPCoo`000ooo:006oookJPSoobP000?oon80oolX0?oonfX00ooo
nfX6oolX0005ool00?oonf[o@`3ooookJ_oo00003_oonfX2ob_o00Oooo]Z00?oobP0oookJ_oonfX0
1?oonfX8ool00003oolX0?oonf[ooo]Z00?ooo]Z2_oo003ooookJP[ooo]Z00?oo`1aoookJ_oonfX0
3ooonfX00ooBo`3ooo]ZoolK000MoookJP04od;o0?oonf[ooo]ZomX0oc[ooo]Z1?l00009oookJP03
ok;o0?oonf[ooo]Z00oooo]Z00Goo`14oookJ_oonf[ooo]ZojL0o`09oookJP06omCo0?oonf[ooo]Z
ool0A_oonf[oon802OoonfX01Omno`3ooo]ZoookJ_oonf[o@`3o013ooo]Z0_l[o`2XoookJP00Q_oo
nfX7ool0013ooo]Z00?od_l0ool00?oo00006?oonfX;oolX03Sooo]Z1?l00008oookJP03oolX0?oo
nf[ooo]Z00kooo]Z1?oo0003oolX00Kooo]Z2?oo:0000ooohP3ooo]ZoookJP03oookJPGoobP00ooo
00000ooonf[o@`3ooookJP0@oookJP03ob_o0?oonf[ooo]Z00gooo]Z1_oo00000ooo:03ooo]Zoook
JP06oookJPOoo`00oooonfX9oookJP03ool0LOoonf[ooo]Z013ooo]Z00?od_l0oookJ_oo6`007?oo
nfX01Om2o`3ooo]ZoookJ_oonf[ofP3o03[ooo]Z1?l00009oookJP03ok;o0?oonf[ooo]Z00oooo]Z
00Goo`14oookJ_oonf[ooo]ZojL0o`09oookJP06omCo0?oonf[ooo]Zool0A_oonf[oon802_oonfX0
1Omno`3ooo]ZoookJ_oonf[o@`3o017ooo]Z0_l[o`2VoookJP00QOoonfX8ool000oooo]Z00?od_l0
ool00?oo00006?oonfX<oolX03Sooo]Z1?l00007oookJP;oobP04?oonfX4ool000CoobP01OoonfX3
oolX00Goo`0000?ooo]ZoooR0?oonfX00ooonfX3oolX0003oookJ_oo003oo`0000Coo`0000?o@`3o
oookJ_oonfX03ooonfX3ob_o00kooo]Z0ooo00000ooonf[oobP0oookJP0:oookJPCoo`00oooonfX8
oookJP03ool0LOoonf[ooo]Z013ooo]Z00?od_l0oookJ_oo6`007?oonfX01Om2o`3ooo]ZoookJ_oo
nf[ofP3o03_ooo]Z1?l00009oookJP03ok;o0?oonf[ooo]Z00oooo]Z00Goo`14oookJ_oonf[ooo]Z
ojL0o`09oookJP07omCo0?oonf[ooo]ZoookJ_oo04Kooo]ZoooR000:oookJP05ogko0?oonf[ooo]Z
oookJ_m30?l04_oonfX3ob_o0:?ooo]Z0024oookJPWoo`003_oonfX01?oBo`3oo`00ool00?oo000G
oookJPgoobP0>?oonfX4o`0000Oooo]Z0_oo:00?oookJPCoo`001Ooo:005oookJP03oolX0?oonf[o
o`0000Koo`0000?oon80oookJ_oonfX00ooonfX00ooo:03ooo]ZoookJP07ool00003od<0oooonf[o
oo]Z017ooo]Z0ol[o`0=oookJP03ool00?oonf[ooo]Z00kooo]Z00?oo`00oookJ_oonfX0oooonfX5
oookJP03ool0LOoonf[ooo]Z013ooo]Z00?od_l0oookJ_oo6`007OoonfX01?m2o`3ooo]ZoookJ_oJ
0?lloookJPCo00002?oonfX00onbo`3ooo]ZoookJP0DoookJP03ojL0oooonf[ooo]Z00Sooo]Z00Ko
e?l0oookJ_oonf[oo`16oookJ_oohP0?oookJP03od<0oooonf[ooo]Z01;ooo]Z0ol[o`2PoookJP00
PooonfX9ool000kooo]Z00Cod_l0ool00?oo003oo`006_oonfX6oolX0004omX0oooonf[oobP0oolX
03Wooo]Z1?l00006oookJP?oobP03ooonfX4ool000KoobP01_oonfX8ool00003oooR0?oonf[ooo]Z
00Kooo]Z1ooo00000om30?oooo]ZoookJP0CoookJP?o:ol0oooonfXSoookJP03ool0LOoonf[ooo]Z
00oooo]Z00Cod_l0oookJ_oonf[ooa/07?oonfX01Om2o`3ooo]ZoookJ_oonf[ofP3o03cooo]Z1?l0
0008oookJP03ok;o0?oonf[ooo]Z01Cooo]Z00?oY`3ooookJ_oonfX02?oonfX00ooDo`3ooo]Zoook
JP03oookJP03oooR0?oonf[ooo]Z00gooo]Z00?o@`3ooookJ_oonfX05?oonfX2ob_o09kooo]Z0025
oookJPOoo`003?oonfX2ool00004om;o0?oo003oo`00ool001_ooo]Z1Ooo:003oookJP03oolX0?oo
nf[ooo]Z03Oooo]Z1?l00006oookJPCoobP03_oonfX4ool000KoobP01_oonfX8ool00003oooR0?oo
nf[ooo]Z00Kooo]Z2?oo00000om30?oooo]ZoookJP0EoookJP;o:ol0oooonfXPoookJP03ool0LOoo
nf[ooo]Z013ooo]Z00?od_l0oookJ_oo6`007?oonfX01Om2o`3ooo]ZoookJ_oonf[ofP3o03gooo]Z
1?l00008oookJP03ok;o0?oonf[ooo]Z01Gooo]Z00?oY`3ooookJ_oonfX03OoonfX00ooohP3ooo]Z
oookJP0>oookJP03od<0oooonf[ooo]Z01Gooo]Z0ol[o`2KoookJP00Q_oonfX5ool000cooo]Z0_oo
00000ooBo`3oo`00ool00002ool001_ooo]Z00Co@_l0oookJ_oo:03oobP0?_oonfX4o`0000Kooo]Z
1?oo:00>oookJPCoo`001ooo:005oookJPWoo`0000?oon80oookJ_oonfX01OoonfX9ool00003od<0
oooonf[ooo]Z01Kooo]Z0_l[o`3ooookJQgooo]Z00?oo`1aoookJ_oonfX04?oonfX00ooBo`3ooo]Z
oolK000MoookJP04od;o0?oonf[ooo]ZomX0ockooo]Z1?l00008oookJP03ok;o0?oonf[ooo]Z01Go
oo]Z00?oY`3ooookJ_oonfX03_oonfX00ooohP3ooo]ZoookJP0>oookJP03od<0oooonf[ooo]Z01Oo
oo]Z0_l[o`2IoookJP00QOoonfX00ooo003ooo]Zool00003ool000_ooo]Z0_oo00000ooBo`3oo`00
ool00002ool001_ooo]Z00Go@_l0oookJ_oonf[ooo]ZoolX000noookJPCo00001OoonfX5oolX00ko
oo]Z1?oo0007oolX00Kooo]Z2?oo00000ooohP3ooo]ZoookJP06oookJPWoo`000_oo:00HoookJPWo
obP0oooonfXCoookJP03ool0LOoonf[ooo]Z013ooo]Z00?od_l0oookJ_oo6`007OoonfX01Om2o`3o
oo]ZoookJ_oonf[ofP3o03kooo]Z1?l00007oookJP03ok;o0?oonf[ooo]Z01Kooo]Z00?oY`3ooook
J_oonfX03_oonfX00ooohP3ooo]ZoookJP0?oookJP03od<0oooonf[ooo]Z01Sooo]Z0ol[o`2Foook
JP00Q?oonfX01?oo003ooo]ZoookJ_oonfX3ool000[ooo]Z2?oo000JoookJP05od;o0?oonf[ooo]Z
oookJ_oJ0?l0?ooonfX4o`0000Gooo]Z1Ooo:00=oookJPGoo`001ooo:006oookJPWoo`0000?oon80
oookJ_oonfX01OoonfX7ool000;ooo]Z0ooo:00IoookJPooobP0oooonfX:oookJP03ool0LOoonf[o
oo]Z013ooo]Z00Cod_l0oookJ_oonf[ooa/07?oonfX01Om2o`3ooo]ZoookJ_oonf[ofP3o03oooo]Z
1?l00007oookJP03ok;o0?oonf[ooo]Z01Kooo]Z00?oY`3ooookJ_oonfX03ooonfX00ooohP3ooo]Z
oookJP0?oookJP03od<0oooonf[ooo]Z01[ooo]Z0ol[o`2CoookJP00Q?oonfX00ooo003ooo]Zoook
JP02oookJP03ool00?oonf[ooo]Z00Sooo]Z2?oo000KoookJP05od;o0?oonf[ooo]ZoookJ_oJ0?l0
?ooonfX4o`0000Cooo]Z1_oo:00=oookJPGoo`002?oo:005oookJPWoo`0000?oon80oookJ_oonfX0
1_oonfX5ool000Cooo]Z1?oo:00IoookJPgoobP0oooonfX:oookJP03ool0LOoonf[ooo]Z013ooo]Z
00?od_l0oookJ_oo6`007OoonfX01Om2o`3ooo]ZoookJ_oonf[ofP3o03oooo]Z1?l00007oookJP03
ok;o0?oonf[ooo]Z01Kooo]Z00?oY`3ooookJ_oonfX03ooonfX00ooohP3ooo]ZoookJP0@oookJP03
od<0oooonf[ooo]Z01cooo]Z1?l[o`2?oookJP00PooonfX00ooo003ooo]ZoookJP0=oookJPWoo`00
6_oonfX01Om2o`3ooo]ZoookJ_oonf[ofP3o043ooo]Z1Ol00003oookJPKoobP03OoonfX5ool000Co
obP000?oo`00oookJ_oonfX01_oonfX:ool00003oooR0?oonf[ooo]Z00Gooo]Z1?oo0005oookJPKo
obP06?oonfX<oolX00Oooo]Z2Ooo003hoookJP03ool0LOoonf[ooo]Z013ooo]Z00?od_l0oookJ_oo
6`007OoonfX01Om2o`3ooo]ZoookJ_oonf[ofP3o043ooo]Z1Ol00006oookJP03ok;o0?oonf[ooo]Z
01Kooo]Z00?oY`3ooookJ_oonfX04?oonfX00ooohP3ooo]ZoookJP0@oookJP03od<0oooonf[ooo]Z
01oooo]Z1Ol[o`2:oookJP00P_oonfX00ooo003ooo]ZoookJP0>oookJPSoo`006ooonfX01?m2o`3o
oo]ZoookJ_oJ0?m1oookJPCo00000ooonfX7oolX01Gooo]Z0_oo0008oookJPWoo`0000?ooo]ZoooR
0?oonfX01_oonfX3ool000Oooo]Z1_oo:00IoookJPWoobP04Ooo003goookJP03ool0LOoonf[ooo]Z
013ooo]Z00Cod_l0oookJ_oonf[ooa/07OoonfX01?m2o`3ooo]ZoookJ_oJ0?m1oookJPCo00001ooo
nfX00onbo`3ooo]ZoookJP0FoookJP03ojL0oooonf[ooo]Z013ooo]Z00?oon80oookJ_oonfX04Ooo
nfX00om30?oooo]ZoookJP0SoookJPCo:ol0Q_oonfX0087ooo]Z00?oo`00oookJ_oonfX03_oonfX9
ool001[ooo]Z00Go@_l0oookJ_oonf[ooo]ZomX0o`11oookJPCo00000ooonfX8oolX01Cooo]Z0ooo
0007oookJPKoo`001OoonfX00ooohP3ooo]ZoookJP05oookJP03ool00?oonf[ooo]Z00Oooo]Z1ooo
:00IoookJPOoobP00_oonfX?ool00?Kooo]Z00?oo`1aoookJ_oonfX04OoonfX00ooBo`3ooo]ZoolK
000MoookJP05od;o0?oonf[ooo]ZoookJ_oJ0?l0@OoonfX4o`0000Oooo]Z00?o/_l0oookJ_oonfX0
5_oonfX00onW0?oooo]ZoookJP0AoookJP03oooR0?oonf[ooo]Z017ooo]Z0_m30?lWoookJPGo:ol0
POoonfX0093ooo]Z1_oo0002oookJP?oo`006OoonfX01Om2o`3ooo]ZoookJ_oonf[ofP3o04;ooo]Z
1?l00003oookJPSoobP04ooonfX4ool000Oooo]Z1?oo0007oookJP03oooR0?oonf[ooo]Z00oooo]Z
2Ooo:00IoookJPGoobP01OoonfX;ool00?oooo]Z2ooonfX00ooBo`3ooo]ZoolK000MoookJP05od;o
0?oonf[ooo]ZoookJ_oJ0?l0@_oonfX4o`0000Oooo]Z00?o/_l0oookJ_oonfX05_oonfX00onW0?oo
oo]ZoookJP0AoookJP03oooR0?oonf[ooo]Z01?ooo]Z00?o@`3ooookJ_oonfX0:OoonfX2ob_o07oo
oo]Z002?oookJPOoo`000ooonfX00ooo003ooo]ZoookJP0HoookJP05od;o0?oonf[ooo]ZoookJ_oJ
0?l0@_oonfX4o`0000;ooo]Z2Ooo:00CoookJPCoo`001ooonfX00ooo003ooo]ZoookJP09oookJP03
oooR0?oonf[ooo]Z00oooo]Z2Ooo:00IoookJP?oobP02?oonfX9ool00?oooo]Z2_oonfX00ooBo`3o
oo]ZoolK000NoookJP05od;o0?oonf[ooo]ZoookJ_oJ0?l0@_oonfX4o`0000Kooo]Z00?o/_l0oook
J_oonfX05ooonfX00onW0?oooo]ZoookJP0BoookJP03oooR0?oonf[ooo]Z01?ooo]Z00?o@`3ooook
J_oonfX0ZOoonfX008kooo]Z1ooo000NoookJP05od;o0?oonf[ooo]ZoookJ_oJ0?l0@ooonfX4o`00
00Kooo]Z00?o/_l0oolX0?oo:0000_oo:00CoookJPGoo`004_oonfX00ooohP3ooo]ZoookJP0?oook
JP[oobP06_oonfX00ooo:03ooo]ZoookJP08oookJPOoo`00oooonfX:oookJP03om;o0?oonf[ooa/0
01gooo]Z00Go@_l0oookJ_oonf[ooo]ZomX0o`13oookJPCo00001_oonfX00onbo`3ooo]ZoookJP0G
oookJP03ojL0oooonf[ooo]Z01;ooo]Z00?oon80oookJ_oonfX05?oonfX00om30?oooo]ZoookJP2X
oookJP00SOoonfX8ool001gooo]Z00Go@_l0oookJ_oonf[ooo]ZomX0o`14oookJPCo00001OoonfX0
0onbo`3ooo]ZoookJP0FoookJPGoo`004ooonfX00ooohP3ooo]ZoookJP0?oookJPWoobP0:?oonfX3
ool00?oooo]Z2_oonfX00ooBo`3ooo]ZoolK000MoookJP05od;o0?oonf[ooo]ZoookJ_oJ0?l0A?oo
nfX4o`0000Kooo]Z00?o/_l0oookJ_oonfX0;OoonfX00ooohP3ooo]ZoookJP0DoookJP;o@`3oZ?oo
nfX008cooo]Z2?oo000NoookJP05od;o0?oonf[ooo]ZoookJ_oJ0?l0A?oonfX4o`0000Gooo]Z00?o
/_l0oookJ_oonfX05_oonfX6ool001;ooo]Z00?oon80oookJ_oonfX03ooonfX8oolX0003ool00?oo
nf[ooo]Z02Sooo]Z00?oo`00oookJ_oonfX0oooonfX7oookJP03om;o0?oonf[ooa/001kooo]Z00Go
@_l0oookJ_oonf[ooo]ZomX0o`14oookJPCo00001_oonfX00onbo`3ooo]ZoookJP0]oookJP03oooR
0?oonf[ooo]Z01Kooo]Z00?o@`3ooookJ_oonfX0YOoonfX008_ooo]Z2Ooo000MoookJP03od;o0?oo
nf[ooo]Z00;oo`00AOoonfX4o`0000Gooo]Z00?oo`00oookJ_oonfX05_oonfX6ool001;ooo]Z00?o
on80oookJ_oonfX04?oonfX6oolX00Coo`00oooonfXaoookJP03om;o0?oonf[ooo]Z01kooo]Z00Go
@_l0oookJ_oonf[ooo]ZomX0o`15oookJPCo00001_oonfX00onbo`3ooo]ZoookJP0^oookJP03oooR
0?oonf[ooo]Z01Kooo]Z00?o@`3ooookJ_oonfX0Y?oonfX008gooo]Z1_oo000NoookJP03od;o0?oo
nf[oo`0000;oo`00AOoonfX4o`0000Gooo]Z00?oo`00oookJ_oonfX05_oonfX7ool001;ooo]Z00?o
on80oookJ_oonfX04?oonfX4oolX0003oookJ_oo003oo`0000Coo`00oooonfX_oookJP03om;o0?oo
nf[ooo]Z01kooo]Z00Go@_l0oookJ_oonf[ooo]ZomX0o`15oookJPCo00001_oonfX00onbo`3ooo]Z
oookJP0^oookJP03oooR0?oonf[ooo]Z01Oooo]Z00?o@`3ooookJ_oonfX0XooonfX008kooo]Z1Ooo
000MoookJP03od;o0?oonf[oo`0000;oo`00A_oonfX4o`0000Cooo]Z0_oo000GoookJPSoo`004_oo
nfX00ooo:03ooo]ZoookJP0@oookJP?oobP00_oonfX8ool00?oooo]Z;?oonfX00ooBo`3ooo]Zoook
JP0NoookJP05od;o0?oonf[ooo]ZoookJ_oJ0?l0A_oonfX4o`0000Kooo]Z00?o/_l0oookJ_oonfX0
;ooonfX00ooohP3ooo]ZoookJP0GoookJP03od<0oooonf[ooo]Z0:;ooo]Z002>oookJP03ool00?oo
nf[oo`0000;oo`007?oonfX00ooo003ooo]Zool00003ool004Kooo]Z1?l00004oookJP;oo`005ooo
nfX8ool001;ooo]Z00?oobP0oookJ_oonfX04OoonfX00ooo:03ooo]ZoookJP02oookJPWoo`00oooo
nfXYoookJP03om;o0?oonf[ooo]Z01kooo]Z00Go@_l0oookJ_oonf[ooo]ZomX0o`17oookJPCo0000
1OoonfX00onbo`3ooo]ZoookJP0`oookJP03oooR0?oonf[ooo]Z01Sooo]Z00?o@`3ooookJ_oonfX0
XOoonfX008gooo]Z00Goo`00oookJ_oonf[ooo]Zool0000LoookJPOoo`00A_oonfX4o`0000?ooo]Z
0ooo000GoookJPWoo`004OoonfX2oolX01Sooo]Z2_oo003ooookJROooo]Z00?od_l0oookJ_oonfX0
7_oonfX01Om2o`3ooo]ZoookJ_oonf[ofP3o04Oooo]Z1?l00005oookJP03ok;o0?oonf[ooo]Z037o
oo]Z00?oon80oookJ_oonfX0^ooonfX008cooo]Z00?oo`00oookJ_oonfX07_oonfX7ool004Oooo]Z
1?l00003oookJP?oo`005ooonfX4ool001Kooo]Z0ooo:00HoookJP[oo`00oooonfXUoookJP03om;o
0?oonf[ooo]Z01kooo]Z00Go@_l0oookJ_oonf[ooo]ZomX0o`18oookJPCo00001OoonfX00onbo`3o
oo]ZoookJP0aoookJP03oooR0?oonf[ooo]Z0;_ooo]Z002<oookJP03ool00?oonf[ooo]Z01gooo]Z
2?oo0017oookJPGo00000_oonfX3ool003;ooo]Z0ooo:00GoookJP[oo`00oooonfXToookJP03om;o
0?oonf[ooo]Z01kooo]Z00?o@_l0oookJ_oonfX00_oonfX00ooJ0?oooo]ZoookJP16oookJPGo0000
1?oonfX00onbo`3ooo]ZoookJP0boookJP03oooR0?oonf[ooo]Z0;[ooo]Z002;oookJP03ool00?oo
nf[ooo]Z01gooo]Z2Ooo0017oookJPCo00000_oonfX4ool003;ooo]Z0ooo:00HoookJPSoo`00oooo
nfXUoookJP03om;o0?oonf[ooo]Z01kooo]Z00Go@_l0oookJ_oonf[ooo]ZomX0o`19oookJPCo0000
1OoonfX00onbo`3ooo]ZoookJP0boookJP03oooR0?oonf[ooo]Z0;[ooo]Z002:oookJP03ool00?oo
nf[ooo]Z01gooo]Z2Ooo0018oookJPCo00000_oonfX5ool0037ooo]Z1?oo:00HoookJPKoo`00oooo
nfXUoookJP03om;o0?oonf[ooo]Z01kooo]Z00Go@_l0oookJ_oonf[ooo]ZomX0o`1:oookJPCo0000
1?oonfX00onbo`3ooo]ZoookJP0coookJP03oooR0?oonf[ooo]Z0;[ooo]Z0029oookJP03ool00?oo
nf[ooo]Z01gooo]Z2_oo0018oookJPCo000000?ooo]Zool00?oo00001?oo000aoookJPGoobP05ooo
nfX5ool00?oooo]Z9OoonfX00ooBo`3ooo]ZoookJP0OoookJP05od;o0?oonf[ooo]ZoookJ_oJ0?l0
B_oonfX4o`0000Cooo]Z00?o/_l0oookJ_oonfX0=?oonfX00ooohP3ooo]ZoookJP2ioookJP00Z?oo
nfX;ool004Sooo]Z1?l000000ooonf[oo`00ool00004ool0037ooo]Z1_oo:00GoookJP?oo`00oooo
nfY7oookJP05od;o0?oonf[ooo]ZoookJ_oJ0?l0BooonfX4o`0000Cooo]Z00?o/_l0oookJ_oonfX0
=?oonfX00ooohP3ooo]ZoookJP2ioookJP00YooonfX;ool004Wooo]Z1?l00007ool003;ooo]Z1_oo
:00GoookJP03ool00?oonf[ooo]Z0?oooo]ZAOoonfX00om2o`3ooo]ZoookJP02oookJP03omX0oooo
nf[ooo]Z04Wooo]Z1?l0000loookJP03oooR0?oonf[ooo]Z0;Sooo]Z002VoookJPcoo`00BOoonfX4
o`0000Ooo`00<_oonfX6oolX0?oooo]ZGooonfX01Om2o`3ooo]ZoookJ_oonf[ofP3o04cooo]Z1?l0
000loookJP03oooR0?oonf[ooo]Z0;Sooo]Z002UoookJPgoo`00BOoonfX4o`0000Ooo`00<_oonfX7
oolX0?oooo]ZGOoonfX01Om2o`3ooo]ZoookJ_oonf[ofP3o04gooo]Z1?l0000loookJP03oooR0?oo
nf[ooo]Z0;Sooo]Z002ToookJPSoo`0000?ooo]Zool00?oo00000_oo001:oookJP?o00002?oo000b
oookJPSoobP0oooonfYLoookJP05od;o0?oonf[ooo]ZoookJ_oJ0?l0COoonfX4o`0003gooo]Z00?o
on80oookJ_oonfX0]ooonfX00:Kooo]Z1ooo0003oookJP03ool00?oonf[ooo]Z04Sooo]Z1?l00004
oookJP?oo`00<_oonfX9oolX0?oooo]ZF_oonfX01Om2o`3ooo]ZoookJ_oonf[ofP3o04kooo]Z1?l0
000moookJP03oooR0?oonf[ooo]Z0;Oooo]Z002WoookJPKoo`00C_oonfX4o`0003[ooo]Z1_oo:03o
oookJU_ooo]Z00?o@_l0oookJ_oonfX00_oonfX00ooJ0?oooo]ZoookJP1<oookJPCo0000?OoonfX0
0ooohP3ooo]ZoookJP2goookJP00YooonfX00ooo003ooo]Zool00002ool004oooo]Z1?l0000joook
JP?oobP000?ooo]Zool00?oonfX0oooonfYKoookJP05od;o0?oonf[ooo]ZoookJ_oJ0?l0CooonfX4
o`0003kooo]Z00?oon80oookJ_oonfX0]_oonfX00:Kooo]Z00Goo`00oookJ_oonf[ooo]Zool0001@
oookJPCo0000>_oonfX01Ooo:03ooo]ZoookJ_oonf[oo`000?oooo]ZFooonfX01Om2o`3ooo]Zoook
J_oonf[ofP3o053ooo]Z1?l0000noookJP03oooR0?oonf[ooo]Z0;Kooo]Z002VoookJP03ool00?oo
nf[ooo]Z05;ooo]Z1?l0000noookJP;oo`00oooonfYJoookJP03od;o0?oonf[ooo]Z05;ooo]Z1?l0
000ooookJP03oooR0?oonf[ooo]Z0;Gooo]Z002UoookJP03ool00?oonf[ooo]Z05?ooo]Z1Ol0000m
oookJP?oo`00oooonfYHoookJP03od;o0?oonf[ooo]Z05?ooo]Z1Ol0000noookJP03oooR0?oonf[o
oo]Z0;Gooo]Z002ToookJP03ool00?oonf[ooo]Z05Cooo]Z1?l0000noookJPCoo`00oooonfYFoook
JP03od;o0?oonf[ooo]Z05Cooo]Z1?l00010oookJP03oooR0?oonf[ooo]Z0;Cooo]Z003koookJPCo
0000?ooonfX3ool00?oooo]Z[OoonfX4o`00047ooo]Z00?oon80oookJ_oonfX0/ooonfX00?_ooo]Z
1?l0000ooookJPCoo`00oooonfZ/oookJPCo0000@OoonfX00ooohP3ooo]ZoookJP2coookJP00nooo
nfX4o`0003oooo]Z1Ooo003ooookJZ_ooo]Z1?l00012oookJP03oooR0?oonf[ooo]Z0;;ooo]Z003k
oookJPCo0000?ooonfX6ool00?oooo]ZZ_oonfX4o`000?Oooo]Z003koookJPCo0000?ooonfX6ool0
0?oooo]ZZ_oonfX4o`000?Oooo]Z003koookJPCo0000?ooonfX7ool00?oooo]ZZOoonfX4o`000?Oo
oo]Z003koookJPCo0000?ooonfX8ool00?oooo]ZZ?oonfX4o`000?Oooo]Z003koookJPCo0000@?oo
nfX8ool00?oooo]ZYooonfX4o`000?Oooo]Z003VoookJP?o001o1OoonfX5o`00O`Sooo]Z1?l00010
oookJPKoo`00oooonfZDoookJP?o001o1OoonfX5o`00O`Sooo]Z1?l0003goookJP00i_oonfX3o`00
O`Cooo]Z1ol007l7oookJPCo0000@?oonfX3ool00?oooo]ZUooonfX3o`00O`Cooo]Z1ol007l7oook
JPCo0000mooonfX00>Kooo]Z0ol007l4oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`00
043ooo]Z00?oo`00oookJ_oonfX0oooonfZGoookJP?o001o1?oonfX3o`00O`04oookJ_l007oo001o
o`00O`Oooo]Z1?l0003goookJP00i_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX4o`00
0?oooo]Zf_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX4o`000?Oooo]Z003VoookJP?o
001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPKo0000oooonf[HoookJP?o001o0ooonfX3o`00O`?o
oo]Z0ol007l6oookJPKo0000mOoonfX00>Kooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z
1?l0003ooookJ][ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0003goookJP00i_oo
nfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX4o`000?oooo]Zf_oonfX3o`00O`?ooo]Z0ol0
07l3oookJP?o001o1_oonfX4o`000?Oooo]Z003VoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6
oookJPCo0000oooonf[JoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000mooonfX0
0>Kooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0003ooookJ][ooo]Z0ol007l3oook
JP?o001o0ooonfX3o`00O`Kooo]Z1?l0003goookJP00hooonfX6o`00O`?ooo]Z0ol007l3oookJP?o
001o1_oonfX4o`000?oooo]ZeooonfX6o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX4o`000?Oo
oo]Z003SoookJPKo001o1?oonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l0003ooookJ]Oo
oo]Z1_l007l4oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`000?Oooo]Z003UoookJPCo
001o1?oonfX7o`00O`Oooo]Z1?l0003ooookJ]Wooo]Z1?l007l4oookJPOo001o1ooonfX4o`000?Oo
oo]Z003VoookJP?o001o1OoonfX5o`00O`Sooo]Z1?l0003ooookJ][ooo]Z0ol007l5oookJPGo001o
2?oonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003o
oookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo
0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooo
nfX5o`000?oooo]Zk_oonfX5o`000?Kooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX0
0?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oo
oo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0
003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oook
JPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]Z
kooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003o
oookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo
0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1Ol0003ooookJ^kooo]Z1Ol0003foookJP00nooo
nfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX0
0?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oo
oo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0
003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oook
JPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]Z
kooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003o
oookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPGo
0000oooonf[^oookJPGo0000m_oonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooo
nfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX0
0?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oo
oo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0
003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oook
JPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]Z
kooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003o
oookJ^oooo]Z1?l0003goookJP00nooonfX5o`000?oooo]Zk_oonfX5o`000?Kooo]Z003koookJPCo
0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooo
nfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX0
0?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oo
oo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0
003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oook
JPCo0000mooonfX00>Kooo]Z0ol007l5oookJPGo001o2?oonfX4o`000?oooo]Zf_oonfX3o`00O`Go
oo]Z1Ol007l8oookJPCo0000mooonfX00>Kooo]Z0ol007l4oookJPOo001o1ooonfX4o`000?oooo]Z
f_oonfX3o`00O`Cooo]Z1ol007l7oookJPCo0000mooonfX00>Kooo]Z0ol007l3oookJPCo001o00Co
oo]Zo`00Ool007oo001o1ooonfX4o`000?oooo]Zf_oonfX3o`00O`?ooo]Z1?l007l01?oonf[o001o
o`00Ool007l7oookJPCo0000mooonfX00>Kooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z
1?l0003ooookJ][ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0003goookJP00i_oo
nfX3o`00O`Wooo]Z0ol007l6oookJPKo0000oooonf[HoookJP?o001o2OoonfX3o`00O`Kooo]Z1_l0
003eoookJP00i_oonfX3o`00O`Wooo]Z0ol007l6oookJPCo0000oooonf[JoookJP?o001o2OoonfX3
o`00O`Kooo]Z1?l0003goookJP00i_oonfX3o`00O`Cooo]Z0_l007l2oookJPCo001o1_oonfX4o`00
0?oooo]Zf_oonfX3o`00O`Cooo]Z0_l007l2oookJPCo001o1_oonfX4o`000?Oooo]Z003VoookJP?o
001o1?oonfX7o`00Oooooo]ZiOoonfX3o`00O`Cooo]Z1ol007oooookJP?ooo]Z003VoookJP?o001o
1?oonfX6o`00Oooooo]Zi_oonfX3o`00O`Cooo]Z1_l007oooookJPCooo]Z003SoookJPKo001o1?oo
nfX2o`00Oooooo]ZiooonfX6o`00O`Cooo]Z0_l007oooookJPSooo]Z003SoookJPKo001o1?oonfX2
o`00Oooooo]ZiooonfX6o`00O`Cooo]Z0_l007oooookJPSooo]Z003UoookJPCo001o1OoonfX7o`00
Oooooo]ZhooonfX4o`00O`Gooo]Z1ol007oooookJP;ooo]Z003VoookJP?o001o1OoonfX7o`00Oooo
oo]Zi?oonfX3o`00O`Gooo]Z1ol007oooookJP;ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooo
nf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oook
JP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooo
nf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oo
oo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003o
oookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_o
oo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[o
oookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Z
oooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX0
0?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]Z
jooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooook
J_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 999}, {999, 0}} -> {-0.0500105, -0.0500105, \
0.00210213, 0.00210213}, {{23.75, 476.812}, {975.188, 522.125}} -> {-1.17208, \
-1.15742, 0.00462332, 0.00462332}, {{522.125, 975.188}, {975.188, 522.125}} -> \
{-3.47623, -1.15742, 0.00462332, 0.00462332}, {{23.75, 476.812}, {476.812, \
23.75}} -> {-17.9973, -53.1523, 0.070991, 0.070991}, {{522.125, 975.188}, \
{476.812, 23.75}} -> {-53.3774, -53.1523, 0.070991, 0.070991}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
In this next example, the eigenvalues are real and positive, and \
the system of equations has an unstable node. The eigenvectors are real and \
correspond to directions along which the system will evolve along a straight \
trajectory.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CritPointPlotPointsMany[1.25, \(-0.25\), \(-0.75\), 0.75, 
      200]\)], "Input",
  CellTags->"mmtag:25:fixed_point__unstable_node_visualization"],

Cell[BoxData[
    \("Unstable"\)], "Print"],

Cell[BoxData[
    \("Node"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Eigenvalues = \
"\[InvisibleSpace]1.5`\[InvisibleSpace]" and "\[InvisibleSpace]0.5`\),
      SequenceForm[ "Eigenvalues = ", 1.5, " and ", 0.5],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Unstable (\[Lambda]="\[InvisibleSpace]1.5`\
\[InvisibleSpace]") direction is \[Theta] = "\[InvisibleSpace]\(-45.`\)\),
      SequenceForm[ 
      "Unstable (\[Lambda]=", 1.5, ") direction is \[Theta] = ", -45.0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Unstable (\[Lambda]="\[InvisibleSpace]0.5`\
\[InvisibleSpace]") direction is \[Theta] = \
"\[InvisibleSpace]71.565051177078`\),
      SequenceForm[ 
      "Unstable (\[Lambda]=", 0.5, ") direction is \[Theta] = ", 
        71.565051177078004],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{1.5`, 
        0.5`}, {{0.7071067811865475`, \(-0.7071067811865475`\)}, \
{0.3162277660168379`, 0.9486832980505138`}}}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 1000 1000 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto fill
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto
-15. 3.75 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00833333 0.5 0.00833333 [
[0 .4875 -18.4688 -20 ]
[0 .4875 18.4688 0 ]
[.16667 .4875 -18.4688 -20 ]
[.16667 .4875 18.4688 0 ]
[.33333 .4875 -18.4688 -20 ]
[.33333 .4875 18.4688 0 ]
[.66667 .4875 -12 -20 ]
[.66667 .4875 12 0 ]
[.83333 .4875 -12 -20 ]
[.83333 .4875 12 0 ]
[1 .4875 -12 -20 ]
[1 .4875 12 0 ]
[.4875 0 -36.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .16667 -36.9375 -10 ]
[.4875 .16667 0 10 ]
[.4875 .33333 -36.9375 -10 ]
[.4875 .33333 0 10 ]
[.4875 .66667 -24 -10 ]
[.4875 .66667 0 10 ]
[.4875 .83333 -24 -10 ]
[.4875 .83333 0 10 ]
[.4875 1 -24 -10 ]
[.4875 1 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.16667 .5 m
.16667 .50625 L
s
gsave
.16667 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.33333 .5 m
.33333 .50625 L
s
gsave
.33333 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.66667 .5 m
.66667 .50625 L
s
gsave
.66667 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.83333 .5 m
.83333 .50625 L
s
gsave
.83333 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 .5 m
.04167 .50375 L
s
.08333 .5 m
.08333 .50375 L
s
.125 .5 m
.125 .50375 L
s
.20833 .5 m
.20833 .50375 L
s
.25 .5 m
.25 .50375 L
s
.29167 .5 m
.29167 .50375 L
s
.375 .5 m
.375 .50375 L
s
.41667 .5 m
.41667 .50375 L
s
.45833 .5 m
.45833 .50375 L
s
.54167 .5 m
.54167 .50375 L
s
.58333 .5 m
.58333 .50375 L
s
.625 .5 m
.625 .50375 L
s
.70833 .5 m
.70833 .50375 L
s
.75 .5 m
.75 .50375 L
s
.79167 .5 m
.79167 .50375 L
s
.875 .5 m
.875 .50375 L
s
.91667 .5 m
.91667 .50375 L
s
.95833 .5 m
.95833 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.5 .16667 m
.50625 .16667 L
s
gsave
.4875 .16667 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.5 .33333 m
.50625 .33333 L
s
gsave
.4875 .33333 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.5 .66667 m
.50625 .66667 L
s
gsave
.4875 .66667 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.5 .83333 m
.50625 .83333 L
s
gsave
.4875 .83333 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .04167 m
.50375 .04167 L
s
.5 .08333 m
.50375 .08333 L
s
.5 .125 m
.50375 .125 L
s
.5 .20833 m
.50375 .20833 L
s
.5 .25 m
.50375 .25 L
s
.5 .29167 m
.50375 .29167 L
s
.5 .375 m
.50375 .375 L
s
.5 .41667 m
.50375 .41667 L
s
.5 .45833 m
.50375 .45833 L
s
.5 .54167 m
.50375 .54167 L
s
.5 .58333 m
.50375 .58333 L
s
.5 .625 m
.50375 .625 L
s
.5 .70833 m
.50375 .70833 L
s
.5 .75 m
.50375 .75 L
s
.5 .79167 m
.50375 .79167 L
s
.5 .875 m
.50375 .875 L
s
.5 .91667 m
.50375 .91667 L
s
.5 .95833 m
.50375 .95833 L
s
.01 w
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.918 0 1 r
.5 Mabswid
.53 .41786 m
.53629 .40889 L
.54368 .39869 L
.55234 .38708 L
.56249 .37383 L
.57436 .35869 L
.58825 .34137 L
.60447 .32154 L
.62342 .29879 L
.64555 .27268 L
.67136 .24267 L
.70147 .20815 L
.73657 .16842 L
.77749 .12263 L
.82515 .06984 L
.88068 .00894 L
s
.88068 .00894 m
.8889 0 L
s
1 0 0 r
.53 .41786 m
.53629 .40889 L
s
% Start of user PostScript
3.5995507 -9.8566221 4.3550316 -10.93291 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54368 .39869 m
.55234 .38708 L
s
% Start of user PostScript
5.2416426 -12.156776 6.2810596 -13.550739 MAarrowhead1
% End of user PostScript
1 .473 0 r
.67136 .24267 m
.70147 .20815 L
s
% Start of user PostScript
20.563587 -30.879754 24.176627 -35.021715 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
72.988757 -88.378669 85.226226 -101.4052 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
249.36552 -272.32457 290.35601 -314.49219 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
838.41665 -872.66753 975.04789 -1011.0549 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2799.2965 -2850.3928 3253.7308 -3307.4469 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9317.3463 -9393.573 10827.319 -10907.454 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
30969.52 -31083.237 35984.592 -36104.14 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
102874.41 -103044.05 119527.7 -119706.04 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
341632.59 -341885.68 396927.44 -397193.5 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1134375.8 -1134753.4 1317967.1 -1318364. MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3766433. -3766996.2 4375986.4 -4376578.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
12505255. -12506096. 14529057. -14529940. MAarrowhead1
% End of user PostScript
.175 1 0 r
.43693 .43696 m
.43021 .43721 L
.42258 .43804 L
.4139 .43957 L
.40402 .44194 L
.39275 .44532 L
.37987 .4499 L
.36513 .45591 L
.34825 .46361 L
.32889 .47332 L
.30667 .48541 L
.28113 .50029 L
.25175 .51846 L
.21792 .5405 L
.17895 .56709 L
.13401 .59901 L
.08216 .63717 L
.0223 .68264 L
s
.0223 .68264 m
0 .70006 L
s
1 0 0 r
.43693 .43696 m
.43021 .43721 L
s
% Start of user PostScript
-7.5681849 -7.5653633 -8.3746732 -7.5347886 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42258 .43804 m
.4139 .43957 L
s
% Start of user PostScript
-9.290232 -7.4349253 -10.331413 -7.2512613 MAarrowhead1
% End of user PostScript
1 .473 0 r
.30667 .48541 m
.28113 .50029 L
s
% Start of user PostScript
-23.200038 -1.750965 -26.264933 0.034664988 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-65.622407 28.399885 -75.2135 36.082538 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-200.86065 145.33117 -231.83191 173.45537 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-641.49982 558.65958 -743.02669 655.93913 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2091.9904 1968.4072 -2427.1301 2297.2107 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6889.1661 6704.8018 -7998.9731 7805.1562 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-22788.569 22513.53 -26468.938 26179.797 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-75535.001 75124.69 -87747.809 87316.462 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-250597.49 249985.38 -291135.83 290492.33 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-831733.2 830820.03 -966310.87 965350.89 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2761034.1 2759671.8 -3207826.3 3206394.2 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-9166333.3 9164301. -10649704. 10647567. MAarrowhead1
% End of user PostScript
.341 1 0 r
.41928 .49969 m
.40846 .50635 L
.396 .51445 L
.38165 .52421 L
.36509 .53593 L
.346 .54996 L
.32395 .56667 L
.29848 .58653 L
.26905 .61007 L
.23501 .6379 L
.19564 .67076 L
.15008 .70947 L
.09733 .75502 L
.03625 .80853 L
s
.03625 .80853 m
0 .8407 L
s
1 0 0 r
.41928 .49969 m
.40846 .50635 L
s
% Start of user PostScript
-9.6860033 -0.037775242 -10.984757 0.76243009 MAarrowhead1
% End of user PostScript
1 .158 0 r
.396 .51445 m
.38165 .52421 L
s
% Start of user PostScript
-12.479914 1.7334769 -14.202552 2.9051327 MAarrowhead1
% End of user PostScript
1 .473 0 r
.19564 .67076 m
.15008 .70947 L
s
% Start of user PostScript
-36.522867 20.491067 -41.990386 25.136618 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-113.93249 90.015849 -131.70959 106.56672 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-367.33752 331.65809 -425.7991 388.29035 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1203.2954 1150.068 -1396.5586 1340.6021 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3970.7526 3891.3466 -4611.1615 4527.6843 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-13147.069 13028.609 -15271.44 15146.907 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-43595.66 43418.939 -50646.046 50460.264 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-144661.92 144398.28 -168065.88 167788.73 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-480173.97 479780.67 -557871.69 557458.23 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1594054. 1593467.2 -1852010.3 1851393.4 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-5292177.4 5291302. -6148608.7 6147688.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-17570248. 17568942. -20413679. 20412306. MAarrowhead1
% End of user PostScript
0 .834 1 r
.46459 .53177 m
.45896 .53722 L
.45243 .54356 L
.44484 .55094 L
.43603 .55953 L
.4258 .56954 L
.41392 .58118 L
.40012 .59472 L
.3841 .61048 L
.36549 .62881 L
.34388 .65012 L
.31878 .67492 L
.28963 .70375 L
.25577 .73727 L
.21644 .77625 L
.17075 .82156 L
.11768 .87424 L
.05603 .93547 L
s
.05603 .93547 m
0 .99116 L
s
1 0 0 r
.46459 .53177 m
.45896 .53722 L
s
% Start of user PostScript
-4.2490508 3.8129251 -4.9246379 4.4661515 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45243 .54356 m
.44484 .55094 L
s
% Start of user PostScript
-5.70894 5.2269466 -6.6195193 6.1128135 MAarrowhead1
% End of user PostScript
1 .473 0 r
.34388 .65012 m
.31878 .67492 L
s
% Start of user PostScript
-18.734042 18.014992 -21.745977 20.99006 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-61.870552 60.797856 -71.853676 70.725981 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-204.92717 203.32689 -238.04717 236.36484 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-679.65071 677.26338 -789.57548 787.06575 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2255.4286 2251.8672 -2620.3358 2616.5917 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-7486.659 7481.3459 -8698.1099 8692.5244 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-24854.155 24846.228 -28876.189 28867.856 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-82515.077 82503.252 -95868.515 95856.084 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-273954.3 273936.66 -318289. 318270.45 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-909552.24 909525.92 -1056748.2 1056720.5 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3019807.7 3019768.5 -3508515. 3508473.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-10026097. 10026038. -11648661. 11648599. MAarrowhead1
% End of user PostScript
1 .716 0 r
.46058 .47102 m
.45609 .472 L
.45098 .47343 L
.44513 .4754 L
.43845 .47801 L
.4308 .48138 L
.42203 .48565 L
.41196 .49098 L
.40039 .49757 L
.38709 .50564 L
.37179 .51545 L
.35416 .5273 L
.33383 .54154 L
.31038 .5586 L
.28332 .57895 L
.25206 .60315 L
.21593 .63185 L
.17417 .66581 L
.12586 .70591 L
.06997 .75318 L
.00526 .80882 L
s
.00526 .80882 m
0 .81341 L
s
1 0 0 r
.46058 .47102 m
.45609 .472 L
s
% Start of user PostScript
-4.7299999 -3.4775696 -5.2686122 -3.3597685 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45098 .47343 m
.44513 .4754 L
s
% Start of user PostScript
-5.8827588 -3.1880084 -6.5840675 -2.9517679 MAarrowhead1
% End of user PostScript
1 .473 0 r
.37179 .51545 m
.35416 .5273 L
s
% Start of user PostScript
-15.385444 1.8534493 -17.5013 3.2755058 MAarrowhead1
% End of user PostScript
1 .788 0 r
.12586 .70591 m
.06997 .75318 L
s
% Start of user PostScript
-44.896362 24.708999 -51.604136 30.381744 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-139.83407 109.71806 -161.63158 129.97149 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-450.50025 405.57245 -522.16478 474.93348 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1475.1782 1408.1538 -1712.06 1641.5991 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4867.1291 4767.1405 -5652.0335 5546.9183 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-16113.736 15964.57 -18717.367 18560.553 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-53431.307 53208.778 -62072.171 61838.233 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-177296.47 176964.5 -205979.94 205630.94 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-588493.29 587998.04 -683717.97 683197.33 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1953640.2 1952901.3 -2269785.6 2269008.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-6485976.1 6484873.9 -7535598.6 7534439.9 MAarrowhead1
% End of user PostScript
1 .182 0 r
.42344 .45177 m
.4145 .45431 L
.40429 .4578 L
.39261 .4624 L
.37924 .46834 L
.36391 .47585 L
.34632 .48523 L
.3261 .49681 L
.30286 .51098 L
.2761 .52819 L
.24527 .54899 L
.20974 .57397 L
.16874 .60388 L
.12141 .63955 L
.06675 .68195 L
.00359 .73224 L
s
.00359 .73224 m
0 .73516 L
s
1 0 0 r
.42344 .45177 m
.4145 .45431 L
s
% Start of user PostScript
-9.1869443 -5.7877038 -10.259795 -5.4826193 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40429 .4578 m
.39261 .4624 L
s
% Start of user PostScript
-11.485049 -5.0644967 -12.886281 -4.5117783 MAarrowhead1
% End of user PostScript
1 .473 0 r
.24527 .54899 m
.20974 .57397 L
s
% Start of user PostScript
-30.567354 5.8783329 -34.831774 8.8769204 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-90.202502 53.370811 -103.7823 65.062207 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-282.64808 227.70165 -326.87146 269.10787 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-913.31015 831.33971 -1058.8493 972.67613 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2994.83 2872.5445 -3476.116 3347.5607 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-9887.2923 9704.8638 -11482.352 11290.57 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-32743.583 32471.432 -38035.094 37748.989 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-108588.13 108182.13 -126150.19 125723.37 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-360339.72 359734.04 -418638.29 418001.55 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1196093.2 1195189.6 -1389637. 1388687.1 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3970756.2 3969408.2 -4613323.2 4611906.2 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-13182759. 13180748. -15316125. 15314011. MAarrowhead1
% End of user PostScript
1 0 .955 r
.56003 .45359 m
.56937 .44495 L
.5802 .43486 L
.59276 .42307 L
.60733 .40931 L
.62424 .39325 L
.64387 .37452 L
.66664 .35269 L
.69308 .32725 L
.72376 .2976 L
.75938 .26308 L
.80074 .22287 L
.84876 .17607 L
.90451 .12159 L
.96925 .05818 L
s
.96925 .05818 m
1 .02801 L
s
1 0 0 r
.56003 .45359 m
.56937 .44495 L
s
% Start of user PostScript
7.2034519 -5.5687153 8.3240316 -6.6054804 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5802 .43486 m
.59276 .42307 L
s
% Start of user PostScript
9.6236429 -7.8169796 11.13114 -9.2318474 MAarrowhead1
% End of user PostScript
1 .473 0 r
.75938 .26308 m
.80074 .22287 L
s
% Start of user PostScript
31.125842 -28.430618 36.088572 -33.255159 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
102.10952 -98.088719 118.5232 -114.29625 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
337.17775 -331.17942 391.57886 -385.27298 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1116.7279 -1107.7794 1297.2053 -1287.7981 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3703.577 -3690.2275 4302.5736 -4288.5396 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
12290.207 -12270.292 14278.633 -14257.697 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
40795.822 -40766.112 47397.161 -47365.928 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
135433.32 -135389. 157349.84 -157303.25 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
449634.19 -449568.07 522398.58 -522329.06 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1492807.9 -1492709.2 1734392.6 -1734288.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4956251.6 -4956104.4 5758338.8 -5758184.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
16455268. -16455048. 19118287. -19118056. MAarrowhead1
% End of user PostScript
.642 0 1 r
.51711 .58092 m
.51717 .58589 L
.5171 .59124 L
.51688 .59702 L
.51646 .60328 L
.51581 .61006 L
.51489 .61744 L
.51364 .62547 L
.51201 .63424 L
.50991 .64383 L
.50726 .65436 L
.50397 .66594 L
.49992 .67871 L
.49497 .69282 L
.48896 .70845 L
.48172 .72581 L
.47302 .74515 L
.46263 .76673 L
.45024 .79088 L
.43552 .81796 L
.41808 .8484 L
.39746 .88268 L
.37312 .92138 L
.34444 .96516 L
s
.34444 .96516 m
.32075 1 L
s
1 0 0 r
.51711 .58092 m
.51717 .58589 L
s
% Start of user PostScript
2.053491 9.7102411 2.0606573 10.306214 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5171 .59124 m
.51688 .59702 L
s
% Start of user PostScript
2.0523122 10.948622 2.0250905 11.642416 MAarrowhead1
% End of user PostScript
1 .473 0 r
.50726 .65436 m
.50397 .66594 L
s
% Start of user PostScript
0.87153947 18.523576 0.47648816 19.913036 MAarrowhead1
% End of user PostScript
1 .788 0 r
.45024 .79088 m
.43552 .81796 L
s
% Start of user PostScript
-5.9713717 34.905484 -7.7375057 38.155101 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-33.050655 76.215278 -39.592487 84.970208 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-129.46143 193.85548 -152.19262 219.88822 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-459.25986 555.32449 -536.23913 637.2291 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1568.705 1712.0166 -1826.5364 1977.1957 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-5273.7878 5487.5836 -6133.1768 6357.9341 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-17607.312 17926.258 -20465.594 20800.893 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-58604.118 59079.929 -68101.422 68601.629 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-194790. 195499.83 -226333.32 227079.54 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-647050.03 648108.97 -751794.15 752907.38 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2148765.8 2150345.5 -2496553.3 2498214.1 MAarrowhead1
% End of user PostScript
1 .482 0 r
.4742 .53849 m
.46967 .54367 L
.46439 .54963 L
.45824 .5565 L
.45108 .56442 L
.44273 .57356 L
.43301 .58411 L
.4217 .5963 L
.40853 .61039 L
.3932 .62669 L
.37537 .64554 L
.35462 .66736 L
.33049 .69263 L
.30241 .72188 L
.26977 .75578 L
.2318 .79505 L
.18765 .84057 L
.13633 .89335 L
.07665 .95455 L
s
.07665 .95455 m
.03222 1 L
s
1 0 0 r
.4742 .53849 m
.46967 .54367 L
s
% Start of user PostScript
-3.0965615 4.6186151 -3.6397619 5.2398529 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46439 .54963 m
.45824 .5565 L
s
% Start of user PostScript
-4.2730278 5.9551572 -5.0110454 6.7794194 MAarrowhead1
% End of user PostScript
1 .473 0 r
.37537 .64554 m
.35462 .66736 L
s
% Start of user PostScript
-14.955808 17.46525 -17.445533 20.083637 MAarrowhead1
% End of user PostScript
1 .788 0 r
.07665 .95455 m
0 0 rlineto s
.07665 .95455 m
.03222 1 L
s
% Start of user PostScript
-50.802029 54.545677 -59.127015 63.062603 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-170.3798 175.96466 -198.10745 203.97866 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-568.23354 576.56518 -660.42348 669.18229 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1890.41 1902.8393 -2196.6866 2209.7532 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6282.0632 6300.6056 -7299.2287 7318.7218 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-20865.66 20893.322 -24243.203 24272.283 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-69289.073 69330.34 -80503.559 80546.941 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-230066.69 230128.25 -267301.06 267365.78 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-763876.44 763968.28 -887500.34 887596.89 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2536201.1 2536338.1 -2946649. 2946793.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-8420546.7 8420751.1 -9783285.2 9783500.1 MAarrowhead1
% End of user PostScript
0 1 .547 r
.42723 .53881 m
.4164 .54791 L
.40385 .55862 L
.38933 .57122 L
.37251 .58602 L
.35302 .60338 L
.33044 .62373 L
.30427 .64755 L
.27393 .67542 L
.23874 .70801 L
.19793 .74609 L
.15059 .79056 L
.09567 .84246 L
.03195 .90301 L
s
.03195 .90301 m
0 .93352 L
s
1 0 0 r
.42723 .53881 m
.4164 .54791 L
s
% Start of user PostScript
-8.7319082 4.6577152 -10.032416 5.7493347 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40385 .55862 m
.38933 .57122 L
s
% Start of user PostScript
-11.537617 7.0349372 -13.280341 8.5468037 MAarrowhead1
% End of user PostScript
1 .473 0 r
.19793 .74609 m
.15059 .79056 L
s
% Start of user PostScript
-36.248183 29.530974 -41.928711 34.867104 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-117.27795 107.25705 -135.98055 125.44587 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-384.79623 369.8468 -446.65622 430.94032 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1270.7355 1248.4336 -1475.7676 1452.3222 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-4208.7968 4175.5262 -4889.0046 4854.0282 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-13958.49 13908.857 -16216.08 16163.902 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-46321.134 46247.089 -53815.433 53737.591 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-153757.74 153647.27 -178637.95 178521.82 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-510443.17 510278.38 -593045.8 592872.56 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1694655.7 1694409.9 -1968902.2 1968643.8 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-5626342.7 5625975.9 -6536867.4 6536481.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-18679948. 18679401. -21702988. 21702413. MAarrowhead1
% End of user PostScript
0 .093 1 r
.42894 .53691 m
.41839 .54572 L
.40617 .5561 L
.39203 .5683 L
.37565 .58265 L
.35668 .59948 L
.3347 .61921 L
.30922 .64233 L
.27969 .66938 L
.24544 .70101 L
.20573 .73798 L
.15966 .78116 L
.10622 .83157 L
.04421 .89039 L
s
.04421 .89039 m
0 .93254 L
s
1 0 0 r
.42894 .53691 m
.41839 .54572 L
s
% Start of user PostScript
-8.5267536 4.4297894 -9.793431 5.486411 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40617 .5561 m
.39203 .5683 L
s
% Start of user PostScript
-11.259294 6.7314484 -12.95628 8.1962869 MAarrowhead1
% End of user PostScript
1 .473 0 r
.20573 .73798 m
.15966 .78116 L
s
% Start of user PostScript
-35.312617 28.557865 -40.840701 33.739625 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-114.1546 104.0777 -132.35019 121.75663 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-374.40074 359.36776 -434.57608 418.77234 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1236.1831 1213.7565 -1435.6199 1412.0435 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-4094.0217 4060.5652 -4755.6499 4720.478 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-13577.339 13527.428 -15773.238 15720.767 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-45055.539 44981.08 -52345.01 52266.734 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-149555.62 149444.55 -173755.78 173639. MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-496491.39 496325.68 -576836.12 576661.91 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1648333.7 1648086.5 -1915083.7 1914823.8 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-5472547.7 5472178.9 -6358183.1 6357795.4 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-18169330. 18168779. -21109734. 21109156. MAarrowhead1
% End of user PostScript
0 .075 1 r
.47328 .46623 m
.47063 .46578 L
.46764 .46551 L
.46425 .46548 L
.4604 .46572 L
.45604 .4663 L
.45107 .46728 L
.44541 .46876 L
.43894 .47082 L
.43156 .47358 L
.4231 .47717 L
.41341 .48174 L
.4023 .48748 L
.38954 .4946 L
.37486 .50333 L
.35798 .51397 L
.33853 .52685 L
.31612 .54236 L
.29027 .56095 L
.26045 .58315 L
.226 .60958 L
.1862 .64094 L
.1402 .67809 L
.08699 .72198 L
.02543 .77374 L
s
.02543 .77374 m
0 .7955 L
s
1 0 0 r
.47328 .46623 m
.47063 .46578 L
s
% Start of user PostScript
-3.2060374 -4.0524834 -3.5242528 -4.1064203 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46764 .46551 m
.46425 .46548 L
s
% Start of user PostScript
-3.8836798 -4.1382263 -4.2904604 -4.1427376 MAarrowhead1
% End of user PostScript
1 .473 0 r
.4231 .47717 m
.41341 .48174 L
s
% Start of user PostScript
-9.2276739 -2.7396037 -10.390243 -2.1906105 MAarrowhead1
% End of user PostScript
1 .788 0 r
.29027 .56095 m
.26045 .58315 L
s
% Start of user PostScript
-25.167036 7.3139558 -28.746451 9.9780239 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-75.39734 48.763674 -86.863036 58.863833 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-238.15445 198.42169 -275.59776 233.82785 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-772.53986 713.26555 -895.92488 833.6115 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2537.83 2449.4031 -2946.0936 2853.1329 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8385.4747 8253.5573 -9738.8853 9600.2044 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-27780.461 27583.663 -32270.851 32063.963 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-92144.426 91850.839 -107048.43 106739.79 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-305796.08 305358.1 -355272.25 354811.81 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1015078.5 1014425.2 -1179335. 1178648.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3369880.8 3368906.1 -3915216. 3914191.3 MAarrowhead1
% End of user PostScript
0 1 .968 r
.47262 .49849 m
.46899 .50064 L
.46481 .50326 L
.46 .50644 L
.45445 .51026 L
.44805 .51485 L
.44067 .52033 L
.43215 .52686 L
.4223 .5346 L
.41092 .54377 L
.39775 .55462 L
.38252 .5674 L
.3649 .58246 L
.34449 .60018 L
.32085 .62098 L
.29346 .64538 L
.26173 .67398 L
.22495 .70746 L
.1823 .74664 L
.13285 .79245 L
.0755 .84597 L
.00897 .90848 L
s
.00897 .90848 m
0 .91695 L
s
1 0 0 r
.47262 .49849 m
.46899 .50064 L
s
% Start of user PostScript
-3.2855539 -0.18115313 -3.7214466 0.076997624 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46481 .50326 m
.46 .50644 L
s
% Start of user PostScript
-4.2229686 0.39166478 -4.8004893 0.77275031 MAarrowhead1
% End of user PostScript
1 .473 0 r
.39775 .55462 m
.38252 .5674 L
s
% Start of user PostScript
-12.269564 6.5539301 -14.097215 8.0885343 MAarrowhead1
% End of user PostScript
1 .788 0 r
.1823 .74664 m
.13285 .79245 L
s
% Start of user PostScript
-38.123924 29.597201 -44.057995 35.094097 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-122.67855 109.95817 -142.18054 128.80798 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-401.49299 382.51642 -465.94378 445.99426 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1324.33 1296.0203 -1537.8694 1508.1082 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4383.9908 4341.7577 -5092.3033 5047.9048 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-14536.058 14473.054 -16886.749 16820.514 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-48232.616 48138.625 -56035.707 55936.896 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-160094.96 159954.74 -185999.94 185852.53 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-531469.91 531260.73 -617474.16 617254.25 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1764446.6 1764134.6 -2049985.9 2049657.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-5858026.5 5857560.9 -6806042.9 6805553.5 MAarrowhead1
% End of user PostScript
1 .536 0 r
.44433 .51149 m
.43654 .51701 L
.42755 .52361 L
.41718 .53148 L
.40519 .54084 L
.39134 .55192 L
.37532 .56503 L
.3568 .5805 L
.33535 .59873 L
.31053 .62017 L
.28178 .64536 L
.24848 .67493 L
.20989 .70959 L
.16517 .75019 L
.11332 .79769 L
.05321 .85325 L
s
.05321 .85325 m
0 .90279 L
s
1 0 0 r
.44433 .51149 m
.43654 .51701 L
s
% Start of user PostScript
-6.6808659 1.3782884 -7.6154914 2.0410449 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42755 .52361 m
.41718 .53148 L
s
% Start of user PostScript
-8.6938566 2.8336021 -9.9388383 3.7781221 MAarrowhead1
% End of user PostScript
1 .473 0 r
.28178 .64536 m
.24848 .67493 L
s
% Start of user PostScript
-26.186056 17.443584 -30.182208 20.991499 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-82.944819 69.902583 -96.007634 82.296708 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-269.42524 249.96851 -312.48967 292.03538 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-885.63016 856.60413 -1028.1531 997.63892 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2927.1287 2883.8269 -3399.6414 3354.1196 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-9698.6174 9634.0188 -11266.4 11198.49 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-32171.017 32074.648 -37374.726 37273.415 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-106767.49 106623.72 -124042.15 123891.02 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-354414.84 354200.37 -411765.37 411539.9 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1176600.7 1176280.7 -1367006.1 1366669.8 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3906305.6 3905828.3 -4538466.4 4537964.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-12969173. 12968461. -15068010. 15067261. MAarrowhead1
% End of user PostScript
.042 1 0 r
.45797 .55467 m
.45082 .56247 L
.44249 .57148 L
.43279 .58189 L
.42151 .59392 L
.40838 .60784 L
.39311 .62395 L
.37534 .64259 L
.35467 .66418 L
.33063 .68919 L
.30267 .71816 L
.27016 .75174 L
.23236 .79066 L
.18841 .83579 L
.13731 .88813 L
.07792 .94883 L
s
.07792 .94883 m
.02774 1 L
s
1 0 0 r
.45797 .55467 m
.45082 .56247 L
s
% Start of user PostScript
-5.0439966 6.5602056 -5.9021972 7.4961439 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44249 .57148 m
.43279 .58189 L
s
% Start of user PostScript
-6.9014328 8.5771028 -8.0646378 9.8262213 MAarrowhead1
% End of user PostScript
1 .473 0 r
.30267 .71816 m
.27016 .75174 L
s
% Start of user PostScript
-23.679467 26.179273 -27.580713 30.208686 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-79.761194 83.490467 -92.772367 96.692843 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-266.52104 272.08446 -309.80705 315.65571 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-887.42391 895.72356 -1031.2689 1039.9941 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2950.1447 2962.5263 -3427.9213 3440.9378 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-9800.4846 9818.9558 -11387.049 11406.467 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-32547.197 32574.753 -37815.21 37844.179 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-108073.1 108114.2 -125564.16 125607.38 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-358834.1 358895.43 -416907.44 416971.92 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1191399.2 1191490.7 -1384210.9 1384307.1 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3955626.5 3955763. -4595786.1 4595929.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-13133205. 13133408. -15258613. 15258827. MAarrowhead1
% End of user PostScript
.388 1 0 r
.54218 .50333 m
.54775 .50009 L
.55416 .49614 L
.56153 .49134 L
.57003 .48556 L
.57983 .47861 L
.59113 .47031 L
.60418 .46041 L
.61925 .44864 L
.63668 .4347 L
.65682 .41821 L
.68013 .39876 L
.7071 .37583 L
.73832 .34886 L
.77448 .31717 L
.81637 .27998 L
.8649 .23639 L
.92116 .18532 L
.98637 .12557 L
s
.98637 .12557 m
1 .11298 L
s
1 0 0 r
.54218 .50333 m
.54775 .50009 L
s
% Start of user PostScript
5.0621066 0.39937106 5.7303692 0.011124359 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55416 .49614 m
.56153 .49134 L
s
% Start of user PostScript
6.4990398 -0.46317353 7.3839708 -1.0386391 MAarrowhead1
% End of user PostScript
1 .473 0 r
.65682 .41821 m
.68013 .39876 L
s
% Start of user PostScript
18.81874 -9.8142857 21.615366 -12.149244 MAarrowhead1
% End of user PostScript
1 .788 0 r
.98637 .12557 m
0 0 rlineto s
.98637 .12557 m
1 .11298 L
s
% Start of user PostScript
58.364724 -44.931657 67.438834 -53.317039 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
187.63781 -167.59803 217.45012 -196.38288 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
613.81984 -583.924 712.33056 -680.90193 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2024.289 -1979.6897 2350.6556 -2303.7696 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6700.4912 -6633.9567 7783.021 -7713.0753 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
22216.003 -22116.745 25808.569 -25704.223 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
73714.36 -73566.284 85639.774 -85484.107 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
244672.61 -244451.71 284262.91 -284030.68 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
812240.71 -811911.16 943679.96 -943333.52 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2696583.5 -2696091.9 3132969.5 -3132452.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
8952747.8 -8952014.4 10401589. -10400818. MAarrowhead1
% End of user PostScript
1 .402 0 r
.51611 .56591 m
.51645 .56977 L
.51673 .57391 L
.51693 .57836 L
.51704 .58314 L
.51703 .58829 L
.51687 .59384 L
.51654 .59985 L
.51601 .60635 L
.51521 .61342 L
.51412 .62111 L
.51267 .62949 L
.51079 .63866 L
.5084 .64871 L
.50542 .65975 L
.50173 .6719 L
.49721 .68532 L
.49172 .70018 L
.48507 .71666 L
.47708 .735 L
.46751 .75544 L
.45609 .7783 L
.4425 .8039 L
.42639 .83265 L
.40731 .865 L
.38479 .90149 L
.35823 .94273 L
.32697 .98942 L
s
.32697 .98942 m
.31962 1 L
s
1 0 0 r
.51611 .56591 m
.51645 .56977 L
s
% Start of user PostScript
1.9334518 7.9088543 1.9743014 8.3726305 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51673 .57391 m
.51693 .57836 L
s
% Start of user PostScript
2.0078136 8.8696168 2.0320859 9.4030424 MAarrowhead1
% End of user PostScript
1 .473 0 r
.51412 .62111 m
.51267 .62949 L
s
% Start of user PostScript
1.6943956 14.532824 1.5200737 15.539133 MAarrowhead1
% End of user PostScript
1 .788 0 r
.48507 .71666 m
.47708 .735 L
s
% Start of user PostScript
-1.7914334 25.9996 -2.7504814 28.199827 MAarrowhead1
% End of user PostScript
.897 1 0 r
.35823 .94273 m
.32697 .98942 L
s
% Start of user PostScript
-17.012669 53.12701 -20.76413 58.730093 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-72.990942 126.86721 -86.292559 142.93112 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-266.96385 347.3378 -312.38934 396.88415 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-923.08797 1042.9918 -1075.7894 1201.8409 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-3119.5648 3298.4403 -3629.3615 3817.4081 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-10439.079 10705.93 -12135.855 12416.388 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-34780.933 35179.028 -40420.683 40839.189 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-115658.72 116252.61 -134392.68 135017.02 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-384271.94 385157.91 -446484.78 447416.18 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1276232.7 1277554.4 -1482807.4 1484196.9 MAarrowhead1
% End of user PostScript
0 .105 1 r
.51034 .54582 m
.51046 .54857 L
.51052 .55154 L
.51051 .55474 L
.5104 .55818 L
.51019 .56191 L
.50985 .56595 L
.50934 .57034 L
.50865 .57512 L
.50774 .58033 L
.50656 .58602 L
.50506 .59227 L
.50319 .59913 L
.50088 .60669 L
.49804 .61503 L
.4946 .62427 L
.49044 .63453 L
.48544 .64594 L
.47945 .65866 L
.47231 .67288 L
.46382 .68882 L
.45374 .70672 L
.44182 .72687 L
.42774 .7496 L
.41115 .77529 L
.39161 .80438 L
.36866 .83739 L
.3417 .8749 L
.3101 .91761 L
.27307 .96631 L
s
.27307 .96631 m
.24682 1 L
s
1 0 0 r
.51034 .54582 m
.51046 .54857 L
s
% Start of user PostScript
1.2404353 5.497945 1.254926 5.8289383 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51052 .55154 m
.51051 .55474 L
s
% Start of user PostScript
1.2622125 6.1848494 1.260639 6.5682419 MAarrowhead1
% End of user PostScript
1 .473 0 r
.50656 .58602 m
.50506 .59227 L
s
% Start of user PostScript
0.78684159 10.322869 0.60709836 11.07222 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47945 .65866 m
.47231 .67288 L
s
% Start of user PostScript
-2.4655434 19.039284 -3.322664 20.746159 MAarrowhead1
% End of user PostScript
.897 1 0 r
.36866 .83739 m
.3417 .8749 L
s
% Start of user PostScript
-15.761303 40.486419 -18.995443 44.988243 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-63.630552 100.51609 -74.9477 113.7244 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-228.12026 283.14702 -266.55891 324.40695 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-782.53718 864.62746 -911.44754 997.74667 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2635.6362 2758.1005 -3065.5574 3194.3006 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-8806.5955 8989.2908 -10236.854 10428.916 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-29322.432 29594.981 -34075.339 34361.862 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-97478.477 97885.073 -113265.07 113692.51 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-323825.79 324432.35 -376248.65 376886.32 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1075416.7 1076321.6 -1249481. 1250432.3 MAarrowhead1
% End of user PostScript
0 1 .711 r
.4975 .50156 m
.49712 .50189 L
.49668 .50228 L
.49617 .50273 L
.49559 .50327 L
.4949 .50389 L
.49411 .50462 L
.49319 .50547 L
.49213 .50647 L
.49089 .50763 L
.48946 .50899 L
.4878 .51057 L
.48587 .51242 L
.48363 .51457 L
.48103 .51708 L
.47801 .52 L
.47451 .5234 L
.47044 .52736 L
.46571 .53198 L
.46023 .53734 L
.45386 .54359 L
.44646 .55085 L
.43788 .5593 L
.4279 .56914 L
.41631 .58057 L
.40286 .59387 L
.38722 .60933 L
.36907 .62731 L
.34798 .64821 L
.32348 .67251 L
.29503 .70076 L
.26197 .7336 L
.22357 .77178 L
.17897 .81614 L
.12715 .86771 L
.06695 .92765 L
s
.06695 .92765 m
0 .99433 L
s
1 0 0 r
.4975 .50156 m
.49712 .50189 L
s
% Start of user PostScript
-0.30001333 0.18733041 -0.34545111 0.22699082 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49668 .50228 m
.49617 .50273 L
s
% Start of user PostScript
-0.3980826 0.27354872 -0.45906378 0.32814491 MAarrowhead1
% End of user PostScript
1 .473 0 r
.48946 .50899 m
.4878 .51057 L
s
% Start of user PostScript
-1.2647597 1.078977 -1.4643059 1.2689979 MAarrowhead1
% End of user PostScript
1 .788 0 r
.46571 .53198 m
.46023 .53734 L
s
% Start of user PostScript
-4.1142337 3.8370785 -4.7723969 4.4810316 MAarrowhead1
% End of user PostScript
.897 1 0 r
.38722 .60933 m
.36907 .62731 L
s
% Start of user PostScript
-13.533057 13.11959 -15.71174 15.277074 MAarrowhead1
% End of user PostScript
.581 1 0 r
.12715 .86771 m
.06695 .92765 L
s
% Start of user PostScript
-44.742347 44.125526 -51.966141 51.317696 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-148.26789 147.3477 -172.23728 171.26991 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-491.84614 490.47338 -571.40574 569.9626 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-1632.3592 1630.3113 -1896.4742 1894.3213 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-5418.6875 5415.6323 -6295.5322 6292.3204 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-17989.28 17984.722 -20900.435 20895.644 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-59724.428 59717.629 -69389.698 69382.55 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-198288.98 198278.83 -230378.64 230367.98 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-658337.95 658322.82 -764879.16 764863.25 MAarrowhead1
% End of user PostScript
.495 0 1 r
.49346 .54123 m
.49144 .54503 L
.48904 .54929 L
.48621 .55409 L
.48287 .5595 L
.47892 .56561 L
.47428 .57254 L
.46882 .5804 L
.46242 .58933 L
.4549 .59949 L
.4461 .61108 L
.4358 .62432 L
.42375 .63945 L
.40966 .65678 L
.3932 .67664 L
.37399 .69943 L
.35157 .72562 L
.32541 .75573 L
.29492 .79039 L
.25937 .83031 L
.21795 .87633 L
.1697 .92942 L
.1135 .99069 L
s
.1135 .99069 m
.1049 1 L
s
1 0 0 r
.49346 .54123 m
.49144 .54503 L
s
% Start of user PostScript
-0.78539913 4.9474741 -1.0275466 5.4030157 MAarrowhead1
% End of user PostScript
1 .158 0 r
.48904 .54929 m
.48621 .55409 L
s
% Start of user PostScript
-1.3147803 5.9145844 -1.6546989 6.4903401 MAarrowhead1
% End of user PostScript
1 .473 0 r
.4461 .61108 m
.4358 .62432 L
s
% Start of user PostScript
-6.4676708 13.329772 -7.7040352 14.917964 MAarrowhead1
% End of user PostScript
1 .788 0 r
.29492 .79039 m
.25937 .83031 L
s
% Start of user PostScript
-24.609905 34.846957 -28.87559 39.637508 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-86.386842 101.65873 -100.78932 116.84421 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-293.79479 316.57777 -341.97058 365.92167 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-985.84653 1019.8347 -1146.3297 1182.0605 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3288.6608 3339.3653 -3822.2803 3875.5844 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-10941.914 11017.556 -12714.781 12794.302 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-36363.008 36475.853 -42250.907 42369.538 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-120781.02 120949.36 -140332.17 140509.15 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-401084.05 401335.19 -466000.12 466264.14 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1331760.7 1332135.4 -1547295.6 1547689.4 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-4421772.5 4422331.5 -5137382.2 5137969.8 MAarrowhead1
% End of user PostScript
0 .715 1 r
.53808 .58176 m
.54093 .58505 L
.54407 .58837 L
.54755 .59169 L
.55139 .59498 L
.55566 .59822 L
.56042 .60135 L
.56572 .60434 L
.57166 .60712 L
.57831 .60963 L
.58579 .61179 L
.59422 .6135 L
.60372 .61464 L
.61447 .61509 L
.62665 .61468 L
.64048 .61323 L
.6562 .61051 L
.67411 .60628 L
.69453 .60023 L
.71787 .59201 L
.74456 .5812 L
.77514 .56733 L
.8102 .54983 L
.85045 .52804 L
.8967 .50119 L
.9499 .46839 L
s
.9499 .46839 m
1 .43583 L
s
1 0 0 r
.53808 .58176 m
.54093 .58505 L
s
% Start of user PostScript
4.5698078 9.8111744 4.9118576 10.206453 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54407 .58837 m
.54755 .59169 L
s
% Start of user PostScript
5.2888823 10.604561 5.7054973 11.00282 MAarrowhead1
% End of user PostScript
1 .473 0 r
.58579 .61179 m
.59422 .6135 L
s
% Start of user PostScript
10.295243 13.414988 11.305996 13.619884 MAarrowhead1
% End of user PostScript
1 .788 0 r
.69453 .60023 m
.71787 .59201 L
s
% Start of user PostScript
23.344103 12.027406 26.144281 11.040763 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
61.337786 -8.5696964 69.805789 -14.332221 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
179.52975 -100.80901 206.40791 -123.65107 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
560.07863 -442.64109 647.47247 -524.01377 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1805.849 -1630.6528 2093.2547 -1909.0759 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
5915.5524 -5654.1903 6865.6671 -6590.9047 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
19520.864 -19130.958 22669.231 -22259.334 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
64633.335 -64051.663 75077.144 -74465.649 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
214324.36 -213456.61 248985.4 -248073.16 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
711185.32 -709890.79 826243.68 -824882.77 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2360626.7 -2358695.5 2742603.6 -2740573.3 MAarrowhead1
% End of user PostScript
0 .897 1 r
.46272 .51075 m
.45742 .51469 L
.45129 .51938 L
.44422 .52495 L
.43605 .53154 L
.42659 .53933 L
.41566 .54852 L
.403 .55935 L
.38834 .57207 L
.37136 .58702 L
.3517 .60455 L
.32891 .6251 L
.30249 .64916 L
.27186 .67731 L
.23634 .71022 L
.19515 .74867 L
.14737 .79357 L
.09194 .84598 L
.02761 .90712 L
s
.02761 .90712 m
0 .93349 L
s
1 0 0 r
.46272 .51075 m
.45742 .51469 L
s
% Start of user PostScript
-4.4741292 1.2898014 -5.1101792 1.7625875 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45129 .51938 m
.44422 .52495 L
s
% Start of user PostScript
-5.8446512 2.3254247 -6.6932417 2.9935806 MAarrowhead1
% End of user PostScript
1 .473 0 r
.3517 .60455 m
.32891 .6251 L
s
% Start of user PostScript
-17.796382 12.546313 -20.531329 15.012084 MAarrowhead1
% End of user PostScript
1 .788 0 r
.02761 .90712 m
0 0 rlineto s
.02761 .90712 m
0 .93349 L
s
% Start of user PostScript
-56.686403 48.85422 -65.643716 57.409969 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-184.6256 172.94136 -214.18139 201.89808 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-607.63804 590.2072 -705.49288 687.16834 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2009.4622 1983.4584 -2333.9432 2306.6062 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6659.7638 6620.9707 -7736.4693 7695.6873 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-22093.463 22035.591 -25667.342 25606.503 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-73326.429 73240.093 -85190.77 85100.008 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-243412.86 243284.06 -282801.83 282666.43 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-808100.27 807908.13 -938873.26 938671.26 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2682899.6 2682612.9 -3117076.7 3116775.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-8907409.2 8906981.6 -10348921. 10348472. MAarrowhead1
% End of user PostScript
1 0 .639 r
.46034 .54491 m
.45378 .55174 L
.44615 .55966 L
.43727 .56883 L
.42695 .57946 L
.41495 .59179 L
.401 .60609 L
.38479 .62267 L
.36593 .6419 L
.34402 .66422 L
.31855 .69011 L
.28895 .72016 L
.25454 .75503 L
.21455 .79551 L
.16808 .8425 L
.11407 .89705 L
.05131 .96038 L
s
.05131 .96038 m
.01201 1 L
s
1 0 0 r
.46034 .54491 m
.45378 .55174 L
s
% Start of user PostScript
-4.7588003 5.3890574 -5.546358 6.2089291 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44615 .55966 m
.43727 .56883 L
s
% Start of user PostScript
-6.4622626 7.1588044 -7.5273309 8.2595852 MAarrowhead1
% End of user PostScript
1 .473 0 r
.31855 .69011 m
.28895 .72016 L
s
% Start of user PostScript
-21.773838 22.812956 -25.326313 26.418708 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-72.766641 74.316823 -84.585623 86.215285 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-242.3023 244.6149 -281.57903 284.0102 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-805.529 808.97899 -935.98654 939.61342 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2676.0274 2681.1742 -3109.2425 3114.6532 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-8887.0762 8894.7543 -10325.522 10333.593 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-29509.642 29521.096 -34285.629 34297.67 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-97980.696 97997.784 -113837.8 113855.76 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-325315.18 325340.67 -377963.02 377989.82 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1080096.1 1080134.1 -1254893.7 1254933.6 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3586062.6 3586119.4 -4166411.9 4166471.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-11906173. 11906258. -13833002. 13833091. MAarrowhead1
% End of user PostScript
1 0 .666 r
.55438 .46192 m
.56273 .45441 L
.5724 .44561 L
.58362 .43531 L
.59663 .42328 L
.61172 .40921 L
.62922 .39278 L
.64953 .3736 L
.67309 .35123 L
.70043 .32514 L
.73215 .29472 L
.76898 .25927 L
.81173 .21797 L
.86136 .16986 L
.91898 .11385 L
.98587 .04863 L
s
.98587 .04863 m
1 .03483 L
s
1 0 0 r
.55438 .46192 m
.56273 .45441 L
s
% Start of user PostScript
6.5251715 -4.5692282 7.5271038 -5.4708773 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5724 .44561 m
.58362 .43531 L
s
% Start of user PostScript
8.6884113 -6.5267597 10.034744 -7.7622622 MAarrowhead1
% End of user PostScript
1 .473 0 r
.73215 .29472 m
.76898 .25927 L
s
% Start of user PostScript
27.858509 -24.633703 32.277833 -28.887689 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
91.019534 -86.20869 105.61664 -100.55913 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
299.99659 -292.81965 348.34793 -340.80303 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
992.74337 -982.03664 1153.1073 -1141.8516 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3291.1303 -3275.1577 3823.3064 -3806.5149 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
10919.637 -10895.808 12686.149 -12661.099 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
36243.579 -36208.032 42108.049 -42070.679 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
120316.67 -120263.64 139786.57 -139730.82 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
399441.19 -399362.07 464082.26 -463999.09 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1326155.3 -1326037.3 1540769.4 -1540645.3 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4402936.6 -4402760.6 5115477.7 -5115292.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
14618184. -14617921. 16983899. -16983623. MAarrowhead1
% End of user PostScript
.202 1 0 r
.56868 .47284 m
.57865 .46501 L
.59017 .45572 L
.60349 .44475 L
.61891 .43181 L
.63675 .41657 L
.6574 .39865 L
.68133 .3776 L
.70904 .3529 L
.74116 .32396 L
.77839 .29007 L
.82155 .25042 L
.8716 .20406 L
.92965 .14989 L
.99698 .08664 L
s
.99698 .08664 m
1 .08379 L
s
1 0 0 r
.56868 .47284 m
.57865 .46501 L
s
% Start of user PostScript
8.2415573 -3.2586413 9.4375918 -4.1991962 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59017 .45572 m
.60349 .44475 L
s
% Start of user PostScript
10.820124 -5.31315 12.418973 -6.6296509 MAarrowhead1
% End of user PostScript
1 .473 0 r
.77839 .29007 m
.82155 .25042 L
s
% Start of user PostScript
33.406987 -25.191547 38.5863 -29.949646 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
107.16005 -94.904051 124.16345 -111.27907 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
350.182 -331.8982 406.34806 -387.12683 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1154.2882 -1127.0119 1340.3376 -1311.6629 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3819.9044 -3779.2131 4436.971 -4394.1934 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
12663.93 -12603.226 14711.71 -14647.893 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
42017.983 -41927.423 48815.429 -48720.225 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
139463.22 -139328.12 162029.42 -161887.39 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
462972.46 -462770.92 537891.69 -537679.81 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1537030.6 -1536729.9 1785766.5 -1785450.4 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
5102983.8 -5102535.3 5928808.9 -5928337.4 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
16942298. -16941629. 19684123. -19683420. MAarrowhead1
% End of user PostScript
.357 0 1 r
.51452 .57518 m
.5144 .5799 L
.51412 .58502 L
.51366 .59055 L
.51299 .59657 L
.51207 .60311 L
.51084 .61024 L
.50925 .61804 L
.50722 .62659 L
.50469 .63598 L
.50157 .64633 L
.49773 .65774 L
.49307 .67038 L
.48743 .6844 L
.48064 .69999 L
.47252 .71738 L
.46282 .73681 L
.45129 .75858 L
.4376 .78303 L
.42141 .81053 L
.40228 .84156 L
.37972 .87661 L
.35317 .91631 L
.32196 .96133 L
s
.32196 .96133 m
.29427 1 L
s
1 0 0 r
.51452 .57518 m
.5144 .5799 L
s
% Start of user PostScript
1.7429725 9.0210827 1.7275182 9.5884219 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51412 .58502 m
.51366 .59055 L
s
% Start of user PostScript
1.6943083 10.201812 1.6396873 10.866361 MAarrowhead1
% End of user PostScript
1 .473 0 r
.50157 .64633 m
.49773 .65774 L
s
% Start of user PostScript
0.18790538 17.559021 -0.27222411 18.929055 MAarrowhead1
% End of user PostScript
1 .788 0 r
.4376 .78303 m
.42141 .81053 L
s
% Start of user PostScript
-7.4877742 33.963078 -9.4313507 37.264072 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-36.961434 76.457945 -44.034774 85.556315 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-140.76907 199.69094 -165.17898 227.12184 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-494.30138 582.20248 -576.72593 669.13382 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1681.3156 1812.4486 -1957.0347 2094.891 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-5642.1018 5837.7293 -6560.5943 6766.2519 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-18821.854 19113.696 -21875.941 22182.746 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-62624.148 63059.525 -72770.914 73228.613 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-208118.49 208768. -241817.14 242499.95 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-691274.6 692243.55 -803173.28 804191.91 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2295555.4 2297000.9 -2667094.8 2668614.4 MAarrowhead1
% End of user PostScript
0 .614 1 r
.47481 .42791 m
.47342 .4243 L
.47195 .42054 L
.47038 .41659 L
.46871 .41246 L
.46694 .40815 L
.46504 .40364 L
.46301 .39894 L
.46084 .39403 L
.45851 .38892 L
.45602 .38359 L
.45333 .37805 L
.45044 .3723 L
.44732 .36633 L
.44394 .36016 L
.44028 .35377 L
.43631 .34718 L
.43199 .3404 L
.42728 .33345 L
.42212 .32634 L
.41647 .31909 L
.41026 .31174 L
.40342 .30433 L
.39587 .29689 L
.38751 .2895 L
.37823 .28222 L
.36791 .27513 L
.3564 .26834 L
.34354 .26196 L
.32912 .25615 L
.31293 .25108 L
.29471 .24695 L
.27415 .244 L
.25092 .24253 L
.22461 .24287 L
.19477 .24541 L
.16084 .25063 L
.12222 .25908 L
.07819 .27139 L
.0279 .28833 L
s
.0279 .28833 m
0 .29922 L
s
1 0 0 r
.47481 .42791 m
.47342 .4243 L
s
% Start of user PostScript
-3.0225516 -8.6513513 -3.1890281 -9.0834086 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47195 .42054 m
.47038 .41659 L
s
% Start of user PostScript
-3.3659022 -9.5357557 -3.5540085 -10.009132 MAarrowhead1
% End of user PostScript
1 .473 0 r
.45602 .38359 m
.45333 .37805 L
s
% Start of user PostScript
-5.2781888 -13.968823 -5.6003779 -14.63345 MAarrowhead1
% End of user PostScript
1 .788 0 r
.42728 .33345 m
.42212 .32634 L
s
% Start of user PostScript
-8.7269132 -19.986255 -9.345572 -20.839751 MAarrowhead1
% End of user PostScript
.897 1 0 r
.36791 .27513 m
.3564 .26834 L
s
% Start of user PostScript
-15.850357 -26.984656 -17.231494 -27.799717 MAarrowhead1
% End of user PostScript
.581 1 0 r
.22461 .24287 m
.19477 .24541 L
s
% Start of user PostScript
-33.046308 -30.856023 -36.628021 -30.550652 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-80.509572 -14.821503 -90.903751 -9.3150519 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-223.72793 81.510674 -256.00377 106.49488 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-677.7992 465.63599 -781.62596 558.58491 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-2153.3985 1836.8882 -2493.1435 2160.4054 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-7004.8665 6532.6886 -8125.4424 7629.0554 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-23041.156 22336.749 -26750.534 26010.011 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-76177.366 75126.515 -88476.426 87371.697 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-252437.45 250869.76 -293247.14 291599.08 MAarrowhead1
% End of user PostScript
.524 1 0 r
.55149 .45915 m
.55952 .45166 L
.56885 .44291 L
.57966 .4327 L
.59222 .42078 L
.60678 .40688 L
.62368 .39068 L
.6433 .3718 L
.66608 .3498 L
.69251 .32417 L
.72321 .29434 L
.75885 .2596 L
.80023 .21916 L
.84828 .17211 L
.90408 .11735 L
.96888 .05365 L
s
.96888 .05365 m
1 .023 L
s
1 0 0 r
.55149 .45915 m
.55952 .45166 L
s
% Start of user PostScript
6.1783287 -4.9014261 7.1428993 -5.8005284 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56885 .44291 m
.57966 .4327 L
s
% Start of user PostScript
8.2617608 -6.8505651 9.55979 -8.0762408 MAarrowhead1
% End of user PostScript
1 .473 0 r
.72321 .29434 m
.75885 .2596 L
s
% Start of user PostScript
26.784992 -24.679736 31.06153 -28.848335 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
87.96705 -84.826376 102.11632 -98.814621 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
290.62537 -285.94004 337.52901 -332.60345 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
962.76868 -955.77898 1118.3844 -1111.0364 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3193.3098 -3182.8824 3709.8084 -3698.8464 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
10597.396 -10581.84 12311.987 -12295.634 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
35177.483 -35154.276 40869.763 -40845.366 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
116782.75 -116748.13 135681.24 -135644.85 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
387716.56 -387664.91 450460.95 -450406.65 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1287240.7 -1287163.7 1495558.2 -1495477.2 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4273754.4 -4273639.5 4965391. -4965270.2 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
14189312. -14189140. 16485624. -16485443. MAarrowhead1
% End of user PostScript
1 0 .234 r
.56472 .51899 m
.57288 .51512 L
.58224 .51027 L
.593 .50426 L
.60536 .49688 L
.61958 .4879 L
.63596 .47703 L
.65485 .46394 L
.67662 .44826 L
.70175 .42953 L
.73077 .40724 L
.76431 .38078 L
.80307 .34946 L
.8479 .31245 L
.89977 .2688 L
.95981 .2174 L
s
.95981 .2174 m
1 .18246 L
s
1 0 0 r
.56472 .51899 m
.57288 .51512 L
s
% Start of user PostScript
7.7665349 2.2784761 8.7457742 1.8142555 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58224 .51027 m
.593 .50426 L
s
% Start of user PostScript
9.8692524 1.2322016 11.159582 0.51105527 MAarrowhead1
% End of user PostScript
1 .473 0 r
.73077 .40724 m
.76431 .38078 L
s
% Start of user PostScript
27.692896 -11.131473 31.716785 -14.306239 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
84.373874 -59.667133 97.345542 -71.37206 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
268.83834 -231.98022 311.3268 -272.57892 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
875.72787 -820.74201 1015.9308 -958.12573 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2882.3864 -2800.3571 3346.5878 -3260.3528 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9532.3664 -9409.9931 11071.647 -10943. MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
31592.637 -31410.078 36700.362 -36508.442 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
104807.81 -104535.46 121761.77 -121475.46 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
347849.69 -347443.4 404132.45 -403705.33 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1154715.9 -1154109.8 1341571.8 -1340934.6 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3833514.9 -3832610.7 4453883.9 -4452933.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
12727304. -12725955. 14786981. -14785563. MAarrowhead1
% End of user PostScript
0 1 .365 r
.56645 .57875 m
.57319 .57945 L
.58082 .57965 L
.58946 .57923 L
.59928 .57807 L
.61044 .576 L
.62316 .57284 L
.63768 .56837 L
.65426 .56235 L
.67324 .55448 L
.69498 .54441 L
.71992 .53175 L
.74855 .51602 L
.78146 .49667 L
.81932 .47307 L
.86292 .44446 L
.91316 .40999 L
.97109 .36862 L
s
.97109 .36862 m
1 .34724 L
s
1 0 0 r
.56645 .57875 m
.57319 .57945 L
s
% Start of user PostScript
7.9741656 9.4495291 8.783054 9.5339726 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58082 .57965 m
.58946 .57923 L
s
% Start of user PostScript
9.6981559 9.5580048 10.735394 9.508051 MAarrowhead1
% End of user PostScript
1 .473 0 r
.69498 .54441 m
.71992 .53175 L
s
% Start of user PostScript
23.397539 5.3292767 26.390031 3.8096408 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
64.552313 -21.696939 73.814531 -28.761915 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
194.73319 -130.80048 224.48054 -157.26993 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
617.31504 -521.93865 714.58147 -614.31503 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2005.9641 -1863.6793 2326.665 -2177.085 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6595.0009 -6382.7368 7656.4307 -7433.2837 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
21799.154 -21482.493 25318.251 -24985.354 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
72231.003 -71758.6 83907.395 -83410.772 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
239599.45 -238894.71 278355.37 -277614.49 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
795176.08 -794124.73 923833.73 -922728.48 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2639597. -2638028.6 3066730.8 -3065082. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
8763053.8 -8760714. 10181151. -10178692. MAarrowhead1
% End of user PostScript
.862 0 1 r
.45725 .49687 m
.4516 .50016 L
.4451 .50419 L
.43762 .50907 L
.42899 .51496 L
.41905 .52203 L
.40758 .53048 L
.39433 .54055 L
.37903 .55251 L
.36135 .56669 L
.3409 .58345 L
.31724 .60322 L
.28986 .62653 L
.25817 .65393 L
.22146 .68613 L
.17894 .72392 L
.12967 .76821 L
.07255 .82009 L
.00635 .88079 L
s
.00635 .88079 m
0 .88666 L
s
1 0 0 r
.45725 .49687 m
.4516 .50016 L
s
% Start of user PostScript
-5.1301788 -0.37615605 -5.808218 0.019567299 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4451 .50419 m
.43762 .50907 L
s
% Start of user PostScript
-6.5881837 0.50274253 -7.4861711 1.0887226 MAarrowhead1
% End of user PostScript
1 .473 0 r
.3409 .58345 m
.31724 .60322 L
s
% Start of user PostScript
-19.092049 10.013638 -21.930862 12.38699 MAarrowhead1
% End of user PostScript
1 .788 0 r
.00635 .88079 m
0 0 rlineto s
.00635 .88079 m
0 .88666 L
s
% Start of user PostScript
-59.238338 45.694939 -68.450779 54.212996 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-190.48789 170.28351 -220.75688 199.51661 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-623.20718 593.06579 -723.23031 691.54354 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2055.3439 2010.3782 -2386.726 2339.4549 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6803.4294 6736.3485 -7902.6031 7832.0829 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-22557.52 22457.447 -26205.333 26100.13 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-74847.864 74698.573 -86956.685 86799.739 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-248435.42 248212.71 -288634.62 288400.49 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-824732.85 824400.6 -958193.69 957844.4 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2738057.6 2737562. -3181155.4 3180634.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-9090444.9 9089705.5 -10561570. 10560792. MAarrowhead1
% End of user PostScript
1 0 .718 r
.55259 .55285 m
.55819 .55266 L
.56454 .55199 L
.57177 .55074 L
.58 .5488 L
.58938 .54601 L
.60011 .54223 L
.61237 .53726 L
.62642 .53089 L
.64253 .52284 L
.66103 .51282 L
.68228 .50048 L
.70673 .48541 L
.73488 .46711 L
.7673 .44504 L
.80469 .41854 L
.84783 .38684 L
.89764 .34907 L
.95517 .30419 L
s
.95517 .30419 m
1 .26832 L
s
1 0 0 r
.55259 .55285 m
.55819 .55266 L
s
% Start of user PostScript
6.3112699 6.3423274 6.9828941 6.319467 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56454 .55199 m
.57177 .55074 L
s
% Start of user PostScript
7.7452777 6.2391099 8.6121894 6.0891932 MAarrowhead1
% End of user PostScript
1 .473 0 r
.66103 .51282 m
.68228 .50048 L
s
% Start of user PostScript
19.323341 1.5389141 21.87387 0.058015644 MAarrowhead1
% End of user PostScript
1 .788 0 r
.95517 .30419 m
0 0 rlineto s
.95517 .30419 m
1 .26832 L
s
% Start of user PostScript
54.620176 -23.497349 62.599332 -29.880803 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
167.11997 -120.69016 192.88234 -144.07203 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
533.63602 -464.37089 618.08205 -545.26563 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1740.0747 -1636.7433 2018.8223 -1910.1929 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5730.0216 -5575.8692 6653.0744 -6491.0185 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
18953.883 -18723.914 22014.914 -21773.155 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
62823.995 -62480.922 72981.586 -72620.923 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
208426.2 -207914.39 242142.55 -241604.5 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
691765.42 -691001.9 803695.65 -802892.98 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2296393.1 -2295254. 2667996.6 -2666799.2 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
7623772.9 -7622073.7 8857513.5 -8855727.1 MAarrowhead1
% End of user PostScript
0 1 .487 r
.50559 .54648 m
.50506 .54969 L
.50437 .55319 L
.50348 .55702 L
.50237 .56123 L
.501 .56587 L
.49931 .57098 L
.49726 .57664 L
.49477 .58292 L
.49178 .58989 L
.48819 .59767 L
.48391 .60636 L
.47881 .61608 L
.47276 .627 L
.46559 .63928 L
.45712 .65313 L
.44713 .66877 L
.43538 .68647 L
.42155 .70654 L
.40531 .72934 L
.38627 .75529 L
.36395 .78487 L
.33782 .81863 L
.30725 .85722 L
.27151 .9014 L
.22975 .95202 L
s
.22975 .95202 m
.18947 1 L
s
1 0 0 r
.50559 .54648 m
.50506 .54969 L
s
% Start of user PostScript
0.67139184 5.5778831 0.60731115 5.9623709 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50437 .55319 m
.50348 .55702 L
s
% Start of user PostScript
0.52400371 6.3825132 0.4179039 6.8427177 MAarrowhead1
% End of user PostScript
1 .473 0 r
.48819 .59767 m
.48391 .60636 L
s
% Start of user PostScript
-1.4170292 11.720342 -1.9311447 12.762719 MAarrowhead1
% End of user PostScript
1 .788 0 r
.42155 .70654 m
.40531 .72934 L
s
% Start of user PostScript
-9.4140691 24.784805 -11.362447 27.521258 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-38.281359 61.211803 -45.11041 69.216522 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-137.57948 171.78768 -160.79009 196.75218 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-472.4156 523.44824 -550.2792 603.92834 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1591.8007 1667.9324 -1851.5129 1931.548 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-5319.7621 5433.3373 -6183.8211 6303.2194 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-17714.144 17883.579 -20585.583 20763.704 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-58890.474 59143.241 -68427.956 68693.682 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-195638.79 196015.88 -227310.27 227706.69 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-649716.02 650278.56 -754877.87 755469.26 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2157390.3 2158229.5 -2506553.1 2507435.3 MAarrowhead1
% End of user PostScript
0 .011 1 r
.50833 .53451 m
.50849 .53654 L
.50862 .53872 L
.50871 .54106 L
.50874 .54358 L
.50871 .54629 L
.5086 .54922 L
.50839 .5524 L
.50807 .55583 L
.50761 .55957 L
.50698 .56364 L
.50616 .56808 L
.50511 .57295 L
.50378 .57828 L
.50212 .58414 L
.50008 .59061 L
.49758 .59775 L
.49456 .60566 L
.49091 .61445 L
.48652 .62424 L
.48128 .63516 L
.47503 .64738 L
.46761 .66108 L
.45881 .67648 L
.4484 .69382 L
.43612 .71339 L
.42165 .73553 L
.40462 .76061 L
.38462 .78909 L
.36115 .82147 L
.33363 .85835 L
.3014 .90042 L
.26368 .94849 L
s
.26368 .94849 m
.22236 1 L
s
1 0 0 r
.50833 .53451 m
.50849 .53654 L
s
% Start of user PostScript
0.9993007 4.1409703 1.0189406 4.3848777 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50862 .53872 m
.50871 .54106 L
s
% Start of user PostScript
1.0344743 4.6464037 1.0448638 4.9272791 MAarrowhead1
% End of user PostScript
1 .473 0 r
.50698 .56364 m
.50616 .56808 L
s
% Start of user PostScript
0.83799944 7.6368747 0.73936426 8.170026 MAarrowhead1
% End of user PostScript
1 .788 0 r
.49091 .61445 m
.48652 .62424 L
s
% Start of user PostScript
-1.0913805 13.734407 -1.6174665 14.908715 MAarrowhead1
% End of user PostScript
.897 1 0 r
.42165 .73553 m
.40462 .76061 L
s
% Start of user PostScript
-9.4022977 28.263477 -11.445249 31.273462 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-39.837665 67.975238 -47.062508 76.642725 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-145.12663 187.10296 -169.77335 213.90185 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-501.02363 563.64495 -583.83731 649.6693 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-1692.0796 1785.4996 -1968.4982 2066.708 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-5660.6018 5799.9681 -6580.5331 6727.0449 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-18857.56 19065.47 -21915.106 22133.676 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-62704.335 63014.501 -72860.617 73186.685 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-208327.49 208790.2 -242054.8 242541.24 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-691883.13 692573.41 -803872.59 804598.27 MAarrowhead1
% End of user PostScript
.052 0 1 r
.525 .51127 m
.52805 .51009 L
.53153 .50856 L
.53553 .50662 L
.54011 .50419 L
.54538 .5012 L
.55143 .49753 L
.5584 .49307 L
.56643 .48768 L
.57569 .4812 L
.58637 .47344 L
.59869 .46418 L
.61292 .45317 L
.62937 .44011 L
.64839 .42465 L
.67038 .4064 L
.69583 .38489 L
.7253 .35957 L
.75941 .3298 L
.79893 .29486 L
.84471 .25389 L
.89777 .20588 L
.95928 .14969 L
s
.95928 .14969 m
1 .11216 L
s
1 0 0 r
.525 .51127 m
.52805 .51009 L
s
% Start of user PostScript
3.0003576 1.3523013 3.3656073 1.2102172 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53153 .50856 m
.53553 .50662 L
s
% Start of user PostScript
3.7837984 1.0266336 4.2631825 0.79388572 MAarrowhead1
% End of user PostScript
1 .473 0 r
.58637 .47344 m
.59869 .46418 L
s
% Start of user PostScript
10.363934 -3.187613 11.842815 -4.2985554 MAarrowhead1
% End of user PostScript
1 .788 0 r
.75941 .3298 m
.79893 .29486 L
s
% Start of user PostScript
31.129371 -20.423557 35.871252 -24.61654 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
98.459812 -82.488615 113.95252 -97.162467 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
319.59808 -295.77186 370.66142 -345.6136 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1050.2127 -1014.6681 1219.1906 -1181.8236 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3470.5824 -3417.5562 4030.7758 -3975.0309 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
11498.503 -11419.397 13357.167 -13274.006 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
38140.216 -38022.204 44309.347 -44185.284 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
126576.04 -126399.98 147055.51 -146870.43 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
420166.77 -419904.13 488156.88 -487880.77 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1394882.8 -1394490.9 1620611.7 -1620199.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4630994.8 -4630410.2 5380432.1 -5379817.6 MAarrowhead1
% End of user PostScript
0 .312 1 r
.54348 .52992 m
.54849 .52867 L
.5542 .52692 L
.56073 .52455 L
.56821 .52145 L
.57677 .51748 L
.58658 .5125 L
.59786 .5063 L
.61081 .49869 L
.62572 .48939 L
.64289 .47813 L
.66266 .46456 L
.68547 .44827 L
.71179 .42881 L
.74218 .40563 L
.77729 .3781 L
.81787 .34549 L
.86479 .30694 L
.91908 .26145 L
.98192 .20788 L
s
.98192 .20788 m
1 .19221 L
s
1 0 0 r
.54348 .52992 m
.54849 .52867 L
s
% Start of user PostScript
5.217801 3.5903109 5.8187568 3.4409567 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5542 .52692 m
.56073 .52455 L
s
% Start of user PostScript
6.5044851 3.229984 7.2880651 2.9455009 MAarrowhead1
% End of user PostScript
1 .473 0 r
.64289 .47813 m
.66266 .46456 L
s
% Start of user PostScript
17.146288 -2.624166 19.519741 -4.2530545 MAarrowhead1
% End of user PostScript
1 .788 0 r
.91908 .26145 m
.98192 .20788 L
s
% Start of user PostScript
50.290009 -28.625549 57.829832 -35.054612 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
157.06647 -124.74689 181.59186 -147.61523 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
506.70663 -458.49149 587.37641 -536.68923 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1660.2874 -1588.3589 1926.9906 -1851.3742 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5479.4718 -5372.167 6363.272 -6250.4656 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
18143.441 -17983.361 21075.246 -20906.959 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
60165.177 -59926.366 69895.362 -69644.307 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
199646.27 -199290. 231946.02 -231571.49 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
662686.11 -662154.63 769916.73 -769358. MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2199952.5 -2199159.6 2555958.2 -2555124.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
7303737. -7302554.1 8485699. -8484455.5 MAarrowhead1
% End of user PostScript
0 .567 1 r
.48947 .53839 m
.48699 .5423 L
.48408 .54671 L
.48065 .55172 L
.47662 .55741 L
.4719 .56388 L
.46636 .57125 L
.45988 .57966 L
.45229 .58927 L
.44342 .60027 L
.43306 .61288 L
.42095 .62733 L
.40683 .64394 L
.39035 .66302 L
.37112 .68498 L
.34872 .71026 L
.3226 .7394 L
.29218 .773 L
.25675 .81178 L
.21549 .85655 L
.16745 .90828 L
.11154 .96807 L
s
.11154 .96807 m
.0815 1 L
s
1 0 0 r
.48947 .53839 m
.48699 .5423 L
s
% Start of user PostScript
-1.2641089 4.60729 -1.5610932 5.0756828 MAarrowhead1
% End of user PostScript
1 .158 0 r
.48408 .54671 m
.48065 .55172 L
s
% Start of user PostScript
-1.9108775 5.605664 -2.3222498 6.206472 MAarrowhead1
% End of user PostScript
1 .473 0 r
.43306 .61288 m
.42095 .62733 L
s
% Start of user PostScript
-8.0331242 13.545098 -9.4855141 15.280093 MAarrowhead1
% End of user PostScript
1 .788 0 r
.25675 .81178 m
.21549 .85655 L
s
% Start of user PostScript
-29.190286 37.413185 -34.141562 42.786057 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-100.67363 112.94075 -117.30514 130.20121 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-339.85519 358.15559 -395.36123 414.59991 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1136.7236 1164.0246 -1321.439 1350.1397 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3786.5338 3827.262 -4400.4503 4443.2668 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-12590.351 12651.11 -14629.58 14693.455 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-41829.208 41919.85 -48601.111 48696.401 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-138919.29 139054.51 -161404.93 161547.08 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-461290.09 461491.82 -535948.2 536160.27 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1531629.3 1531930.2 -1779507.6 1779824. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-5085325.7 5085774.7 -5908318. 5908790. MAarrowhead1
% End of user PostScript
0 .641 1 r
.45363 .46731 m
.44831 .46858 L
.44224 .47039 L
.43531 .47284 L
.42738 .47606 L
.41829 .48019 L
.40788 .4854 L
.39592 .49189 L
.38218 .49988 L
.36637 .50964 L
.34817 .52148 L
.3272 .53577 L
.30302 .55292 L
.27513 .57343 L
.24292 .59787 L
.20572 .62691 L
.16272 .66133 L
.113 .70203 L
.05548 .75007 L
s
.05548 .75007 m
0 .79724 L
s
1 0 0 r
.45363 .46731 m
.44831 .46858 L
s
% Start of user PostScript
-5.5646438 -3.9225087 -6.2029613 -3.7706079 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44224 .47039 m
.43531 .47284 L
s
% Start of user PostScript
-6.9311356 -3.5537895 -7.7630191 -3.2594796 MAarrowhead1
% End of user PostScript
1 .473 0 r
.34817 .52148 m
.3272 .53577 L
s
% Start of user PostScript
-18.219804 2.5781337 -20.736044 4.2924082 MAarrowhead1
% End of user PostScript
1 .788 0 r
.05548 .75007 m
0 0 rlineto s
.05548 .75007 m
0 .79724 L
s
% Start of user PostScript
-53.342493 30.007863 -61.330147 36.799126 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-166.43768 131.62651 -192.41079 155.81481 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-536.68132 484.74914 -622.09929 567.50449 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1758.1079 1680.6342 -2040.4886 1959.0427 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5801.7127 5686.1356 -6737.4339 6615.9309 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-19209.537 19037.117 -22313.533 22132.271 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-63699.101 63441.88 -74000.687 73730.278 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-211370.9 210987.17 -245567.34 245163.93 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-701600.69 701028.24 -815127.89 814526.08 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2329134.7 2328280.7 -2706044.8 2705147. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-7732609.1 7731335.1 -8983974.9 8982635.5 MAarrowhead1
% End of user PostScript
1 .753 0 r
.50658 .50775 m
.50724 .50781 L
.508 .50783 L
.50886 .50779 L
.50983 .50767 L
.51094 .50745 L
.5122 .50714 L
.51364 .50669 L
.51528 .50608 L
.51717 .5053 L
.51933 .50429 L
.5218 .50303 L
.52464 .50146 L
.52791 .49953 L
.53167 .49718 L
.53599 .49433 L
.54098 .4909 L
.54673 .48678 L
.55337 .48186 L
.56103 .47601 L
.56988 .46905 L
.58012 .46082 L
.59195 .45108 L
.60564 .4396 L
.62149 .42607 L
.63983 .41016 L
.66108 .39148 L
.6857 .36956 L
.71422 .34386 L
.74729 .31378 L
.78562 .27858 L
.83007 .23742 L
.88162 .18933 L
.94142 .13317 L
s
.94142 .13317 m
1 .07782 L
s
1 0 0 r
.50658 .50775 m
.50724 .50781 L
s
% Start of user PostScript
0.78908652 0.92982738 0.86927561 0.93776889 MAarrowhead1
% End of user PostScript
1 .158 0 r
.508 .50783 m
.50886 .50779 L
s
% Start of user PostScript
0.96000604 0.93968762 1.0628589 0.93423417 MAarrowhead1
% End of user PostScript
1 .473 0 r
.51933 .50429 m
.5218 .50303 L
s
% Start of user PostScript
2.3190335 0.5149764 2.6159983 0.36331443 MAarrowhead1
% End of user PostScript
1 .788 0 r
.55337 .48186 m
.56103 .47601 L
s
% Start of user PostScript
6.4041128 -2.1762669 7.3236566 -2.8790443 MAarrowhead1
% End of user PostScript
.897 1 0 r
.66108 .39148 m
.6857 .36956 L
s
% Start of user PostScript
19.329969 -13.022764 22.283884 -15.653301 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
61.294903 -51.885659 70.954439 -61.062772 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
199.20553 -185.16859 231.05582 -216.29919 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
654.96976 -634.0291 760.38748 -738.37317 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
2165.0048 -2133.765 2514.5132 -2481.6717 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
7173.7901 -7127.1858 8333.4668 -8284.473 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
23796.52 -23726.995 27645.69 -27572.6 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
78975.452 -78871.732 91753.517 -91644.479 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
262160.33 -262005.59 304582.57 -304419.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
870332.21 -870101.38 1011175.4 -1010932.7 MAarrowhead1
% End of user PostScript
0 1 .882 r
.43163 .53626 m
.42146 .54479 L
.40968 .55484 L
.39604 .56665 L
.38025 .58053 L
.36195 .59682 L
.34075 .61591 L
.31618 .63826 L
.28769 .66441 L
.25465 .69499 L
.21634 .73072 L
.17189 .77245 L
.12033 .82116 L
.06051 .87798 L
s
.06051 .87798 m
0 .93574 L
s
1 0 0 r
.43163 .53626 m
.42146 .54479 L
s
% Start of user PostScript
-8.2041631 4.3509552 -9.4253719 5.3746058 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40968 .55484 m
.39604 .56665 L
s
% Start of user PostScript
-10.838753 6.5803002 -12.475128 7.9983391 MAarrowhead1
% End of user PostScript
1 .473 0 r
.21634 .73072 m
.17189 .77245 L
s
% Start of user PostScript
-34.039505 27.686639 -39.372664 32.69408 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-110.11141 100.63405 -127.66925 117.70597 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-361.25091 347.11235 -419.32288 404.45942 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1192.9329 1171.8407 -1385.4073 1363.2336 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3951.0361 3919.5701 -4589.5792 4556.5 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-13103.519 13056.578 -15222.82 15173.472 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-43483.761 43413.732 -50518.987 50445.368 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-144339.16 144234.69 -167695.29 167585.47 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-479175.14 479019.29 -556717.78 556553.94 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1590846.3 1590613.8 -1848293.2 1848048.8 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-5281689.3 5281342.5 -6136438. 6136073.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-17535668. 17535150. -20373525. 20372981. MAarrowhead1
% End of user PostScript
0 1 .883 r
.47586 .56121 m
.47093 .56804 L
.46515 .57582 L
.45837 .5847 L
.45045 .59483 L
.44118 .60642 L
.43034 .6197 L
.41769 .63492 L
.40291 .6524 L
.38567 .67247 L
.36556 .69556 L
.34211 .72214 L
.31478 .75276 L
.28294 .78807 L
.24585 .8288 L
.20266 .87582 L
.15237 .93013 L
.09383 .9929 L
s
.09383 .9929 m
.08717 1 L
s
1 0 0 r
.47586 .56121 m
.47093 .56804 L
s
% Start of user PostScript
-2.8967138 7.3453678 -3.4884655 8.165207 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46515 .57582 m
.45837 .5847 L
s
% Start of user PostScript
-4.1822875 9.0988106 -4.9950214 10.16362 MAarrowhead1
% End of user PostScript
1 .473 0 r
.36556 .69556 m
.34211 .72214 L
s
% Start of user PostScript
-16.132894 23.467484 -18.946482 26.657125 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-56.915538 67.857461 -66.428864 77.931792 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-193.9675 210.29093 -225.80927 242.96963 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-651.45577 675.80747 -757.55672 783.15696 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2174.0398 2210.3683 -2526.8781 2565.0691 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-7234.6712 7288.8669 -8406.9868 8463.9611 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-24044.726 24125.576 -27938.221 28023.216 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-79868.255 79988.87 -92797.008 92923.807 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-265227.08 265407.01 -308154.87 308344.03 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-880667.15 880935.58 -1023196.7 1023478.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2924040.6 2924441.1 -3397261.6 3397682.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-9708339.7 9708937.1 -11279498. 11280126. MAarrowhead1
% End of user PostScript
1 0 .791 r
.56948 .55744 m
.57721 .55621 L
.58602 .55424 L
.59606 .55139 L
.60753 .54748 L
.62065 .54231 L
.63567 .53565 L
.65289 .52721 L
.67266 .51668 L
.69537 .50368 L
.72148 .48777 L
.75154 .46844 L
.78617 .44509 L
.82609 .41702 L
.87214 .38344 L
.9253 .34338 L
.9867 .29575 L
s
.9867 .29575 m
1 .28517 L
s
1 0 0 r
.56948 .55744 m
.57721 .55621 L
s
% Start of user PostScript
8.3371043 6.8927983 9.2653667 6.7453896 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58602 .55424 m
.59606 .55139 L
s
% Start of user PostScript
10.32227 6.5093749 11.527527 6.1670949 MAarrowhead1
% End of user PostScript
1 .473 0 r
.72148 .48777 m
.75154 .46844 L
s
% Start of user PostScript
26.577853 -1.467989 30.185004 -3.787729 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
76.764538 -39.305022 88.152258 -48.772152 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
237.74551 -181.86248 274.67622 -215.928 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
763.80025 -680.43256 885.10494 -797.4629 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2497.801 -2373.431 2898.5931 -2767.8465 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8236.1452 -8050.6071 9563.9072 -9368.8562 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
27260.161 -26983.37 31664.137 -31373.156 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
90380.407 -89967.485 104995.64 -104561.54 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
299884.78 -299268.78 348399.38 -347751.79 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
995370.99 -994452.01 1156430.7 -1155464.6 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3304328. -3302957.1 3839043.5 -3837602.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
10970129. -10968084. 12745415. -12743265. MAarrowhead1
% End of user PostScript
0 1 .65 r
.46501 .46628 m
.46125 .46652 L
.45698 .4671 L
.45211 .46807 L
.44657 .46952 L
.44024 .47154 L
.43301 .47425 L
.42473 .47778 L
.41524 .48227 L
.40436 .48789 L
.39186 .49487 L
.37749 .50343 L
.36095 .51386 L
.34191 .52649 L
.31996 .54168 L
.29465 .5599 L
.26544 .58166 L
.23171 .60755 L
.19273 .63829 L
.14767 .67468 L
.09557 .71768 L
.03528 .76839 L
s
.03528 .76839 m
0 .79858 L
s
1 0 0 r
.46501 .46628 m
.46125 .46652 L
s
% Start of user PostScript
-4.1984293 -4.0459609 -4.6499975 -4.0170916 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45698 .4671 m
.45211 .46807 L
s
% Start of user PostScript
-5.1629612 -3.9484991 -5.7466572 -3.8319577 MAarrowhead1
% End of user PostScript
1 .473 0 r
.39186 .49487 m
.37749 .50343 L
s
% Start of user PostScript
-12.977032 -0.61566965 -14.701447 0.4118328 MAarrowhead1
% End of user PostScript
1 .788 0 r
.19273 .63829 m
.14767 .67468 L
s
% Start of user PostScript
-36.872405 16.594478 -42.279125 20.961526 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-113.1522 82.901089 -130.62794 98.825818 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-361.85157 316.72222 -419.16414 371.72095 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1180.7621 1113.437 -1369.9889 1299.212 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3889.4958 3789.0586 -4516.1733 4410.5865 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-12867.674 12717.839 -14945.962 14788.445 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-42653.696 42430.169 -49550.346 49315.358 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-141513.09 141179.63 -164405.54 164054.98 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-469687.59 469190.12 -545685.37 545162.39 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1559190.3 1558448.2 -1811500.2 1810720. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-5176355. 5175247.8 -6014035.8 6012871.9 MAarrowhead1
% End of user PostScript
1 .839 0 r
.53907 .56499 m
.54251 .56688 L
.54637 .56863 L
.5507 .5702 L
.55556 .57154 L
.56104 .57257 L
.56722 .57324 L
.57422 .57345 L
.58215 .57309 L
.59115 .57204 L
.60139 .57017 L
.61306 .5673 L
.62637 .56324 L
.64158 .55775 L
.65898 .55056 L
.67892 .54137 L
.70178 .5298 L
.72803 .51542 L
.75821 .49773 L
.79292 .47614 L
.83289 .44996 L
.87894 .41841 L
.93205 .38055 L
.99333 .3353 L
s
.99333 .3353 m
1 .33022 L
s
1 0 0 r
.53907 .56499 m
.54251 .56688 L
s
% Start of user PostScript
4.6880308 7.798643 5.1015732 8.025306 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54637 .56863 m
.5507 .5702 L
s
% Start of user PostScript
5.5643452 8.2355635 6.0834065 8.4240387 MAarrowhead1
% End of user PostScript
1 .473 0 r
.60139 .57017 m
.61306 .5673 L
s
% Start of user PostScript
12.16671 8.4203344 13.566659 8.0759065 MAarrowhead1
% End of user PostScript
1 .788 0 r
.75821 .49773 m
.79292 .47614 L
s
% Start of user PostScript
30.985117 -0.27285558 35.150659 -2.8637462 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
88.836465 -43.019154 101.94682 -53.780406 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
274.00559 -205.6542 316.45979 -244.60395 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
878.48902 -776.52072 1017.8401 -910.64382 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2870.0793 -2717.9605 3330.3517 -3170.4336 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
9459.4695 -9232.5348 10984.063 -10745.493 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
31302.819 -30964.272 36359.329 -36003.425 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
103774.28 -103269.23 120554.55 -120023.6 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
344311.89 -343558.44 400012.52 -399220.44 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1142811.4 -1141687.3 1327726.3 -1326544.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3793753.6 -3792076.7 4407666.5 -4405903.6 MAarrowhead1
% End of user PostScript
.513 0 1 r
.43607 .54812 m
.42617 .55722 L
.41468 .56786 L
.40135 .58029 L
.38589 .5948 L
.36796 .61174 L
.34715 .63151 L
.32301 .65456 L
.29498 .68144 L
.26246 .71275 L
.2247 .74924 L
.18087 .79174 L
.12998 .84122 L
.07089 .89883 L
.00229 .96589 L
s
.00229 .96589 m
0 .96813 L
s
1 0 0 r
.43607 .54812 m
.42617 .55722 L
s
% Start of user PostScript
-7.6710342 5.7744182 -8.8600463 6.8661887 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41468 .56786 m
.40135 .58029 L
s
% Start of user PostScript
-10.238793 8.1427085 -11.837843 9.6342899 MAarrowhead1
% End of user PostScript
1 .473 0 r
.2247 .74924 m
.18087 .79174 L
s
% Start of user PostScript
-33.035927 29.908936 -38.295839 35.008524 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-108.25388 103.58895 -125.64412 120.74002 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-357.28332 350.32407 -414.91164 407.59558 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1183.0415 1172.6595 -1374.2112 1363.2969 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3923.0908 3907.6027 -4557.5532 4541.271 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-13018.041 12994.936 -15124.167 15099.877 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-43210.857 43176.388 -50202.901 50166.664 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-143449.34 143397.92 -166662.94 166608.88 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-476245.09 476168.38 -553315.73 553235.09 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1581154.3 1581039.9 -1837036.1 1836915.8 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-5249564.9 5249394.2 -6099119.6 6098940.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-17429091. 17428837. -20249708. 20249440. MAarrowhead1
% End of user PostScript
.747 1 0 r
.45182 .57874 m
.44318 .58895 L
.4331 .60068 L
.42133 .61418 L
.40762 .62971 L
.39164 .64761 L
.37302 .66824 L
.35133 .69205 L
.32607 .71953 L
.29666 .75128 L
.26243 .78797 L
.22259 .83039 L
.17623 .87946 L
.12229 .93626 L
s
.12229 .93626 m
.06146 1 L
s
1 0 0 r
.45182 .57874 m
.44318 .58895 L
s
% Start of user PostScript
-5.7814997 9.4493406 -6.8185263 10.674421 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4331 .60068 m
.42133 .61418 L
s
% Start of user PostScript
-8.0285773 12.082168 -9.4399205 13.701344 MAarrowhead1
% End of user PostScript
1 .473 0 r
.26243 .78797 m
.22259 .83039 L
s
% Start of user PostScript
-28.508603 34.55585 -33.289421 39.646718 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-97.415928 106.43736 -113.43052 122.91449 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-327.55572 341.01412 -380.93746 395.08588 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1093.6748 1113.7523 -1271.2238 1292.3307 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3640.305 3670.2573 -4230.259 4261.7468 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-12099.929 12144.612 -14059.347 14106.321 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-40193.602 40260.262 -46700.145 46770.223 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-133477.93 133577.37 -155081.97 155186.52 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-443207.77 443356.13 -514938.07 515094.03 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1471569.4 1471790.8 -1709725.9 1709958.5 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4885883.8 4886213.9 -5676596.2 5676943.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-16221856. 16222349. -18847122. 18847639. MAarrowhead1
% End of user PostScript
.025 0 1 r
.5478 .44379 m
.55576 .43539 L
.56503 .42567 L
.57581 .41441 L
.58835 .40137 L
.60294 .38626 L
.61989 .36875 L
.63961 .34845 L
.66253 .32492 L
.68918 .29762 L
.72017 .26597 L
.75618 .22924 L
.79804 .18663 L
.8467 .13719 L
.90325 .07981 L
.96898 .01321 L
s
.96898 .01321 m
.98204 0 L
s
1 0 0 r
.5478 .44379 m
.55576 .43539 L
s
% Start of user PostScript
5.7355335 -6.7450113 6.6916419 -7.7528768 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56503 .42567 m
.57581 .41441 L
s
% Start of user PostScript
7.8039121 -8.9195577 9.0976896 -10.270536 MAarrowhead1
% End of user PostScript
1 .473 0 r
.72017 .26597 m
.75618 .22924 L
s
% Start of user PostScript
26.419832 -28.08418 30.74147 -32.49115 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
88.47766 -90.960575 102.86501 -105.47522 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
294.89105 -298.59512 342.7169 -346.61089 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
980.7658 -986.29163 1139.64 -1145.4492 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3258.7828 -3267.0264 3786.3933 -3795.0596 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
10823.308 -10835.606 12575.23 -12588.158 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
35940.269 -35958.615 41757.142 -41776.429 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
119334.28 -119361.65 138647.41 -138676.18 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
396216.28 -396257.11 460338.76 -460381.69 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1315503. -1315563.9 1528398.1 -1528462.2 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4367651.7 -4367742.6 5074489.8 -5074585.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
14501156. -14501291. 16847943. -16848086. MAarrowhead1
% End of user PostScript
0 1 .142 r
.49348 .52073 m
.49203 .5229 L
.49033 .52537 L
.48833 .52817 L
.48599 .53137 L
.48324 .535 L
.48002 .53916 L
.47626 .5439 L
.47186 .54933 L
.46672 .55556 L
.46072 .56271 L
.45371 .57091 L
.44554 .58035 L
.43601 .5912 L
.4249 .6037 L
.41196 .61812 L
.39688 .63474 L
.37932 .65392 L
.35887 .67607 L
.33506 .70167 L
.30735 .73126 L
.27511 .76549 L
.23759 .80508 L
.19395 .85092 L
.14318 .90399 L
.08413 .96546 L
s
.08413 .96546 m
.05082 1 L
s
1 0 0 r
.49348 .52073 m
.49203 .5229 L
s
% Start of user PostScript
-0.78244483 2.4871804 -0.95619143 2.7483306 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49033 .52537 m
.48833 .52817 L
s
% Start of user PostScript
-1.1604721 3.0444962 -1.4003521 3.3809722 MAarrowhead1
% End of user PostScript
1 .473 0 r
.46072 .56271 m
.45371 .57091 L
s
% Start of user PostScript
-4.7140397 7.5246734 -5.5546208 8.5093588 MAarrowhead1
% End of user PostScript
1 .788 0 r
.35887 .67607 m
.33506 .70167 L
s
% Start of user PostScript
-16.935828 21.128801 -19.792522 24.200473 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-58.145423 64.400604 -67.728242 74.304132 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-195.90868 205.24031 -227.87134 237.68142 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-654.70496 668.62612 -761.04343 775.67834 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2180.06 2200.8279 -2533.4424 2555.2751 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7247.5465 7278.5286 -8421.3041 8453.8747 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-24076.863 24123.083 -27974.601 28023.191 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-79959.126 80028.078 -92901.157 92973.644 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-265505.16 265608.03 -308475.83 308583.97 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-881555.2 881708.66 -1024225.3 1024386.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2926936.5 2927165.4 -3400621.4 3400862. MAarrowhead1
% End of user PostScript
0 .032 1 r
.43378 .55269 m
.42343 .56234 L
.41144 .57361 L
.39752 .58676 L
.38137 .6021 L
.36262 .62 L
.34087 .64086 L
.31562 .66517 L
.28632 .69349 L
.25229 .72648 L
.21279 .76489 L
.16693 .80961 L
.11368 .86166 L
.05184 .92223 L
s
.05184 .92223 m
0 .97311 L
s
1 0 0 r
.43378 .55269 m
.42343 .56234 L
s
% Start of user PostScript
-7.9468046 6.3225374 -9.1879736 7.4804285 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41144 .57361 m
.39752 .58676 L
s
% Start of user PostScript
-10.627705 8.8326117 -12.298013 10.410884 MAarrowhead1
% End of user PostScript
1 .473 0 r
.21279 .76489 m
.16693 .80961 L
s
% Start of user PostScript
-34.464733 31.786769 -39.968286 37.15302 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-113.20292 109.20787 -131.4126 127.21272 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-374.02089 368.06098 -434.38554 428.12005 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1239.069 1230.1778 -1439.347 1430. MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-4109.79 4096.5259 -4774.5281 4760.584 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-13638.921 13619.133 -15845.618 15824.816 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-45273.767 45244.247 -52599.797 52568.763 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-150300.71 150256.67 -174623.29 174576.99 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-498995.79 498930.09 -579748.58 579679.52 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1656694.3 1656596.3 -1924801.5 1924698.5 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-5500374.1 5500227.9 -6390519. 6390365.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-18261818. 18261600. -21217200. 21216971. MAarrowhead1
% End of user PostScript
.008 0 1 r
.56134 .48561 m
.56997 .47939 L
.57992 .47196 L
.59143 .46312 L
.60471 .45263 L
.62007 .44021 L
.63784 .42554 L
.6584 .40823 L
.68219 .38785 L
.70974 .3639 L
.74164 .33576 L
.77861 .30277 L
.82145 .2641 L
.87111 .21883 L
.92868 .16587 L
.99544 .10395 L
s
.99544 .10395 m
1 .09969 L
s
1 0 0 r
.56134 .48561 m
.56997 .47939 L
s
% Start of user PostScript
7.3604807 -1.7265361 8.3959318 -2.4731287 MAarrowhead1
% End of user PostScript
1 .158 0 r
.57992 .47196 m
.59143 .46312 L
s
% Start of user PostScript
9.5909702 -3.3644984 10.971013 -4.4253032 MAarrowhead1
% End of user PostScript
1 .473 0 r
.74164 .33576 m
.77861 .30277 L
s
% Start of user PostScript
28.99719 -19.708386 33.433178 -23.668127 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
92.028399 -78.171131 106.53872 -91.970974 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
299.21126 -278.53865 347.06248 -325.32996 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
983.96747 -953.12756 1142.3547 -1109.9336 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3252.791 -3206.7832 3777.9322 -3729.5656 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
10778.617 -10709.982 12521.07 -12448.915 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
35754.899 -35652.507 41538.436 -41430.794 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
118663.64 -118510.89 137863.26 -137702.68 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
393907.35 -393679.48 457648.75 -457409.19 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1307714.3 -1307374.4 1519337.9 -1518980.5 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4341609. -4341101.9 5044216. -5043682.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
14414418. -14413661. 16747143. -16746348. MAarrowhead1
% End of user PostScript
.524 1 0 r
.55262 .47013 m
.56051 .46341 L
.56964 .4555 L
.58021 .44622 L
.59246 .43532 L
.60666 .42255 L
.62311 .4076 L
.64218 .3901 L
.6643 .36963 L
.68995 .34572 L
.71971 .3178 L
.75423 .2852 L
.79428 .24717 L
.84076 .20281 L
.8947 .15111 L
.95731 .09085 L
s
.95731 .09085 m
1 .04961 L
s
1 0 0 r
.55262 .47013 m
.56051 .46341 L
s
% Start of user PostScript
6.3141997 -3.5844595 7.2606013 -4.3909043 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56964 .4555 m
.58021 .44622 L
s
% Start of user PostScript
8.3562945 -5.339465 9.6252416 -6.4537359 MAarrowhead1
% End of user PostScript
1 .473 0 r
.71971 .3178 m
.75423 .2852 L
s
% Start of user PostScript
26.364963 -21.864383 30.507318 -25.775987 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
85.477667 -78.763589 99.125298 -92.066982 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
280.72702 -270.7108 325.88141 -315.35164 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
927.4684 -912.52594 1077.1515 -1061.443 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3072.4737 -3050.1822 3569.089 -3545.6546 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
10190.783 -10157.528 11839.082 -11804.122 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
33819.392 -33769.781 39291.156 -39239.002 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
112261.66 -112187.65 130427.39 -130349.59 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
372688.01 -372577.59 432998.63 -432882.56 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1237317.3 -1237152.6 1437553. -1437379.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4107962.8 -4107717.1 4772765. -4772506.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
13638804. -13638438. 15846020. -15845635. MAarrowhead1
% End of user PostScript
0 .194 1 r
.55451 .43785 m
.56354 .42842 L
.57405 .41751 L
.58627 .40486 L
.60047 .3902 L
.61699 .3732 L
.63619 .35349 L
.65852 .33064 L
.68447 .30413 L
.71464 .27337 L
.74971 .23769 L
.79047 .19629 L
.83785 .14823 L
.8929 .09246 L
.95689 .02772 L
s
.95689 .02772 m
.98432 0 L
s
1 0 0 r
.55451 .43785 m
.56354 .42842 L
s
% Start of user PostScript
6.5412674 -7.4581569 7.625212 -8.5891115 MAarrowhead1
% End of user PostScript
1 .158 0 r
.57405 .41751 m
.58627 .40486 L
s
% Start of user PostScript
8.8858753 -9.899195 10.351923 -11.417197 MAarrowhead1
% End of user PostScript
1 .473 0 r
.74971 .23769 m
.79047 .19629 L
s
% Start of user PostScript
29.965306 -31.477001 34.856503 -36.445705 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
100.17928 -102.43446 116.45405 -118.82486 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
333.63769 -337.00203 387.72469 -391.26152 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1109.2539 -1114.2729 1288.9079 -1294.1842 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3685.1467 -3692.6341 4281.7366 -4289.6079 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
12238.54 -12249.71 14219.464 -14231.206 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
40638.49 -40655.153 47215.65 -47233.168 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
134932.15 -134957.01 156769.48 -156795.62 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
448001.89 -448038.98 520504.96 -520543.95 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1487435.6 -1487490.9 1728155.2 -1728213.3 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4938485.4 -4938568. 5737703.8 -5737790.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
16396387. -16396510. 19049887. -19050016. MAarrowhead1
% End of user PostScript
0 1 .721 r
.57249 .48841 m
.58253 .48148 L
.59412 .47317 L
.60749 .46325 L
.62293 .45144 L
.64077 .43741 L
.66139 .4208 L
.68524 .40117 L
.71283 .37801 L
.74476 .35074 L
.78173 .31866 L
.82455 .28099 L
.87416 .23679 L
.93164 .185 L
.99827 .12435 L
s
.99827 .12435 m
1 .12276 L
s
1 0 0 r
.57249 .48841 m
.58253 .48148 L
s
% Start of user PostScript
8.6982844 -1.3913287 9.9039947 -2.2224034 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59412 .47317 m
.60749 .46325 L
s
% Start of user PostScript
11.294475 -3.21904 12.899096 -4.409625 MAarrowhead1
% End of user PostScript
1 .473 0 r
.78173 .31866 m
.82455 .28099 L
s
% Start of user PostScript
33.807914 -21.76078 38.9462 -26.281397 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
106.73981 -88.767595 123.5172 -104.62353 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
346.17402 -319.36264 401.45575 -373.26971 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1137.0835 -1097.0856 1319.9969 -1277.9483 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3756.9681 -3697.2983 4363.3249 -4300.5957 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
12446.3 -12357.283 14458.077 -14364.496 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
41282.484 -41149.686 47959.733 -47820.126 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
137001.97 -136803.86 159168.11 -158959.84 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
454772.02 -454476.48 528361.54 -528050.84 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1509761.2 -1509320.3 1754080.1 -1753616.6 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
5012382.2 -5011724.5 5823539.1 -5822847.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
16641394. -16640413. 19334515. -19333483. MAarrowhead1
% End of user PostScript
.376 1 0 r
.55292 .42422 m
.56212 .41385 L
.57284 .4019 L
.58533 .38812 L
.59987 .37221 L
.6168 .35385 L
.63652 .33263 L
.65946 .3081 L
.68616 .27973 L
.71723 .24691 L
.75338 .20893 L
.79543 .16495 L
.84433 .11401 L
.90121 .055 L
s
.90121 .055 m
.9544 0 L
s
1 0 0 r
.55292 .42422 m
.56212 .41385 L
s
% Start of user PostScript
6.3509265 -9.0941553 7.4545489 -10.338426 MAarrowhead1
% End of user PostScript
1 .158 0 r
.57284 .4019 m
.58533 .38812 L
s
% Start of user PostScript
8.7406628 -11.772399 10.239001 -13.426178 MAarrowhead1
% End of user PostScript
1 .473 0 r
.75338 .20893 m
.79543 .16495 L
s
% Start of user PostScript
30.405748 -34.928567 35.451453 -40.206163 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
103.0179 -109.76515 119.87622 -126.96941 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
345.11545 -355.18117 401.24517 -411.82697 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1150.4244 -1165.4407 1337.0175 -1352.8037 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3826.4071 -3848.8088 4446.27 -4469.8202 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
12714.358 -12747.778 14772.9 -14808.033 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
42228.431 -42278.287 49063.815 -49116.227 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
140226.12 -140300.49 162921.56 -162999.75 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
465601.1 -465712.05 540954.36 -541071.01 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1545900.8 -1546066.3 1796085.1 -1796259.1 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
5132647. -5132894. 5963291.9 -5963551.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
17041101. -17041470. 19798945. -19799332. MAarrowhead1
% End of user PostScript
1 0 .811 r
.55439 .4985 m
.56174 .49387 L
.57019 .48827 L
.57993 .48153 L
.59117 .47344 L
.60414 .46378 L
.61911 .45229 L
.63642 .43865 L
.65642 .4225 L
.67955 .40341 L
.70632 .3809 L
.7373 .35439 L
.77316 .32322 L
.81471 .28662 L
.86284 .24369 L
.91861 .19337 L
.98326 .13447 L
s
.98326 .13447 m
1 .11907 L
s
1 0 0 r
.55439 .4985 m
.56174 .49387 L
s
% Start of user PostScript
6.5273951 -0.1796209 7.4082937 -0.73506213 MAarrowhead1
% End of user PostScript
1 .158 0 r
.57019 .48827 m
.57993 .48153 L
s
% Start of user PostScript
8.4227559 -1.4073805 9.5919358 -2.2168743 MAarrowhead1
% End of user PostScript
1 .473 0 r
.70632 .3809 m
.7373 .35439 L
s
% Start of user PostScript
24.757995 -14.292285 28.475406 -17.473108 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
77.415845 -61.80284 89.512824 -73.099323 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
249.89337 -226.60151 289.69087 -265.20481 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
819.02913 -784.28175 950.61565 -914.08673 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2703.3904 -2651.5534 3139.4587 -3084.964 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8951.8789 -8874.5472 10398.462 -10317.165 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
29685.938 -29570.573 34486.951 -34365.671 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
98508.056 -98335.951 114445.28 -114264.35 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
326979.6 -326722.85 379889. -379619.08 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1085493.1 -1085110.1 1261152.5 -1260749.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3603789.1 -3603217.7 4186989.8 -4186389.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
11964740. -11963888. 13901021. -13900125. MAarrowhead1
% End of user PostScript
.405 0 1 r
.49609 .43042 m
.49749 .42526 L
.49921 .41957 L
.50133 .41328 L
.50391 .40633 L
.50702 .39862 L
.51077 .39003 L
.51525 .38046 L
.5206 .36977 L
.52696 .35778 L
.53451 .34432 L
.54345 .32918 L
.554 .31209 L
.56644 .29279 L
.58108 .27093 L
.5983 .24612 L
.6185 .21794 L
.6422 .18586 L
.66997 .14927 L
.70247 .1075 L
.74049 .05974 L
.78493 .00506 L
s
.78493 .00506 m
.78912 0 L
s
1 0 0 r
.49609 .43042 m
.49749 .42526 L
s
% Start of user PostScript
-0.46953047 -8.3493024 -0.3017571 -8.969227 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49921 .41957 m
.50133 .41328 L
s
% Start of user PostScript
-0.094334437 -9.6519832 0.15979491 -10.405817 MAarrowhead1
% End of user PostScript
1 .473 0 r
.53451 .34432 m
.54345 .32918 L
s
% Start of user PostScript
4.1415778 -18.681375 5.2137184 -20.498987 MAarrowhead1
% End of user PostScript
1 .788 0 r
.66997 .14927 m
.70247 .1075 L
s
% Start of user PostScript
20.396272 -42.087101 24.296639 -47.09958 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
77.632302 -109.99122 91.090292 -125.10828 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
272.53871 -320.81253 317.97913 -368.72801 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
926.92504 -998.94113 1078.9238 -1154.6323 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3110.4161 -3217.8515 3616.7576 -3729.7013 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
10376.051 -10536.326 12059.681 -12228.174 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
34522.96 -34762.062 40116.566 -40367.927 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
114729.55 -115086.25 133306.58 -133681.57 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
381078.56 -381610.69 442764.83 -443324.24 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1265468.6 -1266262.4 1470286.7 -1471121.2 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4201866.5 -4203050.8 4881905.2 -4883150.2 MAarrowhead1
% End of user PostScript
1 .947 0 r
.52839 .479 m
.53278 .47499 L
.53787 .4703 L
.54377 .46482 L
.55062 .45841 L
.55856 .45093 L
.56777 .44221 L
.57846 .43203 L
.59087 .42016 L
.60527 .40632 L
.62199 .3902 L
.6414 .37142 L
.66392 .34955 L
.69008 .32408 L
.72045 .29444 L
.75572 .25993 L
.79667 .21979 L
.84422 .17307 L
.89945 .11873 L
.96359 .05552 L
s
.96359 .05552 m
1 .01959 L
s
1 0 0 r
.52839 .479 m
.53278 .47499 L
s
% Start of user PostScript
3.4065677 -2.5194295 3.9333458 -3.0007231 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53787 .4703 m
.54377 .46482 L
s
% Start of user PostScript
4.5441174 -3.5636781 5.2524111 -4.2217036 MAarrowhead1
% End of user PostScript
1 .473 0 r
.62199 .3902 m
.6414 .37142 L
s
% Start of user PostScript
14.638869 -13.176225 16.96751 -15.429875 MAarrowhead1
% End of user PostScript
1 .788 0 r
.89945 .11873 m
.96359 .05552 L
s
% Start of user PostScript
47.93422 -45.752213 55.631306 -53.337425 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
158.14988 -154.89471 183.65397 -180.2319 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
523.58824 -518.73209 608.18852 -603.08339 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1736.1546 -1728.91 2016.9236 -2009.3076 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5760.9249 -5750.1173 6692.9411 -6681.5794 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
19122.004 -19105.881 22216.154 -22199.204 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
63479.921 -63455.868 73752.481 -73727.195 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
210749.77 -210713.88 244855.3 -244817.58 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
699697.46 -699643.93 812930.99 -812874.72 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2323052.9 -2322973.1 2699000.2 -2698916.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
7712770.8 -7712651.7 8960957.9 -8960832.7 MAarrowhead1
% End of user PostScript
1 0 .63 r
.45833 .52532 m
.45203 .53077 L
.44475 .53717 L
.4363 .54469 L
.42652 .5535 L
.41518 .56381 L
.40204 .57588 L
.38679 .58999 L
.36911 .60648 L
.34861 .62574 L
.32481 .64821 L
.29721 .67444 L
.26517 .70502 L
.22799 .74067 L
.18484 .78222 L
.13475 .83062 L
.07659 .887 L
.00908 .95265 L
s
.00908 .95265 m
0 .9615 L
s
1 0 0 r
.45833 .52532 m
.45203 .53077 L
s
% Start of user PostScript
-5.0009452 3.0378398 -5.7560076 3.6922516 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44475 .53717 m
.4363 .54469 L
s
% Start of user PostScript
-6.6304829 4.4609159 -7.6435535 5.3627504 MAarrowhead1
% End of user PostScript
1 .473 0 r
.32481 .64821 m
.29721 .67444 L
s
% Start of user PostScript
-21.022328 17.785714 -24.334998 20.932439 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-68.317217 63.488757 -79.23982 74.163799 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-224.61419 217.41097 -260.76535 253.19282 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-742.45298 731.70704 -862.31027 851.01337 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2460.119 2444.088 -2857.8074 2840.9544 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-8160.5554 8136.6399 -9480.5517 9455.41 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-27083.067 27047.389 -31465.048 31427.541 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-89902.642 89849.417 -104450.5 104394.54 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-298462.95 298383.55 -346762.29 346678.81 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-990895.61 990777.16 -1151253.2 1151128.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3289835.2 3289658.4 -3822238.2 3822052.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-10922557. 10922293. -12690193. 12689916. MAarrowhead1
% End of user PostScript
0 1 .701 r
.46931 .52556 m
.46449 .53012 L
.45889 .53545 L
.4524 .54165 L
.44486 .54889 L
.4361 .55732 L
.42595 .56714 L
.41415 .57858 L
.40046 .5919 L
.38456 .6074 L
.3661 .62545 L
.34467 .64645 L
.31977 .67089 L
.29087 .69932 L
.25729 .73239 L
.2183 .77086 L
.17301 .81559 L
.12041 .86761 L
.05931 .92809 L
s
.05931 .92809 m
0 .98686 L
s
1 0 0 r
.46931 .52556 m
.46449 .53012 L
s
% Start of user PostScript
-3.682338 3.0675487 -4.2612731 3.6149629 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45889 .53545 m
.4524 .54165 L
s
% Start of user PostScript
-4.9330285 4.2535812 -5.712581 4.9982977 MAarrowhead1
% End of user PostScript
1 .473 0 r
.3661 .62545 m
.34467 .64645 L
s
% Start of user PostScript
-16.067674 15.054058 -18.639957 17.574372 MAarrowhead1
% End of user PostScript
1 .788 0 r
.05931 .92809 m
0 0 rlineto s
.05931 .92809 m
0 .98686 L
s
% Start of user PostScript
-52.883261 51.371123 -61.399787 59.81012 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-174.88745 172.63161 -203.12788 200.75637 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-579.61571 576.25038 -673.32436 669.78649 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1922.8537 1917.8332 -2233.8985 2228.6206 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6381.8044 6374.3148 -7414.3919 7406.5182 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-21184.914 21173.74 -24613.049 24601.303 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-70331.283 70314.615 -81712.832 81695.309 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-233500.46 233475.6 -271288.15 271262.01 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-775237.48 775200.38 -900696.42 900657.42 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2573862.1 2573806.8 -2990399.6 2990341.4 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-8545497.9 8545415.3 -9928449.8 9928363. MAarrowhead1
% End of user PostScript
1 0 .805 r
.48452 .54822 m
.48111 .55331 L
.47711 .55908 L
.4724 .56564 L
.46688 .57311 L
.46042 .58162 L
.45285 .59135 L
.444 .60247 L
.43365 .61519 L
.42157 .62979 L
.40745 .64653 L
.39098 .66577 L
.37177 .68789 L
.34937 .71335 L
.32326 .74268 L
.29284 .77648 L
.25739 .81548 L
.21612 .86049 L
.16806 .91248 L
.11211 .97255 L
s
.11211 .97255 m
.08638 1 L
s
1 0 0 r
.48452 .54822 m
.48111 .55331 L
s
% Start of user PostScript
-1.8570745 5.7862836 -2.2662192 6.3968831 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47711 .55908 m
.4724 .56564 L
s
% Start of user PostScript
-2.7471458 7.0895934 -3.3117567 7.8768464 MAarrowhead1
% End of user PostScript
1 .473 0 r
.40745 .64653 m
.39098 .66577 L
s
% Start of user PostScript
-11.105661 17.583832 -13.081999 19.892313 MAarrowhead1
% End of user PostScript
1 .788 0 r
.16806 .91248 m
.11211 .97255 L
s
% Start of user PostScript
-39.833091 49.497386 -46.546577 56.706371 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-136.66781 151.08524 -159.18385 174.34048 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-460.34292 481.8512 -535.43667 558.04771 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1538.2232 1570.3098 -1788.0473 1821.779 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5121.7467 5169.6143 -5951.9438 6002.2656 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-17026.677 17098.087 -19784.15 19859.221 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-56563.198 56669.729 -65720.005 65831.998 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-187845.12 188004.05 -218249.29 218416.36 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-623740.41 623977.5 -724689.52 724938.77 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2070999.5 2071353.2 -2406167.9 2406539.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-6876122. 6876649.7 -7988928.6 7989483.3 MAarrowhead1
% End of user PostScript
1 0 .55 r
.53551 .50078 m
.54025 .49789 L
.54571 .49439 L
.552 .49015 L
.55925 .48507 L
.56762 .47897 L
.57727 .47171 L
.58842 .46307 L
.60131 .45282 L
.61621 .4407 L
.63344 .42638 L
.65338 .40951 L
.67647 .38965 L
.7032 .36631 L
.73416 .33891 L
.77004 .30678 L
.81161 .26914 L
.85981 .22508 L
.91569 .17355 L
.9805 .11332 L
s
.9805 .11332 m
1 .09507 L
s
1 0 0 r
.53551 .50078 m
.54025 .49789 L
s
% Start of user PostScript
4.2610043 0.093003079 4.8302325 -0.2529904 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54571 .49439 m
.552 .49015 L
s
% Start of user PostScript
5.4854109 -0.67348863 6.240133 -1.1814981 MAarrowhead1
% End of user PostScript
1 .473 0 r
.63344 .42638 m
.65338 .40951 L
s
% Start of user PostScript
16.012806 -8.8342611 18.405805 -10.859209 MAarrowhead1
% End of user PostScript
1 .788 0 r
.91569 .17355 m
.9805 .11332 L
s
% Start of user PostScript
49.883268 -39.174138 57.66008 -46.401881 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
160.72343 -144.74728 186.29239 -169.49713 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
526.3183 -502.4847 610.83585 -585.78027 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1736.5446 -1700.989 2016.5942 -1979.2157 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5749.2796 -5696.237 6678.2438 -6622.4816 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
19064.036 -18984.906 22147.063 -22063.875 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
63258.661 -63140.612 73492.816 -73368.715 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
209972.19 -209796.09 243948.02 -243762.88 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
697051.74 -696789.02 809851.32 -809575.13 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2314173.2 -2313781.3 2688674.8 -2688262.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
7683146.5 -7682561.8 8926526.5 -8925911.8 MAarrowhead1
% End of user PostScript
.15 1 0 r
.57651 .53557 m
.58579 .53203 L
.59642 .52745 L
.6086 .52162 L
.62257 .51432 L
.63863 .50528 L
.65708 .49421 L
.67832 .48072 L
.70278 .46441 L
.73098 .44479 L
.7635 .42128 L
.80104 .39322 L
.84439 .35983 L
.89447 .32021 L
.95238 .27331 L
s
.95238 .27331 m
1 .23392 L
s
1 0 0 r
.57651 .53557 m
.58579 .53203 L
s
% Start of user PostScript
9.1807867 4.2683791 10.294807 3.8439125 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59642 .52745 m
.6086 .52162 L
s
% Start of user PostScript
11.570054 3.2935732 13.031642 2.5940591 MAarrowhead1
% End of user PostScript
1 .473 0 r
.7635 .42128 m
.80104 .39322 L
s
% Start of user PostScript
31.620168 -9.4462421 36.124489 -12.813682 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
94.84755 -61.76794 109.28279 -74.507148 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
299.78516 -250.43618 346.93662 -295.05746 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
972.76569 -899.14566 1128.1576 -1050.763 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3196.0461 -3086.2179 3710.2401 -3594.7809 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
10561.047 -10397.203 12265.658 -12093.413 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
34989.023 -34744.596 40644.689 -40387.73 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
116055.93 -115691.28 134827.67 -134444.33 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
385152.58 -384608.59 447468.41 -446896.54 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1278502.9 -1277691.4 1485386.1 -1484532.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4244408.3 -4243197.7 4931265.5 -4929992.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
14091379. -14089572. 16371796. -16369898. MAarrowhead1
% End of user PostScript
.103 1 0 r
.43653 .43494 m
.42982 .43507 L
.42219 .43577 L
.41353 .43715 L
.40366 .43936 L
.39241 .44257 L
.37956 .44696 L
.36486 .45276 L
.34803 .46024 L
.32874 .4697 L
.30659 .48151 L
.28115 .49609 L
.25189 .51393 L
.21821 .5356 L
.17941 .56178 L
.13468 .59324 L
.08308 .63089 L
.02351 .67579 L
s
.02351 .67579 m
0 .69403 L
s
1 0 0 r
.43653 .43494 m
.42982 .43507 L
s
% Start of user PostScript
-7.6159153 -7.8068692 -8.4221333 -7.7913943 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42219 .43577 m
.41353 .43715 L
s
% Start of user PostScript
-9.3369682 -7.7078447 -10.376877 -7.5418418 MAarrowhead1
% End of user PostScript
1 .473 0 r
.30659 .48151 m
.28115 .49609 L
s
% Start of user PostScript
-23.209101 -2.2187714 -26.262282 -0.46930542 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-65.434535 27.500606 -74.97556 35.096717 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-199.91173 143.32096 -230.70008 171.20784 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-637.8642 553.44069 -738.75894 650.00694 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2079.196 1953.2509 -2412.1999 2279.7975 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6845.6078 6657.7198 -7948.2681 7750.7469 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-22642.34 22362.044 -26298.898 26004.231 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-75047.099 74628.947 -87180.732 86741.14 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-248974.02 248350.21 -289249.3 288593.5 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-826337.72 825407.11 -960041.74 959063.41 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2743112.5 2741724.2 -3187003.7 3185544.2 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-9106819.7 9104748.6 -10580558. 10578380. MAarrowhead1
% End of user PostScript
0 .043 1 r
.58175 .5697 m
.59079 .56842 L
.60108 .56629 L
.61282 .56314 L
.62621 .55877 L
.64152 .55294 L
.65905 .54538 L
.67914 .53578 L
.70219 .52374 L
.72866 .50885 L
.7591 .49059 L
.79413 .46836 L
.83448 .44148 L
.88098 .40912 L
.93462 .37036 L
.99653 .32409 L
s
.99653 .32409 m
1 .32141 L
s
1 0 0 r
.58175 .5697 m
.59079 .56842 L
s
% Start of user PostScript
9.8096592 8.3640016 10.894864 8.2105807 MAarrowhead1
% End of user PostScript
1 .158 0 r
.60108 .56629 m
.61282 .56314 L
s
% Start of user PostScript
12.129936 7.9550652 13.53781 7.5769715 MAarrowhead1
% End of user PostScript
1 .473 0 r
.7591 .49059 m
.79413 .46836 L
s
% Start of user PostScript
31.092493 -1.1291922 35.296114 -3.7965618 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
89.535296 -44.835303 102.78963 -55.797819 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
276.83649 -210.15194 319.7949 -249.69135 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
888.6498 -789.16813 1029.714 -925.13181 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2904.9508 -2756.5416 3370.9692 -3214.9509 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9576.9426 -9355.5421 11120.7 -10887.948 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
31695.373 -31365.082 36815.64 -36468.415 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
105081.38 -104588.64 122073.52 -121555.52 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
348657.24 -347922.17 405061.6 -404288.84 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1157246.8 -1156150.2 1344498.7 -1343345.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3841693.5 -3840057.6 4463365.9 -4461646.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
12754124. -12751683. 14818111. -14815545. MAarrowhead1
% End of user PostScript
.37 1 0 r
.56524 .42676 m
.57602 .41557 L
.58856 .40261 L
.60313 .38758 L
.62008 .37016 L
.63978 .34995 L
.66269 .32652 L
.68932 .29934 L
.72027 .26781 L
.75624 .23122 L
.79806 .18876 L
.84666 .13949 L
.90314 .08229 L
.96879 .0159 L
s
.96879 .0159 m
.98453 0 L
s
1 0 0 r
.56524 .42676 m
.57602 .41557 L
s
% Start of user PostScript
7.8291107 -8.7882922 9.1226414 -10.131001 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58856 .40261 m
.60313 .38758 L
s
% Start of user PostScript
10.626869 -11.686929 12.375961 -13.490371 MAarrowhead1
% End of user PostScript
1 .473 0 r
.79806 .18876 m
.84666 .13949 L
s
% Start of user PostScript
35.766972 -37.348395 41.599005 -43.261509 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
119.47336 -121.83256 138.87345 -141.35361 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
397.74384 -401.26336 462.2097 -465.90967 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1322.1647 -1327.4152 1536.2814 -1541.8011 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
4392.1414 -4399.9742 5103.1568 -5111.3912 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
14586.003 -14597.688 16946.841 -16959.125 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
48432.577 -48450.009 56271.108 -56289.434 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
160809.79 -160835.79 186835.03 -186862.37 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
533919.18 -533957.97 620326.65 -620367.44 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1772691.8 -1772749.7 2059575.7 -2059636.5 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
5885570.6 -5885656.9 6838059.8 -6838150.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
19540822. -19540951. 22703200. -22703335. MAarrowhead1
% End of user PostScript
0 1 .045 r
.5265 .42287 m
.53218 .41459 L
.53886 .40518 L
.5467 .39448 L
.55588 .38228 L
.56664 .36835 L
.57922 .35244 L
.59393 .33423 L
.61111 .31336 L
.63118 .28941 L
.65461 .26192 L
.68193 .23031 L
.7138 .19394 L
.75095 .15206 L
.79425 .1038 L
.84468 .04813 L
s
.84468 .04813 m
.8887 0 L
s
1 0 0 r
.5265 .42287 m
.53218 .41459 L
s
% Start of user PostScript
3.179543 -9.2551471 3.8620364 -10.249143 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53886 .40518 m
.5467 .39448 L
s
% Start of user PostScript
4.6635908 -11.378172 5.6039158 -12.662761 MAarrowhead1
% End of user PostScript
1 .473 0 r
.65461 .26192 m
.68193 .23031 L
s
% Start of user PostScript
18.552721 -28.569698 21.832063 -32.362623 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
66.175693 -81.119268 77.298238 -93.007986 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
226.54134 -248.83454 263.81969 -287.25588 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
762.33336 -795.5909 886.62427 -921.58696 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2546.237 -2595.8514 2959.6768 -3011.835 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8476.4821 -8550.4981 9850.313 -9928.1239 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
28176.742 -28287.161 32739.756 -32855.836 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
93600.548 -93765.274 108752.88 -108926.05 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
310840.06 -311085.8 361151.41 -361409.76 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1032137.7 -1032504.3 1199183. -1199568.4 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3426985.3 -3427532.2 3981603.9 -3982178.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
11378242. -11379058. 13219653. -13220511. MAarrowhead1
% End of user PostScript
.625 1 0 r
.55733 .56383 m
.56325 .56412 L
.56997 .56393 L
.57759 .56318 L
.58626 .56173 L
.59613 .55945 L
.60739 .55616 L
.62024 .55169 L
.63495 .5458 L
.65179 .53822 L
.67111 .52865 L
.69328 .51673 L
.71875 .50202 L
.74805 .48404 L
.78178 .46221 L
.82064 .43586 L
.86544 .40421 L
.91712 .36635 L
.97679 .32122 L
s
.97679 .32122 m
1 .30315 L
s
1 0 0 r
.55733 .56383 m
.56325 .56412 L
s
% Start of user PostScript
6.8791725 7.6601914 7.5905788 7.6942343 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56997 .56393 m
.57759 .56318 L
s
% Start of user PostScript
8.3965101 7.6719721 9.3112074 7.5811234 MAarrowhead1
% End of user PostScript
1 .473 0 r
.67111 .52865 m
.69328 .51673 L
s
% Start of user PostScript
20.532925 3.4384336 23.193268 2.0071283 MAarrowhead1
% End of user PostScript
1 .788 0 r
.97679 .32122 m
0 0 rlineto s
.97679 .32122 m
1 .30315 L
s
% Start of user PostScript
57.215049 -21.453985 65.48594 -27.891366 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
173.61523 -120.266 200.23751 -144.153 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
552.03838 -472.45067 639.17723 -555.50896 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1796.4546 -1677.7236 2083.9006 -1959.0822 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5910.1705 -5733.0448 6861.7426 -6675.5354 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
19541.498 -19277.257 22696.677 -22418.889 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
64759.28 -64365.079 75228.653 -74814.241 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
214828.2 -214240.12 249578.51 -248960.28 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
712985.96 -712108.65 828347.25 -827424.96 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2366795.7 -2365487. 2749788.2 -2748412.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
7857440.4 -7855487.9 9128989.4 -9126936.8 MAarrowhead1
% End of user PostScript
.697 1 0 r
.54557 .51156 m
.55137 .50869 L
.55802 .50512 L
.56566 .50071 L
.57446 .49532 L
.58458 .48878 L
.59624 .48088 L
.60968 .47139 L
.62519 .46004 L
.64309 .44651 L
.66377 .43042 L
.68768 .41135 L
.71531 .38879 L
.74728 .36216 L
.78427 .33078 L
.8271 .29385 L
.87669 .25046 L
.93414 .19953 L
s
.93414 .19953 m
1 .14045 L
s
1 0 0 r
.54557 .51156 m
.55137 .50869 L
s
% Start of user PostScript
5.4685853 1.3871422 6.164092 1.0431362 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55802 .50512 m
.56566 .50071 L
s
% Start of user PostScript
6.9624397 0.61431098 7.8797735 0.085445489 MAarrowhead1
% End of user PostScript
1 .473 0 r
.66377 .43042 m
.68768 .41135 L
s
% Start of user PostScript
19.652985 -8.3498014 22.521082 -10.638372 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
60.083828 -43.221459 69.341359 -51.614439 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
191.778 -166.6223 222.11892 -195.67347 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
625.22739 -587.6995 725.37329 -685.9213 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2058.675 -2002.69 2390.2917 -2331.4362 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6809.4526 -6725.9328 7909.1467 -7821.3446 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
22570.004 -22445.407 26219.16 -26088.175 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
74878.103 -74692.226 86990.806 -86795.399 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
248519.1 -248241.8 288730.33 -288438.82 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
824985.72 -824572.04 958485.22 -958050.33 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2738860. -2738242.8 3182084.2 -3181435.4 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
9093053.2 -9092132.6 10564595. -10563627. MAarrowhead1
% End of user PostScript
1 0 .545 r
.52426 .46322 m
.52853 .45831 L
.53351 .45266 L
.53932 .44614 L
.54608 .43863 L
.55396 .42997 L
.56314 .41996 L
.57383 .40841 L
.58626 .39506 L
.60074 .37963 L
.61759 .36178 L
.63719 .34112 L
.65999 .31721 L
.68651 .28952 L
.71736 .25744 L
.75323 .22028 L
.79494 .1772 L
.84344 .12727 L
.89983 .06938 L
.96539 .00225 L
s
.96539 .00225 m
.96759 0 L
s
1 0 0 r
.52426 .46322 m
.52853 .45831 L
s
% Start of user PostScript
2.9110943 -4.4130218 3.4237235 -5.0026564 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53351 .45266 m
.53932 .44614 L
s
% Start of user PostScript
4.0214422 -5.6813287 4.7181298 -6.4631205 MAarrowhead1
% End of user PostScript
1 .473 0 r
.61759 .36178 m
.63719 .34112 L
s
% Start of user PostScript
14.110348 -16.586607 16.462331 -19.065551 MAarrowhead1
% End of user PostScript
1 .788 0 r
.89983 .06938 m
.96539 .00225 L
s
% Start of user PostScript
47.979836 -51.673981 55.846725 -59.730273 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
160.98716 -166.49818 187.19272 -192.9863 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
537.01513 -545.2366 624.14981 -632.79281 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1786.7108 -1798.9758 2076.2008 -2089.0947 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5937.6948 -5955.9921 6899.1229 -6918.3583 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
19722.204 -19749.501 22914.687 -22943.383 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
65492.501 -65533.222 76092.555 -76135.364 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
217461.37 -217522.12 252655.75 -252719.61 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
722024.95 -722115.57 838875.81 -838971.09 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2397248.7 -2397383.9 2785209.3 -2785351.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
7959207.7 -7959409.4 9247285.6 -9247497.6 MAarrowhead1
% End of user PostScript
0 1 .755 r
.44287 .43957 m
.43687 .43954 L
.43007 .44 L
.42234 .44107 L
.41355 .44286 L
.40353 .44552 L
.39209 .44922 L
.37901 .45416 L
.36404 .46057 L
.34689 .46874 L
.32721 .47896 L
.3046 .49163 L
.27861 .50718 L
.2487 .5261 L
.21426 .549 L
.17456 .57656 L
.12877 .60959 L
.07592 .64902 L
.0149 .69594 L
s
.0149 .69594 m
0 .70771 L
s
1 0 0 r
.44287 .43957 m
.43687 .43954 L
s
% Start of user PostScript
-6.8561293 -7.2515562 -7.5757383 -7.2552638 MAarrowhead1
% End of user PostScript
1 .158 0 r
.43007 .44 m
.42234 .44107 L
s
% Start of user PostScript
-8.3918116 -7.1995922 -9.3189354 -7.0718567 MAarrowhead1
% End of user PostScript
1 .473 0 r
.32721 .47896 m
.3046 .49163 L
s
% Start of user PostScript
-20.735385 -2.5242561 -23.448166 -1.0040229 MAarrowhead1
% End of user PostScript
1 .788 0 r
.0149 .69594 m
0 0 rlineto s
.0149 .69594 m
0 .70771 L
s
% Start of user PostScript
-58.212548 23.51324 -66.674215 30.195836 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-177.41235 125.64706 -204.69291 150.27356 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-565.36922 488.14449 -654.73076 573.54664 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1841.7946 1726.5888 -2136.6756 2015.5631 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6062.3158 5890.449 -7038.6556 6857.977 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-20049.042 19792.647 -23286.576 23017.035 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-66447.971 66065.475 -77190.956 76788.848 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-220440.21 219869.59 -256099.21 255499.33 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-731626.44 730775.18 -850005.12 849110.22 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2428696.2 2427426.3 -2821707.4 2820372.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-8062975. 8061080.5 -9367788.1 9365796.5 MAarrowhead1
% End of user PostScript
0 .548 1 r
.48286 .55855 m
.47894 .56459 L
.47433 .57143 L
.46891 .57919 L
.46255 .58802 L
.45509 .59807 L
.44636 .60954 L
.43613 .62263 L
.42417 .6376 L
.41019 .65475 L
.39386 .6744 L
.3748 .69697 L
.35255 .72289 L
.32661 .75271 L
.29635 .78703 L
.26109 .82657 L
.22001 .87215 L
.17215 .92473 L
.11641 .98543 L
s
.11641 .98543 m
.10293 1 L
s
1 0 0 r
.48286 .55855 m
.47894 .56459 L
s
% Start of user PostScript
-2.0566577 7.0254544 -2.5268368 7.7503891 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47433 .57143 m
.46891 .57919 L
s
% Start of user PostScript
-3.0801486 8.5715182 -3.7304079 9.503326 MAarrowhead1
% End of user PostScript
1 .473 0 r
.39386 .6744 m
.3748 .69697 L
s
% Start of user PostScript
-12.736411 20.928571 -15.024036 23.636218 MAarrowhead1
% End of user PostScript
1 .788 0 r
.11641 .98543 m
0 0 rlineto s
.11641 .98543 m
.10293 1 L
s
% Start of user PostScript
-46.030788 58.252056 -53.817951 66.665817 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-158.41361 176.6456 -184.5543 203.72107 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-534.28506 561.48399 -621.50248 650.09593 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1786.3208 1826.8968 -2076.5302 2119.1866 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5949.3401 6009.8724 -6913.8202 6977.4561 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-19780.172 19870.476 -22983.778 23078.711 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-65713.76 65848.477 -76352.22 76493.845 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-218238.94 218439.92 -253563.03 253774.31 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-724670.67 724970.49 -841955.48 842270.67 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2406128.4 2406575.7 -2795534.7 2796004.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-7988832. 7989499.3 -9281717. 9282418.5 MAarrowhead1
% End of user PostScript
.336 1 0 r
.50865 .57068 m
.50786 .57554 L
.50682 .58085 L
.5055 .58667 L
.50385 .59305 L
.50179 .60008 L
.49926 .60783 L
.49618 .6164 L
.49245 .6259 L
.48796 .63646 L
.48257 .64822 L
.47614 .66137 L
.46848 .67608 L
.45938 .69259 L
.44861 .71115 L
.43587 .73208 L
.42085 .75571 L
.40316 .78245 L
.38236 .81277 L
.35793 .8472 L
.32927 .88638 L
.29568 .93103 L
.25634 .98199 L
s
.25634 .98199 m
.24211 1 L
s
1 0 0 r
.50865 .57068 m
.50786 .57554 L
s
% Start of user PostScript
1.0378612 8.4820956 0.94268354 9.0653718 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50682 .58085 m
.5055 .58667 L
s
% Start of user PostScript
0.8186115 9.7025678 0.6602772 10.400335 MAarrowhead1
% End of user PostScript
1 .473 0 r
.48257 .64822 m
.47614 .66137 L
s
% Start of user PostScript
-2.0910617 17.786817 -2.8633101 19.363804 MAarrowhead1
% End of user PostScript
1 .788 0 r
.38236 .81277 m
.35793 .8472 L
s
% Start of user PostScript
-14.116676 37.531991 -17.048455 41.664299 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-57.571525 92.50307 -67.854104 104.57663 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-207.11046 259.2222 -242.06844 296.85201 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-711.44982 789.19141 -828.73561 910.46309 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2397.6302 2513.607 -2788.8545 2910.7776 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8013.4224 8186.4395 -9315.0509 9496.9388 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-26684.581 26942.692 -31010.194 31281.539 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-88713.904 89098.961 -103081.49 103486.29 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-294716.53 295290.97 -342427.64 343031.53 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-978755.91 979612.87 -1137175.8 1138076.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3249975.8 3251254.2 -3775968.5 3777312.4 MAarrowhead1
% End of user PostScript
.753 0 1 r
.48436 .5175 m
.48178 .52018 L
.47877 .52328 L
.47528 .52688 L
.47122 .53105 L
.4665 .53589 L
.46101 .5415 L
.45463 .54801 L
.44722 .55556 L
.4386 .56432 L
.42858 .57448 L
.41694 .58628 L
.40341 .59998 L
.38769 .61588 L
.36941 .63433 L
.34817 .65576 L
.3235 .68064 L
.29482 .70954 L
.26149 .74308 L
.22277 .78204 L
.17777 .82729 L
.12548 .87984 L
.06472 .94087 L
s
.06472 .94087 m
.00583 1 L
s
1 0 0 r
.48436 .5175 m
.48178 .52018 L
s
% Start of user PostScript
-1.8769196 2.1001277 -2.1868391 2.4214914 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47877 .52328 m
.47528 .52688 L
s
% Start of user PostScript
-2.5472305 2.7939137 -2.9662782 3.225609 MAarrowhead1
% End of user PostScript
1 .473 0 r
.42858 .57448 m
.41694 .58628 L
s
% Start of user PostScript
-8.5698554 8.9378634 -9.9669235 10.3538 MAarrowhead1
% End of user PostScript
1 .788 0 r
.26149 .74308 m
.22277 .78204 L
s
% Start of user PostScript
-28.621128 29.170132 -33.268182 33.845333 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-95.276427 96.095444 -110.71805 111.57906 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-316.70323 317.92506 -367.99043 369.2749 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1052.0502 1053.873 -1222.3584 1224.2746 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3493.7629 3496.4821 -4059.2485 4062.1071 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-11600.944 11605.001 -13478.486 13482.751 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-38518.345 38524.397 -44752.099 44758.461 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-127888.18 127897.2 -148585.11 148594.6 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-424607.82 424621.29 -493324.28 493338.44 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1409753.8 1409773.9 -1637900.8 1637921.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-4680556.5 4680586.5 -5438031.7 5438063.2 MAarrowhead1
% End of user PostScript
0 .385 1 r
.42191 .4508 m
.41279 .45339 L
.40237 .45694 L
.39046 .46164 L
.37682 .4677 L
.36119 .47536 L
.34324 .48493 L
.32262 .49674 L
.29891 .51119 L
.27161 .52875 L
.24017 .54996 L
.20392 .57544 L
.1621 .60595 L
.11383 .64233 L
.05808 .68558 L
s
.05808 .68558 m
0 .73181 L
s
1 0 0 r
.42191 .4508 m
.41279 .45339 L
s
% Start of user PostScript
-9.3711275 -5.9043775 -10.46547 -5.5932271 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40237 .45694 m
.39046 .46164 L
s
% Start of user PostScript
-11.715266 -5.1667777 -13.144564 -4.6030403 MAarrowhead1
% End of user PostScript
1 .473 0 r
.24017 .54996 m
.20392 .57544 L
s
% Start of user PostScript
-31.179726 5.9946762 -35.529539 9.0532239 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-92.008929 54.437249 -105.86061 66.362593 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-288.3074 232.25704 -333.41613 274.49201 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-931.59517 847.97786 -1080.0479 992.14346 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3054.7857 2930.0433 -3545.7066 3414.5686 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-10085.229 9899.1355 -11712.221 11516.586 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-33399.082 33121.462 -38796.523 38504.67 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-110761.96 110347.8 -128675.59 128240.2 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-367553.37 366935.52 -427019.01 426369.48 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1220037.8 1219116. -1417456.2 1416487.2 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4050246.7 4048871.7 -4705677.3 4704231.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-13446664. 13444613. -15622738. 15620582. MAarrowhead1
% End of user PostScript
0 .287 1 r
.54538 .57515 m
.54939 .57732 L
.55388 .57933 L
.55891 .58112 L
.56458 .58264 L
.57096 .5838 L
.57817 .58453 L
.58632 .58472 L
.59556 .58425 L
.60605 .58297 L
.61799 .58073 L
.6316 .57731 L
.64712 .5725 L
.66486 .56602 L
.68515 .55756 L
.70841 .54675 L
.73508 .53316 L
.76571 .51628 L
.80092 .49553 L
.84143 .47023 L
.88807 .43957 L
.94181 .40262 L
s
.94181 .40262 m
1 .36101 L
s
1 0 0 r
.54538 .57515 m
.54939 .57732 L
s
% Start of user PostScript
5.445026 9.018577 5.9264323 9.2787355 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55388 .57933 m
.55891 .58112 L
s
% Start of user PostScript
6.4652492 9.5195042 7.0697167 9.7345925 MAarrowhead1
% End of user PostScript
1 .473 0 r
.61799 .58073 m
.6316 .57731 L
s
% Start of user PostScript
14.159183 9.6872668 15.791489 9.2775944 MAarrowhead1
% End of user PostScript
1 .788 0 r
.80092 .49553 m
.84143 .47023 L
s
% Start of user PostScript
36.110574 -0.53585072 40.971188 -3.5725097 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
103.63108 -50.559829 118.93521 -63.142934 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
319.80986 -240.63686 369.37764 -286.14536 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1025.6183 -907.50605 1188.3337 -1064.1657 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3351.1867 -3174.984 3888.6531 -3703.4162 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
11045.794 -10782.931 12826.116 -12549.775 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
36553.18 -36161.034 42457.897 -42045.645 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
121181.59 -120596.58 140776.75 -140161.75 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
402069.66 -401196.93 467114.18 -466196.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1334519.4 -1333217.4 1550454.3 -1549085.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4430165.3 -4428223. 5147064.1 -5145022.2 MAarrowhead1
% End of user PostScript
1 .599 0 r
.52808 .43651 m
.53361 .42917 L
.54007 .42079 L
.54764 .41122 L
.55649 .40026 L
.56682 .38771 L
.5789 .37331 L
.59298 .35677 L
.60942 .33775 L
.62859 .31587 L
.65094 .29068 L
.67698 .26165 L
.70731 .22816 L
.74265 .18952 L
.78379 .1449 L
.83169 .09335 L
.88744 .03375 L
s
.88744 .03375 m
.91921 0 L
s
1 0 0 r
.52808 .43651 m
.53361 .42917 L
s
% Start of user PostScript
3.3698838 -7.6191487 4.0326994 -8.4998288 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54007 .42079 m
.54764 .41122 L
s
% Start of user PostScript
4.8088033 -9.5049673 5.716838 -10.653779 MAarrowhead1
% End of user PostScript
1 .473 0 r
.65094 .29068 m
.67698 .26165 L
s
% Start of user PostScript
18.112279 -25.118133 21.237113 -28.602165 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
63.337071 -73.788576 73.876066 -84.863431 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
215.06358 -230.6554 250.29921 -266.69043 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
721.16284 -744.42309 838.51462 -862.96745 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2404.9766 -2439.6768 2795.1433 -2831.6226 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8000.664 -8052.4307 9296.8763 -9351.2971 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
26586.801 -26664.028 30891.591 -30972.777 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
88306.587 -88421.795 102600.8 -102721.92 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
293240.85 -293412.72 340702.01 -340882.7 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
973672.47 -973928.87 1131253.1 -1131522.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3232823.6 -3233206.1 3756015.8 -3756417.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
10733527. -10734098. 12470595. -12471195. MAarrowhead1
% End of user PostScript
.226 0 1 r
.57542 .55374 m
.58405 .55172 L
.5939 .54884 L
.60515 .5449 L
.61802 .53973 L
.63276 .53308 L
.64966 .52468 L
.66907 .51421 L
.69136 .50132 L
.717 .48555 L
.74652 .46642 L
.78053 .44332 L
.81975 .41559 L
.86499 .38241 L
.91722 .34287 L
.97755 .29587 L
s
.97755 .29587 m
1 .27793 L
s
1 0 0 r
.57542 .55374 m
.58405 .55172 L
s
% Start of user PostScript
9.0500618 6.4484835 10.08628 6.206893 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5939 .54884 m
.60515 .5449 L
s
% Start of user PostScript
11.268229 5.8603125 12.618368 5.3883727 MAarrowhead1
% End of user PostScript
1 .473 0 r
.74652 .46642 m
.78053 .44332 L
s
% Start of user PostScript
29.582843 -4.0300618 33.664061 -6.8011607 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
86.539011 -48.41874 99.490312 -59.415573 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
269.89588 -213.02712 312.00238 -252.2179 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
870.09272 -785.25449 1008.5585 -919.37055 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2850.0323 -2723.4685 3307.7668 -3174.714 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9404.5915 -9215.7806 10921.358 -10722.866 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
31138.043 -30856.37 36169.459 -35873.345 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
103253.2 -102832.99 119951.49 -119509.74 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
342620.63 -341993.75 398051.05 -397392.04 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1137254. -1136318.8 1321274.8 -1320291.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3775388.9 -3773993.7 4386337.5 -4384870.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
12534095. -12532013. 14562483. -14560295. MAarrowhead1
% End of user PostScript
0 .254 1 r
.43574 .50535 m
.42697 .5111 L
.41686 .51804 L
.40521 .52635 L
.39176 .53629 L
.37623 .54813 L
.35829 .56219 L
.33756 .57885 L
.31358 .59854 L
.28584 .62178 L
.25374 .64915 L
.21657 .68134 L
.17352 .71915 L
.12365 .76352 L
.06586 .81552 L
s
.06586 .81552 m
0 .8754 L
s
1 0 0 r
.43574 .50535 m
.42697 .5111 L
s
% Start of user PostScript
-7.7109577 0.64228927 -8.7634711 1.3323843 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41686 .51804 m
.40521 .52635 L
s
% Start of user PostScript
-9.9762998 2.164213 -11.374874 3.1622534 MAarrowhead1
% End of user PostScript
1 .473 0 r
.25374 .64915 m
.21657 .68134 L
s
% Start of user PostScript
-29.551787 17.897523 -34.012145 21.760355 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-92.788539 75.40242 -107.32434 89.046812 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-300.12207 274.18503 -347.97518 320.70832 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-984.58525 945.89173 -1142.8553 1102.178 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3251.2524 3193.5284 -3775.8208 3715.1373 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-10768.154 10682.04 -12508.43 12417.901 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-35712.17 35583.703 -41488.071 41353.017 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-118509.86 118318.21 -137683.52 137482.04 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-393379. 393093.09 -457033.29 456732.72 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1305933.6 1305507.1 -1517266.6 1516818.2 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4335657.2 4335020.9 -5037297.4 5036628.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-14394598. 14393649. -16724111. 16723113. MAarrowhead1
% End of user PostScript
0 .488 1 r
.55027 .48272 m
.55749 .47719 L
.56583 .47062 L
.57548 .46285 L
.58664 .45366 L
.59954 .44282 L
.61448 .43005 L
.63178 .41504 L
.65181 .3974 L
.67502 .37672 L
.70191 .35248 L
.73309 .32409 L
.76923 .29088 L
.81113 .25206 L
.85974 .20669 L
.91612 .15372 L
.98153 .09188 L
s
.98153 .09188 m
1 .07433 L
s
1 0 0 r
.55027 .48272 m
.55749 .47719 L
s
% Start of user PostScript
6.0319218 -2.0732131 6.8986715 -2.7369955 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56583 .47062 m
.57548 .46285 L
s
% Start of user PostScript
7.9000807 -3.5250311 9.0576545 -4.4582912 MAarrowhead1
% End of user PostScript
1 .473 0 r
.70191 .35248 m
.73309 .32409 L
s
% Start of user PostScript
24.229474 -17.702667 27.970227 -21.108783 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
77.46146 -67.724608 89.728243 -79.492172 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
252.73065 -238.20498 293.22963 -277.9592 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
832.45602 -810.78626 966.57694 -943.79615 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2753.9467 -2721.6192 3198.736 -3164.751 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9128.6489 -9080.4219 10604.644 -10553.944 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
30286.138 -30214.192 35185.484 -35109.849 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
100520.64 -100413.3 116785.35 -116672.52 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
333691.21 -333531.09 387689.44 -387521.12 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1107820.6 -1107581.8 1287097.3 -1286846.2 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3677984.9 -3677628.5 4273198.9 -4272824.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
12211177. -12210645. 14187349. -14186790. MAarrowhead1
% End of user PostScript
1 .789 0 r
.48063 .51134 m
.47771 .51385 L
.47434 .51679 L
.47043 .52024 L
.46591 .52429 L
.46066 .52903 L
.45458 .53458 L
.44753 .54108 L
.43935 .54867 L
.42987 .55754 L
.41886 .5679 L
.4061 .57999 L
.39129 .59408 L
.3741 .61052 L
.35415 .62968 L
.33099 .65201 L
.30411 .67802 L
.2729 .70831 L
.23667 .74358 L
.1946 .78464 L
.14575 .83243 L
.08902 .88804 L
.02315 .95274 L
s
.02315 .95274 m
0 .97551 L
s
1 0 0 r
.48063 .51134 m
.47771 .51385 L
s
% Start of user PostScript
-2.3247146 1.3613016 -2.6743035 1.6614953 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47434 .51679 m
.47043 .52024 L
s
% Start of user PostScript
-3.0791026 2.0143666 -3.5479767 2.4286505 MAarrowhead1
% End of user PostScript
1 .473 0 r
.41886 .5679 m
.4061 .57999 L
s
% Start of user PostScript
-9.7363185 8.147919 -11.268084 9.5982451 MAarrowhead1
% End of user PostScript
1 .788 0 r
.23667 .74358 m
.1946 .78464 L
s
% Start of user PostScript
-31.599701 29.230088 -36.648117 34.157011 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-103.83162 100.29657 -120.53742 116.82112 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-343.11733 337.84366 -398.4997 392.95564 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1136.7792 1128.9118 -1320.5315 1312.2608 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3770.6439 3758.9071 -4380.5388 4368.2003 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-12513.614 12496.105 -14538.261 14519.854 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-41538.659 41512.538 -48260.314 48232.854 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-137901.27 137862.3 -160217.33 160176.37 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-457830.51 457772.38 -531921.56 531860.45 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1520024.3 1519937.5 -1766013.8 1765922.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-5046618.6 5046489.3 -5863330.8 5863194.8 MAarrowhead1
% End of user PostScript
.503 0 1 r
.54194 .51199 m
.54723 .50946 L
.55331 .50629 L
.56029 .50236 L
.56831 .49755 L
.57755 .49169 L
.58818 .4846 L
.60044 .47608 L
.61458 .46586 L
.6309 .45366 L
.64975 .43915 L
.67153 .42193 L
.6967 .40155 L
.72582 .37747 L
.75951 .34907 L
.79851 .31564 L
.84366 .27634 L
.89596 .2302 L
.95656 .17607 L
s
.95656 .17607 m
1 .13684 L
s
1 0 0 r
.54194 .51199 m
.54723 .50946 L
s
% Start of user PostScript
5.032248 1.4384762 5.6677821 1.1347031 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55331 .50629 m
.56029 .50236 L
s
% Start of user PostScript
6.3969973 0.75425884 7.2345842 0.28332471 MAarrowhead1
% End of user PostScript
1 .473 0 r
.64975 .43915 m
.67153 .42193 L
s
% Start of user PostScript
17.970132 -7.301712 20.583432 -9.3680296 MAarrowhead1
% End of user PostScript
1 .788 0 r
.95656 .17607 m
0 0 rlineto s
.95656 .17607 m
1 .13684 L
s
% Start of user PostScript
54.786693 -38.87128 63.213142 -46.481728 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
174.62372 -150.88071 202.22754 -177.26721 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
568.91888 -533.49848 660.01039 -622.77395 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1872.6875 -1819.8465 2174.2919 -2118.7416 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6193.3893 -6114.5597 7193.5128 -7110.6416 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
20526.746 -20409.146 23845.425 -23721.796 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
68097.444 -67922.005 79113.093 -78928.659 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
226011.29 -225749.56 262580.42 -262305.28 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
750264.27 -749873.83 871671.93 -871261.47 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2490786.6 -2490204.2 2893865.1 -2893252.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
8269436.7 -8268567.7 9607690.7 -9606777.2 MAarrowhead1
% End of user PostScript
0 1 .48 r
.48245 .54778 m
.47877 .55301 L
.47446 .55895 L
.4694 .56572 L
.46348 .57344 L
.45655 .58227 L
.44845 .59236 L
.43898 .60392 L
.42791 .61718 L
.415 .63241 L
.39994 .64991 L
.38236 .67003 L
.36188 .69321 L
.338 .7199 L
.31019 .75069 L
.27778 .78621 L
.24005 .82723 L
.19613 .8746 L
.14499 .92936 L
.08549 .99268 L
s
.08549 .99268 m
.07857 1 L
s
1 0 0 r
.48245 .54778 m
.47877 .55301 L
s
% Start of user PostScript
-2.1060095 5.7336518 -2.5471049 6.3607403 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47446 .55895 m
.4694 .56572 L
s
% Start of user PostScript
-3.0647255 7.0738903 -3.6715196 7.8862385 MAarrowhead1
% End of user PostScript
1 .473 0 r
.39994 .64991 m
.38236 .67003 L
s
% Start of user PostScript
-12.007728 17.988699 -14.116309 20.403931 MAarrowhead1
% End of user PostScript
1 .788 0 r
.14499 .92936 m
.08549 .99268 L
s
% Start of user PostScript
-42.600803 51.523363 -49.741698 59.121728 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-145.51791 158.8288 -169.43561 183.42897 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-489.22052 509.07804 -568.94203 589.81767 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1633.3457 1662.9696 -1898.4958 1929.6385 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5436.4389 5480.6326 -6317.4624 6363.922 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-18069.813 18135.742 -20995.949 21065.259 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-60024.025 60122.38 -69740.686 69844.084 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-199331.74 199478.46 -231594.49 231748.74 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-661871.74 662090.63 -768991.3 769221.41 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2197591.6 2197918.2 -2553246.2 2553589.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-7296410.3 7296897.5 -8477232.8 8477745. MAarrowhead1
% End of user PostScript
1 0 .805 r
.41816 .54229 m
.40601 .55241 L
.39195 .56434 L
.37568 .57838 L
.35683 .59487 L
.33499 .61423 L
.30969 .63693 L
.28037 .66352 L
.24637 .69463 L
.20696 .73102 L
.16125 .77355 L
.10823 .82323 L
.04672 .88122 L
s
.04672 .88122 m
0 .92552 L
s
1 0 0 r
.41816 .54229 m
.40601 .55241 L
s
% Start of user PostScript
-9.8202619 5.0746733 -11.278345 6.2894447 MAarrowhead1
% End of user PostScript
1 .158 0 r
.39195 .56434 m
.37568 .57838 L
s
% Start of user PostScript
-12.96567 7.7209835 -14.918992 9.4054048 MAarrowhead1
% End of user PostScript
1 .473 0 r
.16125 .77355 m
.10823 .82323 L
s
% Start of user PostScript
-40.650336 32.826183 -47.012686 38.78738 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-131.38766 119.71539 -152.32805 140.05733 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-430.88731 413.47433 -500.13832 481.83257 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1422.6372 1396.6601 -1652.1506 1624.8417 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-4711.4485 4672.6953 -5472.8511 5432.1109 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-15624.847 15567.034 -18151.884 18091.107 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-51849.894 51763.647 -60238.598 60147.929 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-172108.29 171979.62 -199957.75 199822.49 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-571360.83 571168.89 -663821.28 663619.49 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1896897. 1896610.7 -2203872. 2203571. MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-6297789.1 6297361.9 -7316975.2 7316526.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-20909201. 20908564. -24293008. 24292338. MAarrowhead1
% End of user PostScript
.762 0 1 r
.49659 .46345 m
.49714 .46084 L
.49784 .45799 L
.49872 .45485 L
.49979 .4514 L
.50111 .44758 L
.5027 .44335 L
.50463 .43866 L
.50695 .43343 L
.50972 .4276 L
.51303 .42109 L
.51696 .41378 L
.52162 .40557 L
.52713 .39632 L
.53363 .38589 L
.5413 .3741 L
.55032 .36074 L
.56093 .34558 L
.57337 .32834 L
.58796 .30871 L
.60505 .28632 L
.62506 .26075 L
.64845 .2315 L
.67579 .198 L
.70773 .15959 L
.74502 .1155 L
.78852 .06484 L
.83927 .00658 L
s
.83927 .00658 m
.84507 0 L
s
1 0 0 r
.49659 .46345 m
.49714 .46084 L
s
% Start of user PostScript
-0.40898867 -4.3864731 -0.3426267 -4.6987036 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49784 .45799 m
.49872 .45485 L
s
% Start of user PostScript
-0.2587291 -5.0410758 -0.15410956 -5.4174221 MAarrowhead1
% End of user PostScript
1 .473 0 r
.51303 .42109 m
.51696 .41378 L
s
% Start of user PostScript
1.5633871 -9.4697669 2.0349353 -10.346684 MAarrowhead1
% End of user PostScript
1 .788 0 r
.57337 .32834 m
.58796 .30871 L
s
% Start of user PostScript
8.8044213 -20.599354 10.555299 -22.954971 MAarrowhead1
% End of user PostScript
.897 1 0 r
.78852 .06484 m
.83927 .00658 L
s
% Start of user PostScript
34.622854 -52.218826 40.712384 -59.21052 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
122.99457 -149.24467 143.62487 -171.22085 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
420.35456 -459.51512 489.46475 -530.63311 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1413.5255 -1471.9462 1643.8972 -1705.3131 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
4719.7726 -4806.926 5486.0024 -5577.6242 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
15710.032 -15840.05 18256.047 -18392.731 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
52218.571 -52412.535 60674.686 -60878.594 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
173460.42 -173749.78 201540.25 -201844.45 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
576041.13 -576472.8 669276.24 -669730.04 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1912721.2 -1913365.2 2222282.8 -2222959.8 MAarrowhead1
% End of user PostScript
0 1 .18 r
.47768 .47432 m
.4754 .47414 L
.47281 .47414 L
.46988 .47436 L
.46654 .47483 L
.46275 .47562 L
.45842 .47679 L
.45349 .4784 L
.44784 .48055 L
.44138 .48335 L
.43397 .48689 L
.42548 .49133 L
.41572 .49683 L
.40449 .50357 L
.39158 .51177 L
.3767 .52169 L
.35956 .53362 L
.33978 .54792 L
.31696 .56499 L
.2906 .5853 L
.26014 .60939 L
.22493 .63791 L
.18421 .6716 L
.13709 .71133 L
.08254 .7581 L
.01939 .81309 L
s
.01939 .81309 m
0 .8302 L
s
1 0 0 r
.47768 .47432 m
.4754 .47414 L
s
% Start of user PostScript
-2.6780544 -3.0815507 -2.9522553 -3.1026511 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47281 .47414 m
.46988 .47436 L
s
% Start of user PostScript
-3.2626689 -3.1026792 -3.6147373 -3.0769692 MAarrowhead1
% End of user PostScript
1 .473 0 r
.43397 .48689 m
.42548 .49133 L
s
% Start of user PostScript
-7.9230132 -1.5729703 -8.9427516 -1.0401014 MAarrowhead1
% End of user PostScript
1 .788 0 r
.31696 .56499 m
.2906 .5853 L
s
% Start of user PostScript
-21.964972 7.7986294 -25.128088 10.235421 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-66.451222 45.317522 -76.621153 54.403905 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-210.96618 179.43841 -244.23628 211.09204 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-686.02189 638.98798 -795.74367 746.29828 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2256.175 2186.0086 -2619.3619 2545.598 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7458.6935 7354.0176 -8662.8722 8552.8295 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-24715.89 24559.732 -28711.451 28547.287 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-81988.269 81755.309 -95250.339 95005.435 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-272104.16 271756.62 -316130.32 315764.97 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-903258.78 902740.31 -1049422.6 1048877.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2998687.8 2997914.3 -3483956.8 3483143.6 MAarrowhead1
% End of user PostScript
1 .195 0 r
.52284 .56904 m
.524 .5726 L
.52521 .57634 L
.52649 .58027 L
.52782 .58441 L
.52922 .58876 L
.53069 .59334 L
.53223 .59816 L
.53384 .60324 L
.53553 .60858 L
.53729 .6142 L
.53914 .62012 L
.54107 .62635 L
.54309 .63292 L
.5452 .63983 L
.5474 .64712 L
.5497 .6548 L
.55209 .66289 L
.55457 .67143 L
.55716 .68043 L
.55984 .68993 L
.56262 .69996 L
.5655 .71054 L
.56847 .72173 L
.57153 .73354 L
.57467 .74604 L
.57789 .75927 L
.58117 .77327 L
.58451 .7881 L
.58789 .80383 L
.59129 .82051 L
.59468 .83824 L
.59803 .85708 L
.60132 .87713 L
.60449 .89848 L
.6075 .92126 L
.61028 .94559 L
.61276 .97161 L
.61486 .99948 L
s
.61486 .99948 m
.61489 1 L
s
1 0 0 r
.52284 .56904 m
.524 .5726 L
s
% Start of user PostScript
2.7410113 8.2852288 2.8798269 8.7117407 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52521 .57634 m
.52649 .58027 L
s
% Start of user PostScript
3.0254814 9.1603985 3.1782806 9.6323827 MAarrowhead1
% End of user PostScript
1 .473 0 r
.53729 .6142 m
.53914 .62012 L
s
% Start of user PostScript
4.4751147 13.704082 4.6968542 14.41441 MAarrowhead1
% End of user PostScript
1 .788 0 r
.55457 .67143 m
.55716 .68043 L
s
% Start of user PostScript
6.5486831 20.571491 6.8588614 21.651794 MAarrowhead1
% End of user PostScript
.897 1 0 r
.57789 .75927 m
.58117 .77327 L
s
% Start of user PostScript
9.3464927 31.112054 9.7407692 32.792131 MAarrowhead1
% End of user PostScript
.581 1 0 r
.60449 .89848 m
.6075 .92126 L
s
% Start of user PostScript
12.538937 47.818121 12.89985 50.551781 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
14.043152 75.998998 13.826979 80.831731 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5.4690662 128.85804 2.6412415 138.57296 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-43.239361 243.63185 -55.775976 266.44281 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-235.15374 534.10421 -281.4729 595.75088 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-917.38012 1363.3618 -1078.1709 1547.0186 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-3249.6555 3914.982 -3793.9512 4493.3897 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-11093.339 12085.889 -12916.056 13959.496 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-37284.851 38765.562 -43359.744 44916.373 MAarrowhead1
% End of user PostScript
1 0 .522 r
.44671 .56192 m
.43785 .57122 L
.42754 .58199 L
.41555 .59447 L
.4016 .60893 L
.38539 .62569 L
.36653 .64511 L
.34461 .66763 L
.31912 .69374 L
.2895 .72403 L
.25506 .75916 L
.21502 .79993 L
.16849 .84722 L
.11441 .90211 L
.05155 .96582 L
s
.05155 .96582 m
.01778 1 L
s
1 0 0 r
.44671 .56192 m
.43785 .57122 L
s
% Start of user PostScript
-6.3949642 7.4299065 -7.458495 8.5465 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42754 .58199 m
.41555 .59447 L
s
% Start of user PostScript
-8.6956082 9.8393964 -10.134471 11.336902 MAarrowhead1
% End of user PostScript
1 .473 0 r
.25506 .75916 m
.21502 .79993 L
s
% Start of user PostScript
-29.393231 31.099562 -34.197226 35.991043 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-98.36888 100.91443 -114.35869 117.03476 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-327.75969 331.5572 -380.90739 384.89961 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1089.9362 1095.6014 -1266.4818 1272.4375 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3621.3051 3629.7566 -4207.5899 4216.4747 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-12027.019 12039.627 -13973.751 13987.006 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-39936.873 39955.682 -46400.547 46420.32 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-132603.69 132631.75 -154064.28 154093.78 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-440272.57 440314.43 -511524.9 511568.91 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1461775.5 1461838. -1698342.6 1698408.2 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4853294.2 4853387.4 -5638726. 5638823.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-16113547. 16113686. -18721274. 18721420. MAarrowhead1
% End of user PostScript
0 .654 1 r
.49099 .48551 m
.49018 .48512 L
.48928 .48475 L
.48826 .48444 L
.48712 .48419 L
.48582 .48401 L
.48436 .48392 L
.48271 .48395 L
.48083 .48411 L
.4787 .48445 L
.47627 .48499 L
.4735 .48577 L
.47034 .48685 L
.46673 .48827 L
.46259 .4901 L
.45784 .49242 L
.45239 .49532 L
.44613 .4989 L
.43893 .50328 L
.43065 .5086 L
.4211 .51503 L
.4101 .52276 L
.3974 .53201 L
.38275 .54305 L
.36583 .55617 L
.34627 .57173 L
.32366 .59013 L
.2975 .61187 L
.26724 .63749 L
.2322 .66764 L
.19163 .70307 L
.14463 .74467 L
.09018 .79344 L
.02708 .85058 L
s
.02708 .85058 m
0 .87534 L
s
1 0 0 r
.49099 .48551 m
.49018 .48512 L
s
% Start of user PostScript
-1.0808415 -1.738562 -1.1778282 -1.7861293 MAarrowhead1
% End of user PostScript
1 .158 0 r
.48928 .48475 m
.48826 .48444 L
s
% Start of user PostScript
-1.286515 -1.8294078 -1.4085906 -1.867089 MAarrowhead1
% End of user PostScript
1 .473 0 r
.47627 .48499 m
.4735 .48577 L
s
% Start of user PostScript
-2.8471758 -1.8012348 -3.1794606 -1.7072791 MAarrowhead1
% End of user PostScript
1 .788 0 r
.43893 .50328 m
.43065 .5086 L
s
% Start of user PostScript
-7.3282933 0.39367956 -8.3225839 1.0324249 MAarrowhead1
% End of user PostScript
.897 1 0 r
.32366 .59013 m
.2975 .61187 L
s
% Start of user PostScript
-21.161165 10.815937 -24.299816 13.424177 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-65.529018 50.095752 -75.70727 59.482723 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-210.50987 187.48614 -243.94118 219.737 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-688.39387 654.0465 -798.85018 762.74178 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2269.8489 2218.6086 -2635.7718 2581.9044 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-7512.7431 7436.3016 -8726.4493 8646.0886 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-24908.246 24794.209 -28936.101 28816.217 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-82646.166 82476.043 -96016.444 95837.597 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-274317.18 274063.38 -318704.07 318437.27 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-910649.1 910270.48 -1058012.8 1057614.8 MAarrowhead1
% End of user PostScript
0 .175 1 r
.55818 .51232 m
.56565 .50847 L
.57423 .50369 L
.58408 .49783 L
.59543 .49068 L
.60849 .48204 L
.62355 .47162 L
.64091 .45914 L
.66095 .44423 L
.68409 .42648 L
.71082 .40541 L
.74173 .38047 L
.77747 .35099 L
.81882 .31622 L
.86669 .27529 L
.92211 .22715 L
.98629 .17061 L
s
.98629 .17061 m
1 .15839 L
s
1 0 0 r
.55818 .51232 m
.56565 .50847 L
s
% Start of user PostScript
6.9818599 1.4783033 7.8779184 1.0160067 MAarrowhead1
% End of user PostScript
1 .158 0 r
.57423 .50369 m
.58408 .49783 L
s
% Start of user PostScript
8.9070003 0.44292613 10.090019 -0.26071121 MAarrowhead1
% End of user PostScript
1 .473 0 r
.71082 .40541 m
.74173 .38047 L
s
% Start of user PostScript
25.298683 -11.350232 29.00733 -14.343726 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
77.619124 -56.81048 89.605389 -67.729863 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
248.1935 -217.15065 287.50165 -254.8672 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
809.84258 -763.53209 939.62278 -890.9379 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2667.6048 -2598.5176 3097.4049 -3024.7756 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8825.1819 -8722.116 10250.55 -10142.199 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
29253.527 -29099.771 33983.5 -33821.86 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
97054.852 -96825.475 112755.31 -112514.17 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
322128.62 -321786.42 374250.6 -373890.86 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1069348.3 -1068837.8 1242391.3 -1241854.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3550127.9 -3549366.4 4124639.1 -4123838.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
11786492. -11785356. 13693918. -13692724. MAarrowhead1
% End of user PostScript
1 .71 0 r
.46155 .42266 m
.45853 .41974 L
.45518 .41685 L
.45147 .414 L
.44733 .41124 L
.44272 .40861 L
.43756 .40614 L
.43177 .40391 L
.42527 .40199 L
.41795 .40045 L
.4097 .3994 L
.40036 .39895 L
.38978 .39924 L
.37777 .40043 L
.36412 .4027 L
.34858 .40629 L
.33085 .41146 L
.3106 .4185 L
.28743 .42777 L
.26091 .4397 L
.23049 .45476 L
.19557 .47354 L
.15545 .4967 L
.10931 .52501 L
.05619 .55938 L
s
.05619 .55938 m
0 .59747 L
s
1 0 0 r
.46155 .42266 m
.45853 .41974 L
s
% Start of user PostScript
-4.6137569 -9.2809877 -4.9763591 -9.6307843 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45518 .41685 m
.45147 .414 L
s
% Start of user PostScript
-5.3779515 -9.9781162 -5.8238344 -10.319556 MAarrowhead1
% End of user PostScript
1 .473 0 r
.4097 .3994 m
.40036 .39895 L
s
% Start of user PostScript
-10.836583 -12.071978 -11.957102 -12.126006 MAarrowhead1
% End of user PostScript
1 .788 0 r
.28743 .42777 m
.26091 .4397 L
s
% Start of user PostScript
-25.507836 -8.6677207 -28.691238 -7.2365369 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-69.068273 18.084333 -78.836648 25.238706 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-206.01136 129.95225 -237.24871 157.28998 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-649.21722 535.75038 -751.14649 631.86207 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2103.6144 1934.3418 -2439.3725 2261.421 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6906.876 6654.3509 -8017.665 7752.1927 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-22816.213 22439.49 -26498.245 26102.207 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-75580.306 75018.301 -87796.253 87205.434 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-250678.58 249840.16 -291223.78 290342.38 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-831898.97 830648.2 -966494.13 965179.24 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2761430.1 2759564.2 -3208272.5 3206310.9 MAarrowhead1
% End of user PostScript
0 1 .077 r
.575 .44593 m
.58656 .43544 L
.59996 .42317 L
.6155 .40882 L
.63352 .39205 L
.65442 .37246 L
.67867 .34959 L
.7068 .3229 L
.73945 .29178 L
.77734 .25549 L
.82131 .2132 L
.87236 .16392 L
.93162 .10653 L
s
.93162 .10653 m
1 .04009 L
s
1 0 0 r
.575 .44593 m
.58656 .43544 L
s
% Start of user PostScript
9.0003262 -6.4883107 10.387453 -7.7466438 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59996 .42317 m
.6155 .40882 L
s
% Start of user PostScript
11.995505 -9.2192982 13.860052 -10.941506 MAarrowhead1
% End of user PostScript
1 .473 0 r
.82131 .2132 m
.87236 .16392 L
s
% Start of user PostScript
38.557549 -34.415935 44.683003 -40.329045 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
126.12255 -119.94399 146.36272 -139.86737 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
415.91756 -406.70023 482.97249 -473.28258 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1376.6819 -1362.9313 1599.0961 -1584.6405 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
4564.4599 -4543.9464 5302.5789 -5281.0136 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
15145.165 -15114.562 17595.325 -17563.153 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
50269.729 -50224.076 58403.831 -58355.837 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
166880.51 -166812.4 193885.61 -193814.01 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
554031.68 -553930.08 643690.17 -643583.36 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1839403.5 -1839251.9 2137077.8 -2136918.5 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
6106965.5 -6106739.4 7095275.4 -7095037.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
20275736. -20275399. 23557035. -23556681. MAarrowhead1
% End of user PostScript
1 .361 0 r
.41849 .4531 m
.40885 .45616 L
.39783 .46026 L
.38521 .4656 L
.37076 .4724 L
.35418 .48094 L
.33514 .49153 L
.31325 .50453 L
.28807 .52037 L
.25906 .53955 L
.22564 .56265 L
.18709 .59035 L
.1426 .62343 L
.09123 .6628 L
.03187 .70954 L
s
.03187 .70954 m
0 .73526 L
s
1 0 0 r
.41849 .4531 m
.40885 .45616 L
s
% Start of user PostScript
-9.7812949 -5.6276498 -10.938328 -5.2606502 MAarrowhead1
% End of user PostScript
1 .158 0 r
.39783 .46026 m
.38521 .4656 L
s
% Start of user PostScript
-12.260772 -4.768746 -13.774275 -4.1283647 MAarrowhead1
% End of user PostScript
1 .473 0 r
.22564 .56265 m
.18709 .59035 L
s
% Start of user PostScript
-32.923462 7.5184066 -37.549389 10.841789 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-97.697776 59.797887 -112.46104 72.617981 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-307.04502 250.50503 -355.17261 295.73375 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-993.58246 909.23471 -1152.0467 1063.3743 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3260.2569 3134.4248 -3784.4 3652.1164 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-10766.92 10579.2 -12504.187 12306.843 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-35661.63 35381.586 -41425.163 41130.76 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-118272.78 117855. -137401.82 136962.62 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-392488.51 391865.26 -455989.36 455334.16 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1302822.9 1301893.1 -1513638.5 1512661.1 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4325099.3 4323712.2 -5025010.1 5023551.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-14359201. 14357132. -16682955. 16680779. MAarrowhead1
% End of user PostScript
1 0 .702 r
.45956 .44697 m
.4556 .44614 L
.45113 .44557 L
.44608 .44532 L
.44036 .44548 L
.43386 .44613 L
.42647 .44736 L
.41806 .4493 L
.40846 .4521 L
.39751 .45591 L
.38497 .46093 L
.37061 .46738 L
.35415 .47553 L
.33526 .4857 L
.31355 .49823 L
.28857 .51355 L
.25983 .53215 L
.22671 .55461 L
.18852 .58158 L
.14447 .61384 L
.09362 .65231 L
.03487 .69803 L
s
.03487 .69803 m
0 .72586 L
s
1 0 0 r
.45956 .44697 m
.4556 .44614 L
s
% Start of user PostScript
-4.8525099 -6.3638028 -5.3277844 -6.4636009 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45113 .44557 m
.44608 .44532 L
s
% Start of user PostScript
-5.8640792 -6.5318634 -6.4704544 -6.5610417 MAarrowhead1
% End of user PostScript
1 .473 0 r
.38497 .46093 m
.37061 .46738 L
s
% Start of user PostScript
-13.803577 -4.688996 -15.52632 -3.9143883 MAarrowhead1
% End of user PostScript
1 .788 0 r
.18852 .58158 m
.14447 .61384 L
s
% Start of user PostScript
-37.377034 9.789356 -42.663372 13.661244 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-111.48654 70.330559 -128.39129 85.125202 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-351.33705 289.93955 -406.49834 341.95292 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1138.4169 1046.8226 -1320.12 1223.8296 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3737.8121 3601.1694 -4338.9411 4195.2927 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-12347.517 12143.671 -14340.134 14125.836 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-40902.029 40597.925 -47512.972 47193.276 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-135660.52 135206.85 -157602.5 157125.57 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-450201.43 449524.63 -523040.73 522329.23 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1494412. 1493402.4 -1736231.2 1735169.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-4961161.2 4959654.9 -5764005.3 5762421.9 MAarrowhead1
% End of user PostScript
1 .86 0 r
.43081 .499 m
.42155 .50466 L
.4109 .51153 L
.39862 .51983 L
.38447 .5298 L
.36814 .54173 L
.34929 .55596 L
.32752 .57287 L
.30236 .59293 L
.27327 .61665 L
.23962 .64465 L
.20068 .67766 L
.1556 .7165 L
.1034 .76214 L
.04293 .81572 L
s
.04293 .81572 m
0 .85421 L
s
1 0 0 r
.43081 .499 m
.42155 .50466 L
s
% Start of user PostScript
-8.3029791 -0.12012487 -9.4138643 0.55889848 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4109 .51153 m
.39862 .51983 L
s
% Start of user PostScript
-10.692592 1.383622 -12.165712 2.3794612 MAarrowhead1
% End of user PostScript
1 .473 0 r
.23962 .64465 m
.20068 .67766 L
s
% Start of user PostScript
-31.245775 17.358425 -35.918554 21.319184 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-97.392093 76.6746 -112.58082 90.80112 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-313.88373 282.97686 -363.82657 331.33508 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1028.004 981.89636 -1193.0958 1144.6242 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3392.0189 3323.2344 -3939.0624 3866.7513 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-11230.46 11127.845 -13045.096 12937.221 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-37239.537 37086.454 -43261.938 43101.007 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-123569.65 123341.27 -143561.14 143321.05 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-410161.29 409820.6 -476530.02 476171.86 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1361627.7 1361119.5 -1581971.7 1581437.4 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4520531. 4519772.7 -5252086.7 5251289.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-15008345. 15007214. -17437178. 17435989. MAarrowhead1
% End of user PostScript
1 .262 0 r
.47619 .51536 m
.47256 .51855 L
.46837 .52229 L
.46351 .52667 L
.45788 .5318 L
.45134 .53781 L
.44377 .54482 L
.43498 .55302 L
.42479 .5626 L
.41297 .57378 L
.39925 .58681 L
.38333 .60202 L
.36486 .61974 L
.34341 .6404 L
.31852 .66446 L
.28962 .69249 L
.25607 .72512 L
.21711 .76312 L
.17188 .80734 L
.11935 .8588 L
.05835 .91868 L
s
.05835 .91868 m
0 .97606 L
s
1 0 0 r
.47619 .51536 m
.47256 .51855 L
s
% Start of user PostScript
-2.8577925 1.8437759 -3.292253 2.2262467 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46837 .52229 m
.46351 .52667 L
s
% Start of user PostScript
-3.795587 2.6749254 -4.378867 3.2007478 MAarrowhead1
% End of user PostScript
1 .473 0 r
.39925 .58681 m
.38333 .60202 L
s
% Start of user PostScript
-12.089568 10.417738 -13.999864 12.242317 MAarrowhead1
% End of user PostScript
1 .788 0 r
.17188 .80734 m
.11935 .8588 L
s
% Start of user PostScript
-39.374632 36.880554 -45.677857 43.055905 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-129.58841 125.86768 -150.4574 146.54591 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-428.54801 422.99734 -497.74833 491.91307 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1420.2925 1412.0118 -1649.9155 1641.2103 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4711.7522 4699.3989 -5473.9335 5460.9469 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-15637.922 15619.493 -18168.164 18148.79 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-51911.305 51883.813 -60311.572 60282.67 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-172339.04 172298.02 -200228.26 200185.14 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-572167.01 572105.82 -664761.53 664697.21 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1899633.4 1899542.1 -2207056.6 2206960.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-6306963.2 6306827.1 -7327642.1 7327499. MAarrowhead1
% End of user PostScript
.935 0 1 r
.44292 .52226 m
.43464 .52875 L
.42508 .53644 L
.41401 .54553 L
.40122 .55626 L
.38641 .56889 L
.36926 .58374 L
.3494 .60119 L
.32639 .62166 L
.29973 .64566 L
.26883 .67376 L
.23301 .70664 L
.19147 .74509 L
.14329 .79001 L
.0874 .84248 L
.02257 .90372 L
s
.02257 .90372 m
0 .92515 L
s
1 0 0 r
.44292 .52226 m
.43464 .52875 L
s
% Start of user PostScript
-6.85 2.6717019 -7.8430731 3.4505491 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42508 .53644 m
.41401 .54553 L
s
% Start of user PostScript
-8.9909381 4.3732045 -10.318342 5.4638521 MAarrowhead1
% End of user PostScript
1 .473 0 r
.26883 .67376 m
.23301 .70664 L
s
% Start of user PostScript
-27.740324 20.851475 -32.039245 24.797197 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-88.952412 78.675457 -103.0639 92.26003 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-290.63509 275.30367 -337.24603 321.12855 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-957.9349 935.06312 -1112.3294 1088.2849 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3170.0018 3135.8811 -3682.0735 3646.2034 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-10509.181 10458.279 -12208.519 12155.007 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-34868.444 34792.507 -40509.253 40429.423 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-115732.6 115619.32 -134458.97 134339.88 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-384193.99 384024.99 -446365.06 446187.4 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1275491.7 1275239.6 -1481903. 1481637.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4234666.4 4234290.3 -4919970. 4919574.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-14059416. 14058855. -16334695. 16334105. MAarrowhead1
% End of user PostScript
1 0 .527 r
.55236 .50426 m
.55927 .50026 L
.56721 .49536 L
.57636 .48942 L
.5869 .48226 L
.59905 .47365 L
.61307 .46336 L
.62926 .45109 L
.64796 .43651 L
.66957 .41923 L
.69456 .3988 L
.72346 .37468 L
.75691 .34626 L
.79564 .31282 L
.84048 .27354 L
.89243 .22743 L
.95263 .17338 L
s
.95263 .17338 m
1 .1304 L
s
1 0 0 r
.55236 .50426 m
.55927 .50026 L
s
% Start of user PostScript
6.2830902 0.51145724 7.1121028 0.030808619 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56721 .49536 m
.57636 .48942 L
s
% Start of user PostScript
8.0656488 -0.55651256 9.1633886 -1.2692506 MAarrowhead1
% End of user PostScript
1 .473 0 r
.69456 .3988 m
.72346 .37468 L
s
% Start of user PostScript
23.346673 -12.144358 26.815324 -15.038654 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
72.393409 -55.681519 83.647212 -66.078485 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
232.71603 -207.78482 269.68833 -243.47887 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
761.24904 -724.05604 883.41715 -844.31723 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2510.4359 -2454.9505 2915.1767 -2856.8465 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8309.5798 -8226.8053 9652.0664 -9565.0479 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
27550.942 -27427.457 32006.215 -31876.399 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
91415.909 -91231.691 106205.04 -106011.38 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
303427.3 -303152.48 352524.64 -352235.72 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1007288.5 -1006878.5 1170291. -1169859.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3344128.2 -3343516.6 3885305.8 -3884662.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
11102617. -11101705. 12899376. -12898416. MAarrowhead1
% End of user PostScript
1 .13 0 r
.55148 .4998 m
.5584 .49552 L
.56636 .49032 L
.57553 .48405 L
.58611 .47653 L
.59831 .46754 L
.6124 .45683 L
.62868 .4441 L
.64749 .42902 L
.66925 .41119 L
.69441 .39014 L
.72354 .36535 L
.75726 .33619 L
.79631 .30193 L
.84155 .26173 L
.89397 .21461 L
.95472 .15942 L
s
.95472 .15942 m
1 .1179 L
s
1 0 0 r
.55148 .4998 m
.5584 .49552 L
s
% Start of user PostScript
6.1781471 -0.023790818 7.0078717 -0.53797474 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56636 .49032 m
.57553 .48405 L
s
% Start of user PostScript
7.9631522 -1.1615366 9.0638609 -1.913519 MAarrowhead1
% End of user PostScript
1 .473 0 r
.69441 .39014 m
.72354 .36535 L
s
% Start of user PostScript
23.329761 -13.182943 26.824849 -16.157793 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
72.819698 -57.682424 84.186012 -68.272634 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
234.85107 -212.26891 272.23383 -248.49386 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
769.41132 -735.7227 892.99724 -857.58136 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2539.1374 -2488.8799 2948.6676 -2895.8333 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8407.2616 -8332.2862 9765.772 -9686.9526 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
27878.822 -27766.972 32387.479 -32269.894 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
92509.826 -92342.965 107476.47 -107301.06 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
307067.17 -306818.24 356754.27 -356492.58 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1019385.1 -1019013.8 1184346.3 -1183955.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3384308.1 -3383754.1 3931989.7 -3931407.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
11236045. -11235219. 13054399. -13053531. MAarrowhead1
% End of user PostScript
1 0 .201 r
.52814 .53374 m
.53098 .53407 L
.5342 .53418 L
.53784 .53405 L
.54198 .53359 L
.54669 .53276 L
.55205 .53148 L
.55816 .52965 L
.56515 .52716 L
.57314 .5239 L
.58229 .51973 L
.59279 .51446 L
.60484 .50791 L
.61869 .49984 L
.63462 .48998 L
.65297 .47803 L
.6741 .46361 L
.69847 .4463 L
.72659 .4256 L
.75905 .40094 L
.79655 .37165 L
.8399 .33693 L
.89002 .29587 L
.948 .24742 L
s
.948 .24742 m
1 .20318 L
s
1 0 0 r
.52814 .53374 m
.53098 .53407 L
s
% Start of user PostScript
3.3768241 4.0483968 3.7180709 4.0878492 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5342 .53418 m
.53784 .53405 L
s
% Start of user PostScript
4.1040203 4.1021178 4.5413673 4.0855086 MAarrowhead1
% End of user PostScript
1 .473 0 r
.58229 .51973 m
.59279 .51446 L
s
% Start of user PostScript
9.8750227 2.3670969 11.134758 1.7350288 MAarrowhead1
% End of user PostScript
1 .788 0 r
.72659 .4256 m
.75905 .40094 L
s
% Start of user PostScript
27.190687 -8.9275907 31.086265 -11.8868 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
81.928691 -54.683353 94.434476 -65.792239 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
259.55972 -218.91445 300.44191 -257.71271 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
843.19077 -782.55516 977.9719 -914.22743 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2771.777 -2681.3193 3217.8452 -3122.7496 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
9161.2781 -9026.3311 10640.157 -10498.291 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
30354.834 -30153.516 35261.721 -35050.082 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
100689.58 -100389.25 116976.3 -116660.57 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
334163.91 -333715.87 388230.69 -387759.68 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1109258.5 -1108590.1 1288756. -1288053.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3682562.3 -3681565.1 4278499.4 -4277451.1 MAarrowhead1
% End of user PostScript
1 .19 0 r
.55389 .52048 m
.56056 .51763 L
.5682 .514 L
.57696 .50945 L
.58703 .50381 L
.5986 .49689 L
.61192 .48847 L
.62726 .47828 L
.64494 .46601 L
.66532 .45131 L
.68886 .43376 L
.71603 .41288 L
.74743 .38809 L
.78372 .35874 L
.8257 .32407 L
.87427 .28317 L
.93049 .23503 L
.99558 .17842 L
s
.99558 .17842 m
1 .17453 L
s
1 0 0 r
.55389 .52048 m
.56056 .51763 L
s
% Start of user PostScript
6.4670846 2.4575743 7.2669958 2.1152402 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5682 .514 m
.57696 .50945 L
s
% Start of user PostScript
8.1837121 1.6795614 9.2354884 1.133486 MAarrowhead1
% End of user PostScript
1 .473 0 r
.68886 .43376 m
.71603 .41288 L
s
% Start of user PostScript
22.662645 -7.9483695 25.923522 -10.45483 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
68.517131 -46.566012 78.998803 -55.922226 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
217.45162 -184.7044 251.73758 -217.31137 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
706.99694 -658.14382 820.06291 -768.70505 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2324.9831 -2252.1028 2699.2305 -2622.6135 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
7685.904 -7577.1794 8926.7412 -8812.4421 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
25468.405 -25306.207 29585.581 -29415.067 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
84483.945 -84241.974 98149.652 -97895.275 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
280385.98 -280025. 325752.05 -325372.57 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
930749.24 -930210.72 1081361.4 -1080795.3 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3089950.1 -3089146.8 3589987.7 -3589143.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
10258629. -10257430. 11918793. -11917533. MAarrowhead1
% End of user PostScript
1 .277 0 r
.43349 .51694 m
.42409 .5238 L
.41325 .53197 L
.40072 .54169 L
.38625 .55321 L
.36951 .56684 L
.35016 .58293 L
.32776 .6019 L
.30183 .62423 L
.2718 .65046 L
.23702 .68126 L
.19672 .71737 L
.15001 .75967 L
.09586 .80919 L
.03309 .8671 L
s
.03309 .8671 m
0 .89786 L
s
1 0 0 r
.43349 .51694 m
.42409 .5238 L
s
% Start of user PostScript
-7.9815337 2.033386 -9.1088077 2.8556919 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41325 .53197 m
.40072 .54169 L
s
% Start of user PostScript
-10.410084 3.8363638 -11.913089 5.0023272 MAarrowhead1
% End of user PostScript
1 .473 0 r
.23702 .68126 m
.19672 .71737 L
s
% Start of user PostScript
-31.558025 21.751187 -36.394125 26.08448 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-100.29389 85.663808 -116.12049 100.74031 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-326.30043 304.47491 -378.50374 355.5592 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1073.3797 1040.8199 -1246.1893 1211.9601 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3548.8639 3500.2903 -4121.849 4070.785 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-11760.441 11687.978 -13661.681 13585.502 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-39012.92 38904.817 -45323.558 45209.913 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-129478.04 129316.77 -150427.57 150258.03 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-429808.53 429567.95 -499359.62 499106.7 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1426904.6 1426545.7 -1657816.7 1657439.4 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4737326.1 4736790.7 -5503972.9 5503410. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-15728232. 15727433. -18273576. 18272737. MAarrowhead1
% End of user PostScript
.735 0 1 r
.54027 .44711 m
.54714 .4396 L
.55513 .43092 L
.56444 .4209 L
.57527 .40932 L
.58788 .39592 L
.60255 .38042 L
.61962 .36248 L
.63947 .34171 L
.66256 .31765 L
.68942 .28978 L
.72065 .25748 L
.75696 .22005 L
.79918 .17665 L
.84826 .12633 L
.90533 .06796 L
.97166 .00026 L
s
.97166 .00026 m
.97191 0 L
s
1 0 0 r
.54027 .44711 m
.54714 .4396 L
s
% Start of user PostScript
4.832462 -6.3466621 5.6563735 -7.2482083 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55513 .43092 m
.56444 .4209 L
s
% Start of user PostScript
6.615768 -8.2892179 7.7326812 -9.4919308 MAarrowhead1
% End of user PostScript
1 .473 0 r
.68942 .28978 m
.72065 .25748 L
s
% Start of user PostScript
22.730012 -25.226506 26.477511 -29.102003 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
76.607378 -80.331709 89.108018 -93.0233 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
256.04774 -261.60379 297.63861 -303.47952 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
852.64797 -860.93662 990.86471 -999.57833 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2834.6795 -2847.0447 3293.7694 -3306.7686 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9417.1191 -9435.5658 10941.641 -10961.034 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
31274.368 -31301.887 36336.392 -36365.322 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
103847.14 -103888.19 120654.29 -120697.45 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
344803.4 -344864.64 400606.09 -400670.47 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1144815.6 -1144907. 1330088.5 -1330184.5 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3800963.4 -3801099.7 4416093.2 -4416236.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
12619705. -12619909. 14662011. -14662225. MAarrowhead1
% End of user PostScript
.317 1 0 r
.46789 .4177 m
.46586 .41387 L
.46366 .40991 L
.46127 .40581 L
.45868 .40159 L
.45585 .39725 L
.45277 .3928 L
.44939 .38826 L
.44569 .38364 L
.44162 .37896 L
.43713 .37425 L
.43217 .36954 L
.42667 .36487 L
.42057 .36029 L
.41377 .35585 L
.40619 .35162 L
.3977 .34769 L
.38818 .34416 L
.37748 .34113 L
.36543 .33876 L
.35183 .33719 L
.33645 .33663 L
.31901 .3373 L
.29922 .33947 L
.27672 .34345 L
.25108 .34961 L
.22184 .35839 L
.18842 .37028 L
.1502 .38588 L
.10641 .40588 L
.0562 .43109 L
s
.0562 .43109 m
0 .46166 L
s
1 0 0 r
.46789 .4177 m
.46586 .41387 L
s
% Start of user PostScript
-3.8528361 -9.8754921 -4.0968951 -10.3353 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46366 .40991 m
.46127 .40581 L
s
% Start of user PostScript
-4.3609958 -10.811153 -4.6473841 -11.302658 MAarrowhead1
% End of user PostScript
1 .473 0 r
.43713 .37425 m
.43217 .36954 L
s
% Start of user PostScript
-7.5442354 -15.089951 -8.1395243 -15.655142 MAarrowhead1
% End of user PostScript
1 .788 0 r
.37748 .34113 m
.36543 .33876 L
s
% Start of user PostScript
-14.702267 -19.063972 -16.148272 -19.349199 MAarrowhead1
% End of user PostScript
.897 1 0 r
.22184 .35839 m
.18842 .37028 L
s
% Start of user PostScript
-33.379607 -16.993702 -37.389212 -15.566792 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-87.799914 12.651768 -99.931793 20.930719 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-257.15779 145.04993 -295.67598 177.82022 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-802.55244 635.30717 -927.81012 751.99 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2588.1246 2338.624 -3000.0754 2737.7826 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-8478.8364 8106.6252 -9840.7143 9449.4194 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-27980.601 27425.327 -32493.472 31909.728 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-92645.065 91816.693 -107615.31 106744.47 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-307213.82 305978.04 -356897.38 355598.23 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1019421. 1017577.4 -1184347.2 1182409.1 MAarrowhead1
% End of user PostScript
0 .027 1 r
.42899 .46256 m
.42049 .4655 L
.41078 .46937 L
.39965 .47435 L
.38689 .48065 L
.37225 .4885 L
.35542 .49818 L
.33607 .51003 L
.3138 .52441 L
.28813 .54178 L
.25855 .56265 L
.22441 .58761 L
.18501 .61738 L
.1395 .65276 L
.0869 .69471 L
.02608 .74433 L
s
.02608 .74433 m
0 .76604 L
s
1 0 0 r
.42899 .46256 m
.42049 .4655 L
s
% Start of user PostScript
-8.5216842 -4.4924751 -9.5410629 -4.1403466 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41078 .46937 m
.39965 .47435 L
s
% Start of user PostScript
-10.706969 -3.6759017 -12.042169 -3.0781269 MAarrowhead1
% End of user PostScript
1 .473 0 r
.25855 .56265 m
.22441 .58761 L
s
% Start of user PostScript
-28.974365 7.5176442 -33.070329 10.513498 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-86.390992 54.381325 -99.48724 65.836403 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-272.19744 224.44463 -314.92838 264.72723 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-881.9008 810.66197 -1022.6534 947.76213 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2895.4524 2789.1766 -3361.0982 3249.3735 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-9564.6647 9406.1198 -11108.173 10941.499 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-31683.339 31446.817 -36804.25 36555.602 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-105084.28 104731.43 -122080.76 121709.82 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-348730.82 348204.44 -405152.86 404599.49 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1157586.5 1156801.2 -1344901.9 1344076.4 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3842963.6 3841792.1 -4464854.4 4463622.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-12758553. 12756805. -14823276. 14821438. MAarrowhead1
% End of user PostScript
0 .322 1 r
.43329 .48506 m
.42475 .48942 L
.41494 .49482 L
.40367 .50147 L
.39071 .50957 L
.37578 .51939 L
.35857 .53122 L
.33873 .54541 L
.31583 .56236 L
.28939 .58256 L
.25885 .60654 L
.22354 .63494 L
.18272 .66851 L
.13548 .70812 L
.08081 .75477 L
.01752 .80963 L
s
.01752 .80963 m
0 .82503 L
s
1 0 0 r
.43329 .48506 m
.42475 .48942 L
s
% Start of user PostScript
-8.0052826 -1.7924212 -9.0299953 -1.2700476 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41494 .49482 m
.40367 .50147 L
s
% Start of user PostScript
-10.206656 -0.62148098 -11.559145 0.17583682 MAarrowhead1
% End of user PostScript
1 .473 0 r
.25885 .60654 m
.22354 .63494 L
s
% Start of user PostScript
-28.938043 12.78436 -33.174709 16.192809 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-88.694273 64.59581 -102.38194 77.047925 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-283.4606 247.50991 -328.34052 290.54661 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-924.69024 871.05812 -1072.8543 1016.4725 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3045.5659 2965.5562 -3536.2312 3452.1193 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-10075.065 9955.7042 -11702.256 11576.776 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-33395.836 33217.771 -38795.504 38608.31 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-110796.69 110531.05 -128720.05 128440.79 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-367736.55 367340.26 -427237.97 426821.36 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1220747.2 1220156. -1418289.6 1417668.1 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4052753.3 4051871.3 -4708603.2 4707676. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-13455212. 13453896. -15632689. 15631306. MAarrowhead1
% End of user PostScript
0 .285 1 r
.42877 .43993 m
.42088 .4411 L
.41189 .44301 L
.40164 .44582 L
.38994 .4497 L
.37656 .45486 L
.36124 .46153 L
.34368 .47 L
.32353 .4806 L
.30039 .4937 L
.27378 .50976 L
.24315 .52928 L
.20787 .55289 L
.16721 .58129 L
.12031 .6153 L
.06617 .65589 L
.00364 .70416 L
s
.00364 .70416 m
0 .70705 L
s
1 0 0 r
.42877 .43993 m
.42088 .4411 L
s
% Start of user PostScript
-8.5470209 -7.2081732 -9.4947356 -7.0682446 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41189 .44301 m
.40164 .44582 L
s
% Start of user PostScript
-10.573495 -6.8386872 -11.803362 -6.5015618 MAarrowhead1
% End of user PostScript
1 .473 0 r
.27378 .50976 m
.24315 .52928 L
s
% Start of user PostScript
-27.146601 1.1706769 -30.821855 3.5141174 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-78.256993 39.505469 -89.850532 49.112174 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-242.11009 184.29961 -279.69387 218.91938 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-777.41019 691.16709 -900.83796 810.17307 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2541.6733 2413.0137 -2949.4469 2814.1908 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-8379.8458 8187.9083 -9730.6865 9528.9081 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-27734.338 27448.001 -32214.79 31913.772 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-91950.369 91523.205 -106819.28 106370.21 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-305090.73 304453.48 -354447.25 353777.32 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1012645.6 1011695. -1176500.1 1175500.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3361667.4 3360249.1 -3905661.1 3904170.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-11160480. 11158365. -12966570. 12964346. MAarrowhead1
% End of user PostScript
1 .283 0 r
.49284 .57223 m
.48988 .57852 L
.48636 .58556 L
.48216 .59344 L
.47718 .6023 L
.47129 .61226 L
.46434 .6235 L
.45614 .6362 L
.44649 .65059 L
.43514 .66691 L
.42183 .68546 L
.40621 .70657 L
.38792 .73065 L
.3665 .75815 L
.34145 .78959 L
.31217 .82559 L
.27796 .86686 L
.23803 .91422 L
.19142 .96863 L
s
.19142 .96863 m
.16416 1 L
s
1 0 0 r
.49284 .57223 m
.48988 .57852 L
s
% Start of user PostScript
-0.85911723 8.6676813 -1.2139867 9.4229044 MAarrowhead1
% End of user PostScript
1 .158 0 r
.48636 .58556 m
.48216 .59344 L
s
% Start of user PostScript
-1.6373522 10.26715 -2.1408663 11.213123 MAarrowhead1
% End of user PostScript
1 .473 0 r
.42183 .68546 m
.40621 .70657 L
s
% Start of user PostScript
-9.3806489 22.254795 -11.254611 24.788828 MAarrowhead1
% End of user PostScript
1 .788 0 r
.19142 .96863 m
0 0 rlineto s
.19142 .96863 m
.16416 1 L
s
% Start of user PostScript
-37.029276 56.235245 -43.552749 63.743429 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-131.72006 160.372 -153.82884 183.94979 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-450.42202 493.16569 -524.4972 569.43238 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1514.9908 1578.7568 -1761.9307 1828.9661 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5059.0922 5154.22 -5880.456 5980.4611 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-16840.258 16982.172 -19569.511 19718.701 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-55976.491 56188.201 -65041.255 65263.821 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-185945.26 186261.1 -216046.3 216378.33 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-617504.37 617975.54 -717450.74 717946.07 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2050402.1 2051105. -2382246.8 2382985.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-6807895.9 6808944.5 -7909675.5 7910777.9 MAarrowhead1
% End of user PostScript
.584 0 1 r
.52523 .56087 m
.52694 .56358 L
.5288 .56637 L
.53083 .56921 L
.53305 .57212 L
.53549 .57507 L
.53818 .57805 L
.54114 .58105 L
.54443 .58403 L
.54806 .58698 L
.55211 .58985 L
.55662 .59262 L
.56166 .59524 L
.5673 .59764 L
.57363 .59976 L
.58075 .60153 L
.58878 .60285 L
.59786 .6036 L
.60812 .60366 L
.61977 .60288 L
.633 .60106 L
.64805 .59801 L
.66521 .59347 L
.68479 .58714 L
.70718 .5787 L
.73281 .56773 L
.76218 .55377 L
.79588 .53627 L
.83458 .5146 L
.87907 .488 L
.93028 .45562 L
.98924 .41644 L
s
.98924 .41644 m
1 .40898 L
s
1 0 0 r
.52523 .56087 m
.52694 .56358 L
s
% Start of user PostScript
3.0281471 7.3045073 3.2326023 7.6298186 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5288 .56637 m
.53083 .56921 L
s
% Start of user PostScript
3.4555022 7.963847 3.699081 8.3057507 MAarrowhead1
% End of user PostScript
1 .473 0 r
.55211 .58985 m
.55662 .59262 L
s
% Start of user PostScript
6.2531946 10.782473 6.7942964 11.114808 MAarrowhead1
% End of user PostScript
1 .788 0 r
.60812 .60366 m
.61977 .60288 L
s
% Start of user PostScript
12.974793 12.439436 14.372089 12.345155 MAarrowhead1
% End of user PostScript
.897 1 0 r
.76218 .55377 m
.79588 .53627 L
s
% Start of user PostScript
31.46167 6.4519046 35.505284 4.3521607 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
87.127149 -30.566742 99.663931 -40.20361 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
263.42008 -179.04187 303.71819 -215.01382 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
836.01847 -710.14097 967.83554 -835.50416 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
2718.1439 -2530.3567 3152.842 -2955.4268 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
8938.723 -8658.5775 10377.571 -10083.062 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
29549.558 -29131.63 34320.137 -33880.781 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
97916.966 -97293.49 113746.05 -113090.61 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
324810.8 -323880.68 377350.6 -376372.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1077984.7 -1076597.1 1252401.2 -1250942.5 MAarrowhead1
% End of user PostScript
.356 1 0 r
.55911 .44614 m
.56854 .43699 L
.57947 .42633 L
.59218 .41393 L
.60692 .39949 L
.62405 .3827 L
.64394 .36315 L
.66704 .34042 L
.69386 .31398 L
.72502 .28322 L
.76121 .24745 L
.80324 .20587 L
.85207 .15751 L
.90878 .10129 L
.97465 .03593 L
s
.97465 .03593 m
1 .01076 L
s
1 0 0 r
.55911 .44614 m
.56854 .43699 L
s
% Start of user PostScript
7.0937339 -6.4630604 8.2243106 -7.5613019 MAarrowhead1
% End of user PostScript
1 .158 0 r
.57947 .42633 m
.59218 .41393 L
s
% Start of user PostScript
9.5369596 -8.8399577 11.061101 -10.328363 MAarrowhead1
% End of user PostScript
1 .473 0 r
.76121 .24745 m
.80324 .20587 L
s
% Start of user PostScript
31.34524 -30.305435 36.389232 -35.296116 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
103.5946 -102.04339 120.31687 -118.68613 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
343.23715 -340.92303 398.72072 -396.28794 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1138.5298 -1135.0775 1322.6874 -1319.0582 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3778.474 -3773.3238 4389.8181 -4384.4039 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
12542.621 -12534.938 14572.235 -14564.158 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
41639.458 -41627.996 48377.831 -48365.781 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
138242.63 -138225.53 160614.55 -160596.57 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
458973.88 -458948.37 533250.86 -533224.05 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1523835.3 -1523797.2 1770443. -1770403. MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
5059293.9 -5059237.1 5878059.3 -5877999.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
16797421. -16797337. 19515817. -19515728. MAarrowhead1
% End of user PostScript
1 .515 0 r
.41907 .43734 m
.40995 .43911 L
.39955 .44177 L
.38767 .44551 L
.37411 .45052 L
.35858 .45706 L
.34079 .4654 L
.32038 .47587 L
.29694 .48886 L
.27 .50482 L
.23901 .52427 L
.20331 .54783 L
.16218 .5762 L
.11474 .61023 L
.05999 .65087 L
s
.05999 .65087 m
0 .6968 L
s
1 0 0 r
.41907 .43734 m
.40995 .43911 L
s
% Start of user PostScript
-9.7110625 -7.5186348 -10.806403 -7.3066803 MAarrowhead1
% End of user PostScript
1 .158 0 r
.39955 .44177 m
.38767 .44551 L
s
% Start of user PostScript
-12.054589 -6.9871718 -13.479105 -6.5389477 MAarrowhead1
% End of user PostScript
1 .473 0 r
.23901 .52427 m
.20331 .54783 L
s
% Start of user PostScript
-31.319168 2.9121998 -35.602491 5.7390663 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-90.999241 48.621024 -104.55467 60.003672 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-282.75818 219.53731 -326.77066 260.30838 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-909.89365 815.5792 -1054.5387 955.38862 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2977.8447 2837.1441 -3455.8729 3307.9584 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-9822.4822 9612.5815 -11406.294 11185.632 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-32515.849 32202.714 -37769.372 37440.182 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-107813.3 107346.15 -125248.27 124757.17 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-357739.23 357042.34 -415614.43 414881.8 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1187417.5 1186377.9 -1379553.6 1378460.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3941889.9 3940338.9 -4579779.8 4578149.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-13086826. 13084513. -15204659. 15202227. MAarrowhead1
% End of user PostScript
0 1 .599 r
.48868 .56654 m
.48532 .57273 L
.48134 .57969 L
.47664 .58752 L
.47108 .59637 L
.46454 .60637 L
.45684 .6177 L
.44779 .63057 L
.43718 .6452 L
.42473 .66187 L
.41016 .68089 L
.3931 .70261 L
.37316 .72746 L
.34985 .75593 L
.32262 .78858 L
.29085 .82606 L
.25377 .86913 L
.21052 .91868 L
.1601 .97572 L
s
.1601 .97572 m
.1384 1 L
s
1 0 0 r
.48868 .56654 m
.48532 .57273 L
s
% Start of user PostScript
-1.3583578 7.9849892 -1.761352 8.727738 MAarrowhead1
% End of user PostScript
1 .158 0 r
.48134 .57969 m
.47664 .58752 L
s
% Start of user PostScript
-2.2389554 9.5625157 -2.803724 10.502771 MAarrowhead1
% End of user PostScript
1 .473 0 r
.41016 .68089 m
.3931 .70261 L
s
% Start of user PostScript
-10.780996 21.706464 -12.827719 24.313347 MAarrowhead1
% End of user PostScript
1 .788 0 r
.1601 .97572 m
0 0 rlineto s
.1601 .97572 m
.1384 1 L
s
% Start of user PostScript
-40.787904 57.086787 -47.839297 64.973842 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-142.87039 167.18547 -166.6638 192.22554 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-485.46016 521.734 -565.02688 603.16051 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1628.3643 1682.4785 -1893.3852 1950.2739 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5431.094 5511.8229 -6312.2624 6397.1304 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-18068.766 18189.199 -20996.24 21122.848 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-60045.463 60225.128 -69767.841 69956.718 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-199440.08 199708.11 -231723.72 232005.49 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-662286.89 662686.74 -769478.64 769898.99 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2199052.7 2199649.2 -2554951.2 2555578.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-7301384.6 7302274.5 -8483023.3 8483958.8 MAarrowhead1
% End of user PostScript
0 .984 1 r
.56971 .50996 m
.57879 .50497 L
.58923 .49883 L
.60123 .49134 L
.61506 .48226 L
.63099 .47132 L
.64936 .45819 L
.67056 .44251 L
.69503 .42383 L
.72331 .40165 L
.756 .37537 L
.79379 .34431 L
.83752 .30766 L
.88813 .26449 L
.94673 .21372 L
s
.94673 .21372 m
1 .16691 L
s
1 0 0 r
.56971 .50996 m
.57879 .50497 L
s
% Start of user PostScript
8.3653774 1.1957635 9.4549044 0.59644665 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58923 .49883 m
.60123 .49134 L
s
% Start of user PostScript
10.707204 -0.14050961 12.147925 -1.0394641 MAarrowhead1
% End of user PostScript
1 .473 0 r
.756 .37537 m
.79379 .34431 L
s
% Start of user PostScript
30.719419 -14.955763 35.255153 -18.683277 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
94.786921 -71.270309 109.47667 -84.754339 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
303.95485 -268.87219 352.17544 -315.29405 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
993.1303 -940.79312 1152.4062 -1097.3856 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3273.3868 -3195.3089 3800.9748 -3718.8937 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
10832.34 -10715.861 12582.164 -12459.713 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
35911.395 -35737.629 41718.285 -41535.611 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
119150.61 -118891.38 138426.09 -138153.57 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
395475.46 -395088.74 459466.24 -459059.69 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1312848. -1312271.1 1525295.8 -1524689.3 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4358545.2 -4357684.5 5063883.2 -5062978.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
14470486. -14469202. 16812271. -16810921. MAarrowhead1
% End of user PostScript
.527 1 0 r
.45107 .48409 m
.44495 .48689 L
.43792 .49043 L
.42985 .49482 L
.42059 .50023 L
.40992 .50683 L
.39765 .51484 L
.3835 .5245 L
.36719 .53609 L
.34837 .54995 L
.32664 .56646 L
.30154 .58608 L
.27253 .60933 L
.23898 .63682 L
.20017 .66927 L
.15526 .70749 L
.10326 .75245 L
.04304 .80527 L
s
.04304 .80527 m
0 .84351 L
s
1 0 0 r
.45107 .48409 m
.44495 .48689 L
s
% Start of user PostScript
-5.8713023 -1.9088781 -6.6064298 -1.572649 MAarrowhead1
% End of user PostScript
1 .158 0 r
.43792 .49043 m
.42985 .49482 L
s
% Start of user PostScript
-7.4495002 -1.148929 -8.4174171 -0.621863 MAarrowhead1
% End of user PostScript
1 .473 0 r
.32664 .56646 m
.30154 .58608 L
s
% Start of user PostScript
-20.803101 7.9757523 -23.815197 10.330176 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-63.205693 44.069537 -72.9056 52.788313 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-201.10367 172.55588 -232.86005 202.84858 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-654.63927 612.05097 -759.40515 714.6333 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2154.013 2090.4787 -2500.8499 2434.0581 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-7122.5351 7027.7531 -8272.5853 8172.9437 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-23604.327 23462.929 -27420.407 27271.759 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-78304.496 78093.555 -90971.014 90749.258 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-259883.67 259568.98 -301933.05 301602.22 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-862700.33 862230.87 -1002301.8 1001808.3 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2864051.4 2863351. -3327533.6 3326797.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-9508665.3 9507620.5 -11047464. 11046366. MAarrowhead1
% End of user PostScript
1 .15 0 r
.47205 .43212 m
.47017 .42908 L
.46813 .42596 L
.4659 .42276 L
.46346 .41949 L
.46078 .41616 L
.45784 .4128 L
.45459 .40942 L
.451 .40603 L
.44702 .40268 L
.4426 .39939 L
.43768 .39621 L
.43219 .39319 L
.42604 .39039 L
.41915 .38787 L
.4114 .38573 L
.40266 .38406 L
.39281 .38298 L
.38166 .38263 L
.36902 .38318 L
.35467 .38483 L
.33836 .38779 L
.31977 .39234 L
.29856 .39879 L
.27432 .4075 L
.24659 .41892 L
.21483 .43353 L
.1784 .45193 L
.13657 .47481 L
.08849 .50296 L
.03319 .53732 L
s
.03319 .53732 m
0 .55903 L
s
1 0 0 r
.47205 .43212 m
.47017 .42908 L
s
% Start of user PostScript
-3.3541462 -8.1458129 -3.579094 -8.5104806 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46813 .42596 m
.4659 .42276 L
s
% Start of user PostScript
-3.8241486 -8.8852718 -4.0917284 -9.2693179 MAarrowhead1
% End of user PostScript
1 .473 0 r
.4426 .39939 m
.43768 .39621 L
s
% Start of user PostScript
-6.8874868 -12.07274 -7.4780424 -12.454296 MAarrowhead1
% End of user PostScript
1 .788 0 r
.38166 .38263 m
.36902 .38318 L
s
% Start of user PostScript
-14.201053 -14.084283 -15.71744 -14.018115 MAarrowhead1
% End of user PostScript
.897 1 0 r
.21483 .43353 m
.1784 .45193 L
s
% Start of user PostScript
-34.22069 -7.9760715 -38.592418 -5.7678179 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-94.32969 31.379519 -107.85547 41.677776 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-284.41277 190.50215 -327.84473 229.11921 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-901.35964 761.26146 -1043.3581 896.0769 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2928.5843 2719.5824 -3396.7525 3177.0349 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-9627.7131 9315.9189 -11177.189 10849.408 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-31822.621 31357.478 -36959.753 36470.763 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-105442.22 104748.31 -122487.2 121757.71 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-349763.32 348728.13 -406338.39 405250.12 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1160782. 1159237.6 -1348593.5 1346970. MAarrowhead1
% End of user PostScript
.185 0 1 r
.54873 .48403 m
.55571 .47872 L
.56377 .47243 L
.57309 .46496 L
.58387 .45614 L
.59634 .44572 L
.61077 .43345 L
.62747 .41901 L
.64682 .40205 L
.66923 .38214 L
.69519 .35881 L
.72529 .33148 L
.76018 .29951 L
.80063 .26211 L
.84755 .21841 L
.90198 .16737 L
.96511 .10779 L
s
.96511 .10779 m
1 .07468 L
s
1 0 0 r
.54873 .48403 m
.55571 .47872 L
s
% Start of user PostScript
5.8475534 -1.9169291 6.6852423 -2.5530905 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56377 .47243 m
.57309 .46496 L
s
% Start of user PostScript
7.6529275 -3.3089158 8.7713613 -4.2046274 MAarrowhead1
% End of user PostScript
1 .473 0 r
.69519 .35881 m
.72529 .33148 L
s
% Start of user PostScript
23.423083 -16.942579 27.034614 -20.221848 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
74.805311 -65.137536 86.644147 -76.480694 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
243.9435 -229.52087 283.02326 -267.86117 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
803.32875 -781.81272 932.74013 -910.12095 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2657.311 -2625.2128 3086.4677 -3052.7238 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8807.912 -8760.0272 10232.01 -10181.67 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
29221.411 -29149.975 33948.461 -33873.363 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
96985.849 -96879.279 112678.53 -112566.5 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
321955.65 -321796.66 374054.7 -373887.57 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1068857.7 -1068620.6 1241829. -1241579.6 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3548624.2 -3548270.4 4122903.4 -4122531.4 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
11781686. -11781158. 13688351. -13687796. MAarrowhead1
% End of user PostScript
.574 0 1 r
.58312 .5607 m
.5926 .5586 L
.60341 .55555 L
.61575 .55135 L
.62986 .54581 L
.64602 .53866 L
.66455 .5296 L
.68581 .51829 L
.71024 .50432 L
.73833 .48723 L
.77067 .46646 L
.80791 .44137 L
.85085 .41121 L
.90039 .37511 L
.95757 .33205 L
s
.95757 .33205 m
1 .29917 L
s
1 0 0 r
.58312 .5607 m
.5926 .5586 L
s
% Start of user PostScript
9.9746633 7.2843018 11.111854 7.0319972 MAarrowhead1
% End of user PostScript
1 .158 0 r
.60341 .55555 m
.61575 .55135 L
s
% Start of user PostScript
12.408622 6.6654841 13.889539 6.1625178 MAarrowhead1
% End of user PostScript
1 .473 0 r
.77067 .46646 m
.80791 .44137 L
s
% Start of user PostScript
32.479817 -4.0245936 36.949638 -7.0354849 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
94.830673 -52.380468 109.00417 -64.377493 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
295.44608 -232.11781 341.50893 -274.93375 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
951.96988 -857.49521 1103.4198 -1004.1014 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3117.4695 -2976.5298 3618.0871 -3469.9213 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
10285.943 -10075.686 11944.75 -11723.712 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
34054.432 -33740.765 39556.935 -39227.186 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
112921.33 -112453.39 131182.93 -130691. MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
374698.13 -374000.05 435317.82 -434583.95 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1243722.5 -1242681.1 1444970.6 -1443875.8 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4128828.2 -4127274.6 4796971. -4795337.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
13707482. -13705165. 15925758. -15923322. MAarrowhead1
% End of user PostScript
1 .175 0 r
.47622 .50383 m
.47292 .50611 L
.46912 .50884 L
.46473 .51209 L
.45966 .51597 L
.45381 .52058 L
.44704 .52603 L
.43921 .53248 L
.43016 .54008 L
.41968 .54904 L
.40754 .55957 L
.39349 .57193 L
.37721 .58644 L
.35834 .60345 L
.33647 .62336 L
.31112 .64665 L
.28172 .67388 L
.24762 .70571 L
.20807 .74287 L
.16218 .78624 L
.10894 .83684 L
.04715 .89585 L
s
.04715 .89585 m
0 .94107 L
s
1 0 0 r
.47622 .50383 m
.47292 .50611 L
s
% Start of user PostScript
-2.8538346 0.46010253 -3.2495181 0.73305678 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46912 .50884 m
.46473 .51209 L
s
% Start of user PostScript
-3.7058444 1.0603614 -4.2324537 1.4513339 MAarrowhead1
% End of user PostScript
1 .473 0 r
.40754 .55957 m
.39349 .57193 L
s
% Start of user PostScript
-11.094658 7.1480609 -12.781066 8.632123 MAarrowhead1
% End of user PostScript
1 .788 0 r
.20807 .74287 m
.16218 .78624 L
s
% Start of user PostScript
-35.031678 29.144047 -40.538264 34.348768 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-113.61819 104.83488 -131.76273 122.52908 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-373.21106 360.1079 -433.24721 419.47223 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1233.1153 1213.5676 -1432.1352 1411.5854 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4085.1521 4055.9905 -4745.4636 4714.8068 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-13549.854 13506.35 -15741.482 15695.747 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-44967.214 44902.314 -52242.655 52174.427 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-149266.74 149169.92 -173420.54 173318.75 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-495538.79 495394.35 -575729.94 575578.1 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1645180.7 1644965.2 -1911421.3 1911194.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-5462093.8 5461772.3 -6346038.7 6345700.8 MAarrowhead1
% End of user PostScript
1 0 .73 r
.51313 .53761 m
.51385 .53948 L
.51462 .54145 L
.51543 .54351 L
.5163 .54567 L
.51722 .54792 L
.51821 .55027 L
.51927 .55273 L
.52039 .55529 L
.5216 .55796 L
.5229 .56075 L
.52429 .56364 L
.52579 .56665 L
.52741 .56977 L
.52916 .573 L
.53106 .57634 L
.53311 .57979 L
.53535 .58334 L
.53779 .58699 L
.54046 .59072 L
.54338 .59452 L
.54659 .59838 L
.55012 .60228 L
.55402 .6062 L
.55834 .6101 L
.56312 .61395 L
.56844 .61771 L
.57437 .62132 L
.581 .62473 L
.58842 .62785 L
.59675 .63061 L
.60613 .6329 L
.61669 .63458 L
.62863 .63553 L
.64215 .63555 L
.65748 .63446 L
.6749 .63202 L
.69472 .62793 L
.71731 .62188 L
.7431 .61348 L
.77259 .60227 L
.80634 .58774 L
.84503 .56926 L
.88941 .54612 L
.94039 .51747 L
.99901 .48232 L
s
.99901 .48232 m
1 .4817 L
s
1 0 0 r
.51313 .53761 m
.51385 .53948 L
s
% Start of user PostScript
1.575168 4.5126805 1.6618112 4.738168 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51462 .54145 m
.51543 .54351 L
s
% Start of user PostScript
1.7538487 4.9742645 1.8517111 5.2213598 MAarrowhead1
% End of user PostScript
1 .473 0 r
.5229 .56075 m
.52429 .56364 L
s
% Start of user PostScript
2.7477435 7.2894219 2.9149873 7.6367945 MAarrowhead1
% End of user PostScript
1 .788 0 r
.53779 .58699 m
.54046 .59072 L
s
% Start of user PostScript
4.5351118 10.438579 4.8551636 10.886245 MAarrowhead1
% End of user PostScript
.897 1 0 r
.56844 .61771 m
.57437 .62132 L
s
% Start of user PostScript
8.2130307 14.125092 8.924737 14.558685 MAarrowhead1
% End of user PostScript
.581 1 0 r
.64215 .63555 m
.65748 .63446 L
s
% Start of user PostScript
17.058068 16.266494 18.897531 16.135619 MAarrowhead1
% End of user PostScript
.266 1 0 r
.84503 .56926 m
.88941 .54612 L
s
% Start of user PostScript
41.403022 8.3113839 46.729303 5.5340146 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
114.73976 -40.57458 131.2586 -53.290888 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
347.05051 -236.40906 400.15695 -283.84279 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
1101.677 -936.6194 1275.4038 -1101.8835 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
3582.2532 -3336.0161 4155.1782 -3896.3163 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
11780.951 -11413.609 13677.359 -13291.182 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
38946.233 -38398.222 45233.919 -44657.812 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
129055.57 -128238.03 149918.58 -149059.13 MAarrowhead1
% End of user PostScript
1 0 .463 r
.48294 .45724 m
.48183 .45528 L
.48063 .45326 L
.47932 .45118 L
.4779 .44904 L
.47634 .44685 L
.47464 .44462 L
.47276 .44236 L
.4707 .44006 L
.46843 .43776 L
.46591 .43547 L
.46312 .43321 L
.46001 .43099 L
.45656 .42887 L
.45269 .42685 L
.44836 .42501 L
.44351 .42337 L
.43805 .42201 L
.43189 .42099 L
.42493 .4204 L
.41706 .42035 L
.40813 .42094 L
.39799 .42232 L
.38644 .42465 L
.37329 .42812 L
.35827 .43295 L
.34111 .43941 L
.32146 .44781 L
.29894 .45849 L
.27311 .47189 L
.24344 .48849 L
.20933 .50885 L
.17008 .53365 L
.12487 .56367 L
.07277 .5998 L
.01268 .6431 L
s
.01268 .6431 m
0 .65256 L
s
1 0 0 r
.48294 .45724 m
.48183 .45528 L
s
% Start of user PostScript
-2.0471489 -5.1307417 -2.1800452 -5.3658638 MAarrowhead1
% End of user PostScript
1 .158 0 r
.48063 .45326 m
.47932 .45118 L
s
% Start of user PostScript
-2.3242763 -5.6085197 -2.481155 -5.8583641 MAarrowhead1
% End of user PostScript
1 .473 0 r
.46591 .43547 m
.46312 .43321 L
s
% Start of user PostScript
-4.0910017 -7.7433393 -4.4259553 -8.0151453 MAarrowhead1
% End of user PostScript
1 .788 0 r
.43189 .42099 m
.42493 .4204 L
s
% Start of user PostScript
-8.1734454 -9.4813168 -9.0081972 -9.551744 MAarrowhead1
% End of user PostScript
.897 1 0 r
.34111 .43941 m
.32146 .44781 L
s
% Start of user PostScript
-19.067278 -7.270532 -21.425019 -6.2631596 MAarrowhead1
% End of user PostScript
.581 1 0 r
.07277 .5998 m
.01268 .6431 L
s
% Start of user PostScript
-51.26729 11.975894 -58.478048 17.172139 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-152.25436 93.638484 -175.27414 113.65296 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-478.71054 391.26593 -553.76525 461.83726 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-1549.4064 1418.9543 -1796.5476 1659.4071 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-5084.5842 4889.9727 -5902.0648 5697.4753 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-16792.462 16502.136 -19502.033 19196.821 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-55620.238 55187.122 -64609.526 64154.203 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-184467.73 183821.6 -214303.06 213623.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-612159.1 611195.18 -711200.76 710187.42 MAarrowhead1
% End of user PostScript
.745 1 0 r
.47717 .45981 m
.47522 .45853 L
.47304 .45731 L
.4706 .45618 L
.46787 .45516 L
.4648 .45428 L
.46134 .45359 L
.45743 .45314 L
.45302 .45297 L
.44801 .45315 L
.44233 .45377 L
.43587 .4549 L
.42851 .45666 L
.42012 .45917 L
.41052 .46257 L
.39955 .46704 L
.38698 .47276 L
.37257 .47999 L
.35602 .48897 L
.33701 .50004 L
.31513 .51356 L
.28995 .52996 L
.26093 .54975 L
.22748 .57349 L
.18887 .60189 L
.14431 .63573 L
.09282 .67594 L
.03332 .72359 L
s
.03332 .72359 m
0 .75087 L
s
1 0 0 r
.47717 .45981 m
.47522 .45853 L
s
% Start of user PostScript
-2.7392097 -4.8231421 -2.9734782 -4.9766036 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47304 .45731 m
.4706 .45618 L
s
% Start of user PostScript
-3.2349423 -5.122749 -3.5274536 -5.2587457 MAarrowhead1
% End of user PostScript
1 .473 0 r
.44233 .45377 m
.43587 .4549 L
s
% Start of user PostScript
-6.9203112 -5.5478991 -7.6956234 -5.4118457 MAarrowhead1
% End of user PostScript
1 .788 0 r
.35602 .48897 m
.33701 .50004 L
s
% Start of user PostScript
-17.277359 -1.3230246 -19.559299 0.0052524272 MAarrowhead1
% End of user PostScript
.897 1 0 r
.09282 .67594 m
.03332 .72359 L
s
% Start of user PostScript
-48.861119 21.112607 -56.00153 26.830322 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-149.54153 108.14561 -172.59826 129.07993 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-477.57441 415.81896 -553.15533 488.23361 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1557.3761 1465.2478 -1806.8664 1710.0146 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-5128.5615 4991.1222 -5954.7394 5810.2534 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-16964.604 16759.569 -19704.39 19488.843 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-56230.752 55924.876 -65322.359 65000.8 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-186552.86 186096.55 -216730.89 216251.18 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-619168.75 618488.01 -719352.64 718637. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2055401.5 2054386. -2388007.8 2386940.2 MAarrowhead1
% End of user PostScript
1 .804 0 r
.5129 .53707 m
.51361 .53892 L
.51436 .54087 L
.51515 .5429 L
.516 .54503 L
.5169 .54726 L
.51786 .54958 L
.51889 .55201 L
.51999 .55455 L
.52116 .5572 L
.52242 .55996 L
.52377 .56283 L
.52523 .56582 L
.52679 .56892 L
.52848 .57214 L
.53031 .57547 L
.53229 .57891 L
.53445 .58246 L
.53679 .58611 L
.53935 .58985 L
.54214 .59368 L
.54521 .59758 L
.54858 .60153 L
.55229 .60551 L
.55639 .6095 L
.56093 .61347 L
.56597 .61737 L
.57158 .62116 L
.57784 .62478 L
.58484 .62817 L
.59268 .63125 L
.60149 .63393 L
.61141 .63608 L
.62259 .63758 L
.63524 .63827 L
.64957 .63797 L
.66583 .63645 L
.68431 .63347 L
.70535 .62872 L
.72935 .62185 L
.75676 .61244 L
.78811 .60002 L
.82401 .58403 L
.86516 .56379 L
.9124 .53854 L
.96668 .50739 L
s
.96668 .50739 m
1 .48704 L
s
1 0 0 r
.5129 .53707 m
.51361 .53892 L
s
% Start of user PostScript
1.5479083 4.4480496 1.6326799 4.6706974 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51436 .54087 m
.51515 .5429 L
s
% Start of user PostScript
1.7226731 4.9038853 1.8182973 5.148012 MAarrowhead1
% End of user PostScript
1 .473 0 r
.52242 .55996 m
.52377 .56283 L
s
% Start of user PostScript
2.6906548 7.1950086 2.8528474 7.5396649 MAarrowhead1
% End of user PostScript
1 .788 0 r
.53679 .58611 m
.53935 .58985 L
s
% Start of user PostScript
4.4148182 10.332859 4.7216495 10.782157 MAarrowhead1
% End of user PostScript
.897 1 0 r
.56597 .61737 m
.57158 .62116 L
s
% Start of user PostScript
7.9169467 14.084002 8.5900563 14.538905 MAarrowhead1
% End of user PostScript
.581 1 0 r
.63524 .63827 m
.64957 .63797 L
s
% Start of user PostScript
16.229148 16.59241 17.948366 16.55599 MAarrowhead1
% End of user PostScript
.266 1 0 r
.82401 .58403 m
.86516 .56379 L
s
% Start of user PostScript
38.880819 10.083193 43.819663 7.654787 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
106.70873 -33.663013 121.95882 -45.167965 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
320.89824 -211.92683 369.81851 -255.26002 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
1015.6118 -853.04555 1175.4791 -1004.5779 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
3297.6453 -3055.1249 3824.6137 -3569.6591 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
10837.718 -10475.92 12581.632 -12201.284 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
35817.124 -35277.385 41598.642 -41031.23 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
118670.34 -117865.14 137853.01 -137006.53 MAarrowhead1
% End of user PostScript
.605 0 1 r
.5673 .48929 m
.57663 .48286 L
.58739 .47515 L
.5998 .46595 L
.61414 .45498 L
.6307 .44197 L
.64984 .42655 L
.67198 .40833 L
.69759 .38683 L
.72723 .36152 L
.76155 .33175 L
.8013 .29678 L
.84735 .25576 L
.90072 .20768 L
.96257 .15139 L
s
.96257 .15139 m
1 .11701 L
s
1 0 0 r
.5673 .48929 m
.57663 .48286 L
s
% Start of user PostScript
8.0764399 -1.2856016 9.1957803 -2.0567683 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58739 .47515 m
.5998 .46595 L
s
% Start of user PostScript
10.486645 -2.9816076 11.976298 -4.0864692 MAarrowhead1
% End of user PostScript
1 .473 0 r
.76155 .33175 m
.8013 .29678 L
s
% Start of user PostScript
31.386536 -20.190336 36.15648 -24.386239 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
99.089488 -82.386721 114.66388 -97.104746 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
321.3543 -296.4367 372.67169 -346.47653 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1055.5447 -1018.372 1225.3405 -1186.2619 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3487.5411 -3432.086 4050.4119 -3992.1135 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
11553.697 -11470.968 13421.194 -13334.223 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
38321.813 -38198.395 44520.183 -44390.437 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
127176.49 -126992.37 147752.91 -147559.35 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
422156.65 -421881.98 490468.46 -490179.71 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1401483.9 -1401074.1 1628280.7 -1627849.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4652903.1 -4652291.8 5405885.3 -5405242.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
15447903. -15446991. 17947878. -17946919. MAarrowhead1
% End of user PostScript
.115 1 0 r
.54573 .50088 m
.55184 .49716 L
.55887 .49264 L
.56698 .48718 L
.57632 .48061 L
.58709 .47275 L
.59954 .46338 L
.6139 .45224 L
.63051 .43902 L
.64971 .42339 L
.67192 .40493 L
.69761 .38317 L
.72736 .35757 L
.76181 .32747 L
.80171 .29215 L
.84794 .25073 L
.90153 .20221 L
.96364 .14541 L
s
.96364 .14541 m
1 .11187 L
s
1 0 0 r
.54573 .50088 m
.55184 .49716 L
s
% Start of user PostScript
5.4870555 0.10613269 6.2204489 -0.34049177 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55887 .49264 m
.56698 .48718 L
s
% Start of user PostScript
7.0646038 -0.88317492 8.0370391 -1.5386815 MAarrowhead1
% End of user PostScript
1 .473 0 r
.67192 .40493 m
.69761 .38317 L
s
% Start of user PostScript
20.629946 -11.408338 23.713685 -14.019275 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
64.278885 -50.521862 74.301154 -59.838794 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
207.12545 -186.60238 240.07816 -218.50286 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
678.30016 -647.68335 787.22609 -755.03951 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2238.0417 -2192.3668 2598.971 -2550.9543 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
7409.6835 -7341.5445 8606.9406 -8535.308 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
24569.871 -24468.22 28543.308 -28436.444 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
81528.382 -81376.736 94718.275 -94558.853 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
270614.45 -270388.22 314402.88 -314165.05 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
898368.2 -898030.71 1043745.6 -1043390.8 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2982533.2 -2982029.7 3465195.3 -3464666. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
9902128.9 -9901377.8 11504612. -11503822. MAarrowhead1
% End of user PostScript
0 .217 1 r
.48567 .50549 m
.4836 .50711 L
.4812 .50903 L
.47843 .5113 L
.47522 .51398 L
.47151 .51714 L
.46721 .52086 L
.46223 .52522 L
.45647 .53034 L
.44979 .53635 L
.44204 .54338 L
.43307 .55161 L
.42266 .56123 L
.41059 .57248 L
.39658 .58561 L
.38034 .60094 L
.36149 .61883 L
.33962 .63969 L
.31424 .66401 L
.28478 .69236 L
.25058 .72538 L
.21088 .76385 L
.16479 .80865 L
.11127 .8608 L
.04914 .92151 L
s
.04914 .92151 m
0 .96962 L
s
1 0 0 r
.48567 .50549 m
.4836 .50711 L
s
% Start of user PostScript
-1.7195235 0.65842354 -1.9684717 0.85296793 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4812 .50903 m
.47843 .5113 L
s
% Start of user PostScript
-2.2562044 1.0835076 -2.5889213 1.356099 MAarrowhead1
% End of user PostScript
1 .473 0 r
.44204 .54338 m
.43307 .55161 L
s
% Start of user PostScript
-6.9548543 5.2053962 -8.0320315 6.1928767 MAarrowhead1
% End of user PostScript
1 .788 0 r
.31424 .66401 m
.28478 .69236 L
s
% Start of user PostScript
-22.291299 19.681414 -25.826656 23.082959 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-72.816812 68.923321 -84.493446 80.400332 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-239.98072 234.17231 -278.65727 272.55106 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-794.10918 785.44406 -922.38373 913.27434 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2632.5747 2619.6479 -3058.2582 3044.6686 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8734.5474 8715.2629 -10147.563 10127.29 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-28990.904 28962.135 -33681.83 33651.586 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-96240.042 96197.124 -111813.79 111768.67 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-319508.58 319444.55 -371214.23 371146.93 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1060776.6 1060681. -1232443.9 1232343.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3521858.6 3521716.1 -4091811.9 4091662.1 MAarrowhead1
% End of user PostScript
0 .599 1 r
.51432 .58327 m
.51394 .58865 L
.51337 .59449 L
.51255 .60084 L
.51144 .60775 L
.51 .61531 L
.50816 .62358 L
.50583 .63265 L
.50295 .64264 L
.4994 .65365 L
.49508 .66582 L
.48983 .67931 L
.48351 .69431 L
.47593 .71101 L
.46687 .72966 L
.45607 .75053 L
.44325 .77394 L
.42807 .80026 L
.41011 .82992 L
.38893 .86341 L
.36398 .90129 L
.33464 .94424 L
.30017 .99301 L
s
.30017 .99301 m
.29507 1 L
s
1 0 0 r
.51432 .58327 m
.51394 .58865 L
s
% Start of user PostScript
1.7188558 9.991949 1.6733296 10.637901 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51337 .59449 m
.51255 .60084 L
s
% Start of user PostScript
1.6038396 11.338601 1.5056565 12.100357 MAarrowhead1
% End of user PostScript
1 .473 0 r
.49508 .66582 m
.48983 .67931 L
s
% Start of user PostScript
-0.59070608 19.898559 -1.2199868 21.517775 MAarrowhead1
% End of user PostScript
1 .788 0 r
.41011 .82992 m
.38893 .86341 L
s
% Start of user PostScript
-10.786313 39.590244 -13.328071 43.608812 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-48.97732 91.947737 -58.091264 103.26482 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-182.25105 246.35538 -213.5174 280.90843 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-634.39515 730.02758 -739.70537 840.24097 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2149.9771 2292.6439 -2501.8604 2651.8419 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7203.3845 7416.2184 -8375.0217 8598.7677 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-24013.359 24330.87 -27908.319 28242.109 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-79872.286 80345.957 -92811.45 93309.406 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-265401.83 266108.47 -308372.47 309115.33 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-881488.1 882542.27 -1024172.2 1025280.4 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2927125.4 2928698. -3400878. 3402531.2 MAarrowhead1
% End of user PostScript
.98 0 1 r
.52774 .54525 m
.53021 .54652 L
.53298 .54769 L
.53609 .54872 L
.53958 .54957 L
.54353 .5502 L
.54798 .55055 L
.55302 .55056 L
.55874 .55015 L
.56523 .54924 L
.57263 .54771 L
.58105 .54546 L
.59067 .54232 L
.60167 .53814 L
.61426 .53272 L
.62869 .52583 L
.64525 .5172 L
.66426 .50651 L
.68613 .4934 L
.71128 .47745 L
.74026 .45815 L
.77366 .43492 L
.81218 .4071 L
.85664 .37388 L
.90799 .33435 L
.96731 .28745 L
s
.96731 .28745 m
1 .26099 L
s
1 0 0 r
.52774 .54525 m
.53021 .54652 L
s
% Start of user PostScript
3.3288095 5.4301147 3.6254213 5.5825826 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53298 .54769 m
.53609 .54872 L
s
% Start of user PostScript
3.9576222 5.7224862 4.3305352 5.845883 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57263 .54771 m
.58105 .54546 L
s
% Start of user PostScript
8.7152516 5.7257731 9.7265165 5.4549154 MAarrowhead1
% End of user PostScript
1 .788 0 r
.68613 .4934 m
.71128 .47745 L
s
% Start of user PostScript
22.335051 -0.7915738 25.354149 -2.7061135 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
64.308038 -32.168947 73.826931 -40.040033 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
198.82029 -150.8744 229.67096 -179.26683 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
638.19185 -566.66498 739.49608 -664.30196 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2086.1785 -1979.473 2420.8442 -2308.6678 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
6877.5845 -6718.3985 7986.2131 -7818.8655 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
22761.625 -22524.147 26438.671 -26189.018 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
75462.712 -75108.437 87665.37 -87292.931 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
250383.1 -249854.58 290889.05 -290333.43 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
831059.58 -830271.13 965531.69 -964702.81 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2758854.6 -2757678.4 3205299.2 -3204062.7 MAarrowhead1
% End of user PostScript
.599 0 1 r
.51082 .43648 m
.51403 .43057 L
.51783 .42392 L
.52233 .41644 L
.52763 .408 L
.53388 .39844 L
.54124 .38762 L
.54988 .37533 L
.56002 .36136 L
.5719 .34544 L
.58583 .32728 L
.60212 .30653 L
.62117 .2828 L
.64343 .25561 L
.66944 .22443 L
.69979 .18864 L
.73521 .1475 L
.77651 .10018 L
.82467 .0457 L
s
.82467 .0457 m
.86553 0 L
s
1 0 0 r
.51082 .43648 m
.51403 .43057 L
s
% Start of user PostScript
1.298612 -7.6229684 1.683582 -8.3321951 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51783 .42392 m
.52233 .41644 L
s
% Start of user PostScript
2.1398162 -9.1293109 2.6793068 -10.027161 MAarrowhead1
% End of user PostScript
1 .473 0 r
.58583 .32728 m
.60212 .30653 L
s
% Start of user PostScript
10.29915 -20.72625 12.254118 -23.215828 MAarrowhead1
% End of user PostScript
1 .788 0 r
.82467 .0457 m
0 0 rlineto s
.82467 .0457 m
.86553 0 L
s
% Start of user PostScript
38.960328 -54.515734 45.695407 -62.048356 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
136.4628 -159.66874 159.18858 -183.58432 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
463.67926 -498.29846 539.67535 -576.06951 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1555.2929 -1606.9386 1808.42 -1862.7137 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5187.3601 -5264.4065 6028.9822 -6109.9789 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
17257.858 -17372.798 20053.947 -20174.78 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
57350.642 -57522.112 66636.679 -66816.94 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
190489.21 -190745.01 221323.96 -221592.88 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
632563.37 -632944.98 734944.33 -735345.51 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2100358.8 -2100928.1 2440284.5 -2440883. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
6973696.9 -6974546.2 8102303.4 -8103196.2 MAarrowhead1
% End of user PostScript
1 .611 0 r
.51334 .56024 m
.51346 .56388 L
.5135 .56781 L
.51344 .57204 L
.51325 .57661 L
.51291 .58156 L
.51239 .58692 L
.51165 .59275 L
.51065 .59911 L
.50934 .60604 L
.50767 .61364 L
.50555 .62197 L
.50293 .63113 L
.4997 .64124 L
.49575 .65241 L
.49097 .66479 L
.4852 .67854 L
.47828 .69386 L
.47001 .71095 L
.46015 .73009 L
.44845 .75155 L
.43458 .77567 L
.41818 .80285 L
.39883 .83354 L
.37603 .86825 L
.34921 .90758 L
.31771 .95225 L
s
.31771 .95225 m
.28297 1 L
s
1 0 0 r
.51334 .56024 m
.51346 .56388 L
s
% Start of user PostScript
1.6005047 7.2283787 1.6154838 7.6660661 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5135 .56781 m
.51344 .57204 L
s
% Start of user PostScript
1.6203751 8.1370501 1.6129044 8.6447947 MAarrowhead1
% End of user PostScript
1 .473 0 r
.50767 .61364 m
.50555 .62197 L
s
% Start of user PostScript
0.91997866 13.636389 0.66651325 14.636176 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47001 .71095 m
.46015 .73009 L
s
% Start of user PostScript
-3.5988868 25.314436 -4.7815448 27.610474 MAarrowhead1
% End of user PostScript
.897 1 0 r
.31771 .95225 m
0 0 rlineto s
.31771 .95225 m
.28297 1 L
s
% Start of user PostScript
-21.874317 54.27011 -26.309776 60.366536 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-87.432535 135.76138 -102.91796 153.72468 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-312.37605 384.47421 -364.92204 440.71676 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1070.0791 1177.637 -1246.2276 1359.3 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-3601.9497 3762.4071 -4189.3036 4357.9879 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-12032.235 12271.609 -13986.079 14237.726 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-40057.838 40414.942 -46550.438 46925.852 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-133159.93 133692.67 -154724.49 155284.54 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-442350.03 443144.78 -513959.38 514794.88 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1469017.1 1470202.7 -1706787.1 1708033.5 MAarrowhead1
% End of user PostScript
0 .033 1 r
.42339 .53674 m
.41209 .546 L
.39902 .55691 L
.3839 .56978 L
.36639 .58491 L
.34612 .60269 L
.32263 .62356 L
.29541 .64801 L
.26387 .67666 L
.22729 .71018 L
.18489 .74938 L
.13571 .79519 L
.07867 .84869 L
.01249 .91114 L
s
.01249 .91114 m
0 .92299 L
s
1 0 0 r
.42339 .53674 m
.41209 .546 L
s
% Start of user PostScript
-9.1933143 4.4091557 -10.548869 5.5194218 MAarrowhead1
% End of user PostScript
1 .158 0 r
.39902 .55691 m
.3839 .56978 L
s
% Start of user PostScript
-12.11702 6.829707 -13.931823 8.3734239 MAarrowhead1
% End of user PostScript
1 .473 0 r
.18489 .74938 m
.13571 .79519 L
s
% Start of user PostScript
-37.813235 29.92549 -43.714687 35.42253 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-121.93908 110.17195 -141.34775 128.97731 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-399.47358 381.91908 -463.63686 445.18233 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1318.2753 1292.0871 -1530.8935 1503.3626 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-4364.8582 4325.79 -5070.1619 5029.0905 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-14473.983 14415.7 -16814.758 16753.486 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-48028.675 47941.727 -55798.956 55707.55 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-159421.07 159291.36 -185217.28 185080.92 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-529237.32 529043.81 -614880.69 614677.26 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1757041.3 1756752.7 -2041382.8 2041079.3 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-5833450.7 5833020.1 -6777490.9 6777038.2 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-19367542. 19366899. -22501855. 22501180. MAarrowhead1
% End of user PostScript
0 1 .801 r
.54738 .50553 m
.55359 .50204 L
.56072 .49776 L
.56893 .49255 L
.57839 .48624 L
.58928 .47866 L
.60186 .46957 L
.61637 .45872 L
.63312 .44582 L
.65248 .4305 L
.67487 .41238 L
.70075 .39096 L
.73071 .36571 L
.76538 .33598 L
.80553 .30103 L
.85203 .26 L
.9059 .21187 L
.96833 .15547 L
s
.96833 .15547 m
1 .12658 L
s
1 0 0 r
.54738 .50553 m
.55359 .50204 L
s
% Start of user PostScript
5.6856223 0.66417731 6.4302373 0.24512358 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56072 .49776 m
.56893 .49255 L
s
% Start of user PostScript
7.2863576 -0.26874371 8.2715674 -0.89415275 MAarrowhead1
% End of user PostScript
1 .473 0 r
.67487 .41238 m
.70075 .39096 L
s
% Start of user PostScript
20.983997 -10.514947 24.090553 -13.084744 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
64.884203 -49.266216 74.952995 -58.534257 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
208.28458 -184.98528 241.34815 -216.85427 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
680.87967 -646.12121 790.10857 -753.568 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2244.713 -2192.8594 2606.5511 -2552.039 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
7429.0087 -7351.6523 8629.1385 -8547.8159 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
24629.82 -24514.418 28612.578 -28491.259 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
81721.134 -81548.975 94941.654 -94760.667 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
271245.03 -270988.2 315134.67 -314864.67 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
900447.83 -900064.68 1046160.5 -1045757.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2989416.9 -2988845.4 3473191.2 -3472590.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
9924952.5 -9924099.8 11531126. -11530230. MAarrowhead1
% End of user PostScript
0 1 .317 r
.44663 .49649 m
.43956 .50064 L
.43143 .5057 L
.42207 .51184 L
.41129 .51923 L
.39885 .52811 L
.3845 .53871 L
.36793 .55134 L
.34879 .56635 L
.32667 .58412 L
.30108 .60513 L
.27148 .62992 L
.23722 .65913 L
.19756 .69347 L
.15163 .73382 L
.09842 .78116 L
.03676 .83665 L
s
.03676 .83665 m
0 .87006 L
s
1 0 0 r
.44663 .49649 m
.43956 .50064 L
s
% Start of user PostScript
-6.4049428 -0.42120862 -7.2528016 0.076665986 MAarrowhead1
% End of user PostScript
1 .158 0 r
.43143 .5057 m
.42207 .51184 L
s
% Start of user PostScript
-8.2281993 0.68413527 -9.3512798 1.4204234 MAarrowhead1
% End of user PostScript
1 .473 0 r
.30108 .60513 m
.27148 .62992 L
s
% Start of user PostScript
-23.870395 12.615974 -27.422362 15.590914 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-74.108411 57.318787 -85.637611 67.987165 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-238.3745 213.32733 -276.25934 249.92797 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-779.98284 742.61684 -905.17794 865.89615 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2572.5552 2516.8117 -2987.342 2928.7404 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-8515.7053 8432.5457 -9891.5394 9804.1162 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-28235.127 28111.068 -32801.109 32670.688 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-93687.219 93502.144 -108843.9 108649.34 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-310967.93 310691.83 -361285.56 360995.3 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1032323.7 1031911.8 -1199377.6 1198944.6 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3427247.1 3426632.6 -3981876. 3981230.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-11378580. 11377663. -13219999. 13219035. MAarrowhead1
% End of user PostScript
.432 0 1 r
.5068 .44615 m
.5092 .44133 L
.51205 .43594 L
.51544 .42989 L
.51945 .42307 L
.52419 .41539 L
.52977 .40671 L
.53635 .39688 L
.54408 .38572 L
.55315 .37305 L
.56379 .35863 L
.57626 .34218 L
.59085 .3234 L
.60793 .30193 L
.62788 .27736 L
.6512 .24918 L
.67842 .21685 L
.71019 .17971 L
.74725 .13701 L
.79046 .08786 L
.84083 .03125 L
s
.84083 .03125 m
.86895 0 L
s
1 0 0 r
.5068 .44615 m
.5092 .44133 L
s
% Start of user PostScript
0.81564954 -6.4624595 1.1037318 -7.0400599 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51205 .43594 m
.51544 .42989 L
s
% Start of user PostScript
1.4464382 -7.6871283 1.853019 -8.4136762 MAarrowhead1
% End of user PostScript
1 .473 0 r
.56379 .35863 m
.57626 .34218 L
s
% Start of user PostScript
7.6547953 -16.964811 9.1509395 -18.93829 MAarrowhead1
% End of user PostScript
1 .788 0 r
.74725 .13701 m
.79046 .08786 L
s
% Start of user PostScript
29.670173 -43.559084 34.855723 -49.456734 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
104.85669 -125.57651 122.3988 -144.18095 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
357.60694 -388.51728 416.33438 -448.82952 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1201.4251 -1247.538 1397.1315 -1445.6085 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4009.9489 -4078.7411 4660.7974 -4733.1167 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
13344.942 -13447.568 15507.447 -15615.335 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
44353.676 -44506.776 51535.851 -51696.801 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
147329.37 -147557.77 171178.62 -171418.73 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
489255.12 -489595.85 568442.77 -568800.97 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1624539.9 -1625048.3 1887460.2 -1887994.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
5393894.9 -5394653.2 6266832.8 -6267630. MAarrowhead1
% End of user PostScript
1 0 .171 r
.44949 .54715 m
.44141 .55506 L
.43203 .56426 L
.42113 .57497 L
.40847 .58743 L
.39378 .60191 L
.3767 .61877 L
.35688 .63836 L
.33384 .66115 L
.30709 .68764 L
.27602 .71845 L
.23993 .75426 L
.198 .79589 L
.14929 .84428 L
.09271 .90053 L
.02699 .96591 L
s
.02699 .96591 m
0 .99277 L
s
1 0 0 r
.44949 .54715 m
.44141 .55506 L
s
% Start of user PostScript
-6.0608528 5.658083 -7.0305735 6.6071532 MAarrowhead1
% End of user PostScript
1 .158 0 r
.43203 .56426 m
.42113 .57497 L
s
% Start of user PostScript
-8.1566573 7.7115279 -9.4643801 8.9964283 MAarrowhead1
% End of user PostScript
1 .473 0 r
.27602 .71845 m
.23993 .75426 L
s
% Start of user PostScript
-26.877599 26.213544 -31.20896 30.510858 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-88.933251 87.942597 -103.29831 102.25687 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-294.81599 293.33811 -342.48646 340.93281 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-978.14806 975.94332 -1136.385 1134.0672 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3246.5582 3243.2691 -3771.8716 3768.4138 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-10777.449 10772.543 -12521.474 12516.316 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-35780.149 35772.829 -41570.401 41562.705 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-118790.93 118780.01 -138015.07 138003.59 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-394394.8 394378.51 -458220.93 458203.81 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1309429.4 1309405.1 -1521339.2 1521313.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4347447.6 4347411.3 -5051012.5 5050974.4 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-14434018. 14433964. -16769935. 16769878. MAarrowhead1
% End of user PostScript
1 0 .365 r
.5017 .43287 m
.50378 .42743 L
.5063 .42139 L
.50932 .41466 L
.51292 .40716 L
.51723 .39876 L
.52234 .38934 L
.52839 .37875 L
.53555 .36683 L
.544 .35338 L
.55396 .33816 L
.56568 .32091 L
.57944 .30133 L
.59559 .27907 L
.61453 .25371 L
.6367 .22477 L
.66266 .19172 L
.693 .15391 L
.72847 .11059 L
.76989 .06092 L
.81825 .00389 L
s
.81825 .00389 m
.82159 0 L
s
1 0 0 r
.5017 .43287 m
.50378 .42743 L
s
% Start of user PostScript
0.2040366 -8.0559748 0.45409045 -8.7086062 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5063 .42139 m
.50932 .41466 L
s
% Start of user PostScript
0.75573914 -9.4334729 1.117903 -10.240554 MAarrowhead1
% End of user PostScript
1 .473 0 r
.55396 .33816 m
.56568 .32091 L
s
% Start of user PostScript
6.4755006 -19.421158 7.8812865 -21.490682 MAarrowhead1
% End of user PostScript
1 .788 0 r
.72847 .11059 m
.76989 .06092 L
s
% Start of user PostScript
27.41653 -46.729182 32.387281 -52.690113 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
99.85338 -128.66447 116.80944 -147.0977 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
344.69367 -387.67477 401.66494 -446.84972 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1164.0688 -1228.189 1354.2273 -1421.6351 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3894.1521 -3989.8083 4527.0033 -4627.5639 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
12972.762 -13115.464 15076.144 -15226.163 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
43136.313 -43349.199 50123.13 -50346.931 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
143314.91 -143632.5 166516.94 -166850.82 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
475967.41 -476441.2 553008.33 -553506.41 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1580484. -1581190.8 1836280. -1837023. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
5247714.7 -5248769.2 6097003.8 -6098112.3 MAarrowhead1
% End of user PostScript
.414 1 0 r
.55193 .49905 m
.55893 .49467 L
.56698 .48936 L
.57626 .48297 L
.58697 .4753 L
.59932 .46614 L
.61359 .45523 L
.63007 .44228 L
.64912 .42694 L
.67115 .40881 L
.69664 .38742 L
.72613 .36223 L
.76029 .3326 L
.79984 .29781 L
.84567 .25699 L
.89877 .20915 L
.96033 .15313 L
s
.96033 .15313 m
1 .11669 L
s
1 0 0 r
.55193 .49905 m
.55893 .49467 L
s
% Start of user PostScript
6.2318003 -0.11418369 7.0712232 -0.63994972 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56698 .48936 m
.57626 .48297 L
s
% Start of user PostScript
8.0378238 -1.2768119 9.1517392 -2.0440828 MAarrowhead1
% End of user PostScript
1 .473 0 r
.69664 .38742 m
.72613 .36223 L
s
% Start of user PostScript
23.596238 -13.509994 27.136126 -16.532749 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
73.73212 -58.685211 85.248593 -69.430213 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
237.92172 -215.47437 275.80514 -252.20689 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
779.66786 -746.18035 904.9192 -869.71474 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2573.2822 -2523.3247 2988.3465 -2935.8277 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8520.7636 -8446.2358 9897.6549 -9819.306 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
28255.867 -28144.684 32825.56 -32708.677 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
93761.963 -93596.098 108931.27 -108756.91 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
311224.87 -310977.43 361584.87 -361324.74 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1033189.9 -1032820.7 1200385.1 -1199997.1 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3430142.4 -3429591.7 3985241.7 -3984662.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
11388222. -11387401. 13231204. -13230340. MAarrowhead1
% End of user PostScript
.442 1 0 r
.45874 .45643 m
.4544 .45641 L
.44949 .45676 L
.44391 .45753 L
.43755 .45883 L
.43031 .46076 L
.42204 .46344 L
.41259 .46702 L
.40177 .47167 L
.38938 .47758 L
.37515 .48498 L
.35881 .49415 L
.34003 .5054 L
.31841 .51909 L
.29351 .53565 L
.26482 .55559 L
.23172 .57948 L
.19353 .60799 L
.14941 .64193 L
.09844 .6822 L
.03952 .72988 L
s
.03952 .72988 m
0 .76254 L
s
1 0 0 r
.45874 .45643 m
.4544 .45641 L
s
% Start of user PostScript
-4.9516669 -5.2283088 -5.4716337 -5.2302806 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44949 .45676 m
.44391 .45753 L
s
% Start of user PostScript
-6.061322 -5.1892911 -6.7312757 -5.0961687 MAarrowhead1
% End of user PostScript
1 .473 0 r
.37515 .48498 m
.35881 .49415 L
s
% Start of user PostScript
-14.981946 -1.8019968 -16.942616 -0.70185745 MAarrowhead1
% End of user PostScript
1 .788 0 r
.14941 .64193 m
.09844 .6822 L
s
% Start of user PostScript
-42.070324 17.031624 -48.186653 21.864192 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-128.23388 90.880528 -147.95404 108.68554 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-408.67826 352.95361 -473.27612 414.69441 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1331.3894 1248.258 -1544.5559 1457.1623 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4382.3713 4258.3538 -5088.161 4957.785 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-14493.3 14308.288 -16833.698 16639.2 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-48034.886 47758.88 -55800.947 55510.789 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-159355.28 158943.53 -185133.04 184700.18 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-528889.97 528275.71 -614465.5 613819.75 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1755695.8 1754779.4 -2039802.2 2038838.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-5828696.4 5827329.4 -6771941.3 6770504.2 MAarrowhead1
% End of user PostScript
.702 0 1 r
.57983 .43654 m
.5923 .42491 L
.60676 .41134 L
.62354 .39549 L
.643 .377 L
.66559 .35543 L
.69181 .33029 L
.72224 .30099 L
.75757 .26686 L
.79857 .22711 L
.84618 .18081 L
.90146 .12692 L
.96565 .06419 L
s
.96565 .06419 m
1 .03054 L
s
1 0 0 r
.57983 .43654 m
.5923 .42491 L
s
% Start of user PostScript
9.5797562 -7.6149174 11.075779 -9.0102008 MAarrowhead1
% End of user PostScript
1 .158 0 r
.60676 .41134 m
.62354 .39549 L
s
% Start of user PostScript
12.811125 -10.639642 14.824382 -12.541565 MAarrowhead1
% End of user PostScript
1 .473 0 r
.84618 .18081 m
.90146 .12692 L
s
% Start of user PostScript
41.541907 -38.302436 48.175269 -44.769706 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
136.44331 -131.61059 158.39093 -153.31043 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
450.79885 -443.58927 523.55426 -515.97504 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1493.4096 -1482.6542 1734.7971 -1723.4902 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
4953.3784 -4937.3332 5754.5612 -5737.6933 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
16438.462 -16414.525 19098.106 -19072.942 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
54566.674 -54530.965 63396.443 -63358.903 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
181151.42 -181098.14 210466.45 -210410.44 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
601419.53 -601340.06 698747.61 -698664.06 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1996746.8 -1996628.3 2319885.6 -2319760.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
6629378.8 -6629201.9 7702234.4 -7702048.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
22010232. -22009968. 25572234. -25571956. MAarrowhead1
% End of user PostScript
1 0 .88 r
.56893 .43165 m
.58007 .42054 L
.59301 .40763 L
.60805 .39263 L
.62551 .3752 L
.64581 .35494 L
.66938 .33141 L
.69677 .30406 L
.72859 .27228 L
.76556 .23535 L
.80851 .19245 L
.85841 .1426 L
.91639 .08467 L
.98375 .01737 L
s
.98375 .01737 m
1 .00113 L
s
1 0 0 r
.56893 .43165 m
.58007 .42054 L
s
% Start of user PostScript
8.2716951 -8.201736 9.6084049 -9.5348589 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59301 .40763 m
.60805 .39263 L
s
% Start of user PostScript
11.161341 -11.084024 12.965491 -12.88421 MAarrowhead1
% End of user PostScript
1 .473 0 r
.80851 .19245 m
.85841 .1426 L
s
% Start of user PostScript
37.021618 -36.906275 43.009795 -42.888538 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
122.86338 -122.69131 142.74213 -142.56123 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
407.84214 -407.58543 473.83786 -473.568 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1353.9662 -1353.5833 1573.0738 -1572.6712 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
4495.1512 -4494.5799 5222.6048 -5222.0042 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
14924.166 -14923.314 17339.384 -17338.488 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
49549.588 -49548.317 57568.373 -57567.036 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
164509.84 -164507.95 191133.12 -191131.12 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
546191.05 -546188.22 634583.39 -634580.41 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1813416.9 -1813412.6 2106889.7 -2106885.3 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
6020754.1 -6020747.8 6995118.1 -6995111.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
19989605. -19989595. 23224607. -23224597. MAarrowhead1
% End of user PostScript
.648 1 0 r
.4959 .51693 m
.49488 .51861 L
.49368 .5205 L
.49227 .52265 L
.4906 .52507 L
.48865 .52783 L
.48636 .53097 L
.48367 .53454 L
.48052 .53862 L
.47684 .54329 L
.47254 .54862 L
.46751 .55474 L
.46164 .56175 L
.45478 .56981 L
.44678 .57906 L
.43746 .58972 L
.42658 .60198 L
.41391 .61612 L
.39915 .63242 L
.38196 .65123 L
.36193 .67295 L
.33863 .69805 L
.3115 .72706 L
.27992 .76061 L
.24319 .79942 L
.20045 .84435 L
.15073 .89636 L
.09291 .9566 L
s
.09291 .9566 m
.05109 1 L
s
1 0 0 r
.4959 .51693 m
.49488 .51861 L
s
% Start of user PostScript
-0.4919263 2.0321241 -0.6141091 2.2332745 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49368 .5205 m
.49227 .52265 L
s
% Start of user PostScript
-0.75824798 2.4604298 -0.92800812 2.7174627 MAarrowhead1
% End of user PostScript
1 .473 0 r
.47254 .54862 m
.46751 .55474 L
s
% Start of user PostScript
-3.2954934 5.8348503 -3.8990069 6.5685594 MAarrowhead1
% End of user PostScript
1 .788 0 r
.39915 .63242 m
.38196 .65123 L
s
% Start of user PostScript
-12.102095 15.89037 -14.165339 18.147844 MAarrowhead1
% End of user PostScript
.897 1 0 r
.15073 .89636 m
.09291 .9566 L
s
% Start of user PostScript
-41.911889 47.563332 -48.850878 54.792076 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-141.73549 150.16646 -164.90619 173.76942 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-474.43198 487.00949 -551.55897 564.78135 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1580.9185 1599.6819 -1837.2839 1857.0093 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-5257.4105 5285.4023 -6109.0132 6138.4402 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-17468.012 17509.771 -20296.088 20339.988 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-58014.928 58077.225 -67405.452 67470.943 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-192644.82 192737.76 -223823.92 223921.62 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-639645.8 639784.45 -743166.23 743311.98 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2123762.2 2123969.1 -2467465.4 2467682.8 MAarrowhead1
% End of user PostScript
0 1 .681 r
.45071 .52863 m
.4433 .53498 L
.43473 .54244 L
.4248 .5512 L
.41329 .56148 L
.39995 .57352 L
.3845 .58762 L
.36657 .60411 L
.34579 .62339 L
.32169 .64591 L
.29373 .67221 L
.26129 .70291 L
.22364 .73871 L
.17996 .78047 L
.12926 .82914 L
.07041 .88585 L
.0021 .95192 L
s
.0021 .95192 m
0 .95396 L
s
1 0 0 r
.45071 .52863 m
.4433 .53498 L
s
% Start of user PostScript
-5.9148823 3.4357986 -6.803589 4.1973999 MAarrowhead1
% End of user PostScript
1 .158 0 r
.43473 .54244 m
.4248 .5512 L
s
% Start of user PostScript
-7.8326056 5.0927943 -9.0244588 6.1441744 MAarrowhead1
% End of user PostScript
1 .473 0 r
.29373 .67221 m
.26129 .70291 L
s
% Start of user PostScript
-24.752872 20.665554 -28.645758 24.348879 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-80.314227 74.216665 -93.143278 86.733087 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-263.86559 254.7691 -306.31665 296.75377 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-871.90686 858.33649 -1012.6362 998.37001 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2888.6301 2868.3855 -3355.5498 3334.2672 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-9581.3363 9551.1349 -11131.09 11099.34 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-31797.353 31752.297 -36942.008 36894.643 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-105550.34 105483.12 -122630.14 122559.48 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-350408.73 350308.46 -407114.09 407008.68 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1163352.1 1163202.5 -1351618.2 1351460.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3862396.7 3862173.6 -4487458.6 4487224. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-12823507. 12823174. -14898780. 14898430. MAarrowhead1
% End of user PostScript
1 .628 0 r
.4399 .54308 m
.43065 .55146 L
.41992 .56128 L
.40748 .57275 L
.39305 .58616 L
.37632 .60183 L
.35691 .62012 L
.33438 .64147 L
.30825 .66637 L
.27792 .69539 L
.24272 .72923 L
.20185 .76865 L
.15442 .81457 L
.09935 .86805 L
.03541 .93032 L
s
.03541 .93032 m
0 .96489 L
s
1 0 0 r
.4399 .54308 m
.43065 .55146 L
s
% Start of user PostScript
-7.2116284 5.1696356 -8.3222746 6.1755866 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41992 .56128 m
.40748 .57275 L
s
% Start of user PostScript
-9.6097675 7.3530164 -11.102579 8.7301214 MAarrowhead1
% End of user PostScript
1 .473 0 r
.24272 .72923 m
.20185 .76865 L
s
% Start of user PostScript
-30.874051 27.507374 -35.777473 32.238182 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-100.96664 95.944151 -117.16768 111.88768 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-332.92542 325.43274 -386.59704 378.72021 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1101.9266 1090.7488 -1279.9471 1268.1962 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3653.4161 3636.7409 -4244.203 4226.6728 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-12122.147 12097.27 -14083.238 14057.086 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-40235.575 40198.463 -46746.042 46707.028 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-133569.85 133514.49 -155184.49 155126.29 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-443442.21 443359.62 -515204.06 515117.24 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1472242.2 1472119. -1710498. 1710368.5 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4887960.1 4887776.2 -5678994.3 5678801. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-16228515. 16228241. -18854837. 18854548. MAarrowhead1
% End of user PostScript
1 0 .665 r
.54275 .52394 m
.54783 .52229 L
.55363 .52008 L
.56027 .51722 L
.56788 .51358 L
.57661 .50902 L
.58665 .50338 L
.59818 .49647 L
.61145 .48805 L
.62674 .47786 L
.64436 .4656 L
.66468 .45092 L
.68814 .43339 L
.71522 .41253 L
.74652 .38779 L
.78271 .35849 L
.82455 .32388 L
.87298 .28307 L
.92902 .23502 L
.99392 .17854 L
s
.99392 .17854 m
1 .17317 L
s
1 0 0 r
.54275 .52394 m
.54783 .52229 L
s
% Start of user PostScript
5.1300272 2.8733632 5.7390213 2.6747117 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55363 .52008 m
.56027 .51722 L
s
% Start of user PostScript
6.4352292 2.4098851 7.2321838 2.0664293 MAarrowhead1
% End of user PostScript
1 .473 0 r
.64436 .4656 m
.66468 .45092 L
s
% Start of user PostScript
17.32285 -4.12749 19.76155 -5.8896496 MAarrowhead1
% End of user PostScript
1 .788 0 r
.92902 .23502 m
.99392 .17854 L
s
% Start of user PostScript
51.482644 -31.79748 59.270185 -38.575741 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
161.93084 -132.56403 187.32507 -156.45259 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
524.20654 -480.3964 607.83016 -561.77383 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1720.4026 -1655.0455 1997.0161 -1928.3081 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5682.0648 -5584.5635 6598.9224 -6496.4221 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
18820.554 -18675.099 21862.344 -21709.431 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
62419.957 -62202.964 72515.645 -72287.527 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
207142.37 -206818.66 240656.15 -240315.84 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
687588.94 -687106.01 798851.02 -798343.34 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2282654.9 -2281934.5 2652046.8 -2651289.4 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
7578352. -7577277.2 8804759.1 -8803629.3 MAarrowhead1
% End of user PostScript
0 1 .347 r
.41953 .46733 m
.40964 .47142 L
.3983 .47666 L
.3853 .48325 L
.37037 .49144 L
.35321 .50151 L
.33347 .5138 L
.31075 .5287 L
.28456 .54666 L
.25436 .56821 L
.21951 .59396 L
.17927 .62463 L
.13278 .66106 L
.07905 .70422 L
.01692 .75525 L
s
.01692 .75525 m
0 .76942 L
s
1 0 0 r
.41953 .46733 m
.40964 .47142 L
s
% Start of user PostScript
-9.65591 -3.9207083 -10.843299 -3.429408 MAarrowhead1
% End of user PostScript
1 .158 0 r
.3983 .47666 m
.3853 .48325 L
s
% Start of user PostScript
-12.203607 -2.8008771 -13.763832 -2.0099477 MAarrowhead1
% End of user PostScript
1 .473 0 r
.21951 .59396 m
.17927 .62463 L
s
% Start of user PostScript
-33.659256 11.275196 -38.487763 14.956048 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-101.52151 68.128421 -117.02816 81.922967 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-321.80021 271.98357 -372.50154 320.13074 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1045.6445 971.3268 -1212.8114 1134.6833 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3437.6934 3326.8244 -3990.9654 3874.412 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-11362.869 11197.472 -13197.198 13023.321 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-37650.454 37403.711 -43736.767 43477.372 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-124891.13 124523.03 -145092.62 144705.65 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-414484.91 413935.77 -481547.58 480970.29 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1375887.4 1375068.1 -1598530.4 1597669.2 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4567732.5 4566510.3 -5306914.2 5305629.4 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-15164847. 15163024. -17618988. 17617072. MAarrowhead1
% End of user PostScript
0 1 .529 r
.57824 .57005 m
.5868 .56909 L
.59654 .56735 L
.60763 .56466 L
.62029 .56084 L
.63475 .55566 L
.65129 .54888 L
.67024 .54019 L
.69197 .52925 L
.71693 .51564 L
.74561 .49888 L
.7786 .47843 L
.81658 .45363 L
.86034 .42371 L
.91081 .38781 L
.96904 .3449 L
s
.96904 .3449 m
1 .32134 L
s
1 0 0 r
.57824 .57005 m
.5868 .56909 L
s
% Start of user PostScript
9.3883871 8.4064847 10.415885 8.291349 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59654 .56735 m
.60763 .56466 L
s
% Start of user PostScript
11.58445 8.0819251 12.915616 7.7590752 MAarrowhead1
% End of user PostScript
1 .473 0 r
.74561 .49888 m
.7786 .47843 L
s
% Start of user PostScript
29.472757 -0.13397353 33.431511 -2.5884962 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
84.443032 -40.67471 96.899015 -50.886644 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
260.35542 -195.06076 300.68504 -232.04265 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
834.566 -737.15781 966.93492 -864.5325 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2726.334 -2581.0181 3163.5316 -3010.7651 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8985.3278 -8768.5419 10433.469 -10205.569 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
29733.252 -29409.845 34536.171 -34196.183 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
98570.052 -98087.586 114508.73 -114001.52 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
327043.58 -326323.82 379950.53 -379193.87 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1085493.9 -1084420.2 1261134.3 -1260005.5 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3603476. -3601874.1 4186597.5 -4184913.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
11963229. -11960840. 13899224. -13896711. MAarrowhead1
% End of user PostScript
0 1 .597 r
.51911 .53523 m
.5207 .53643 L
.52247 .53759 L
.52444 .53869 L
.52665 .53971 L
.52913 .54064 L
.53192 .54143 L
.53505 .54205 L
.5386 .54246 L
.5426 .54261 L
.54714 .54244 L
.55229 .54188 L
.55815 .54085 L
.56483 .53926 L
.57244 .53698 L
.58114 .53389 L
.59109 .52983 L
.60249 .52463 L
.61557 .51808 L
.63058 .50992 L
.64782 .49988 L
.66766 .48761 L
.69051 .47273 L
.71682 .45478 L
.74717 .43323 L
.78219 .40747 L
.82261 .37677 L
.86931 .34029 L
.92328 .29706 L
.98569 .24595 L
s
.98569 .24595 m
1 .234 L
s
1 0 0 r
.51911 .53523 m
.5207 .53643 L
s
% Start of user PostScript
2.2926531 4.2277333 2.4834542 4.3712395 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52247 .53759 m
.52444 .53869 L
s
% Start of user PostScript
2.6958931 4.5102483 2.9329974 4.6426107 MAarrowhead1
% End of user PostScript
1 .473 0 r
.54714 .54244 m
.55229 .54188 L
s
% Start of user PostScript
5.6569471 5.0933526 6.2752881 5.0261912 MAarrowhead1
% End of user PostScript
1 .788 0 r
.61557 .51808 m
.63058 .50992 L
s
% Start of user PostScript
13.868053 2.1695091 15.669089 1.1907374 MAarrowhead1
% End of user PostScript
.897 1 0 r
.82261 .37677 m
.86931 .34029 L
s
% Start of user PostScript
38.713221 -14.787989 44.317034 -19.165129 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
117.59684 -81.90459 135.64148 -98.119243 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
374.1213 -320.87472 433.19516 -377.21856 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1217.7889 -1138.3543 1412.6732 -1329.1659 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
4006.8941 -3888.3916 4652.0712 -4527.493 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
13249.192 -13072.408 15388.479 -15202.63 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
43908.065 -43644.332 51006.603 -50729.349 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
145659.36 -145265.92 169221.16 -168807.55 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
483426.29 -482839.34 561644.99 -561027.95 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1604763.5 -1603887.9 1864445. -1863524.5 MAarrowhead1
% End of user PostScript
1 .375 0 r
.54037 .44023 m
.54744 .43217 L
.55568 .42288 L
.56528 .41218 L
.57647 .39983 L
.5895 .38559 L
.60467 .36914 L
.62234 .35013 L
.6429 .32816 L
.66682 .30275 L
.69466 .27335 L
.72705 .23933 L
.76472 .19993 L
.80854 .1543 L
.8595 .10143 L
.91876 .04017 L
s
.91876 .04017 m
.95774 0 L
s
1 0 0 r
.54037 .44023 m
.54744 .43217 L
s
% Start of user PostScript
4.8442965 -7.172334 5.6926183 -8.1400168 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55568 .42288 m
.56528 .41218 L
s
% Start of user PostScript
6.6815269 -9.2544062 7.8339431 -10.538737 MAarrowhead1
% End of user PostScript
1 .473 0 r
.69466 .27335 m
.72705 .23933 L
s
% Start of user PostScript
23.359444 -27.197729 27.245896 -31.280974 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
79.310463 -85.036511 92.303884 -98.323513 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
265.93723 -274.47949 309.2111 -318.19133 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
886.84714 -899.5907 1030.7216 -1044.1186 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2950.2609 -2969.2721 3428.2397 -3448.2255 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9803.9008 -9832.2621 11391.292 -11421.107 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
32563.06 -32605.37 37834.048 -37878.527 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
108132.51 -108195.62 125633.79 -125700.15 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
359041.41 -359135.57 417149.21 -417248.2 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1192102.5 -1192243. 1385029.4 -1385177.1 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3957983.9 -3958193.5 4598527. -4598747.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
13141065. -13141378. 15267748. -15268077. MAarrowhead1
% End of user PostScript
0 1 .715 r
.44457 .52083 m
.43655 .52707 L
.42729 .53446 L
.41658 .54321 L
.40419 .55354 L
.38985 .56571 L
.37326 .58003 L
.35404 .59686 L
.33177 .6166 L
.30597 .63975 L
.27607 .66687 L
.24141 .69861 L
.20122 .73572 L
.15461 .7791 L
.10055 .82976 L
.03783 .88891 L
s
.03783 .88891 m
0 .92479 L
s
1 0 0 r
.44457 .52083 m
.43655 .52707 L
s
% Start of user PostScript
-6.6520441 2.4992663 -7.6137865 3.2480913 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42729 .53446 m
.41658 .54321 L
s
% Start of user PostScript
-8.7252867 4.1357575 -10.010479 5.1856393 MAarrowhead1
% End of user PostScript
1 .473 0 r
.27607 .66687 m
.24141 .69861 L
s
% Start of user PostScript
-26.871222 20.024449 -31.030655 23.832841 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-86.086123 75.871938 -99.735477 88.9976 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-281.14736 265.90959 -326.22545 310.20642 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-926.47735 903.74526 -1075.7848 1051.8872 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3065.6229 3031.7106 -3560.8083 3525.1573 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-10162.726 10112.135 -11806.005 11752.82 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-33718.315 33642.842 -39173.007 39093.664 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-111914.25 111801.66 -130022.7 129904.33 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-371516.94 371348.97 -431636.45 431459.87 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1233402.9 1233152.3 -1433002.8 1432739.4 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4094927.3 4094553.5 -4757616.4 4757223.4 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-13595466. 13594909. -15795663. 15795077. MAarrowhead1
% End of user PostScript
0 1 .828 r
.52686 .55855 m
.52885 .56095 L
.53103 .56337 L
.53345 .56579 L
.53612 .56821 L
.53908 .5706 L
.54237 .57293 L
.54604 .57517 L
.55014 .57728 L
.55473 .57923 L
.55989 .58094 L
.56569 .58236 L
.57223 .58341 L
.57961 .584 L
.58798 .58403 L
.59746 .58337 L
.60823 .58186 L
.62049 .57935 L
.63447 .57562 L
.65042 .57044 L
.66866 .56352 L
.68954 .55455 L
.71347 .54314 L
.74092 .52884 L
.77246 .51114 L
.80871 .48942 L
.85043 .46299 L
.89848 .43101 L
.95386 .39252 L
s
.95386 .39252 m
1 .35921 L
s
1 0 0 r
.52686 .55855 m
.52885 .56095 L
s
% Start of user PostScript
3.2233621 7.0265728 3.4616962 7.3137641 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53103 .56337 m
.53345 .56579 L
s
% Start of user PostScript
3.724075 7.603855 4.0136449 7.8950804 MAarrowhead1
% End of user PostScript
1 .473 0 r
.55989 .58094 m
.56569 .58236 L
s
% Start of user PostScript
7.1866728 9.7126129 7.882613 9.8831176 MAarrowhead1
% End of user PostScript
1 .788 0 r
.63447 .57562 m
.65042 .57044 L
s
% Start of user PostScript
16.136386 9.074386 18.05096 8.4523956 MAarrowhead1
% End of user PostScript
.897 1 0 r
.85043 .46299 m
.89848 .43101 L
s
% Start of user PostScript
42.051523 -4.4414711 47.817328 -8.2789675 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
122.42543 -66.317827 140.6872 -81.702898 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
380.82147 -297.11876 440.13782 -352.14358 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1226.1136 -1101.2438 1421.0892 -1289.8172 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
4013.7658 -3827.482 4658.1815 -4462.3467 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
13241.026 -12963.124 15376.196 -15084.045 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
43834.734 -43420.152 50917.236 -50481.397 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
145346.95 -144728.46 168851.97 -168201.77 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
482286.17 -481363.5 560311.08 -559341.11 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1600824.7 -1599448.3 1859855. -1858407.9 MAarrowhead1
% End of user PostScript
1 .566 0 r
.4994 .49706 m
.4994 .49688 L
.49941 .49668 L
.49942 .49647 L
.49944 .49623 L
.49947 .49598 L
.49951 .49571 L
.49957 .49541 L
.49963 .49509 L
.49972 .49473 L
.49983 .49434 L
.49996 .4939 L
.50013 .49343 L
.50032 .4929 L
.50056 .49231 L
.50085 .49166 L
.5012 .49093 L
.50161 .49011 L
.5021 .4892 L
.50268 .48817 L
.50337 .48701 L
.50418 .48571 L
.50513 .48424 L
.50626 .48257 L
.50758 .48067 L
.50913 .47852 L
.51095 .47607 L
.51308 .47327 L
.51557 .47008 L
.51849 .46642 L
.5219 .46224 L
.52588 .45745 L
.53053 .45194 L
.53596 .44562 L
.54228 .43835 L
.54966 .42997 L
.55826 .42033 L
.56828 .40921 L
.57995 .39639 L
.59355 .38158 L
.60937 .36448 L
.6278 .34471 L
.64924 .32186 L
.67419 .29543 L
.70322 .26484 L
.73699 .22944 L
.77627 .18843 L
.82196 .14094 L
.87509 .08591 L
.93687 .02213 L
Mistroke
Mfstroke
.93687 .02213 m
.95836 0 L
s
1 0 0 r
.4994 .49706 m
.4994 .49688 L
s
% Start of user PostScript
-0.071682501 -0.35295855 -0.071545772 -0.3748671 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49941 .49668 m
.49942 .49647 L
s
% Start of user PostScript
-0.070785125 -0.39851582 -0.069268735 -0.42409378 MAarrowhead1
% End of user PostScript
1 .473 0 r
.49983 .49434 m
.49996 .4939 L
s
% Start of user PostScript
-0.020510074 -0.67960467 -0.004477584 -0.73153281 MAarrowhead1
% End of user PostScript
1 .788 0 r
.5021 .4892 m
.50268 .48817 L
s
% Start of user PostScript
0.25190774 -1.2963562 0.32154442 -1.4195429 MAarrowhead1
% End of user PostScript
.897 1 0 r
.51095 .47607 m
.51308 .47327 L
s
% Start of user PostScript
1.3137524 -2.8718864 1.5694306 -3.2074518 MAarrowhead1
% End of user PostScript
.581 1 0 r
.54228 .43835 m
.54966 .42997 L
s
% Start of user PostScript
5.0739927 -7.3984555 5.9593884 -8.403029 MAarrowhead1
% End of user PostScript
.266 1 0 r
.64924 .32186 m
.67419 .29543 L
s
% Start of user PostScript
17.908698 -21.376389 20.902789 -24.548272 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
61.04396 -66.217147 71.065954 -76.504376 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
205.03761 -212.7551 238.43303 -246.54621 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
684.27629 -695.78943 795.33386 -807.43729 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
2277.1396 -2294.3152 2646.1336 -2664.1898 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
7568.2204 -7593.8433 8793.7258 -8820.6625 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
25139.088 -25177.313 29208.51 -29248.695 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
83482.183 -83539.208 96994.036 -97053.984 MAarrowhead1
% End of user PostScript
0 .179 1 r
.46511 .51365 m
.46005 .51762 L
.45421 .52232 L
.44744 .52788 L
.43962 .53444 L
.43057 .54216 L
.42008 .55124 L
.40794 .56191 L
.39388 .57443 L
.37758 .58911 L
.35869 .60629 L
.33679 .6264 L
.31139 .64991 L
.28194 .67737 L
.24777 .70945 L
.20813 .7469 L
.16214 .79058 L
.10877 .84153 L
.04683 .90092 L
s
.04683 .90092 m
0 .94601 L
s
1 0 0 r
.46511 .51365 m
.46005 .51762 L
s
% Start of user PostScript
-4.1865775 1.6375346 -4.7936515 2.1139164 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45421 .52232 m
.44744 .52788 L
s
% Start of user PostScript
-5.4953585 2.6782304 -6.306828 3.3452627 MAarrowhead1
% End of user PostScript
1 .473 0 r
.35869 .60629 m
.33679 .6264 L
s
% Start of user PostScript
-16.957599 12.754938 -19.585755 15.167619 MAarrowhead1
% End of user PostScript
1 .788 0 r
.04683 .90092 m
0 0 rlineto s
.04683 .90092 m
0 .94601 L
s
% Start of user PostScript
-54.380289 48.110656 -63.007585 56.4165 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-177.68324 168.33004 -206.17994 196.3472 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-585.65403 571.70071 -680.04723 665.3785 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1938.0622 1917.2463 -2251.1316 2229.2485 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6425.0787 6394.025 -7464.018 7431.3722 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-21317.819 21271.492 -24766.491 24717.789 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-70756.475 70687.364 -82205.386 82132.731 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-234888.18 234785.08 -272898.28 272789.9 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-779809.1 779655.29 -906004.67 905842.97 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2588987.1 2588757.6 -3007967.5 3007726.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-8595635. 8595292.7 -9986693.6 9986333.8 MAarrowhead1
% End of user PostScript
0 .283 1 r
.52734 .44281 m
.53258 .43603 L
.53873 .42828 L
.5459 .41941 L
.55429 .40925 L
.56409 .39758 L
.57552 .38419 L
.58885 .36879 L
.6044 .35106 L
.62253 .33065 L
.64365 .30713 L
.66826 .28 L
.69692 .24869 L
.73029 .21252 L
.76914 .17074 L
.81436 .12244 L
.86698 .06658 L
.92821 .00195 L
s
.92821 .00195 m
.93006 0 L
s
1 0 0 r
.52734 .44281 m
.53258 .43603 L
s
% Start of user PostScript
3.2802978 -6.8624884 3.9101769 -7.6760304 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53873 .42828 m
.5459 .41941 L
s
% Start of user PostScript
4.6470686 -8.6060015 5.5085515 -9.6704632 MAarrowhead1
% End of user PostScript
1 .473 0 r
.64365 .30713 m
.66826 .28 L
s
% Start of user PostScript
17.238333 -23.144366 20.191333 -26.400175 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
59.932769 -68.743536 69.87548 -79.137985 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
203.01096 -216.15508 236.2284 -250.04644 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
680.02796 -699.63669 790.62177 -811.23586 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2266.735 -2295.9877 2634.3789 -2665.1315 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
7539.1958 -7582.8358 8760.5021 -8806.3795 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
25050.958 -25116.061 29106.86 -29175.302 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
83201.867 -83298.99 96669.463 -96771.565 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
276284.32 -276429.21 321000.59 -321152.91 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
917362.47 -917578.62 1065829.1 -1066056.3 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3045849.4 -3046171.9 3538781.1 -3539120.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
10112724. -10113205. 11749322. -11749828. MAarrowhead1
% End of user PostScript
0 .179 1 r
.50871 .57865 m
.5077 .58413 L
.50641 .59013 L
.50478 .59671 L
.50275 .60395 L
.50024 .61192 L
.49718 .62073 L
.49347 .63049 L
.48898 .64133 L
.4836 .6534 L
.47716 .66687 L
.46948 .68193 L
.46035 .69881 L
.44954 .71779 L
.43675 .73916 L
.42165 .76328 L
.40386 .79055 L
.38293 .82145 L
.35833 .85653 L
.32946 .89641 L
.29562 .94183 L
.25598 .99364 L
s
.25598 .99364 m
.251 1 L
s
1 0 0 r
.50871 .57865 m
.5077 .58413 L
s
% Start of user PostScript
1.0449095 9.4375646 0.92426784 10.095654 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50641 .59013 m
.50478 .59671 L
s
% Start of user PostScript
0.76924671 10.815679 0.57352071 11.605377 MAarrowhead1
% End of user PostScript
1 .473 0 r
.47716 .66687 m
.46948 .68193 L
s
% Start of user PostScript
-2.7411683 20.023846 -3.66249 21.83127 MAarrowhead1
% End of user PostScript
1 .788 0 r
.35833 .85653 m
.32946 .89641 L
s
% Start of user PostScript
-17.000446 42.783172 -20.464355 47.56899 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-68.228057 106.69136 -80.332849 120.76821 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-244.10567 301.48618 -285.19637 345.51884 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-836.68645 922.28811 -974.45706 1064.4476 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2817.0231 2944.7257 -3276.4436 3410.6938 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-9411.2154 9601.7254 -10939.538 11139.816 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-31333.412 31617.62 -36412.087 36710.866 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-104160.5 104584.48 -121028.95 121474.68 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-346018.82 346651.34 -402034. 402698.94 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1149112. 1150055.6 -1335103.8 1336095.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3815617.6 3817025.3 -4433154.1 4434634. MAarrowhead1
% End of user PostScript
.138 1 0 r
.56296 .50758 m
.5712 .50296 L
.58068 .49729 L
.59158 .49038 L
.60413 .48203 L
.6186 .47198 L
.6353 .45993 L
.65456 .44555 L
.6768 .42844 L
.70251 .40813 L
.73222 .38408 L
.76659 .35568 L
.80635 .32219 L
.85238 .28275 L
.90567 .23639 L
.9674 .18195 L
s
.9674 .18195 m
1 .15283 L
s
1 0 0 r
.56296 .50758 m
.5712 .50296 L
s
% Start of user PostScript
7.5557184 0.90965601 8.5445028 0.35490068 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58068 .49729 m
.59158 .49038 L
s
% Start of user PostScript
9.6813094 -0.32562377 10.989478 -1.1541164 MAarrowhead1
% End of user PostScript
1 .473 0 r
.73222 .38408 m
.76659 .35568 L
s
% Start of user PostScript
27.866847 -13.909804 31.990874 -17.318238 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
86.141803 -65.320342 99.506975 -77.617975 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
276.48393 -245.42196 320.36992 -287.71537 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
903.76138 -857.42237 1048.7401 -1000.0252 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2979.4132 -2910.2835 3459.6734 -3386.9994 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9860.4027 -9757.2733 11453.303 -11344.886 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
32690.552 -32536.701 37976.75 -37815.011 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
108466.13 -108236.62 126013.33 -125772.04 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
360015.34 -359672.94 418268.69 -417908.73 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1195136.5 -1194625.7 1388536.4 -1387999.4 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3967759.5 -3966997.5 4609857.8 -4609056.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
13173077. -13171940. 15304901. -15303706. MAarrowhead1
% End of user PostScript
0 1 .834 r
.45215 .46278 m
.44676 .46381 L
.44062 .46536 L
.43361 .46756 L
.42559 .4705 L
.41642 .47434 L
.40592 .47925 L
.39387 .48541 L
.38003 .49306 L
.36412 .50246 L
.34582 .51393 L
.32474 .52781 L
.30045 .54454 L
.27244 .5646 L
.24012 .58857 L
.2028 .61711 L
.15968 .65099 L
.10984 .69113 L
.0522 .73856 L
s
.0522 .73856 m
0 .78236 L
s
1 0 0 r
.45215 .46278 m
.44676 .46381 L
s
% Start of user PostScript
-5.7416401 -4.4668785 -6.3886626 -4.343258 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44062 .46536 m
.43361 .46756 L
s
% Start of user PostScript
-7.1259283 -4.1562297 -7.9672998 -3.8933068 MAarrowhead1
% End of user PostScript
1 .473 0 r
.34582 .51393 m
.32474 .52781 L
s
% Start of user PostScript
-18.502145 1.6711428 -21.031203 3.3372573 MAarrowhead1
% End of user PostScript
1 .788 0 r
.0522 .73856 m
0 0 rlineto s
.0522 .73856 m
0 .78236 L
s
% Start of user PostScript
-53.736286 28.627382 -61.738628 35.342362 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-166.93415 129.47607 -192.91444 153.53584 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-537.11981 481.23892 -622.4996 563.75363 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1757.7589 1674.3944 -2039.9203 1952.2816 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5797.8615 5673.4963 -6732.7165 6601.9749 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-19192.734 19007.203 -22293.648 22098.604 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-63637.32 63360.54 -73928.367 73637.397 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-211156.83 210743.93 -245317.83 244883.75 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-700876.65 700260.67 -814285.47 813637.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2326710.9 2325791.9 -2703227. 2702260.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-7724532.2 7723161.3 -8974588.1 8973146.9 MAarrowhead1
% End of user PostScript
1 0 .731 r
.51624 .48457 m
.51884 .48201 L
.52187 .47902 L
.52538 .47556 L
.52947 .47152 L
.53421 .46683 L
.53971 .46138 L
.54611 .45504 L
.55354 .44766 L
.56217 .43909 L
.5722 .42913 L
.58385 .41755 L
.59738 .40409 L
.6131 .38845 L
.63136 .37027 L
.65257 .34914 L
.67722 .32458 L
.70585 .29604 L
.73911 .26288 L
.77775 .22434 L
.82264 .17956 L
.87479 .12752 L
.93538 .06704 L
s
.93538 .06704 m
1 .00254 L
s
1 0 0 r
.51624 .48457 m
.51884 .48201 L
s
% Start of user PostScript
1.9485631 -1.8515584 2.2612261 -2.1592478 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52187 .47902 m
.52538 .47556 L
s
% Start of user PostScript
2.6243511 -2.5171443 3.0460977 -2.9333943 MAarrowhead1
% End of user PostScript
1 .473 0 r
.5722 .42913 m
.58385 .41755 L
s
% Start of user PostScript
8.6641512 -8.5042174 10.061887 -9.8937531 MAarrowhead1
% End of user PostScript
1 .788 0 r
.73911 .26288 m
.77775 .22434 L
s
% Start of user PostScript
28.692894 -28.4543 33.329791 -33.078965 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
95.154707 -94.798768 110.54416 -110.16997 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
315.76206 -315.23106 366.8485 -366.29028 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1048.1243 -1047.3321 1217.7248 -1216.892 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3479.533 -3478.3513 4042.608 -4041.3656 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
11551.916 -11550.153 13421.363 -13419.51 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
38352.907 -38350.277 44559.648 -44556.883 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
127334.93 -127331.01 147941.98 -147937.85 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
422765.08 -422759.22 491182.78 -491176.63 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1403626.8 -1403618.1 1630781.4 -1630772.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4660201.1 -4660188.1 5414380.9 -5414367.2 MAarrowhead1
% End of user PostScript
0 .874 1 r
.54547 .45351 m
.55285 .44607 L
.56144 .43743 L
.57141 .4274 L
.583 .41575 L
.59646 .40222 L
.61211 .38651 L
.63029 .36825 L
.65142 .34705 L
.67597 .32243 L
.70449 .29382 L
.73763 .2606 L
.77614 .222 L
.82087 .17716 L
.87286 .12508 L
.93326 .06458 L
s
.93326 .06458 m
.99773 0 L
s
1 0 0 r
.54547 .45351 m
.55285 .44607 L
s
% Start of user PostScript
5.4559094 -5.5788186 6.3422597 -6.4714706 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56144 .43743 m
.57141 .4274 L
s
% Start of user PostScript
7.3722259 -7.5080617 8.5690592 -8.7118593 MAarrowhead1
% End of user PostScript
1 .473 0 r
.70449 .29382 m
.73763 .2606 L
s
% Start of user PostScript
24.538739 -24.741382 28.515548 -28.728581 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
81.564105 -81.866413 94.772326 -95.090134 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
270.94054 -271.39153 314.80047 -315.27458 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
899.76042 -900.43322 1045.3911 -1046.0984 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2987.6173 -2988.621 3471.1438 -3472.199 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9919.6975 -9921.1949 11525.086 -11526.66 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
32935.24 -32937.474 38265.351 -38267.7 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
109349.87 -109353.2 127046.51 -127050.02 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
363055.87 -363060.84 421810.88 -421816.11 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1205390.2 -1205397.6 1400463.8 -1400471.6 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4002039.9 -4002050.9 4649707.3 -4649718.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
13287245. -13287262. 15437577. -15437594. MAarrowhead1
% End of user PostScript
.873 0 1 r
.50879 .56893 m
.50807 .57364 L
.50712 .57878 L
.50589 .58441 L
.50435 .59058 L
.50243 .59737 L
.50007 .60485 L
.49718 .61312 L
.49367 .62228 L
.48944 .63245 L
.48437 .64378 L
.47829 .65642 L
.47106 .67056 L
.46246 .68642 L
.45227 .70425 L
.44022 .72432 L
.42599 .74698 L
.40924 .77261 L
.38952 .80165 L
.36636 .83461 L
.33917 .8721 L
.30731 .9148 L
.26998 .96351 L
s
.26998 .96351 m
.24134 1 L
s
1 0 0 r
.50879 .56893 m
.50807 .57364 L
s
% Start of user PostScript
1.0553029 8.2715331 0.96828592 8.8367471 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50712 .57878 m
.50589 .58441 L
s
% Start of user PostScript
0.85396891 9.4537789 0.70725607 10.128981 MAarrowhead1
% End of user PostScript
1 .473 0 r
.48437 .64378 m
.47829 .65642 L
s
% Start of user PostScript
-1.8761172 17.25347 -2.6047793 18.770546 MAarrowhead1
% End of user PostScript
1 .788 0 r
.38952 .80165 m
.36636 .83461 L
s
% Start of user PostScript
-13.257502 36.197817 -16.037108 40.153598 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-54.501856 88.724784 -64.268072 100.24565 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-196.59491 247.64952 -229.82189 283.49413 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-676.05379 752.21831 -787.56769 867.63725 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2279.3904 2393.0145 -2651.4144 2770.8642 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7619.7771 7789.2843 -8857.6032 9035.8013 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-25376.028 25628.903 -29489.728 29755.568 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-84366.962 84744.208 -98030.853 98427.44 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-280280.61 280843.39 -325655.16 326246.8 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-930821.62 931661.2 -1081483.6 1082366.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3090820.4 3092072.9 -3591055.6 3592372.3 MAarrowhead1
% End of user PostScript
1 0 .515 r
.56983 .53499 m
.57823 .53196 L
.58784 .528 L
.59886 .52292 L
.61149 .51653 L
.62599 .50859 L
.64266 .49882 L
.66184 .4869 L
.68392 .47245 L
.70936 .45502 L
.7387 .43411 L
.77255 .40912 L
.81164 .37935 L
.8568 .34398 L
.90899 .30209 L
.96934 .25255 L
s
.96934 .25255 m
1 .22689 L
s
1 0 0 r
.56983 .53499 m
.57823 .53196 L
s
% Start of user PostScript
8.3790656 4.1989068 9.3874203 3.8354385 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58784 .528 m
.59886 .52292 L
s
% Start of user PostScript
10.541136 3.3596731 11.862824 2.7506954 MAarrowhead1
% End of user PostScript
1 .473 0 r
.7387 .43411 m
.77255 .40912 L
s
% Start of user PostScript
28.644119 -7.9065485 32.706516 -10.905707 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
85.62324 -54.68642 98.624894 -66.101909 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
270.13878 -223.98647 312.5808 -264.06221 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
875.79736 -806.9462 1015.6283 -943.24703 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2876.2796 -2773.5658 3338.9211 -3230.941 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9502.6369 -9349.4059 11036.254 -10875.166 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
31479.828 -31251.234 36568.023 -36327.709 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
104412.23 -104071.2 121300.27 -120941.77 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
346504.92 -345996.18 402567.22 -402032.39 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1150204.3 -1149445.4 1336325.8 -1335527.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3818466. -3817333.7 4436393.2 -4435202.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
12677236. -12675547. 14728800. -14727024. MAarrowhead1
% End of user PostScript
1 0 .233 r
.4715 .55956 m
.46603 .56663 L
.45963 .5747 L
.45215 .58394 L
.44341 .59454 L
.4332 .60669 L
.42129 .62065 L
.40739 .6367 L
.39119 .65516 L
.3723 .67643 L
.35028 .70094 L
.32464 .72921 L
.29477 .76184 L
.25999 .79952 L
.2195 .84306 L
.17238 .89339 L
.11754 .9516 L
s
.11754 .9516 m
.07169 1 L
s
1 0 0 r
.4715 .55956 m
.46603 .56663 L
s
% Start of user PostScript
-3.4196384 7.1477751 -4.0761017 7.995384 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45963 .5747 m
.45215 .58394 L
s
% Start of user PostScript
-4.8440865 8.9643148 -5.741912 10.073389 MAarrowhead1
% End of user PostScript
1 .473 0 r
.35028 .70094 m
.32464 .72921 L
s
% Start of user PostScript
-17.966179 24.112837 -21.04362 27.505425 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-62.459287 71.629023 -72.820797 82.460676 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-211.56337 225.24301 -246.17969 260.5607 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-708.66773 729.07536 -823.91852 845.37247 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2362.1875 2392.6321 -2745.3119 2777.3174 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-7856.6541 7902.0721 -9129.3852 9177.1318 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-26105.77 26173.525 -30332.45 30403.68 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-86705.177 86806.257 -100739.84 100846.1 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-287917.53 288068.32 -334516.61 334675.13 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-955988.78 956213.73 -1110706.7 1110943.2 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3174097.3 3174432.9 -3687784.3 3688137.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-10538528. 10539028. -12244036. 12244562. MAarrowhead1
% End of user PostScript
.878 1 0 r
.52158 .53842 m
.52342 .53967 L
.52546 .54086 L
.52775 .54197 L
.53032 .54298 L
.5332 .54386 L
.53644 .54456 L
.5401 .54506 L
.54423 .54529 L
.54892 .5452 L
.55423 .54471 L
.56027 .54374 L
.56715 .54219 L
.575 .53995 L
.58396 .53688 L
.59421 .53283 L
.60594 .52761 L
.61939 .52101 L
.63483 .51276 L
.65257 .50259 L
.67298 .49014 L
.69646 .47502 L
.72352 .45676 L
.75471 .43481 L
.79069 .40855 L
.83222 .37723 L
.8802 .33999 L
.93564 .29584 L
.99975 .2436 L
s
.99975 .2436 m
1 .24339 L
s
1 0 0 r
.52158 .53842 m
.52342 .53967 L
s
% Start of user PostScript
2.5900604 4.6109618 2.810179 4.7600475 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52546 .54086 m
.52775 .54197 L
s
% Start of user PostScript
3.0557152 4.9026452 3.3302592 5.036135 MAarrowhead1
% End of user PostScript
1 .473 0 r
.55423 .54471 m
.56027 .54374 L
s
% Start of user PostScript
6.5077795 5.364699 7.2327965 5.2483971 MAarrowhead1
% End of user PostScript
1 .788 0 r
.63483 .51276 m
.65257 .50259 L
s
% Start of user PostScript
16.179999 1.5316578 18.308913 0.31084009 MAarrowhead1
% End of user PostScript
.897 1 0 r
.8802 .33999 m
.93564 .29584 L
s
% Start of user PostScript
45.623967 -19.20128 52.277143 -24.499736 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
139.39981 -99.98179 160.86992 -119.4309 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
444.80675 -386.00197 515.1663 -453.34654 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1449.9323 -1362.2059 1682.1562 -1589.932 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
4773.8475 -4642.975 5542.802 -5405.2196 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
15789.914 -15594.675 18339.866 -18134.617 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
52335.121 -52043.859 60796.685 -60490.489 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
173625.59 -173191.08 201712.15 -201255.36 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
576258.66 -575610.45 669499.13 -668817.68 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1912949.9 -1911982.8 2222503.9 -2221487.3 MAarrowhead1
% End of user PostScript
.073 1 0 r
.4446 .52909 m
.43636 .53598 L
.42683 .54409 L
.41579 .55364 L
.40301 .56486 L
.3882 .57802 L
.37104 .59344 L
.35115 .61151 L
.32809 .63265 L
.30136 .65738 L
.27035 .68627 L
.23438 .72001 L
.19266 .7594 L
.14425 .80535 L
.08806 .85895 L
.02286 .92143 L
s
.02286 .92143 m
0 .94343 L
s
1 0 0 r
.4446 .52909 m
.43636 .53598 L
s
% Start of user PostScript
-6.6480196 3.4904701 -7.6366197 4.3171792 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42683 .54409 m
.41579 .55364 L
s
% Start of user PostScript
-8.7807343 5.2911024 -10.105302 6.4367525 MAarrowhead1
% End of user PostScript
1 .473 0 r
.27035 .68627 m
.23438 .72001 L
s
% Start of user PostScript
-27.558048 22.352129 -31.873988 26.401156 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-89.116456 81.350137 -103.32388 95.159377 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-292.32728 280.74129 -339.3156 327.13558 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-965.2651 947.98084 -1121.0003 1102.8299 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3196.8928 3171.1077 -3713.5468 3686.4397 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-10602.272 10563.806 -12317.02 12276.581 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-35183.202 35125.816 -40875.462 40815.134 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-116786.11 116700.5 -135683.74 135593.74 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-387704.42 387576.71 -450444.74 450310.48 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1287165.6 1286975.1 -1495467.8 1495267.6 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4273453.3 4273169.1 -4965036.6 4964737.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-14188235. 14187811. -16484365. 16483920. MAarrowhead1
% End of user PostScript
1 .215 0 r
.46026 .48167 m
.45544 .48352 L
.44991 .48591 L
.44358 .48895 L
.43631 .49276 L
.42797 .49747 L
.41837 .50324 L
.40733 .51027 L
.39461 .51876 L
.37995 .52898 L
.36304 .54122 L
.34352 .55583 L
.32098 .57321 L
.29493 .59384 L
.26481 .61825 L
.22999 .64708 L
.18969 .68107 L
.14304 .7211 L
.08903 .76814 L
.02646 .82338 L
s
.02646 .82338 m
0 .84704 L
s
1 0 0 r
.46026 .48167 m
.45544 .48352 L
s
% Start of user PostScript
-4.768513 -2.19997 -5.3476073 -1.9781574 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44991 .48591 m
.44358 .48895 L
s
% Start of user PostScript
-6.0105434 -1.6908213 -6.7703834 -1.3258387 MAarrowhead1
% End of user PostScript
1 .473 0 r
.36304 .54122 m
.34352 .55583 L
s
% Start of user PostScript
-16.435621 4.9465345 -18.777899 6.6997553 MAarrowhead1
% End of user PostScript
1 .788 0 r
.08903 .76814 m
.02646 .82338 L
s
% Start of user PostScript
-49.316831 32.177128 -56.824228 38.805754 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-155.90355 130.33412 -180.42732 153.54692 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-505.93091 467.7858 -586.75349 546.65264 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1662.3147 1605.4089 -1929.7612 1869.9377 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5493.0689 5408.1754 -6379.6891 6290.443 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-18198.829 18072.182 -21140.522 21007.382 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-60364.352 60175.418 -70128.149 69929.528 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-200330.35 200048.49 -232742.87 232446.56 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-664991.36 664570.88 -772598.11 772156.07 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2207656.9 2207029.6 -2564914. 2564254.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-7329392.2 7328456.4 -8515513. 8514529.2 MAarrowhead1
% End of user PostScript
1 .995 0 r
.4523 .48143 m
.44641 .48393 L
.43966 .4871 L
.43192 .49109 L
.42303 .49603 L
.41281 .5021 L
.40105 .50949 L
.38751 .51845 L
.3719 .52923 L
.35391 .54216 L
.33314 .5576 L
.30915 .57598 L
.28144 .59781 L
.24941 .62365 L
.21236 .65418 L
.1695 .6902 L
.1199 .73262 L
.06246 .78249 L
s
.06246 .78249 m
0 .83749 L
s
1 0 0 r
.4523 .48143 m
.44641 .48393 L
s
% Start of user PostScript
-5.7245794 -2.2278555 -6.4312009 -1.9289642 MAarrowhead1
% End of user PostScript
1 .158 0 r
.43966 .4871 m
.43192 .49109 L
s
% Start of user PostScript
-7.2409078 -1.547892 -8.1698053 -1.0696059 MAarrowhead1
% End of user PostScript
1 .473 0 r
.33314 .5576 m
.30915 .57598 L
s
% Start of user PostScript
-20.023537 6.9121883 -22.901623 9.1180411 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-60.48764 40.927806 -69.735962 49.173274 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-191.88576 162.70592 -222.1329 191.45697 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-623.74585 580.21464 -723.48605 677.72295 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2051.0122 1986.0713 -2381.1412 2312.8707 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6779.9176 6683.0371 -7874.4626 7772.6149 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-22465.838 22321.309 -26097.585 25945.646 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-74523.148 74307.536 -86577.585 86350.919 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-247327.01 247005.36 -287344.1 287005.96 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-821007.59 820527.73 -953861.46 953357.01 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2725621.9 2724906. -3166701. 3165948.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-9049056. 9047988.1 -10513474. 10512351. MAarrowhead1
% End of user PostScript
1 0 .152 r
.52678 .46746 m
.53127 .46267 L
.5365 .45714 L
.54258 .45073 L
.54966 .44331 L
.55789 .43472 L
.56746 .42476 L
.5786 .41323 L
.59154 .39987 L
.60659 .38438 L
.62409 .36641 L
.64444 .34558 L
.66809 .32142 L
.69558 .29339 L
.72754 .26087 L
.76468 .22313 L
.80785 .17933 L
.85803 .1285 L
.91634 .0695 L
.98411 .001 L
s
.98411 .001 m
.9851 0 L
s
1 0 0 r
.52678 .46746 m
.53127 .46267 L
s
% Start of user PostScript
3.2134503 -3.9044432 3.7525962 -4.479017 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5365 .45714 m
.54258 .45073 L
s
% Start of user PostScript
4.3799736 -5.1436388 5.1099117 -5.9127308 MAarrowhead1
% End of user PostScript
1 .473 0 r
.62409 .36641 m
.64444 .34558 L
s
% Start of user PostScript
14.891075 -16.03033 17.332451 -18.530117 MAarrowhead1
% End of user PostScript
1 .788 0 r
.91634 .0695 m
.98411 .001 L
s
% Start of user PostScript
49.960834 -51.660402 58.093185 -59.879892 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
166.65264 -169.18809 193.69282 -196.35828 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
554.46513 -558.24759 644.30112 -648.27751 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1842.6179 -1848.2607 2140.9726 -2146.9046 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6120.2861 -6128.7041 7110.9906 -7119.8402 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
20323.913 -20336.471 23613.365 -23626.567 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
67483.508 -67502.242 78405.168 -78424.863 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
224061.7 -224089.65 260323.33 -260352.71 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
743923.81 -743965.51 864317.31 -864361.14 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2469933.1 -2469995.3 2869654.6 -2869720. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
8200495.1 -8200587.9 9527618.6 -9527716.1 MAarrowhead1
% End of user PostScript
.031 1 0 r
.53661 .56032 m
.53985 .56205 L
.54348 .56364 L
.54756 .56506 L
.55215 .56625 L
.55731 .56715 L
.56315 .5677 L
.56975 .5678 L
.57724 .56737 L
.58574 .56628 L
.59541 .5644 L
.60643 .56157 L
.61902 .5576 L
.63339 .55228 L
.64985 .54534 L
.66871 .5365 L
.69034 .52539 L
.71518 .51161 L
.74373 .49468 L
.77659 .47405 L
.81442 .44906 L
.85802 .41897 L
.9083 .38289 L
.96633 .33979 L
s
.96633 .33979 m
1 .31401 L
s
1 0 0 r
.53661 .56032 m
.53985 .56205 L
s
% Start of user PostScript
4.3928447 7.2387856 4.78225 7.4457468 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54348 .56364 m
.54756 .56506 L
s
% Start of user PostScript
5.2181903 7.6367492 5.7073516 7.8066748 MAarrowhead1
% End of user PostScript
1 .473 0 r
.59541 .5644 m
.60643 .56157 L
s
% Start of user PostScript
11.449356 7.7279607 12.772177 7.3883811 MAarrowhead1
% End of user PostScript
1 .788 0 r
.74373 .49468 m
.77659 .47405 L
s
% Start of user PostScript
29.247765 -0.63857044 33.190274 -3.1142549 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
84.029506 -41.349604 96.448652 -51.580504 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
259.47995 -195.80902 299.71278 -232.77737 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
832.40151 -737.41564 964.4871 -864.6312 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2720.2549 -2578.5526 3156.5685 -3007.601 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
8966.7959 -8755.401 10412.087 -10189.854 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
29674.188 -29358.824 34467.771 -34136.238 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
98377.629 -97907.161 114285.49 -113790.9 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
326410.19 -325708.34 379215.14 -378477.3 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1083399.2 -1082352.2 1258701.4 -1257600.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3596533.5 -3594971.5 4178532.6 -4176890.5 MAarrowhead1
% End of user PostScript
.96 1 0 r
.50998 .57407 m
.50927 .57908 L
.50833 .58456 L
.50711 .59054 L
.50556 .59709 L
.50362 .60429 L
.50123 .61222 L
.49829 .62098 L
.49472 .63067 L
.4904 .64141 L
.4852 .65337 L
.47897 .6667 L
.47155 .6816 L
.46271 .69829 L
.45222 .71703 L
.43981 .73811 L
.42515 .7619 L
.40787 .78877 L
.38753 .8192 L
.36361 .85371 L
.33553 .89293 L
.3026 .93758 L
.26401 .98848 L
s
.26401 .98848 m
.25506 1 L
s
1 0 0 r
.50998 .57407 m
.50927 .57908 L
s
% Start of user PostScript
1.1975495 8.8880599 1.1125799 9.4901298 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50833 .58456 m
.50711 .59054 L
s
% Start of user PostScript
0.99956616 10.146756 0.85323708 10.864569 MAarrowhead1
% End of user PostScript
1 .473 0 r
.4852 .65337 m
.47897 .6667 L
s
% Start of user PostScript
-1.776007 18.404366 -2.5230467 20.00396 MAarrowhead1
% End of user PostScript
1 .788 0 r
.38753 .8192 m
.36361 .85371 L
s
% Start of user PostScript
-13.496926 38.303522 -16.366864 42.445322 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-56.149799 93.156892 -66.259664 105.16415 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-203.33884 258.54694 -237.77202 295.8107 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-700.34286 782.70366 -815.95884 902.54237 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2362.8651 2485.733 -2748.6537 2877.8212 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7901.148 8084.4453 -9184.8908 9377.586 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-26316.515 26589.963 -30582.987 30870.454 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-87498.894 87906.829 -101670.49 102099.34 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-290693.01 291301.58 -337753.92 338393.69 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-965412.96 966320.83 -1121674.9 1122629.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3205698.9 3207053.3 -3724528.1 3725952. MAarrowhead1
% End of user PostScript
1 .367 0 r
.57589 .50103 m
.58605 .49481 L
.59774 .48727 L
.6112 .47816 L
.62673 .46722 L
.64464 .45412 L
.66532 .43851 L
.6892 .41994 L
.71681 .39794 L
.74872 .37191 L
.78564 .34117 L
.82836 .30495 L
.87781 .26233 L
.93508 .21225 L
s
.93508 .21225 m
1 .15473 L
s
1 0 0 r
.57589 .50103 m
.58605 .49481 L
s
% Start of user PostScript
9.1067398 0.12309145 10.325402 -0.62234752 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59774 .48727 m
.6112 .47816 L
s
% Start of user PostScript
11.728206 -1.5276649 13.34428 -2.6207463 MAarrowhead1
% End of user PostScript
1 .473 0 r
.78564 .34117 m
.82836 .30495 L
s
% Start of user PostScript
34.276622 -19.059203 39.403132 -23.405499 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
106.84692 -84.1452 123.51092 -99.645255 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
344.36793 -310.50094 399.16234 -363.55895 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1127.8621 -1077.3385 1308.9923 -1255.8783 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3721.5411 -3646.1687 4321.7305 -4242.4937 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
12321.501 -12209.058 14312.433 -14194.226 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
40857.429 -40689.684 47464.923 -47288.578 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
135574.77 -135324.52 157508.49 -157245.42 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
450009.71 -449636.38 522826.37 -522433.9 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1493914.2 -1493357.3 1735665.3 -1735079.8 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4959715.3 -4958884.4 5762344.1 -5761470.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
16466455. -16465215. 19131257. -19129954. MAarrowhead1
% End of user PostScript
1 .299 0 r
.44103 .49815 m
.43316 .50289 L
.42411 .50866 L
.41369 .51564 L
.40168 .52403 L
.38782 .53408 L
.37182 .54607 L
.35335 .56033 L
.332 .57726 L
.30732 .59728 L
.27878 .62094 L
.24575 .64882 L
.20752 .68165 L
.16325 .72024 L
.11197 .76554 L
.05256 .81868 L
s
.05256 .81868 m
0 .86619 L
s
1 0 0 r
.44103 .49815 m
.43316 .50289 L
s
% Start of user PostScript
-7.0768438 -0.22227461 -8.020366 0.34701387 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42411 .50866 m
.41369 .51564 L
s
% Start of user PostScript
-9.1062384 1.0394651 -10.356968 1.876602 MAarrowhead1
% End of user PostScript
1 .473 0 r
.27878 .62094 m
.24575 .64882 L
s
% Start of user PostScript
-26.546671 14.51246 -30.510197 17.858978 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-82.637539 64.684605 -95.51489 76.641489 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-266.16049 239.37786 -308.49408 280.33827 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-871.44233 831.48734 -1011.3672 969.36363 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2875.0281 2815.4222 -3338.6585 3275.9966 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-9518.1851 9429.2637 -11056.096 10962.615 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-31560.844 31428.189 -36664.803 36525.346 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-104725.06 104527.16 -121667.69 121459.64 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-347608.99 347313.76 -403855.86 403545.5 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1153967.5 1153527.1 -1340706.8 1340243.8 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3831105.8 3830448.8 -4451091.8 4450401.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-12719419. 12718439. -14777829. 14776799. MAarrowhead1
% End of user PostScript
0 .032 1 r
.54604 .57397 m
.55018 .57599 L
.55481 .57782 L
.56001 .57942 L
.56587 .58071 L
.57248 .58162 L
.57995 .58205 L
.58841 .58189 L
.59801 .58102 L
.60892 .57929 L
.62135 .57651 L
.63552 .57249 L
.6517 .56697 L
.67021 .55968 L
.6914 .55027 L
.71569 .53837 L
.74358 .52351 L
.77561 .50517 L
.81246 .48272 L
.85486 .45545 L
.90372 .42251 L
.96003 .38291 L
s
.96003 .38291 m
1 .35377 L
s
1 0 0 r
.54604 .57397 m
.55018 .57599 L
s
% Start of user PostScript
5.5250587 8.8762421 6.0211391 9.1185321 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55481 .57782 m
.56001 .57942 L
s
% Start of user PostScript
6.5770932 9.3388056 7.2015641 9.5303602 MAarrowhead1
% End of user PostScript
1 .473 0 r
.62135 .57651 m
.63552 .57249 L
s
% Start of user PostScript
14.56199 9.181741 16.262323 8.6987749 MAarrowhead1
% End of user PostScript
1 .788 0 r
.81246 .48272 m
.85486 .45545 L
s
% Start of user PostScript
37.494889 -2.0734052 42.583769 -5.3461862 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
108.29721 -55.454566 124.3628 -68.81085 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
335.40645 -256.57449 387.50772 -304.63396 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1077.5567 -959.9532 1248.6916 -1125.0585 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3523.8608 -3348.417 4089.2927 -3904.8538 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
11619.439 -11357.708 13492.628 -13217.477 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
38458.266 -38067.809 44671.338 -44260.862 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
127507.47 -126924.98 148126.45 -147514.09 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
423073.48 -422204.5 491517.23 -490603.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1404256.2 -1402959.9 1631477.1 -1630114.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4661702.3 -4659768.4 5416071.9 -5414038.8 MAarrowhead1
% End of user PostScript
0 .554 1 r
.53509 .4201 m
.54201 .41089 L
.55011 .40037 L
.55959 .38835 L
.57067 .3746 L
.58362 .35885 L
.59874 .34077 L
.61639 .32002 L
.63699 .29617 L
.66101 .26872 L
.689 .23712 L
.72163 .2007 L
.75965 .15871 L
.80393 .11024 L
.85548 .05428 L
s
.85548 .05428 m
.90588 0 L
s
1 0 0 r
.53509 .4201 m
.54201 .41089 L
s
% Start of user PostScript
4.2109948 -9.587945 5.0411011 -10.693733 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55011 .40037 m
.55959 .38835 L
s
% Start of user PostScript
6.0131671 -11.955616 7.1505574 -13.397682 MAarrowhead1
% End of user PostScript
1 .473 0 r
.689 .23712 m
.72163 .2007 L
s
% Start of user PostScript
22.680551 -31.545643 26.596079 -35.915694 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
79.354076 -92.579239 92.561837 -106.46507 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
269.50968 -289.2393 313.67091 -334.4121 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
903.82152 -933.25466 1050.9043 -1081.8466 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3014.2462 -3058.1553 3503.2682 -3549.4285 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
10027.72 -10093.224 11652.359 -11721.222 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
33323.142 -33420.863 38718.668 -38821.4 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
110681.39 -110827.18 128597.46 -128750.72 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
367541.8 -367759.28 427028.66 -427257.29 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1220381.2 -1220705.6 1417889.6 -1418230.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4051956.4 -4052440.4 4707715.1 -4708223.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
13453190. -13453912. 15630397. -15631156. MAarrowhead1
% End of user PostScript
.997 1 0 r
.55643 .55286 m
.56254 .55235 L
.56949 .55129 L
.57739 .54958 L
.58641 .54707 L
.5967 .54362 L
.60848 .53904 L
.62195 .53313 L
.6374 .52563 L
.65513 .51626 L
.6755 .50468 L
.69892 .4905 L
.72588 .47325 L
.75693 .45241 L
.79273 .42735 L
.83401 .39734 L
.88168 .36155 L
.93672 .31897 L
s
.93672 .31897 m
1 .26873 L
s
1 0 0 r
.55643 .55286 m
.56254 .55235 L
s
% Start of user PostScript
6.7716188 6.342695 7.5050086 6.2816904 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56949 .55129 m
.57739 .54958 L
s
% Start of user PostScript
8.3385008 6.1550574 9.2873424 5.9493164 MAarrowhead1
% End of user PostScript
1 .473 0 r
.6755 .50468 m
.69892 .4905 L
s
% Start of user PostScript
21.060183 0.56166535 23.870797 -1.1403726 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
60.039505 -27.783498 68.864371 -34.954564 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
184.59482 -136.47452 213.13851 -162.55102 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
590.8819 -519.09484 684.52258 -609.05491 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1928.9851 -1821.8914 2238.2008 -2125.6162 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6355.5064 -6195.7413 7379.6289 -7211.6725 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
21028. -20789.658 24424.462 -24173.901 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
69706.479 -69350.915 80977.546 -80603.752 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
231271.14 -230740.7 268684.07 -268126.44 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
767604.78 -766813.46 891807.65 -890975.75 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2548175.9 -2546995.4 2960525.4 -2959284.4 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
8459702.5 -8457941.3 9828723.3 -9826871.9 MAarrowhead1
% End of user PostScript
1 .994 0 r
.52201 .52658 m
.52423 .52685 L
.52674 .52696 L
.52958 .52687 L
.53281 .52653 L
.53648 .52591 L
.54066 .52493 L
.54543 .52352 L
.55087 .52161 L
.5571 .5191 L
.56424 .51587 L
.57242 .51179 L
.58181 .50672 L
.59261 .50047 L
.60502 .49282 L
.61931 .48355 L
.63578 .47236 L
.65476 .45892 L
.67667 .44284 L
.70195 .42368 L
.73116 .40091 L
.76492 .37392 L
.80396 .34201 L
.84911 .30433 L
.90137 .25994 L
.96187 .20772 L
s
.96187 .20772 m
1 .17432 L
s
1 0 0 r
.52201 .52658 m
.52423 .52685 L
s
% Start of user PostScript
2.6414266 3.1890682 2.9077404 3.2216903 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52674 .52696 m
.52958 .52687 L
s
% Start of user PostScript
3.20889 3.2348032 3.5500896 3.2239789 MAarrowhead1
% End of user PostScript
1 .473 0 r
.56424 .51587 m
.57242 .51179 L
s
% Start of user PostScript
7.7086515 1.9042092 8.6904683 1.4152544 MAarrowhead1
% End of user PostScript
1 .788 0 r
.67667 .44284 m
.70195 .42368 L
s
% Start of user PostScript
21.199845 -6.8591416 24.234317 -9.1583506 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
63.831214 -42.437399 73.569949 -51.079249 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
202.14856 -170.23274 233.98094 -200.42876 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
656.56899 -608.95618 761.50828 -711.4543 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2158.1233 -2087.0933 2505.4182 -2430.7464 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
7132.7557 -7026.7915 8284.1509 -8172.7537 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
23633.15 -23475.069 27453.433 -27287.248 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
78392.566 -78156.738 91072.649 -90824.73 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
260164.69 -259812.88 302258.52 -301888.67 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
863616.4 -863091.55 1003364.6 -1002812.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2867067.5 -2866284.5 3331035.6 -3330212.5 MAarrowhead1
% End of user PostScript
.703 1 0 r
.42436 .53568 m
.41323 .54477 L
.40034 .5555 L
.38544 .56814 L
.36818 .58302 L
.3482 .6005 L
.32505 .62102 L
.29822 .64507 L
.26714 .67325 L
.2311 .70624 L
.18931 .74481 L
.14085 .78989 L
.08465 .84255 L
.01944 .90402 L
s
.01944 .90402 m
0 .92245 L
s
1 0 0 r
.42436 .53568 m
.41323 .54477 L
s
% Start of user PostScript
-9.0765598 4.2816743 -10.412924 5.3721991 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40034 .5555 m
.38544 .56814 L
s
% Start of user PostScript
-11.958762 6.6595936 -13.747626 8.1767634 MAarrowhead1
% End of user PostScript
1 .473 0 r
.18931 .74481 m
.14085 .78989 L
s
% Start of user PostScript
-37.28238 29.37695 -43.097433 34.786684 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-120.1685 108.37499 -139.2899 126.89172 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-393.58298 375.98912 -456.79187 438.29596 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1298.6998 1272.4529 -1508.1484 1480.5558 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-4299.8385 4260.6826 -4994.6173 4953.4539 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-14258.069 14199.656 -16563.899 16502.49 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-47311.758 47224.615 -54966.012 54874.401 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-157040.74 156910.74 -182451.71 182315.05 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-521334.19 521140.25 -605698.56 605494.67 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1730801.8 1730512.5 -2010896.8 2010592.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-5746332.2 5745900.6 -6676273.6 6675819.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-19078298. 19077654. -22165802. 22165125. MAarrowhead1
% End of user PostScript
1 0 .987 r
.48318 .56913 m
.47902 .57598 L
.4741 .58371 L
.46831 .59247 L
.4615 .60239 L
.4535 .61367 L
.44412 .62649 L
.43313 .64111 L
.42026 .65779 L
.40519 .67685 L
.38758 .69867 L
.367 .72367 L
.34298 .75234 L
.31493 .78528 L
.28221 .82314 L
.24405 .8667 L
.19957 .91686 L
.14773 .97466 L
s
.14773 .97466 m
.12478 1 L
s
1 0 0 r
.48318 .56913 m
.47902 .57598 L
s
% Start of user PostScript
-2.0180367 8.2955268 -2.5181389 9.1174828 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4741 .58371 m
.46831 .59247 L
s
% Start of user PostScript
-3.108071 10.045771 -3.8028268 11.09623 MAarrowhead1
% End of user PostScript
1 .473 0 r
.38758 .69867 m
.367 .72367 L
s
% Start of user PostScript
-13.490195 23.840026 -15.959448 26.839926 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-49.519653 64.959787 -57.960406 74.192173 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-171.46831 194.50228 -199.85443 224.06938 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-579.82304 614.18569 -674.60807 710.73253 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1940.7865 1992.0496 -2256.2892 2310.1805 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6467.0691 6543.5446 -7515.7762 7596.1727 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-21506.381 21620.469 -24990.003 25109.94 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-71455.844 71626.044 -83024.551 83203.477 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-237319.55 237573.46 -275733. 275999.93 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-788044.71 788423.5 -915587.8 915986.01 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2616573.7 2617138.8 -3040040.6 3040634.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-8687589. 8688432. -10093562. 10094448. MAarrowhead1
% End of user PostScript
.448 1 0 r
.50098 .49556 m
.50123 .49512 L
.50153 .49464 L
.50189 .49409 L
.5023 .49346 L
.50279 .49276 L
.50337 .49195 L
.50404 .49104 L
.50483 .49 L
.50576 .48881 L
.50684 .48744 L
.50811 .48589 L
.50958 .4841 L
.51131 .48205 L
.51332 .4797 L
.51567 .47699 L
.51841 .47388 L
.5216 .47029 L
.52532 .46615 L
.52966 .46138 L
.5347 .45587 L
.54058 .44951 L
.54742 .44217 L
.55538 .43367 L
.56465 .42384 L
.57543 .41247 L
.58797 .39931 L
.60256 .38407 L
.61953 .36642 L
.63926 .34596 L
.6622 .32226 L
.68888 .29479 L
.7199 .26293 L
.75596 .22599 L
.79789 .18314 L
.84662 .13343 L
.90327 .07576 L
.96911 .00885 L
s
.96911 .00885 m
.97783 0 L
s
1 0 0 r
.50098 .49556 m
.50123 .49512 L
s
% Start of user PostScript
0.11742413 -0.53335885 0.14792414 -0.58518429 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50153 .49464 m
.50189 .49409 L
s
% Start of user PostScript
0.18394954 -0.6436285 0.22642477 -0.70967197 MAarrowhead1
% End of user PostScript
1 .473 0 r
.50684 .48744 m
.50811 .48589 L
s
% Start of user PostScript
0.82084086 -1.5066013 0.97263598 -1.6935561 MAarrowhead1
% End of user PostScript
1 .788 0 r
.52532 .46615 m
.52966 .46138 L
s
% Start of user PostScript
3.0387302 -4.0617646 3.5587783 -4.6342647 MAarrowhead1
% End of user PostScript
.897 1 0 r
.58797 .39931 m
.60256 .38407 L
s
% Start of user PostScript
10.556541 -12.082729 12.307136 -13.911573 MAarrowhead1
% End of user PostScript
.581 1 0 r
.79789 .18314 m
.84662 .13343 L
s
% Start of user PostScript
35.74653 -38.023335 41.594476 -43.988015 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
119.72333 -123.11992 139.19254 -142.76328 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
399.04793 -404.11505 463.76761 -469.09453 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
1327.2018 -1334.7611 1542.1975 -1550.1443 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
4409.9204 -4421.1975 5123.9083 -5135.7635 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
14646.606 -14663.429 17017.393 -17035.079 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
48636.133 -48661.231 56507.819 -56534.203 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
161489.12 -161526.56 187624.63 -187663.99 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
536179.88 -536235.73 622953.69 -623012.41 MAarrowhead1
% End of user PostScript
1 0 .695 r
.56653 .52327 m
.57482 .51959 L
.58432 .51493 L
.59522 .50912 L
.60775 .50194 L
.62215 .49316 L
.63873 .48249 L
.65783 .46961 L
.67985 .45412 L
.70526 .43559 L
.73458 .41348 L
.76845 .3872 L
.80759 .35604 L
.85285 .31917 L
.9052 .27565 L
.96578 .22434 L
s
.96578 .22434 m
1 .19487 L
s
1 0 0 r
.56653 .52327 m
.57482 .51959 L
s
% Start of user PostScript
7.9840992 2.7925031 8.9783261 2.3508044 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58432 .51493 m
.59522 .50912 L
s
% Start of user PostScript
10.118181 1.7918068 11.426447 1.0941783 MAarrowhead1
% End of user PostScript
1 .473 0 r
.73458 .41348 m
.76845 .3872 L
s
% Start of user PostScript
28.149808 -10.382195 32.2143 -13.535722 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
85.339558 -58.833393 98.417769 -70.552604 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
271.22206 -231.6795 314.02208 -272.45214 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
882.4151 -823.42455 1023.5895 -961.57447 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2902.7583 -2814.7548 3370.0915 -3277.5759 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9597.273 -9465.9871 11146.812 -11008.794 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
31804.061 -31608.206 36945.634 -36739.736 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
105503.68 -105211.5 122569.71 -122262.55 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
350151.01 -349715.12 406805.38 -406347.15 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1162343.1 -1161692.8 1350432. -1349748.4 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3858817.6 -3857847.6 4483279.7 -4482259.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
12811282. -12809835. 14884547. -14883025. MAarrowhead1
% End of user PostScript
0 .989 1 r
.45595 .52404 m
.44937 .52959 L
.44176 .53612 L
.43295 .5438 L
.42274 .55281 L
.41091 .56339 L
.39721 .57578 L
.38132 .59028 L
.36289 .60725 L
.34153 .62708 L
.31675 .65025 L
.28801 .6773 L
.25466 .70887 L
.21597 .7457 L
.17106 .78864 L
.11894 .83869 L
.05844 .89702 L
s
.05844 .89702 m
0 .95356 L
s
1 0 0 r
.45595 .52404 m
.44937 .52959 L
s
% Start of user PostScript
-5.2861049 2.8843058 -6.0751901 3.5502481 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44176 .53612 m
.43295 .5438 L
s
% Start of user PostScript
-6.9885725 4.334174 -8.0461932 5.2557008 MAarrowhead1
% End of user PostScript
1 .473 0 r
.31675 .65025 m
.28801 .6773 L
s
% Start of user PostScript
-21.989624 18.029727 -25.438843 21.275918 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-71.19816 65.290687 -82.557173 76.346818 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-233.68607 224.87316 -271.26088 261.99612 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-771.83693 758.68961 -896.38317 882.56177 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2556.5796 2536.9661 -2969.7795 2949.1604 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-8479.1783 8449.9184 -9850.5909 9819.8308 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-28138.489 28094.839 -32691.054 32645.165 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-93403.123 93338.004 -108517.15 108448.69 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-310079.53 309982.38 -360258.33 360156.2 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1029455.9 1029311. -1196053.1 1195900.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3417847.6 3417631.4 -3970966.4 3970739.2 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-11347555. 11347232. -13183969. 13183630. MAarrowhead1
% End of user PostScript
0 1 .651 r
.51438 .50741 m
.5161 .50681 L
.51808 .50601 L
.52034 .50498 L
.52293 .50369 L
.5259 .50208 L
.52932 .5001 L
.53326 .49767 L
.53778 .49473 L
.543 .49118 L
.54901 .48692 L
.55595 .48182 L
.56396 .47575 L
.57321 .46853 L
.58391 .45998 L
.59627 .44986 L
.61058 .43792 L
.62714 .42386 L
.6463 .4073 L
.6685 .38786 L
.69421 .36504 L
.724 .33828 L
.75853 .30695 L
.79856 .27027 L
.84497 .22739 L
.8988 .17727 L
.96123 .11873 L
s
.96123 .11873 m
1 .08216 L
s
1 0 0 r
.51438 .50741 m
.5161 .50681 L
s
% Start of user PostScript
1.7256067 0.88966548 1.9325808 0.81677928 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51808 .50601 m
.52034 .50498 L
s
% Start of user PostScript
2.1693441 0.72097871 2.4405274 0.59798537 MAarrowhead1
% End of user PostScript
1 .473 0 r
.54901 .48692 m
.55595 .48182 L
s
% Start of user PostScript
5.8813873 -1.5695324 6.714014 -2.1810856 MAarrowhead1
% End of user PostScript
1 .788 0 r
.6463 .4073 m
.6685 .38786 L
s
% Start of user PostScript
17.556061 -11.123529 20.219432 -13.457098 MAarrowhead1
% End of user PostScript
.897 1 0 r
.96123 .11873 m
0 0 rlineto s
.96123 .11873 m
1 .08216 L
s
% Start of user PostScript
55.348037 -45.751828 64.039998 -53.95178 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
179.37579 -165.05992 208.00923 -192.95938 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
589.00519 -567.64843 683.73608 -661.28434 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1945.8045 -1913.944 2259.8216 -2226.3276 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
6445.7358 -6398.2055 7487.5628 -7437.5956 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
21378.872 -21307.965 24836.745 -24762.203 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
70947.944 -70842.164 82426.827 -82315.623 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
235507.12 -235349.32 273615.88 -273449.98 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
781839.05 -781603.63 908360.87 -908113.38 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2595689.5 -2595338.3 3015751.2 -3015382. MAarrowhead1
% End of user PostScript
1 .498 0 r
.55349 .48961 m
.56095 .48435 L
.56956 .47807 L
.5795 .47057 L
.59099 .46165 L
.60426 .45108 L
.6196 .43857 L
.63735 .42381 L
.65788 .40641 L
.68166 .38593 L
.70919 .36187 L
.74107 .33362 L
.77802 .3005 L
.82085 .2617 L
.87049 .21629 L
.92805 .16318 L
.9948 .10111 L
s
.9948 .10111 m
1 .09624 L
s
1 0 0 r
.55349 .48961 m
.56095 .48435 L
s
% Start of user PostScript
6.418319 -1.2468494 7.3140793 -1.8774628 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56956 .47807 m
.5795 .47057 L
s
% Start of user PostScript
8.3474754 -2.6321176 9.5404057 -3.5320153 MAarrowhead1
% End of user PostScript
1 .473 0 r
.70919 .36187 m
.74107 .33362 L
s
% Start of user PostScript
25.102258 -16.575946 28.928989 -19.965524 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
79.445285 -66.725522 91.950668 -78.578749 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
257.95377 -238.97812 299.17503 -279.22647 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
847.76343 -819.45508 984.17812 -954.41836 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2801.7347 -2759.5036 3253.984 -3209.5877 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9282.7842 -9219.7828 10783.315 -10717.084 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
30791.133 -30697.146 35771.594 -35672.788 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
102187.2 -102046.99 118720.71 -118573.31 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
339209.37 -339000.2 394099.28 -393879.38 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1126119.2 -1125807.1 1308355.2 -1308027.1 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3738704.7 -3738239.1 4343742.2 -4343252.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
12412724. -12412029. 14421508. -14420778. MAarrowhead1
% End of user PostScript
0 .004 1 r
.51073 .50529 m
.51203 .50481 L
.51351 .5042 L
.5152 .50341 L
.51715 .50242 L
.51938 .50118 L
.52195 .49967 L
.52491 .49782 L
.52831 .49559 L
.53223 .49289 L
.53675 .48966 L
.54197 .48579 L
.548 .48119 L
.55496 .47573 L
.563 .46925 L
.57231 .4616 L
.58307 .45258 L
.59553 .44195 L
.60995 .42945 L
.62666 .41476 L
.64601 .39753 L
.66844 .37734 L
.69443 .35369 L
.72457 .32602 L
.75951 .29367 L
.80004 .25587 L
.84705 .21173 L
.90159 .1602 L
.96487 .10009 L
s
.96487 .10009 m
1 .06655 L
s
1 0 0 r
.51073 .50529 m
.51203 .50481 L
s
% Start of user PostScript
1.2878386 0.63432963 1.4431247 0.57759517 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51351 .5042 m
.5152 .50341 L
s
% Start of user PostScript
1.6208174 0.50350698 1.8244032 0.40883766 MAarrowhead1
% End of user PostScript
1 .473 0 r
.53675 .48966 m
.54197 .48579 L
s
% Start of user PostScript
4.4103318 -1.2412123 5.0364776 -1.7048738 MAarrowhead1
% End of user PostScript
1 .788 0 r
.60995 .42945 m
.62666 .41476 L
s
% Start of user PostScript
13.194298 -8.4665274 15.198908 -10.228739 MAarrowhead1
% End of user PostScript
.897 1 0 r
.84705 .21173 m
.90159 .1602 L
s
% Start of user PostScript
41.645676 -34.592671 48.190422 -40.775801 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
135.04478 -124.52293 156.60881 -145.5475 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
443.55519 -427.85844 514.90374 -498.4022 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1465.4805 -1442.0637 1701.9982 -1677.3808 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
4854.8635 -4819.9298 5639.5811 -5602.8562 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
16102.747 -16050.632 18707.283 -18652.496 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
53439.183 -53361.437 62085.324 -62003.591 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
177388.8 -177272.82 206093.18 -205971.25 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
588898.55 -588725.52 684197.72 -684015.82 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1955132.9 -1954874.8 2271533.3 -2271261.9 MAarrowhead1
% End of user PostScript
0 .946 1 r
.42705 .56222 m
.41555 .57318 L
.40219 .58596 L
.38669 .60085 L
.3687 .6182 L
.34781 .63842 L
.32356 .66196 L
.2954 .68938 L
.26272 .72129 L
.22476 .75842 L
.18068 .80164 L
.12949 .85192 L
.07004 .91042 L
.001 .97846 L
s
.001 .97846 m
0 .97944 L
s
1 0 0 r
.42705 .56222 m
.41555 .57318 L
s
% Start of user PostScript
-8.7534399 7.4664529 -10.134473 8.7815007 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40219 .58596 m
.38669 .60085 L
s
% Start of user PostScript
-11.73718 10.31484 -13.597344 12.102078 MAarrowhead1
% End of user PostScript
1 .473 0 r
.18068 .80164 m
.12949 .85192 L
s
% Start of user PostScript
-38.318698 36.196815 -44.461325 42.230651 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-126.2527 123.08722 -146.59722 143.26944 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-417.72688 413.00454 -485.19886 480.2344 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1384.7436 1377.6987 -1608.6478 1601.2417 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-4594.2907 4583.7809 -5337.5138 5326.4652 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-15248.779 15233.1 -17716.12 17699.637 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-50620.561 50597.172 -58812.055 58787.466 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-168055.49 168020.6 -195251.66 195214.98 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-557947.93 557895.88 -648241.58 648186.85 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1852428.6 1852350.9 -2152212.8 2152131.2 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-6150244. 6150128.1 -7145560.9 7145439.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-20419476. 20419303. -23724042. 23723860. MAarrowhead1
% End of user PostScript
1 .731 0 r
.57025 .52314 m
.57904 .51914 L
.58912 .5141 L
.60069 .50782 L
.61398 .50009 L
.62928 .49064 L
.64688 .47919 L
.66717 .46536 L
.69056 .44877 L
.71755 .42892 L
.74871 .40527 L
.7847 .37718 L
.8263 .34388 L
.8744 .3045 L
.93005 .25802 L
.99445 .20327 L
s
.99445 .20327 m
1 .19847 L
s
1 0 0 r
.57025 .52314 m
.57904 .51914 L
s
% Start of user PostScript
8.4304318 2.7770132 9.4849817 2.2970813 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58912 .5141 m
.60069 .50782 L
s
% Start of user PostScript
10.694311 1.6918312 12.082654 0.93853927 MAarrowhead1
% End of user PostScript
1 .473 0 r
.74871 .40527 m
.7847 .37718 L
s
% Start of user PostScript
29.844991 -11.367038 34.164188 -14.73885 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
90.643086 -63.077219 104.5503 -75.5711 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
288.34603 -247.22259 333.87361 -290.64172 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
938.54611 -877.19715 1088.7393 -1024.2449 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3088.0419 -2996.52 3585.2631 -3489.0487 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
10210.828 -10074.293 11859.516 -11715.981 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
33838.736 -33635.05 39309.372 -39095.243 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
112255.46 -111951.6 130413.84 -130094.4 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
372562.37 -372109.06 432843.19 -432366.64 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1236743.4 -1236067.2 1436872.2 -1436161.2 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4105823.7 -4104814.8 4770258.7 -4769198.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
13631354. -13629849. 15837332. -15835750. MAarrowhead1
% End of user PostScript
.772 1 0 r
.45127 .56616 m
.4429 .57542 L
.43315 .58611 L
.4218 .59844 L
.40858 .6127 L
.3932 .62917 L
.3753 .64822 L
.35447 .67026 L
.33023 .69576 L
.30204 .72529 L
.26925 .75948 L
.23111 .79909 L
.18676 .84499 L
.13519 .89819 L
.07522 .95986 L
s
.07522 .95986 m
.0361 1 L
s
1 0 0 r
.45127 .56616 m
.4429 .57542 L
s
% Start of user PostScript
-5.8481786 7.9389793 -6.8524055 9.0504039 MAarrowhead1
% End of user PostScript
1 .158 0 r
.43315 .58611 m
.4218 .59844 L
s
% Start of user PostScript
-8.0221138 10.332806 -9.3842358 11.8134 MAarrowhead1
% End of user PostScript
1 .473 0 r
.26925 .75948 m
.23111 .79909 L
s
% Start of user PostScript
-27.690511 31.137659 -32.267066 35.890952 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-93.511332 98.653872 -108.78681 114.19302 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-312.81907 320.49084 -363.65596 371.72107 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1042.1025 1053.5474 -1211.0667 1223.0984 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3465.1332 3482.207 -4026.3823 4044.3315 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-11512.451 11537.922 -13376.264 13403.041 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-38234.326 38272.325 -44423. 44462.947 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-126959.8 127016.49 -147507.81 147567.41 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-421547.3 421631.86 -489770.42 489859.33 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1399625. 1399751.1 -1626135.7 1626268.3 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4646976.2 4647164.4 -5399021.3 5399219.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-15428590. 15428871. -17925472. 17925768. MAarrowhead1
% End of user PostScript
.726 0 1 r
.5445 .45922 m
.5516 .45231 L
.55985 .44427 L
.56942 .43491 L
.58053 .42402 L
.59344 .41134 L
.60843 .3966 L
.62584 .37945 L
.64606 .3595 L
.66954 .3363 L
.69682 .30932 L
.7285 .27796 L
.7653 .24149 L
.80805 .19909 L
.8577 .1498 L
.91538 .0925 L
.98239 .0259 L
s
.98239 .0259 m
1 .00839 L
s
1 0 0 r
.5445 .45922 m
.5516 .45231 L
s
% Start of user PostScript
5.3405368 -4.8935414 6.1924632 -5.7225499 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55985 .44427 m
.56942 .43491 L
s
% Start of user PostScript
7.181627 -6.6876207 8.3302055 -7.810871 MAarrowhead1
% End of user PostScript
1 .473 0 r
.69682 .30932 m
.7285 .27796 L
s
% Start of user PostScript
23.618044 -22.881074 27.419882 -26.645126 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
78.07782 -76.978388 90.683095 -89.527295 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
258.72497 -257.08481 300.55019 -298.82594 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
858.24748 -855.80065 997.07368 -994.5014 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2848.3636 -2844.7134 3309.2255 -3305.3881 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9455.2318 -9449.7862 10985.262 -10979.537 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
31389.986 -31381.862 36469.736 -36461.196 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
104214.71 -104202.59 121079.88 -121067.14 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
345999.48 -345981.4 401993.55 -401974.54 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1148750.5 -1148723.5 1334656.9 -1334628.5 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3813973.6 -3813933.3 4431204. -4431161.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
12662820. -12662760. 14712096. -14712033. MAarrowhead1
% End of user PostScript
1 .042 0 r
.49328 .54321 m
.49119 .54717 L
.4887 .55163 L
.48576 .55664 L
.48228 .56229 L
.47818 .56867 L
.47336 .5759 L
.46768 .5841 L
.46102 .59342 L
.45321 .60402 L
.44405 .61611 L
.43334 .62991 L
.4208 .64569 L
.40614 .66376 L
.38902 .68446 L
.36903 .70822 L
.3457 .73551 L
.31848 .76689 L
.28675 .803 L
.24976 .8446 L
.20665 .89254 L
.15644 .94784 L
s
.15644 .94784 m
.10865 1 L
s
1 0 0 r
.49328 .54321 m
.49119 .54717 L
s
% Start of user PostScript
-0.80601608 5.1849668 -1.0574947 5.6609591 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4887 .55163 m
.48576 .55664 L
s
% Start of user PostScript
-1.355877 6.195366 -1.7090716 6.7966865 MAarrowhead1
% End of user PostScript
1 .473 0 r
.44405 .61611 m
.43334 .62991 L
s
% Start of user PostScript
-6.7136701 13.933339 -7.9997291 15.589559 MAarrowhead1
% End of user PostScript
1 .788 0 r
.28675 .803 m
.24976 .8446 L
s
% Start of user PostScript
-25.590086 36.360567 -30.029143 41.351838 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-89.884974 105.95264 -104.87556 121.76704 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-305.77272 329.74287 -355.91977 381.11889 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1026.1573 1061.9165 -1193.2131 1230.8058 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3423.3068 3476.6533 -3978.7896 4034.8713 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-11390.162 11469.746 -13235.68 13319.344 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-37853.045 37971.77 -43982.246 44107.058 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-125730.8 125907.92 -146083.25 146269.45 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-417521.92 417786.15 -485098.57 485376.34 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1386342.4 1386736.5 -1610710.9 1611125.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-4602998.9 4603587. -5347938. 5348556.2 MAarrowhead1
% End of user PostScript
1 .825 0 r
.50002 .53747 m
.49898 .54043 L
.49773 .54371 L
.49622 .54734 L
.4944 .55139 L
.49223 .55591 L
.48964 .56097 L
.48657 .56664 L
.48292 .57301 L
.47861 .58019 L
.47353 .58829 L
.46753 .59745 L
.46048 .60783 L
.4522 .61962 L
.44248 .63302 L
.43108 .64829 L
.41773 .66571 L
.40211 .6856 L
.38385 .70837 L
.3625 .73444 L
.33757 .76434 L
.30847 .79867 L
.27451 .83812 L
.2349 .8835 L
.18873 .93575 L
.13492 .99595 L
s
.13492 .99595 m
.13125 1 L
s
1 0 0 r
.50002 .53747 m
.49898 .54043 L
s
% Start of user PostScript
0.0021358638 4.4969763 -0.12187748 4.851664 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49773 .54371 m
.49622 .54734 L
s
% Start of user PostScript
-0.27233645 5.2446243 -0.45384776 5.6810703 MAarrowhead1
% End of user PostScript
1 .473 0 r
.47353 .58829 m
.46753 .59745 L
s
% Start of user PostScript
-3.1768877 10.59467 -3.8960502 11.69415 MAarrowhead1
% End of user PostScript
1 .788 0 r
.38385 .70837 m
.3625 .73444 L
s
% Start of user PostScript
-13.938107 25.004137 -16.499643 28.133041 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-51.334128 67.842705 -60.098058 77.453048 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-177.98093 202.60884 -207.46508 233.35568 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-602.17426 638.91478 -700.64221 739.26645 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2016.0821 2070.8925 -2343.8682 2401.4888 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6718.6805 6800.448 -7808.2532 7894.213 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-22344.179 22466.161 -25963.604 26091.84 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-74241.04 74423.017 -86260.813 86452.12 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-246572.11 246843.59 -286483.43 286768.82 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-818772.33 819177.32 -951288.92 951714.68 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2718605. 2719209.2 -3158585. 3159220.2 MAarrowhead1
% End of user PostScript
1 0 .628 r
.5383 .44515 m
.54496 .43764 L
.55272 .42899 L
.56175 .41902 L
.57228 .40751 L
.58454 .39422 L
.5988 .37886 L
.61541 .36111 L
.63474 .34057 L
.65723 .31682 L
.68339 .28933 L
.71382 .2575 L
.74922 .22063 L
.79038 .17792 L
.83825 .12842 L
.89391 .07105 L
.95863 .00454 L
s
.95863 .00454 m
.96306 0 L
s
1 0 0 r
.5383 .44515 m
.54496 .43764 L
s
% Start of user PostScript
4.5964709 -6.5823353 5.3952282 -7.48291 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55272 .42899 m
.56175 .41902 L
s
% Start of user PostScript
6.326066 -8.5207856 7.4105039 -9.7177491 MAarrowhead1
% End of user PostScript
1 .473 0 r
.68339 .28933 m
.71382 .2575 L
s
% Start of user PostScript
22.006426 -25.280563 25.658319 -29.100324 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
74.560427 -79.444865 86.761867 -91.896736 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
249.78188 -257.06861 290.40655 -298.06688 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
832.63561 -843.50613 967.68504 -979.1129 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2769.4162 -2785.6331 3218.0508 -3235.0992 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9202.1979 -9226.3907 10692.097 -10717.531 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
30563.431 -30599.522 35510.638 -35548.58 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
101490.66 -101544.5 117916.81 -117973.42 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
336985.47 -337065.79 391523.48 -391607.92 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1118867.9 -1118987.7 1299942.3 -1300068.3 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3714826.9 -3715005.7 4316018.1 -4316206. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
12333742. -12334008. 14329771. -14330051. MAarrowhead1
% End of user PostScript
1 .451 0 r
.53118 .56748 m
.5335 .57022 L
.53605 .57298 L
.53887 .57575 L
.542 .5785 L
.54546 .58121 L
.54932 .58385 L
.55362 .58638 L
.55843 .58875 L
.56381 .59091 L
.56986 .59279 L
.57667 .59432 L
.58436 .59541 L
.59304 .59594 L
.60287 .5958 L
.61403 .59482 L
.62671 .59285 L
.64115 .58967 L
.65761 .58504 L
.67641 .57869 L
.69791 .57027 L
.72252 .5594 L
.75074 .54564 L
.78313 .52844 L
.82034 .50721 L
.86312 .48122 L
.91237 .44962 L
.9691 .41145 L
s
.9691 .41145 m
1 .38977 L
s
1 0 0 r
.53118 .56748 m
.5335 .57022 L
s
% Start of user PostScript
3.7415075 8.0971624 4.0197814 8.4258701 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53605 .57298 m
.53887 .57575 L
s
% Start of user PostScript
4.3263121 8.7574416 4.6648123 9.0897598 MAarrowhead1
% End of user PostScript
1 .473 0 r
.56986 .59279 m
.57667 .59432 L
s
% Start of user PostScript
8.3836306 11.135036 9.2008779 11.318532 MAarrowhead1
% End of user PostScript
1 .788 0 r
.65761 .58504 m
.67641 .57869 L
s
% Start of user PostScript
18.913177 10.205252 21.169121 9.4422425 MAarrowhead1
% End of user PostScript
.897 1 0 r
.91237 .44962 m
.9691 .41145 L
s
% Start of user PostScript
49.48471 -6.0451183 56.292326 -10.625539 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
144.43996 -79.635701 166.02405 -97.897206 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
449.93727 -353.26068 520.08031 -418.447 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1449.6561 -1305.4315 1680.2736 -1528.6545 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
4747.1065 -4531.9488 5509.4038 -5283.2147 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
15662.606 -15341.628 18188.48 -17851.045 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
51854.972 -51376.13 60233.647 -59730.254 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
171945.71 -171231.36 199752.66 -199001.69 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
570553.34 -569487.65 662858.95 -661738.63 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1893816.7 -1892226.9 2200257.1 -2198585.8 MAarrowhead1
% End of user PostScript
.001 1 0 r
.5142 .54891 m
.51476 .55159 L
.51531 .55444 L
.51586 .55746 L
.5164 .56068 L
.51693 .56411 L
.51743 .56776 L
.51789 .57167 L
.51831 .57584 L
.51867 .5803 L
.51896 .58509 L
.51915 .59024 L
.51923 .59577 L
.51916 .60173 L
.51892 .60817 L
.51847 .61514 L
.51776 .62269 L
.51675 .6309 L
.51538 .63984 L
.51358 .6496 L
.51127 .66028 L
.50835 .67199 L
.50472 .68487 L
.50024 .69907 L
.49477 .71476 L
.48814 .73214 L
.48013 .75144 L
.47051 .77293 L
.45901 .79692 L
.4453 .82375 L
.42901 .85383 L
.40971 .88764 L
.38688 .92571 L
.35993 .96869 L
s
.35993 .96869 m
.33947 1 L
s
1 0 0 r
.5142 .54891 m
.51476 .55159 L
s
% Start of user PostScript
1.7044239 5.8688448 1.7709269 6.1906315 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51531 .55444 m
.51586 .55746 L
s
% Start of user PostScript
1.8374598 6.5322964 1.9034771 6.8954057 MAarrowhead1
% End of user PostScript
1 .473 0 r
.51896 .58509 m
.51915 .59024 L
s
% Start of user PostScript
2.2749914 10.211218 2.2980343 10.828356 MAarrowhead1
% End of user PostScript
1 .788 0 r
.51538 .63984 m
.51358 .6496 L
s
% Start of user PostScript
1.8461277 16.781107 1.6300229 17.952251 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48013 .75144 m
.47051 .77293 L
s
% Start of user PostScript
-2.3846476 30.173217 -3.5386632 32.751983 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-20.618715 62.074389 -25.101397 68.682549 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-87.404817 149.24942 -103.25934 168.27478 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-318.46171 410.72301 -372.5499 469.54153 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-1099.5003 1237.138 -1281.2415 1425.936 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-3713.3799 3918.7112 -4320.0075 4535.8663 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-12422.707 12729.025 -14441.593 14763.617 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-41384.849 41841.823 -48094.966 48575.369 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-137611.41 138293.13 -159900.49 160617.17 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-457197.57 458214.58 -531215.9 532285.06 MAarrowhead1
% End of user PostScript
0 1 .406 r
.57969 .58121 m
.58813 .58101 L
.59772 .58009 L
.60862 .57831 L
.62103 .57548 L
.63519 .5714 L
.65136 .56582 L
.66985 .55847 L
.69103 .549 L
.71531 .53702 L
.74317 .52209 L
.7752 .50367 L
.81203 .48114 L
.85442 .45377 L
.90326 .42074 L
.95956 .38104 L
s
.95956 .38104 m
1 .35148 L
s
1 0 0 r
.57969 .58121 m
.58813 .58101 L
s
% Start of user PostScript
9.5622319 9.7446642 10.576071 9.7207111 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59772 .58009 m
.60862 .57831 L
s
% Start of user PostScript
11.726622 9.610798 13.034608 9.396805 MAarrowhead1
% End of user PostScript
1 .473 0 r
.74317 .52209 m
.7752 .50367 L
s
% Start of user PostScript
29.180996 2.6506938 33.023628 0.44010799 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
82.334912 -34.84761 94.346933 -44.424906 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
251.65637 -180.81364 290.42484 -215.94992 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
803.14826 -697.46333 930.20394 -819.10042 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2618.2404 -2460.577 3037.6034 -2871.8564 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8620.8006 -8385.5944 10009.44 -9762.1746 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
28514.56 -28163.673 33119.493 -32750.616 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
94511.291 -93987.83 109791.99 -109241.69 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
313549.28 -312768.36 364270.7 -363449.75 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1040663.3 -1039498.3 1209046.1 -1207821.4 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3454591.4 -3452853.5 4013614.6 -4011787.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
11468853. -11466260. 13324835. -13322109. MAarrowhead1
% End of user PostScript
1 .636 0 r
.4569 .48928 m
.45141 .49201 L
.44512 .4954 L
.43788 .49959 L
.42955 .50471 L
.41997 .51092 L
.40893 .51842 L
.3962 .52743 L
.38151 .5382 L
.36455 .55104 L
.34497 .5663 L
.32233 .58439 L
.29615 .60578 L
.26588 .63103 L
.23084 .66078 L
.19027 .69579 L
.1433 .73692 L
.08888 .7852 L
.02583 .8418 L
s
.02583 .8418 m
0 .86522 L
s
1 0 0 r
.4569 .48928 m
.45141 .49201 L
s
% Start of user PostScript
-5.1717589 -1.2866977 -5.8302097 -0.95937894 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44512 .4954 m
.43788 .49959 L
s
% Start of user PostScript
-6.5860677 -0.55163059 -7.4546274 -0.04902852 MAarrowhead1
% End of user PostScript
1 .473 0 r
.34497 .5663 m
.32233 .58439 L
s
% Start of user PostScript
-18.604065 7.9558707 -21.320516 10.126376 MAarrowhead1
% End of user PostScript
1 .788 0 r
.02583 .8418 m
0 0 rlineto s
.02583 .8418 m
0 .86522 L
s
% Start of user PostScript
-56.900669 41.01543 -65.670066 48.970372 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-181.65616 157.95817 -210.39932 185.4863 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-592.28798 556.93473 -687.16326 649.99741 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1950.3063 1897.5655 -2264.4749 2209.0299 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6451.1386 6372.4585 -7492.9789 7410.2648 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-21382.572 21265.195 -24839.76 24716.365 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-70938.989 70763.883 -82414.506 82230.423 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-235445.7 235184.47 -273541.66 273267.04 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-781587.86 781198.15 -908064.76 907655.08 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2594784.9 2594203.6 -3014693.9 3014082.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-8614723.7 8613856.4 -10008857. 10007945. MAarrowhead1
% End of user PostScript
1 .695 0 r
.47619 .43452 m
.4748 .43133 L
.47332 .428 L
.47173 .42453 L
.47002 .42092 L
.46818 .41717 L
.4662 .41327 L
.46407 .40923 L
.46175 .40504 L
.45925 .40072 L
.45652 .39627 L
.45355 .39168 L
.45032 .38699 L
.44677 .38219 L
.44289 .37731 L
.43861 .37236 L
.4339 .36738 L
.4287 .3624 L
.42293 .35745 L
.41653 .35259 L
.40941 .34788 L
.40145 .34339 L
.39256 .3392 L
.38259 .33542 L
.37138 .33217 L
.35876 .32959 L
.34451 .32786 L
.32841 .32717 L
.31016 .32776 L
.28944 .32991 L
.26589 .33394 L
.23906 .34025 L
.20846 .34929 L
.1735 .36157 L
.13352 .37772 L
.08772 .39846 L
.0352 .42463 L
s
.0352 .42463 m
0 .44366 L
s
1 0 0 r
.47619 .43452 m
.4748 .43133 L
s
% Start of user PostScript
-2.8574068 -7.8573164 -3.0236697 -8.2404091 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47332 .428 m
.47173 .42453 L
s
% Start of user PostScript
-3.201655 -8.6399455 -3.3924812 -9.0562511 MAarrowhead1
% End of user PostScript
1 .473 0 r
.45652 .39627 m
.45355 .39168 L
s
% Start of user PostScript
-5.2173924 -12.4482 -5.5734542 -12.997872 MAarrowhead1
% End of user PostScript
1 .788 0 r
.42293 .35745 m
.41653 .35259 L
s
% Start of user PostScript
-9.2478865 -17.10608 -10.016067 -17.689096 MAarrowhead1
% End of user PostScript
.897 1 0 r
.34451 .32786 m
.32841 .32717 L
s
% Start of user PostScript
-18.658376 -20.657122 -20.591229 -20.740018 MAarrowhead1
% End of user PostScript
.581 1 0 r
.13352 .37772 m
.08772 .39846 L
s
% Start of user PostScript
-43.977937 -14.673895 -49.47389 -12.185085 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-119.20372 31.705469 -136.07644 44.092061 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-355.77719 225.24514 -409.74612 272.52155 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-1121.5592 926.82826 -1297.6834 1092.9684 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-3634.7014 3344.197 -4214.8908 3909.4919 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-11934.852 11501.47 -13854.341 13398.739 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-39427.017 38780.487 -45789.788 45110.11 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-130606.79 129642.29 -151716.79 150702.83 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-433188.98 431750.1 -503254.01 501741.36 MAarrowhead1
% End of user PostScript
0 .672 1 r
.44088 .4206 m
.43514 .41924 L
.42867 .41825 L
.42135 .41771 L
.41307 .41774 L
.40368 .41846 L
.39301 .42001 L
.38087 .42257 L
.36702 .42634 L
.35121 .43155 L
.33313 .43849 L
.31244 .44747 L
.28873 .45888 L
.26151 .47315 L
.23025 .49081 L
.1943 .51245 L
.15294 .53878 L
.10529 .57062 L
.05037 .60893 L
s
.05037 .60893 m
0 .64541 L
s
1 0 0 r
.44088 .4206 m
.43514 .41924 L
s
% Start of user PostScript
-7.0947387 -9.5274736 -7.7834593 -9.690992 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42867 .41825 m
.42135 .41771 L
s
% Start of user PostScript
-8.560082 -9.8103036 -9.4376244 -9.874631 MAarrowhead1
% End of user PostScript
1 .473 0 r
.33313 .43849 m
.31244 .44747 L
s
% Start of user PostScript
-20.023865 -7.3815302 -22.506905 -6.3035946 MAarrowhead1
% End of user PostScript
1 .788 0 r
.05037 .60893 m
0 0 rlineto s
.05037 .60893 m
0 .64541 L
s
% Start of user PostScript
-53.955304 13.071259 -61.557053 18.576838 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-160.45092 99.459096 -184.73152 120.61257 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-504.83811 413.84899 -584.02319 488.36896 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1634.5329 1498.7931 -1895.3043 1752.605 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5364.7972 5162.2972 -6227.4079 6014.5255 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-17719.197 17417.102 -20578.419 20260.836 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-58691.726 58241.054 -68177.6 67703.821 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-194657.4 193985.08 -226141.05 225434.26 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-645978.03 644975.04 -750491.67 749437.26 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2144264.2 2142767.9 -2491238.2 2489665.2 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-7118523.8 7116291.6 -8270483. 8268136.4 MAarrowhead1
% End of user PostScript
.433 1 0 r
.55758 .51941 m
.56478 .51617 L
.57302 .51207 L
.58249 .50697 L
.59336 .50068 L
.60587 .49299 L
.62027 .48366 L
.63686 .4724 L
.65599 .45887 L
.67806 .44269 L
.70354 .4234 L
.73297 .40048 L
.76699 .37331 L
.80632 .34117 L
.85181 .30324 L
.90446 .25854 L
.96541 .20594 L
s
.96541 .20594 m
1 .17566 L
s
1 0 0 r
.55758 .51941 m
.56478 .51617 L
s
% Start of user PostScript
6.910105 2.3294454 7.7730082 1.9402641 MAarrowhead1
% End of user PostScript
1 .158 0 r
.57302 .51207 m
.58249 .50697 L
s
% Start of user PostScript
8.7624646 1.4488178 9.8982836 0.83654249 MAarrowhead1
% End of user PostScript
1 .473 0 r
.70354 .4234 m
.73297 .40048 L
s
% Start of user PostScript
24.425105 -9.1916617 27.956859 -11.94238 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
74.131408 -51.405781 85.500254 -61.609459 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
235.73767 -201.83502 272.951 -237.31012 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
767.18064 -716.60383 889.93875 -836.76881 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2524.0121 -2448.5604 2930.3982 -2851.0779 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8345.5284 -8232.9676 9693.0094 -9574.6775 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
27656.682 -27488.761 32127.838 -31951.308 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
91746.665 -91496.156 106587.49 -106324.14 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
304495.15 -304121.44 353762.57 -353369.69 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1010788.7 -1010231.2 1174353.5 -1173767.4 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3355681.8 -3354850.1 3898723.1 -3897848.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
11140876. -11139635. 12943817. -12942512. MAarrowhead1
% End of user PostScript
1 .549 0 r
.45868 .56038 m
.45147 .56857 L
.44306 .57801 L
.43327 .58889 L
.42185 .60143 L
.40856 .61592 L
.39309 .63265 L
.37508 .65198 L
.35411 .67433 L
.32972 .70019 L
.30133 .7301 L
.26831 .76474 L
.2299 .80484 L
.18523 .85129 L
.13328 .90511 L
.07288 .96749 L
s
.07288 .96749 m
.0413 1 L
s
1 0 0 r
.45868 .56038 m
.45147 .56857 L
s
% Start of user PostScript
-4.9578375 7.2459875 -5.8234317 8.2288976 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44306 .57801 m
.43327 .58889 L
s
% Start of user PostScript
-6.8323513 9.3611481 -8.0079576 10.666409 MAarrowhead1
% End of user PostScript
1 .473 0 r
.30133 .7301 m
.26831 .76474 L
s
% Start of user PostScript
-23.84005 27.612571 -27.802462 31.768405 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-80.876071 86.504012 -94.12015 100.03664 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-271.09039 279.48629 -315.19417 324.02054 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-903.88934 916.41455 -1050.5158 1063.6832 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3006.7432 3025.4287 -3493.8537 3513.4972 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-9991.2797 10019.155 -11608.981 11638.286 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-33184.958 33226.543 -38556.57 38600.287 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-110196.95 110258.99 -128032.3 128097.52 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-365895.11 365987.66 -425112.02 425209.32 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1214856.8 1214994.9 -1411466.1 1411611.2 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4033529.9 4033735.8 -4686298.8 4686515.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-13391885. 13392192. -15559159. 15559482. MAarrowhead1
% End of user PostScript
.311 0 1 r
.53885 .49492 m
.5442 .4913 L
.55037 .48695 L
.55749 .48174 L
.56571 .47553 L
.57521 .46815 L
.58618 .4594 L
.59887 .44905 L
.61354 .43683 L
.63052 .42243 L
.65018 .40549 L
.67295 .38558 L
.69932 .36221 L
.72988 .33481 L
.76529 .30271 L
.80634 .26514 L
.85394 .22121 L
.90915 .16986 L
.97318 .10988 L
s
.97318 .10988 m
1 .08459 L
s
1 0 0 r
.53885 .49492 m
.5442 .4913 L
s
% Start of user PostScript
4.6615991 -0.60948232 5.3040017 -1.0441285 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55037 .48695 m
.55749 .48174 L
s
% Start of user PostScript
6.0446246 -1.566343 6.8990686 -2.1911806 MAarrowhead1
% End of user PostScript
1 .473 0 r
.65018 .40549 m
.67295 .38558 L
s
% Start of user PostScript
18.021959 -11.341147 20.753866 -13.730522 MAarrowhead1
% End of user PostScript
1 .788 0 r
.97318 .10988 m
0 0 rlineto s
.97318 .10988 m
1 .08459 L
s
% Start of user PostScript
56.781391 -46.814792 65.69508 -55.217482 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
183.96539 -169.09697 213.32632 -197.69558 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
603.99066 -581.80959 701.12393 -677.80561 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1995.1812 -1962.091 2317.1552 -2282.3684 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6609.1103 -6559.7455 7677.3262 -7625.4303 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
21920.456 -21846.812 25465.901 -25388.481 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
72744.815 -72634.952 84514.381 -84398.884 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
241471.08 -241307.18 280544.84 -280372.54 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
801637.3 -801392.79 931362.9 -931105.86 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2661417.8 -2661053. 3092116.2 -3091732.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
8836051.5 -8835507.4 10266012. -10265440. MAarrowhead1
% End of user PostScript
.286 1 0 r
.46169 .48527 m
.45695 .48729 L
.45153 .48985 L
.4453 .49307 L
.43816 .49706 L
.42994 .50196 L
.42048 .50792 L
.40959 .51514 L
.39704 .52383 L
.38257 .53425 L
.36586 .54669 L
.34657 .5615 L
.32428 .57908 L
.29851 .59989 L
.26871 .62448 L
.23424 .65348 L
.19433 .68763 L
.14813 .72778 L
.09461 .77493 L
.03261 .83024 L
s
.03261 .83024 m
0 .85966 L
s
1 0 0 r
.46169 .48527 m
.45695 .48729 L
s
% Start of user PostScript
-4.597513 -1.7673021 -5.1656195 -1.5255266 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45153 .48985 m
.4453 .49307 L
s
% Start of user PostScript
-5.8166451 -1.2175634 -6.5635464 -0.83131372 MAarrowhead1
% End of user PostScript
1 .473 0 r
.36586 .54669 m
.34657 .5615 L
s
% Start of user PostScript
-16.096795 5.6029886 -18.41175 7.3799152 MAarrowhead1
% End of user PostScript
1 .788 0 r
.09461 .77493 m
.03261 .83024 L
s
% Start of user PostScript
-48.646804 32.991885 -56.086809 39.629245 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-154.35764 131.00324 -178.69245 154.14065 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-501.81074 466.97007 -582.05787 545.43089 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1650.1456 1598.1694 -1915.759 1861.118 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5454.9194 5377.3801 -6335.5689 6254.0541 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-18075.529 17959.854 -20997.571 20875.965 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-59959.998 59787.431 -69658.809 69477.394 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-198995.33 198737.89 -231192.47 230921.83 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-660570.09 660186.03 -767462.33 767058.59 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2192994.4 2192421.4 -2547880.1 2547277.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-7280735.9 7279881.2 -8458984.7 8458086.1 MAarrowhead1
% End of user PostScript
0 .362 1 r
.44783 .44667 m
.4423 .44679 L
.43603 .44737 L
.4289 .44852 L
.42078 .45036 L
.41152 .45301 L
.40095 .45664 L
.38885 .46143 L
.37501 .4676 L
.35913 .47541 L
.3409 .48515 L
.31996 .49717 L
.29588 .51188 L
.26816 .52974 L
.23623 .55131 L
.19942 .57723 L
.15695 .60825 L
.10792 .64524 L
.05129 .68921 L
s
.05129 .68921 m
0 .73008 L
s
1 0 0 r
.44783 .44667 m
.4423 .44679 L
s
% Start of user PostScript
-6.2606284 -6.3998139 -6.9238678 -6.3856892 MAarrowhead1
% End of user PostScript
1 .158 0 r
.43603 .44737 m
.4289 .44852 L
s
% Start of user PostScript
-7.6765001 -6.3154524 -8.5320721 -6.1772632 MAarrowhead1
% End of user PostScript
1 .473 0 r
.3409 .48515 m
.31996 .49717 L
s
% Start of user PostScript
-19.091533 -1.782007 -21.604236 -0.33951352 MAarrowhead1
% End of user PostScript
1 .788 0 r
.05129 .68921 m
0 0 rlineto s
.05129 .68921 m
0 .73008 L
s
% Start of user PostScript
-53.84539 22.705727 -61.698693 28.962466 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-164.53989 118.08497 -189.88403 141.04732 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-525.05838 455.75579 -608.11523 535.25942 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1711.5789 1608.1915 -1985.7132 1877.0251 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5635.3864 5481.1507 -6543.1217 6380.9781 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-18639.645 18409.552 -21649.818 21407.928 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-61780.631 61437.373 -71769.365 71408.507 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-204962.02 204449.94 -238117.74 237579.41 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-680263.83 679499.89 -790332.69 789529.59 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2258206.3 2257066.6 -2623629.9 2622431.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-7496987.9 7495287.8 -8710210.3 8708423. MAarrowhead1
% End of user PostScript
.946 0 1 r
.55923 .52043 m
.56662 .51713 L
.57508 .51295 L
.5848 .50775 L
.59597 .50133 L
.60881 .49348 L
.62359 .48394 L
.64062 .47242 L
.66025 .45859 L
.6829 .44203 L
.70905 .42229 L
.73925 .39882 L
.77415 .371 L
.8145 .33809 L
.86118 .29923 L
.9152 .25344 L
.97773 .19955 L
s
.97773 .19955 m
1 .18008 L
s
1 0 0 r
.55923 .52043 m
.56662 .51713 L
s
% Start of user PostScript
7.107953 2.4511801 7.9940412 2.0551991 MAarrowhead1
% End of user PostScript
1 .158 0 r
.57508 .51295 m
.5848 .50775 L
s
% Start of user PostScript
9.0099819 1.5544939 10.176095 0.93003301 MAarrowhead1
% End of user PostScript
1 .473 0 r
.70905 .42229 m
.73925 .39882 L
s
% Start of user PostScript
25.085456 -9.3251102 28.709514 -12.141117 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
76.083018 -52.571345 87.745974 -63.028832 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
241.85796 -206.78267 280.02935 -243.15571 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
786.96474 -734.63855 912.87625 -857.86724 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2588.8981 -2510.8366 3005.7127 -2923.6489 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8559.7645 -8443.3104 9941.8086 -9819.3838 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
28366.191 -28192.462 32952.01 -32769.374 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
94099.664 -93840.49 109321.05 -109048.59 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
312303.42 -311916.78 362834.13 -362427.66 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1036707.2 -1036130.4 1204465.9 -1203859.6 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3441725.3 -3440864.9 3998690.6 -3997786. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
11426537. -11425254. 13275707. -13274357. MAarrowhead1
% End of user PostScript
.691 0 1 r
.46517 .4304 m
.46242 .42779 L
.45938 .42521 L
.45599 .42268 L
.45222 .42022 L
.44802 .41789 L
.44331 .41572 L
.43803 .41377 L
.4321 .4121 L
.42542 .4108 L
.41788 .40994 L
.40935 .40965 L
.39968 .41003 L
.3887 .41125 L
.37622 .41348 L
.362 .41692 L
.34578 .4218 L
.32725 .42842 L
.30604 .4371 L
.28175 .44822 L
.2539 .46223 L
.22192 .47966 L
.18516 .50111 L
.14288 .5273 L
.0942 .55907 L
.03811 .59738 L
s
.03811 .59738 m
0 .62448 L
s
1 0 0 r
.46517 .4304 m
.46242 .42779 L
s
% Start of user PostScript
-4.1792757 -8.3524982 -4.5092375 -8.6650542 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45938 .42521 m
.45599 .42268 L
s
% Start of user PostScript
-4.8748387 -8.9749133 -5.2809365 -9.2789075 MAarrowhead1
% End of user PostScript
1 .473 0 r
.41788 .40994 m
.40935 .40965 L
s
% Start of user PostScript
-9.8546861 -10.806716 -10.878414 -10.842321 MAarrowhead1
% End of user PostScript
1 .788 0 r
.30604 .4371 m
.28175 .44822 L
s
% Start of user PostScript
-23.27494 -7.5482504 -26.189645 -6.2138841 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-63.187071 17.204275 -72.141903 23.801518 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-188.77097 120.1727 -217.42446 145.30908 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-595.38726 493.05067 -688.91265 581.32914 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1929.98 1777.3118 -2238.097 2077.6013 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6337.9788 6110.2245 -7357.3855 7117.954 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-20938.73 20598.961 -24317.942 23960.753 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-69363.734 68856.857 -80575.15 80042.286 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-230064.03 229307.86 -267275.36 266480.42 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-763493.84 762365.77 -887022.11 885836.2 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2534373.2 2532690.3 -2944475.1 2942705.9 MAarrowhead1
% End of user PostScript
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00833333 0.5 0.00833333 [
[0 .4875 -18.4688 -20 ]
[0 .4875 18.4688 0 ]
[.16667 .4875 -18.4688 -20 ]
[.16667 .4875 18.4688 0 ]
[.33333 .4875 -18.4688 -20 ]
[.33333 .4875 18.4688 0 ]
[.66667 .4875 -12 -20 ]
[.66667 .4875 12 0 ]
[.83333 .4875 -12 -20 ]
[.83333 .4875 12 0 ]
[1 .4875 -12 -20 ]
[1 .4875 12 0 ]
[.4875 0 -36.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .16667 -36.9375 -10 ]
[.4875 .16667 0 10 ]
[.4875 .33333 -36.9375 -10 ]
[.4875 .33333 0 10 ]
[.4875 .66667 -24 -10 ]
[.4875 .66667 0 10 ]
[.4875 .83333 -24 -10 ]
[.4875 .83333 0 10 ]
[.4875 1 -24 -10 ]
[.4875 1 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.16667 .5 m
.16667 .50625 L
s
gsave
.16667 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.33333 .5 m
.33333 .50625 L
s
gsave
.33333 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.66667 .5 m
.66667 .50625 L
s
gsave
.66667 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.83333 .5 m
.83333 .50625 L
s
gsave
.83333 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 .5 m
.04167 .50375 L
s
.08333 .5 m
.08333 .50375 L
s
.125 .5 m
.125 .50375 L
s
.20833 .5 m
.20833 .50375 L
s
.25 .5 m
.25 .50375 L
s
.29167 .5 m
.29167 .50375 L
s
.375 .5 m
.375 .50375 L
s
.41667 .5 m
.41667 .50375 L
s
.45833 .5 m
.45833 .50375 L
s
.54167 .5 m
.54167 .50375 L
s
.58333 .5 m
.58333 .50375 L
s
.625 .5 m
.625 .50375 L
s
.70833 .5 m
.70833 .50375 L
s
.75 .5 m
.75 .50375 L
s
.79167 .5 m
.79167 .50375 L
s
.875 .5 m
.875 .50375 L
s
.91667 .5 m
.91667 .50375 L
s
.95833 .5 m
.95833 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.5 .16667 m
.50625 .16667 L
s
gsave
.4875 .16667 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.5 .33333 m
.50625 .33333 L
s
gsave
.4875 .33333 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.5 .66667 m
.50625 .66667 L
s
gsave
.4875 .66667 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.5 .83333 m
.50625 .83333 L
s
gsave
.4875 .83333 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .04167 m
.50375 .04167 L
s
.5 .08333 m
.50375 .08333 L
s
.5 .125 m
.50375 .125 L
s
.5 .20833 m
.50375 .20833 L
s
.5 .25 m
.50375 .25 L
s
.5 .29167 m
.50375 .29167 L
s
.5 .375 m
.50375 .375 L
s
.5 .41667 m
.50375 .41667 L
s
.5 .45833 m
.50375 .45833 L
s
.5 .54167 m
.50375 .54167 L
s
.5 .58333 m
.50375 .58333 L
s
.5 .625 m
.50375 .625 L
s
.5 .70833 m
.50375 .70833 L
s
.5 .75 m
.50375 .75 L
s
.5 .79167 m
.50375 .79167 L
s
.5 .875 m
.50375 .875 L
s
.5 .91667 m
.50375 .91667 L
s
.5 .95833 m
.50375 .95833 L
s
.01 w
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.918 0 1 r
.5 Mabswid
.53 .41786 m
.53629 .40889 L
.54368 .39869 L
.55234 .38708 L
.56249 .37383 L
.57436 .35869 L
.58825 .34137 L
.60447 .32154 L
.62342 .29879 L
.64555 .27268 L
.67136 .24267 L
.70147 .20815 L
.73657 .16842 L
.77749 .12263 L
.82515 .06984 L
.88068 .00894 L
s
.88068 .00894 m
.8889 0 L
s
.175 1 0 r
.43693 .43696 m
.43021 .43721 L
.42258 .43804 L
.4139 .43957 L
.40402 .44194 L
.39275 .44532 L
.37987 .4499 L
.36513 .45591 L
.34825 .46361 L
.32889 .47332 L
.30667 .48541 L
.28113 .50029 L
.25175 .51846 L
.21792 .5405 L
.17895 .56709 L
.13401 .59901 L
.08216 .63717 L
.0223 .68264 L
s
.0223 .68264 m
0 .70006 L
s
.341 1 0 r
.41928 .49969 m
.40846 .50635 L
.396 .51445 L
.38165 .52421 L
.36509 .53593 L
.346 .54996 L
.32395 .56667 L
.29848 .58653 L
.26905 .61007 L
.23501 .6379 L
.19564 .67076 L
.15008 .70947 L
.09733 .75502 L
.03625 .80853 L
s
.03625 .80853 m
0 .8407 L
s
0 .834 1 r
.46459 .53177 m
.45896 .53722 L
.45243 .54356 L
.44484 .55094 L
.43603 .55953 L
.4258 .56954 L
.41392 .58118 L
.40012 .59472 L
.3841 .61048 L
.36549 .62881 L
.34388 .65012 L
.31878 .67492 L
.28963 .70375 L
.25577 .73727 L
.21644 .77625 L
.17075 .82156 L
.11768 .87424 L
.05603 .93547 L
s
.05603 .93547 m
0 .99116 L
s
1 .716 0 r
.46058 .47102 m
.45609 .472 L
.45098 .47343 L
.44513 .4754 L
.43845 .47801 L
.4308 .48138 L
.42203 .48565 L
.41196 .49098 L
.40039 .49757 L
.38709 .50564 L
.37179 .51545 L
.35416 .5273 L
.33383 .54154 L
.31038 .5586 L
.28332 .57895 L
.25206 .60315 L
.21593 .63185 L
.17417 .66581 L
.12586 .70591 L
.06997 .75318 L
.00526 .80882 L
s
.00526 .80882 m
0 .81341 L
s
1 .182 0 r
.42344 .45177 m
.4145 .45431 L
.40429 .4578 L
.39261 .4624 L
.37924 .46834 L
.36391 .47585 L
.34632 .48523 L
.3261 .49681 L
.30286 .51098 L
.2761 .52819 L
.24527 .54899 L
.20974 .57397 L
.16874 .60388 L
.12141 .63955 L
.06675 .68195 L
.00359 .73224 L
s
.00359 .73224 m
0 .73516 L
s
1 0 .955 r
.56003 .45359 m
.56937 .44495 L
.5802 .43486 L
.59276 .42307 L
.60733 .40931 L
.62424 .39325 L
.64387 .37452 L
.66664 .35269 L
.69308 .32725 L
.72376 .2976 L
.75938 .26308 L
.80074 .22287 L
.84876 .17607 L
.90451 .12159 L
.96925 .05818 L
s
.96925 .05818 m
1 .02801 L
s
.642 0 1 r
.51711 .58092 m
.51717 .58589 L
.5171 .59124 L
.51688 .59702 L
.51646 .60328 L
.51581 .61006 L
.51489 .61744 L
.51364 .62547 L
.51201 .63424 L
.50991 .64383 L
.50726 .65436 L
.50397 .66594 L
.49992 .67871 L
.49497 .69282 L
.48896 .70845 L
.48172 .72581 L
.47302 .74515 L
.46263 .76673 L
.45024 .79088 L
.43552 .81796 L
.41808 .8484 L
.39746 .88268 L
.37312 .92138 L
.34444 .96516 L
s
.34444 .96516 m
.32075 1 L
s
1 .482 0 r
.4742 .53849 m
.46967 .54367 L
.46439 .54963 L
.45824 .5565 L
.45108 .56442 L
.44273 .57356 L
.43301 .58411 L
.4217 .5963 L
.40853 .61039 L
.3932 .62669 L
.37537 .64554 L
.35462 .66736 L
.33049 .69263 L
.30241 .72188 L
.26977 .75578 L
.2318 .79505 L
.18765 .84057 L
.13633 .89335 L
.07665 .95455 L
s
.07665 .95455 m
.03222 1 L
s
0 1 .547 r
.42723 .53881 m
.4164 .54791 L
.40385 .55862 L
.38933 .57122 L
.37251 .58602 L
.35302 .60338 L
.33044 .62373 L
.30427 .64755 L
.27393 .67542 L
.23874 .70801 L
.19793 .74609 L
.15059 .79056 L
.09567 .84246 L
.03195 .90301 L
s
.03195 .90301 m
0 .93352 L
s
0 .093 1 r
.42894 .53691 m
.41839 .54572 L
.40617 .5561 L
.39203 .5683 L
.37565 .58265 L
.35668 .59948 L
.3347 .61921 L
.30922 .64233 L
.27969 .66938 L
.24544 .70101 L
.20573 .73798 L
.15966 .78116 L
.10622 .83157 L
.04421 .89039 L
s
.04421 .89039 m
0 .93254 L
s
0 .075 1 r
.47328 .46623 m
.47063 .46578 L
.46764 .46551 L
.46425 .46548 L
.4604 .46572 L
.45604 .4663 L
.45107 .46728 L
.44541 .46876 L
.43894 .47082 L
.43156 .47358 L
.4231 .47717 L
.41341 .48174 L
.4023 .48748 L
.38954 .4946 L
.37486 .50333 L
.35798 .51397 L
.33853 .52685 L
.31612 .54236 L
.29027 .56095 L
.26045 .58315 L
.226 .60958 L
.1862 .64094 L
.1402 .67809 L
.08699 .72198 L
.02543 .77374 L
s
.02543 .77374 m
0 .7955 L
s
0 1 .968 r
.47262 .49849 m
.46899 .50064 L
.46481 .50326 L
.46 .50644 L
.45445 .51026 L
.44805 .51485 L
.44067 .52033 L
.43215 .52686 L
.4223 .5346 L
.41092 .54377 L
.39775 .55462 L
.38252 .5674 L
.3649 .58246 L
.34449 .60018 L
.32085 .62098 L
.29346 .64538 L
.26173 .67398 L
.22495 .70746 L
.1823 .74664 L
.13285 .79245 L
.0755 .84597 L
.00897 .90848 L
s
.00897 .90848 m
0 .91695 L
s
1 .536 0 r
.44433 .51149 m
.43654 .51701 L
.42755 .52361 L
.41718 .53148 L
.40519 .54084 L
.39134 .55192 L
.37532 .56503 L
.3568 .5805 L
.33535 .59873 L
.31053 .62017 L
.28178 .64536 L
.24848 .67493 L
.20989 .70959 L
.16517 .75019 L
.11332 .79769 L
.05321 .85325 L
s
.05321 .85325 m
0 .90279 L
s
.042 1 0 r
.45797 .55467 m
.45082 .56247 L
.44249 .57148 L
.43279 .58189 L
.42151 .59392 L
.40838 .60784 L
.39311 .62395 L
.37534 .64259 L
.35467 .66418 L
.33063 .68919 L
.30267 .71816 L
.27016 .75174 L
.23236 .79066 L
.18841 .83579 L
.13731 .88813 L
.07792 .94883 L
s
.07792 .94883 m
.02774 1 L
s
.388 1 0 r
.54218 .50333 m
.54775 .50009 L
.55416 .49614 L
.56153 .49134 L
.57003 .48556 L
.57983 .47861 L
.59113 .47031 L
.60418 .46041 L
.61925 .44864 L
.63668 .4347 L
.65682 .41821 L
.68013 .39876 L
.7071 .37583 L
.73832 .34886 L
.77448 .31717 L
.81637 .27998 L
.8649 .23639 L
.92116 .18532 L
.98637 .12557 L
s
.98637 .12557 m
1 .11298 L
s
1 .402 0 r
.51611 .56591 m
.51645 .56977 L
.51673 .57391 L
.51693 .57836 L
.51704 .58314 L
.51703 .58829 L
.51687 .59384 L
.51654 .59985 L
.51601 .60635 L
.51521 .61342 L
.51412 .62111 L
.51267 .62949 L
.51079 .63866 L
.5084 .64871 L
.50542 .65975 L
.50173 .6719 L
.49721 .68532 L
.49172 .70018 L
.48507 .71666 L
.47708 .735 L
.46751 .75544 L
.45609 .7783 L
.4425 .8039 L
.42639 .83265 L
.40731 .865 L
.38479 .90149 L
.35823 .94273 L
.32697 .98942 L
s
.32697 .98942 m
.31962 1 L
s
0 .105 1 r
.51034 .54582 m
.51046 .54857 L
.51052 .55154 L
.51051 .55474 L
.5104 .55818 L
.51019 .56191 L
.50985 .56595 L
.50934 .57034 L
.50865 .57512 L
.50774 .58033 L
.50656 .58602 L
.50506 .59227 L
.50319 .59913 L
.50088 .60669 L
.49804 .61503 L
.4946 .62427 L
.49044 .63453 L
.48544 .64594 L
.47945 .65866 L
.47231 .67288 L
.46382 .68882 L
.45374 .70672 L
.44182 .72687 L
.42774 .7496 L
.41115 .77529 L
.39161 .80438 L
.36866 .83739 L
.3417 .8749 L
.3101 .91761 L
.27307 .96631 L
s
.27307 .96631 m
.24682 1 L
s
0 1 .711 r
.4975 .50156 m
.49712 .50189 L
.49668 .50228 L
.49617 .50273 L
.49559 .50327 L
.4949 .50389 L
.49411 .50462 L
.49319 .50547 L
.49213 .50647 L
.49089 .50763 L
.48946 .50899 L
.4878 .51057 L
.48587 .51242 L
.48363 .51457 L
.48103 .51708 L
.47801 .52 L
.47451 .5234 L
.47044 .52736 L
.46571 .53198 L
.46023 .53734 L
.45386 .54359 L
.44646 .55085 L
.43788 .5593 L
.4279 .56914 L
.41631 .58057 L
.40286 .59387 L
.38722 .60933 L
.36907 .62731 L
.34798 .64821 L
.32348 .67251 L
.29503 .70076 L
.26197 .7336 L
.22357 .77178 L
.17897 .81614 L
.12715 .86771 L
.06695 .92765 L
s
.06695 .92765 m
0 .99433 L
s
.495 0 1 r
.49346 .54123 m
.49144 .54503 L
.48904 .54929 L
.48621 .55409 L
.48287 .5595 L
.47892 .56561 L
.47428 .57254 L
.46882 .5804 L
.46242 .58933 L
.4549 .59949 L
.4461 .61108 L
.4358 .62432 L
.42375 .63945 L
.40966 .65678 L
.3932 .67664 L
.37399 .69943 L
.35157 .72562 L
.32541 .75573 L
.29492 .79039 L
.25937 .83031 L
.21795 .87633 L
.1697 .92942 L
.1135 .99069 L
s
.1135 .99069 m
.1049 1 L
s
0 .715 1 r
.53808 .58176 m
.54093 .58505 L
.54407 .58837 L
.54755 .59169 L
.55139 .59498 L
.55566 .59822 L
.56042 .60135 L
.56572 .60434 L
.57166 .60712 L
.57831 .60963 L
.58579 .61179 L
.59422 .6135 L
.60372 .61464 L
.61447 .61509 L
.62665 .61468 L
.64048 .61323 L
.6562 .61051 L
.67411 .60628 L
.69453 .60023 L
.71787 .59201 L
.74456 .5812 L
.77514 .56733 L
.8102 .54983 L
.85045 .52804 L
.8967 .50119 L
.9499 .46839 L
s
.9499 .46839 m
1 .43583 L
s
0 .897 1 r
.46272 .51075 m
.45742 .51469 L
.45129 .51938 L
.44422 .52495 L
.43605 .53154 L
.42659 .53933 L
.41566 .54852 L
.403 .55935 L
.38834 .57207 L
.37136 .58702 L
.3517 .60455 L
.32891 .6251 L
.30249 .64916 L
.27186 .67731 L
.23634 .71022 L
.19515 .74867 L
.14737 .79357 L
.09194 .84598 L
.02761 .90712 L
s
.02761 .90712 m
0 .93349 L
s
1 0 .639 r
.46034 .54491 m
.45378 .55174 L
.44615 .55966 L
.43727 .56883 L
.42695 .57946 L
.41495 .59179 L
.401 .60609 L
.38479 .62267 L
.36593 .6419 L
.34402 .66422 L
.31855 .69011 L
.28895 .72016 L
.25454 .75503 L
.21455 .79551 L
.16808 .8425 L
.11407 .89705 L
.05131 .96038 L
s
.05131 .96038 m
.01201 1 L
s
1 0 .666 r
.55438 .46192 m
.56273 .45441 L
.5724 .44561 L
.58362 .43531 L
.59663 .42328 L
.61172 .40921 L
.62922 .39278 L
.64953 .3736 L
.67309 .35123 L
.70043 .32514 L
.73215 .29472 L
.76898 .25927 L
.81173 .21797 L
.86136 .16986 L
.91898 .11385 L
.98587 .04863 L
s
.98587 .04863 m
1 .03483 L
s
.202 1 0 r
.56868 .47284 m
.57865 .46501 L
.59017 .45572 L
.60349 .44475 L
.61891 .43181 L
.63675 .41657 L
.6574 .39865 L
.68133 .3776 L
.70904 .3529 L
.74116 .32396 L
.77839 .29007 L
.82155 .25042 L
.8716 .20406 L
.92965 .14989 L
.99698 .08664 L
s
.99698 .08664 m
1 .08379 L
s
.357 0 1 r
.51452 .57518 m
.5144 .5799 L
.51412 .58502 L
.51366 .59055 L
.51299 .59657 L
.51207 .60311 L
.51084 .61024 L
.50925 .61804 L
.50722 .62659 L
.50469 .63598 L
.50157 .64633 L
.49773 .65774 L
.49307 .67038 L
.48743 .6844 L
.48064 .69999 L
.47252 .71738 L
.46282 .73681 L
.45129 .75858 L
.4376 .78303 L
.42141 .81053 L
.40228 .84156 L
.37972 .87661 L
.35317 .91631 L
.32196 .96133 L
s
.32196 .96133 m
.29427 1 L
s
0 .614 1 r
.47481 .42791 m
.47342 .4243 L
.47195 .42054 L
.47038 .41659 L
.46871 .41246 L
.46694 .40815 L
.46504 .40364 L
.46301 .39894 L
.46084 .39403 L
.45851 .38892 L
.45602 .38359 L
.45333 .37805 L
.45044 .3723 L
.44732 .36633 L
.44394 .36016 L
.44028 .35377 L
.43631 .34718 L
.43199 .3404 L
.42728 .33345 L
.42212 .32634 L
.41647 .31909 L
.41026 .31174 L
.40342 .30433 L
.39587 .29689 L
.38751 .2895 L
.37823 .28222 L
.36791 .27513 L
.3564 .26834 L
.34354 .26196 L
.32912 .25615 L
.31293 .25108 L
.29471 .24695 L
.27415 .244 L
.25092 .24253 L
.22461 .24287 L
.19477 .24541 L
.16084 .25063 L
.12222 .25908 L
.07819 .27139 L
.0279 .28833 L
s
.0279 .28833 m
0 .29922 L
s
.524 1 0 r
.55149 .45915 m
.55952 .45166 L
.56885 .44291 L
.57966 .4327 L
.59222 .42078 L
.60678 .40688 L
.62368 .39068 L
.6433 .3718 L
.66608 .3498 L
.69251 .32417 L
.72321 .29434 L
.75885 .2596 L
.80023 .21916 L
.84828 .17211 L
.90408 .11735 L
.96888 .05365 L
s
.96888 .05365 m
1 .023 L
s
1 0 .234 r
.56472 .51899 m
.57288 .51512 L
.58224 .51027 L
.593 .50426 L
.60536 .49688 L
.61958 .4879 L
.63596 .47703 L
.65485 .46394 L
.67662 .44826 L
.70175 .42953 L
.73077 .40724 L
.76431 .38078 L
.80307 .34946 L
.8479 .31245 L
.89977 .2688 L
.95981 .2174 L
s
.95981 .2174 m
1 .18246 L
s
0 1 .365 r
.56645 .57875 m
.57319 .57945 L
.58082 .57965 L
.58946 .57923 L
.59928 .57807 L
.61044 .576 L
.62316 .57284 L
.63768 .56837 L
.65426 .56235 L
.67324 .55448 L
.69498 .54441 L
.71992 .53175 L
.74855 .51602 L
.78146 .49667 L
.81932 .47307 L
.86292 .44446 L
.91316 .40999 L
.97109 .36862 L
s
.97109 .36862 m
1 .34724 L
s
.862 0 1 r
.45725 .49687 m
.4516 .50016 L
.4451 .50419 L
.43762 .50907 L
.42899 .51496 L
.41905 .52203 L
.40758 .53048 L
.39433 .54055 L
.37903 .55251 L
.36135 .56669 L
.3409 .58345 L
.31724 .60322 L
.28986 .62653 L
.25817 .65393 L
.22146 .68613 L
.17894 .72392 L
.12967 .76821 L
.07255 .82009 L
.00635 .88079 L
s
.00635 .88079 m
0 .88666 L
s
1 0 .718 r
.55259 .55285 m
.55819 .55266 L
.56454 .55199 L
.57177 .55074 L
.58 .5488 L
.58938 .54601 L
.60011 .54223 L
.61237 .53726 L
.62642 .53089 L
.64253 .52284 L
.66103 .51282 L
.68228 .50048 L
.70673 .48541 L
.73488 .46711 L
.7673 .44504 L
.80469 .41854 L
.84783 .38684 L
.89764 .34907 L
.95517 .30419 L
s
.95517 .30419 m
1 .26832 L
s
0 1 .487 r
.50559 .54648 m
.50506 .54969 L
.50437 .55319 L
.50348 .55702 L
.50237 .56123 L
.501 .56587 L
.49931 .57098 L
.49726 .57664 L
.49477 .58292 L
.49178 .58989 L
.48819 .59767 L
.48391 .60636 L
.47881 .61608 L
.47276 .627 L
.46559 .63928 L
.45712 .65313 L
.44713 .66877 L
.43538 .68647 L
.42155 .70654 L
.40531 .72934 L
.38627 .75529 L
.36395 .78487 L
.33782 .81863 L
.30725 .85722 L
.27151 .9014 L
.22975 .95202 L
s
.22975 .95202 m
.18947 1 L
s
0 .011 1 r
.50833 .53451 m
.50849 .53654 L
.50862 .53872 L
.50871 .54106 L
.50874 .54358 L
.50871 .54629 L
.5086 .54922 L
.50839 .5524 L
.50807 .55583 L
.50761 .55957 L
.50698 .56364 L
.50616 .56808 L
.50511 .57295 L
.50378 .57828 L
.50212 .58414 L
.50008 .59061 L
.49758 .59775 L
.49456 .60566 L
.49091 .61445 L
.48652 .62424 L
.48128 .63516 L
.47503 .64738 L
.46761 .66108 L
.45881 .67648 L
.4484 .69382 L
.43612 .71339 L
.42165 .73553 L
.40462 .76061 L
.38462 .78909 L
.36115 .82147 L
.33363 .85835 L
.3014 .90042 L
.26368 .94849 L
s
.26368 .94849 m
.22236 1 L
s
.052 0 1 r
.525 .51127 m
.52805 .51009 L
.53153 .50856 L
.53553 .50662 L
.54011 .50419 L
.54538 .5012 L
.55143 .49753 L
.5584 .49307 L
.56643 .48768 L
.57569 .4812 L
.58637 .47344 L
.59869 .46418 L
.61292 .45317 L
.62937 .44011 L
.64839 .42465 L
.67038 .4064 L
.69583 .38489 L
.7253 .35957 L
.75941 .3298 L
.79893 .29486 L
.84471 .25389 L
.89777 .20588 L
.95928 .14969 L
s
.95928 .14969 m
1 .11216 L
s
0 .312 1 r
.54348 .52992 m
.54849 .52867 L
.5542 .52692 L
.56073 .52455 L
.56821 .52145 L
.57677 .51748 L
.58658 .5125 L
.59786 .5063 L
.61081 .49869 L
.62572 .48939 L
.64289 .47813 L
.66266 .46456 L
.68547 .44827 L
.71179 .42881 L
.74218 .40563 L
.77729 .3781 L
.81787 .34549 L
.86479 .30694 L
.91908 .26145 L
.98192 .20788 L
s
.98192 .20788 m
1 .19221 L
s
0 .567 1 r
.48947 .53839 m
.48699 .5423 L
.48408 .54671 L
.48065 .55172 L
.47662 .55741 L
.4719 .56388 L
.46636 .57125 L
.45988 .57966 L
.45229 .58927 L
.44342 .60027 L
.43306 .61288 L
.42095 .62733 L
.40683 .64394 L
.39035 .66302 L
.37112 .68498 L
.34872 .71026 L
.3226 .7394 L
.29218 .773 L
.25675 .81178 L
.21549 .85655 L
.16745 .90828 L
.11154 .96807 L
s
.11154 .96807 m
.0815 1 L
s
0 .641 1 r
.45363 .46731 m
.44831 .46858 L
.44224 .47039 L
.43531 .47284 L
.42738 .47606 L
.41829 .48019 L
.40788 .4854 L
.39592 .49189 L
.38218 .49988 L
.36637 .50964 L
.34817 .52148 L
.3272 .53577 L
.30302 .55292 L
.27513 .57343 L
.24292 .59787 L
.20572 .62691 L
.16272 .66133 L
.113 .70203 L
.05548 .75007 L
s
.05548 .75007 m
0 .79724 L
s
1 .753 0 r
.50658 .50775 m
.50724 .50781 L
.508 .50783 L
.50886 .50779 L
.50983 .50767 L
.51094 .50745 L
.5122 .50714 L
.51364 .50669 L
.51528 .50608 L
.51717 .5053 L
.51933 .50429 L
.5218 .50303 L
.52464 .50146 L
.52791 .49953 L
.53167 .49718 L
.53599 .49433 L
.54098 .4909 L
.54673 .48678 L
.55337 .48186 L
.56103 .47601 L
.56988 .46905 L
.58012 .46082 L
.59195 .45108 L
.60564 .4396 L
.62149 .42607 L
.63983 .41016 L
.66108 .39148 L
.6857 .36956 L
.71422 .34386 L
.74729 .31378 L
.78562 .27858 L
.83007 .23742 L
.88162 .18933 L
.94142 .13317 L
s
.94142 .13317 m
1 .07782 L
s
0 1 .882 r
.43163 .53626 m
.42146 .54479 L
.40968 .55484 L
.39604 .56665 L
.38025 .58053 L
.36195 .59682 L
.34075 .61591 L
.31618 .63826 L
.28769 .66441 L
.25465 .69499 L
.21634 .73072 L
.17189 .77245 L
.12033 .82116 L
.06051 .87798 L
s
.06051 .87798 m
0 .93574 L
s
0 1 .883 r
.47586 .56121 m
.47093 .56804 L
.46515 .57582 L
.45837 .5847 L
.45045 .59483 L
.44118 .60642 L
.43034 .6197 L
.41769 .63492 L
.40291 .6524 L
.38567 .67247 L
.36556 .69556 L
.34211 .72214 L
.31478 .75276 L
.28294 .78807 L
.24585 .8288 L
.20266 .87582 L
.15237 .93013 L
.09383 .9929 L
s
.09383 .9929 m
.08717 1 L
s
1 0 .791 r
.56948 .55744 m
.57721 .55621 L
.58602 .55424 L
.59606 .55139 L
.60753 .54748 L
.62065 .54231 L
.63567 .53565 L
.65289 .52721 L
.67266 .51668 L
.69537 .50368 L
.72148 .48777 L
.75154 .46844 L
.78617 .44509 L
.82609 .41702 L
.87214 .38344 L
.9253 .34338 L
.9867 .29575 L
s
.9867 .29575 m
1 .28517 L
s
0 1 .65 r
.46501 .46628 m
.46125 .46652 L
.45698 .4671 L
.45211 .46807 L
.44657 .46952 L
.44024 .47154 L
.43301 .47425 L
.42473 .47778 L
.41524 .48227 L
.40436 .48789 L
.39186 .49487 L
.37749 .50343 L
.36095 .51386 L
.34191 .52649 L
.31996 .54168 L
.29465 .5599 L
.26544 .58166 L
.23171 .60755 L
.19273 .63829 L
.14767 .67468 L
.09557 .71768 L
.03528 .76839 L
s
.03528 .76839 m
0 .79858 L
s
1 .839 0 r
.53907 .56499 m
.54251 .56688 L
.54637 .56863 L
.5507 .5702 L
.55556 .57154 L
.56104 .57257 L
.56722 .57324 L
.57422 .57345 L
.58215 .57309 L
.59115 .57204 L
.60139 .57017 L
.61306 .5673 L
.62637 .56324 L
.64158 .55775 L
.65898 .55056 L
.67892 .54137 L
.70178 .5298 L
.72803 .51542 L
.75821 .49773 L
.79292 .47614 L
.83289 .44996 L
.87894 .41841 L
.93205 .38055 L
.99333 .3353 L
s
.99333 .3353 m
1 .33022 L
s
.513 0 1 r
.43607 .54812 m
.42617 .55722 L
.41468 .56786 L
.40135 .58029 L
.38589 .5948 L
.36796 .61174 L
.34715 .63151 L
.32301 .65456 L
.29498 .68144 L
.26246 .71275 L
.2247 .74924 L
.18087 .79174 L
.12998 .84122 L
.07089 .89883 L
.00229 .96589 L
s
.00229 .96589 m
0 .96813 L
s
.747 1 0 r
.45182 .57874 m
.44318 .58895 L
.4331 .60068 L
.42133 .61418 L
.40762 .62971 L
.39164 .64761 L
.37302 .66824 L
.35133 .69205 L
.32607 .71953 L
.29666 .75128 L
.26243 .78797 L
.22259 .83039 L
.17623 .87946 L
.12229 .93626 L
s
.12229 .93626 m
.06146 1 L
s
.025 0 1 r
.5478 .44379 m
.55576 .43539 L
.56503 .42567 L
.57581 .41441 L
.58835 .40137 L
.60294 .38626 L
.61989 .36875 L
.63961 .34845 L
.66253 .32492 L
.68918 .29762 L
.72017 .26597 L
.75618 .22924 L
.79804 .18663 L
.8467 .13719 L
.90325 .07981 L
.96898 .01321 L
s
.96898 .01321 m
.98204 0 L
s
0 1 .142 r
.49348 .52073 m
.49203 .5229 L
.49033 .52537 L
.48833 .52817 L
.48599 .53137 L
.48324 .535 L
.48002 .53916 L
.47626 .5439 L
.47186 .54933 L
.46672 .55556 L
.46072 .56271 L
.45371 .57091 L
.44554 .58035 L
.43601 .5912 L
.4249 .6037 L
.41196 .61812 L
.39688 .63474 L
.37932 .65392 L
.35887 .67607 L
.33506 .70167 L
.30735 .73126 L
.27511 .76549 L
.23759 .80508 L
.19395 .85092 L
.14318 .90399 L
.08413 .96546 L
s
.08413 .96546 m
.05082 1 L
s
0 .032 1 r
.43378 .55269 m
.42343 .56234 L
.41144 .57361 L
.39752 .58676 L
.38137 .6021 L
.36262 .62 L
.34087 .64086 L
.31562 .66517 L
.28632 .69349 L
.25229 .72648 L
.21279 .76489 L
.16693 .80961 L
.11368 .86166 L
.05184 .92223 L
s
.05184 .92223 m
0 .97311 L
s
.008 0 1 r
.56134 .48561 m
.56997 .47939 L
.57992 .47196 L
.59143 .46312 L
.60471 .45263 L
.62007 .44021 L
.63784 .42554 L
.6584 .40823 L
.68219 .38785 L
.70974 .3639 L
.74164 .33576 L
.77861 .30277 L
.82145 .2641 L
.87111 .21883 L
.92868 .16587 L
.99544 .10395 L
s
.99544 .10395 m
1 .09969 L
s
.524 1 0 r
.55262 .47013 m
.56051 .46341 L
.56964 .4555 L
.58021 .44622 L
.59246 .43532 L
.60666 .42255 L
.62311 .4076 L
.64218 .3901 L
.6643 .36963 L
.68995 .34572 L
.71971 .3178 L
.75423 .2852 L
.79428 .24717 L
.84076 .20281 L
.8947 .15111 L
.95731 .09085 L
s
.95731 .09085 m
1 .04961 L
s
0 .194 1 r
.55451 .43785 m
.56354 .42842 L
.57405 .41751 L
.58627 .40486 L
.60047 .3902 L
.61699 .3732 L
.63619 .35349 L
.65852 .33064 L
.68447 .30413 L
.71464 .27337 L
.74971 .23769 L
.79047 .19629 L
.83785 .14823 L
.8929 .09246 L
.95689 .02772 L
s
.95689 .02772 m
.98432 0 L
s
0 1 .721 r
.57249 .48841 m
.58253 .48148 L
.59412 .47317 L
.60749 .46325 L
.62293 .45144 L
.64077 .43741 L
.66139 .4208 L
.68524 .40117 L
.71283 .37801 L
.74476 .35074 L
.78173 .31866 L
.82455 .28099 L
.87416 .23679 L
.93164 .185 L
.99827 .12435 L
s
.99827 .12435 m
1 .12276 L
s
.376 1 0 r
.55292 .42422 m
.56212 .41385 L
.57284 .4019 L
.58533 .38812 L
.59987 .37221 L
.6168 .35385 L
.63652 .33263 L
.65946 .3081 L
.68616 .27973 L
.71723 .24691 L
.75338 .20893 L
.79543 .16495 L
.84433 .11401 L
.90121 .055 L
s
.90121 .055 m
.9544 0 L
s
1 0 .811 r
.55439 .4985 m
.56174 .49387 L
.57019 .48827 L
.57993 .48153 L
.59117 .47344 L
.60414 .46378 L
.61911 .45229 L
.63642 .43865 L
.65642 .4225 L
.67955 .40341 L
.70632 .3809 L
.7373 .35439 L
.77316 .32322 L
.81471 .28662 L
.86284 .24369 L
.91861 .19337 L
.98326 .13447 L
s
.98326 .13447 m
1 .11907 L
s
.405 0 1 r
.49609 .43042 m
.49749 .42526 L
.49921 .41957 L
.50133 .41328 L
.50391 .40633 L
.50702 .39862 L
.51077 .39003 L
.51525 .38046 L
.5206 .36977 L
.52696 .35778 L
.53451 .34432 L
.54345 .32918 L
.554 .31209 L
.56644 .29279 L
.58108 .27093 L
.5983 .24612 L
.6185 .21794 L
.6422 .18586 L
.66997 .14927 L
.70247 .1075 L
.74049 .05974 L
.78493 .00506 L
s
.78493 .00506 m
.78912 0 L
s
1 .947 0 r
.52839 .479 m
.53278 .47499 L
.53787 .4703 L
.54377 .46482 L
.55062 .45841 L
.55856 .45093 L
.56777 .44221 L
.57846 .43203 L
.59087 .42016 L
.60527 .40632 L
.62199 .3902 L
.6414 .37142 L
.66392 .34955 L
.69008 .32408 L
.72045 .29444 L
.75572 .25993 L
.79667 .21979 L
.84422 .17307 L
.89945 .11873 L
.96359 .05552 L
s
.96359 .05552 m
1 .01959 L
s
1 0 .63 r
.45833 .52532 m
.45203 .53077 L
.44475 .53717 L
.4363 .54469 L
.42652 .5535 L
.41518 .56381 L
.40204 .57588 L
.38679 .58999 L
.36911 .60648 L
.34861 .62574 L
.32481 .64821 L
.29721 .67444 L
.26517 .70502 L
.22799 .74067 L
.18484 .78222 L
.13475 .83062 L
.07659 .887 L
.00908 .95265 L
s
.00908 .95265 m
0 .9615 L
s
0 1 .701 r
.46931 .52556 m
.46449 .53012 L
.45889 .53545 L
.4524 .54165 L
.44486 .54889 L
.4361 .55732 L
.42595 .56714 L
.41415 .57858 L
.40046 .5919 L
.38456 .6074 L
.3661 .62545 L
.34467 .64645 L
.31977 .67089 L
.29087 .69932 L
.25729 .73239 L
.2183 .77086 L
.17301 .81559 L
.12041 .86761 L
.05931 .92809 L
s
.05931 .92809 m
0 .98686 L
s
1 0 .805 r
.48452 .54822 m
.48111 .55331 L
.47711 .55908 L
.4724 .56564 L
.46688 .57311 L
.46042 .58162 L
.45285 .59135 L
.444 .60247 L
.43365 .61519 L
.42157 .62979 L
.40745 .64653 L
.39098 .66577 L
.37177 .68789 L
.34937 .71335 L
.32326 .74268 L
.29284 .77648 L
.25739 .81548 L
.21612 .86049 L
.16806 .91248 L
.11211 .97255 L
s
.11211 .97255 m
.08638 1 L
s
1 0 .55 r
.53551 .50078 m
.54025 .49789 L
.54571 .49439 L
.552 .49015 L
.55925 .48507 L
.56762 .47897 L
.57727 .47171 L
.58842 .46307 L
.60131 .45282 L
.61621 .4407 L
.63344 .42638 L
.65338 .40951 L
.67647 .38965 L
.7032 .36631 L
.73416 .33891 L
.77004 .30678 L
.81161 .26914 L
.85981 .22508 L
.91569 .17355 L
.9805 .11332 L
s
.9805 .11332 m
1 .09507 L
s
.15 1 0 r
.57651 .53557 m
.58579 .53203 L
.59642 .52745 L
.6086 .52162 L
.62257 .51432 L
.63863 .50528 L
.65708 .49421 L
.67832 .48072 L
.70278 .46441 L
.73098 .44479 L
.7635 .42128 L
.80104 .39322 L
.84439 .35983 L
.89447 .32021 L
.95238 .27331 L
s
.95238 .27331 m
1 .23392 L
s
.103 1 0 r
.43653 .43494 m
.42982 .43507 L
.42219 .43577 L
.41353 .43715 L
.40366 .43936 L
.39241 .44257 L
.37956 .44696 L
.36486 .45276 L
.34803 .46024 L
.32874 .4697 L
.30659 .48151 L
.28115 .49609 L
.25189 .51393 L
.21821 .5356 L
.17941 .56178 L
.13468 .59324 L
.08308 .63089 L
.02351 .67579 L
s
.02351 .67579 m
0 .69403 L
s
0 .043 1 r
.58175 .5697 m
.59079 .56842 L
.60108 .56629 L
.61282 .56314 L
.62621 .55877 L
.64152 .55294 L
.65905 .54538 L
.67914 .53578 L
.70219 .52374 L
.72866 .50885 L
.7591 .49059 L
.79413 .46836 L
.83448 .44148 L
.88098 .40912 L
.93462 .37036 L
.99653 .32409 L
s
.99653 .32409 m
1 .32141 L
s
.37 1 0 r
.56524 .42676 m
.57602 .41557 L
.58856 .40261 L
.60313 .38758 L
.62008 .37016 L
.63978 .34995 L
.66269 .32652 L
.68932 .29934 L
.72027 .26781 L
.75624 .23122 L
.79806 .18876 L
.84666 .13949 L
.90314 .08229 L
.96879 .0159 L
s
.96879 .0159 m
.98453 0 L
s
0 1 .045 r
.5265 .42287 m
.53218 .41459 L
.53886 .40518 L
.5467 .39448 L
.55588 .38228 L
.56664 .36835 L
.57922 .35244 L
.59393 .33423 L
.61111 .31336 L
.63118 .28941 L
.65461 .26192 L
.68193 .23031 L
.7138 .19394 L
.75095 .15206 L
.79425 .1038 L
.84468 .04813 L
s
.84468 .04813 m
.8887 0 L
s
.625 1 0 r
.55733 .56383 m
.56325 .56412 L
.56997 .56393 L
.57759 .56318 L
.58626 .56173 L
.59613 .55945 L
.60739 .55616 L
.62024 .55169 L
.63495 .5458 L
.65179 .53822 L
.67111 .52865 L
.69328 .51673 L
.71875 .50202 L
.74805 .48404 L
.78178 .46221 L
.82064 .43586 L
.86544 .40421 L
.91712 .36635 L
.97679 .32122 L
s
.97679 .32122 m
1 .30315 L
s
.697 1 0 r
.54557 .51156 m
.55137 .50869 L
.55802 .50512 L
.56566 .50071 L
.57446 .49532 L
.58458 .48878 L
.59624 .48088 L
.60968 .47139 L
.62519 .46004 L
.64309 .44651 L
.66377 .43042 L
.68768 .41135 L
.71531 .38879 L
.74728 .36216 L
.78427 .33078 L
.8271 .29385 L
.87669 .25046 L
.93414 .19953 L
s
.93414 .19953 m
1 .14045 L
s
1 0 .545 r
.52426 .46322 m
.52853 .45831 L
.53351 .45266 L
.53932 .44614 L
.54608 .43863 L
.55396 .42997 L
.56314 .41996 L
.57383 .40841 L
.58626 .39506 L
.60074 .37963 L
.61759 .36178 L
.63719 .34112 L
.65999 .31721 L
.68651 .28952 L
.71736 .25744 L
.75323 .22028 L
.79494 .1772 L
.84344 .12727 L
.89983 .06938 L
.96539 .00225 L
s
.96539 .00225 m
.96759 0 L
s
0 1 .755 r
.44287 .43957 m
.43687 .43954 L
.43007 .44 L
.42234 .44107 L
.41355 .44286 L
.40353 .44552 L
.39209 .44922 L
.37901 .45416 L
.36404 .46057 L
.34689 .46874 L
.32721 .47896 L
.3046 .49163 L
.27861 .50718 L
.2487 .5261 L
.21426 .549 L
.17456 .57656 L
.12877 .60959 L
.07592 .64902 L
.0149 .69594 L
s
.0149 .69594 m
0 .70771 L
s
0 .548 1 r
.48286 .55855 m
.47894 .56459 L
.47433 .57143 L
.46891 .57919 L
.46255 .58802 L
.45509 .59807 L
.44636 .60954 L
.43613 .62263 L
.42417 .6376 L
.41019 .65475 L
.39386 .6744 L
.3748 .69697 L
.35255 .72289 L
.32661 .75271 L
.29635 .78703 L
.26109 .82657 L
.22001 .87215 L
.17215 .92473 L
.11641 .98543 L
s
.11641 .98543 m
.10293 1 L
s
.336 1 0 r
.50865 .57068 m
.50786 .57554 L
.50682 .58085 L
.5055 .58667 L
.50385 .59305 L
.50179 .60008 L
.49926 .60783 L
.49618 .6164 L
.49245 .6259 L
.48796 .63646 L
.48257 .64822 L
.47614 .66137 L
.46848 .67608 L
.45938 .69259 L
.44861 .71115 L
.43587 .73208 L
.42085 .75571 L
.40316 .78245 L
.38236 .81277 L
.35793 .8472 L
.32927 .88638 L
.29568 .93103 L
.25634 .98199 L
s
.25634 .98199 m
.24211 1 L
s
.753 0 1 r
.48436 .5175 m
.48178 .52018 L
.47877 .52328 L
.47528 .52688 L
.47122 .53105 L
.4665 .53589 L
.46101 .5415 L
.45463 .54801 L
.44722 .55556 L
.4386 .56432 L
.42858 .57448 L
.41694 .58628 L
.40341 .59998 L
.38769 .61588 L
.36941 .63433 L
.34817 .65576 L
.3235 .68064 L
.29482 .70954 L
.26149 .74308 L
.22277 .78204 L
.17777 .82729 L
.12548 .87984 L
.06472 .94087 L
s
.06472 .94087 m
.00583 1 L
s
0 .385 1 r
.42191 .4508 m
.41279 .45339 L
.40237 .45694 L
.39046 .46164 L
.37682 .4677 L
.36119 .47536 L
.34324 .48493 L
.32262 .49674 L
.29891 .51119 L
.27161 .52875 L
.24017 .54996 L
.20392 .57544 L
.1621 .60595 L
.11383 .64233 L
.05808 .68558 L
s
.05808 .68558 m
0 .73181 L
s
0 .287 1 r
.54538 .57515 m
.54939 .57732 L
.55388 .57933 L
.55891 .58112 L
.56458 .58264 L
.57096 .5838 L
.57817 .58453 L
.58632 .58472 L
.59556 .58425 L
.60605 .58297 L
.61799 .58073 L
.6316 .57731 L
.64712 .5725 L
.66486 .56602 L
.68515 .55756 L
.70841 .54675 L
.73508 .53316 L
.76571 .51628 L
.80092 .49553 L
.84143 .47023 L
.88807 .43957 L
.94181 .40262 L
s
.94181 .40262 m
1 .36101 L
s
1 .599 0 r
.52808 .43651 m
.53361 .42917 L
.54007 .42079 L
.54764 .41122 L
.55649 .40026 L
.56682 .38771 L
.5789 .37331 L
.59298 .35677 L
.60942 .33775 L
.62859 .31587 L
.65094 .29068 L
.67698 .26165 L
.70731 .22816 L
.74265 .18952 L
.78379 .1449 L
.83169 .09335 L
.88744 .03375 L
s
.88744 .03375 m
.91921 0 L
s
.226 0 1 r
.57542 .55374 m
.58405 .55172 L
.5939 .54884 L
.60515 .5449 L
.61802 .53973 L
.63276 .53308 L
.64966 .52468 L
.66907 .51421 L
.69136 .50132 L
.717 .48555 L
.74652 .46642 L
.78053 .44332 L
.81975 .41559 L
.86499 .38241 L
.91722 .34287 L
.97755 .29587 L
s
.97755 .29587 m
1 .27793 L
s
0 .254 1 r
.43574 .50535 m
.42697 .5111 L
.41686 .51804 L
.40521 .52635 L
.39176 .53629 L
.37623 .54813 L
.35829 .56219 L
.33756 .57885 L
.31358 .59854 L
.28584 .62178 L
.25374 .64915 L
.21657 .68134 L
.17352 .71915 L
.12365 .76352 L
.06586 .81552 L
s
.06586 .81552 m
0 .8754 L
s
0 .488 1 r
.55027 .48272 m
.55749 .47719 L
.56583 .47062 L
.57548 .46285 L
.58664 .45366 L
.59954 .44282 L
.61448 .43005 L
.63178 .41504 L
.65181 .3974 L
.67502 .37672 L
.70191 .35248 L
.73309 .32409 L
.76923 .29088 L
.81113 .25206 L
.85974 .20669 L
.91612 .15372 L
.98153 .09188 L
s
.98153 .09188 m
1 .07433 L
s
1 .789 0 r
.48063 .51134 m
.47771 .51385 L
.47434 .51679 L
.47043 .52024 L
.46591 .52429 L
.46066 .52903 L
.45458 .53458 L
.44753 .54108 L
.43935 .54867 L
.42987 .55754 L
.41886 .5679 L
.4061 .57999 L
.39129 .59408 L
.3741 .61052 L
.35415 .62968 L
.33099 .65201 L
.30411 .67802 L
.2729 .70831 L
.23667 .74358 L
.1946 .78464 L
.14575 .83243 L
.08902 .88804 L
.02315 .95274 L
s
.02315 .95274 m
0 .97551 L
s
.503 0 1 r
.54194 .51199 m
.54723 .50946 L
.55331 .50629 L
.56029 .50236 L
.56831 .49755 L
.57755 .49169 L
.58818 .4846 L
.60044 .47608 L
.61458 .46586 L
.6309 .45366 L
.64975 .43915 L
.67153 .42193 L
.6967 .40155 L
.72582 .37747 L
.75951 .34907 L
.79851 .31564 L
.84366 .27634 L
.89596 .2302 L
.95656 .17607 L
s
.95656 .17607 m
1 .13684 L
s
0 1 .48 r
.48245 .54778 m
.47877 .55301 L
.47446 .55895 L
.4694 .56572 L
.46348 .57344 L
.45655 .58227 L
.44845 .59236 L
.43898 .60392 L
.42791 .61718 L
.415 .63241 L
.39994 .64991 L
.38236 .67003 L
.36188 .69321 L
.338 .7199 L
.31019 .75069 L
.27778 .78621 L
.24005 .82723 L
.19613 .8746 L
.14499 .92936 L
.08549 .99268 L
s
.08549 .99268 m
.07857 1 L
s
1 0 .805 r
.41816 .54229 m
.40601 .55241 L
.39195 .56434 L
.37568 .57838 L
.35683 .59487 L
.33499 .61423 L
.30969 .63693 L
.28037 .66352 L
.24637 .69463 L
.20696 .73102 L
.16125 .77355 L
.10823 .82323 L
.04672 .88122 L
s
.04672 .88122 m
0 .92552 L
s
.762 0 1 r
.49659 .46345 m
.49714 .46084 L
.49784 .45799 L
.49872 .45485 L
.49979 .4514 L
.50111 .44758 L
.5027 .44335 L
.50463 .43866 L
.50695 .43343 L
.50972 .4276 L
.51303 .42109 L
.51696 .41378 L
.52162 .40557 L
.52713 .39632 L
.53363 .38589 L
.5413 .3741 L
.55032 .36074 L
.56093 .34558 L
.57337 .32834 L
.58796 .30871 L
.60505 .28632 L
.62506 .26075 L
.64845 .2315 L
.67579 .198 L
.70773 .15959 L
.74502 .1155 L
.78852 .06484 L
.83927 .00658 L
s
.83927 .00658 m
.84507 0 L
s
0 1 .18 r
.47768 .47432 m
.4754 .47414 L
.47281 .47414 L
.46988 .47436 L
.46654 .47483 L
.46275 .47562 L
.45842 .47679 L
.45349 .4784 L
.44784 .48055 L
.44138 .48335 L
.43397 .48689 L
.42548 .49133 L
.41572 .49683 L
.40449 .50357 L
.39158 .51177 L
.3767 .52169 L
.35956 .53362 L
.33978 .54792 L
.31696 .56499 L
.2906 .5853 L
.26014 .60939 L
.22493 .63791 L
.18421 .6716 L
.13709 .71133 L
.08254 .7581 L
.01939 .81309 L
s
.01939 .81309 m
0 .8302 L
s
1 .195 0 r
.52284 .56904 m
.524 .5726 L
.52521 .57634 L
.52649 .58027 L
.52782 .58441 L
.52922 .58876 L
.53069 .59334 L
.53223 .59816 L
.53384 .60324 L
.53553 .60858 L
.53729 .6142 L
.53914 .62012 L
.54107 .62635 L
.54309 .63292 L
.5452 .63983 L
.5474 .64712 L
.5497 .6548 L
.55209 .66289 L
.55457 .67143 L
.55716 .68043 L
.55984 .68993 L
.56262 .69996 L
.5655 .71054 L
.56847 .72173 L
.57153 .73354 L
.57467 .74604 L
.57789 .75927 L
.58117 .77327 L
.58451 .7881 L
.58789 .80383 L
.59129 .82051 L
.59468 .83824 L
.59803 .85708 L
.60132 .87713 L
.60449 .89848 L
.6075 .92126 L
.61028 .94559 L
.61276 .97161 L
.61486 .99948 L
s
.61486 .99948 m
.61489 1 L
s
1 0 .522 r
.44671 .56192 m
.43785 .57122 L
.42754 .58199 L
.41555 .59447 L
.4016 .60893 L
.38539 .62569 L
.36653 .64511 L
.34461 .66763 L
.31912 .69374 L
.2895 .72403 L
.25506 .75916 L
.21502 .79993 L
.16849 .84722 L
.11441 .90211 L
.05155 .96582 L
s
.05155 .96582 m
.01778 1 L
s
0 .654 1 r
.49099 .48551 m
.49018 .48512 L
.48928 .48475 L
.48826 .48444 L
.48712 .48419 L
.48582 .48401 L
.48436 .48392 L
.48271 .48395 L
.48083 .48411 L
.4787 .48445 L
.47627 .48499 L
.4735 .48577 L
.47034 .48685 L
.46673 .48827 L
.46259 .4901 L
.45784 .49242 L
.45239 .49532 L
.44613 .4989 L
.43893 .50328 L
.43065 .5086 L
.4211 .51503 L
.4101 .52276 L
.3974 .53201 L
.38275 .54305 L
.36583 .55617 L
.34627 .57173 L
.32366 .59013 L
.2975 .61187 L
.26724 .63749 L
.2322 .66764 L
.19163 .70307 L
.14463 .74467 L
.09018 .79344 L
.02708 .85058 L
s
.02708 .85058 m
0 .87534 L
s
0 .175 1 r
.55818 .51232 m
.56565 .50847 L
.57423 .50369 L
.58408 .49783 L
.59543 .49068 L
.60849 .48204 L
.62355 .47162 L
.64091 .45914 L
.66095 .44423 L
.68409 .42648 L
.71082 .40541 L
.74173 .38047 L
.77747 .35099 L
.81882 .31622 L
.86669 .27529 L
.92211 .22715 L
.98629 .17061 L
s
.98629 .17061 m
1 .15839 L
s
1 .71 0 r
.46155 .42266 m
.45853 .41974 L
.45518 .41685 L
.45147 .414 L
.44733 .41124 L
.44272 .40861 L
.43756 .40614 L
.43177 .40391 L
.42527 .40199 L
.41795 .40045 L
.4097 .3994 L
.40036 .39895 L
.38978 .39924 L
.37777 .40043 L
.36412 .4027 L
.34858 .40629 L
.33085 .41146 L
.3106 .4185 L
.28743 .42777 L
.26091 .4397 L
.23049 .45476 L
.19557 .47354 L
.15545 .4967 L
.10931 .52501 L
.05619 .55938 L
s
.05619 .55938 m
0 .59747 L
s
0 1 .077 r
.575 .44593 m
.58656 .43544 L
.59996 .42317 L
.6155 .40882 L
.63352 .39205 L
.65442 .37246 L
.67867 .34959 L
.7068 .3229 L
.73945 .29178 L
.77734 .25549 L
.82131 .2132 L
.87236 .16392 L
.93162 .10653 L
s
.93162 .10653 m
1 .04009 L
s
1 .361 0 r
.41849 .4531 m
.40885 .45616 L
.39783 .46026 L
.38521 .4656 L
.37076 .4724 L
.35418 .48094 L
.33514 .49153 L
.31325 .50453 L
.28807 .52037 L
.25906 .53955 L
.22564 .56265 L
.18709 .59035 L
.1426 .62343 L
.09123 .6628 L
.03187 .70954 L
s
.03187 .70954 m
0 .73526 L
s
1 0 .702 r
.45956 .44697 m
.4556 .44614 L
.45113 .44557 L
.44608 .44532 L
.44036 .44548 L
.43386 .44613 L
.42647 .44736 L
.41806 .4493 L
.40846 .4521 L
.39751 .45591 L
.38497 .46093 L
.37061 .46738 L
.35415 .47553 L
.33526 .4857 L
.31355 .49823 L
.28857 .51355 L
.25983 .53215 L
.22671 .55461 L
.18852 .58158 L
.14447 .61384 L
.09362 .65231 L
.03487 .69803 L
s
.03487 .69803 m
0 .72586 L
s
1 .86 0 r
.43081 .499 m
.42155 .50466 L
.4109 .51153 L
.39862 .51983 L
.38447 .5298 L
.36814 .54173 L
.34929 .55596 L
.32752 .57287 L
.30236 .59293 L
.27327 .61665 L
.23962 .64465 L
.20068 .67766 L
.1556 .7165 L
.1034 .76214 L
.04293 .81572 L
s
.04293 .81572 m
0 .85421 L
s
1 .262 0 r
.47619 .51536 m
.47256 .51855 L
.46837 .52229 L
.46351 .52667 L
.45788 .5318 L
.45134 .53781 L
.44377 .54482 L
.43498 .55302 L
.42479 .5626 L
.41297 .57378 L
.39925 .58681 L
.38333 .60202 L
.36486 .61974 L
.34341 .6404 L
.31852 .66446 L
.28962 .69249 L
.25607 .72512 L
.21711 .76312 L
.17188 .80734 L
.11935 .8588 L
.05835 .91868 L
s
.05835 .91868 m
0 .97606 L
s
.935 0 1 r
.44292 .52226 m
.43464 .52875 L
.42508 .53644 L
.41401 .54553 L
.40122 .55626 L
.38641 .56889 L
.36926 .58374 L
.3494 .60119 L
.32639 .62166 L
.29973 .64566 L
.26883 .67376 L
.23301 .70664 L
.19147 .74509 L
.14329 .79001 L
.0874 .84248 L
.02257 .90372 L
s
.02257 .90372 m
0 .92515 L
s
1 0 .527 r
.55236 .50426 m
.55927 .50026 L
.56721 .49536 L
.57636 .48942 L
.5869 .48226 L
.59905 .47365 L
.61307 .46336 L
.62926 .45109 L
.64796 .43651 L
.66957 .41923 L
.69456 .3988 L
.72346 .37468 L
.75691 .34626 L
.79564 .31282 L
.84048 .27354 L
.89243 .22743 L
.95263 .17338 L
s
.95263 .17338 m
1 .1304 L
s
1 .13 0 r
.55148 .4998 m
.5584 .49552 L
.56636 .49032 L
.57553 .48405 L
.58611 .47653 L
.59831 .46754 L
.6124 .45683 L
.62868 .4441 L
.64749 .42902 L
.66925 .41119 L
.69441 .39014 L
.72354 .36535 L
.75726 .33619 L
.79631 .30193 L
.84155 .26173 L
.89397 .21461 L
.95472 .15942 L
s
.95472 .15942 m
1 .1179 L
s
1 0 .201 r
.52814 .53374 m
.53098 .53407 L
.5342 .53418 L
.53784 .53405 L
.54198 .53359 L
.54669 .53276 L
.55205 .53148 L
.55816 .52965 L
.56515 .52716 L
.57314 .5239 L
.58229 .51973 L
.59279 .51446 L
.60484 .50791 L
.61869 .49984 L
.63462 .48998 L
.65297 .47803 L
.6741 .46361 L
.69847 .4463 L
.72659 .4256 L
.75905 .40094 L
.79655 .37165 L
.8399 .33693 L
.89002 .29587 L
.948 .24742 L
s
.948 .24742 m
1 .20318 L
s
1 .19 0 r
.55389 .52048 m
.56056 .51763 L
.5682 .514 L
.57696 .50945 L
.58703 .50381 L
.5986 .49689 L
.61192 .48847 L
.62726 .47828 L
.64494 .46601 L
.66532 .45131 L
.68886 .43376 L
.71603 .41288 L
.74743 .38809 L
.78372 .35874 L
.8257 .32407 L
.87427 .28317 L
.93049 .23503 L
.99558 .17842 L
s
.99558 .17842 m
1 .17453 L
s
1 .277 0 r
.43349 .51694 m
.42409 .5238 L
.41325 .53197 L
.40072 .54169 L
.38625 .55321 L
.36951 .56684 L
.35016 .58293 L
.32776 .6019 L
.30183 .62423 L
.2718 .65046 L
.23702 .68126 L
.19672 .71737 L
.15001 .75967 L
.09586 .80919 L
.03309 .8671 L
s
.03309 .8671 m
0 .89786 L
s
.735 0 1 r
.54027 .44711 m
.54714 .4396 L
.55513 .43092 L
.56444 .4209 L
.57527 .40932 L
.58788 .39592 L
.60255 .38042 L
.61962 .36248 L
.63947 .34171 L
.66256 .31765 L
.68942 .28978 L
.72065 .25748 L
.75696 .22005 L
.79918 .17665 L
.84826 .12633 L
.90533 .06796 L
.97166 .00026 L
s
.97166 .00026 m
.97191 0 L
s
.317 1 0 r
.46789 .4177 m
.46586 .41387 L
.46366 .40991 L
.46127 .40581 L
.45868 .40159 L
.45585 .39725 L
.45277 .3928 L
.44939 .38826 L
.44569 .38364 L
.44162 .37896 L
.43713 .37425 L
.43217 .36954 L
.42667 .36487 L
.42057 .36029 L
.41377 .35585 L
.40619 .35162 L
.3977 .34769 L
.38818 .34416 L
.37748 .34113 L
.36543 .33876 L
.35183 .33719 L
.33645 .33663 L
.31901 .3373 L
.29922 .33947 L
.27672 .34345 L
.25108 .34961 L
.22184 .35839 L
.18842 .37028 L
.1502 .38588 L
.10641 .40588 L
.0562 .43109 L
s
.0562 .43109 m
0 .46166 L
s
0 .027 1 r
.42899 .46256 m
.42049 .4655 L
.41078 .46937 L
.39965 .47435 L
.38689 .48065 L
.37225 .4885 L
.35542 .49818 L
.33607 .51003 L
.3138 .52441 L
.28813 .54178 L
.25855 .56265 L
.22441 .58761 L
.18501 .61738 L
.1395 .65276 L
.0869 .69471 L
.02608 .74433 L
s
.02608 .74433 m
0 .76604 L
s
0 .322 1 r
.43329 .48506 m
.42475 .48942 L
.41494 .49482 L
.40367 .50147 L
.39071 .50957 L
.37578 .51939 L
.35857 .53122 L
.33873 .54541 L
.31583 .56236 L
.28939 .58256 L
.25885 .60654 L
.22354 .63494 L
.18272 .66851 L
.13548 .70812 L
.08081 .75477 L
.01752 .80963 L
s
.01752 .80963 m
0 .82503 L
s
0 .285 1 r
.42877 .43993 m
.42088 .4411 L
.41189 .44301 L
.40164 .44582 L
.38994 .4497 L
.37656 .45486 L
.36124 .46153 L
.34368 .47 L
.32353 .4806 L
.30039 .4937 L
.27378 .50976 L
.24315 .52928 L
.20787 .55289 L
.16721 .58129 L
.12031 .6153 L
.06617 .65589 L
.00364 .70416 L
s
.00364 .70416 m
0 .70705 L
s
1 .283 0 r
.49284 .57223 m
.48988 .57852 L
.48636 .58556 L
.48216 .59344 L
.47718 .6023 L
.47129 .61226 L
.46434 .6235 L
.45614 .6362 L
.44649 .65059 L
.43514 .66691 L
.42183 .68546 L
.40621 .70657 L
.38792 .73065 L
.3665 .75815 L
.34145 .78959 L
.31217 .82559 L
.27796 .86686 L
.23803 .91422 L
.19142 .96863 L
s
.19142 .96863 m
.16416 1 L
s
.584 0 1 r
.52523 .56087 m
.52694 .56358 L
.5288 .56637 L
.53083 .56921 L
.53305 .57212 L
.53549 .57507 L
.53818 .57805 L
.54114 .58105 L
.54443 .58403 L
.54806 .58698 L
.55211 .58985 L
.55662 .59262 L
.56166 .59524 L
.5673 .59764 L
.57363 .59976 L
.58075 .60153 L
.58878 .60285 L
.59786 .6036 L
.60812 .60366 L
.61977 .60288 L
.633 .60106 L
.64805 .59801 L
.66521 .59347 L
.68479 .58714 L
.70718 .5787 L
.73281 .56773 L
.76218 .55377 L
.79588 .53627 L
.83458 .5146 L
.87907 .488 L
.93028 .45562 L
.98924 .41644 L
s
.98924 .41644 m
1 .40898 L
s
.356 1 0 r
.55911 .44614 m
.56854 .43699 L
.57947 .42633 L
.59218 .41393 L
.60692 .39949 L
.62405 .3827 L
.64394 .36315 L
.66704 .34042 L
.69386 .31398 L
.72502 .28322 L
.76121 .24745 L
.80324 .20587 L
.85207 .15751 L
.90878 .10129 L
.97465 .03593 L
s
.97465 .03593 m
1 .01076 L
s
1 .515 0 r
.41907 .43734 m
.40995 .43911 L
.39955 .44177 L
.38767 .44551 L
.37411 .45052 L
.35858 .45706 L
.34079 .4654 L
.32038 .47587 L
.29694 .48886 L
.27 .50482 L
.23901 .52427 L
.20331 .54783 L
.16218 .5762 L
.11474 .61023 L
.05999 .65087 L
s
.05999 .65087 m
0 .6968 L
s
0 1 .599 r
.48868 .56654 m
.48532 .57273 L
.48134 .57969 L
.47664 .58752 L
.47108 .59637 L
.46454 .60637 L
.45684 .6177 L
.44779 .63057 L
.43718 .6452 L
.42473 .66187 L
.41016 .68089 L
.3931 .70261 L
.37316 .72746 L
.34985 .75593 L
.32262 .78858 L
.29085 .82606 L
.25377 .86913 L
.21052 .91868 L
.1601 .97572 L
s
.1601 .97572 m
.1384 1 L
s
0 .984 1 r
.56971 .50996 m
.57879 .50497 L
.58923 .49883 L
.60123 .49134 L
.61506 .48226 L
.63099 .47132 L
.64936 .45819 L
.67056 .44251 L
.69503 .42383 L
.72331 .40165 L
.756 .37537 L
.79379 .34431 L
.83752 .30766 L
.88813 .26449 L
.94673 .21372 L
s
.94673 .21372 m
1 .16691 L
s
.527 1 0 r
.45107 .48409 m
.44495 .48689 L
.43792 .49043 L
.42985 .49482 L
.42059 .50023 L
.40992 .50683 L
.39765 .51484 L
.3835 .5245 L
.36719 .53609 L
.34837 .54995 L
.32664 .56646 L
.30154 .58608 L
.27253 .60933 L
.23898 .63682 L
.20017 .66927 L
.15526 .70749 L
.10326 .75245 L
.04304 .80527 L
s
.04304 .80527 m
0 .84351 L
s
1 .15 0 r
.47205 .43212 m
.47017 .42908 L
.46813 .42596 L
.4659 .42276 L
.46346 .41949 L
.46078 .41616 L
.45784 .4128 L
.45459 .40942 L
.451 .40603 L
.44702 .40268 L
.4426 .39939 L
.43768 .39621 L
.43219 .39319 L
.42604 .39039 L
.41915 .38787 L
.4114 .38573 L
.40266 .38406 L
.39281 .38298 L
.38166 .38263 L
.36902 .38318 L
.35467 .38483 L
.33836 .38779 L
.31977 .39234 L
.29856 .39879 L
.27432 .4075 L
.24659 .41892 L
.21483 .43353 L
.1784 .45193 L
.13657 .47481 L
.08849 .50296 L
.03319 .53732 L
s
.03319 .53732 m
0 .55903 L
s
.185 0 1 r
.54873 .48403 m
.55571 .47872 L
.56377 .47243 L
.57309 .46496 L
.58387 .45614 L
.59634 .44572 L
.61077 .43345 L
.62747 .41901 L
.64682 .40205 L
.66923 .38214 L
.69519 .35881 L
.72529 .33148 L
.76018 .29951 L
.80063 .26211 L
.84755 .21841 L
.90198 .16737 L
.96511 .10779 L
s
.96511 .10779 m
1 .07468 L
s
.574 0 1 r
.58312 .5607 m
.5926 .5586 L
.60341 .55555 L
.61575 .55135 L
.62986 .54581 L
.64602 .53866 L
.66455 .5296 L
.68581 .51829 L
.71024 .50432 L
.73833 .48723 L
.77067 .46646 L
.80791 .44137 L
.85085 .41121 L
.90039 .37511 L
.95757 .33205 L
s
.95757 .33205 m
1 .29917 L
s
1 .175 0 r
.47622 .50383 m
.47292 .50611 L
.46912 .50884 L
.46473 .51209 L
.45966 .51597 L
.45381 .52058 L
.44704 .52603 L
.43921 .53248 L
.43016 .54008 L
.41968 .54904 L
.40754 .55957 L
.39349 .57193 L
.37721 .58644 L
.35834 .60345 L
.33647 .62336 L
.31112 .64665 L
.28172 .67388 L
.24762 .70571 L
.20807 .74287 L
.16218 .78624 L
.10894 .83684 L
.04715 .89585 L
s
.04715 .89585 m
0 .94107 L
s
1 0 .73 r
.51313 .53761 m
.51385 .53948 L
.51462 .54145 L
.51543 .54351 L
.5163 .54567 L
.51722 .54792 L
.51821 .55027 L
.51927 .55273 L
.52039 .55529 L
.5216 .55796 L
.5229 .56075 L
.52429 .56364 L
.52579 .56665 L
.52741 .56977 L
.52916 .573 L
.53106 .57634 L
.53311 .57979 L
.53535 .58334 L
.53779 .58699 L
.54046 .59072 L
.54338 .59452 L
.54659 .59838 L
.55012 .60228 L
.55402 .6062 L
.55834 .6101 L
.56312 .61395 L
.56844 .61771 L
.57437 .62132 L
.581 .62473 L
.58842 .62785 L
.59675 .63061 L
.60613 .6329 L
.61669 .63458 L
.62863 .63553 L
.64215 .63555 L
.65748 .63446 L
.6749 .63202 L
.69472 .62793 L
.71731 .62188 L
.7431 .61348 L
.77259 .60227 L
.80634 .58774 L
.84503 .56926 L
.88941 .54612 L
.94039 .51747 L
.99901 .48232 L
s
.99901 .48232 m
1 .4817 L
s
1 0 .463 r
.48294 .45724 m
.48183 .45528 L
.48063 .45326 L
.47932 .45118 L
.4779 .44904 L
.47634 .44685 L
.47464 .44462 L
.47276 .44236 L
.4707 .44006 L
.46843 .43776 L
.46591 .43547 L
.46312 .43321 L
.46001 .43099 L
.45656 .42887 L
.45269 .42685 L
.44836 .42501 L
.44351 .42337 L
.43805 .42201 L
.43189 .42099 L
.42493 .4204 L
.41706 .42035 L
.40813 .42094 L
.39799 .42232 L
.38644 .42465 L
.37329 .42812 L
.35827 .43295 L
.34111 .43941 L
.32146 .44781 L
.29894 .45849 L
.27311 .47189 L
.24344 .48849 L
.20933 .50885 L
.17008 .53365 L
.12487 .56367 L
.07277 .5998 L
.01268 .6431 L
s
.01268 .6431 m
0 .65256 L
s
.745 1 0 r
.47717 .45981 m
.47522 .45853 L
.47304 .45731 L
.4706 .45618 L
.46787 .45516 L
.4648 .45428 L
.46134 .45359 L
.45743 .45314 L
.45302 .45297 L
.44801 .45315 L
.44233 .45377 L
.43587 .4549 L
.42851 .45666 L
.42012 .45917 L
.41052 .46257 L
.39955 .46704 L
.38698 .47276 L
.37257 .47999 L
.35602 .48897 L
.33701 .50004 L
.31513 .51356 L
.28995 .52996 L
.26093 .54975 L
.22748 .57349 L
.18887 .60189 L
.14431 .63573 L
.09282 .67594 L
.03332 .72359 L
s
.03332 .72359 m
0 .75087 L
s
1 .804 0 r
.5129 .53707 m
.51361 .53892 L
.51436 .54087 L
.51515 .5429 L
.516 .54503 L
.5169 .54726 L
.51786 .54958 L
.51889 .55201 L
.51999 .55455 L
.52116 .5572 L
.52242 .55996 L
.52377 .56283 L
.52523 .56582 L
.52679 .56892 L
.52848 .57214 L
.53031 .57547 L
.53229 .57891 L
.53445 .58246 L
.53679 .58611 L
.53935 .58985 L
.54214 .59368 L
.54521 .59758 L
.54858 .60153 L
.55229 .60551 L
.55639 .6095 L
.56093 .61347 L
.56597 .61737 L
.57158 .62116 L
.57784 .62478 L
.58484 .62817 L
.59268 .63125 L
.60149 .63393 L
.61141 .63608 L
.62259 .63758 L
.63524 .63827 L
.64957 .63797 L
.66583 .63645 L
.68431 .63347 L
.70535 .62872 L
.72935 .62185 L
.75676 .61244 L
.78811 .60002 L
.82401 .58403 L
.86516 .56379 L
.9124 .53854 L
.96668 .50739 L
s
.96668 .50739 m
1 .48704 L
s
.605 0 1 r
.5673 .48929 m
.57663 .48286 L
.58739 .47515 L
.5998 .46595 L
.61414 .45498 L
.6307 .44197 L
.64984 .42655 L
.67198 .40833 L
.69759 .38683 L
.72723 .36152 L
.76155 .33175 L
.8013 .29678 L
.84735 .25576 L
.90072 .20768 L
.96257 .15139 L
s
.96257 .15139 m
1 .11701 L
s
.115 1 0 r
.54573 .50088 m
.55184 .49716 L
.55887 .49264 L
.56698 .48718 L
.57632 .48061 L
.58709 .47275 L
.59954 .46338 L
.6139 .45224 L
.63051 .43902 L
.64971 .42339 L
.67192 .40493 L
.69761 .38317 L
.72736 .35757 L
.76181 .32747 L
.80171 .29215 L
.84794 .25073 L
.90153 .20221 L
.96364 .14541 L
s
.96364 .14541 m
1 .11187 L
s
0 .217 1 r
.48567 .50549 m
.4836 .50711 L
.4812 .50903 L
.47843 .5113 L
.47522 .51398 L
.47151 .51714 L
.46721 .52086 L
.46223 .52522 L
.45647 .53034 L
.44979 .53635 L
.44204 .54338 L
.43307 .55161 L
.42266 .56123 L
.41059 .57248 L
.39658 .58561 L
.38034 .60094 L
.36149 .61883 L
.33962 .63969 L
.31424 .66401 L
.28478 .69236 L
.25058 .72538 L
.21088 .76385 L
.16479 .80865 L
.11127 .8608 L
.04914 .92151 L
s
.04914 .92151 m
0 .96962 L
s
0 .599 1 r
.51432 .58327 m
.51394 .58865 L
.51337 .59449 L
.51255 .60084 L
.51144 .60775 L
.51 .61531 L
.50816 .62358 L
.50583 .63265 L
.50295 .64264 L
.4994 .65365 L
.49508 .66582 L
.48983 .67931 L
.48351 .69431 L
.47593 .71101 L
.46687 .72966 L
.45607 .75053 L
.44325 .77394 L
.42807 .80026 L
.41011 .82992 L
.38893 .86341 L
.36398 .90129 L
.33464 .94424 L
.30017 .99301 L
s
.30017 .99301 m
.29507 1 L
s
.98 0 1 r
.52774 .54525 m
.53021 .54652 L
.53298 .54769 L
.53609 .54872 L
.53958 .54957 L
.54353 .5502 L
.54798 .55055 L
.55302 .55056 L
.55874 .55015 L
.56523 .54924 L
.57263 .54771 L
.58105 .54546 L
.59067 .54232 L
.60167 .53814 L
.61426 .53272 L
.62869 .52583 L
.64525 .5172 L
.66426 .50651 L
.68613 .4934 L
.71128 .47745 L
.74026 .45815 L
.77366 .43492 L
.81218 .4071 L
.85664 .37388 L
.90799 .33435 L
.96731 .28745 L
s
.96731 .28745 m
1 .26099 L
s
.599 0 1 r
.51082 .43648 m
.51403 .43057 L
.51783 .42392 L
.52233 .41644 L
.52763 .408 L
.53388 .39844 L
.54124 .38762 L
.54988 .37533 L
.56002 .36136 L
.5719 .34544 L
.58583 .32728 L
.60212 .30653 L
.62117 .2828 L
.64343 .25561 L
.66944 .22443 L
.69979 .18864 L
.73521 .1475 L
.77651 .10018 L
.82467 .0457 L
s
.82467 .0457 m
.86553 0 L
s
1 .611 0 r
.51334 .56024 m
.51346 .56388 L
.5135 .56781 L
.51344 .57204 L
.51325 .57661 L
.51291 .58156 L
.51239 .58692 L
.51165 .59275 L
.51065 .59911 L
.50934 .60604 L
.50767 .61364 L
.50555 .62197 L
.50293 .63113 L
.4997 .64124 L
.49575 .65241 L
.49097 .66479 L
.4852 .67854 L
.47828 .69386 L
.47001 .71095 L
.46015 .73009 L
.44845 .75155 L
.43458 .77567 L
.41818 .80285 L
.39883 .83354 L
.37603 .86825 L
.34921 .90758 L
.31771 .95225 L
s
.31771 .95225 m
.28297 1 L
s
0 .033 1 r
.42339 .53674 m
.41209 .546 L
.39902 .55691 L
.3839 .56978 L
.36639 .58491 L
.34612 .60269 L
.32263 .62356 L
.29541 .64801 L
.26387 .67666 L
.22729 .71018 L
.18489 .74938 L
.13571 .79519 L
.07867 .84869 L
.01249 .91114 L
s
.01249 .91114 m
0 .92299 L
s
0 1 .801 r
.54738 .50553 m
.55359 .50204 L
.56072 .49776 L
.56893 .49255 L
.57839 .48624 L
.58928 .47866 L
.60186 .46957 L
.61637 .45872 L
.63312 .44582 L
.65248 .4305 L
.67487 .41238 L
.70075 .39096 L
.73071 .36571 L
.76538 .33598 L
.80553 .30103 L
.85203 .26 L
.9059 .21187 L
.96833 .15547 L
s
.96833 .15547 m
1 .12658 L
s
0 1 .317 r
.44663 .49649 m
.43956 .50064 L
.43143 .5057 L
.42207 .51184 L
.41129 .51923 L
.39885 .52811 L
.3845 .53871 L
.36793 .55134 L
.34879 .56635 L
.32667 .58412 L
.30108 .60513 L
.27148 .62992 L
.23722 .65913 L
.19756 .69347 L
.15163 .73382 L
.09842 .78116 L
.03676 .83665 L
s
.03676 .83665 m
0 .87006 L
s
.432 0 1 r
.5068 .44615 m
.5092 .44133 L
.51205 .43594 L
.51544 .42989 L
.51945 .42307 L
.52419 .41539 L
.52977 .40671 L
.53635 .39688 L
.54408 .38572 L
.55315 .37305 L
.56379 .35863 L
.57626 .34218 L
.59085 .3234 L
.60793 .30193 L
.62788 .27736 L
.6512 .24918 L
.67842 .21685 L
.71019 .17971 L
.74725 .13701 L
.79046 .08786 L
.84083 .03125 L
s
.84083 .03125 m
.86895 0 L
s
1 0 .171 r
.44949 .54715 m
.44141 .55506 L
.43203 .56426 L
.42113 .57497 L
.40847 .58743 L
.39378 .60191 L
.3767 .61877 L
.35688 .63836 L
.33384 .66115 L
.30709 .68764 L
.27602 .71845 L
.23993 .75426 L
.198 .79589 L
.14929 .84428 L
.09271 .90053 L
.02699 .96591 L
s
.02699 .96591 m
0 .99277 L
s
1 0 .365 r
.5017 .43287 m
.50378 .42743 L
.5063 .42139 L
.50932 .41466 L
.51292 .40716 L
.51723 .39876 L
.52234 .38934 L
.52839 .37875 L
.53555 .36683 L
.544 .35338 L
.55396 .33816 L
.56568 .32091 L
.57944 .30133 L
.59559 .27907 L
.61453 .25371 L
.6367 .22477 L
.66266 .19172 L
.693 .15391 L
.72847 .11059 L
.76989 .06092 L
.81825 .00389 L
s
.81825 .00389 m
.82159 0 L
s
.414 1 0 r
.55193 .49905 m
.55893 .49467 L
.56698 .48936 L
.57626 .48297 L
.58697 .4753 L
.59932 .46614 L
.61359 .45523 L
.63007 .44228 L
.64912 .42694 L
.67115 .40881 L
.69664 .38742 L
.72613 .36223 L
.76029 .3326 L
.79984 .29781 L
.84567 .25699 L
.89877 .20915 L
.96033 .15313 L
s
.96033 .15313 m
1 .11669 L
s
.442 1 0 r
.45874 .45643 m
.4544 .45641 L
.44949 .45676 L
.44391 .45753 L
.43755 .45883 L
.43031 .46076 L
.42204 .46344 L
.41259 .46702 L
.40177 .47167 L
.38938 .47758 L
.37515 .48498 L
.35881 .49415 L
.34003 .5054 L
.31841 .51909 L
.29351 .53565 L
.26482 .55559 L
.23172 .57948 L
.19353 .60799 L
.14941 .64193 L
.09844 .6822 L
.03952 .72988 L
s
.03952 .72988 m
0 .76254 L
s
.702 0 1 r
.57983 .43654 m
.5923 .42491 L
.60676 .41134 L
.62354 .39549 L
.643 .377 L
.66559 .35543 L
.69181 .33029 L
.72224 .30099 L
.75757 .26686 L
.79857 .22711 L
.84618 .18081 L
.90146 .12692 L
.96565 .06419 L
s
.96565 .06419 m
1 .03054 L
s
1 0 .88 r
.56893 .43165 m
.58007 .42054 L
.59301 .40763 L
.60805 .39263 L
.62551 .3752 L
.64581 .35494 L
.66938 .33141 L
.69677 .30406 L
.72859 .27228 L
.76556 .23535 L
.80851 .19245 L
.85841 .1426 L
.91639 .08467 L
.98375 .01737 L
s
.98375 .01737 m
1 .00113 L
s
.648 1 0 r
.4959 .51693 m
.49488 .51861 L
.49368 .5205 L
.49227 .52265 L
.4906 .52507 L
.48865 .52783 L
.48636 .53097 L
.48367 .53454 L
.48052 .53862 L
.47684 .54329 L
.47254 .54862 L
.46751 .55474 L
.46164 .56175 L
.45478 .56981 L
.44678 .57906 L
.43746 .58972 L
.42658 .60198 L
.41391 .61612 L
.39915 .63242 L
.38196 .65123 L
.36193 .67295 L
.33863 .69805 L
.3115 .72706 L
.27992 .76061 L
.24319 .79942 L
.20045 .84435 L
.15073 .89636 L
.09291 .9566 L
s
.09291 .9566 m
.05109 1 L
s
0 1 .681 r
.45071 .52863 m
.4433 .53498 L
.43473 .54244 L
.4248 .5512 L
.41329 .56148 L
.39995 .57352 L
.3845 .58762 L
.36657 .60411 L
.34579 .62339 L
.32169 .64591 L
.29373 .67221 L
.26129 .70291 L
.22364 .73871 L
.17996 .78047 L
.12926 .82914 L
.07041 .88585 L
.0021 .95192 L
s
.0021 .95192 m
0 .95396 L
s
1 .628 0 r
.4399 .54308 m
.43065 .55146 L
.41992 .56128 L
.40748 .57275 L
.39305 .58616 L
.37632 .60183 L
.35691 .62012 L
.33438 .64147 L
.30825 .66637 L
.27792 .69539 L
.24272 .72923 L
.20185 .76865 L
.15442 .81457 L
.09935 .86805 L
.03541 .93032 L
s
.03541 .93032 m
0 .96489 L
s
1 0 .665 r
.54275 .52394 m
.54783 .52229 L
.55363 .52008 L
.56027 .51722 L
.56788 .51358 L
.57661 .50902 L
.58665 .50338 L
.59818 .49647 L
.61145 .48805 L
.62674 .47786 L
.64436 .4656 L
.66468 .45092 L
.68814 .43339 L
.71522 .41253 L
.74652 .38779 L
.78271 .35849 L
.82455 .32388 L
.87298 .28307 L
.92902 .23502 L
.99392 .17854 L
s
.99392 .17854 m
1 .17317 L
s
0 1 .347 r
.41953 .46733 m
.40964 .47142 L
.3983 .47666 L
.3853 .48325 L
.37037 .49144 L
.35321 .50151 L
.33347 .5138 L
.31075 .5287 L
.28456 .54666 L
.25436 .56821 L
.21951 .59396 L
.17927 .62463 L
.13278 .66106 L
.07905 .70422 L
.01692 .75525 L
s
.01692 .75525 m
0 .76942 L
s
0 1 .529 r
.57824 .57005 m
.5868 .56909 L
.59654 .56735 L
.60763 .56466 L
.62029 .56084 L
.63475 .55566 L
.65129 .54888 L
.67024 .54019 L
.69197 .52925 L
.71693 .51564 L
.74561 .49888 L
.7786 .47843 L
.81658 .45363 L
.86034 .42371 L
.91081 .38781 L
.96904 .3449 L
s
.96904 .3449 m
1 .32134 L
s
0 1 .597 r
.51911 .53523 m
.5207 .53643 L
.52247 .53759 L
.52444 .53869 L
.52665 .53971 L
.52913 .54064 L
.53192 .54143 L
.53505 .54205 L
.5386 .54246 L
.5426 .54261 L
.54714 .54244 L
.55229 .54188 L
.55815 .54085 L
.56483 .53926 L
.57244 .53698 L
.58114 .53389 L
.59109 .52983 L
.60249 .52463 L
.61557 .51808 L
.63058 .50992 L
.64782 .49988 L
.66766 .48761 L
.69051 .47273 L
.71682 .45478 L
.74717 .43323 L
.78219 .40747 L
.82261 .37677 L
.86931 .34029 L
.92328 .29706 L
.98569 .24595 L
s
.98569 .24595 m
1 .234 L
s
1 .375 0 r
.54037 .44023 m
.54744 .43217 L
.55568 .42288 L
.56528 .41218 L
.57647 .39983 L
.5895 .38559 L
.60467 .36914 L
.62234 .35013 L
.6429 .32816 L
.66682 .30275 L
.69466 .27335 L
.72705 .23933 L
.76472 .19993 L
.80854 .1543 L
.8595 .10143 L
.91876 .04017 L
s
.91876 .04017 m
.95774 0 L
s
0 1 .715 r
.44457 .52083 m
.43655 .52707 L
.42729 .53446 L
.41658 .54321 L
.40419 .55354 L
.38985 .56571 L
.37326 .58003 L
.35404 .59686 L
.33177 .6166 L
.30597 .63975 L
.27607 .66687 L
.24141 .69861 L
.20122 .73572 L
.15461 .7791 L
.10055 .82976 L
.03783 .88891 L
s
.03783 .88891 m
0 .92479 L
s
0 1 .828 r
.52686 .55855 m
.52885 .56095 L
.53103 .56337 L
.53345 .56579 L
.53612 .56821 L
.53908 .5706 L
.54237 .57293 L
.54604 .57517 L
.55014 .57728 L
.55473 .57923 L
.55989 .58094 L
.56569 .58236 L
.57223 .58341 L
.57961 .584 L
.58798 .58403 L
.59746 .58337 L
.60823 .58186 L
.62049 .57935 L
.63447 .57562 L
.65042 .57044 L
.66866 .56352 L
.68954 .55455 L
.71347 .54314 L
.74092 .52884 L
.77246 .51114 L
.80871 .48942 L
.85043 .46299 L
.89848 .43101 L
.95386 .39252 L
s
.95386 .39252 m
1 .35921 L
s
1 .566 0 r
.4994 .49706 m
.4994 .49688 L
.49941 .49668 L
.49942 .49647 L
.49944 .49623 L
.49947 .49598 L
.49951 .49571 L
.49957 .49541 L
.49963 .49509 L
.49972 .49473 L
.49983 .49434 L
.49996 .4939 L
.50013 .49343 L
.50032 .4929 L
.50056 .49231 L
.50085 .49166 L
.5012 .49093 L
.50161 .49011 L
.5021 .4892 L
.50268 .48817 L
.50337 .48701 L
.50418 .48571 L
.50513 .48424 L
.50626 .48257 L
.50758 .48067 L
.50913 .47852 L
.51095 .47607 L
.51308 .47327 L
.51557 .47008 L
.51849 .46642 L
.5219 .46224 L
.52588 .45745 L
.53053 .45194 L
.53596 .44562 L
.54228 .43835 L
.54966 .42997 L
.55826 .42033 L
.56828 .40921 L
.57995 .39639 L
.59355 .38158 L
.60937 .36448 L
.6278 .34471 L
.64924 .32186 L
.67419 .29543 L
.70322 .26484 L
.73699 .22944 L
.77627 .18843 L
.82196 .14094 L
.87509 .08591 L
.93687 .02213 L
Mistroke
Mfstroke
.93687 .02213 m
.95836 0 L
s
0 .179 1 r
.46511 .51365 m
.46005 .51762 L
.45421 .52232 L
.44744 .52788 L
.43962 .53444 L
.43057 .54216 L
.42008 .55124 L
.40794 .56191 L
.39388 .57443 L
.37758 .58911 L
.35869 .60629 L
.33679 .6264 L
.31139 .64991 L
.28194 .67737 L
.24777 .70945 L
.20813 .7469 L
.16214 .79058 L
.10877 .84153 L
.04683 .90092 L
s
.04683 .90092 m
0 .94601 L
s
0 .283 1 r
.52734 .44281 m
.53258 .43603 L
.53873 .42828 L
.5459 .41941 L
.55429 .40925 L
.56409 .39758 L
.57552 .38419 L
.58885 .36879 L
.6044 .35106 L
.62253 .33065 L
.64365 .30713 L
.66826 .28 L
.69692 .24869 L
.73029 .21252 L
.76914 .17074 L
.81436 .12244 L
.86698 .06658 L
.92821 .00195 L
s
.92821 .00195 m
.93006 0 L
s
0 .179 1 r
.50871 .57865 m
.5077 .58413 L
.50641 .59013 L
.50478 .59671 L
.50275 .60395 L
.50024 .61192 L
.49718 .62073 L
.49347 .63049 L
.48898 .64133 L
.4836 .6534 L
.47716 .66687 L
.46948 .68193 L
.46035 .69881 L
.44954 .71779 L
.43675 .73916 L
.42165 .76328 L
.40386 .79055 L
.38293 .82145 L
.35833 .85653 L
.32946 .89641 L
.29562 .94183 L
.25598 .99364 L
s
.25598 .99364 m
.251 1 L
s
.138 1 0 r
.56296 .50758 m
.5712 .50296 L
.58068 .49729 L
.59158 .49038 L
.60413 .48203 L
.6186 .47198 L
.6353 .45993 L
.65456 .44555 L
.6768 .42844 L
.70251 .40813 L
.73222 .38408 L
.76659 .35568 L
.80635 .32219 L
.85238 .28275 L
.90567 .23639 L
.9674 .18195 L
s
.9674 .18195 m
1 .15283 L
s
0 1 .834 r
.45215 .46278 m
.44676 .46381 L
.44062 .46536 L
.43361 .46756 L
.42559 .4705 L
.41642 .47434 L
.40592 .47925 L
.39387 .48541 L
.38003 .49306 L
.36412 .50246 L
.34582 .51393 L
.32474 .52781 L
.30045 .54454 L
.27244 .5646 L
.24012 .58857 L
.2028 .61711 L
.15968 .65099 L
.10984 .69113 L
.0522 .73856 L
s
.0522 .73856 m
0 .78236 L
s
1 0 .731 r
.51624 .48457 m
.51884 .48201 L
.52187 .47902 L
.52538 .47556 L
.52947 .47152 L
.53421 .46683 L
.53971 .46138 L
.54611 .45504 L
.55354 .44766 L
.56217 .43909 L
.5722 .42913 L
.58385 .41755 L
.59738 .40409 L
.6131 .38845 L
.63136 .37027 L
.65257 .34914 L
.67722 .32458 L
.70585 .29604 L
.73911 .26288 L
.77775 .22434 L
.82264 .17956 L
.87479 .12752 L
.93538 .06704 L
s
.93538 .06704 m
1 .00254 L
s
0 .874 1 r
.54547 .45351 m
.55285 .44607 L
.56144 .43743 L
.57141 .4274 L
.583 .41575 L
.59646 .40222 L
.61211 .38651 L
.63029 .36825 L
.65142 .34705 L
.67597 .32243 L
.70449 .29382 L
.73763 .2606 L
.77614 .222 L
.82087 .17716 L
.87286 .12508 L
.93326 .06458 L
s
.93326 .06458 m
.99773 0 L
s
.873 0 1 r
.50879 .56893 m
.50807 .57364 L
.50712 .57878 L
.50589 .58441 L
.50435 .59058 L
.50243 .59737 L
.50007 .60485 L
.49718 .61312 L
.49367 .62228 L
.48944 .63245 L
.48437 .64378 L
.47829 .65642 L
.47106 .67056 L
.46246 .68642 L
.45227 .70425 L
.44022 .72432 L
.42599 .74698 L
.40924 .77261 L
.38952 .80165 L
.36636 .83461 L
.33917 .8721 L
.30731 .9148 L
.26998 .96351 L
s
.26998 .96351 m
.24134 1 L
s
1 0 .515 r
.56983 .53499 m
.57823 .53196 L
.58784 .528 L
.59886 .52292 L
.61149 .51653 L
.62599 .50859 L
.64266 .49882 L
.66184 .4869 L
.68392 .47245 L
.70936 .45502 L
.7387 .43411 L
.77255 .40912 L
.81164 .37935 L
.8568 .34398 L
.90899 .30209 L
.96934 .25255 L
s
.96934 .25255 m
1 .22689 L
s
1 0 .233 r
.4715 .55956 m
.46603 .56663 L
.45963 .5747 L
.45215 .58394 L
.44341 .59454 L
.4332 .60669 L
.42129 .62065 L
.40739 .6367 L
.39119 .65516 L
.3723 .67643 L
.35028 .70094 L
.32464 .72921 L
.29477 .76184 L
.25999 .79952 L
.2195 .84306 L
.17238 .89339 L
.11754 .9516 L
s
.11754 .9516 m
.07169 1 L
s
.878 1 0 r
.52158 .53842 m
.52342 .53967 L
.52546 .54086 L
.52775 .54197 L
.53032 .54298 L
.5332 .54386 L
.53644 .54456 L
.5401 .54506 L
.54423 .54529 L
.54892 .5452 L
.55423 .54471 L
.56027 .54374 L
.56715 .54219 L
.575 .53995 L
.58396 .53688 L
.59421 .53283 L
.60594 .52761 L
.61939 .52101 L
.63483 .51276 L
.65257 .50259 L
.67298 .49014 L
.69646 .47502 L
.72352 .45676 L
.75471 .43481 L
.79069 .40855 L
.83222 .37723 L
.8802 .33999 L
.93564 .29584 L
.99975 .2436 L
s
.99975 .2436 m
1 .24339 L
s
.073 1 0 r
.4446 .52909 m
.43636 .53598 L
.42683 .54409 L
.41579 .55364 L
.40301 .56486 L
.3882 .57802 L
.37104 .59344 L
.35115 .61151 L
.32809 .63265 L
.30136 .65738 L
.27035 .68627 L
.23438 .72001 L
.19266 .7594 L
.14425 .80535 L
.08806 .85895 L
.02286 .92143 L
s
.02286 .92143 m
0 .94343 L
s
1 .215 0 r
.46026 .48167 m
.45544 .48352 L
.44991 .48591 L
.44358 .48895 L
.43631 .49276 L
.42797 .49747 L
.41837 .50324 L
.40733 .51027 L
.39461 .51876 L
.37995 .52898 L
.36304 .54122 L
.34352 .55583 L
.32098 .57321 L
.29493 .59384 L
.26481 .61825 L
.22999 .64708 L
.18969 .68107 L
.14304 .7211 L
.08903 .76814 L
.02646 .82338 L
s
.02646 .82338 m
0 .84704 L
s
1 .995 0 r
.4523 .48143 m
.44641 .48393 L
.43966 .4871 L
.43192 .49109 L
.42303 .49603 L
.41281 .5021 L
.40105 .50949 L
.38751 .51845 L
.3719 .52923 L
.35391 .54216 L
.33314 .5576 L
.30915 .57598 L
.28144 .59781 L
.24941 .62365 L
.21236 .65418 L
.1695 .6902 L
.1199 .73262 L
.06246 .78249 L
s
.06246 .78249 m
0 .83749 L
s
1 0 .152 r
.52678 .46746 m
.53127 .46267 L
.5365 .45714 L
.54258 .45073 L
.54966 .44331 L
.55789 .43472 L
.56746 .42476 L
.5786 .41323 L
.59154 .39987 L
.60659 .38438 L
.62409 .36641 L
.64444 .34558 L
.66809 .32142 L
.69558 .29339 L
.72754 .26087 L
.76468 .22313 L
.80785 .17933 L
.85803 .1285 L
.91634 .0695 L
.98411 .001 L
s
.98411 .001 m
.9851 0 L
s
.031 1 0 r
.53661 .56032 m
.53985 .56205 L
.54348 .56364 L
.54756 .56506 L
.55215 .56625 L
.55731 .56715 L
.56315 .5677 L
.56975 .5678 L
.57724 .56737 L
.58574 .56628 L
.59541 .5644 L
.60643 .56157 L
.61902 .5576 L
.63339 .55228 L
.64985 .54534 L
.66871 .5365 L
.69034 .52539 L
.71518 .51161 L
.74373 .49468 L
.77659 .47405 L
.81442 .44906 L
.85802 .41897 L
.9083 .38289 L
.96633 .33979 L
s
.96633 .33979 m
1 .31401 L
s
.96 1 0 r
.50998 .57407 m
.50927 .57908 L
.50833 .58456 L
.50711 .59054 L
.50556 .59709 L
.50362 .60429 L
.50123 .61222 L
.49829 .62098 L
.49472 .63067 L
.4904 .64141 L
.4852 .65337 L
.47897 .6667 L
.47155 .6816 L
.46271 .69829 L
.45222 .71703 L
.43981 .73811 L
.42515 .7619 L
.40787 .78877 L
.38753 .8192 L
.36361 .85371 L
.33553 .89293 L
.3026 .93758 L
.26401 .98848 L
s
.26401 .98848 m
.25506 1 L
s
1 .367 0 r
.57589 .50103 m
.58605 .49481 L
.59774 .48727 L
.6112 .47816 L
.62673 .46722 L
.64464 .45412 L
.66532 .43851 L
.6892 .41994 L
.71681 .39794 L
.74872 .37191 L
.78564 .34117 L
.82836 .30495 L
.87781 .26233 L
.93508 .21225 L
s
.93508 .21225 m
1 .15473 L
s
1 .299 0 r
.44103 .49815 m
.43316 .50289 L
.42411 .50866 L
.41369 .51564 L
.40168 .52403 L
.38782 .53408 L
.37182 .54607 L
.35335 .56033 L
.332 .57726 L
.30732 .59728 L
.27878 .62094 L
.24575 .64882 L
.20752 .68165 L
.16325 .72024 L
.11197 .76554 L
.05256 .81868 L
s
.05256 .81868 m
0 .86619 L
s
0 .032 1 r
.54604 .57397 m
.55018 .57599 L
.55481 .57782 L
.56001 .57942 L
.56587 .58071 L
.57248 .58162 L
.57995 .58205 L
.58841 .58189 L
.59801 .58102 L
.60892 .57929 L
.62135 .57651 L
.63552 .57249 L
.6517 .56697 L
.67021 .55968 L
.6914 .55027 L
.71569 .53837 L
.74358 .52351 L
.77561 .50517 L
.81246 .48272 L
.85486 .45545 L
.90372 .42251 L
.96003 .38291 L
s
.96003 .38291 m
1 .35377 L
s
0 .554 1 r
.53509 .4201 m
.54201 .41089 L
.55011 .40037 L
.55959 .38835 L
.57067 .3746 L
.58362 .35885 L
.59874 .34077 L
.61639 .32002 L
.63699 .29617 L
.66101 .26872 L
.689 .23712 L
.72163 .2007 L
.75965 .15871 L
.80393 .11024 L
.85548 .05428 L
s
.85548 .05428 m
.90588 0 L
s
.997 1 0 r
.55643 .55286 m
.56254 .55235 L
.56949 .55129 L
.57739 .54958 L
.58641 .54707 L
.5967 .54362 L
.60848 .53904 L
.62195 .53313 L
.6374 .52563 L
.65513 .51626 L
.6755 .50468 L
.69892 .4905 L
.72588 .47325 L
.75693 .45241 L
.79273 .42735 L
.83401 .39734 L
.88168 .36155 L
.93672 .31897 L
s
.93672 .31897 m
1 .26873 L
s
1 .994 0 r
.52201 .52658 m
.52423 .52685 L
.52674 .52696 L
.52958 .52687 L
.53281 .52653 L
.53648 .52591 L
.54066 .52493 L
.54543 .52352 L
.55087 .52161 L
.5571 .5191 L
.56424 .51587 L
.57242 .51179 L
.58181 .50672 L
.59261 .50047 L
.60502 .49282 L
.61931 .48355 L
.63578 .47236 L
.65476 .45892 L
.67667 .44284 L
.70195 .42368 L
.73116 .40091 L
.76492 .37392 L
.80396 .34201 L
.84911 .30433 L
.90137 .25994 L
.96187 .20772 L
s
.96187 .20772 m
1 .17432 L
s
.703 1 0 r
.42436 .53568 m
.41323 .54477 L
.40034 .5555 L
.38544 .56814 L
.36818 .58302 L
.3482 .6005 L
.32505 .62102 L
.29822 .64507 L
.26714 .67325 L
.2311 .70624 L
.18931 .74481 L
.14085 .78989 L
.08465 .84255 L
.01944 .90402 L
s
.01944 .90402 m
0 .92245 L
s
1 0 .987 r
.48318 .56913 m
.47902 .57598 L
.4741 .58371 L
.46831 .59247 L
.4615 .60239 L
.4535 .61367 L
.44412 .62649 L
.43313 .64111 L
.42026 .65779 L
.40519 .67685 L
.38758 .69867 L
.367 .72367 L
.34298 .75234 L
.31493 .78528 L
.28221 .82314 L
.24405 .8667 L
.19957 .91686 L
.14773 .97466 L
s
.14773 .97466 m
.12478 1 L
s
.448 1 0 r
.50098 .49556 m
.50123 .49512 L
.50153 .49464 L
.50189 .49409 L
.5023 .49346 L
.50279 .49276 L
.50337 .49195 L
.50404 .49104 L
.50483 .49 L
.50576 .48881 L
.50684 .48744 L
.50811 .48589 L
.50958 .4841 L
.51131 .48205 L
.51332 .4797 L
.51567 .47699 L
.51841 .47388 L
.5216 .47029 L
.52532 .46615 L
.52966 .46138 L
.5347 .45587 L
.54058 .44951 L
.54742 .44217 L
.55538 .43367 L
.56465 .42384 L
.57543 .41247 L
.58797 .39931 L
.60256 .38407 L
.61953 .36642 L
.63926 .34596 L
.6622 .32226 L
.68888 .29479 L
.7199 .26293 L
.75596 .22599 L
.79789 .18314 L
.84662 .13343 L
.90327 .07576 L
.96911 .00885 L
s
.96911 .00885 m
.97783 0 L
s
1 0 .695 r
.56653 .52327 m
.57482 .51959 L
.58432 .51493 L
.59522 .50912 L
.60775 .50194 L
.62215 .49316 L
.63873 .48249 L
.65783 .46961 L
.67985 .45412 L
.70526 .43559 L
.73458 .41348 L
.76845 .3872 L
.80759 .35604 L
.85285 .31917 L
.9052 .27565 L
.96578 .22434 L
s
.96578 .22434 m
1 .19487 L
s
0 .989 1 r
.45595 .52404 m
.44937 .52959 L
.44176 .53612 L
.43295 .5438 L
.42274 .55281 L
.41091 .56339 L
.39721 .57578 L
.38132 .59028 L
.36289 .60725 L
.34153 .62708 L
.31675 .65025 L
.28801 .6773 L
.25466 .70887 L
.21597 .7457 L
.17106 .78864 L
.11894 .83869 L
.05844 .89702 L
s
.05844 .89702 m
0 .95356 L
s
0 1 .651 r
.51438 .50741 m
.5161 .50681 L
.51808 .50601 L
.52034 .50498 L
.52293 .50369 L
.5259 .50208 L
.52932 .5001 L
.53326 .49767 L
.53778 .49473 L
.543 .49118 L
.54901 .48692 L
.55595 .48182 L
.56396 .47575 L
.57321 .46853 L
.58391 .45998 L
.59627 .44986 L
.61058 .43792 L
.62714 .42386 L
.6463 .4073 L
.6685 .38786 L
.69421 .36504 L
.724 .33828 L
.75853 .30695 L
.79856 .27027 L
.84497 .22739 L
.8988 .17727 L
.96123 .11873 L
s
.96123 .11873 m
1 .08216 L
s
1 .498 0 r
.55349 .48961 m
.56095 .48435 L
.56956 .47807 L
.5795 .47057 L
.59099 .46165 L
.60426 .45108 L
.6196 .43857 L
.63735 .42381 L
.65788 .40641 L
.68166 .38593 L
.70919 .36187 L
.74107 .33362 L
.77802 .3005 L
.82085 .2617 L
.87049 .21629 L
.92805 .16318 L
.9948 .10111 L
s
.9948 .10111 m
1 .09624 L
s
0 .004 1 r
.51073 .50529 m
.51203 .50481 L
.51351 .5042 L
.5152 .50341 L
.51715 .50242 L
.51938 .50118 L
.52195 .49967 L
.52491 .49782 L
.52831 .49559 L
.53223 .49289 L
.53675 .48966 L
.54197 .48579 L
.548 .48119 L
.55496 .47573 L
.563 .46925 L
.57231 .4616 L
.58307 .45258 L
.59553 .44195 L
.60995 .42945 L
.62666 .41476 L
.64601 .39753 L
.66844 .37734 L
.69443 .35369 L
.72457 .32602 L
.75951 .29367 L
.80004 .25587 L
.84705 .21173 L
.90159 .1602 L
.96487 .10009 L
s
.96487 .10009 m
1 .06655 L
s
0 .946 1 r
.42705 .56222 m
.41555 .57318 L
.40219 .58596 L
.38669 .60085 L
.3687 .6182 L
.34781 .63842 L
.32356 .66196 L
.2954 .68938 L
.26272 .72129 L
.22476 .75842 L
.18068 .80164 L
.12949 .85192 L
.07004 .91042 L
.001 .97846 L
s
.001 .97846 m
0 .97944 L
s
1 .731 0 r
.57025 .52314 m
.57904 .51914 L
.58912 .5141 L
.60069 .50782 L
.61398 .50009 L
.62928 .49064 L
.64688 .47919 L
.66717 .46536 L
.69056 .44877 L
.71755 .42892 L
.74871 .40527 L
.7847 .37718 L
.8263 .34388 L
.8744 .3045 L
.93005 .25802 L
.99445 .20327 L
s
.99445 .20327 m
1 .19847 L
s
.772 1 0 r
.45127 .56616 m
.4429 .57542 L
.43315 .58611 L
.4218 .59844 L
.40858 .6127 L
.3932 .62917 L
.3753 .64822 L
.35447 .67026 L
.33023 .69576 L
.30204 .72529 L
.26925 .75948 L
.23111 .79909 L
.18676 .84499 L
.13519 .89819 L
.07522 .95986 L
s
.07522 .95986 m
.0361 1 L
s
.726 0 1 r
.5445 .45922 m
.5516 .45231 L
.55985 .44427 L
.56942 .43491 L
.58053 .42402 L
.59344 .41134 L
.60843 .3966 L
.62584 .37945 L
.64606 .3595 L
.66954 .3363 L
.69682 .30932 L
.7285 .27796 L
.7653 .24149 L
.80805 .19909 L
.8577 .1498 L
.91538 .0925 L
.98239 .0259 L
s
.98239 .0259 m
1 .00839 L
s
1 .042 0 r
.49328 .54321 m
.49119 .54717 L
.4887 .55163 L
.48576 .55664 L
.48228 .56229 L
.47818 .56867 L
.47336 .5759 L
.46768 .5841 L
.46102 .59342 L
.45321 .60402 L
.44405 .61611 L
.43334 .62991 L
.4208 .64569 L
.40614 .66376 L
.38902 .68446 L
.36903 .70822 L
.3457 .73551 L
.31848 .76689 L
.28675 .803 L
.24976 .8446 L
.20665 .89254 L
.15644 .94784 L
s
.15644 .94784 m
.10865 1 L
s
1 .825 0 r
.50002 .53747 m
.49898 .54043 L
.49773 .54371 L
.49622 .54734 L
.4944 .55139 L
.49223 .55591 L
.48964 .56097 L
.48657 .56664 L
.48292 .57301 L
.47861 .58019 L
.47353 .58829 L
.46753 .59745 L
.46048 .60783 L
.4522 .61962 L
.44248 .63302 L
.43108 .64829 L
.41773 .66571 L
.40211 .6856 L
.38385 .70837 L
.3625 .73444 L
.33757 .76434 L
.30847 .79867 L
.27451 .83812 L
.2349 .8835 L
.18873 .93575 L
.13492 .99595 L
s
.13492 .99595 m
.13125 1 L
s
1 0 .628 r
.5383 .44515 m
.54496 .43764 L
.55272 .42899 L
.56175 .41902 L
.57228 .40751 L
.58454 .39422 L
.5988 .37886 L
.61541 .36111 L
.63474 .34057 L
.65723 .31682 L
.68339 .28933 L
.71382 .2575 L
.74922 .22063 L
.79038 .17792 L
.83825 .12842 L
.89391 .07105 L
.95863 .00454 L
s
.95863 .00454 m
.96306 0 L
s
1 .451 0 r
.53118 .56748 m
.5335 .57022 L
.53605 .57298 L
.53887 .57575 L
.542 .5785 L
.54546 .58121 L
.54932 .58385 L
.55362 .58638 L
.55843 .58875 L
.56381 .59091 L
.56986 .59279 L
.57667 .59432 L
.58436 .59541 L
.59304 .59594 L
.60287 .5958 L
.61403 .59482 L
.62671 .59285 L
.64115 .58967 L
.65761 .58504 L
.67641 .57869 L
.69791 .57027 L
.72252 .5594 L
.75074 .54564 L
.78313 .52844 L
.82034 .50721 L
.86312 .48122 L
.91237 .44962 L
.9691 .41145 L
s
.9691 .41145 m
1 .38977 L
s
.001 1 0 r
.5142 .54891 m
.51476 .55159 L
.51531 .55444 L
.51586 .55746 L
.5164 .56068 L
.51693 .56411 L
.51743 .56776 L
.51789 .57167 L
.51831 .57584 L
.51867 .5803 L
.51896 .58509 L
.51915 .59024 L
.51923 .59577 L
.51916 .60173 L
.51892 .60817 L
.51847 .61514 L
.51776 .62269 L
.51675 .6309 L
.51538 .63984 L
.51358 .6496 L
.51127 .66028 L
.50835 .67199 L
.50472 .68487 L
.50024 .69907 L
.49477 .71476 L
.48814 .73214 L
.48013 .75144 L
.47051 .77293 L
.45901 .79692 L
.4453 .82375 L
.42901 .85383 L
.40971 .88764 L
.38688 .92571 L
.35993 .96869 L
s
.35993 .96869 m
.33947 1 L
s
0 1 .406 r
.57969 .58121 m
.58813 .58101 L
.59772 .58009 L
.60862 .57831 L
.62103 .57548 L
.63519 .5714 L
.65136 .56582 L
.66985 .55847 L
.69103 .549 L
.71531 .53702 L
.74317 .52209 L
.7752 .50367 L
.81203 .48114 L
.85442 .45377 L
.90326 .42074 L
.95956 .38104 L
s
.95956 .38104 m
1 .35148 L
s
1 .636 0 r
.4569 .48928 m
.45141 .49201 L
.44512 .4954 L
.43788 .49959 L
.42955 .50471 L
.41997 .51092 L
.40893 .51842 L
.3962 .52743 L
.38151 .5382 L
.36455 .55104 L
.34497 .5663 L
.32233 .58439 L
.29615 .60578 L
.26588 .63103 L
.23084 .66078 L
.19027 .69579 L
.1433 .73692 L
.08888 .7852 L
.02583 .8418 L
s
.02583 .8418 m
0 .86522 L
s
1 .695 0 r
.47619 .43452 m
.4748 .43133 L
.47332 .428 L
.47173 .42453 L
.47002 .42092 L
.46818 .41717 L
.4662 .41327 L
.46407 .40923 L
.46175 .40504 L
.45925 .40072 L
.45652 .39627 L
.45355 .39168 L
.45032 .38699 L
.44677 .38219 L
.44289 .37731 L
.43861 .37236 L
.4339 .36738 L
.4287 .3624 L
.42293 .35745 L
.41653 .35259 L
.40941 .34788 L
.40145 .34339 L
.39256 .3392 L
.38259 .33542 L
.37138 .33217 L
.35876 .32959 L
.34451 .32786 L
.32841 .32717 L
.31016 .32776 L
.28944 .32991 L
.26589 .33394 L
.23906 .34025 L
.20846 .34929 L
.1735 .36157 L
.13352 .37772 L
.08772 .39846 L
.0352 .42463 L
s
.0352 .42463 m
0 .44366 L
s
0 .672 1 r
.44088 .4206 m
.43514 .41924 L
.42867 .41825 L
.42135 .41771 L
.41307 .41774 L
.40368 .41846 L
.39301 .42001 L
.38087 .42257 L
.36702 .42634 L
.35121 .43155 L
.33313 .43849 L
.31244 .44747 L
.28873 .45888 L
.26151 .47315 L
.23025 .49081 L
.1943 .51245 L
.15294 .53878 L
.10529 .57062 L
.05037 .60893 L
s
.05037 .60893 m
0 .64541 L
s
.433 1 0 r
.55758 .51941 m
.56478 .51617 L
.57302 .51207 L
.58249 .50697 L
.59336 .50068 L
.60587 .49299 L
.62027 .48366 L
.63686 .4724 L
.65599 .45887 L
.67806 .44269 L
.70354 .4234 L
.73297 .40048 L
.76699 .37331 L
.80632 .34117 L
.85181 .30324 L
.90446 .25854 L
.96541 .20594 L
s
.96541 .20594 m
1 .17566 L
s
1 .549 0 r
.45868 .56038 m
.45147 .56857 L
.44306 .57801 L
.43327 .58889 L
.42185 .60143 L
.40856 .61592 L
.39309 .63265 L
.37508 .65198 L
.35411 .67433 L
.32972 .70019 L
.30133 .7301 L
.26831 .76474 L
.2299 .80484 L
.18523 .85129 L
.13328 .90511 L
.07288 .96749 L
s
.07288 .96749 m
.0413 1 L
s
.311 0 1 r
.53885 .49492 m
.5442 .4913 L
.55037 .48695 L
.55749 .48174 L
.56571 .47553 L
.57521 .46815 L
.58618 .4594 L
.59887 .44905 L
.61354 .43683 L
.63052 .42243 L
.65018 .40549 L
.67295 .38558 L
.69932 .36221 L
.72988 .33481 L
.76529 .30271 L
.80634 .26514 L
.85394 .22121 L
.90915 .16986 L
.97318 .10988 L
s
.97318 .10988 m
1 .08459 L
s
.286 1 0 r
.46169 .48527 m
.45695 .48729 L
.45153 .48985 L
.4453 .49307 L
.43816 .49706 L
.42994 .50196 L
.42048 .50792 L
.40959 .51514 L
.39704 .52383 L
.38257 .53425 L
.36586 .54669 L
.34657 .5615 L
.32428 .57908 L
.29851 .59989 L
.26871 .62448 L
.23424 .65348 L
.19433 .68763 L
.14813 .72778 L
.09461 .77493 L
.03261 .83024 L
s
.03261 .83024 m
0 .85966 L
s
0 .362 1 r
.44783 .44667 m
.4423 .44679 L
.43603 .44737 L
.4289 .44852 L
.42078 .45036 L
.41152 .45301 L
.40095 .45664 L
.38885 .46143 L
.37501 .4676 L
.35913 .47541 L
.3409 .48515 L
.31996 .49717 L
.29588 .51188 L
.26816 .52974 L
.23623 .55131 L
.19942 .57723 L
.15695 .60825 L
.10792 .64524 L
.05129 .68921 L
s
.05129 .68921 m
0 .73008 L
s
.946 0 1 r
.55923 .52043 m
.56662 .51713 L
.57508 .51295 L
.5848 .50775 L
.59597 .50133 L
.60881 .49348 L
.62359 .48394 L
.64062 .47242 L
.66025 .45859 L
.6829 .44203 L
.70905 .42229 L
.73925 .39882 L
.77415 .371 L
.8145 .33809 L
.86118 .29923 L
.9152 .25344 L
.97773 .19955 L
s
.97773 .19955 m
1 .18008 L
s
.691 0 1 r
.46517 .4304 m
.46242 .42779 L
.45938 .42521 L
.45599 .42268 L
.45222 .42022 L
.44802 .41789 L
.44331 .41572 L
.43803 .41377 L
.4321 .4121 L
.42542 .4108 L
.41788 .40994 L
.40935 .40965 L
.39968 .41003 L
.3887 .41125 L
.37622 .41348 L
.362 .41692 L
.34578 .4218 L
.32725 .42842 L
.30604 .4371 L
.28175 .44822 L
.2539 .46223 L
.22192 .47966 L
.18516 .50111 L
.14288 .5273 L
.0942 .55907 L
.03811 .59738 L
s
.03811 .59738 m
0 .62448 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0333333 0.5 0.0333333 [
[0 .4875 -18.4688 -20 ]
[0 .4875 18.4688 0 ]
[.16667 .4875 -18.4688 -20 ]
[.16667 .4875 18.4688 0 ]
[.33333 .4875 -13.4688 -20 ]
[.33333 .4875 13.4688 0 ]
[.66667 .4875 -7 -20 ]
[.66667 .4875 7 0 ]
[.83333 .4875 -12 -20 ]
[.83333 .4875 12 0 ]
[1 .4875 -12 -20 ]
[1 .4875 12 0 ]
[.4875 0 -36.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .16667 -36.9375 -10 ]
[.4875 .16667 0 10 ]
[.4875 .33333 -26.9375 -10 ]
[.4875 .33333 0 10 ]
[.4875 .66667 -14 -10 ]
[.4875 .66667 0 10 ]
[.4875 .83333 -24 -10 ]
[.4875 .83333 0 10 ]
[.4875 1 -24 -10 ]
[.4875 1 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.16667 .5 m
.16667 .50625 L
s
gsave
.16667 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.33333 .5 m
.33333 .50625 L
s
gsave
.33333 .4875 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.66667 .5 m
.66667 .50625 L
s
gsave
.66667 .4875 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.83333 .5 m
.83333 .50625 L
s
gsave
.83333 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.5 .16667 m
.50625 .16667 L
s
gsave
.4875 .16667 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 .33333 m
.50625 .33333 L
s
gsave
.4875 .33333 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .66667 m
.50625 .66667 L
s
gsave
.4875 .66667 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .83333 m
.50625 .83333 L
s
gsave
.4875 .83333 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.01 w
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.918 0 1 r
.5 Mabswid
.61999 .17145 m
.64517 .13557 L
.67472 .09477 L
.70937 .04831 L
s
.70937 .04831 m
.74635 0 L
s
1 0 0 r
.61999 .17145 m
.64517 .13557 L
s
% Start of user PostScript
3.5995507 -9.8566221 4.3550316 -10.93291 MAarrowhead1
% End of user PostScript
1 .158 0 r
.67472 .09477 m
.70937 .04831 L
s
% Start of user PostScript
5.2416426 -12.156776 6.2810596 -13.550739 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
20.563587 -30.879754 24.176627 -35.021715 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
72.988757 -88.378669 85.226226 -101.4052 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
249.36552 -272.32457 290.35601 -314.49219 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
838.41665 -872.66753 975.04789 -1011.0549 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2799.2965 -2850.3928 3253.7308 -3307.4469 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9317.3463 -9393.573 10827.319 -10907.454 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
30969.52 -31083.237 35984.592 -36104.14 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
102874.41 -103044.05 119527.7 -119706.04 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
341632.59 -341885.68 396927.44 -397193.5 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1134375.8 -1134753.4 1317967.1 -1318364. MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3766433. -3766996.2 4375986.4 -4376578.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
12505255. -12506096. 14529057. -14529940. MAarrowhead1
% End of user PostScript
.175 1 0 r
.24773 .24782 m
.22084 .24884 L
.19033 .25217 L
.15562 .25829 L
.11609 .26777 L
.07099 .28128 L
.01946 .2996 L
s
.01946 .2996 m
0 .30753 L
s
1 0 0 r
.24773 .24782 m
.22084 .24884 L
s
% Start of user PostScript
-7.5681849 -7.5653633 -8.3746732 -7.5347886 MAarrowhead1
% End of user PostScript
1 .158 0 r
.19033 .25217 m
.15562 .25829 L
s
% Start of user PostScript
-9.290232 -7.4349253 -10.331413 -7.2512613 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-23.200038 -1.750965 -26.264933 0.034664988 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-65.622407 28.399885 -75.2135 36.082538 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-200.86065 145.33117 -231.83191 173.45537 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-641.49982 558.65958 -743.02669 655.93913 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2091.9904 1968.4072 -2427.1301 2297.2107 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6889.1661 6704.8018 -7998.9731 7805.1562 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-22788.569 22513.53 -26468.938 26179.797 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-75535.001 75124.69 -87747.809 87316.462 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-250597.49 249985.38 -291135.83 290492.33 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-831733.2 830820.03 -966310.87 965350.89 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2761034.1 2759671.8 -3207826.3 3206394.2 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-9166333.3 9164301. -10649704. 10647567. MAarrowhead1
% End of user PostScript
.341 1 0 r
.17713 .49874 m
.13384 .52541 L
.084 .55778 L
.02658 .59684 L
s
.02658 .59684 m
0 .61567 L
s
1 0 0 r
.17713 .49874 m
.13384 .52541 L
s
% Start of user PostScript
-9.6860033 -0.037775242 -10.984757 0.76243009 MAarrowhead1
% End of user PostScript
1 .158 0 r
.084 .55778 m
.02658 .59684 L
s
% Start of user PostScript
-12.479914 1.7334769 -14.202552 2.9051327 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-36.522867 20.491067 -41.990386 25.136618 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-113.93249 90.015849 -131.70959 106.56672 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-367.33752 331.65809 -425.7991 388.29035 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1203.2954 1150.068 -1396.5586 1340.6021 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3970.7526 3891.3466 -4611.1615 4527.6843 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-13147.069 13028.609 -15271.44 15146.907 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-43595.66 43418.939 -50646.046 50460.264 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-144661.92 144398.28 -168065.88 167788.73 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-480173.97 479780.67 -557871.69 557458.23 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1594054. 1593467.2 -1852010.3 1851393.4 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-5292177.4 5291302. -6148608.7 6147688.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-17570248. 17568942. -20413679. 20412306. MAarrowhead1
% End of user PostScript
0 .834 1 r
.35836 .6271 m
.33585 .64887 L
.3097 .67423 L
.27935 .70376 L
.24411 .73814 L
.20319 .77815 L
.15567 .82471 L
.10048 .87889 L
.0364 .94191 L
s
.0364 .94191 m
0 .97777 L
s
1 0 0 r
.35836 .6271 m
.33585 .64887 L
s
% Start of user PostScript
-4.2490508 3.8129251 -4.9246379 4.4661515 MAarrowhead1
% End of user PostScript
1 .158 0 r
.3097 .67423 m
.27935 .70376 L
s
% Start of user PostScript
-5.70894 5.2269466 -6.6195193 6.1128135 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-18.734042 18.014992 -21.745977 20.99006 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-61.870552 60.797856 -71.853676 70.725981 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-204.92717 203.32689 -238.04717 236.36484 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-679.65071 677.26338 -789.57548 787.06575 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2255.4286 2251.8672 -2620.3358 2616.5917 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-7486.659 7481.3459 -8698.1099 8692.5244 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-24854.155 24846.228 -28876.189 28867.856 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-82515.077 82503.252 -95868.515 95856.084 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-273954.3 273936.66 -318289. 318270.45 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-909552.24 909525.92 -1056748.2 1056720.5 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3019807.7 3019768.5 -3508515. 3508473.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-10026097. 10026038. -11648661. 11648599. MAarrowhead1
% End of user PostScript
1 .716 0 r
.34233 .38408 m
.32438 .38801 L
.30391 .39373 L
.28053 .40161 L
.2538 .41204 L
.22319 .42552 L
.18811 .44259 L
.14784 .46393 L
.10158 .49028 L
.04838 .52255 L
s
.04838 .52255 m
0 .55355 L
s
1 0 0 r
.34233 .38408 m
.32438 .38801 L
s
% Start of user PostScript
-4.7299999 -3.4775696 -5.2686122 -3.3597685 MAarrowhead1
% End of user PostScript
1 .158 0 r
.30391 .39373 m
.28053 .40161 L
s
% Start of user PostScript
-5.8827588 -3.1880084 -6.5840675 -2.9517679 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-15.385444 1.8534493 -17.5013 3.2755058 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-44.896362 24.708999 -51.604136 30.381744 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-139.83407 109.71806 -161.63158 129.97149 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-450.50025 405.57245 -522.16478 474.93348 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1475.1782 1408.1538 -1712.06 1641.5991 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4867.1291 4767.1405 -5652.0335 5546.9183 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-16113.736 15964.57 -18717.367 18560.553 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-53431.307 53208.778 -62072.171 61838.233 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-177296.47 176964.5 -205979.94 205630.94 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-588493.29 587998.04 -683717.97 683197.33 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1953640.2 1952901.3 -2269785.6 2269008.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-6485976.1 6484873.9 -7535598.6 7534439.9 MAarrowhead1
% End of user PostScript
1 .182 0 r
.19377 .30708 m
.15801 .31725 L
.11717 .33118 L
.07046 .34961 L
.01697 .37336 L
s
.01697 .37336 m
0 .38168 L
s
1 0 0 r
.19377 .30708 m
.15801 .31725 L
s
% Start of user PostScript
-9.1869443 -5.7877038 -10.259795 -5.4826193 MAarrowhead1
% End of user PostScript
1 .158 0 r
.11717 .33118 m
.07046 .34961 L
s
% Start of user PostScript
-11.485049 -5.0644967 -12.886281 -4.5117783 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-30.567354 5.8783329 -34.831774 8.8769204 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-90.202502 53.370811 -103.7823 65.062207 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-282.64808 227.70165 -326.87146 269.10787 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-913.31015 831.33971 -1058.8493 972.67613 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2994.83 2872.5445 -3476.116 3347.5607 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-9887.2923 9704.8638 -11482.352 11290.57 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-32743.583 32471.432 -38035.094 37748.989 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-108588.13 108182.13 -126150.19 125723.37 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-360339.72 359734.04 -418638.29 418001.55 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1196093.2 1195189.6 -1389637. 1388687.1 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3970756.2 3969408.2 -4613323.2 4611906.2 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-13182759. 13180748. -15316125. 15314011. MAarrowhead1
% End of user PostScript
1 0 .955 r
.74012 .31438 m
.77747 .27982 L
.82079 .23943 L
.87104 .19227 L
.92933 .13722 L
.99698 .07299 L
s
.99698 .07299 m
1 .07011 L
s
1 0 0 r
.74012 .31438 m
.77747 .27982 L
s
% Start of user PostScript
7.2034519 -5.5687153 8.3240316 -6.6054804 MAarrowhead1
% End of user PostScript
1 .158 0 r
.82079 .23943 m
.87104 .19227 L
s
% Start of user PostScript
9.6236429 -7.8169796 11.13114 -9.2318474 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
31.125842 -28.430618 36.088572 -33.255159 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
102.10952 -98.088719 118.5232 -114.29625 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
337.17775 -331.17942 391.57886 -385.27298 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1116.7279 -1107.7794 1297.2053 -1287.7981 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3703.577 -3690.2275 4302.5736 -4288.5396 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
12290.207 -12270.292 14278.633 -14257.697 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
40795.822 -40766.112 47397.161 -47365.928 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
135433.32 -135389. 157349.84 -157303.25 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
449634.19 -449568.07 522398.58 -522329.06 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1492807.9 -1492709.2 1734392.6 -1734288.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4956251.6 -4956104.4 5758338.8 -5758184.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
16455268. -16455048. 19118287. -19118056. MAarrowhead1
% End of user PostScript
.642 0 1 r
.56845 .82367 m
.56869 .84354 L
.56841 .86495 L
.5675 .88808 L
.56583 .91311 L
.56325 .94025 L
.55957 .96974 L
s
.55957 .96974 m
.55487 1 L
s
1 0 0 r
.56845 .82367 m
.56869 .84354 L
s
% Start of user PostScript
2.053491 9.7102411 2.0606573 10.306214 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56841 .86495 m
.5675 .88808 L
s
% Start of user PostScript
2.0523122 10.948622 2.0250905 11.642416 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
0.87153947 18.523576 0.47648816 19.913036 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-5.9713717 34.905484 -7.7375057 38.155101 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-33.050655 76.215278 -39.592487 84.970208 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-129.46143 193.85548 -152.19262 219.88822 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-459.25986 555.32449 -536.23913 637.2291 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1568.705 1712.0166 -1826.5364 1977.1957 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-5273.7878 5487.5836 -6133.1768 6357.9341 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-17607.312 17926.258 -20465.594 20800.893 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-58604.118 59079.929 -68101.422 68601.629 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-194790. 195499.83 -226333.32 227079.54 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-647050.03 648108.97 -751794.15 752907.38 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2148765.8 2150345.5 -2496553.3 2498214.1 MAarrowhead1
% End of user PostScript
1 .482 0 r
.39678 .65395 m
.37867 .67466 L
.35757 .69851 L
.33297 .72598 L
.3043 .75766 L
.27092 .79422 L
.23205 .83644 L
.18679 .88521 L
.13411 .94158 L
s
.13411 .94158 m
.07917 1 L
s
1 0 0 r
.39678 .65395 m
.37867 .67466 L
s
% Start of user PostScript
-3.0965615 4.6186151 -3.6397619 5.2398529 MAarrowhead1
% End of user PostScript
1 .158 0 r
.35757 .69851 m
.33297 .72598 L
s
% Start of user PostScript
-4.2730278 5.9551572 -5.0110454 6.7794194 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-14.955808 17.46525 -17.445533 20.083637 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-50.802029 54.545677 -59.127015 63.062603 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-170.3798 175.96466 -198.10745 203.97866 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-568.23354 576.56518 -660.42348 669.18229 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1890.41 1902.8393 -2196.6866 2209.7532 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6282.0632 6300.6056 -7299.2287 7318.7218 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-20865.66 20893.322 -24243.203 24272.283 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-69289.073 69330.34 -80503.559 80546.941 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-230066.69 230128.25 -267301.06 267365.78 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-763876.44 763968.28 -887500.34 887596.89 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2536201.1 2536338.1 -2946649. 2946793.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-8420546.7 8420751.1 -9783285.2 9783500.1 MAarrowhead1
% End of user PostScript
0 1 .547 r
.20894 .65526 m
.16559 .69164 L
.11541 .7345 L
.05732 .78489 L
s
.05732 .78489 m
0 .83532 L
s
1 0 0 r
.20894 .65526 m
.16559 .69164 L
s
% Start of user PostScript
-8.7319082 4.6577152 -10.032416 5.7493347 MAarrowhead1
% End of user PostScript
1 .158 0 r
.11541 .7345 m
.05732 .78489 L
s
% Start of user PostScript
-11.537617 7.0349372 -13.280341 8.5468037 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-36.248183 29.530974 -41.928711 34.867104 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-117.27795 107.25705 -135.98055 125.44587 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-384.79623 369.8468 -446.65622 430.94032 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1270.7355 1248.4336 -1475.7676 1452.3222 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-4208.7968 4175.5262 -4889.0046 4854.0282 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-13958.49 13908.857 -16216.08 16163.902 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-46321.134 46247.089 -53815.433 53737.591 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-153757.74 153647.27 -178637.95 178521.82 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-510443.17 510278.38 -593045.8 592872.56 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1694655.7 1694409.9 -1968902.2 1968643.8 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-5626342.7 5625975.9 -6536867.4 6536481.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-18679948. 18679401. -21702988. 21702413. MAarrowhead1
% End of user PostScript
0 .093 1 r
.21577 .64766 m
.17355 .68288 L
.12469 .72438 L
.06812 .77321 L
.00262 .83058 L
s
.00262 .83058 m
0 .8329 L
s
1 0 0 r
.21577 .64766 m
.17355 .68288 L
s
% Start of user PostScript
-8.5267536 4.4297894 -9.793431 5.486411 MAarrowhead1
% End of user PostScript
1 .158 0 r
.12469 .72438 m
.06812 .77321 L
s
% Start of user PostScript
-11.259294 6.7314484 -12.95628 8.1962869 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-35.312617 28.557865 -40.840701 33.739625 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-114.1546 104.0777 -132.35019 121.75663 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-374.40074 359.36776 -434.57608 418.77234 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1236.1831 1213.7565 -1435.6199 1412.0435 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-4094.0217 4060.5652 -4755.6499 4720.478 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-13577.339 13527.428 -15773.238 15720.767 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-45055.539 44981.08 -52345.01 52266.734 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-149555.62 149444.55 -173755.78 173639. MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-496491.39 496325.68 -576836.12 576661.91 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1648333.7 1648086.5 -1915083.7 1914823.8 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-5472547.7 5472178.9 -6358183.1 6357795.4 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-18169330. 18168779. -21109734. 21109156. MAarrowhead1
% End of user PostScript
0 .075 1 r
.39313 .36492 m
.38252 .36312 L
.37054 .36206 L
.35698 .36191 L
.34161 .36287 L
.32415 .36518 L
.30427 .36913 L
.28163 .37503 L
.25578 .38328 L
.22623 .39432 L
.19241 .40868 L
.15366 .42698 L
.1092 .44994 L
.05814 .47839 L
s
.05814 .47839 m
0 .513 L
s
1 0 0 r
.39313 .36492 m
.38252 .36312 L
s
% Start of user PostScript
-3.2060374 -4.0524834 -3.5242528 -4.1064203 MAarrowhead1
% End of user PostScript
1 .158 0 r
.37054 .36206 m
.35698 .36191 L
s
% Start of user PostScript
-3.8836798 -4.1382263 -4.2904604 -4.1427376 MAarrowhead1
% End of user PostScript
1 .473 0 r
.19241 .40868 m
.15366 .42698 L
s
% Start of user PostScript
-9.2276739 -2.7396037 -10.390243 -2.1906105 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-25.167036 7.3139558 -28.746451 9.9780239 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-75.39734 48.763674 -86.863036 58.863833 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-238.15445 198.42169 -275.59776 233.82785 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-772.53986 713.26555 -895.92488 833.6115 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2537.83 2449.4031 -2946.0936 2853.1329 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8385.4747 8253.5573 -9738.8853 9600.2044 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-27780.461 27583.663 -32270.851 32063.963 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-92144.426 91850.839 -107048.43 106739.79 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-305796.08 305358.1 -355272.25 354811.81 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1015078.5 1014425.2 -1179335. 1178648.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3369880.8 3368906.1 -3915216. 3914191.3 MAarrowhead1
% End of user PostScript
0 1 .968 r
.39048 .49396 m
.37595 .50257 L
.35923 .51306 L
.33998 .52576 L
.3178 .54106 L
.29221 .55941 L
.26269 .58133 L
.22859 .60742 L
.1892 .63841 L
.14367 .6751 L
.09101 .71846 L
.03009 .76962 L
s
.03009 .76962 m
0 .79533 L
s
1 0 0 r
.39048 .49396 m
.37595 .50257 L
s
% Start of user PostScript
-3.2855539 -0.18115313 -3.7214466 0.076997624 MAarrowhead1
% End of user PostScript
1 .158 0 r
.35923 .51306 m
.33998 .52576 L
s
% Start of user PostScript
-4.2229686 0.39166478 -4.8004893 0.77275031 MAarrowhead1
% End of user PostScript
1 .473 0 r
.09101 .71846 m
.03009 .76962 L
s
% Start of user PostScript
-12.269564 6.5539301 -14.097215 8.0885343 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-38.123924 29.597201 -44.057995 35.094097 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-122.67855 109.95817 -142.18054 128.80798 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-401.49299 382.51642 -465.94378 445.99426 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1324.33 1296.0203 -1537.8694 1508.1082 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4383.9908 4341.7577 -5092.3033 5047.9048 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-14536.058 14473.054 -16886.749 16820.514 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-48232.616 48138.625 -56035.707 55936.896 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-160094.96 159954.74 -185999.94 185852.53 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-531469.91 531260.73 -617474.16 617254.25 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1764446.6 1764134.6 -2049985.9 2049657.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-5858026.5 5857560.9 -6806042.9 6805553.5 MAarrowhead1
% End of user PostScript
1 .536 0 r
.2773 .54594 m
.24615 .56803 L
.2102 .59445 L
.16871 .62594 L
.12077 .66335 L
.06536 .70768 L
.00129 .76011 L
s
.00129 .76011 m
0 .7612 L
s
1 0 0 r
.2773 .54594 m
.24615 .56803 L
s
% Start of user PostScript
-6.6808659 1.3782884 -7.6154914 2.0410449 MAarrowhead1
% End of user PostScript
1 .158 0 r
.2102 .59445 m
.16871 .62594 L
s
% Start of user PostScript
-8.6938566 2.8336021 -9.9388383 3.7781221 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-26.186056 17.443584 -30.182208 20.991499 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-82.944819 69.902583 -96.007634 82.296708 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-269.42524 249.96851 -312.48967 292.03538 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-885.63016 856.60413 -1028.1531 997.63892 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2927.1287 2883.8269 -3399.6414 3354.1196 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-9698.6174 9634.0188 -11266.4 11198.49 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-32171.017 32074.648 -37374.726 37273.415 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-106767.49 106623.72 -124042.15 123891.02 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-354414.84 354200.37 -411765.37 411539.9 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1176600.7 1176280.7 -1367006.1 1366669.8 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3906305.6 3905828.3 -4538466.4 4537964.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-12969173. 12968461. -15068010. 15067261. MAarrowhead1
% End of user PostScript
.042 1 0 r
.33187 .71867 m
.30326 .74987 L
.26995 .7859 L
.23118 .82754 L
.18605 .87568 L
.13354 .93136 L
.07244 .99578 L
s
.07244 .99578 m
.06842 1 L
s
1 0 0 r
.33187 .71867 m
.30326 .74987 L
s
% Start of user PostScript
-5.0439966 6.5602056 -5.9021972 7.4961439 MAarrowhead1
% End of user PostScript
1 .158 0 r
.26995 .7859 m
.23118 .82754 L
s
% Start of user PostScript
-6.9014328 8.5771028 -8.0646378 9.8262213 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-23.679467 26.179273 -27.580713 30.208686 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-79.761194 83.490467 -92.772367 96.692843 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-266.52104 272.08446 -309.80705 315.65571 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-887.42391 895.72356 -1031.2689 1039.9941 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2950.1447 2962.5263 -3427.9213 3440.9378 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-9800.4846 9818.9558 -11387.049 11406.467 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-32547.197 32574.753 -37815.21 37844.179 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-108073.1 108114.2 -125564.16 125607.38 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-358834.1 358895.43 -416907.44 416971.92 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1191399.2 1191490.7 -1384210.9 1384307.1 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3955626.5 3955763. -4595786.1 4595929.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-13133205. 13133408. -15258613. 15258827. MAarrowhead1
% End of user PostScript
.388 1 0 r
.66874 .51331 m
.69101 .50037 L
.71663 .48456 L
.74613 .46538 L
.78012 .44224 L
.81931 .41445 L
.86452 .38122 L
.91672 .34162 L
.97702 .29457 L
s
.97702 .29457 m
1 .27618 L
s
1 0 0 r
.66874 .51331 m
.69101 .50037 L
s
% Start of user PostScript
5.0621066 0.39937106 5.7303692 0.011124359 MAarrowhead1
% End of user PostScript
1 .158 0 r
.71663 .48456 m
.74613 .46538 L
s
% Start of user PostScript
6.4990398 -0.46317353 7.3839708 -1.0386391 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
18.81874 -9.8142857 21.615366 -12.149244 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
58.364724 -44.931657 67.438834 -53.317039 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
187.63781 -167.59803 217.45012 -196.38288 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
613.81984 -583.924 712.33056 -680.90193 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2024.289 -1979.6897 2350.6556 -2303.7696 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6700.4912 -6633.9567 7783.021 -7713.0753 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
22216.003 -22116.745 25808.569 -25704.223 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
73714.36 -73566.284 85639.774 -85484.107 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
244672.61 -244451.71 284262.91 -284030.68 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
812240.71 -811911.16 943679.96 -943333.52 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2696583.5 -2696091.9 3132969.5 -3132452.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
8952747.8 -8952014.4 10401589. -10400818. MAarrowhead1
% End of user PostScript
1 .402 0 r
.56445 .76363 m
.56581 .77909 L
.56693 .79565 L
.56774 .81343 L
.56816 .83255 L
.56812 .85314 L
.5675 .87536 L
.56618 .89938 L
.56402 .92541 L
.56085 .95367 L
.55648 .98443 L
s
.55648 .98443 m
.55378 1 L
s
1 0 0 r
.56445 .76363 m
.56581 .77909 L
s
% Start of user PostScript
1.9334518 7.9088543 1.9743014 8.3726305 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56693 .79565 m
.56774 .81343 L
s
% Start of user PostScript
2.0078136 8.8696168 2.0320859 9.4030424 MAarrowhead1
% End of user PostScript
1 .473 0 r
.55648 .98443 m
0 0 rlineto s
.55648 .98443 m
.55378 1 L
s
% Start of user PostScript
1.6943956 14.532824 1.5200737 15.539133 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.7914334 25.9996 -2.7504814 28.199827 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-17.012669 53.12701 -20.76413 58.730093 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-72.990942 126.86721 -86.292559 142.93112 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-266.96385 347.3378 -312.38934 396.88415 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-923.08797 1042.9918 -1075.7894 1201.8409 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-3119.5648 3298.4403 -3629.3615 3817.4081 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-10439.079 10705.93 -12135.855 12416.388 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-34780.933 35179.028 -40420.683 40839.189 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-115658.72 116252.61 -134392.68 135017.02 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-384271.94 385157.91 -446484.78 447416.18 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1276232.7 1277554.4 -1482807.4 1484196.9 MAarrowhead1
% End of user PostScript
0 .105 1 r
.54135 .68326 m
.54183 .6943 L
.54207 .70616 L
.54202 .71894 L
.54161 .73273 L
.54076 .74765 L
.53938 .76381 L
.53738 .78136 L
.53462 .80047 L
.53096 .82131 L
.52623 .8441 L
.52024 .86907 L
.51275 .89652 L
.5035 .92675 L
.49218 .96014 L
.47841 .9971 L
s
.47841 .9971 m
.47723 1 L
s
1 0 0 r
.54135 .68326 m
.54183 .6943 L
s
% Start of user PostScript
1.2404353 5.497945 1.254926 5.8289383 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54207 .70616 m
.54202 .71894 L
s
% Start of user PostScript
1.2622125 6.1848494 1.260639 6.5682419 MAarrowhead1
% End of user PostScript
1 .473 0 r
.52623 .8441 m
.52024 .86907 L
s
% Start of user PostScript
0.78684159 10.322869 0.60709836 11.07222 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-2.4655434 19.039284 -3.322664 20.746159 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-15.761303 40.486419 -18.995443 44.988243 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-63.630552 100.51609 -74.9477 113.7244 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-228.12026 283.14702 -266.55891 324.40695 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-782.53718 864.62746 -911.44754 997.74667 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2635.6362 2758.1005 -3065.5574 3194.3006 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-8806.5955 8989.2908 -10236.854 10428.916 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-29322.432 29594.981 -34075.339 34361.862 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-97478.477 97885.073 -113265.07 113692.51 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-323825.79 324432.35 -376248.65 376886.32 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1075416.7 1076321.6 -1249481. 1250432.3 MAarrowhead1
% End of user PostScript
0 1 .711 r
.49 .50624 m
.48848 .50757 L
.48673 .50912 L
.4847 .51094 L
.48234 .51307 L
.47961 .51557 L
.47644 .51848 L
.47277 .5219 L
.46851 .52588 L
.46357 .53054 L
.45784 .53597 L
.45119 .5423 L
.44347 .54969 L
.43451 .55829 L
.42411 .56832 L
.41204 .58001 L
.39802 .59362 L
.38175 .60946 L
.36286 .6279 L
.34092 .64937 L
.31544 .67435 L
.28586 .70341 L
.2515 .73722 L
.2116 .77654 L
.16525 .82228 L
.11142 .87547 L
.0489 .93732 L
s
.0489 .93732 m
0 .98574 L
s
1 0 0 r
.49 .50624 m
.48848 .50757 L
s
% Start of user PostScript
-0.30001333 0.18733041 -0.34545111 0.22699082 MAarrowhead1
% End of user PostScript
1 .158 0 r
.48673 .50912 m
.4847 .51094 L
s
% Start of user PostScript
-0.3980826 0.27354872 -0.45906378 0.32814491 MAarrowhead1
% End of user PostScript
1 .473 0 r
.45784 .53597 m
.45119 .5423 L
s
% Start of user PostScript
-1.2647597 1.078977 -1.4643059 1.2689979 MAarrowhead1
% End of user PostScript
1 .788 0 r
.36286 .6279 m
.34092 .64937 L
s
% Start of user PostScript
-4.1142337 3.8370785 -4.7723969 4.4810316 MAarrowhead1
% End of user PostScript
.897 1 0 r
.0489 .93732 m
0 0 rlineto s
.0489 .93732 m
0 .98574 L
s
% Start of user PostScript
-13.533057 13.11959 -15.71174 15.277074 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-44.742347 44.125526 -51.966141 51.317696 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-148.26789 147.3477 -172.23728 171.26991 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-491.84614 490.47338 -571.40574 569.9626 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-1632.3592 1630.3113 -1896.4742 1894.3213 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-5418.6875 5415.6323 -6295.5322 6292.3204 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-17989.28 17984.722 -20900.435 20895.644 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-59724.428 59717.629 -69389.698 69382.55 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-198288.98 198278.83 -230378.64 230367.98 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-658337.95 658322.82 -764879.16 764863.25 MAarrowhead1
% End of user PostScript
.495 0 1 r
.47382 .66492 m
.46575 .6801 L
.45617 .69715 L
.44484 .71634 L
.43146 .73799 L
.41569 .76245 L
.39712 .79016 L
.37529 .82158 L
.34967 .8573 L
.31962 .89796 L
.28441 .94433 L
.2432 .99727 L
s
.2432 .99727 m
.24102 1 L
s
1 0 0 r
.47382 .66492 m
.46575 .6801 L
s
% Start of user PostScript
-0.78539913 4.9474741 -1.0275466 5.4030157 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45617 .69715 m
.44484 .71634 L
s
% Start of user PostScript
-1.3147803 5.9145844 -1.6546989 6.4903401 MAarrowhead1
% End of user PostScript
1 .473 0 r
.28441 .94433 m
.2432 .99727 L
s
% Start of user PostScript
-6.4676708 13.329772 -7.7040352 14.917964 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-24.609905 34.846957 -28.87559 39.637508 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-86.386842 101.65873 -100.78932 116.84421 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-293.79479 316.57777 -341.97058 365.92167 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-985.84653 1019.8347 -1146.3297 1182.0605 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3288.6608 3339.3653 -3822.2803 3875.5844 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-10941.914 11017.556 -12714.781 12794.302 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-36363.008 36475.853 -42250.907 42369.538 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-120781.02 120949.36 -140332.17 140509.15 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-401084.05 401335.19 -466000.12 466264.14 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1331760.7 1332135.4 -1547295.6 1547689.4 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-4421772.5 4422331.5 -5137382.2 5137969.8 MAarrowhead1
% End of user PostScript
0 .715 1 r
.65233 .82704 m
.66373 .84022 L
.6763 .85349 L
.69018 .86676 L
.70557 .87993 L
.72265 .89287 L
.74167 .90541 L
.7629 .91736 L
.78664 .92849 L
.81326 .93854 L
.84317 .94717 L
.87687 .954 L
.91489 .95857 L
.95789 .96035 L
s
.95789 .96035 m
1 .95894 L
s
1 0 0 r
.65233 .82704 m
.66373 .84022 L
s
% Start of user PostScript
4.5698078 9.8111744 4.9118576 10.206453 MAarrowhead1
% End of user PostScript
1 .158 0 r
.6763 .85349 m
.69018 .86676 L
s
% Start of user PostScript
5.2888823 10.604561 5.7054973 11.00282 MAarrowhead1
% End of user PostScript
1 .473 0 r
.84317 .94717 m
.87687 .954 L
s
% Start of user PostScript
10.295243 13.414988 11.305996 13.619884 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
23.344103 12.027406 26.144281 11.040763 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
61.337786 -8.5696964 69.805789 -14.332221 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
179.52975 -100.80901 206.40791 -123.65107 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
560.07863 -442.64109 647.47247 -524.01377 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1805.849 -1630.6528 2093.2547 -1909.0759 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
5915.5524 -5654.1903 6865.6671 -6590.9047 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
19520.864 -19130.958 22669.231 -22259.334 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
64633.335 -64051.663 75077.144 -74465.649 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
214324.36 -213456.61 248985.4 -248073.16 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
711185.32 -709890.79 826243.68 -824882.77 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2360626.7 -2358695.5 2742603.6 -2740573.3 MAarrowhead1
% End of user PostScript
0 .897 1 r
.35086 .54299 m
.32966 .55875 L
.30518 .57751 L
.27689 .59979 L
.24419 .62616 L
.20638 .65733 L
.16263 .69409 L
.11199 .73738 L
.05336 .78829 L
s
.05336 .78829 m
0 .83527 L
s
1 0 0 r
.35086 .54299 m
.32966 .55875 L
s
% Start of user PostScript
-4.4741292 1.2898014 -5.1101792 1.7625875 MAarrowhead1
% End of user PostScript
1 .158 0 r
.30518 .57751 m
.27689 .59979 L
s
% Start of user PostScript
-5.8446512 2.3254247 -6.6932417 2.9935806 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-17.796382 12.546313 -20.531329 15.012084 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-56.686403 48.85422 -65.643716 57.409969 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-184.6256 172.94136 -214.18139 201.89808 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-607.63804 590.2072 -705.49288 687.16834 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2009.4622 1983.4584 -2333.9432 2306.6062 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6659.7638 6620.9707 -7736.4693 7695.6873 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-22093.463 22035.591 -25667.342 25606.503 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-73326.429 73240.093 -85190.77 85100.008 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-243412.86 243284.06 -282801.83 282666.43 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-808100.27 807908.13 -938873.26 938671.26 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2682899.6 2682612.9 -3117076.7 3116775.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-8907409.2 8906981.6 -10348921. 10348472. MAarrowhead1
% End of user PostScript
1 0 .639 r
.34137 .67964 m
.31512 .70696 L
.28459 .73863 L
.24909 .77532 L
.20781 .81785 L
.15981 .86716 L
.10401 .92435 L
.03914 .99067 L
s
.03914 .99067 m
.03 1 L
s
1 0 0 r
.34137 .67964 m
.31512 .70696 L
s
% Start of user PostScript
-4.7588003 5.3890574 -5.546358 6.2089291 MAarrowhead1
% End of user PostScript
1 .158 0 r
.28459 .73863 m
.24909 .77532 L
s
% Start of user PostScript
-6.4622626 7.1588044 -7.5273309 8.2595852 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-21.773838 22.812956 -25.326313 26.418708 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-72.766641 74.316823 -84.585623 86.215285 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-242.3023 244.6149 -281.57903 284.0102 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-805.529 808.97899 -935.98654 939.61342 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2676.0274 2681.1742 -3109.2425 3114.6532 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-8887.0762 8894.7543 -10325.522 10333.593 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-29509.642 29521.096 -34285.629 34297.67 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-97980.696 97997.784 -113837.8 113855.76 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-325315.18 325340.67 -377963.02 377989.82 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1080096.1 1080134.1 -1254893.7 1254933.6 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3586062.6 3586119.4 -4166411.9 4166471.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-11906173. 11906258. -13833002. 13833091. MAarrowhead1
% End of user PostScript
1 0 .666 r
.71751 .34769 m
.7509 .31764 L
.78961 .28244 L
.83449 .24126 L
.88653 .1931 L
.94688 .13683 L
s
.94688 .13683 m
1 .08697 L
s
1 0 0 r
.71751 .34769 m
.7509 .31764 L
s
% Start of user PostScript
6.5251715 -4.5692282 7.5271038 -5.4708773 MAarrowhead1
% End of user PostScript
1 .158 0 r
.78961 .28244 m
.83449 .24126 L
s
% Start of user PostScript
8.6884113 -6.5267597 10.034744 -7.7622622 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
27.858509 -24.633703 32.277833 -28.887689 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
91.019534 -86.20869 105.61664 -100.55913 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
299.99659 -292.81965 348.34793 -340.80303 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
992.74337 -982.03664 1153.1073 -1141.8516 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3291.1303 -3275.1577 3823.3064 -3806.5149 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
10919.637 -10895.808 12686.149 -12661.099 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
36243.579 -36208.032 42108.049 -42070.679 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
120316.67 -120263.64 139786.57 -139730.82 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
399441.19 -399362.07 464082.26 -463999.09 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1326155.3 -1326037.3 1540769.4 -1540645.3 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4402936.6 -4402760.6 5115477.7 -5115292.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
14618184. -14617921. 16983899. -16983623. MAarrowhead1
% End of user PostScript
.202 1 0 r
.77472 .39138 m
.81459 .36003 L
.86067 .32289 L
.91397 .27901 L
.97563 .22725 L
s
.97563 .22725 m
1 .20642 L
s
1 0 0 r
.77472 .39138 m
.81459 .36003 L
s
% Start of user PostScript
8.2415573 -3.2586413 9.4375918 -4.1991962 MAarrowhead1
% End of user PostScript
1 .158 0 r
.86067 .32289 m
.91397 .27901 L
s
% Start of user PostScript
10.820124 -5.31315 12.418973 -6.6296509 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
33.406987 -25.191547 38.5863 -29.949646 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
107.16005 -94.904051 124.16345 -111.27907 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
350.182 -331.8982 406.34806 -387.12683 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1154.2882 -1127.0119 1340.3376 -1311.6629 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3819.9044 -3779.2131 4436.971 -4394.1934 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
12663.93 -12603.226 14711.71 -14647.893 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
42017.983 -41927.423 48815.429 -48720.225 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
139463.22 -139328.12 162029.42 -161887.39 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
462972.46 -462770.92 537891.69 -537679.81 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1537030.6 -1536729.9 1785766.5 -1785450.4 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
5102983.8 -5102535.3 5928808.9 -5928337.4 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
16942298. -16941629. 19684123. -19683420. MAarrowhead1
% End of user PostScript
.357 0 1 r
.5581 .8007 m
.55758 .81961 L
.55648 .84006 L
.55466 .86221 L
.55198 .88626 L
.54828 .91243 L
.54336 .94098 L
.53699 .97218 L
s
.53699 .97218 m
.5304 1 L
s
1 0 0 r
.5581 .8007 m
.55758 .81961 L
s
% Start of user PostScript
1.7429725 9.0210827 1.7275182 9.5884219 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55648 .84006 m
.55466 .86221 L
s
% Start of user PostScript
1.6943083 10.201812 1.6396873 10.866361 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
0.18790538 17.559021 -0.27222411 18.929055 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-7.4877742 33.963078 -9.4313507 37.264072 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-36.961434 76.457945 -44.034774 85.556315 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-140.76907 199.69094 -165.17898 227.12184 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-494.30138 582.20248 -576.72593 669.13382 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1681.3156 1812.4486 -1957.0347 2094.891 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-5642.1018 5837.7293 -6560.5943 6766.2519 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-18821.854 19113.696 -21875.941 22182.746 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-62624.148 63059.525 -72770.914 73228.613 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-208118.49 208768. -241817.14 242499.95 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-691274.6 692243.55 -803173.28 804191.91 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2295555.4 2297000.9 -2667094.8 2668614.4 MAarrowhead1
% End of user PostScript
0 .614 1 r
.39925 .21162 m
.3937 .19722 L
.3878 .18214 L
.38153 .16636 L
.37486 .14986 L
.36774 .1326 L
.36015 .11458 L
.35204 .09576 L
.34335 .07613 L
.33405 .05567 L
.32406 .03437 L
.31332 .01222 L
s
.31332 .01222 m
.30718 0 L
s
1 0 0 r
.39925 .21162 m
.3937 .19722 L
s
% Start of user PostScript
-3.0225516 -8.6513513 -3.1890281 -9.0834086 MAarrowhead1
% End of user PostScript
1 .158 0 r
.3878 .18214 m
.38153 .16636 L
s
% Start of user PostScript
-3.3659022 -9.5357557 -3.5540085 -10.009132 MAarrowhead1
% End of user PostScript
1 .473 0 r
.32406 .03437 m
.31332 .01222 L
s
% Start of user PostScript
-5.2781888 -13.968823 -5.6003779 -14.63345 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-8.7269132 -19.986255 -9.345572 -20.839751 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-15.850357 -26.984656 -17.231494 -27.799717 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-33.046308 -30.856023 -36.628021 -30.550652 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-80.509572 -14.821503 -90.903751 -9.3150519 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-223.72793 81.510674 -256.00377 106.49488 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-677.7992 465.63599 -781.62596 558.58491 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-2153.3985 1836.8882 -2493.1435 2160.4054 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-7004.8665 6532.6886 -8125.4424 7629.0554 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-23041.156 22336.749 -26750.534 26010.011 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-76177.366 75126.515 -88476.426 87371.697 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-252437.45 250869.76 -293247.14 291599.08 MAarrowhead1
% End of user PostScript
.524 1 0 r
.70594 .33662 m
.7381 .30665 L
.77539 .27165 L
.81866 .23079 L
.86886 .18312 L
.92712 .12753 L
.99473 .06272 L
s
.99473 .06272 m
1 .05765 L
s
1 0 0 r
.70594 .33662 m
.7381 .30665 L
s
% Start of user PostScript
6.1783287 -4.9014261 7.1428993 -5.8005284 MAarrowhead1
% End of user PostScript
1 .158 0 r
.77539 .27165 m
.81866 .23079 L
s
% Start of user PostScript
8.2617608 -6.8505651 9.55979 -8.0762408 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
26.784992 -24.679736 31.06153 -28.848335 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
87.96705 -84.826376 102.11632 -98.814621 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
290.62537 -285.94004 337.52901 -332.60345 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
962.76868 -955.77898 1118.3844 -1111.0364 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3193.3098 -3182.8824 3709.8084 -3698.8464 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
10597.396 -10581.84 12311.987 -12295.634 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
35177.483 -35154.276 40869.763 -40845.366 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
116782.75 -116748.13 135681.24 -135644.85 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
387716.56 -387664.91 450460.95 -450406.65 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1287240.7 -1287163.7 1495558.2 -1495477.2 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4273754.4 -4273639.5 4965391. -4965270.2 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
14189312. -14189140. 16485624. -16485443. MAarrowhead1
% End of user PostScript
1 0 .234 r
.75888 .57595 m
.79153 .56048 L
.82898 .54107 L
.87199 .51704 L
.92143 .48753 L
.97833 .4516 L
s
.97833 .4516 m
1 .43722 L
s
1 0 0 r
.75888 .57595 m
.79153 .56048 L
s
% Start of user PostScript
7.7665349 2.2784761 8.7457742 1.8142555 MAarrowhead1
% End of user PostScript
1 .158 0 r
.82898 .54107 m
.87199 .51704 L
s
% Start of user PostScript
9.8692524 1.2322016 11.159582 0.51105527 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
27.692896 -11.131473 31.716785 -14.306239 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
84.373874 -59.667133 97.345542 -71.37206 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
268.83834 -231.98022 311.3268 -272.57892 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
875.72787 -820.74201 1015.9308 -958.12573 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2882.3864 -2800.3571 3346.5878 -3260.3528 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9532.3664 -9409.9931 11071.647 -10943. MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
31592.637 -31410.078 36700.362 -36508.442 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
104807.81 -104535.46 121761.77 -121475.46 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
347849.69 -347443.4 404132.45 -403705.33 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1154715.9 -1154109.8 1341571.8 -1340934.6 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3833514.9 -3832610.7 4453883.9 -4452933.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
12727304. -12725955. 14786981. -14785563. MAarrowhead1
% End of user PostScript
0 1 .365 r
.76581 .81498 m
.79277 .8178 L
.82327 .8186 L
.85785 .81694 L
.89711 .81227 L
.94176 .80398 L
.99264 .79134 L
s
.99264 .79134 m
1 .78908 L
s
1 0 0 r
.76581 .81498 m
.79277 .8178 L
s
% Start of user PostScript
7.9741656 9.4495291 8.783054 9.5339726 MAarrowhead1
% End of user PostScript
1 .158 0 r
.82327 .8186 m
.85785 .81694 L
s
% Start of user PostScript
9.6981559 9.5580048 10.735394 9.508051 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
23.397539 5.3292767 26.390031 3.8096408 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
64.552313 -21.696939 73.814531 -28.761915 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
194.73319 -130.80048 224.48054 -157.26993 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
617.31504 -521.93865 714.58147 -614.31503 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2005.9641 -1863.6793 2326.665 -2177.085 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6595.0009 -6382.7368 7656.4307 -7433.2837 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
21799.154 -21482.493 25318.251 -24985.354 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
72231.003 -71758.6 83907.395 -83410.772 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
239599.45 -238894.71 278355.37 -277614.49 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
795176.08 -794124.73 923833.73 -922728.48 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2639597. -2638028.6 3066730.8 -3065082. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
8763053.8 -8760714. 10181151. -10178692. MAarrowhead1
% End of user PostScript
.862 0 1 r
.32899 .48746 m
.30639 .50065 L
.28039 .51676 L
.25046 .53629 L
.21597 .55985 L
.1762 .58812 L
.13032 .62193 L
.07734 .6622 L
.01613 .71005 L
s
.01613 .71005 m
0 .72298 L
s
1 0 0 r
.32899 .48746 m
.30639 .50065 L
s
% Start of user PostScript
-5.1301788 -0.37615605 -5.808218 0.019567299 MAarrowhead1
% End of user PostScript
1 .158 0 r
.28039 .51676 m
.25046 .53629 L
s
% Start of user PostScript
-6.5881837 0.50274253 -7.4861711 1.0887226 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-19.092049 10.013638 -21.930862 12.38699 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-59.238338 45.694939 -68.450779 54.212996 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-190.48789 170.28351 -220.75688 199.51661 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-623.20718 593.06579 -723.23031 691.54354 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2055.3439 2010.3782 -2386.726 2339.4549 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6803.4294 6736.3485 -7902.6031 7832.0829 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-22557.52 22457.447 -26205.333 26100.13 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-74847.864 74698.573 -86956.685 86799.739 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-248435.42 248212.71 -288634.62 288400.49 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-824732.85 824400.6 -958193.69 957844.4 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2738057.6 2737562. -3181155.4 3180634.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-9090444.9 9089705.5 -10561570. 10560792. MAarrowhead1
% End of user PostScript
1 0 .718 r
.71038 .71141 m
.73276 .71065 L
.75818 .70797 L
.78707 .70297 L
.81999 .69519 L
.85753 .68405 L
.90042 .66893 L
.94949 .64906 L
s
.94949 .64906 m
1 .62613 L
s
1 0 0 r
.71038 .71141 m
.73276 .71065 L
s
% Start of user PostScript
6.3112699 6.3423274 6.9828941 6.319467 MAarrowhead1
% End of user PostScript
1 .158 0 r
.75818 .70797 m
.78707 .70297 L
s
% Start of user PostScript
7.7452777 6.2391099 8.6121894 6.0891932 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
19.323341 1.5389141 21.87387 0.058015644 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
54.620176 -23.497349 62.599332 -29.880803 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
167.11997 -120.69016 192.88234 -144.07203 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
533.63602 -464.37089 618.08205 -545.26563 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1740.0747 -1636.7433 2018.8223 -1910.1929 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5730.0216 -5575.8692 6653.0744 -6491.0185 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
18953.883 -18723.914 22014.914 -21773.155 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
62823.995 -62480.922 72981.586 -72620.923 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
208426.2 -207914.39 242142.55 -241604.5 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
691765.42 -691001.9 803695.65 -802892.98 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2296393.1 -2295254. 2667996.6 -2666799.2 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
7623772.9 -7622073.7 8857513.5 -8855727.1 MAarrowhead1
% End of user PostScript
0 1 .487 r
.52238 .68593 m
.52024 .69875 L
.51747 .71275 L
.51393 .72809 L
.50949 .74493 L
.504 .76348 L
.49725 .78394 L
.48904 .80657 L
.47909 .83167 L
.46712 .85958 L
.45277 .89068 L
.43563 .92542 L
.41523 .96433 L
s
.41523 .96433 m
.39546 1 L
s
1 0 0 r
.52238 .68593 m
.52024 .69875 L
s
% Start of user PostScript
0.67139184 5.5778831 0.60731115 5.9623709 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51747 .71275 m
.51393 .72809 L
s
% Start of user PostScript
0.52400371 6.3825132 0.4179039 6.8427177 MAarrowhead1
% End of user PostScript
1 .473 0 r
.45277 .89068 m
.43563 .92542 L
s
% Start of user PostScript
-1.4170292 11.720342 -1.9311447 12.762719 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-9.4140691 24.784805 -11.362447 27.521258 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-38.281359 61.211803 -45.11041 69.216522 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-137.57948 171.78768 -160.79009 196.75218 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-472.4156 523.44824 -550.2792 603.92834 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1591.8007 1667.9324 -1851.5129 1931.548 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-5319.7621 5433.3373 -6183.8211 6303.2194 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-17714.144 17883.579 -20585.583 20763.704 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-58890.474 59143.241 -68427.956 68693.682 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-195638.79 196015.88 -227310.27 227706.69 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-649716.02 650278.56 -754877.87 755469.26 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2157390.3 2158229.5 -2506553.1 2507435.3 MAarrowhead1
% End of user PostScript
0 .011 1 r
.53331 .63803 m
.53396 .64616 L
.53448 .65488 L
.53483 .66424 L
.53496 .67432 L
.53484 .68517 L
.53439 .6969 L
.53357 .70958 L
.53228 .72334 L
.53044 .73828 L
.52793 .75456 L
.52465 .77233 L
.52043 .79178 L
.5151 .81311 L
.50847 .83657 L
.50031 .86242 L
.49033 .891 L
.47823 .92266 L
.46362 .95781 L
.44608 .99696 L
s
.44608 .99696 m
.44462 1 L
s
1 0 0 r
.53331 .63803 m
.53396 .64616 L
s
% Start of user PostScript
0.9993007 4.1409703 1.0189406 4.3848777 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53448 .65488 m
.53483 .66424 L
s
% Start of user PostScript
1.0344743 4.6464037 1.0448638 4.9272791 MAarrowhead1
% End of user PostScript
1 .473 0 r
.52793 .75456 m
.52465 .77233 L
s
% Start of user PostScript
0.83799944 7.6368747 0.73936426 8.170026 MAarrowhead1
% End of user PostScript
1 .788 0 r
.46362 .95781 m
.44608 .99696 L
s
% Start of user PostScript
-1.0913805 13.734407 -1.6174665 14.908715 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-9.4022977 28.263477 -11.445249 31.273462 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-39.837665 67.975238 -47.062508 76.642725 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-145.12663 187.10296 -169.77335 213.90185 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-501.02363 563.64495 -583.83731 649.6693 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-1692.0796 1785.4996 -1968.4982 2066.708 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-5660.6018 5799.9681 -6580.5331 6727.0449 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-18857.56 19065.47 -21915.106 22133.676 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-62704.335 63014.501 -72860.617 73186.685 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-208327.49 208790.2 -242054.8 242541.24 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-691883.13 692573.41 -803872.59 804598.27 MAarrowhead1
% End of user PostScript
.052 0 1 r
.60001 .54508 m
.61219 .54034 L
.62613 .53422 L
.64211 .52646 L
.66044 .51677 L
.68151 .50479 L
.70574 .49011 L
.73362 .47227 L
.76574 .45071 L
.80276 .42479 L
.84546 .39375 L
.89476 .35671 L
.9517 .31267 L
s
.9517 .31267 m
1 .27432 L
s
1 0 0 r
.60001 .54508 m
.61219 .54034 L
s
% Start of user PostScript
3.0003576 1.3523013 3.3656073 1.2102172 MAarrowhead1
% End of user PostScript
1 .158 0 r
.62613 .53422 m
.64211 .52646 L
s
% Start of user PostScript
3.7837984 1.0266336 4.2631825 0.79388572 MAarrowhead1
% End of user PostScript
1 .473 0 r
.84546 .39375 m
.89476 .35671 L
s
% Start of user PostScript
10.363934 -3.187613 11.842815 -4.2985554 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
31.129371 -20.423557 35.871252 -24.61654 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
98.459812 -82.488615 113.95252 -97.162467 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
319.59808 -295.77186 370.66142 -345.6136 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1050.2127 -1014.6681 1219.1906 -1181.8236 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3470.5824 -3417.5562 4030.7758 -3975.0309 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
11498.503 -11419.397 13357.167 -13274.006 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
38140.216 -38022.204 44309.347 -44185.284 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
126576.04 -126399.98 147055.51 -146870.43 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
420166.77 -419904.13 488156.88 -487880.77 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1394882.8 -1394490.9 1620611.7 -1620199.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4630994.8 -4630410.2 5380432.1 -5379817.6 MAarrowhead1
% End of user PostScript
0 .312 1 r
.67393 .61968 m
.69396 .6147 L
.71682 .60767 L
.74294 .59818 L
.77282 .58579 L
.80706 .56993 L
.84633 .54999 L
.89143 .52522 L
.94326 .49475 L
s
.94326 .49475 m
1 .45938 L
s
1 0 0 r
.67393 .61968 m
.69396 .6147 L
s
% Start of user PostScript
5.217801 3.5903109 5.8187568 3.4409567 MAarrowhead1
% End of user PostScript
1 .158 0 r
.71682 .60767 m
.74294 .59818 L
s
% Start of user PostScript
6.5044851 3.229984 7.2880651 2.9455009 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
17.146288 -2.624166 19.519741 -4.2530545 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
50.290009 -28.625549 57.829832 -35.054612 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
157.06647 -124.74689 181.59186 -147.61523 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
506.70663 -458.49149 587.37641 -536.68923 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1660.2874 -1588.3589 1926.9906 -1851.3742 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5479.4718 -5372.167 6363.272 -6250.4656 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
18143.441 -17983.361 21075.246 -20906.959 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
60165.177 -59926.366 69895.362 -69644.307 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
199646.27 -199290. 231946.02 -231571.49 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
662686.11 -662154.63 769916.73 -769358. MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2199952.5 -2199159.6 2555958.2 -2555124.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
7303737. -7302554.1 8485699. -8484455.5 MAarrowhead1
% End of user PostScript
0 .567 1 r
.45786 .65358 m
.44796 .66919 L
.4363 .68686 L
.42259 .70688 L
.40649 .72963 L
.38759 .7555 L
.36544 .78498 L
.33951 .81863 L
.30916 .85708 L
.27369 .90109 L
.23223 .9515 L
s
.23223 .9515 m
.19163 1 L
s
1 0 0 r
.45786 .65358 m
.44796 .66919 L
s
% Start of user PostScript
-1.2641089 4.60729 -1.5610932 5.0756828 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4363 .68686 m
.42259 .70688 L
s
% Start of user PostScript
-1.9108775 5.605664 -2.3222498 6.206472 MAarrowhead1
% End of user PostScript
1 .473 0 r
.23223 .9515 m
0 0 rlineto s
.23223 .9515 m
.19163 1 L
s
% Start of user PostScript
-8.0331242 13.545098 -9.4855141 15.280093 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-29.190286 37.413185 -34.141562 42.786057 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-100.67363 112.94075 -117.30514 130.20121 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-339.85519 358.15559 -395.36123 414.59991 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1136.7236 1164.0246 -1321.439 1350.1397 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3786.5338 3827.262 -4400.4503 4443.2668 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-12590.351 12651.11 -14629.58 14693.455 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-41829.208 41919.85 -48601.111 48696.401 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-138919.29 139054.51 -161404.93 161547.08 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-461290.09 461491.82 -535948.2 536160.27 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1531629.3 1531930.2 -1779507.6 1779824. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-5085325.7 5085774.7 -5908318. 5908790. MAarrowhead1
% End of user PostScript
0 .641 1 r
.31451 .36925 m
.29323 .37431 L
.26896 .38154 L
.24123 .39135 L
.20951 .40423 L
.17318 .42077 L
.13151 .44161 L
.08367 .46756 L
.0287 .49953 L
s
.0287 .49953 m
0 .51725 L
s
1 0 0 r
.31451 .36925 m
.29323 .37431 L
s
% Start of user PostScript
-5.5646438 -3.9225087 -6.2029613 -3.7706079 MAarrowhead1
% End of user PostScript
1 .158 0 r
.26896 .38154 m
.24123 .39135 L
s
% Start of user PostScript
-6.9311356 -3.5537895 -7.7630191 -3.2594796 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-18.219804 2.5781337 -20.736044 4.2924082 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-53.342493 30.007863 -61.330147 36.799126 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-166.43768 131.62651 -192.41079 155.81481 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-536.68132 484.74914 -622.09929 567.50449 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1758.1079 1680.6342 -2040.4886 1959.0427 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5801.7127 5686.1356 -6737.4339 6615.9309 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-19209.537 19037.117 -22313.533 22132.271 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-63699.101 63441.88 -74000.687 73730.278 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-211370.9 210987.17 -245567.34 245163.93 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-701600.69 701028.24 -815127.89 814526.08 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2329134.7 2328280.7 -2706044.8 2705147. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-7732609.1 7731335.1 -8983974.9 8982635.5 MAarrowhead1
% End of user PostScript
1 .753 0 r
.5263 .53099 m
.52898 .53126 L
.532 .53132 L
.53543 .53114 L
.53932 .53066 L
.54375 .52982 L
.5488 .52854 L
.55456 .52675 L
.56114 .52434 L
.56867 .52119 L
.5773 .51717 L
.5872 .51211 L
.59857 .50584 L
.61163 .49812 L
.62666 .48872 L
.64397 .47732 L
.66392 .4636 L
.68692 .44713 L
.71347 .42746 L
.74412 .40403 L
.77953 .37622 L
.82047 .34327 L
.8678 .30433 L
.92257 .25839 L
.98595 .20428 L
s
.98595 .20428 m
1 .1921 L
s
1 0 0 r
.5263 .53099 m
.52898 .53126 L
s
% Start of user PostScript
0.78908652 0.92982738 0.86927561 0.93776889 MAarrowhead1
% End of user PostScript
1 .158 0 r
.532 .53132 m
.53543 .53114 L
s
% Start of user PostScript
0.96000604 0.93968762 1.0628589 0.93423417 MAarrowhead1
% End of user PostScript
1 .473 0 r
.5773 .51717 m
.5872 .51211 L
s
% Start of user PostScript
2.3190335 0.5149764 2.6159983 0.36331443 MAarrowhead1
% End of user PostScript
1 .788 0 r
.71347 .42746 m
.74412 .40403 L
s
% Start of user PostScript
6.4041128 -2.1762669 7.3236566 -2.8790443 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
19.329969 -13.022764 22.283884 -15.653301 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
61.294903 -51.885659 70.954439 -61.062772 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
199.20553 -185.16859 231.05582 -216.29919 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
654.96976 -634.0291 760.38748 -738.37317 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
2165.0048 -2133.765 2514.5132 -2481.6717 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
7173.7901 -7127.1858 8333.4668 -8284.473 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
23796.52 -23726.995 27645.69 -27572.6 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
78975.452 -78871.732 91753.517 -91644.479 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
262160.33 -262005.59 304582.57 -304419.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
870332.21 -870101.38 1011175.4 -1010932.7 MAarrowhead1
% End of user PostScript
0 1 .882 r
.22653 .64503 m
.18582 .67915 L
.13871 .71934 L
.08416 .76661 L
.02099 .82213 L
s
.02099 .82213 m
0 .84082 L
s
1 0 0 r
.22653 .64503 m
.18582 .67915 L
s
% Start of user PostScript
-8.2041631 4.3509552 -9.4253719 5.3746058 MAarrowhead1
% End of user PostScript
1 .158 0 r
.13871 .71934 m
.08416 .76661 L
s
% Start of user PostScript
-10.838753 6.5803002 -12.475128 7.9983391 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-34.039505 27.686639 -39.372664 32.69408 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-110.11141 100.63405 -127.66925 117.70597 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-361.25091 347.11235 -419.32288 404.45942 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1192.9329 1171.8407 -1385.4073 1363.2336 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3951.0361 3919.5701 -4589.5792 4556.5 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-13103.519 13056.578 -15222.82 15173.472 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-43483.761 43413.732 -50518.987 50445.368 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-144339.16 144234.69 -167695.29 167585.47 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-479175.14 479019.29 -556717.78 556553.94 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1590846.3 1590613.8 -1848293.2 1848048.8 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-5281689.3 5281342.5 -6136438. 6136073.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-17535668. 17535150. -20373525. 20372981. MAarrowhead1
% End of user PostScript
0 1 .883 r
.40344 .74485 m
.38372 .77217 L
.36059 .80329 L
.3335 .83879 L
.30179 .87933 L
.26471 .9257 L
.22137 .9788 L
s
.22137 .9788 m
.20374 1 L
s
1 0 0 r
.40344 .74485 m
.38372 .77217 L
s
% Start of user PostScript
-2.8967138 7.3453678 -3.4884655 8.165207 MAarrowhead1
% End of user PostScript
1 .158 0 r
.36059 .80329 m
.3335 .83879 L
s
% Start of user PostScript
-4.1822875 9.0988106 -4.9950214 10.16362 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-16.132894 23.467484 -18.946482 26.657125 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-56.915538 67.857461 -66.428864 77.931792 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-193.9675 210.29093 -225.80927 242.96963 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-651.45577 675.80747 -757.55672 783.15696 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2174.0398 2210.3683 -2526.8781 2565.0691 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-7234.6712 7288.8669 -8406.9868 8463.9611 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-24044.726 24125.576 -27938.221 28023.216 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-79868.255 79988.87 -92797.008 92923.807 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-265227.08 265407.01 -308154.87 308344.03 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-880667.15 880935.58 -1023196.7 1023478.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2924040.6 2924441.1 -3397261.6 3397682.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-9708339.7 9708937.1 -11279498. 11280126. MAarrowhead1
% End of user PostScript
1 0 .791 r
.7779 .72976 m
.80885 .72485 L
.84408 .71698 L
.88425 .70557 L
.93013 .68993 L
.9826 .66925 L
s
.9826 .66925 m
1 .66153 L
s
1 0 0 r
.7779 .72976 m
.80885 .72485 L
s
% Start of user PostScript
8.3371043 6.8927983 9.2653667 6.7453896 MAarrowhead1
% End of user PostScript
1 .158 0 r
.84408 .71698 m
.88425 .70557 L
s
% Start of user PostScript
10.32227 6.5093749 11.527527 6.1670949 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
26.577853 -1.467989 30.185004 -3.787729 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
76.764538 -39.305022 88.152258 -48.772152 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
237.74551 -181.86248 274.67622 -215.928 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
763.80025 -680.43256 885.10494 -797.4629 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2497.801 -2373.431 2898.5931 -2767.8465 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8236.1452 -8050.6071 9563.9072 -9368.8562 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
27260.161 -26983.37 31664.137 -31373.156 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
90380.407 -89967.485 104995.64 -104561.54 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
299884.78 -299268.78 348399.38 -347751.79 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
995370.99 -994452.01 1156430.7 -1155464.6 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3304328. -3302957.1 3839043.5 -3837602.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
10970129. -10968084. 12745415. -12743265. MAarrowhead1
% End of user PostScript
0 1 .65 r
.36005 .36513 m
.345 .3661 L
.3279 .36838 L
.30844 .37227 L
.28627 .37807 L
.26096 .38617 L
.23203 .39701 L
.19891 .41111 L
.16097 .42906 L
.11743 .45158 L
.06743 .47948 L
.00995 .51373 L
s
.00995 .51373 m
0 .52 L
s
1 0 0 r
.36005 .36513 m
.345 .3661 L
s
% Start of user PostScript
-4.1984293 -4.0459609 -4.6499975 -4.0170916 MAarrowhead1
% End of user PostScript
1 .158 0 r
.3279 .36838 m
.30844 .37227 L
s
% Start of user PostScript
-5.1629612 -3.9484991 -5.7466572 -3.8319577 MAarrowhead1
% End of user PostScript
1 .473 0 r
.06743 .47948 m
.00995 .51373 L
s
% Start of user PostScript
-12.977032 -0.61566965 -14.701447 0.4118328 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-36.872405 16.594478 -42.279125 20.961526 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-113.1522 82.901089 -130.62794 98.825818 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-361.85157 316.72222 -419.16414 371.72095 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1180.7621 1113.437 -1369.9889 1299.212 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3889.4958 3789.0586 -4516.1733 4410.5865 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-12867.674 12717.839 -14945.962 14788.445 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-42653.696 42430.169 -49550.346 49315.358 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-141513.09 141179.63 -164405.54 164054.98 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-469687.59 469190.12 -545685.37 545162.39 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1559190.3 1558448.2 -1811500.2 1810720. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-5176355. 5175247.8 -6014035.8 6012871.9 MAarrowhead1
% End of user PostScript
1 .839 0 r
.65627 .75995 m
.67005 .76751 L
.68548 .77452 L
.70278 .7808 L
.72223 .78614 L
.74414 .7903 L
.76888 .79296 L
.79687 .79378 L
.82858 .79235 L
.8646 .78817 L
.90556 .78068 L
.95222 .7692 L
s
.95222 .7692 m
1 .75461 L
s
1 0 0 r
.65627 .75995 m
.67005 .76751 L
s
% Start of user PostScript
4.6880308 7.798643 5.1015732 8.025306 MAarrowhead1
% End of user PostScript
1 .158 0 r
.68548 .77452 m
.70278 .7808 L
s
% Start of user PostScript
5.5643452 8.2355635 6.0834065 8.4240387 MAarrowhead1
% End of user PostScript
1 .473 0 r
.90556 .78068 m
.95222 .7692 L
s
% Start of user PostScript
12.16671 8.4203344 13.566659 8.0759065 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
30.985117 -0.27285558 35.150659 -2.8637462 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
88.836465 -43.019154 101.94682 -53.780406 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
274.00559 -205.6542 316.45979 -244.60395 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
878.48902 -776.52072 1017.8401 -910.64382 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2870.0793 -2717.9605 3330.3517 -3170.4336 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
9459.4695 -9232.5348 10984.063 -10745.493 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
31302.819 -30964.272 36359.329 -36003.425 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
103774.28 -103269.23 120554.55 -120023.6 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
344311.89 -343558.44 400012.52 -399220.44 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1142811.4 -1141687.3 1327726.3 -1326544.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3793753.6 -3792076.7 4407666.5 -4405903.6 MAarrowhead1
% End of user PostScript
.513 0 1 r
.2443 .69248 m
.20467 .72887 L
.15871 .77142 L
.10541 .82114 L
.04358 .87921 L
s
.04358 .87921 m
0 .92038 L
s
1 0 0 r
.2443 .69248 m
.20467 .72887 L
s
% Start of user PostScript
-7.6710342 5.7744182 -8.8600463 6.8661887 MAarrowhead1
% End of user PostScript
1 .158 0 r
.15871 .77142 m
.10541 .82114 L
s
% Start of user PostScript
-10.238793 8.1427085 -11.837843 9.6342899 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-33.035927 29.908936 -38.295839 35.008524 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-108.25388 103.58895 -125.64412 120.74002 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-357.28332 350.32407 -414.91164 407.59558 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1183.0415 1172.6595 -1374.2112 1363.2969 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3923.0908 3907.6027 -4557.5532 4541.271 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-13018.041 12994.936 -15124.167 15099.877 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-43210.857 43176.388 -50202.901 50166.664 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-143449.34 143397.92 -166662.94 166608.88 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-476245.09 476168.38 -553315.73 553235.09 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1581154.3 1581039.9 -1837036.1 1836915.8 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-5249564.9 5249394.2 -6099119.6 6098940.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-17429091. 17428837. -20249708. 20249440. MAarrowhead1
% End of user PostScript
.747 1 0 r
.30728 .81498 m
.27272 .85581 L
.23238 .90274 L
.18534 .95671 L
s
.18534 .95671 m
.14712 1 L
s
1 0 0 r
.30728 .81498 m
.27272 .85581 L
s
% Start of user PostScript
-5.7814997 9.4493406 -6.8185263 10.674421 MAarrowhead1
% End of user PostScript
1 .158 0 r
.23238 .90274 m
.18534 .95671 L
s
% Start of user PostScript
-8.0285773 12.082168 -9.4399205 13.701344 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-28.508603 34.55585 -33.289421 39.646718 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-97.415928 106.43736 -113.43052 122.91449 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-327.55572 341.01412 -380.93746 395.08588 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1093.6748 1113.7523 -1271.2238 1292.3307 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3640.305 3670.2573 -4230.259 4261.7468 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-12099.929 12144.612 -14059.347 14106.321 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-40193.602 40260.262 -46700.145 46770.223 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-133477.93 133577.37 -155081.97 155186.52 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-443207.77 443356.13 -514938.07 515094.03 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1471569.4 1471790.8 -1709725.9 1709958.5 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4885883.8 4886213.9 -5676596.2 5676943.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-16221856. 16222349. -18847122. 18847639. MAarrowhead1
% End of user PostScript
.025 0 1 r
.69118 .27517 m
.72305 .24157 L
.76013 .20268 L
.80326 .15765 L
.85341 .10549 L
.91174 .04505 L
s
.91174 .04505 m
.95537 0 L
s
1 0 0 r
.69118 .27517 m
.72305 .24157 L
s
% Start of user PostScript
5.7355335 -6.7450113 6.6916419 -7.7528768 MAarrowhead1
% End of user PostScript
1 .158 0 r
.76013 .20268 m
.80326 .15765 L
s
% Start of user PostScript
7.8039121 -8.9195577 9.0976896 -10.270536 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
26.419832 -28.08418 30.74147 -32.49115 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
88.47766 -90.960575 102.86501 -105.47522 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
294.89105 -298.59512 342.7169 -346.61089 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
980.7658 -986.29163 1139.64 -1145.4492 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3258.7828 -3267.0264 3786.3933 -3795.0596 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
10823.308 -10835.606 12575.23 -12588.158 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
35940.269 -35958.615 41757.142 -41776.429 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
119334.28 -119361.65 138647.41 -138676.18 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
396216.28 -396257.11 460338.76 -460381.69 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1315503. -1315563.9 1528398.1 -1528462.2 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4367651.7 -4367742.6 5074489.8 -5074585.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
14501156. -14501291. 16847943. -16848086. MAarrowhead1
% End of user PostScript
0 1 .142 r
.47392 .58291 m
.46813 .59161 L
.46132 .60148 L
.45332 .6127 L
.44394 .62546 L
.43295 .64001 L
.42008 .65662 L
.40503 .67561 L
.38743 .69734 L
.36687 .72225 L
.34287 .75082 L
.31485 .78365 L
.28216 .82138 L
.24404 .86481 L
.19961 .91482 L
.14784 .97246 L
s
.14784 .97246 m
.12285 1 L
s
1 0 0 r
.47392 .58291 m
.46813 .59161 L
s
% Start of user PostScript
-0.78244483 2.4871804 -0.95619143 2.7483306 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46132 .60148 m
.45332 .6127 L
s
% Start of user PostScript
-1.1604721 3.0444962 -1.4003521 3.3809722 MAarrowhead1
% End of user PostScript
1 .473 0 r
.34287 .75082 m
.31485 .78365 L
s
% Start of user PostScript
-4.7140397 7.5246734 -5.5546208 8.5093588 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-16.935828 21.128801 -19.792522 24.200473 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-58.145423 64.400604 -67.728242 74.304132 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-195.90868 205.24031 -227.87134 237.68142 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-654.70496 668.62612 -761.04343 775.67834 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2180.06 2200.8279 -2533.4424 2555.2751 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7247.5465 7278.5286 -8421.3041 8453.8747 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-24076.863 24123.083 -27974.601 28023.191 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-79959.126 80028.078 -92901.157 92973.644 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-265505.16 265608.03 -308475.83 308583.97 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-881555.2 881708.66 -1024225.3 1024386.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2926936.5 2927165.4 -3400621.4 3400862. MAarrowhead1
% End of user PostScript
0 .032 1 r
.23511 .71075 m
.19373 .74935 L
.14574 .79442 L
.09007 .84703 L
.02546 .90841 L
s
.02546 .90841 m
0 .93272 L
s
1 0 0 r
.23511 .71075 m
.19373 .74935 L
s
% Start of user PostScript
-7.9468046 6.3225374 -9.1879736 7.4804285 MAarrowhead1
% End of user PostScript
1 .158 0 r
.14574 .79442 m
.09007 .84703 L
s
% Start of user PostScript
-10.627705 8.8326117 -12.298013 10.410884 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-34.464733 31.786769 -39.968286 37.15302 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-113.20292 109.20787 -131.4126 127.21272 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-374.02089 368.06098 -434.38554 428.12005 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1239.069 1230.1778 -1439.347 1430. MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-4109.79 4096.5259 -4774.5281 4760.584 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-13638.921 13619.133 -15845.618 15824.816 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-45273.767 45244.247 -52599.797 52568.763 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-150300.71 150256.67 -174623.29 174576.99 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-498995.79 498930.09 -579748.58 579679.52 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1656694.3 1656596.3 -1924801.5 1924698.5 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-5500374.1 5500227.9 -6390519. 6390365.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-18261818. 18261600. -21217200. 21216971. MAarrowhead1
% End of user PostScript
.008 0 1 r
.74535 .44245 m
.77986 .41756 L
.8197 .38785 L
.8657 .35249 L
.91885 .31052 L
.9803 .26084 L
s
.9803 .26084 m
1 .24457 L
s
1 0 0 r
.74535 .44245 m
.77986 .41756 L
s
% Start of user PostScript
7.3604807 -1.7265361 8.3959318 -2.4731287 MAarrowhead1
% End of user PostScript
1 .158 0 r
.8197 .38785 m
.8657 .35249 L
s
% Start of user PostScript
9.5909702 -3.3644984 10.971013 -4.4253032 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
28.99719 -19.708386 33.433178 -23.668127 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
92.028399 -78.171131 106.53872 -91.970974 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
299.21126 -278.53865 347.06248 -325.32996 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
983.96747 -953.12756 1142.3547 -1109.9336 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3252.791 -3206.7832 3777.9322 -3729.5656 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
10778.617 -10709.982 12521.07 -12448.915 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
35754.899 -35652.507 41538.436 -41430.794 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
118663.64 -118510.89 137863.26 -137702.68 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
393907.35 -393679.48 457648.75 -457409.19 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1307714.3 -1307374.4 1519337.9 -1518980.5 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4341609. -4341101.9 5044216. -5043682.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
14414418. -14413661. 16747143. -16746348. MAarrowhead1
% End of user PostScript
.524 1 0 r
.71047 .38052 m
.74202 .35364 L
.77854 .32202 L
.82084 .28488 L
.86984 .24129 L
.92662 .19021 L
.99244 .13039 L
s
.99244 .13039 m
1 .12345 L
s
1 0 0 r
.71047 .38052 m
.74202 .35364 L
s
% Start of user PostScript
6.3141997 -3.5844595 7.2606013 -4.3909043 MAarrowhead1
% End of user PostScript
1 .158 0 r
.77854 .32202 m
.82084 .28488 L
s
% Start of user PostScript
8.3562945 -5.339465 9.6252416 -6.4537359 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
26.364963 -21.864383 30.507318 -25.775987 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
85.477667 -78.763589 99.125298 -92.066982 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
280.72702 -270.7108 325.88141 -315.35164 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
927.4684 -912.52594 1077.1515 -1061.443 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3072.4737 -3050.1822 3569.089 -3545.6546 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
10190.783 -10157.528 11839.082 -11804.122 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
33819.392 -33769.781 39291.156 -39239.002 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
112261.66 -112187.65 130427.39 -130349.59 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
372688.01 -372577.59 432998.63 -432882.56 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1237317.3 -1237152.6 1437553. -1437379.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4107962.8 -4107717.1 4772765. -4772506.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
13638804. -13638438. 15846020. -15845635. MAarrowhead1
% End of user PostScript
0 .194 1 r
.71804 .25139 m
.75417 .2137 L
.7962 .17003 L
.84506 .11943 L
.90189 .06078 L
s
.90189 .06078 m
.96096 0 L
s
1 0 0 r
.71804 .25139 m
.75417 .2137 L
s
% Start of user PostScript
6.5412674 -7.4581569 7.625212 -8.5891115 MAarrowhead1
% End of user PostScript
1 .158 0 r
.7962 .17003 m
.84506 .11943 L
s
% Start of user PostScript
8.8858753 -9.899195 10.351923 -11.417197 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
29.965306 -31.477001 34.856503 -36.445705 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
100.17928 -102.43446 116.45405 -118.82486 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
333.63769 -337.00203 387.72469 -391.26152 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1109.2539 -1114.2729 1288.9079 -1294.1842 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3685.1467 -3692.6341 4281.7366 -4289.6079 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
12238.54 -12249.71 14219.464 -14231.206 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
40638.49 -40655.153 47215.65 -47233.168 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
134932.15 -134957.01 156769.48 -156795.62 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
448001.89 -448038.98 520504.96 -520543.95 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1487435.6 -1487490.9 1728155.2 -1728213.3 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4938485.4 -4938568. 5737703.8 -5737790.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
16396387. -16396510. 19049887. -19050016. MAarrowhead1
% End of user PostScript
0 1 .721 r
.78994 .45362 m
.83013 .42592 L
.87648 .3927 L
.92997 .35301 L
.99173 .30576 L
s
.99173 .30576 m
1 .29926 L
s
1 0 0 r
.78994 .45362 m
.83013 .42592 L
s
% Start of user PostScript
8.6982844 -1.3913287 9.9039947 -2.2224034 MAarrowhead1
% End of user PostScript
1 .158 0 r
.87648 .3927 m
.92997 .35301 L
s
% Start of user PostScript
11.294475 -3.21904 12.899096 -4.409625 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
33.807914 -21.76078 38.9462 -26.281397 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
106.73981 -88.767595 123.5172 -104.62353 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
346.17402 -319.36264 401.45575 -373.26971 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1137.0835 -1097.0856 1319.9969 -1277.9483 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3756.9681 -3697.2983 4363.3249 -4300.5957 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
12446.3 -12357.283 14458.077 -14364.496 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
41282.484 -41149.686 47959.733 -47820.126 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
137001.97 -136803.86 159168.11 -158959.84 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
454772.02 -454476.48 528361.54 -528050.84 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1509761.2 -1509320.3 1754080.1 -1753616.6 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
5012382.2 -5011724.5 5823539.1 -5822847.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
16641394. -16640413. 19334515. -19333483. MAarrowhead1
% End of user PostScript
.376 1 0 r
.7117 .19686 m
.74848 .15539 L
.79136 .10759 L
.8413 .05246 L
s
.8413 .05246 m
.88927 0 L
s
1 0 0 r
.7117 .19686 m
.74848 .15539 L
s
% Start of user PostScript
6.3509265 -9.0941553 7.4545489 -10.338426 MAarrowhead1
% End of user PostScript
1 .158 0 r
.79136 .10759 m
.8413 .05246 L
s
% Start of user PostScript
8.7406628 -11.772399 10.239001 -13.426178 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
30.405748 -34.928567 35.451453 -40.206163 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
103.0179 -109.76515 119.87622 -126.96941 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
345.11545 -355.18117 401.24517 -411.82697 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1150.4244 -1165.4407 1337.0175 -1352.8037 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3826.4071 -3848.8088 4446.27 -4469.8202 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
12714.358 -12747.778 14772.9 -14808.033 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
42228.431 -42278.287 49063.815 -49116.227 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
140226.12 -140300.49 162921.56 -162999.75 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
465601.1 -465712.05 540954.36 -541071.01 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1545900.8 -1546066.3 1796085.1 -1796259.1 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
5132647. -5132894. 5963291.9 -5963551.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
17041101. -17041470. 19798945. -19799332. MAarrowhead1
% End of user PostScript
1 0 .811 r
.71758 .49401 m
.74694 .4755 L
.78076 .45309 L
.81973 .4261 L
.86468 .39376 L
.91655 .35514 L
.97646 .30916 L
s
.97646 .30916 m
1 .2906 L
s
1 0 0 r
.71758 .49401 m
.74694 .4755 L
s
% Start of user PostScript
6.5273951 -0.1796209 7.4082937 -0.73506213 MAarrowhead1
% End of user PostScript
1 .158 0 r
.78076 .45309 m
.81973 .4261 L
s
% Start of user PostScript
8.4227559 -1.4073805 9.5919358 -2.2168743 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
24.757995 -14.292285 28.475406 -17.473108 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
77.415845 -61.80284 89.512824 -73.099323 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
249.89337 -226.60151 289.69087 -265.20481 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
819.02913 -784.28175 950.61565 -914.08673 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2703.3904 -2651.5534 3139.4587 -3084.964 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8951.8789 -8874.5472 10398.462 -10317.165 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
29685.938 -29570.573 34486.951 -34365.671 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
98508.056 -98335.951 114445.28 -114264.35 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
326979.6 -326722.85 379889. -379619.08 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1085493.1 -1085110.1 1261152.5 -1260749.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3603789.1 -3603217.7 4186989.8 -4186389.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
11964740. -11963888. 13901021. -13900125. MAarrowhead1
% End of user PostScript
.405 0 1 r
.48435 .22169 m
.48994 .20103 L
.49686 .17827 L
.50533 .15314 L
.51563 .12533 L
.52808 .09446 L
.54306 .06013 L
.561 .02185 L
s
.561 .02185 m
.57193 0 L
s
1 0 0 r
.48435 .22169 m
.48994 .20103 L
s
% Start of user PostScript
-0.46953047 -8.3493024 -0.3017571 -8.969227 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49686 .17827 m
.50533 .15314 L
s
% Start of user PostScript
-0.094334437 -9.6519832 0.15979491 -10.405817 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
4.1415778 -18.681375 5.2137184 -20.498987 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
20.396272 -42.087101 24.296639 -47.09958 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
77.632302 -109.99122 91.090292 -125.10828 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
272.53871 -320.81253 317.97913 -368.72801 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
926.92504 -998.94113 1078.9238 -1154.6323 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3110.4161 -3217.8515 3616.7576 -3729.7013 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
10376.051 -10536.326 12059.681 -12228.174 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
34522.96 -34762.062 40116.566 -40367.927 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
114729.55 -115086.25 133306.58 -133681.57 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
381078.56 -381610.69 442764.83 -443324.24 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1265468.6 -1266262.4 1470286.7 -1471121.2 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4201866.5 -4203050.8 4881905.2 -4883150.2 MAarrowhead1
% End of user PostScript
1 .947 0 r
.61355 .41602 m
.63111 .39998 L
.65147 .38121 L
.67508 .35928 L
.70246 .33365 L
.73423 .30374 L
.77109 .26883 L
.81386 .22811 L
.86349 .18062 L
.9211 .12528 L
.98796 .06079 L
s
.98796 .06079 m
1 .04914 L
s
1 0 0 r
.61355 .41602 m
.63111 .39998 L
s
% Start of user PostScript
3.4065677 -2.5194295 3.9333458 -3.0007231 MAarrowhead1
% End of user PostScript
1 .158 0 r
.65147 .38121 m
.67508 .35928 L
s
% Start of user PostScript
4.5441174 -3.5636781 5.2524111 -4.2217036 MAarrowhead1
% End of user PostScript
1 .473 0 r
.98796 .06079 m
0 0 rlineto s
.98796 .06079 m
1 .04914 L
s
% Start of user PostScript
14.638869 -13.176225 16.96751 -15.429875 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
47.93422 -45.752213 55.631306 -53.337425 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
158.14988 -154.89471 183.65397 -180.2319 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
523.58824 -518.73209 608.18852 -603.08339 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1736.1546 -1728.91 2016.9236 -2009.3076 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5760.9249 -5750.1173 6692.9411 -6681.5794 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
19122.004 -19105.881 22216.154 -22199.204 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
63479.921 -63455.868 73752.481 -73727.195 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
210749.77 -210713.88 244855.3 -244817.58 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
699697.46 -699643.93 812930.99 -812874.72 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2323052.9 -2322973.1 2699000.2 -2698916.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
7712770.8 -7712651.7 8960957.9 -8960832.7 MAarrowhead1
% End of user PostScript
1 0 .63 r
.3333 .60126 m
.30813 .62308 L
.27898 .6487 L
.24521 .67876 L
.20608 .71399 L
.16073 .75525 L
.10814 .80353 L
.04717 .85997 L
s
.04717 .85997 m
0 .90397 L
s
1 0 0 r
.3333 .60126 m
.30813 .62308 L
s
% Start of user PostScript
-5.0009452 3.0378398 -5.7560076 3.6922516 MAarrowhead1
% End of user PostScript
1 .158 0 r
.27898 .6487 m
.24521 .67876 L
s
% Start of user PostScript
-6.6304829 4.4609159 -7.6435535 5.3627504 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-21.022328 17.785714 -24.334998 20.932439 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-68.317217 63.488757 -79.23982 74.163799 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-224.61419 217.41097 -260.76535 253.19282 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-742.45298 731.70704 -862.31027 851.01337 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2460.119 2444.088 -2857.8074 2840.9544 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-8160.5554 8136.6399 -9480.5517 9455.41 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-27083.067 27047.389 -31465.048 31427.541 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-89902.642 89849.417 -104450.5 104394.54 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-298462.95 298383.55 -346762.29 346678.81 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-990895.61 990777.16 -1151253.2 1151128.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3289835.2 3289658.4 -3822238.2 3822052.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-10922557. 10922293. -12690193. 12689916. MAarrowhead1
% End of user PostScript
0 1 .701 r
.37726 .60225 m
.35796 .6205 L
.33557 .64179 L
.30958 .66661 L
.27942 .69555 L
.24442 .72927 L
.20378 .76855 L
.15661 .81431 L
.10184 .86759 L
.03825 .92961 L
s
.03825 .92961 m
0 .96701 L
s
1 0 0 r
.37726 .60225 m
.35796 .6205 L
s
% Start of user PostScript
-3.682338 3.0675487 -4.2612731 3.6149629 MAarrowhead1
% End of user PostScript
1 .158 0 r
.33557 .64179 m
.30958 .66661 L
s
% Start of user PostScript
-4.9330285 4.2535812 -5.712581 4.9982977 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-16.067674 15.054058 -18.639957 17.574372 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-52.883261 51.371123 -61.399787 59.81012 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-174.88745 172.63161 -203.12788 200.75637 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-579.61571 576.25038 -673.32436 669.78649 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1922.8537 1917.8332 -2233.8985 2228.6206 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6381.8044 6374.3148 -7414.3919 7406.5182 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-21184.914 21173.74 -24613.049 24601.303 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-70331.283 70314.615 -81712.832 81695.309 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-233500.46 233475.6 -271288.15 271262.01 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-775237.48 775200.38 -900696.42 900657.42 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2573862.1 2573806.8 -2990399.6 2990341.4 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-8545497.9 8545415.3 -9928449.8 9928363. MAarrowhead1
% End of user PostScript
1 0 .805 r
.4381 .69288 m
.42446 .71323 L
.40843 .73632 L
.38961 .76256 L
.36754 .79243 L
.34168 .8265 L
.31141 .86539 L
.276 .90986 L
.23461 .96078 L
s
.23461 .96078 m
.20212 1 L
s
1 0 0 r
.4381 .69288 m
.42446 .71323 L
s
% Start of user PostScript
-1.8570745 5.7862836 -2.2662192 6.3968831 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40843 .73632 m
.38961 .76256 L
s
% Start of user PostScript
-2.7471458 7.0895934 -3.3117567 7.8768464 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-11.105661 17.583832 -13.081999 19.892313 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-39.833091 49.497386 -46.546577 56.706371 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-136.66781 151.08524 -159.18385 174.34048 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-460.34292 481.8512 -535.43667 558.04771 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1538.2232 1570.3098 -1788.0473 1821.779 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5121.7467 5169.6143 -5951.9438 6002.2656 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-17026.677 17098.087 -19784.15 19859.221 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-56563.198 56669.729 -65720.005 65831.998 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-187845.12 188004.05 -218249.29 218416.36 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-623740.41 623977.5 -724689.52 724938.77 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2070999.5 2071353.2 -2406167.9 2406539.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-6876122. 6876649.7 -7988928.6 7989483.3 MAarrowhead1
% End of user PostScript
1 0 .55 r
.64203 .5031 m
.66101 .49157 L
.68285 .47755 L
.708 .46062 L
.73701 .44026 L
.77046 .41589 L
.80908 .38683 L
.85369 .35227 L
.90523 .31128 L
.96483 .26279 L
s
.96483 .26279 m
1 .23357 L
s
1 0 0 r
.64203 .5031 m
.66101 .49157 L
s
% Start of user PostScript
4.2610043 0.093003079 4.8302325 -0.2529904 MAarrowhead1
% End of user PostScript
1 .158 0 r
.68285 .47755 m
.708 .46062 L
s
% Start of user PostScript
5.4854109 -0.67348863 6.240133 -1.1814981 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
16.012806 -8.8342611 18.405805 -10.859209 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
49.883268 -39.174138 57.66008 -46.401881 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
160.72343 -144.74728 186.29239 -169.49713 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
526.3183 -502.4847 610.83585 -585.78027 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1736.5446 -1700.989 2016.5942 -1979.2157 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5749.2796 -5696.237 6678.2438 -6622.4816 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
19064.036 -18984.906 22147.063 -22063.875 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
63258.661 -63140.612 73492.816 -73368.715 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
209972.19 -209796.09 243948.02 -243762.88 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
697051.74 -696789.02 809851.32 -809575.13 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2314173.2 -2313781.3 2688674.8 -2688262.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
7683146.5 -7682561.8 8926526.5 -8925911.8 MAarrowhead1
% End of user PostScript
.15 1 0 r
.80603 .64228 m
.84316 .62813 L
.88567 .60979 L
.93439 .58647 L
.99029 .55727 L
s
.99029 .55727 m
1 .55181 L
s
1 0 0 r
.80603 .64228 m
.84316 .62813 L
s
% Start of user PostScript
9.1807867 4.2683791 10.294807 3.8439125 MAarrowhead1
% End of user PostScript
1 .158 0 r
.88567 .60979 m
.93439 .58647 L
s
% Start of user PostScript
11.570054 3.2935732 13.031642 2.5940591 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
31.620168 -9.4462421 36.124489 -12.813682 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
94.84755 -61.76794 109.28279 -74.507148 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
299.78516 -250.43618 346.93662 -295.05746 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
972.76569 -899.14566 1128.1576 -1050.763 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3196.0461 -3086.2179 3710.2401 -3594.7809 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
10561.047 -10397.203 12265.658 -12093.413 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
34989.023 -34744.596 40644.689 -40387.73 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
116055.93 -115691.28 134827.67 -134444.33 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
385152.58 -384608.59 447468.41 -446896.54 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1278502.9 -1277691.4 1485386.1 -1484532.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4244408.3 -4243197.7 4931265.5 -4929992.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
14091379. -14089572. 16371796. -16369898. MAarrowhead1
% End of user PostScript
.103 1 0 r
.24614 .23977 m
.21926 .24029 L
.18877 .24307 L
.1541 .24861 L
.11464 .25745 L
.06963 .27026 L
.01822 .28782 L
s
.01822 .28782 m
0 .29502 L
s
1 0 0 r
.24614 .23977 m
.21926 .24029 L
s
% Start of user PostScript
-7.6159153 -7.8068692 -8.4221333 -7.7913943 MAarrowhead1
% End of user PostScript
1 .158 0 r
.18877 .24307 m
.1541 .24861 L
s
% Start of user PostScript
-9.3369682 -7.7078447 -10.376877 -7.5418418 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-23.209101 -2.2187714 -26.262282 -0.46930542 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-65.434535 27.500606 -74.97556 35.096717 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-199.91173 143.32096 -230.70008 171.20784 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-637.8642 553.44069 -738.75894 650.00694 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2079.196 1953.2509 -2412.1999 2279.7975 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6845.6078 6657.7198 -7948.2681 7750.7469 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-22642.34 22362.044 -26298.898 26004.231 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-75047.099 74628.947 -87180.732 86741.14 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-248974.02 248350.21 -289249.3 288593.5 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-826337.72 825407.11 -960041.74 959063.41 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2743112.5 2741724.2 -3187003.7 3185544.2 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-9106819.7 9104748.6 -10580558. 10578380. MAarrowhead1
% End of user PostScript
0 .043 1 r
.82699 .7788 m
.86316 .77369 L
.90433 .76517 L
.95126 .75257 L
s
.95126 .75257 m
1 .73666 L
s
1 0 0 r
.82699 .7788 m
.86316 .77369 L
s
% Start of user PostScript
9.8096592 8.3640016 10.894864 8.2105807 MAarrowhead1
% End of user PostScript
1 .158 0 r
.90433 .76517 m
.95126 .75257 L
s
% Start of user PostScript
12.129936 7.9550652 13.53781 7.5769715 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
31.092493 -1.1291922 35.296114 -3.7965618 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
89.535296 -44.835303 102.78963 -55.797819 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
276.83649 -210.15194 319.7949 -249.69135 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
888.6498 -789.16813 1029.714 -925.13181 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2904.9508 -2756.5416 3370.9692 -3214.9509 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9576.9426 -9355.5421 11120.7 -10887.948 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
31695.373 -31365.082 36815.64 -36468.415 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
105081.38 -104588.64 122073.52 -121555.52 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
348657.24 -347922.17 405061.6 -404288.84 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1157246.8 -1156150.2 1344498.7 -1343345.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3841693.5 -3840057.6 4463365.9 -4461646.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
12754124. -12751683. 14818111. -14815545. MAarrowhead1
% End of user PostScript
.37 1 0 r
.76097 .20706 m
.80409 .1623 L
.85423 .11044 L
.91253 .05032 L
s
.91253 .05032 m
.96148 0 L
s
1 0 0 r
.76097 .20706 m
.80409 .1623 L
s
% Start of user PostScript
7.8291107 -8.7882922 9.1226414 -10.131001 MAarrowhead1
% End of user PostScript
1 .158 0 r
.85423 .11044 m
.91253 .05032 L
s
% Start of user PostScript
10.626869 -11.686929 12.375961 -13.490371 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
35.766972 -37.348395 41.599005 -43.261509 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
119.47336 -121.83256 138.87345 -141.35361 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
397.74384 -401.26336 462.2097 -465.90967 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1322.1647 -1327.4152 1536.2814 -1541.8011 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
4392.1414 -4399.9742 5103.1568 -5111.3912 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
14586.003 -14597.688 16946.841 -16959.125 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
48432.577 -48450.009 56271.108 -56289.434 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
160809.79 -160835.79 186835.03 -186862.37 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
533919.18 -533957.97 620326.65 -620367.44 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1772691.8 -1772749.7 2059575.7 -2059636.5 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
5885570.6 -5885656.9 6838059.8 -6838150.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
19540822. -19540951. 22703200. -22703335. MAarrowhead1
% End of user PostScript
0 1 .045 r
.60598 .1915 m
.62873 .15836 L
.65545 .12073 L
.6868 .07791 L
.72353 .02911 L
s
.72353 .02911 m
.74601 0 L
s
1 0 0 r
.60598 .1915 m
.62873 .15836 L
s
% Start of user PostScript
3.179543 -9.2551471 3.8620364 -10.249143 MAarrowhead1
% End of user PostScript
1 .158 0 r
.65545 .12073 m
.6868 .07791 L
s
% Start of user PostScript
4.6635908 -11.378172 5.6039158 -12.662761 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
18.552721 -28.569698 21.832063 -32.362623 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
66.175693 -81.119268 77.298238 -93.007986 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
226.54134 -248.83454 263.81969 -287.25588 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
762.33336 -795.5909 886.62427 -921.58696 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2546.237 -2595.8514 2959.6768 -3011.835 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8476.4821 -8550.4981 9850.313 -9928.1239 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
28176.742 -28287.161 32739.756 -32855.836 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
93600.548 -93765.274 108752.88 -108926.05 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
310840.06 -311085.8 361151.41 -361409.76 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1032137.7 -1032504.3 1199183. -1199568.4 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3426985.3 -3427532.2 3981603.9 -3982178.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
11378242. -11379058. 13219653. -13220511. MAarrowhead1
% End of user PostScript
.625 1 0 r
.72931 .75534 m
.75302 .75647 L
.77988 .75573 L
.81037 .7527 L
.84504 .74691 L
.88452 .73778 L
.92954 .72466 L
.98098 .70677 L
s
.98098 .70677 m
1 .69915 L
s
1 0 0 r
.72931 .75534 m
.75302 .75647 L
s
% Start of user PostScript
6.8791725 7.6601914 7.5905788 7.6942343 MAarrowhead1
% End of user PostScript
1 .158 0 r
.77988 .75573 m
.81037 .7527 L
s
% Start of user PostScript
8.3965101 7.6719721 9.3112074 7.5811234 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
20.532925 3.4384336 23.193268 2.0071283 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
57.215049 -21.453985 65.48594 -27.891366 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
173.61523 -120.266 200.23751 -144.153 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
552.03838 -472.45067 639.17723 -555.50896 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1796.4546 -1677.7236 2083.9006 -1959.0822 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5910.1705 -5733.0448 6861.7426 -6675.5354 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
19541.498 -19277.257 22696.677 -22418.889 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
64759.28 -64365.079 75228.653 -74814.241 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
214828.2 -214240.12 249578.51 -248960.28 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
712985.96 -712108.65 828347.25 -827424.96 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2366795.7 -2365487. 2749788.2 -2748412.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
7857440.4 -7855487.9 9128989.4 -9126936.8 MAarrowhead1
% End of user PostScript
.697 1 0 r
.68229 .54624 m
.70547 .53477 L
.73208 .52048 L
.76266 .50285 L
.79783 .48129 L
.83831 .45512 L
.88495 .42352 L
.93872 .38557 L
s
.93872 .38557 m
1 .34071 L
s
1 0 0 r
.68229 .54624 m
.70547 .53477 L
s
% Start of user PostScript
5.4685853 1.3871422 6.164092 1.0431362 MAarrowhead1
% End of user PostScript
1 .158 0 r
.73208 .52048 m
.76266 .50285 L
s
% Start of user PostScript
6.9624397 0.61431098 7.8797735 0.085445489 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
19.652985 -8.3498014 22.521082 -10.638372 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
60.083828 -43.221459 69.341359 -51.614439 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
191.778 -166.6223 222.11892 -195.67347 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
625.22739 -587.6995 725.37329 -685.9213 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2058.675 -2002.69 2390.2917 -2331.4362 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6809.4526 -6725.9328 7909.1467 -7821.3446 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
22570.004 -22445.407 26219.16 -26088.175 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
74878.103 -74692.226 86990.806 -86795.399 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
248519.1 -248241.8 288730.33 -288438.82 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
824985.72 -824572.04 958485.22 -958050.33 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2738860. -2738242.8 3182084.2 -3181435.4 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
9093053.2 -9092132.6 10564595. -10563627. MAarrowhead1
% End of user PostScript
1 0 .545 r
.59704 .3529 m
.61412 .33324 L
.63405 .31062 L
.65727 .28456 L
.68433 .25452 L
.71585 .21986 L
.75256 .17986 L
.7953 .13365 L
.84506 .08026 L
.90296 .01852 L
s
.90296 .01852 m
.92044 0 L
s
1 0 0 r
.59704 .3529 m
.61412 .33324 L
s
% Start of user PostScript
2.9110943 -4.4130218 3.4237235 -5.0026564 MAarrowhead1
% End of user PostScript
1 .158 0 r
.63405 .31062 m
.65727 .28456 L
s
% Start of user PostScript
4.0214422 -5.6813287 4.7181298 -6.4631205 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
14.110348 -16.586607 16.462331 -19.065551 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
47.979836 -51.673981 55.846725 -59.730273 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
160.98716 -166.49818 187.19272 -192.9863 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
537.01513 -545.2366 624.14981 -632.79281 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1786.7108 -1798.9758 2076.2008 -2089.0947 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5937.6948 -5955.9921 6899.1229 -6918.3583 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
19722.204 -19749.501 22914.687 -22943.383 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
65492.501 -65533.222 76092.555 -76135.364 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
217461.37 -217522.12 252655.75 -252719.61 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
722024.95 -722115.57 838875.81 -838971.09 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2397248.7 -2397383.9 2785209.3 -2785351.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
7959207.7 -7959409.4 9247285.6 -9247497.6 MAarrowhead1
% End of user PostScript
0 1 .755 r
.27146 .25828 m
.24748 .25816 L
.22027 .26001 L
.18937 .26427 L
.1542 .27143 L
.11411 .28207 L
.06835 .29687 L
.01604 .31663 L
s
.01604 .31663 m
0 .32351 L
s
1 0 0 r
.27146 .25828 m
.24748 .25816 L
s
% Start of user PostScript
-6.8561293 -7.2515562 -7.5757383 -7.2552638 MAarrowhead1
% End of user PostScript
1 .158 0 r
.22027 .26001 m
.18937 .26427 L
s
% Start of user PostScript
-8.3918116 -7.1995922 -9.3189354 -7.0718567 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-20.735385 -2.5242561 -23.448166 -1.0040229 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-58.212548 23.51324 -66.674215 30.195836 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-177.41235 125.64706 -204.69291 150.27356 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-565.36922 488.14449 -654.73076 573.54664 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1841.7946 1726.5888 -2136.6756 2015.5631 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6062.3158 5890.449 -7038.6556 6857.977 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-20049.042 19792.647 -23286.576 23017.035 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-66447.971 66065.475 -77190.956 76788.848 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-220440.21 219869.59 -256099.21 255499.33 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-731626.44 730775.18 -850005.12 849110.22 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2428696.2 2427426.3 -2821707.4 2820372.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-8062975. 8061080.5 -9367788.1 9365796.5 MAarrowhead1
% End of user PostScript
0 .548 1 r
.43144 .73418 m
.41577 .75835 L
.39733 .78572 L
.37565 .81678 L
.35021 .85209 L
.32038 .89229 L
.28543 .93814 L
.24453 .99051 L
s
.24453 .99051 m
.23694 1 L
s
1 0 0 r
.43144 .73418 m
.41577 .75835 L
s
% Start of user PostScript
-2.0566577 7.0254544 -2.5268368 7.7503891 MAarrowhead1
% End of user PostScript
1 .158 0 r
.39733 .78572 m
.37565 .81678 L
s
% Start of user PostScript
-3.0801486 8.5715182 -3.7304079 9.503326 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-12.736411 20.928571 -15.024036 23.636218 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-46.030788 58.252056 -53.817951 66.665817 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-158.41361 176.6456 -184.5543 203.72107 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-534.28506 561.48399 -621.50248 650.09593 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1786.3208 1826.8968 -2076.5302 2119.1866 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5949.3401 6009.8724 -6913.8202 6977.4561 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-19780.172 19870.476 -22983.778 23078.711 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-65713.76 65848.477 -76352.22 76493.845 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-218238.94 218439.92 -253563.03 253774.31 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-724670.67 724970.49 -841955.48 842270.67 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2406128.4 2406575.7 -2795534.7 2796004.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-7988832. 7989499.3 -9281717. 9282418.5 MAarrowhead1
% End of user PostScript
.336 1 0 r
.5346 .78274 m
.53142 .80218 L
.52729 .82342 L
.52201 .84668 L
.51538 .87221 L
.50716 .90031 L
.49705 .9313 L
.48473 .96558 L
s
.48473 .96558 m
.47122 1 L
s
1 0 0 r
.5346 .78274 m
.53142 .80218 L
s
% Start of user PostScript
1.0378612 8.4820956 0.94268354 9.0653718 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52729 .82342 m
.52201 .84668 L
s
% Start of user PostScript
0.8186115 9.7025678 0.6602772 10.400335 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.0910617 17.786817 -2.8633101 19.363804 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-14.116676 37.531991 -17.048455 41.664299 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-57.571525 92.50307 -67.854104 104.57663 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-207.11046 259.2222 -242.06844 296.85201 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-711.44982 789.19141 -828.73561 910.46309 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2397.6302 2513.607 -2788.8545 2910.7776 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8013.4224 8186.4395 -9315.0509 9496.9388 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-26684.581 26942.692 -31010.194 31281.539 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-88713.904 89098.961 -103081.49 103486.29 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-294716.53 295290.97 -342427.64 343031.53 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-978755.91 979612.87 -1137175.8 1138076.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3249975.8 3251254.2 -3775968.5 3777312.4 MAarrowhead1
% End of user PostScript
.753 0 1 r
.43744 .57 m
.42711 .58072 L
.41509 .59313 L
.40112 .60752 L
.38488 .6242 L
.366 .64355 L
.34405 .66599 L
.31854 .69202 L
.28888 .72222 L
.25441 .75726 L
.21434 .79793 L
.16777 .84513 L
.11365 .89991 L
.05075 .96351 L
s
.05075 .96351 m
.01461 1 L
s
1 0 0 r
.43744 .57 m
.42711 .58072 L
s
% Start of user PostScript
-1.8769196 2.1001277 -2.1868391 2.4214914 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41509 .59313 m
.40112 .60752 L
s
% Start of user PostScript
-2.5472305 2.7939137 -2.9662782 3.225609 MAarrowhead1
% End of user PostScript
1 .473 0 r
.21434 .79793 m
.16777 .84513 L
s
% Start of user PostScript
-8.5698554 8.9378634 -9.9669235 10.3538 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-28.621128 29.170132 -33.268182 33.845333 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-95.276427 96.095444 -110.71805 111.57906 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-316.70323 317.92506 -367.99043 369.2749 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1052.0502 1053.873 -1222.3584 1224.2746 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3493.7629 3496.4821 -4059.2485 4062.1071 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-11600.944 11605.001 -13478.486 13482.751 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-38518.345 38524.397 -44752.099 44758.461 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-127888.18 127897.2 -148585.11 148594.6 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-424607.82 424621.29 -493324.28 493338.44 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1409753.8 1409773.9 -1637900.8 1637921.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-4680556.5 4680586.5 -5438031.7 5438063.2 MAarrowhead1
% End of user PostScript
0 .385 1 r
.18763 .30319 m
.15115 .31356 L
.10949 .32777 L
.06185 .34657 L
.00729 .37079 L
s
.00729 .37079 m
0 .37436 L
s
1 0 0 r
.18763 .30319 m
.15115 .31356 L
s
% Start of user PostScript
-9.3711275 -5.9043775 -10.46547 -5.5932271 MAarrowhead1
% End of user PostScript
1 .158 0 r
.10949 .32777 m
.06185 .34657 L
s
% Start of user PostScript
-11.715266 -5.1667777 -13.144564 -4.6030403 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-31.179726 5.9946762 -35.529539 9.0532239 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-92.008929 54.437249 -105.86061 66.362593 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-288.3074 232.25704 -333.41613 274.49201 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-931.59517 847.97786 -1080.0479 992.14346 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3054.7857 2930.0433 -3545.7066 3414.5686 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-10085.229 9899.1355 -11712.221 11516.586 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-33399.082 33121.462 -38796.523 38504.67 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-110761.96 110347.8 -128675.59 128240.2 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-367553.37 366935.52 -427019.01 426369.48 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1220037.8 1219116. -1417456.2 1416487.2 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4050246.7 4048871.7 -4705677.3 4704231.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-13446664. 13444613. -15622738. 15620582. MAarrowhead1
% End of user PostScript
0 .287 1 r
.6815 .80062 m
.69755 .80929 L
.71551 .81732 L
.73566 .82449 L
.75831 .83055 L
.78384 .83522 L
.81266 .83813 L
.84527 .83889 L
.88224 .837 L
.92422 .8319 L
.97197 .82291 L
s
.97197 .82291 m
1 .81587 L
s
1 0 0 r
.6815 .80062 m
.69755 .80929 L
s
% Start of user PostScript
5.445026 9.018577 5.9264323 9.2787355 MAarrowhead1
% End of user PostScript
1 .158 0 r
.71551 .81732 m
.73566 .82449 L
s
% Start of user PostScript
6.4652492 9.5195042 7.0697167 9.7345925 MAarrowhead1
% End of user PostScript
1 .473 0 r
.97197 .82291 m
0 0 rlineto s
.97197 .82291 m
1 .81587 L
s
% Start of user PostScript
14.159183 9.6872668 15.791489 9.2775944 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
36.110574 -0.53585072 40.971188 -3.5725097 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
103.63108 -50.559829 118.93521 -63.142934 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
319.80986 -240.63686 369.37764 -286.14536 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1025.6183 -907.50605 1188.3337 -1064.1657 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3351.1867 -3174.984 3888.6531 -3703.4162 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
11045.794 -10782.931 12826.116 -12549.775 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
36553.18 -36161.034 42457.897 -42045.645 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
121181.59 -120596.58 140776.75 -140161.75 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
402069.66 -401196.93 467114.18 -466196.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1334519.4 -1333217.4 1550454.3 -1549085.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4430165.3 -4428223. 5147064.1 -5145022.2 MAarrowhead1
% End of user PostScript
1 .599 0 r
.61233 .24603 m
.63442 .21667 L
.66029 .18317 L
.69056 .14487 L
.72595 .10105 L
.7673 .05083 L
s
.7673 .05083 m
.8099 0 L
s
1 0 0 r
.61233 .24603 m
.63442 .21667 L
s
% Start of user PostScript
3.3698838 -7.6191487 4.0326994 -8.4998288 MAarrowhead1
% End of user PostScript
1 .158 0 r
.66029 .18317 m
.69056 .14487 L
s
% Start of user PostScript
4.8088033 -9.5049673 5.716838 -10.653779 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
18.112279 -25.118133 21.237113 -28.602165 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
63.337071 -73.788576 73.876066 -84.863431 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
215.06358 -230.6554 250.29921 -266.69043 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
721.16284 -744.42309 838.51462 -862.96745 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2404.9766 -2439.6768 2795.1433 -2831.6226 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8000.664 -8052.4307 9296.8763 -9351.2971 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
26586.801 -26664.028 30891.591 -30972.777 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
88306.587 -88421.795 102600.8 -102721.92 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
293240.85 -293412.72 340702.01 -340882.7 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
973672.47 -973928.87 1131253.1 -1131522.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3232823.6 -3233206.1 3756015.8 -3756417.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
10733527. -10734098. 12470595. -12471195. MAarrowhead1
% End of user PostScript
.226 0 1 r
.80167 .71495 m
.83621 .7069 L
.87561 .69534 L
.92061 .67961 L
.97209 .65891 L
s
.97209 .65891 m
1 .64631 L
s
1 0 0 r
.80167 .71495 m
.83621 .7069 L
s
% Start of user PostScript
9.0500618 6.4484835 10.08628 6.206893 MAarrowhead1
% End of user PostScript
1 .158 0 r
.87561 .69534 m
.92061 .67961 L
s
% Start of user PostScript
11.268229 5.8603125 12.618368 5.3883727 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
29.582843 -4.0300618 33.664061 -6.8011607 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
86.539011 -48.41874 99.490312 -59.415573 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
269.89588 -213.02712 312.00238 -252.2179 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
870.09272 -785.25449 1008.5585 -919.37055 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2850.0323 -2723.4685 3307.7668 -3174.714 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9404.5915 -9215.7806 10921.358 -10722.866 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
31138.043 -30856.37 36169.459 -35873.345 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
103253.2 -102832.99 119951.49 -119509.74 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
342620.63 -341993.75 398051.05 -397392.04 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1137254. -1136318.8 1321274.8 -1320291.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3775388.9 -3773993.7 4386337.5 -4384870.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
12534095. -12532013. 14562483. -14560295. MAarrowhead1
% End of user PostScript
0 .254 1 r
.24297 .52141 m
.20788 .54441 L
.16746 .57214 L
.12084 .60541 L
.06704 .64517 L
.00493 .69252 L
s
.00493 .69252 m
0 .69639 L
s
1 0 0 r
.24297 .52141 m
.20788 .54441 L
s
% Start of user PostScript
-7.7109577 0.64228927 -8.7634711 1.3323843 MAarrowhead1
% End of user PostScript
1 .158 0 r
.16746 .57214 m
.12084 .60541 L
s
% Start of user PostScript
-9.9762998 2.164213 -11.374874 3.1622534 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-29.551787 17.897523 -34.012145 21.760355 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-92.788539 75.40242 -107.32434 89.046812 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-300.12207 274.18503 -347.97518 320.70832 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-984.58525 945.89173 -1142.8553 1102.178 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3251.2524 3193.5284 -3775.8208 3715.1373 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-10768.154 10682.04 -12508.43 12417.901 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-35712.17 35583.703 -41488.071 41353.017 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-118509.86 118318.21 -137683.52 137482.04 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-393379. 393093.09 -457033.29 456732.72 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1305933.6 1305507.1 -1517266.6 1516818.2 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4335657.2 4335020.9 -5037297.4 5036628.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-14394598. 14393649. -16724111. 16723113. MAarrowhead1
% End of user PostScript
0 .488 1 r
.70106 .43089 m
.72996 .40877 L
.76334 .3825 L
.80192 .35139 L
.84655 .31463 L
.89817 .27126 L
.95793 .2202 L
s
.95793 .2202 m
1 .18368 L
s
1 0 0 r
.70106 .43089 m
.72996 .40877 L
s
% Start of user PostScript
6.0319218 -2.0732131 6.8986715 -2.7369955 MAarrowhead1
% End of user PostScript
1 .158 0 r
.76334 .3825 m
.80192 .35139 L
s
% Start of user PostScript
7.9000807 -3.5250311 9.0576545 -4.4582912 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
24.229474 -17.702667 27.970227 -21.108783 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
77.46146 -67.724608 89.728243 -79.492172 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
252.73065 -238.20498 293.22963 -277.9592 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
832.45602 -810.78626 966.57694 -943.79615 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2753.9467 -2721.6192 3198.736 -3164.751 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9128.6489 -9080.4219 10604.644 -10553.944 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
30286.138 -30214.192 35185.484 -35109.849 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
100520.64 -100413.3 116785.35 -116672.52 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
333691.21 -333531.09 387689.44 -387521.12 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1107820.6 -1107581.8 1287097.3 -1286846.2 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3677984.9 -3677628.5 4273198.9 -4272824.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
12211177. -12210645. 14187349. -14186790. MAarrowhead1
% End of user PostScript
1 .789 0 r
.42251 .54538 m
.41086 .55538 L
.39736 .56715 L
.38173 .58096 L
.36363 .59715 L
.34264 .61612 L
.31831 .63834 L
.29011 .66432 L
.2574 .69469 L
.21946 .73017 L
.17546 .7716 L
.1244 .81994 L
.06515 .87633 L
s
.06515 .87633 m
0 .93864 L
s
1 0 0 r
.42251 .54538 m
.41086 .55538 L
s
% Start of user PostScript
-2.3247146 1.3613016 -2.6743035 1.6614953 MAarrowhead1
% End of user PostScript
1 .158 0 r
.39736 .56715 m
.38173 .58096 L
s
% Start of user PostScript
-3.0791026 2.0143666 -3.5479767 2.4286505 MAarrowhead1
% End of user PostScript
1 .473 0 r
.17546 .7716 m
.1244 .81994 L
s
% Start of user PostScript
-9.7363185 8.147919 -11.268084 9.5982451 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-31.599701 29.230088 -36.648117 34.157011 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-103.83162 100.29657 -120.53742 116.82112 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-343.11733 337.84366 -398.4997 392.95564 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1136.7792 1128.9118 -1320.5315 1312.2608 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3770.6439 3758.9071 -4380.5388 4368.2003 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-12513.614 12496.105 -14538.261 14519.854 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-41538.659 41512.538 -48260.314 48232.854 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-137901.27 137862.3 -160217.33 160176.37 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-457830.51 457772.38 -531921.56 531860.45 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1520024.3 1519937.5 -1766013.8 1765922.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-5046618.6 5046489.3 -5863330.8 5863194.8 MAarrowhead1
% End of user PostScript
.503 0 1 r
.66774 .54795 m
.68893 .53782 L
.71323 .52514 L
.74115 .50944 L
.77325 .49019 L
.81019 .46676 L
.85274 .43841 L
.90177 .40431 L
.95834 .36344 L
s
.95834 .36344 m
1 .3323 L
s
1 0 0 r
.66774 .54795 m
.68893 .53782 L
s
% Start of user PostScript
5.032248 1.4384762 5.6677821 1.1347031 MAarrowhead1
% End of user PostScript
1 .158 0 r
.71323 .52514 m
.74115 .50944 L
s
% Start of user PostScript
6.3969973 0.75425884 7.2345842 0.28332471 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
17.970132 -7.301712 20.583432 -9.3680296 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
54.786693 -38.87128 63.213142 -46.481728 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
174.62372 -150.88071 202.22754 -177.26721 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
568.91888 -533.49848 660.01039 -622.77395 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1872.6875 -1819.8465 2174.2919 -2118.7416 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6193.3893 -6114.5597 7193.5128 -7110.6416 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
20526.746 -20409.146 23845.425 -23721.796 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
68097.444 -67922.005 79113.093 -78928.659 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
226011.29 -225749.56 262580.42 -262305.28 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
750264.27 -749873.83 871671.93 -871261.47 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2490786.6 -2490204.2 2893865.1 -2893252.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
8269436.7 -8268567.7 9607690.7 -9606777.2 MAarrowhead1
% End of user PostScript
0 1 .48 r
.4298 .69112 m
.4151 .71202 L
.39784 .7358 L
.37762 .76287 L
.35393 .79377 L
.3262 .82906 L
.29379 .86944 L
.2559 .91569 L
.21166 .96874 L
s
.21166 .96874 m
.18514 1 L
s
1 0 0 r
.4298 .69112 m
.4151 .71202 L
s
% Start of user PostScript
-2.1060095 5.7336518 -2.5471049 6.3607403 MAarrowhead1
% End of user PostScript
1 .158 0 r
.39784 .7358 m
.37762 .76287 L
s
% Start of user PostScript
-3.0647255 7.0738903 -3.6715196 7.8862385 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-12.007728 17.988699 -14.116309 20.403931 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-42.600803 51.523363 -49.741698 59.121728 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-145.51791 158.8288 -169.43561 183.42897 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-489.22052 509.07804 -568.94203 589.81767 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1633.3457 1662.9696 -1898.4958 1929.6385 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5436.4389 5480.6326 -6317.4624 6363.922 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-18069.813 18135.742 -20995.949 21065.259 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-60024.025 60122.38 -69740.686 69844.084 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-199331.74 199478.46 -231594.49 231748.74 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-661871.74 662090.63 -768991.3 769221.41 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2197591.6 2197918.2 -2553246.2 2553589.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-7296410.3 7296897.5 -8477232.8 8477745. MAarrowhead1
% End of user PostScript
1 0 .805 r
.17266 .66916 m
.12406 .70965 L
.06781 .75737 L
.0027 .81351 L
s
.0027 .81351 m
0 .81588 L
s
1 0 0 r
.17266 .66916 m
.12406 .70965 L
s
% Start of user PostScript
-9.8202619 5.0746733 -11.278345 6.2894447 MAarrowhead1
% End of user PostScript
1 .158 0 r
.06781 .75737 m
.0027 .81351 L
s
% Start of user PostScript
-12.96567 7.7209835 -14.918992 9.4054048 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-40.650336 32.826183 -47.012686 38.78738 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-131.38766 119.71539 -152.32805 140.05733 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-430.88731 413.47433 -500.13832 481.83257 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1422.6372 1396.6601 -1652.1506 1624.8417 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-4711.4485 4672.6953 -5472.8511 5432.1109 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-15624.847 15567.034 -18151.884 18091.107 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-51849.894 51763.647 -60238.598 60147.929 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-172108.29 171979.62 -199957.75 199822.49 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-571360.83 571168.89 -663821.28 663619.49 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1896897. 1896610.7 -2203872. 2203571. MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-6297789.1 6297361.9 -7316975.2 7316526.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-20909201. 20908564. -24293008. 24292338. MAarrowhead1
% End of user PostScript
.762 0 1 r
.48637 .35378 m
.48858 .34338 L
.49138 .33196 L
.49486 .31942 L
.49917 .3056 L
.50443 .29032 L
.51082 .27341 L
.51853 .25463 L
.5278 .23373 L
.53889 .21042 L
.55211 .18434 L
.56783 .15511 L
.58647 .12227 L
.60851 .08529 L
.63453 .04357 L
s
.63453 .04357 m
.66286 0 L
s
1 0 0 r
.48637 .35378 m
.48858 .34338 L
s
% Start of user PostScript
-0.40898867 -4.3864731 -0.3426267 -4.6987036 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49138 .33196 m
.49486 .31942 L
s
% Start of user PostScript
-0.2587291 -5.0410758 -0.15410956 -5.4174221 MAarrowhead1
% End of user PostScript
1 .473 0 r
.55211 .18434 m
.56783 .15511 L
s
% Start of user PostScript
1.5633871 -9.4697669 2.0349353 -10.346684 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
8.8044213 -20.599354 10.555299 -22.954971 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
34.622854 -52.218826 40.712384 -59.21052 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
122.99457 -149.24467 143.62487 -171.22085 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
420.35456 -459.51512 489.46475 -530.63311 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1413.5255 -1471.9462 1643.8972 -1705.3131 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
4719.7726 -4806.926 5486.0024 -5577.6242 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
15710.032 -15840.05 18256.047 -18392.731 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
52218.571 -52412.535 60674.686 -60878.594 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
173460.42 -173749.78 201540.25 -201844.45 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
576041.13 -576472.8 669276.24 -669730.04 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1912721.2 -1913365.2 2222282.8 -2222959.8 MAarrowhead1
% End of user PostScript
0 1 .18 r
.41073 .39728 m
.40159 .39658 L
.39124 .39658 L
.37951 .39743 L
.36617 .39933 L
.351 .40249 L
.3337 .40715 L
.31395 .41361 L
.29137 .42222 L
.26552 .43338 L
.2359 .44757 L
.20191 .46533 L
.16286 .48731 L
.11797 .51427 L
.06631 .54707 L
.00682 .58675 L
s
.00682 .58675 m
0 .59149 L
s
1 0 0 r
.41073 .39728 m
.40159 .39658 L
s
% Start of user PostScript
-2.6780544 -3.0815507 -2.9522553 -3.1026511 MAarrowhead1
% End of user PostScript
1 .158 0 r
.39124 .39658 m
.37951 .39743 L
s
% Start of user PostScript
-3.2626689 -3.1026792 -3.6147373 -3.0769692 MAarrowhead1
% End of user PostScript
1 .473 0 r
.2359 .44757 m
.20191 .46533 L
s
% Start of user PostScript
-7.9230132 -1.5729703 -8.9427516 -1.0401014 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-21.964972 7.7986294 -25.128088 10.235421 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-66.451222 45.317522 -76.621153 54.403905 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-210.96618 179.43841 -244.23628 211.09204 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-686.02189 638.98798 -795.74367 746.29828 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2256.175 2186.0086 -2619.3619 2545.598 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7458.6935 7354.0176 -8662.8722 8552.8295 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-24715.89 24559.732 -28711.451 28547.287 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-81988.269 81755.309 -95250.339 95005.435 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-272104.16 271756.62 -316130.32 315764.97 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-903258.78 902740.31 -1049422.6 1048877.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2998687.8 2997914.3 -3483956.8 3483143.6 MAarrowhead1
% End of user PostScript
1 .195 0 r
.59137 .77617 m
.59599 .79039 L
.60085 .80535 L
.60594 .82108 L
.61128 .83763 L
.61689 .85505 L
.62276 .87337 L
.62891 .89266 L
.63536 .91295 L
.64211 .93431 L
.64917 .9568 L
.65656 .98048 L
s
.65656 .98048 m
.66261 1 L
s
1 0 0 r
.59137 .77617 m
.59599 .79039 L
s
% Start of user PostScript
2.7410113 8.2852288 2.8798269 8.7117407 MAarrowhead1
% End of user PostScript
1 .158 0 r
.60085 .80535 m
.60594 .82108 L
s
% Start of user PostScript
3.0254814 9.1603985 3.1782806 9.6323827 MAarrowhead1
% End of user PostScript
1 .473 0 r
.64917 .9568 m
.65656 .98048 L
s
% Start of user PostScript
4.4751147 13.704082 4.6968542 14.41441 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
6.5486831 20.571491 6.8588614 21.651794 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
9.3464927 31.112054 9.7407692 32.792131 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
12.538937 47.818121 12.89985 50.551781 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
14.043152 75.998998 13.826979 80.831731 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5.4690662 128.85804 2.6412415 138.57296 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-43.239361 243.63185 -55.775976 266.44281 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-235.15374 534.10421 -281.4729 595.75088 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-917.38012 1363.3618 -1078.1709 1547.0186 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-3249.6555 3914.982 -3793.9512 4493.3897 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-11093.339 12085.889 -12916.056 13959.496 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-37284.851 38765.562 -43359.744 44916.373 MAarrowhead1
% End of user PostScript
1 0 .522 r
.28683 .74766 m
.25138 .78488 L
.21015 .82798 L
.16218 .8779 L
.10641 .93573 L
s
.10641 .93573 m
.04421 1 L
s
1 0 0 r
.28683 .74766 m
.25138 .78488 L
s
% Start of user PostScript
-6.3949642 7.4299065 -7.458495 8.5465 MAarrowhead1
% End of user PostScript
1 .158 0 r
.21015 .82798 m
.16218 .8779 L
s
% Start of user PostScript
-8.6956082 9.8393964 -10.134471 11.336902 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-29.393231 31.099562 -34.197226 35.991043 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-98.36888 100.91443 -114.35869 117.03476 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-327.75969 331.5572 -380.90739 384.89961 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1089.9362 1095.6014 -1266.4818 1272.4375 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3621.3051 3629.7566 -4207.5899 4216.4747 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-12027.019 12039.627 -13973.751 13987.006 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-39936.873 39955.682 -46400.547 46420.32 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-132603.69 132631.75 -154064.28 154093.78 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-440272.57 440314.43 -511524.9 511568.91 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1461775.5 1461838. -1698342.6 1698408.2 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4853294.2 4853387.4 -5638726. 5638823.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-16113547. 16113686. -18721274. 18721420. MAarrowhead1
% End of user PostScript
0 .654 1 r
.46397 .44205 m
.46074 .44046 L
.45712 .43902 L
.45305 .43776 L
.44847 .43675 L
.4433 .43603 L
.43746 .43568 L
.43084 .43579 L
.42334 .43646 L
.41481 .4378 L
.40509 .43996 L
.39402 .44309 L
.38137 .44739 L
.3669 .45307 L
.35034 .46041 L
.33135 .46969 L
.30956 .48129 L
.28452 .4956 L
.25572 .51312 L
.22258 .53441 L
.1844 .56013 L
.14039 .59105 L
.08961 .62805 L
.031 .67219 L
s
.031 .67219 m
0 .69622 L
s
1 0 0 r
.46397 .44205 m
.46074 .44046 L
s
% Start of user PostScript
-1.0808415 -1.738562 -1.1778282 -1.7861293 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45712 .43902 m
.45305 .43776 L
s
% Start of user PostScript
-1.286515 -1.8294078 -1.4085906 -1.867089 MAarrowhead1
% End of user PostScript
1 .473 0 r
.40509 .43996 m
.39402 .44309 L
s
% Start of user PostScript
-2.8471758 -1.8012348 -3.1794606 -1.7072791 MAarrowhead1
% End of user PostScript
1 .788 0 r
.25572 .51312 m
.22258 .53441 L
s
% Start of user PostScript
-7.3282933 0.39367956 -8.3225839 1.0324249 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-21.161165 10.815937 -24.299816 13.424177 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-65.529018 50.095752 -75.70727 59.482723 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-210.50987 187.48614 -243.94118 219.737 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-688.39387 654.0465 -798.85018 762.74178 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2269.8489 2218.6086 -2635.7718 2581.9044 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-7512.7431 7436.3016 -8726.4493 8646.0886 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-24908.246 24794.209 -28936.101 28816.217 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-82646.166 82476.043 -96016.444 95837.597 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-274317.18 274063.38 -318704.07 318437.27 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-910649.1 910270.48 -1058012.8 1057614.8 MAarrowhead1
% End of user PostScript
0 .175 1 r
.73273 .54928 m
.7626 .53387 L
.7969 .51476 L
.83633 .49131 L
.88171 .46273 L
.93396 .42814 L
.99418 .38649 L
s
.99418 .38649 m
1 .3823 L
s
1 0 0 r
.73273 .54928 m
.7626 .53387 L
s
% Start of user PostScript
6.9818599 1.4783033 7.8779184 1.0160067 MAarrowhead1
% End of user PostScript
1 .158 0 r
.7969 .51476 m
.83633 .49131 L
s
% Start of user PostScript
8.9070003 0.44292613 10.090019 -0.26071121 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
25.298683 -11.350232 29.00733 -14.343726 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
77.619124 -56.81048 89.605389 -67.729863 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
248.1935 -217.15065 287.50165 -254.8672 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
809.84258 -763.53209 939.62278 -890.9379 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2667.6048 -2598.5176 3097.4049 -3024.7756 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8825.1819 -8722.116 10250.55 -10142.199 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
29253.527 -29099.771 33983.5 -33821.86 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
97054.852 -96825.475 112755.31 -112514.17 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
322128.62 -321786.42 374250.6 -373890.86 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1069348.3 -1068837.8 1242391.3 -1241854.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3550127.9 -3549366.4 4124639.1 -4123838.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
11786492. -11785356. 13693918. -13692724. MAarrowhead1
% End of user PostScript
1 .71 0 r
.34621 .19063 m
.33412 .17897 L
.32073 .1674 L
.30587 .15601 L
.28933 .14497 L
.27087 .13442 L
.25023 .12457 L
.22709 .11566 L
.20109 .10796 L
.17181 .10181 L
.13878 .0976 L
.10143 .0958 L
.05912 .09695 L
.01109 .10171 L
s
.01109 .10171 m
0 .10356 L
s
1 0 0 r
.34621 .19063 m
.33412 .17897 L
s
% Start of user PostScript
-4.6137569 -9.2809877 -4.9763591 -9.6307843 MAarrowhead1
% End of user PostScript
1 .158 0 r
.32073 .1674 m
.30587 .15601 L
s
% Start of user PostScript
-5.3779515 -9.9781162 -5.8238344 -10.319556 MAarrowhead1
% End of user PostScript
1 .473 0 r
.13878 .0976 m
.10143 .0958 L
s
% Start of user PostScript
-10.836583 -12.071978 -11.957102 -12.126006 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-25.507836 -8.6677207 -28.691238 -7.2365369 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-69.068273 18.084333 -78.836648 25.238706 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-206.01136 129.95225 -237.24871 157.28998 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-649.21722 535.75038 -751.14649 631.86207 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2103.6144 1934.3418 -2439.3725 2261.421 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6906.876 6654.3509 -8017.665 7752.1927 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-22816.213 22439.49 -26498.245 26102.207 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-75580.306 75018.301 -87796.253 87205.434 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-250678.58 249840.16 -291223.78 290342.38 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-831898.97 830648.2 -966494.13 965179.24 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2761430.1 2759564.2 -3208272.5 3206310.9 MAarrowhead1
% End of user PostScript
0 1 .077 r
.80001 .28372 m
.84625 .24178 L
.89985 .19269 L
.962 .13528 L
s
.962 .13528 m
1 .09991 L
s
1 0 0 r
.80001 .28372 m
.84625 .24178 L
s
% Start of user PostScript
9.0003262 -6.4883107 10.387453 -7.7466438 MAarrowhead1
% End of user PostScript
1 .158 0 r
.89985 .19269 m
.962 .13528 L
s
% Start of user PostScript
11.995505 -9.2192982 13.860052 -10.941506 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
38.557549 -34.415935 44.683003 -40.329045 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
126.12255 -119.94399 146.36272 -139.86737 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
415.91756 -406.70023 482.97249 -473.28258 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1376.6819 -1362.9313 1599.0961 -1584.6405 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
4564.4599 -4543.9464 5302.5789 -5281.0136 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
15145.165 -15114.562 17595.325 -17563.153 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
50269.729 -50224.076 58403.831 -58355.837 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
166880.51 -166812.4 193885.61 -193814.01 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
554031.68 -553930.08 643690.17 -643583.36 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1839403.5 -1839251.9 2137077.8 -2136918.5 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
6106965.5 -6106739.4 7095275.4 -7095037.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
20275736. -20275399. 23557035. -23556681. MAarrowhead1
% End of user PostScript
1 .361 0 r
.17396 .31241 m
.13539 .32464 L
.09131 .34104 L
.04086 .36239 L
s
.04086 .36239 m
0 .38162 L
s
1 0 0 r
.17396 .31241 m
.13539 .32464 L
s
% Start of user PostScript
-9.7812949 -5.6276498 -10.938328 -5.2606502 MAarrowhead1
% End of user PostScript
1 .158 0 r
.09131 .34104 m
.04086 .36239 L
s
% Start of user PostScript
-12.260772 -4.768746 -13.774275 -4.1283647 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-32.923462 7.5184066 -37.549389 10.841789 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-97.697776 59.797887 -112.46104 72.617981 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-307.04502 250.50503 -355.17261 295.73375 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-993.58246 909.23471 -1152.0467 1063.3743 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3260.2569 3134.4248 -3784.4 3652.1164 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-10766.92 10579.2 -12504.187 12306.843 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-35661.63 35381.586 -41425.163 41130.76 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-118272.78 117855. -137401.82 136962.62 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-392488.51 391865.26 -455989.36 455334.16 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1302822.9 1301893.1 -1513638.5 1512661.1 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4325099.3 4323712.2 -5025010.1 5023551.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-14359201. 14357132. -16682955. 16680779. MAarrowhead1
% End of user PostScript
1 0 .702 r
.33825 .28787 m
.32241 .28455 L
.30453 .28227 L
.28432 .2813 L
.26142 .28193 L
.23543 .2845 L
.20589 .28943 L
.17224 .29721 L
.13386 .30838 L
.09002 .32362 L
.03988 .3437 L
s
.03988 .3437 m
0 .36163 L
s
1 0 0 r
.33825 .28787 m
.32241 .28455 L
s
% Start of user PostScript
-4.8525099 -6.3638028 -5.3277844 -6.4636009 MAarrowhead1
% End of user PostScript
1 .158 0 r
.30453 .28227 m
.28432 .2813 L
s
% Start of user PostScript
-5.8640792 -6.5318634 -6.4704544 -6.5610417 MAarrowhead1
% End of user PostScript
1 .473 0 r
.03988 .3437 m
0 0 rlineto s
.03988 .3437 m
0 .36163 L
s
% Start of user PostScript
-13.803577 -4.688996 -15.52632 -3.9143883 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-37.377034 9.789356 -42.663372 13.661244 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-111.48654 70.330559 -128.39129 85.125202 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-351.33705 289.93955 -406.49834 341.95292 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1138.4169 1046.8226 -1320.12 1223.8296 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3737.8121 3601.1694 -4338.9411 4195.2927 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-12347.517 12143.671 -14340.134 14125.836 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-40902.029 40597.925 -47512.972 47193.276 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-135660.52 135206.85 -157602.5 157125.57 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-450201.43 449524.63 -523040.73 522329.23 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1494412. 1493402.4 -1736231.2 1735169.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-4961161.2 4959654.9 -5764005.3 5762421.9 MAarrowhead1
% End of user PostScript
1 .86 0 r
.22323 .496 m
.1862 .51863 L
.14358 .54612 L
.09448 .57932 L
.03787 .6192 L
s
.03787 .6192 m
0 .64687 L
s
1 0 0 r
.22323 .496 m
.1862 .51863 L
s
% Start of user PostScript
-8.3029791 -0.12012487 -9.4138643 0.55889848 MAarrowhead1
% End of user PostScript
1 .158 0 r
.14358 .54612 m
.09448 .57932 L
s
% Start of user PostScript
-10.692592 1.383622 -12.165712 2.3794612 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-31.245775 17.358425 -35.918554 21.319184 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-97.392093 76.6746 -112.58082 90.80112 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-313.88373 282.97686 -363.82657 331.33508 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1028.004 981.89636 -1193.0958 1144.6242 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3392.0189 3323.2344 -3939.0624 3866.7513 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-11230.46 11127.845 -13045.096 12937.221 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-37239.537 37086.454 -43261.938 43101.007 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-123569.65 123341.27 -143561.14 143321.05 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-410161.29 409820.6 -476530.02 476171.86 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1361627.7 1361119.5 -1581971.7 1581437.4 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4520531. 4519772.7 -5252086.7 5251289.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-15008345. 15007214. -17437178. 17435989. MAarrowhead1
% End of user PostScript
1 .262 0 r
.40474 .56146 m
.39026 .57421 L
.37348 .58916 L
.35404 .60669 L
.3315 .62721 L
.30537 .65123 L
.27508 .6793 L
.23994 .7121 L
.19918 .7504 L
.15189 .7951 L
.09701 .84726 L
.03334 .90808 L
s
.03334 .90808 m
0 .94006 L
s
1 0 0 r
.40474 .56146 m
.39026 .57421 L
s
% Start of user PostScript
-2.8577925 1.8437759 -3.292253 2.2262467 MAarrowhead1
% End of user PostScript
1 .158 0 r
.37348 .58916 m
.35404 .60669 L
s
% Start of user PostScript
-3.795587 2.6749254 -4.378867 3.2007478 MAarrowhead1
% End of user PostScript
1 .473 0 r
.09701 .84726 m
.03334 .90808 L
s
% Start of user PostScript
-12.089568 10.417738 -13.999864 12.242317 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-39.374632 36.880554 -45.677857 43.055905 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-129.58841 125.86768 -150.4574 146.54591 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-428.54801 422.99734 -497.74833 491.91307 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1420.2925 1412.0118 -1649.9155 1641.2103 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4711.7522 4699.3989 -5473.9335 5460.9469 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-15637.922 15619.493 -18168.164 18148.79 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-51911.305 51883.813 -60311.572 60282.67 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-172339.04 172298.02 -200228.26 200185.14 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-572167.01 572105.82 -664761.53 664697.21 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1899633.4 1899542.1 -2207056.6 2206960.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-6306963.2 6306827.1 -7327642.1 7327499. MAarrowhead1
% End of user PostScript
.935 0 1 r
.27167 .58906 m
.23856 .61502 L
.2003 .64577 L
.15606 .68213 L
.10487 .72502 L
.04562 .77554 L
s
.04562 .77554 m
0 .81507 L
s
1 0 0 r
.27167 .58906 m
.23856 .61502 L
s
% Start of user PostScript
-6.85 2.6717019 -7.8430731 3.4505491 MAarrowhead1
% End of user PostScript
1 .158 0 r
.2003 .64577 m
.15606 .68213 L
s
% Start of user PostScript
-8.9909381 4.3732045 -10.318342 5.4638521 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-27.740324 20.851475 -32.039245 24.797197 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-88.952412 78.675457 -103.0639 92.26003 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-290.63509 275.30367 -337.24603 321.12855 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-957.9349 935.06312 -1112.3294 1088.2849 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3170.0018 3135.8811 -3682.0735 3646.2034 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-10509.181 10458.279 -12208.519 12155.007 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-34868.444 34792.507 -40509.253 40429.423 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-115732.6 115619.32 -134458.97 134339.88 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-384193.99 384024.99 -446365.06 446187.4 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1275491.7 1275239.6 -1481903. 1481637.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4234666.4 4234290.3 -4919970. 4919574.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-14059416. 14058855. -16334695. 16334105. MAarrowhead1
% End of user PostScript
1 0 .527 r
.70944 .51705 m
.73707 .50103 L
.76885 .48145 L
.80545 .45769 L
.8476 .42902 L
.89621 .3946 L
.9523 .35343 L
s
.9523 .35343 m
1 .31727 L
s
1 0 0 r
.70944 .51705 m
.73707 .50103 L
s
% Start of user PostScript
6.2830902 0.51145724 7.1121028 0.030808619 MAarrowhead1
% End of user PostScript
1 .158 0 r
.76885 .48145 m
.80545 .45769 L
s
% Start of user PostScript
8.0656488 -0.55651256 9.1633886 -1.2692506 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
23.346673 -12.144358 26.815324 -15.038654 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
72.393409 -55.681519 83.647212 -66.078485 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
232.71603 -207.78482 269.68833 -243.47887 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
761.24904 -724.05604 883.41715 -844.31723 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2510.4359 -2454.9505 2915.1767 -2856.8465 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8309.5798 -8226.8053 9652.0664 -9565.0479 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
27550.942 -27427.457 32006.215 -31876.399 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
91415.909 -91231.691 106205.04 -106011.38 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
303427.3 -303152.48 352524.64 -352235.72 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1007288.5 -1006878.5 1170291. -1169859.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3344128.2 -3343516.6 3885305.8 -3884662.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
11102617. -11101705. 12899376. -12898416. MAarrowhead1
% End of user PostScript
1 .13 0 r
.70594 .49921 m
.7336 .48207 L
.76544 .46128 L
.80213 .43622 L
.84444 .40613 L
.89325 .37016 L
.94961 .32731 L
s
.94961 .32731 m
1 .2879 L
s
1 0 0 r
.70594 .49921 m
.7336 .48207 L
s
% Start of user PostScript
6.1781471 -0.023790818 7.0078717 -0.53797474 MAarrowhead1
% End of user PostScript
1 .158 0 r
.76544 .46128 m
.80213 .43622 L
s
% Start of user PostScript
7.9631522 -1.1615366 9.0638609 -1.913519 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
23.329761 -13.182943 26.824849 -16.157793 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
72.819698 -57.682424 84.186012 -68.272634 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
234.85107 -212.26891 272.23383 -248.49386 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
769.41132 -735.7227 892.99724 -857.58136 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2539.1374 -2488.8799 2948.6676 -2895.8333 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8407.2616 -8332.2862 9765.772 -9686.9526 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
27878.822 -27766.972 32387.479 -32269.894 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
92509.826 -92342.965 107476.47 -107301.06 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
307067.17 -306818.24 356754.27 -356492.58 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1019385.1 -1019013.8 1184346.3 -1183955.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3384308.1 -3383754.1 3931989.7 -3931407.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
11236045. -11235219. 13054399. -13053531. MAarrowhead1
% End of user PostScript
1 0 .201 r
.61256 .63495 m
.62394 .63626 L
.6368 .63674 L
.65138 .63618 L
.66793 .63438 L
.68675 .63106 L
.70819 .62591 L
.73264 .61859 L
.76059 .60865 L
.79255 .59562 L
.82917 .5789 L
.87116 .55783 L
.91937 .53162 L
.97477 .49934 L
s
.97477 .49934 m
1 .48373 L
s
1 0 0 r
.61256 .63495 m
.62394 .63626 L
s
% Start of user PostScript
3.3768241 4.0483968 3.7180709 4.0878492 MAarrowhead1
% End of user PostScript
1 .158 0 r
.6368 .63674 m
.65138 .63618 L
s
% Start of user PostScript
4.1040203 4.1021178 4.5413673 4.0855086 MAarrowhead1
% End of user PostScript
1 .473 0 r
.82917 .5789 m
.87116 .55783 L
s
% Start of user PostScript
9.8750227 2.3670969 11.134758 1.7350288 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
27.190687 -8.9275907 31.086265 -11.8868 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
81.928691 -54.683353 94.434476 -65.792239 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
259.55972 -218.91445 300.44191 -257.71271 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
843.19077 -782.55516 977.9719 -914.22743 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2771.777 -2681.3193 3217.8452 -3122.7496 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
9161.2781 -9026.3311 10640.157 -10498.291 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
30354.834 -30153.516 35261.721 -35050.082 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
100689.58 -100389.25 116976.3 -116660.57 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
334163.91 -333715.87 388230.69 -387759.68 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1109258.5 -1108590.1 1288756. -1288053.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3682562.3 -3681565.1 4278499.4 -4277451.1 MAarrowhead1
% End of user PostScript
1 .19 0 r
.71557 .58192 m
.74223 .57051 L
.77279 .55599 L
.80785 .53778 L
.84812 .51524 L
.89441 .48757 L
.94768 .45389 L
s
.94768 .45389 m
1 .41913 L
s
1 0 0 r
.71557 .58192 m
.74223 .57051 L
s
% Start of user PostScript
6.4670846 2.4575743 7.2669958 2.1152402 MAarrowhead1
% End of user PostScript
1 .158 0 r
.77279 .55599 m
.80785 .53778 L
s
% Start of user PostScript
8.1837121 1.6795614 9.2354884 1.133486 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
22.662645 -7.9483695 25.923522 -10.45483 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
68.517131 -46.566012 78.998803 -55.922226 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
217.45162 -184.7044 251.73758 -217.31137 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
706.99694 -658.14382 820.06291 -768.70505 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2324.9831 -2252.1028 2699.2305 -2622.6135 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
7685.904 -7577.1794 8926.7412 -8812.4421 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
25468.405 -25306.207 29585.581 -29415.067 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
84483.945 -84241.974 98149.652 -97895.275 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
280385.98 -280025. 325752.05 -325372.57 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
930749.24 -930210.72 1081361.4 -1080795.3 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3089950.1 -3089146.8 3589987.7 -3589143.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
10258629. -10257430. 11918793. -11917533. MAarrowhead1
% End of user PostScript
1 .277 0 r
.23395 .56778 m
.19637 .59519 L
.153 .62788 L
.1029 .66674 L
.045 .71283 L
s
.045 .71283 m
0 .74948 L
s
1 0 0 r
.23395 .56778 m
.19637 .59519 L
s
% Start of user PostScript
-7.9815337 2.033386 -9.1088077 2.8556919 MAarrowhead1
% End of user PostScript
1 .158 0 r
.153 .62788 m
.1029 .66674 L
s
% Start of user PostScript
-10.410084 3.8363638 -11.913089 5.0023272 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-31.558025 21.751187 -36.394125 26.08448 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-100.29389 85.663808 -116.12049 100.74031 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-326.30043 304.47491 -378.50374 355.5592 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1073.3797 1040.8199 -1246.1893 1211.9601 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3548.8639 3500.2903 -4121.849 4070.785 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-11760.441 11687.978 -13661.681 13585.502 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-39012.92 38904.817 -45323.558 45209.913 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-129478.04 129316.77 -150427.57 150258.03 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-429808.53 429567.95 -499359.62 499106.7 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1426904.6 1426545.7 -1657816.7 1657439.4 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4737326.1 4736790.7 -5503972.9 5503410. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-15728232. 15727433. -18273576. 18272737. MAarrowhead1
% End of user PostScript
.735 0 1 r
.66108 .28844 m
.68855 .25839 L
.72053 .22369 L
.75776 .1836 L
.80109 .13726 L
.85152 .08367 L
.9102 .02167 L
s
.9102 .02167 m
.93081 0 L
s
1 0 0 r
.66108 .28844 m
.68855 .25839 L
s
% Start of user PostScript
4.832462 -6.3466621 5.6563735 -7.2482083 MAarrowhead1
% End of user PostScript
1 .158 0 r
.72053 .22369 m
.75776 .1836 L
s
% Start of user PostScript
6.615768 -8.2892179 7.7326812 -9.4919308 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
22.730012 -25.226506 26.477511 -29.102003 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
76.607378 -80.331709 89.108018 -93.0233 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
256.04774 -261.60379 297.63861 -303.47952 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
852.64797 -860.93662 990.86471 -999.57833 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2834.6795 -2847.0447 3293.7694 -3306.7686 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9417.1191 -9435.5658 10941.641 -10961.034 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
31274.368 -31301.887 36336.392 -36365.322 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
103847.14 -103888.19 120654.29 -120697.45 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
344803.4 -344864.64 400606.09 -400670.47 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1144815.6 -1144907. 1330088.5 -1330184.5 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3800963.4 -3801099.7 4416093.2 -4416236.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
12619705. -12619909. 14662011. -14662225. MAarrowhead1
% End of user PostScript
.317 1 0 r
.37157 .17082 m
.36344 .15549 L
.35463 .13963 L
.34509 .12324 L
.33471 .10636 L
.32341 .089 L
.31108 .07121 L
.29758 .05304 L
.28277 .03456 L
.26648 .01584 L
s
.26648 .01584 m
.25138 0 L
s
1 0 0 r
.37157 .17082 m
.36344 .15549 L
s
% Start of user PostScript
-3.8528361 -9.8754921 -4.0968951 -10.3353 MAarrowhead1
% End of user PostScript
1 .158 0 r
.35463 .13963 m
.34509 .12324 L
s
% Start of user PostScript
-4.3609958 -10.811153 -4.6473841 -11.302658 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-7.5442354 -15.089951 -8.1395243 -15.655142 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-14.702267 -19.063972 -16.148272 -19.349199 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-33.379607 -16.993702 -37.389212 -15.566792 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-87.799914 12.651768 -99.931793 20.930719 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-257.15779 145.04993 -295.67598 177.82022 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-802.55244 635.30717 -927.81012 751.99 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2588.1246 2338.624 -3000.0754 2737.7826 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-8478.8364 8106.6252 -9840.7143 9449.4194 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-27980.601 27425.327 -32493.472 31909.728 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-92645.065 91816.693 -107615.31 106744.47 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-307213.82 305978.04 -356897.38 355598.23 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1019421. 1017577.4 -1184347.2 1182409.1 MAarrowhead1
% End of user PostScript
0 .027 1 r
.21594 .35025 m
.18196 .36199 L
.1431 .37747 L
.09859 .3974 L
.04756 .42258 L
s
.04756 .42258 m
0 .44809 L
s
1 0 0 r
.21594 .35025 m
.18196 .36199 L
s
% Start of user PostScript
-8.5216842 -4.4924751 -9.5410629 -4.1403466 MAarrowhead1
% End of user PostScript
1 .158 0 r
.1431 .37747 m
.09859 .3974 L
s
% Start of user PostScript
-10.706969 -3.6759017 -12.042169 -3.0781269 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-28.974365 7.5176442 -33.070329 10.513498 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-86.390992 54.381325 -99.48724 65.836403 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-272.19744 224.44463 -314.92838 264.72723 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-881.9008 810.66197 -1022.6534 947.76213 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2895.4524 2789.1766 -3361.0982 3249.3735 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-9564.6647 9406.1198 -11108.173 10941.499 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-31683.339 31446.817 -36804.25 36555.602 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-105084.28 104731.43 -122080.76 121709.82 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-348730.82 348204.44 -405152.86 404599.49 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1157586.5 1156801.2 -1344901.9 1344076.4 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3842963.6 3841792.1 -4464854.4 4463622.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-12758553. 12756805. -14823276. 14821438. MAarrowhead1
% End of user PostScript
0 .322 1 r
.23316 .44025 m
.199 .45767 L
.15978 .47928 L
.1147 .50586 L
.06283 .53827 L
.0031 .57755 L
s
.0031 .57755 m
0 .57968 L
s
1 0 0 r
.23316 .44025 m
.199 .45767 L
s
% Start of user PostScript
-8.0052826 -1.7924212 -9.0299953 -1.2700476 MAarrowhead1
% End of user PostScript
1 .158 0 r
.15978 .47928 m
.1147 .50586 L
s
% Start of user PostScript
-10.206656 -0.62148098 -11.559145 0.17583682 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-28.938043 12.78436 -33.174709 16.192809 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-88.694273 64.59581 -102.38194 77.047925 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-283.4606 247.50991 -328.34052 290.54661 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-924.69024 871.05812 -1072.8543 1016.4725 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3045.5659 2965.5562 -3536.2312 3452.1193 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-10075.065 9955.7042 -11702.256 11576.776 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-33395.836 33217.771 -38795.504 38608.31 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-110796.69 110531.05 -128720.05 128440.79 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-367736.55 367340.26 -427237.97 426821.36 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1220747.2 1220156. -1418289.6 1417668.1 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4052753.3 4051871.3 -4708603.2 4707676. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-13455212. 13453896. -15632689. 15631306. MAarrowhead1
% End of user PostScript
0 .285 1 r
.2151 .25973 m
.18351 .26439 L
.14755 .27204 L
.10655 .28328 L
.05975 .29881 L
.00623 .31944 L
s
.00623 .31944 m
0 .32215 L
s
1 0 0 r
.2151 .25973 m
.18351 .26439 L
s
% Start of user PostScript
-8.5470209 -7.2081732 -9.4947356 -7.0682446 MAarrowhead1
% End of user PostScript
1 .158 0 r
.14755 .27204 m
.10655 .28328 L
s
% Start of user PostScript
-10.573495 -6.8386872 -11.803362 -6.5015618 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-27.146601 1.1706769 -30.821855 3.5141174 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-78.256993 39.505469 -89.850532 49.112174 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-242.11009 184.29961 -279.69387 218.91938 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-777.41019 691.16709 -900.83796 810.17307 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2541.6733 2413.0137 -2949.4469 2814.1908 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-8379.8458 8187.9083 -9730.6865 9528.9081 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-27734.338 27448.001 -32214.79 31913.772 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-91950.369 91523.205 -106819.28 106370.21 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-305090.73 304453.48 -354447.25 353777.32 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1012645.6 1011695. -1176500.1 1175500.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3361667.4 3360249.1 -3905661.1 3904170.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-11160480. 11158365. -12966570. 12964346. MAarrowhead1
% End of user PostScript
1 .283 0 r
.47136 .78892 m
.45953 .8141 L
.44542 .84224 L
.42864 .87377 L
.40873 .90918 L
.38517 .94904 L
.35735 .994 L
s
.35735 .994 m
.35348 1 L
s
1 0 0 r
.47136 .78892 m
.45953 .8141 L
s
% Start of user PostScript
-0.85911723 8.6676813 -1.2139867 9.4229044 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44542 .84224 m
.42864 .87377 L
s
% Start of user PostScript
-1.6373522 10.26715 -2.1408663 11.213123 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-9.3806489 22.254795 -11.254611 24.788828 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-37.029276 56.235245 -43.552749 63.743429 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-131.72006 160.372 -153.82884 183.94979 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-450.42202 493.16569 -524.4972 569.43238 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1514.9908 1578.7568 -1761.9307 1828.9661 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5059.0922 5154.22 -5880.456 5980.4611 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-16840.258 16982.172 -19569.511 19718.701 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-55976.491 56188.201 -65041.255 65263.821 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-185945.26 186261.1 -216046.3 216378.33 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-617504.37 617975.54 -717450.74 717946.07 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2050402.1 2051105. -2382246.8 2382985.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-6807895.9 6808944.5 -7909675.5 7910777.9 MAarrowhead1
% End of user PostScript
.584 0 1 r
.60094 .74348 m
.60775 .75433 L
.61518 .76546 L
.6233 .77686 L
.6322 .78848 L
.64196 .80028 L
.65271 .81221 L
.66458 .82418 L
.6777 .83612 L
.69226 .8479 L
.70844 .85942 L
.72648 .87049 L
.74663 .88095 L
.76919 .89056 L
.79452 .89906 L
.82301 .90613 L
.85514 .91139 L
.89142 .9144 L
.93249 .91465 L
.97907 .91151 L
s
.97907 .91151 m
1 .90864 L
s
1 0 0 r
.60094 .74348 m
.60775 .75433 L
s
% Start of user PostScript
3.0281471 7.3045073 3.2326023 7.6298186 MAarrowhead1
% End of user PostScript
1 .158 0 r
.61518 .76546 m
.6233 .77686 L
s
% Start of user PostScript
3.4555022 7.963847 3.699081 8.3057507 MAarrowhead1
% End of user PostScript
1 .473 0 r
.70844 .85942 m
.72648 .87049 L
s
% Start of user PostScript
6.2531946 10.782473 6.7942964 11.114808 MAarrowhead1
% End of user PostScript
1 .788 0 r
.93249 .91465 m
.97907 .91151 L
s
% Start of user PostScript
12.974793 12.439436 14.372089 12.345155 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
31.46167 6.4519046 35.505284 4.3521607 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
87.127149 -30.566742 99.663931 -40.20361 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
263.42008 -179.04187 303.71819 -215.01382 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
836.01847 -710.14097 967.83554 -835.50416 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
2718.1439 -2530.3567 3152.842 -2955.4268 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
8938.723 -8658.5775 10377.571 -10083.062 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
29549.558 -29131.63 34320.137 -33880.781 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
97916.966 -97293.49 113746.05 -113090.61 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
324810.8 -323880.68 377350.6 -376372.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1077984.7 -1076597.1 1252401.2 -1250942.5 MAarrowhead1
% End of user PostScript
.356 1 0 r
.73646 .28456 m
.77414 .24796 L
.8179 .20533 L
.8687 .15572 L
.9277 .09798 L
.9962 .03079 L
s
.9962 .03079 m
1 .02706 L
s
1 0 0 r
.73646 .28456 m
.77414 .24796 L
s
% Start of user PostScript
7.0937339 -6.4630604 8.2243106 -7.5613019 MAarrowhead1
% End of user PostScript
1 .158 0 r
.8179 .20533 m
.8687 .15572 L
s
% Start of user PostScript
9.5369596 -8.8399577 11.061101 -10.328363 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
31.34524 -30.305435 36.389232 -35.296116 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
103.5946 -102.04339 120.31687 -118.68613 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
343.23715 -340.92303 398.72072 -396.28794 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1138.5298 -1135.0775 1322.6874 -1319.0582 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3778.474 -3773.3238 4389.8181 -4384.4039 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
12542.621 -12534.938 14572.235 -14564.158 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
41639.458 -41627.996 48377.831 -48365.781 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
138242.63 -138225.53 160614.55 -160596.57 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
458973.88 -458948.37 533250.86 -533224.05 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1523835.3 -1523797.2 1770443. -1770403. MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
5059293.9 -5059237.1 5878059.3 -5877999.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
16797421. -16797337. 19515817. -19515728. MAarrowhead1
% End of user PostScript
1 .515 0 r
.1763 .24938 m
.13979 .25644 L
.09818 .26709 L
.0507 .28204 L
s
.0507 .28204 m
0 .30077 L
s
1 0 0 r
.1763 .24938 m
.13979 .25644 L
s
% Start of user PostScript
-9.7110625 -7.5186348 -10.806403 -7.3066803 MAarrowhead1
% End of user PostScript
1 .158 0 r
.09818 .26709 m
.0507 .28204 L
s
% Start of user PostScript
-12.054589 -6.9871718 -13.479105 -6.5389477 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-31.319168 2.9121998 -35.602491 5.7390663 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-90.999241 48.621024 -104.55467 60.003672 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-282.75818 219.53731 -326.77066 260.30838 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-909.89365 815.5792 -1054.5387 955.38862 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2977.8447 2837.1441 -3455.8729 3307.9584 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-9822.4822 9612.5815 -11406.294 11185.632 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-32515.849 32202.714 -37769.372 37440.182 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-107813.3 107346.15 -125248.27 124757.17 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-357739.23 357042.34 -415614.43 414881.8 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1187417.5 1186377.9 -1379553.6 1378460.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3941889.9 3940338.9 -4579779.8 4578149.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-13086826. 13084513. -15204659. 15202227. MAarrowhead1
% End of user PostScript
0 1 .599 r
.45472 .76617 m
.44129 .79092 L
.42537 .81875 L
.40654 .85009 L
.38432 .88547 L
.35815 .92548 L
.32735 .97082 L
s
.32735 .97082 m
.30684 1 L
s
1 0 0 r
.45472 .76617 m
.44129 .79092 L
s
% Start of user PostScript
-1.3583578 7.9849892 -1.761352 8.727738 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42537 .81875 m
.40654 .85009 L
s
% Start of user PostScript
-2.2389554 9.5625157 -2.803724 10.502771 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-10.780996 21.706464 -12.827719 24.313347 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-40.787904 57.086787 -47.839297 64.973842 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-142.87039 167.18547 -166.6638 192.22554 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-485.46016 521.734 -565.02688 603.16051 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1628.3643 1682.4785 -1893.3852 1950.2739 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5431.094 5511.8229 -6312.2624 6397.1304 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-18068.766 18189.199 -20996.24 21122.848 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-60045.463 60225.128 -69767.841 69956.718 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-199440.08 199708.11 -231723.72 232005.49 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-662286.89 662686.74 -769478.64 769898.99 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2199052.7 2199649.2 -2554951.2 2555578.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-7301384.6 7302274.5 -8483023.3 8483958.8 MAarrowhead1
% End of user PostScript
0 .984 1 r
.77885 .53986 m
.81516 .51988 L
.85691 .49532 L
.90493 .46535 L
.96023 .42904 L
s
.96023 .42904 m
1 .40172 L
s
1 0 0 r
.77885 .53986 m
.81516 .51988 L
s
% Start of user PostScript
8.3653774 1.1957635 9.4549044 0.59644665 MAarrowhead1
% End of user PostScript
1 .158 0 r
.85691 .49532 m
.90493 .46535 L
s
% Start of user PostScript
10.707204 -0.14050961 12.147925 -1.0394641 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
30.719419 -14.955763 35.255153 -18.683277 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
94.786921 -71.270309 109.47667 -84.754339 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
303.95485 -268.87219 352.17544 -315.29405 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
993.1303 -940.79312 1152.4062 -1097.3856 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3273.3868 -3195.3089 3800.9748 -3718.8937 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
10832.34 -10715.861 12582.164 -12459.713 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
35911.395 -35737.629 41718.285 -41535.611 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
119150.61 -118891.38 138426.09 -138153.57 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
395475.46 -395088.74 459466.24 -459059.69 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1312848. -1312271.1 1525295.8 -1524689.3 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4358545.2 -4357684.5 5063883.2 -5062978.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
14470486. -14469202. 16812271. -16810921. MAarrowhead1
% End of user PostScript
.527 1 0 r
.30429 .43637 m
.27979 .44758 L
.25168 .4617 L
.21942 .47927 L
.18234 .5009 L
.13969 .52731 L
.09058 .55935 L
.034 .59798 L
s
.034 .59798 m
0 .62215 L
s
1 0 0 r
.30429 .43637 m
.27979 .44758 L
s
% Start of user PostScript
-5.8713023 -1.9088781 -6.6064298 -1.572649 MAarrowhead1
% End of user PostScript
1 .158 0 r
.25168 .4617 m
.21942 .47927 L
s
% Start of user PostScript
-7.4495002 -1.148929 -8.4174171 -0.621863 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-20.803101 7.9757523 -23.815197 10.330176 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-63.205693 44.069537 -72.9056 52.788313 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-201.10367 172.55588 -232.86005 202.84858 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-654.63927 612.05097 -759.40515 714.6333 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2154.013 2090.4787 -2500.8499 2434.0581 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-7122.5351 7027.7531 -8272.5853 8172.9437 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-23604.327 23462.929 -27420.407 27271.759 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-78304.496 78093.555 -90971.014 90749.258 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-259883.67 259568.98 -301933.05 301602.22 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-862700.33 862230.87 -1002301.8 1001808.3 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2864051.4 2863351. -3327533.6 3326797.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-9508665.3 9507620.5 -11047464. 11046366. MAarrowhead1
% End of user PostScript
1 .15 0 r
.3882 .22847 m
.3807 .21632 L
.37253 .20382 L
.36361 .19102 L
.35385 .17795 L
.34314 .16466 L
.33135 .1512 L
.31836 .13766 L
.30401 .12413 L
.28809 .11072 L
.27042 .09758 L
.25073 .08486 L
.22876 .07277 L
.20417 .06155 L
.17659 .05148 L
.14558 .0429 L
.11066 .03622 L
.07123 .03191 L
.02663 .03052 L
s
.02663 .03052 m
0 .03169 L
s
1 0 0 r
.3882 .22847 m
.3807 .21632 L
s
% Start of user PostScript
-3.3541462 -8.1458129 -3.579094 -8.5104806 MAarrowhead1
% End of user PostScript
1 .158 0 r
.37253 .20382 m
.36361 .19102 L
s
% Start of user PostScript
-3.8241486 -8.8852718 -4.0917284 -9.2693179 MAarrowhead1
% End of user PostScript
1 .473 0 r
.27042 .09758 m
.25073 .08486 L
s
% Start of user PostScript
-6.8874868 -12.07274 -7.4780424 -12.454296 MAarrowhead1
% End of user PostScript
1 .788 0 r
.02663 .03052 m
0 0 rlineto s
.02663 .03052 m
0 .03169 L
s
% Start of user PostScript
-14.201053 -14.084283 -15.71744 -14.018115 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-34.22069 -7.9760715 -38.592418 -5.7678179 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-94.32969 31.379519 -107.85547 41.677776 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-284.41277 190.50215 -327.84473 229.11921 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-901.35964 761.26146 -1043.3581 896.0769 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2928.5843 2719.5824 -3396.7525 3177.0349 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-9627.7131 9315.9189 -11177.189 10849.408 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-31822.621 31357.478 -36959.753 36470.763 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-105442.22 104748.31 -122487.2 121757.71 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-349763.32 348728.13 -406338.39 405250.12 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1160782. 1159237.6 -1348593.5 1346970. MAarrowhead1
% End of user PostScript
.185 0 1 r
.69492 .4361 m
.72284 .4149 L
.7551 .3897 L
.79238 .35985 L
.83549 .32454 L
.88536 .28288 L
.94307 .23379 L
s
.94307 .23379 m
1 .18459 L
s
1 0 0 r
.69492 .4361 m
.72284 .4149 L
s
% Start of user PostScript
5.8475534 -1.9169291 6.6852423 -2.5530905 MAarrowhead1
% End of user PostScript
1 .158 0 r
.7551 .3897 m
.79238 .35985 L
s
% Start of user PostScript
7.6529275 -3.3089158 8.7713613 -4.2046274 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
23.423083 -16.942579 27.034614 -20.221848 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
74.805311 -65.137536 86.644147 -76.480694 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
243.9435 -229.52087 283.02326 -267.86117 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
803.32875 -781.81272 932.74013 -910.12095 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2657.311 -2625.2128 3086.4677 -3052.7238 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8807.912 -8760.0272 10232.01 -10181.67 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
29221.411 -29149.975 33948.461 -33873.363 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
96985.849 -96879.279 112678.53 -112566.5 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
321955.65 -321796.66 374054.7 -373887.57 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1068857.7 -1068620.6 1241829. -1241579.6 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3548624.2 -3548270.4 4122903.4 -4122531.4 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
11781686. -11781158. 13688351. -13687796. MAarrowhead1
% End of user PostScript
.574 0 1 r
.83249 .74281 m
.8704 .7344 L
.91362 .72218 L
.96298 .70542 L
s
.96298 .70542 m
1 .69087 L
s
1 0 0 r
.83249 .74281 m
.8704 .7344 L
s
% Start of user PostScript
9.9746633 7.2843018 11.111854 7.0319972 MAarrowhead1
% End of user PostScript
1 .158 0 r
.91362 .72218 m
.96298 .70542 L
s
% Start of user PostScript
12.408622 6.6654841 13.889539 6.1625178 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
32.479817 -4.0245936 36.949638 -7.0354849 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
94.830673 -52.380468 109.00417 -64.377493 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
295.44608 -232.11781 341.50893 -274.93375 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
951.96988 -857.49521 1103.4198 -1004.1014 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3117.4695 -2976.5298 3618.0871 -3469.9213 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
10285.943 -10075.686 11944.75 -11723.712 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
34054.432 -33740.765 39556.935 -39227.186 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
112921.33 -112453.39 131182.93 -130691. MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
374698.13 -374000.05 435317.82 -434583.95 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1243722.5 -1242681.1 1444970.6 -1443875.8 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4128828.2 -4127274.6 4796971. -4795337.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
13707482. -13705165. 15925758. -15923322. MAarrowhead1
% End of user PostScript
1 .175 0 r
.40487 .51534 m
.39168 .52444 L
.37647 .53535 L
.35892 .54838 L
.33865 .56389 L
.31523 .58232 L
.28816 .60413 L
.25685 .62992 L
.22063 .66033 L
.17871 .69615 L
.13018 .73827 L
.07396 .78774 L
.00884 .84577 L
s
.00884 .84577 m
0 .85374 L
s
1 0 0 r
.40487 .51534 m
.39168 .52444 L
s
% Start of user PostScript
-2.8538346 0.46010253 -3.2495181 0.73305678 MAarrowhead1
% End of user PostScript
1 .158 0 r
.37647 .53535 m
.35892 .54838 L
s
% Start of user PostScript
-3.7058444 1.0603614 -4.2324537 1.4513339 MAarrowhead1
% End of user PostScript
1 .473 0 r
.13018 .73827 m
.07396 .78774 L
s
% Start of user PostScript
-11.094658 7.1480609 -12.781066 8.632123 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-35.031678 29.144047 -40.538264 34.348768 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-113.61819 104.83488 -131.76273 122.52908 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-373.21106 360.1079 -433.24721 419.47223 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1233.1153 1213.5676 -1432.1352 1411.5854 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4085.1521 4055.9905 -4745.4636 4714.8068 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-13549.854 13506.35 -15741.482 15695.747 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-44967.214 44902.314 -52242.655 52174.427 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-149266.74 149169.92 -173420.54 173318.75 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-495538.79 495394.35 -575729.94 575578.1 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1645180.7 1644965.2 -1911421.3 1911194.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-5462093.8 5461772.3 -6346038.7 6345700.8 MAarrowhead1
% End of user PostScript
1 0 .73 r
.55251 .65042 m
.55539 .65794 L
.55846 .66581 L
.56172 .67405 L
.5652 .68266 L
.5689 .69167 L
.57284 .70108 L
.57706 .71091 L
.58157 .72116 L
.5864 .73185 L
.59159 .74298 L
.59717 .75456 L
.60317 .76659 L
.60964 .77907 L
.61664 .792 L
.62423 .80537 L
.63246 .81917 L
.64141 .83337 L
.65117 .84795 L
.66184 .86287 L
.67353 .87809 L
.68636 .89354 L
.70049 .90914 L
.71609 .9248 L
.73334 .9404 L
.75248 .9558 L
.77377 .97084 L
.79749 .98529 L
.824 .99892 L
s
.824 .99892 m
.82657 1 L
s
1 0 0 r
.55251 .65042 m
.55539 .65794 L
s
% Start of user PostScript
1.575168 4.5126805 1.6618112 4.738168 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55846 .66581 m
.56172 .67405 L
s
% Start of user PostScript
1.7538487 4.9742645 1.8517111 5.2213598 MAarrowhead1
% End of user PostScript
1 .473 0 r
.59159 .74298 m
.59717 .75456 L
s
% Start of user PostScript
2.7477435 7.2894219 2.9149873 7.6367945 MAarrowhead1
% End of user PostScript
1 .788 0 r
.65117 .84795 m
.66184 .86287 L
s
% Start of user PostScript
4.5351118 10.438579 4.8551636 10.886245 MAarrowhead1
% End of user PostScript
.897 1 0 r
.77377 .97084 m
.79749 .98529 L
s
% Start of user PostScript
8.2130307 14.125092 8.924737 14.558685 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
17.058068 16.266494 18.897531 16.135619 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
41.403022 8.3113839 46.729303 5.5340146 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
114.73976 -40.57458 131.2586 -53.290888 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
347.05051 -236.40906 400.15695 -283.84279 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
1101.677 -936.6194 1275.4038 -1101.8835 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
3582.2532 -3336.0161 4155.1782 -3896.3163 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
11780.951 -11413.609 13677.359 -13291.182 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
38946.233 -38398.222 45233.919 -44657.812 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
129055.57 -128238.03 149918.58 -149059.13 MAarrowhead1
% End of user PostScript
1 0 .463 r
.43176 .32898 m
.42733 .32114 L
.42252 .31305 L
.41729 .30472 L
.41159 .29617 L
.40536 .28742 L
.39854 .27849 L
.39105 .26942 L
.3828 .26026 L
.3737 .25106 L
.36363 .24189 L
.35247 .23283 L
.34006 .22398 L
.32622 .21546 L
.31077 .20742 L
.29346 .20002 L
.27403 .19348 L
.25218 .18803 L
.22755 .18396 L
.19973 .18161 L
.16823 .18138 L
.13252 .18375 L
.09195 .18927 L
.04578 .19858 L
s
.04578 .19858 m
0 .21066 L
s
1 0 0 r
.43176 .32898 m
.42733 .32114 L
s
% Start of user PostScript
-2.0471489 -5.1307417 -2.1800452 -5.3658638 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42252 .31305 m
.41729 .30472 L
s
% Start of user PostScript
-2.3242763 -5.6085197 -2.481155 -5.8583641 MAarrowhead1
% End of user PostScript
1 .473 0 r
.36363 .24189 m
.35247 .23283 L
s
% Start of user PostScript
-4.0910017 -7.7433393 -4.4259553 -8.0151453 MAarrowhead1
% End of user PostScript
1 .788 0 r
.22755 .18396 m
.19973 .18161 L
s
% Start of user PostScript
-8.1734454 -9.4813168 -9.0081972 -9.551744 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-19.067278 -7.270532 -21.425019 -6.2631596 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-51.26729 11.975894 -58.478048 17.172139 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-152.25436 93.638484 -175.27414 113.65296 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-478.71054 391.26593 -553.76525 461.83726 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-1549.4064 1418.9543 -1796.5476 1659.4071 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-5084.5842 4889.9727 -5902.0648 5697.4753 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-16792.462 16502.136 -19502.033 19196.821 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-55620.238 55187.122 -64609.526 64154.203 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-184467.73 183821.6 -214303.06 213623.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-612159.1 611195.18 -711200.76 710187.42 MAarrowhead1
% End of user PostScript
.745 1 0 r
.40869 .33923 m
.40088 .33411 L
.39217 .32924 L
.38242 .32471 L
.37148 .32063 L
.3592 .31713 L
.34536 .31437 L
.32974 .31255 L
.31207 .31187 L
.29205 .31261 L
.26932 .31507 L
.24348 .31961 L
.21404 .32664 L
.18046 .33667 L
.14209 .35028 L
.0982 .36815 L
.04793 .39106 L
s
.04793 .39106 m
0 .41508 L
s
1 0 0 r
.40869 .33923 m
.40088 .33411 L
s
% Start of user PostScript
-2.7392097 -4.8231421 -2.9734782 -4.9766036 MAarrowhead1
% End of user PostScript
1 .158 0 r
.39217 .32924 m
.38242 .32471 L
s
% Start of user PostScript
-3.2349423 -5.122749 -3.5274536 -5.2587457 MAarrowhead1
% End of user PostScript
1 .473 0 r
.26932 .31507 m
.24348 .31961 L
s
% Start of user PostScript
-6.9203112 -5.5478991 -7.6956234 -5.4118457 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-17.277359 -1.3230246 -19.559299 0.0052524272 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-48.861119 21.112607 -56.00153 26.830322 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-149.54153 108.14561 -172.59826 129.07993 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-477.57441 415.81896 -553.15533 488.23361 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1557.3761 1465.2478 -1806.8664 1710.0146 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-5128.5615 4991.1222 -5954.7394 5810.2534 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-16964.604 16759.569 -19704.39 19488.843 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-56230.752 55924.876 -65322.359 65000.8 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-186552.86 186096.55 -216730.89 216251.18 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-619168.75 618488.01 -719352.64 718637. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2055401.5 2054386. -2388007.8 2386940.2 MAarrowhead1
% End of user PostScript
1 .804 0 r
.5516 .64827 m
.55442 .65569 L
.55742 .66346 L
.56061 .6716 L
.564 .68012 L
.56761 .68902 L
.57146 .69833 L
.57557 .70806 L
.57995 .71821 L
.58465 .7288 L
.58969 .73983 L
.59509 .75132 L
.60091 .76327 L
.60717 .77568 L
.61394 .78854 L
.62125 .80187 L
.62918 .81563 L
.63779 .82983 L
.64716 .84443 L
.65739 .85941 L
.66857 .87472 L
.68084 .89031 L
.69432 .90611 L
.70917 .92204 L
.72557 .938 L
.74374 .95386 L
.7639 .96947 L
.78634 .98463 L
.81136 .99913 L
s
.81136 .99913 m
.81316 1 L
s
1 0 0 r
.5516 .64827 m
.55442 .65569 L
s
% Start of user PostScript
1.5479083 4.4480496 1.6326799 4.6706974 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55742 .66346 m
.56061 .6716 L
s
% Start of user PostScript
1.7226731 4.9038853 1.8182973 5.148012 MAarrowhead1
% End of user PostScript
1 .473 0 r
.58969 .73983 m
.59509 .75132 L
s
% Start of user PostScript
2.6906548 7.1950086 2.8528474 7.5396649 MAarrowhead1
% End of user PostScript
1 .788 0 r
.64716 .84443 m
.65739 .85941 L
s
% Start of user PostScript
4.4148182 10.332859 4.7216495 10.782157 MAarrowhead1
% End of user PostScript
.897 1 0 r
.7639 .96947 m
.78634 .98463 L
s
% Start of user PostScript
7.9169467 14.084002 8.5900563 14.538905 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
16.229148 16.59241 17.948366 16.55599 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
38.880819 10.083193 43.819663 7.654787 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
106.70873 -33.663013 121.95882 -45.167965 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
320.89824 -211.92683 369.81851 -255.26002 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
1015.6118 -853.04555 1175.4791 -1004.5779 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
3297.6453 -3055.1249 3824.6137 -3569.6591 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
10837.718 -10475.92 12581.632 -12201.284 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
35817.124 -35277.385 41598.642 -41031.23 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
118670.34 -117865.14 137853.01 -137006.53 MAarrowhead1
% End of user PostScript
.605 0 1 r
.76921 .45715 m
.80653 .43144 L
.84955 .40061 L
.89921 .36378 L
.95655 .31993 L
s
.95655 .31993 m
1 .28578 L
s
1 0 0 r
.76921 .45715 m
.80653 .43144 L
s
% Start of user PostScript
8.0764399 -1.2856016 9.1957803 -2.0567683 MAarrowhead1
% End of user PostScript
1 .158 0 r
.84955 .40061 m
.89921 .36378 L
s
% Start of user PostScript
10.486645 -2.9816076 11.976298 -4.0864692 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
31.386536 -20.190336 36.15648 -24.386239 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
99.089488 -82.386721 114.66388 -97.104746 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
321.3543 -296.4367 372.67169 -346.47653 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1055.5447 -1018.372 1225.3405 -1186.2619 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3487.5411 -3432.086 4050.4119 -3992.1135 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
11553.697 -11470.968 13421.194 -13334.223 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
38321.813 -38198.395 44520.183 -44390.437 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
127176.49 -126992.37 147752.91 -147559.35 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
422156.65 -421881.98 490468.46 -490179.71 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1401483.9 -1401074.1 1628280.7 -1627849.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4652903.1 -4652291.8 5405885.3 -5405242.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
15447903. -15446991. 17947878. -17946919. MAarrowhead1
% End of user PostScript
.115 1 0 r
.6829 .50354 m
.70735 .48865 L
.73549 .47056 L
.7679 .44871 L
.80527 .42245 L
.84838 .39101 L
.89814 .35353 L
.95562 .30895 L
s
.95562 .30895 m
1 .27363 L
s
1 0 0 r
.6829 .50354 m
.70735 .48865 L
s
% Start of user PostScript
5.4870555 0.10613269 6.2204489 -0.34049177 MAarrowhead1
% End of user PostScript
1 .158 0 r
.73549 .47056 m
.7679 .44871 L
s
% Start of user PostScript
7.0646038 -0.88317492 8.0370391 -1.5386815 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
20.629946 -11.408338 23.713685 -14.019275 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
64.278885 -50.521862 74.301154 -59.838794 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
207.12545 -186.60238 240.07816 -218.50286 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
678.30016 -647.68335 787.22609 -755.03951 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2238.0417 -2192.3668 2598.971 -2550.9543 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
7409.6835 -7341.5445 8606.9406 -8535.308 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
24569.871 -24468.22 28543.308 -28436.444 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
81528.382 -81376.736 94718.275 -94558.853 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
270614.45 -270388.22 314402.88 -314165.05 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
898368.2 -898030.71 1043745.6 -1043390.8 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2982533.2 -2982029.7 3465195.3 -3464666. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
9902128.9 -9901377.8 11504612. -11503822. MAarrowhead1
% End of user PostScript
0 .217 1 r
.44268 .52195 m
.43438 .52843 L
.42479 .53612 L
.4137 .5452 L
.40087 .55593 L
.38602 .56856 L
.36883 .58342 L
.34893 .60088 L
.32587 .62137 L
.29914 .64539 L
.26817 .67351 L
.23227 .70643 L
.19063 .74492 L
.14235 .7899 L
.08634 .84243 L
.02136 .90376 L
s
.02136 .90376 m
0 .92403 L
s
1 0 0 r
.44268 .52195 m
.43438 .52843 L
s
% Start of user PostScript
-1.7195235 0.65842354 -1.9684717 0.85296793 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42479 .53612 m
.4137 .5452 L
s
% Start of user PostScript
-2.2562044 1.0835076 -2.5889213 1.356099 MAarrowhead1
% End of user PostScript
1 .473 0 r
.26817 .67351 m
.23227 .70643 L
s
% Start of user PostScript
-6.9548543 5.2053962 -8.0320315 6.1928767 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-22.291299 19.681414 -25.826656 23.082959 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-72.816812 68.923321 -84.493446 80.400332 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-239.98072 234.17231 -278.65727 272.55106 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-794.10918 785.44406 -922.38373 913.27434 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2632.5747 2619.6479 -3058.2582 3044.6686 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8734.5474 8715.2629 -10147.563 10127.29 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-28990.904 28962.135 -33681.83 33651.586 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-96240.042 96197.124 -111813.79 111768.67 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-319508.58 319444.55 -371214.23 371146.93 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1060776.6 1060681. -1232443.9 1232343.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3521858.6 3521716.1 -4091811.9 4091662.1 MAarrowhead1
% End of user PostScript
0 .599 1 r
.5573 .83306 m
.55578 .8546 L
.55346 .87795 L
.55019 .90335 L
.54577 .93101 L
.54 .96123 L
.53262 .99431 L
s
.53262 .99431 m
.53117 1 L
s
1 0 0 r
.5573 .83306 m
.55578 .8546 L
s
% Start of user PostScript
1.7188558 9.991949 1.6733296 10.637901 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55346 .87795 m
.55019 .90335 L
s
% Start of user PostScript
1.6038396 11.338601 1.5056565 12.100357 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-0.59070608 19.898559 -1.2199868 21.517775 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-10.786313 39.590244 -13.328071 43.608812 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-48.97732 91.947737 -58.091264 103.26482 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-182.25105 246.35538 -213.5174 280.90843 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-634.39515 730.02758 -739.70537 840.24097 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2149.9771 2292.6439 -2501.8604 2651.8419 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7203.3845 7416.2184 -8375.0217 8598.7677 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-24013.359 24330.87 -27908.319 28242.109 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-79872.286 80345.957 -92811.45 93309.406 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-265401.83 266108.47 -308372.47 309115.33 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-881488.1 882542.27 -1024172.2 1025280.4 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2927125.4 2928698. -3400878. 3402531.2 MAarrowhead1
% End of user PostScript
.98 0 1 r
.61096 .681 m
.62085 .68609 L
.63192 .69075 L
.64435 .69486 L
.65834 .69827 L
.6741 .70079 L
.69192 .70219 L
.71208 .70223 L
.73495 .70061 L
.76094 .69695 L
.79051 .69086 L
.82422 .68183 L
.8627 .66929 L
.90669 .65258 L
.95705 .63089 L
s
.95705 .63089 m
1 .61038 L
s
1 0 0 r
.61096 .681 m
.62085 .68609 L
s
% Start of user PostScript
3.3288095 5.4301147 3.6254213 5.5825826 MAarrowhead1
% End of user PostScript
1 .158 0 r
.63192 .69075 m
.64435 .69486 L
s
% Start of user PostScript
3.9576222 5.7224862 4.3305352 5.845883 MAarrowhead1
% End of user PostScript
1 .473 0 r
.79051 .69086 m
.82422 .68183 L
s
% Start of user PostScript
8.7152516 5.7257731 9.7265165 5.4549154 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
22.335051 -0.7915738 25.354149 -2.7061135 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
64.308038 -32.168947 73.826931 -40.040033 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
198.82029 -150.8744 229.67096 -179.26683 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
638.19185 -566.66498 739.49608 -664.30196 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2086.1785 -1979.473 2420.8442 -2308.6678 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
6877.5845 -6718.3985 7986.2131 -7818.8655 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
22761.625 -22524.147 26438.671 -26189.018 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
75462.712 -75108.437 87665.37 -87292.931 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
250383.1 -249854.58 290889.05 -290333.43 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
831059.58 -830271.13 965531.69 -964702.81 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2758854.6 -2757678.4 3205299.2 -3204062.7 MAarrowhead1
% End of user PostScript
.599 0 1 r
.54329 .2459 m
.55612 .22226 L
.57133 .19569 L
.58931 .16576 L
.61053 .13198 L
.63554 .09377 L
.66496 .05048 L
.69952 .00133 L
s
.69952 .00133 m
.70048 0 L
s
1 0 0 r
.54329 .2459 m
.55612 .22226 L
s
% Start of user PostScript
1.298612 -7.6229684 1.683582 -8.3321951 MAarrowhead1
% End of user PostScript
1 .158 0 r
.57133 .19569 m
.58931 .16576 L
s
% Start of user PostScript
2.1398162 -9.1293109 2.6793068 -10.027161 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
10.29915 -20.72625 12.254118 -23.215828 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
38.960328 -54.515734 45.695407 -62.048356 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
136.4628 -159.66874 159.18858 -183.58432 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
463.67926 -498.29846 539.67535 -576.06951 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1555.2929 -1606.9386 1808.42 -1862.7137 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5187.3601 -5264.4065 6028.9822 -6109.9789 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
17257.858 -17372.798 20053.947 -20174.78 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
57350.642 -57522.112 66636.679 -66816.94 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
190489.21 -190745.01 221323.96 -221592.88 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
632563.37 -632944.98 734944.33 -735345.51 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2100358.8 -2100928.1 2440284.5 -2440883. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
6973696.9 -6974546.2 8102303.4 -8103196.2 MAarrowhead1
% End of user PostScript
1 .611 0 r
.55335 .74095 m
.55385 .75554 L
.55401 .77124 L
.55376 .78816 L
.55301 .80644 L
.55166 .82623 L
.54957 .84769 L
.54661 .87101 L
.54261 .89642 L
.53737 .92417 L
.53067 .95455 L
.52222 .98787 L
s
.52222 .98787 m
.51874 1 L
s
1 0 0 r
.55335 .74095 m
.55385 .75554 L
s
% Start of user PostScript
1.6005047 7.2283787 1.6154838 7.6660661 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55401 .77124 m
.55376 .78816 L
s
% Start of user PostScript
1.6203751 8.1370501 1.6129044 8.6447947 MAarrowhead1
% End of user PostScript
1 .473 0 r
.53067 .95455 m
.52222 .98787 L
s
% Start of user PostScript
0.91997866 13.636389 0.66651325 14.636176 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-3.5988868 25.314436 -4.7815448 27.610474 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-21.874317 54.27011 -26.309776 60.366536 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-87.432535 135.76138 -102.91796 153.72468 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-312.37605 384.47421 -364.92204 440.71676 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1070.0791 1177.637 -1246.2276 1359.3 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-3601.9497 3762.4071 -4189.3036 4357.9879 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-12032.235 12271.609 -13986.079 14237.726 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-40057.838 40414.942 -46550.438 46925.852 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-133159.93 133692.67 -154724.49 155284.54 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-442350.03 443144.78 -513959.38 514794.88 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1469017.1 1470202.7 -1706787.1 1708033.5 MAarrowhead1
% End of user PostScript
0 .033 1 r
.19356 .64697 m
.14837 .68398 L
.0961 .72766 L
.03561 .77911 L
s
.03561 .77911 m
0 .80989 L
s
1 0 0 r
.19356 .64697 m
.14837 .68398 L
s
% Start of user PostScript
-9.1933143 4.4091557 -10.548869 5.5194218 MAarrowhead1
% End of user PostScript
1 .158 0 r
.0961 .72766 m
.03561 .77911 L
s
% Start of user PostScript
-12.11702 6.829707 -13.931823 8.3734239 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-37.813235 29.92549 -43.714687 35.42253 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-121.93908 110.17195 -141.34775 128.97731 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-399.47358 381.91908 -463.63686 445.18233 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1318.2753 1292.0871 -1530.8935 1503.3626 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-4364.8582 4325.79 -5070.1619 5029.0905 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-14473.983 14415.7 -16814.758 16753.486 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-48028.675 47941.727 -55798.956 55707.55 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-159421.07 159291.36 -185217.28 185080.92 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-529237.32 529043.81 -614880.69 614677.26 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1757041.3 1756752.7 -2041382.8 2041079.3 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-5833450.7 5833020.1 -6777490.9 6777038.2 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-19367542. 19366899. -22501855. 22501180. MAarrowhead1
% End of user PostScript
0 1 .801 r
.68952 .52214 m
.71434 .50817 L
.74288 .49104 L
.77572 .47019 L
.81354 .44498 L
.85714 .41464 L
.90742 .37829 L
.96546 .3349 L
s
.96546 .3349 m
1 .3083 L
s
1 0 0 r
.68952 .52214 m
.71434 .50817 L
s
% Start of user PostScript
5.6856223 0.66417731 6.4302373 0.24512358 MAarrowhead1
% End of user PostScript
1 .158 0 r
.74288 .49104 m
.77572 .47019 L
s
% Start of user PostScript
7.2863576 -0.26874371 8.2715674 -0.89415275 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
20.983997 -10.514947 24.090553 -13.084744 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
64.884203 -49.266216 74.952995 -58.534257 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
208.28458 -184.98528 241.34815 -216.85427 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
680.87967 -646.12121 790.10857 -753.568 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2244.713 -2192.8594 2606.5511 -2552.039 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
7429.0087 -7351.6523 8629.1385 -8547.8159 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
24629.82 -24514.418 28612.578 -28491.259 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
81721.134 -81548.975 94941.654 -94760.667 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
271245.03 -270988.2 315134.67 -314864.67 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
900447.83 -900064.68 1046160.5 -1045757.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2989416.9 -2988845.4 3473191.2 -3472590.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
9924952.5 -9924099.8 11531126. -11530230. MAarrowhead1
% End of user PostScript
0 1 .317 r
.2865 .48596 m
.25824 .50256 L
.22573 .5228 L
.18829 .54735 L
.14515 .57693 L
.09541 .61243 L
.03801 .65485 L
s
.03801 .65485 m
0 .68382 L
s
1 0 0 r
.2865 .48596 m
.25824 .50256 L
s
% Start of user PostScript
-6.4049428 -0.42120862 -7.2528016 0.076665986 MAarrowhead1
% End of user PostScript
1 .158 0 r
.22573 .5228 m
.18829 .54735 L
s
% Start of user PostScript
-8.2281993 0.68413527 -9.3512798 1.4204234 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-23.870395 12.615974 -27.422362 15.590914 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-74.108411 57.318787 -85.637611 67.987165 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-238.3745 213.32733 -276.25934 249.92797 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-779.98284 742.61684 -905.17794 865.89615 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2572.5552 2516.8117 -2987.342 2928.7404 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-8515.7053 8432.5457 -9891.5394 9804.1162 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-28235.127 28111.068 -32801.109 32670.688 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-93687.219 93502.144 -108843.9 108649.34 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-310967.93 310691.83 -361285.56 360995.3 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1032323.7 1031911.8 -1199377.6 1198944.6 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3427247.1 3426632.6 -3981876. 3981230.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-11378580. 11377663. -13219999. 13219035. MAarrowhead1
% End of user PostScript
.432 0 1 r
.52719 .28458 m
.53679 .26533 L
.54821 .24376 L
.56177 .21954 L
.57781 .19229 L
.59675 .16156 L
.61909 .12683 L
.64539 .0875 L
.6763 .0429 L
s
.6763 .0429 m
.70701 0 L
s
1 0 0 r
.52719 .28458 m
.53679 .26533 L
s
% Start of user PostScript
0.81564954 -6.4624595 1.1037318 -7.0400599 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54821 .24376 m
.56177 .21954 L
s
% Start of user PostScript
1.4464382 -7.6871283 1.853019 -8.4136762 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
7.6547953 -16.964811 9.1509395 -18.93829 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
29.670173 -43.559084 34.855723 -49.456734 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
104.85669 -125.57651 122.3988 -144.18095 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
357.60694 -388.51728 416.33438 -448.82952 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1201.4251 -1247.538 1397.1315 -1445.6085 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4009.9489 -4078.7411 4660.7974 -4733.1167 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
13344.942 -13447.568 15507.447 -15615.335 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
44353.676 -44506.776 51535.851 -51696.801 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
147329.37 -147557.77 171178.62 -171418.73 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
489255.12 -489595.85 568442.77 -568800.97 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1624539.9 -1625048.3 1887460.2 -1887994.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
5393894.9 -5394653.2 6266832.8 -6267630. MAarrowhead1
% End of user PostScript
1 0 .171 r
.29797 .6886 m
.26565 .72024 L
.22811 .75705 L
.18452 .79988 L
.1339 .84971 L
.0751 .90766 L
.00682 .97506 L
s
.00682 .97506 m
0 .9818 L
s
1 0 0 r
.29797 .6886 m
.26565 .72024 L
s
% Start of user PostScript
-6.0608528 5.658083 -7.0305735 6.6071532 MAarrowhead1
% End of user PostScript
1 .158 0 r
.22811 .75705 m
.18452 .79988 L
s
% Start of user PostScript
-8.1566573 7.7115279 -9.4643801 8.9964283 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-26.877599 26.213544 -31.20896 30.510858 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-88.933251 87.942597 -103.29831 102.25687 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-294.81599 293.33811 -342.48646 340.93281 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-978.14806 975.94332 -1136.385 1134.0672 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3246.5582 3243.2691 -3771.8716 3768.4138 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-10777.449 10772.543 -12521.474 12516.316 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-35780.149 35772.829 -41570.401 41562.705 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-118790.93 118780.01 -138015.07 138003.59 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-394394.8 394378.51 -458220.93 458203.81 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1309429.4 1309405.1 -1521339.2 1521313.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4347447.6 4347411.3 -5051012.5 5050974.4 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-14434018. 14433964. -16769935. 16769878. MAarrowhead1
% End of user PostScript
1 0 .365 r
.5068 .23147 m
.51514 .20971 L
.52519 .18555 L
.53726 .15865 L
.5517 .12862 L
.5689 .09503 L
.58934 .05736 L
.61357 .01502 L
s
.61357 .01502 m
.62259 0 L
s
1 0 0 r
.5068 .23147 m
.51514 .20971 L
s
% Start of user PostScript
0.2040366 -8.0559748 0.45409045 -8.7086062 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52519 .18555 m
.53726 .15865 L
s
% Start of user PostScript
0.75573914 -9.4334729 1.117903 -10.240554 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
6.4755006 -19.421158 7.8812865 -21.490682 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
27.41653 -46.729182 32.387281 -52.690113 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
99.85338 -128.66447 116.80944 -147.0977 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
344.69367 -387.67477 401.66494 -446.84972 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1164.0688 -1228.189 1354.2273 -1421.6351 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3894.1521 -3989.8083 4527.0033 -4627.5639 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
12972.762 -13115.464 15076.144 -15226.163 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
43136.313 -43349.199 50123.13 -50346.931 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
143314.91 -143632.5 166516.94 -166850.82 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
475967.41 -476441.2 553008.33 -553506.41 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1580484. -1581190.8 1836280. -1837023. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
5247714.7 -5248769.2 6097003.8 -6098112.3 MAarrowhead1
% End of user PostScript
.414 1 0 r
.70773 .49619 m
.73571 .47867 L
.76793 .45744 L
.80506 .43186 L
.84788 .40119 L
.89729 .36455 L
.95435 .32091 L
s
.95435 .32091 m
1 .28504 L
s
1 0 0 r
.70773 .49619 m
.73571 .47867 L
s
% Start of user PostScript
6.2318003 -0.11418369 7.0712232 -0.63994972 MAarrowhead1
% End of user PostScript
1 .158 0 r
.76793 .45744 m
.80506 .43186 L
s
% Start of user PostScript
8.0378238 -1.2768119 9.1517392 -2.0440828 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
23.596238 -13.509994 27.136126 -16.532749 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
73.73212 -58.685211 85.248593 -69.430213 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
237.92172 -215.47437 275.80514 -252.20689 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
779.66786 -746.18035 904.9192 -869.71474 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2573.2822 -2523.3247 2988.3465 -2935.8277 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8520.7636 -8446.2358 9897.6549 -9819.306 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
28255.867 -28144.684 32825.56 -32708.677 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
93761.963 -93596.098 108931.27 -108756.91 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
311224.87 -310977.43 361584.87 -361324.74 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1033189.9 -1032820.7 1200385.1 -1199997.1 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3430142.4 -3429591.7 3985241.7 -3984662.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
11388222. -11387401. 13231204. -13230340. MAarrowhead1
% End of user PostScript
.442 1 0 r
.33494 .32572 m
.31761 .32566 L
.29796 .32702 L
.27562 .33013 L
.25021 .33533 L
.22124 .34305 L
.18817 .35378 L
.15037 .3681 L
.1071 .38668 L
.0575 .41032 L
.0006 .43993 L
s
.0006 .43993 m
0 .44027 L
s
1 0 0 r
.33494 .32572 m
.31761 .32566 L
s
% Start of user PostScript
-4.9516669 -5.2283088 -5.4716337 -5.2302806 MAarrowhead1
% End of user PostScript
1 .158 0 r
.29796 .32702 m
.27562 .33013 L
s
% Start of user PostScript
-6.061322 -5.1892911 -6.7312757 -5.0961687 MAarrowhead1
% End of user PostScript
1 .473 0 r
.0006 .43993 m
0 0 rlineto s
.0006 .43993 m
0 .44027 L
s
% Start of user PostScript
-14.981946 -1.8019968 -16.942616 -0.70185745 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-42.070324 17.031624 -48.186653 21.864192 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-128.23388 90.880528 -147.95404 108.68554 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-408.67826 352.95361 -473.27612 414.69441 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1331.3894 1248.258 -1544.5559 1457.1623 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4382.3713 4258.3538 -5088.161 4957.785 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-14493.3 14308.288 -16833.698 16639.2 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-48034.886 47758.88 -55800.947 55510.789 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-159355.28 158943.53 -185133.04 184700.18 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-528889.97 528275.71 -614465.5 613819.75 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1755695.8 1754779.4 -2039802.2 2038838.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-5828696.4 5827329.4 -6771941.3 6770504.2 MAarrowhead1
% End of user PostScript
.702 0 1 r
.81933 .24617 m
.86919 .19966 L
.92704 .14535 L
.99415 .08195 L
s
.99415 .08195 m
1 .07639 L
s
1 0 0 r
.81933 .24617 m
.86919 .19966 L
s
% Start of user PostScript
9.5797562 -7.6149174 11.075779 -9.0102008 MAarrowhead1
% End of user PostScript
1 .158 0 r
.92704 .14535 m
.99415 .08195 L
s
% Start of user PostScript
12.811125 -10.639642 14.824382 -12.541565 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
41.541907 -38.302436 48.175269 -44.769706 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
136.44331 -131.61059 158.39093 -153.31043 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
450.79885 -443.58927 523.55426 -515.97504 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1493.4096 -1482.6542 1734.7971 -1723.4902 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
4953.3784 -4937.3332 5754.5612 -5737.6933 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
16438.462 -16414.525 19098.106 -19072.942 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
54566.674 -54530.965 63396.443 -63358.903 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
181151.42 -181098.14 210466.45 -210410.44 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
601419.53 -601340.06 698747.61 -698664.06 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1996746.8 -1996628.3 2319885.6 -2319760.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
6629378.8 -6629201.9 7702234.4 -7702048.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
22010232. -22009968. 25572234. -25571956. MAarrowhead1
% End of user PostScript
1 0 .88 r
.77572 .22661 m
.82028 .18217 L
.87204 .13053 L
.93218 .07053 L
s
.93218 .07053 m
1 .00284 L
s
1 0 0 r
.77572 .22661 m
.82028 .18217 L
s
% Start of user PostScript
8.2716951 -8.201736 9.6084049 -9.5348589 MAarrowhead1
% End of user PostScript
1 .158 0 r
.87204 .13053 m
.93218 .07053 L
s
% Start of user PostScript
11.161341 -11.084024 12.965491 -12.88421 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
37.021618 -36.906275 43.009795 -42.888538 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
122.86338 -122.69131 142.74213 -142.56123 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
407.84214 -407.58543 473.83786 -473.568 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1353.9662 -1353.5833 1573.0738 -1572.6712 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
4495.1512 -4494.5799 5222.6048 -5222.0042 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
14924.166 -14923.314 17339.384 -17338.488 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
49549.588 -49548.317 57568.373 -57567.036 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
164509.84 -164507.95 191133.12 -191131.12 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
546191.05 -546188.22 634583.39 -634580.41 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1813416.9 -1813412.6 2106889.7 -2106885.3 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
6020754.1 -6020747.8 6995118.1 -6995111.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
19989605. -19989595. 23224607. -23224597. MAarrowhead1
% End of user PostScript
.648 1 0 r
.4836 .56774 m
.47953 .57444 L
.47473 .58201 L
.46907 .59058 L
.46241 .6003 L
.4546 .61133 L
.44543 .62388 L
.43468 .63818 L
.42209 .6545 L
.40737 .67315 L
.39015 .6945 L
.37003 .71895 L
.34654 .74701 L
.31912 .77922 L
.28713 .81626 L
.24982 .85887 L
.20633 .90793 L
.15565 .96447 L
s
.15565 .96447 m
.12347 1 L
s
1 0 0 r
.4836 .56774 m
.47953 .57444 L
s
% Start of user PostScript
-0.4919263 2.0321241 -0.6141091 2.2332745 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47473 .58201 m
.46907 .59058 L
s
% Start of user PostScript
-0.75824798 2.4604298 -0.92800812 2.7174627 MAarrowhead1
% End of user PostScript
1 .473 0 r
.39015 .6945 m
.37003 .71895 L
s
% Start of user PostScript
-3.2954934 5.8348503 -3.8990069 6.5685594 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-12.102095 15.89037 -14.165339 18.147844 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-41.911889 47.563332 -48.850878 54.792076 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-141.73549 150.16646 -164.90619 173.76942 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-474.43198 487.00949 -551.55897 564.78135 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1580.9185 1599.6819 -1837.2839 1857.0093 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-5257.4105 5285.4023 -6109.0132 6138.4402 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-17468.012 17509.771 -20296.088 20339.988 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-58014.928 58077.225 -67405.452 67470.943 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-192644.82 192737.76 -223823.92 223921.62 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-639645.8 639784.45 -743166.23 743311.98 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2123762.2 2123969.1 -2467465.4 2467682.8 MAarrowhead1
% End of user PostScript
0 1 .681 r
.30284 .61453 m
.27321 .63991 L
.23891 .66976 L
.19918 .70481 L
.15316 .74591 L
.09981 .79408 L
.03798 .85047 L
s
.03798 .85047 m
0 .88542 L
s
1 0 0 r
.30284 .61453 m
.27321 .63991 L
s
% Start of user PostScript
-5.9148823 3.4357986 -6.803589 4.1973999 MAarrowhead1
% End of user PostScript
1 .158 0 r
.23891 .66976 m
.19918 .70481 L
s
% Start of user PostScript
-7.8326056 5.0927943 -9.0244588 6.1441744 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-24.752872 20.665554 -28.645758 24.348879 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-80.314227 74.216665 -93.143278 86.733087 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-263.86559 254.7691 -306.31665 296.75377 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-871.90686 858.33649 -1012.6362 998.37001 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2888.6301 2868.3855 -3355.5498 3334.2672 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-9581.3363 9551.1349 -11131.09 11099.34 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-31797.353 31752.297 -36942.008 36894.643 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-105550.34 105483.12 -122630.14 122559.48 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-350408.73 350308.46 -407114.09 407008.68 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1163352.1 1163202.5 -1351618.2 1351460.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3862396.7 3862173.6 -4487458.6 4487224. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-12823507. 12823174. -14898780. 14898430. MAarrowhead1
% End of user PostScript
1 .628 0 r
.25961 .67232 m
.22259 .70585 L
.17967 .7451 L
.12991 .791 L
.07221 .84466 L
.00527 .90733 L
s
.00527 .90733 m
0 .9123 L
s
1 0 0 r
.25961 .67232 m
.22259 .70585 L
s
% Start of user PostScript
-7.2116284 5.1696356 -8.3222746 6.1755866 MAarrowhead1
% End of user PostScript
1 .158 0 r
.17967 .7451 m
.12991 .791 L
s
% Start of user PostScript
-9.6097675 7.3530164 -11.102579 8.7301214 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-30.874051 27.507374 -35.777473 32.238182 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-100.96664 95.944151 -117.16768 111.88768 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-332.92542 325.43274 -386.59704 378.72021 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1101.9266 1090.7488 -1279.9471 1268.1962 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3653.4161 3636.7409 -4244.203 4226.6728 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-12122.147 12097.27 -14083.238 14057.086 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-40235.575 40198.463 -46746.042 46707.028 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-133569.85 133514.49 -155184.49 155126.29 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-443442.21 443359.62 -515204.06 515117.24 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1472242.2 1472119. -1710498. 1710368.5 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4887960.1 4887776.2 -5678994.3 5678801. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-16228515. 16228241. -18854837. 18854548. MAarrowhead1
% End of user PostScript
1 0 .665 r
.671 .59578 m
.6913 .58916 L
.71451 .58033 L
.74107 .56888 L
.77152 .55433 L
.80645 .5361 L
.84658 .51353 L
.89271 .48586 L
.94581 .45218 L
s
.94581 .45218 m
1 .41607 L
s
1 0 0 r
.671 .59578 m
.6913 .58916 L
s
% Start of user PostScript
5.1300272 2.8733632 5.7390213 2.6747117 MAarrowhead1
% End of user PostScript
1 .158 0 r
.71451 .58033 m
.74107 .56888 L
s
% Start of user PostScript
6.4352292 2.4098851 7.2321838 2.0664293 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
17.32285 -4.12749 19.76155 -5.8896496 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
51.482644 -31.79748 59.270185 -38.575741 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
161.93084 -132.56403 187.32507 -156.45259 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
524.20654 -480.3964 607.83016 -561.77383 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1720.4026 -1655.0455 1997.0161 -1928.3081 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5682.0648 -5584.5635 6598.9224 -6496.4221 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
18820.554 -18675.099 21862.344 -21709.431 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
62419.957 -62202.964 72515.645 -72287.527 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
207142.37 -206818.66 240656.15 -240315.84 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
687588.94 -687106.01 798851.02 -798343.34 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2282654.9 -2281934.5 2652046.8 -2651289.4 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
7578352. -7577277.2 8804759.1 -8803629.3 MAarrowhead1
% End of user PostScript
0 1 .347 r
.17814 .36931 m
.13856 .38569 L
.09321 .40664 L
.04121 .433 L
s
.04121 .433 m
0 .45561 L
s
1 0 0 r
.17814 .36931 m
.13856 .38569 L
s
% Start of user PostScript
-9.65591 -3.9207083 -10.843299 -3.429408 MAarrowhead1
% End of user PostScript
1 .158 0 r
.09321 .40664 m
.04121 .433 L
s
% Start of user PostScript
-12.203607 -2.8008771 -13.763832 -2.0099477 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-33.659256 11.275196 -38.487763 14.956048 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-101.52151 68.128421 -117.02816 81.922967 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-321.80021 271.98357 -372.50154 320.13074 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1045.6445 971.3268 -1212.8114 1134.6833 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3437.6934 3326.8244 -3990.9654 3874.412 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-11362.869 11197.472 -13197.198 13023.321 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-37650.454 37403.711 -43736.767 43477.372 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-124891.13 124523.03 -145092.62 144705.65 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-414484.91 413935.77 -481547.58 480970.29 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1375887.4 1375068.1 -1598530.4 1597669.2 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4567732.5 4566510.3 -5306914.2 5305629.4 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-15164847. 15163024. -17618988. 17617072. MAarrowhead1
% End of user PostScript
0 1 .529 r
.81295 .78022 m
.8472 .77638 L
.88615 .7694 L
.93052 .75864 L
.98114 .74335 L
s
.98114 .74335 m
1 .7366 L
s
1 0 0 r
.81295 .78022 m
.8472 .77638 L
s
% Start of user PostScript
9.3883871 8.4064847 10.415885 8.291349 MAarrowhead1
% End of user PostScript
1 .158 0 r
.88615 .7694 m
.93052 .75864 L
s
% Start of user PostScript
11.58445 8.0819251 12.915616 7.7590752 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
29.472757 -0.13397353 33.431511 -2.5884962 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
84.443032 -40.67471 96.899015 -50.886644 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
260.35542 -195.06076 300.68504 -232.04265 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
834.566 -737.15781 966.93492 -864.5325 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2726.334 -2581.0181 3163.5316 -3010.7651 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8985.3278 -8768.5419 10433.469 -10205.569 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
29733.252 -29409.845 34536.171 -34196.183 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
98570.052 -98087.586 114508.73 -114001.52 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
327043.58 -326323.82 379950.53 -379193.87 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1085493.9 -1084420.2 1261134.3 -1260005.5 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3603476. -3601874.1 4186597.5 -4184913.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
11963229. -11960840. 13899224. -13896711. MAarrowhead1
% End of user PostScript
0 1 .597 r
.57642 .64092 m
.58278 .64571 L
.58986 .65034 L
.59777 .65475 L
.60661 .65886 L
.61652 .66255 L
.62767 .66572 L
.64022 .66821 L
.65439 .66986 L
.67041 .67046 L
.68856 .66978 L
.70918 .66754 L
.73262 .66342 L
.75931 .65702 L
.78977 .64791 L
.82457 .63555 L
.86438 .61934 L
.90998 .59854 L
.96227 .57232 L
s
.96227 .57232 m
1 .55181 L
s
1 0 0 r
.57642 .64092 m
.58278 .64571 L
s
% Start of user PostScript
2.2926531 4.2277333 2.4834542 4.3712395 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58986 .65034 m
.59777 .65475 L
s
% Start of user PostScript
2.6958931 4.5102483 2.9329974 4.6426107 MAarrowhead1
% End of user PostScript
1 .473 0 r
.68856 .66978 m
.70918 .66754 L
s
% Start of user PostScript
5.6569471 5.0933526 6.2752881 5.0261912 MAarrowhead1
% End of user PostScript
1 .788 0 r
.96227 .57232 m
0 0 rlineto s
.96227 .57232 m
1 .55181 L
s
% Start of user PostScript
13.868053 2.1695091 15.669089 1.1907374 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
38.713221 -14.787989 44.317034 -19.165129 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
117.59684 -81.90459 135.64148 -98.119243 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
374.1213 -320.87472 433.19516 -377.21856 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1217.7889 -1138.3543 1412.6732 -1329.1659 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
4006.8941 -3888.3916 4652.0712 -4527.493 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
13249.192 -13072.408 15388.479 -15202.63 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
43908.065 -43644.332 51006.603 -50729.349 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
145659.36 -145265.92 169221.16 -168807.55 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
483426.29 -482839.34 561644.99 -561027.95 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1604763.5 -1603887.9 1864445. -1863524.5 MAarrowhead1
% End of user PostScript
1 .375 0 r
.66148 .26092 m
.68975 .22867 L
.72272 .19152 L
.76113 .14871 L
.80588 .09933 L
.85801 .04235 L
s
.85801 .04235 m
.89707 0 L
s
1 0 0 r
.66148 .26092 m
.68975 .22867 L
s
% Start of user PostScript
4.8442965 -7.172334 5.6926183 -8.1400168 MAarrowhead1
% End of user PostScript
1 .158 0 r
.72272 .19152 m
.76113 .14871 L
s
% Start of user PostScript
6.6815269 -9.2544062 7.8339431 -10.538737 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
23.359444 -27.197729 27.245896 -31.280974 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
79.310463 -85.036511 92.303884 -98.323513 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
265.93723 -274.47949 309.2111 -318.19133 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
886.84714 -899.5907 1030.7216 -1044.1186 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2950.2609 -2969.2721 3428.2397 -3448.2255 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9803.9008 -9832.2621 11391.292 -11421.107 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
32563.06 -32605.37 37834.048 -37878.527 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
108132.51 -108195.62 125633.79 -125700.15 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
359041.41 -359135.57 417149.21 -417248.2 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1192102.5 -1192243. 1385029.4 -1385177.1 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3957983.9 -3958193.5 4598527. -4598747.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
13141065. -13141378. 15267748. -15268077. MAarrowhead1
% End of user PostScript
0 1 .715 r
.27827 .58331 m
.24621 .60827 L
.20916 .63786 L
.16632 .67285 L
.11676 .71416 L
.05941 .76284 L
s
.05941 .76284 m
0 .8141 L
s
1 0 0 r
.27827 .58331 m
.24621 .60827 L
s
% Start of user PostScript
-6.6520441 2.4992663 -7.6137865 3.2480913 MAarrowhead1
% End of user PostScript
1 .158 0 r
.20916 .63786 m
.16632 .67285 L
s
% Start of user PostScript
-8.7252867 4.1357575 -10.010479 5.1856393 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-26.871222 20.024449 -31.030655 23.832841 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-86.086123 75.871938 -99.735477 88.9976 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-281.14736 265.90959 -326.22545 310.20642 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-926.47735 903.74526 -1075.7848 1051.8872 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3065.6229 3031.7106 -3560.8083 3525.1573 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-10162.726 10112.135 -11806.005 11752.82 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-33718.315 33642.842 -39173.007 39093.664 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-111914.25 111801.66 -130022.7 129904.33 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-371516.94 371348.97 -431636.45 431459.87 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1233402.9 1233152.3 -1433002.8 1432739.4 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4094927.3 4094553.5 -4757616.4 4757223.4 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-13595466. 13594909. -15795663. 15795077. MAarrowhead1
% End of user PostScript
0 1 .828 r
.60745 .73422 m
.61539 .74379 L
.62414 .75346 L
.63379 .76317 L
.64447 .77284 L
.65631 .78239 L
.66948 .79172 L
.68416 .80068 L
.70057 .80914 L
.71894 .8169 L
.73956 .82375 L
.76275 .82944 L
.78891 .83365 L
.81845 .83602 L
.8519 .83613 L
.88983 .83347 L
.93293 .82746 L
.98197 .8174 L
s
.98197 .8174 m
1 .81259 L
s
1 0 0 r
.60745 .73422 m
.61539 .74379 L
s
% Start of user PostScript
3.2233621 7.0265728 3.4616962 7.3137641 MAarrowhead1
% End of user PostScript
1 .158 0 r
.62414 .75346 m
.63379 .76317 L
s
% Start of user PostScript
3.724075 7.603855 4.0136449 7.8950804 MAarrowhead1
% End of user PostScript
1 .473 0 r
.73956 .82375 m
.76275 .82944 L
s
% Start of user PostScript
7.1866728 9.7126129 7.882613 9.8831176 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
16.136386 9.074386 18.05096 8.4523956 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
42.051523 -4.4414711 47.817328 -8.2789675 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
122.42543 -66.317827 140.6872 -81.702898 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
380.82147 -297.11876 440.13782 -352.14358 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1226.1136 -1101.2438 1421.0892 -1289.8172 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
4013.7658 -3827.482 4658.1815 -4462.3467 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
13241.026 -12963.124 15376.196 -15084.045 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
43834.734 -43420.152 50917.236 -50481.397 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
145346.95 -144728.46 168851.97 -168201.77 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
482286.17 -481363.5 560311.08 -559341.11 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1600824.7 -1599448.3 1859855. -1858407.9 MAarrowhead1
% End of user PostScript
1 .566 0 r
.49761 .48823 m
.49762 .4875 L
.49764 .48672 L
.49769 .48586 L
.49777 .48494 L
.49789 .48394 L
.49805 .48284 L
.49826 .48165 L
.49854 .48035 L
.49888 .47892 L
.49932 .47735 L
.49985 .47562 L
.5005 .4737 L
.5013 .47159 L
.50226 .46924 L
.50341 .46662 L
.50479 .46371 L
.50644 .46044 L
.5084 .45679 L
.51072 .45268 L
.51346 .44806 L
.51671 .44284 L
.52053 .43695 L
.52503 .43027 L
.53031 .42269 L
.53652 .41408 L
.54379 .40427 L
.55231 .39308 L
.56229 .38031 L
.57396 .3657 L
.58759 .34897 L
.60352 .32979 L
.62212 .30777 L
.64382 .28248 L
.66913 .25338 L
.69865 .2199 L
.73305 .18132 L
.77313 .13685 L
.81982 .08555 L
.87419 .02632 L
s
.87419 .02632 m
.89855 0 L
s
1 0 0 r
.49761 .48823 m
.49762 .4875 L
s
% Start of user PostScript
-0.071682501 -0.35295855 -0.071545772 -0.3748671 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49764 .48672 m
.49769 .48586 L
s
% Start of user PostScript
-0.070785125 -0.39851582 -0.069268735 -0.42409378 MAarrowhead1
% End of user PostScript
1 .473 0 r
.49932 .47735 m
.49985 .47562 L
s
% Start of user PostScript
-0.020510074 -0.67960467 -0.004477584 -0.73153281 MAarrowhead1
% End of user PostScript
1 .788 0 r
.5084 .45679 m
.51072 .45268 L
s
% Start of user PostScript
0.25190774 -1.2963562 0.32154442 -1.4195429 MAarrowhead1
% End of user PostScript
.897 1 0 r
.54379 .40427 m
.55231 .39308 L
s
% Start of user PostScript
1.3137524 -2.8718864 1.5694306 -3.2074518 MAarrowhead1
% End of user PostScript
.581 1 0 r
.66913 .25338 m
.69865 .2199 L
s
% Start of user PostScript
5.0739927 -7.3984555 5.9593884 -8.403029 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
17.908698 -21.376389 20.902789 -24.548272 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
61.04396 -66.217147 71.065954 -76.504376 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
205.03761 -212.7551 238.43303 -246.54621 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
684.27629 -695.78943 795.33386 -807.43729 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
2277.1396 -2294.3152 2646.1336 -2664.1898 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
7568.2204 -7593.8433 8793.7258 -8820.6625 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
25139.088 -25177.313 29208.51 -29248.695 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
83482.183 -83539.208 96994.036 -97053.984 MAarrowhead1
% End of user PostScript
0 .179 1 r
.36045 .55458 m
.34021 .57046 L
.31682 .58927 L
.28977 .61151 L
.25848 .63774 L
.22226 .66864 L
.18033 .70498 L
.13177 .74766 L
.07551 .79774 L
.01031 .85643 L
s
.01031 .85643 m
0 .86581 L
s
1 0 0 r
.36045 .55458 m
.34021 .57046 L
s
% Start of user PostScript
-4.1865775 1.6375346 -4.7936515 2.1139164 MAarrowhead1
% End of user PostScript
1 .158 0 r
.31682 .58927 m
.28977 .61151 L
s
% Start of user PostScript
-5.4953585 2.6782304 -6.306828 3.3452627 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-16.957599 12.754938 -19.585755 15.167619 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-54.380289 48.110656 -63.007585 56.4165 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-177.68324 168.33004 -206.17994 196.3472 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-585.65403 571.70071 -680.04723 665.3785 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1938.0622 1917.2463 -2251.1316 2229.2485 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6425.0787 6394.025 -7464.018 7431.3722 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-21317.819 21271.492 -24766.491 24717.789 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-70756.475 70687.364 -82205.386 82132.731 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-234888.18 234785.08 -272898.28 272789.9 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-779809.1 779655.29 -906004.67 905842.97 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2588987.1 2588757.6 -3007967.5 3007726.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-8595635. 8595292.7 -9986693.6 9986333.8 MAarrowhead1
% End of user PostScript
0 .283 1 r
.60934 .27125 m
.63034 .24413 L
.6549 .21313 L
.68362 .17765 L
.71717 .13699 L
.75635 .09033 L
.80207 .03675 L
s
.80207 .03675 m
.83389 0 L
s
1 0 0 r
.60934 .27125 m
.63034 .24413 L
s
% Start of user PostScript
3.2802978 -6.8624884 3.9101769 -7.6760304 MAarrowhead1
% End of user PostScript
1 .158 0 r
.6549 .21313 m
.68362 .17765 L
s
% Start of user PostScript
4.6470686 -8.6060015 5.5085515 -9.6704632 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
17.238333 -23.144366 20.191333 -26.400175 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
59.932769 -68.743536 69.87548 -79.137985 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
203.01096 -216.15508 236.2284 -250.04644 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
680.02796 -699.63669 790.62177 -811.23586 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2266.735 -2295.9877 2634.3789 -2665.1315 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
7539.1958 -7582.8358 8760.5021 -8806.3795 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
25050.958 -25116.061 29106.86 -29175.302 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
83201.867 -83298.99 96669.463 -96771.565 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
276284.32 -276429.21 321000.59 -321152.91 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
917362.47 -917578.62 1065829.1 -1066056.3 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3045849.4 -3046171.9 3538781.1 -3539120.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
10112724. -10113205. 11749322. -11749828. MAarrowhead1
% End of user PostScript
0 .179 1 r
.53483 .81459 m
.53081 .83652 L
.52564 .86052 L
.51912 .88685 L
.51099 .91579 L
.50097 .94769 L
.48873 .98293 L
s
.48873 .98293 m
.48223 1 L
s
1 0 0 r
.53483 .81459 m
.53081 .83652 L
s
% Start of user PostScript
1.0449095 9.4375646 0.92426784 10.095654 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52564 .86052 m
.51912 .88685 L
s
% Start of user PostScript
0.76924671 10.815679 0.57352071 11.605377 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.7411683 20.023846 -3.66249 21.83127 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-17.000446 42.783172 -20.464355 47.56899 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-68.228057 106.69136 -80.332849 120.76821 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-244.10567 301.48618 -285.19637 345.51884 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-836.68645 922.28811 -974.45706 1064.4476 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2817.0231 2944.7257 -3276.4436 3410.6938 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-9411.2154 9601.7254 -10939.538 11139.816 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-31333.412 31617.62 -36412.087 36710.866 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-104160.5 104584.48 -121028.95 121474.68 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-346018.82 346651.34 -402034. 402698.94 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1149112. 1150055.6 -1335103.8 1336095.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3815617.6 3817025.3 -4433154.1 4434634. MAarrowhead1
% End of user PostScript
.138 1 0 r
.75186 .53032 m
.78482 .51183 L
.82271 .48915 L
.86632 .46153 L
.91654 .42812 L
.97442 .38791 L
s
.97442 .38791 m
1 .36944 L
s
1 0 0 r
.75186 .53032 m
.78482 .51183 L
s
% Start of user PostScript
7.5557184 0.90965601 8.5445028 0.35490068 MAarrowhead1
% End of user PostScript
1 .158 0 r
.82271 .48915 m
.86632 .46153 L
s
% Start of user PostScript
9.6813094 -0.32562377 10.989478 -1.1541164 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
27.866847 -13.909804 31.990874 -17.318238 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
86.141803 -65.320342 99.506975 -77.617975 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
276.48393 -245.42196 320.36992 -287.71537 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
903.76138 -857.42237 1048.7401 -1000.0252 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2979.4132 -2910.2835 3459.6734 -3386.9994 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9860.4027 -9757.2733 11453.303 -11344.886 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
32690.552 -32536.701 37976.75 -37815.011 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
108466.13 -108236.62 126013.33 -125772.04 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
360015.34 -359672.94 418268.69 -417908.73 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1195136.5 -1194625.7 1388536.4 -1387999.4 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3967759.5 -3966997.5 4609857.8 -4609056.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
13173077. -13171940. 15304901. -15303706. MAarrowhead1
% End of user PostScript
0 1 .834 r
.30861 .3511 m
.28704 .35522 L
.26247 .36146 L
.23442 .37022 L
.20237 .382 L
.16569 .39737 L
.12367 .417 L
.07546 .44165 L
.0201 .47225 L
s
.0201 .47225 m
0 .48413 L
s
1 0 0 r
.30861 .3511 m
.28704 .35522 L
s
% Start of user PostScript
-5.7416401 -4.4668785 -6.3886626 -4.343258 MAarrowhead1
% End of user PostScript
1 .158 0 r
.26247 .36146 m
.23442 .37022 L
s
% Start of user PostScript
-7.1259283 -4.1562297 -7.9672998 -3.8933068 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-18.502145 1.6711428 -21.031203 3.3372573 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-53.736286 28.627382 -61.738628 35.342362 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-166.93415 129.47607 -192.91444 153.53584 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-537.11981 481.23892 -622.4996 563.75363 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1757.7589 1674.3944 -2039.9203 1952.2816 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5797.8615 5673.4963 -6732.7165 6601.9749 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-19192.734 19007.203 -22293.648 22098.604 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-63637.32 63360.54 -73928.367 73637.397 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-211156.83 210743.93 -245317.83 244883.75 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-700876.65 700260.67 -814285.47 813637.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2326710.9 2325791.9 -2703227. 2702260.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-7724532.2 7723161.3 -8974588.1 8973146.9 MAarrowhead1
% End of user PostScript
1 0 .731 r
.56495 .43828 m
.57537 .42803 L
.58748 .4161 L
.60154 .40222 L
.61786 .38608 L
.63683 .36732 L
.65886 .34551 L
.68445 .32014 L
.71417 .29065 L
.7487 .25637 L
.78881 .21653 L
.8354 .17021 L
.88952 .11637 L
.95239 .0538 L
s
.95239 .0538 m
1 .0064 L
s
1 0 0 r
.56495 .43828 m
.57537 .42803 L
s
% Start of user PostScript
1.9485631 -1.8515584 2.2612261 -2.1592478 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58748 .4161 m
.60154 .40222 L
s
% Start of user PostScript
2.6243511 -2.5171443 3.0460977 -2.9333943 MAarrowhead1
% End of user PostScript
1 .473 0 r
.78881 .21653 m
.8354 .17021 L
s
% Start of user PostScript
8.6641512 -8.5042174 10.061887 -9.8937531 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
28.692894 -28.4543 33.329791 -33.078965 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
95.154707 -94.798768 110.54416 -110.16997 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
315.76206 -315.23106 366.8485 -366.29028 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1048.1243 -1047.3321 1217.7248 -1216.892 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3479.533 -3478.3513 4042.608 -4041.3656 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
11551.916 -11550.153 13421.363 -13419.51 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
38352.907 -38350.277 44559.648 -44556.883 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
127334.93 -127331.01 147941.98 -147937.85 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
422765.08 -422759.22 491182.78 -491176.63 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1403626.8 -1403618.1 1630781.4 -1630772.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4660201.1 -4660188.1 5414380.9 -5414367.2 MAarrowhead1
% End of user PostScript
0 .874 1 r
.68186 .31404 m
.71141 .28428 L
.74574 .24973 L
.78564 .2096 L
.83199 .163 L
.88586 .10888 L
.94845 .04602 L
s
.94845 .04602 m
.99429 0 L
s
1 0 0 r
.68186 .31404 m
.71141 .28428 L
s
% Start of user PostScript
5.4559094 -5.5788186 6.3422597 -6.4714706 MAarrowhead1
% End of user PostScript
1 .158 0 r
.74574 .24973 m
.78564 .2096 L
s
% Start of user PostScript
7.3722259 -7.5080617 8.5690592 -8.7118593 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
24.538739 -24.741382 28.515548 -28.728581 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
81.564105 -81.866413 94.772326 -95.090134 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
270.94054 -271.39153 314.80047 -315.27458 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
899.76042 -900.43322 1045.3911 -1046.0984 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2987.6173 -2988.621 3471.1438 -3472.199 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9919.6975 -9921.1949 11525.086 -11526.66 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
32935.24 -32937.474 38265.351 -38267.7 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
109349.87 -109353.2 127046.51 -127050.02 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
363055.87 -363060.84 421810.88 -421816.11 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1205390.2 -1205397.6 1400463.8 -1400471.6 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4002039.9 -4002050.9 4649707.3 -4649718.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
13287245. -13287262. 15437577. -15437594. MAarrowhead1
% End of user PostScript
.873 0 1 r
.53518 .77572 m
.53228 .79456 L
.52847 .81513 L
.52358 .83763 L
.51741 .86232 L
.50973 .88947 L
.50027 .9194 L
.48871 .95247 L
.47469 .98911 L
s
.47469 .98911 m
.47016 1 L
s
1 0 0 r
.53518 .77572 m
.53228 .79456 L
s
% Start of user PostScript
1.0553029 8.2715331 0.96828592 8.8367471 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52847 .81513 m
.52358 .83763 L
s
% Start of user PostScript
0.85396891 9.4537789 0.70725607 10.128981 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.8761172 17.25347 -2.6047793 18.770546 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-13.257502 36.197817 -16.037108 40.153598 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-54.501856 88.724784 -64.268072 100.24565 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-196.59491 247.64952 -229.82189 283.49413 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-676.05379 752.21831 -787.56769 867.63725 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2279.3904 2393.0145 -2651.4144 2770.8642 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7619.7771 7789.2843 -8857.6032 9035.8013 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-25376.028 25628.903 -29489.728 29755.568 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-84366.962 84744.208 -98030.853 98427.44 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-280280.61 280843.39 -325655.16 326246.8 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-930821.62 931661.2 -1081483.6 1082366.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3090820.4 3092072.9 -3591055.6 3592372.3 MAarrowhead1
% End of user PostScript
1 0 .515 r
.7793 .63996 m
.81291 .62785 L
.85137 .61199 L
.89543 .59169 L
.94596 .56614 L
s
.94596 .56614 m
1 .53655 L
s
1 0 0 r
.7793 .63996 m
.81291 .62785 L
s
% Start of user PostScript
8.3790656 4.1989068 9.3874203 3.8354385 MAarrowhead1
% End of user PostScript
1 .158 0 r
.85137 .61199 m
.89543 .59169 L
s
% Start of user PostScript
10.541136 3.3596731 11.862824 2.7506954 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
28.644119 -7.9065485 32.706516 -10.905707 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
85.62324 -54.68642 98.624894 -66.101909 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
270.13878 -223.98647 312.5808 -264.06221 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
875.79736 -806.9462 1015.6283 -943.24703 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2876.2796 -2773.5658 3338.9211 -3230.941 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9502.6369 -9349.4059 11036.254 -10875.166 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
31479.828 -31251.234 36568.023 -36327.709 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
104412.23 -104071.2 121300.27 -120941.77 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
346504.92 -345996.18 402567.22 -402032.39 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1150204.3 -1149445.4 1336325.8 -1335527.9 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3818466. -3817333.7 4436393.2 -4435202.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
12677236. -12675547. 14728800. -14727024. MAarrowhead1
% End of user PostScript
1 0 .233 r
.38601 .73826 m
.36413 .76651 L
.33853 .79881 L
.3086 .83578 L
.27364 .87815 L
.23281 .92676 L
.18516 .98259 L
s
.18516 .98259 m
.17008 1 L
s
1 0 0 r
.38601 .73826 m
.36413 .76651 L
s
% Start of user PostScript
-3.4196384 7.1477751 -4.0761017 7.995384 MAarrowhead1
% End of user PostScript
1 .158 0 r
.33853 .79881 m
.3086 .83578 L
s
% Start of user PostScript
-4.8440865 8.9643148 -5.741912 10.073389 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-17.966179 24.112837 -21.04362 27.505425 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-62.459287 71.629023 -72.820797 82.460676 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-211.56337 225.24301 -246.17969 260.5607 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-708.66773 729.07536 -823.91852 845.37247 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2362.1875 2392.6321 -2745.3119 2777.3174 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-7856.6541 7902.0721 -9129.3852 9177.1318 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-26105.77 26173.525 -30332.45 30403.68 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-86705.177 86806.257 -100739.84 100846.1 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-287917.53 288068.32 -334516.61 334675.13 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-955988.78 956213.73 -1110706.7 1110943.2 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3174097.3 3174432.9 -3687784.3 3688137.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-10538528. 10539028. -12244036. 12244562. MAarrowhead1
% End of user PostScript
.878 1 0 r
.58634 .6537 m
.59367 .65867 L
.60186 .66342 L
.61101 .66787 L
.62127 .67191 L
.63279 .67542 L
.64576 .67826 L
.66039 .68024 L
.67693 .68116 L
.69567 .68078 L
.71693 .67882 L
.74109 .67495 L
.76861 .66876 L
.79999 .6598 L
.83583 .64754 L
.87682 .63133 L
.92376 .61045 L
.97757 .58403 L
s
.97757 .58403 m
1 .57205 L
s
1 0 0 r
.58634 .6537 m
.59367 .65867 L
s
% Start of user PostScript
2.5900604 4.6109618 2.810179 4.7600475 MAarrowhead1
% End of user PostScript
1 .158 0 r
.60186 .66342 m
.61101 .66787 L
s
% Start of user PostScript
3.0557152 4.9026452 3.3302592 5.036135 MAarrowhead1
% End of user PostScript
1 .473 0 r
.71693 .67882 m
.74109 .67495 L
s
% Start of user PostScript
6.5077795 5.364699 7.2327965 5.2483971 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
16.179999 1.5316578 18.308913 0.31084009 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
45.623967 -19.20128 52.277143 -24.499736 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
139.39981 -99.98179 160.86992 -119.4309 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
444.80675 -386.00197 515.1663 -453.34654 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1449.9323 -1362.2059 1682.1562 -1589.932 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
4773.8475 -4642.975 5542.802 -5405.2196 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
15789.914 -15594.675 18339.866 -18134.617 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
52335.121 -52043.859 60796.685 -60490.489 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
173625.59 -173191.08 201712.15 -201255.36 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
576258.66 -575610.45 669499.13 -668817.68 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1912949.9 -1911982.8 2222503.9 -2221487.3 MAarrowhead1
% End of user PostScript
.073 1 0 r
.2784 .61635 m
.24545 .64391 L
.20731 .67637 L
.16316 .71456 L
.11202 .75942 L
.05279 .81206 L
s
.05279 .81206 m
0 .85953 L
s
1 0 0 r
.2784 .61635 m
.24545 .64391 L
s
% Start of user PostScript
-6.6480196 3.4904701 -7.6366197 4.3171792 MAarrowhead1
% End of user PostScript
1 .158 0 r
.20731 .67637 m
.16316 .71456 L
s
% Start of user PostScript
-8.7807343 5.2911024 -10.105302 6.4367525 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-27.558048 22.352129 -31.873988 26.401156 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-89.116456 81.350137 -103.32388 95.159377 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-292.32728 280.74129 -339.3156 327.13558 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-965.2651 947.98084 -1121.0003 1102.8299 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3196.8928 3171.1077 -3713.5468 3686.4397 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-10602.272 10563.806 -12317.02 12276.581 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-35183.202 35125.816 -40875.462 40815.134 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-116786.11 116700.5 -135683.74 135593.74 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-387704.42 387576.71 -450444.74 450310.48 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1287165.6 1286975.1 -1495467.8 1495267.6 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4273453.3 4273169.1 -4965036.6 4964737.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-14188235. 14187811. -16484365. 16483920. MAarrowhead1
% End of user PostScript
1 .215 0 r
.34105 .42667 m
.32175 .43406 L
.29965 .44364 L
.27432 .45581 L
.24526 .47103 L
.21187 .48987 L
.17349 .51296 L
.12931 .54106 L
.07844 .57504 L
.01979 .61592 L
s
.01979 .61592 m
0 .63024 L
s
1 0 0 r
.34105 .42667 m
.32175 .43406 L
s
% Start of user PostScript
-4.768513 -2.19997 -5.3476073 -1.9781574 MAarrowhead1
% End of user PostScript
1 .158 0 r
.29965 .44364 m
.27432 .45581 L
s
% Start of user PostScript
-6.0105434 -1.6908213 -6.7703834 -1.3258387 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-16.435621 4.9465345 -18.777899 6.6997553 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-49.316831 32.177128 -56.824228 38.805754 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-155.90355 130.33412 -180.42732 153.54692 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-505.93091 467.7858 -586.75349 546.65264 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1662.3147 1605.4089 -1929.7612 1869.9377 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5493.0689 5408.1754 -6379.6891 6290.443 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-18198.829 18072.182 -21140.522 21007.382 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-60364.352 60175.418 -70128.149 69929.528 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-200330.35 200048.49 -232742.87 232446.56 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-664991.36 664570.88 -772598.11 772156.07 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2207656.9 2207029.6 -2564914. 2564254.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-7329392.2 7328456.4 -8515513. 8514529.2 MAarrowhead1
% End of user PostScript
1 .995 0 r
.30918 .42574 m
.28563 .4357 L
.25864 .4484 L
.22767 .46435 L
.19211 .48411 L
.15124 .50839 L
.1042 .53797 L
.05004 .57379 L
s
.05004 .57379 m
0 .60837 L
s
1 0 0 r
.30918 .42574 m
.28563 .4357 L
s
% Start of user PostScript
-5.7245794 -2.2278555 -6.4312009 -1.9289642 MAarrowhead1
% End of user PostScript
1 .158 0 r
.25864 .4484 m
.22767 .46435 L
s
% Start of user PostScript
-7.2409078 -1.547892 -8.1698053 -1.0696059 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-20.023537 6.9121883 -22.901623 9.1180411 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-60.48764 40.927806 -69.735962 49.173274 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-191.88576 162.70592 -222.1329 191.45697 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-623.74585 580.21464 -723.48605 677.72295 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2051.0122 1986.0713 -2381.1412 2312.8707 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6779.9176 6683.0371 -7874.4626 7772.6149 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-22465.838 22321.309 -26097.585 25945.646 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-74523.148 74307.536 -86577.585 86350.919 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-247327.01 247005.36 -287344.1 287005.96 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-821007.59 820527.73 -953861.46 953357.01 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2725621.9 2724906. -3166701. 3165948.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-9049056. 9047988.1 -10513474. 10512351. MAarrowhead1
% End of user PostScript
1 0 .152 r
.60712 .36985 m
.62509 .3507 L
.646 .32855 L
.67033 .30291 L
.69864 .27323 L
.73156 .23887 L
.76985 .19906 L
.81438 .15293 L
.86616 .09948 L
.92637 .03751 L
s
.92637 .03751 m
.96291 0 L
s
1 0 0 r
.60712 .36985 m
.62509 .3507 L
s
% Start of user PostScript
3.2134503 -3.9044432 3.7525962 -4.479017 MAarrowhead1
% End of user PostScript
1 .158 0 r
.646 .32855 m
.67033 .30291 L
s
% Start of user PostScript
4.3799736 -5.1436388 5.1099117 -5.9127308 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
14.891075 -16.03033 17.332451 -18.530117 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
49.960834 -51.660402 58.093185 -59.879892 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
166.65264 -169.18809 193.69282 -196.35828 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
554.46513 -558.24759 644.30112 -648.27751 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1842.6179 -1848.2607 2140.9726 -2146.9046 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6120.2861 -6128.7041 7110.9906 -7119.8402 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
20323.913 -20336.471 23613.365 -23626.567 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
67483.508 -67502.242 78405.168 -78424.863 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
224061.7 -224089.65 260323.33 -260352.71 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
743923.81 -743965.51 864317.31 -864361.14 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2469933.1 -2469995.3 2869654.6 -2869720. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
8200495.1 -8200587.9 9527618.6 -9527716.1 MAarrowhead1
% End of user PostScript
.031 1 0 r
.64643 .74129 m
.65941 .74819 L
.67394 .75456 L
.69025 .76022 L
.70858 .76498 L
.72925 .7686 L
.75259 .77078 L
.779 .7712 L
.80894 .76947 L
.84295 .76512 L
.88165 .7576 L
.92574 .74628 L
.97606 .73041 L
s
.97606 .73041 m
1 .72155 L
s
1 0 0 r
.64643 .74129 m
.65941 .74819 L
s
% Start of user PostScript
4.3928447 7.2387856 4.78225 7.4457468 MAarrowhead1
% End of user PostScript
1 .158 0 r
.67394 .75456 m
.69025 .76022 L
s
% Start of user PostScript
5.2181903 7.6367492 5.7073516 7.8066748 MAarrowhead1
% End of user PostScript
1 .473 0 r
.88165 .7576 m
.92574 .74628 L
s
% Start of user PostScript
11.449356 7.7279607 12.772177 7.3883811 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
29.247765 -0.63857044 33.190274 -3.1142549 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
84.029506 -41.349604 96.448652 -51.580504 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
259.47995 -195.80902 299.71278 -232.77737 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
832.40151 -737.41564 964.4871 -864.6312 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2720.2549 -2578.5526 3156.5685 -3007.601 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
8966.7959 -8755.401 10412.087 -10189.854 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
29674.188 -29358.824 34467.771 -34136.238 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
98377.629 -97907.161 114285.49 -113790.9 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
326410.19 -325708.34 379215.14 -378477.3 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1083399.2 -1082352.2 1258701.4 -1257600.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3596533.5 -3594971.5 4178532.6 -4176890.5 MAarrowhead1
% End of user PostScript
.96 1 0 r
.53992 .79627 m
.53709 .81634 L
.53332 .83823 L
.52844 .86215 L
.52225 .88837 L
.5145 .91717 L
.50491 .94889 L
.49316 .98391 L
s
.49316 .98391 m
.48723 1 L
s
1 0 0 r
.53992 .79627 m
.53709 .81634 L
s
% Start of user PostScript
1.1975495 8.8880599 1.1125799 9.4901298 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53332 .83823 m
.52844 .86215 L
s
% Start of user PostScript
0.99956616 10.146756 0.85323708 10.864569 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.776007 18.404366 -2.5230467 20.00396 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-13.496926 38.303522 -16.366864 42.445322 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-56.149799 93.156892 -66.259664 105.16415 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-203.33884 258.54694 -237.77202 295.8107 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-700.34286 782.70366 -815.95884 902.54237 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2362.8651 2485.733 -2748.6537 2877.8212 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7901.148 8084.4453 -9184.8908 9377.586 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-26316.515 26589.963 -30582.987 30870.454 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-87498.894 87906.829 -101670.49 102099.34 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-290693.01 291301.58 -337753.92 338393.69 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-965412.96 966320.83 -1121674.9 1122629.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3205698.9 3207053.3 -3724528.1 3725952. MAarrowhead1
% End of user PostScript
1 .367 0 r
.80356 .5041 m
.84418 .47926 L
.89094 .44908 L
.94481 .41264 L
s
.94481 .41264 m
1 .37374 L
s
1 0 0 r
.80356 .5041 m
.84418 .47926 L
s
% Start of user PostScript
9.1067398 0.12309145 10.325402 -0.62234752 MAarrowhead1
% End of user PostScript
1 .158 0 r
.89094 .44908 m
.94481 .41264 L
s
% Start of user PostScript
11.728206 -1.5276649 13.34428 -2.6207463 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
34.276622 -19.059203 39.403132 -23.405499 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
106.84692 -84.1452 123.51092 -99.645255 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
344.36793 -310.50094 399.16234 -363.55895 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1127.8621 -1077.3385 1308.9923 -1255.8783 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3721.5411 -3646.1687 4321.7305 -4242.4937 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
12321.501 -12209.058 14312.433 -14194.226 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
40857.429 -40689.684 47464.923 -47288.578 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
135574.77 -135324.52 157508.49 -157245.42 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
450009.71 -449636.38 522826.37 -522433.9 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1493914.2 -1493357.3 1735665.3 -1735079.8 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4959715.3 -4958884.4 5762344.1 -5761470.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
16466455. -16465215. 19131257. -19129954. MAarrowhead1
% End of user PostScript
1 .299 0 r
.26411 .49259 m
.23265 .51157 L
.19646 .53465 L
.15477 .56255 L
.10671 .59612 L
.05128 .63631 L
s
.05128 .63631 m
0 .67475 L
s
1 0 0 r
.26411 .49259 m
.23265 .51157 L
s
% Start of user PostScript
-7.0768438 -0.22227461 -8.020366 0.34701387 MAarrowhead1
% End of user PostScript
1 .158 0 r
.19646 .53465 m
.15477 .56255 L
s
% Start of user PostScript
-9.1062384 1.0394651 -10.356968 1.876602 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-26.546671 14.51246 -30.510197 17.858978 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-82.637539 64.684605 -95.51489 76.641489 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-266.16049 239.37786 -308.49408 280.33827 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-871.44233 831.48734 -1011.3672 969.36363 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2875.0281 2815.4222 -3338.6585 3275.9966 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-9518.1851 9429.2637 -11056.096 10962.615 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-31560.844 31428.189 -36664.803 36525.346 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-104725.06 104527.16 -121667.69 121459.64 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-347608.99 347313.76 -403855.86 403545.5 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1153967.5 1153527.1 -1340706.8 1340243.8 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3831105.8 3830448.8 -4451091.8 4450401.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-12719419. 12718439. -14777829. 14776799. MAarrowhead1
% End of user PostScript
0 .032 1 r
.68417 .79587 m
.7007 .80395 L
.71924 .81129 L
.74005 .81768 L
.76348 .82284 L
.78992 .82647 L
.8198 .82819 L
.85364 .82757 L
.89205 .82409 L
.9357 .81716 L
.9854 .80606 L
s
.9854 .80606 m
1 .80191 L
s
1 0 0 r
.68417 .79587 m
.7007 .80395 L
s
% Start of user PostScript
5.5250587 8.8762421 6.0211391 9.1185321 MAarrowhead1
% End of user PostScript
1 .158 0 r
.71924 .81129 m
.74005 .81768 L
s
% Start of user PostScript
6.5770932 9.3388056 7.2015641 9.5303602 MAarrowhead1
% End of user PostScript
1 .473 0 r
.9854 .80606 m
0 0 rlineto s
.9854 .80606 m
1 .80191 L
s
% Start of user PostScript
14.56199 9.181741 16.262323 8.6987749 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
37.494889 -2.0734052 42.583769 -5.3461862 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
108.29721 -55.454566 124.3628 -68.81085 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
335.40645 -256.57449 387.50772 -304.63396 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1077.5567 -959.9532 1248.6916 -1125.0585 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3523.8608 -3348.417 4089.2927 -3904.8538 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
11619.439 -11357.708 13492.628 -13217.477 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
38458.266 -38067.809 44671.338 -44260.862 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
127507.47 -126924.98 148126.45 -147514.09 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
423073.48 -422204.5 491517.23 -490603.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1404256.2 -1402959.9 1631477.1 -1630114.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4661702.3 -4659768.4 5416071.9 -5414038.8 MAarrowhead1
% End of user PostScript
0 .554 1 r
.64037 .1804 m
.66804 .14354 L
.70044 .10148 L
.73835 .05341 L
s
.73835 .05341 m
.7814 0 L
s
1 0 0 r
.64037 .1804 m
.66804 .14354 L
s
% Start of user PostScript
4.2109948 -9.587945 5.0411011 -10.693733 MAarrowhead1
% End of user PostScript
1 .158 0 r
.70044 .10148 m
.73835 .05341 L
s
% Start of user PostScript
6.0131671 -11.955616 7.1505574 -13.397682 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
22.680551 -31.545643 26.596079 -35.915694 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
79.354076 -92.579239 92.561837 -106.46507 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
269.50968 -289.2393 313.67091 -334.4121 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
903.82152 -933.25466 1050.9043 -1081.8466 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3014.2462 -3058.1553 3503.2682 -3549.4285 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
10027.72 -10093.224 11652.359 -11721.222 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
33323.142 -33420.863 38718.668 -38821.4 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
110681.39 -110827.18 128597.46 -128750.72 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
367541.8 -367759.28 427028.66 -427257.29 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1220381.2 -1220705.6 1417889.6 -1418230.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4051956.4 -4052440.4 4707715.1 -4708223.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
13453190. -13453912. 15630397. -15631156. MAarrowhead1
% End of user PostScript
.997 1 0 r
.72572 .71142 m
.75017 .70939 L
.77795 .70517 L
.80958 .69831 L
.84564 .68829 L
.88682 .67449 L
.9339 .65618 L
.98781 .63252 L
s
.98781 .63252 m
1 .62661 L
s
1 0 0 r
.72572 .71142 m
.75017 .70939 L
s
% Start of user PostScript
6.7716188 6.342695 7.5050086 6.2816904 MAarrowhead1
% End of user PostScript
1 .158 0 r
.77795 .70517 m
.80958 .69831 L
s
% Start of user PostScript
8.3385008 6.1550574 9.2873424 5.9493164 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
21.060183 0.56166535 23.870797 -1.1403726 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
60.039505 -27.783498 68.864371 -34.954564 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
184.59482 -136.47452 213.13851 -162.55102 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
590.8819 -519.09484 684.52258 -609.05491 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1928.9851 -1821.8914 2238.2008 -2125.6162 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6355.5064 -6195.7413 7379.6289 -7211.6725 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
21028. -20789.658 24424.462 -24173.901 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
69706.479 -69350.915 80977.546 -80603.752 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
231271.14 -230740.7 268684.07 -268126.44 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
767604.78 -766813.46 891807.65 -890975.75 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2548175.9 -2546995.4 2960525.4 -2959284.4 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
8459702.5 -8457941.3 9828723.3 -9826871.9 MAarrowhead1
% End of user PostScript
1 .994 0 r
.58805 .6063 m
.59692 .60739 L
.60696 .60783 L
.61834 .60747 L
.63125 .60613 L
.64592 .60363 L
.66264 .5997 L
.68171 .59408 L
.7035 .58644 L
.72841 .57639 L
.75696 .56347 L
.78968 .54718 L
.82725 .52688 L
.87042 .50186 L
.92008 .47129 L
.97725 .43419 L
s
.97725 .43419 m
1 .41873 L
s
1 0 0 r
.58805 .6063 m
.59692 .60739 L
s
% Start of user PostScript
2.6414266 3.1890682 2.9077404 3.2216903 MAarrowhead1
% End of user PostScript
1 .158 0 r
.60696 .60783 m
.61834 .60747 L
s
% Start of user PostScript
3.20889 3.2348032 3.5500896 3.2239789 MAarrowhead1
% End of user PostScript
1 .473 0 r
.75696 .56347 m
.78968 .54718 L
s
% Start of user PostScript
7.7086515 1.9042092 8.6904683 1.4152544 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
21.199845 -6.8591416 24.234317 -9.1583506 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
63.831214 -42.437399 73.569949 -51.079249 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
202.14856 -170.23274 233.98094 -200.42876 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
656.56899 -608.95618 761.50828 -711.4543 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2158.1233 -2087.0933 2505.4182 -2430.7464 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
7132.7557 -7026.7915 8284.1509 -8172.7537 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
23633.15 -23475.069 27453.433 -27287.248 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
78392.566 -78156.738 91072.649 -90824.73 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
260164.69 -259812.88 302258.52 -301888.67 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
863616.4 -863091.55 1003364.6 -1002812.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2867067.5 -2866284.5 3331035.6 -3330212.5 MAarrowhead1
% End of user PostScript
.703 1 0 r
.19745 .64272 m
.1529 .67907 L
.10137 .72199 L
.04175 .77256 L
s
.04175 .77256 m
0 .80855 L
s
1 0 0 r
.19745 .64272 m
.1529 .67907 L
s
% Start of user PostScript
-9.0765598 4.2816743 -10.412924 5.3721991 MAarrowhead1
% End of user PostScript
1 .158 0 r
.10137 .72199 m
.04175 .77256 L
s
% Start of user PostScript
-11.958762 6.6595936 -13.747626 8.1767634 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-37.28238 29.37695 -43.097433 34.786684 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-120.1685 108.37499 -139.2899 126.89172 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-393.58298 375.98912 -456.79187 438.29596 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1298.6998 1272.4529 -1508.1484 1480.5558 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-4299.8385 4260.6826 -4994.6173 4953.4539 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-14258.069 14199.656 -16563.899 16502.49 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-47311.758 47224.615 -54966.012 54874.401 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-157040.74 156910.74 -182451.71 182315.05 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-521334.19 521140.25 -605698.56 605494.67 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1730801.8 1730512.5 -2010896.8 2010592.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-5746332.2 5745900.6 -6676273.6 6675819.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-19078298. 19077654. -22165802. 22165125. MAarrowhead1
% End of user PostScript
1 0 .987 r
.43273 .77652 m
.41606 .80392 L
.3964 .83486 L
.37324 .86987 L
.34601 .90957 L
.31402 .95466 L
s
.31402 .95466 m
.28086 1 L
s
1 0 0 r
.43273 .77652 m
.41606 .80392 L
s
% Start of user PostScript
-2.0180367 8.2955268 -2.5181389 9.1174828 MAarrowhead1
% End of user PostScript
1 .158 0 r
.3964 .83486 m
.37324 .86987 L
s
% Start of user PostScript
-3.108071 10.045771 -3.8028268 11.09623 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-13.490195 23.840026 -15.959448 26.839926 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-49.519653 64.959787 -57.960406 74.192173 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-171.46831 194.50228 -199.85443 224.06938 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-579.82304 614.18569 -674.60807 710.73253 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1940.7865 1992.0496 -2256.2892 2310.1805 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6467.0691 6543.5446 -7515.7762 7596.1727 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-21506.381 21620.469 -24990.003 25109.94 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-71455.844 71626.044 -83024.551 83203.477 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-237319.55 237573.46 -275733. 275999.93 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-788044.71 788423.5 -915587.8 915986.01 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2616573.7 2617138.8 -3040040.6 3040634.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-8687589. 8688432. -10093562. 10094448. MAarrowhead1
% End of user PostScript
.448 1 0 r
.50391 .48222 m
.50493 .48049 L
.50613 .47855 L
.50755 .47634 L
.50921 .47385 L
.51117 .47102 L
.51347 .46781 L
.51617 .46415 L
.51933 .45998 L
.52303 .45522 L
.52736 .44978 L
.53242 .44355 L
.53833 .4364 L
.54523 .42821 L
.55329 .41879 L
.56268 .40796 L
.57364 .3955 L
.58641 .38115 L
.60129 .36461 L
.61863 .34552 L
.63881 .3235 L
.66232 .29806 L
.68969 .26866 L
.72153 .23468 L
.7586 .19537 L
.80172 .14989 L
.85188 .09724 L
.91024 .03628 L
s
.91024 .03628 m
.94511 0 L
s
1 0 0 r
.50391 .48222 m
.50493 .48049 L
s
% Start of user PostScript
0.11742413 -0.53335885 0.14792414 -0.58518429 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50613 .47855 m
.50755 .47634 L
s
% Start of user PostScript
0.18394954 -0.6436285 0.22642477 -0.70967197 MAarrowhead1
% End of user PostScript
1 .473 0 r
.52736 .44978 m
.53242 .44355 L
s
% Start of user PostScript
0.82084086 -1.5066013 0.97263598 -1.6935561 MAarrowhead1
% End of user PostScript
1 .788 0 r
.60129 .36461 m
.61863 .34552 L
s
% Start of user PostScript
3.0387302 -4.0617646 3.5587783 -4.6342647 MAarrowhead1
% End of user PostScript
.897 1 0 r
.85188 .09724 m
.91024 .03628 L
s
% Start of user PostScript
10.556541 -12.082729 12.307136 -13.911573 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
35.74653 -38.023335 41.594476 -43.988015 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
119.72333 -123.11992 139.19254 -142.76328 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
399.04793 -404.11505 463.76761 -469.09453 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
1327.2018 -1334.7611 1542.1975 -1550.1443 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
4409.9204 -4421.1975 5123.9083 -5135.7635 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
14646.606 -14663.429 17017.393 -17035.079 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
48636.133 -48661.231 56507.819 -56534.203 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
161489.12 -161526.56 187624.63 -187663.99 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
536179.88 -536235.73 622953.69 -623012.41 MAarrowhead1
% End of user PostScript
1 0 .695 r
.76614 .59308 m
.79928 .57836 L
.83727 .55973 L
.88088 .53647 L
.93099 .50777 L
.98861 .47264 L
s
.98861 .47264 m
1 .46531 L
s
1 0 0 r
.76614 .59308 m
.79928 .57836 L
s
% Start of user PostScript
7.9840992 2.7925031 8.9783261 2.3508044 MAarrowhead1
% End of user PostScript
1 .158 0 r
.83727 .55973 m
.88088 .53647 L
s
% Start of user PostScript
10.118181 1.7918068 11.426447 1.0941783 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
28.149808 -10.382195 32.2143 -13.535722 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
85.339558 -58.833393 98.417769 -70.552604 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
271.22206 -231.6795 314.02208 -272.45214 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
882.4151 -823.42455 1023.5895 -961.57447 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2902.7583 -2814.7548 3370.0915 -3277.5759 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9597.273 -9465.9871 11146.812 -11008.794 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
31804.061 -31608.206 36945.634 -36739.736 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
105503.68 -105211.5 122569.71 -122262.55 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
350151.01 -349715.12 406805.38 -406347.15 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1162343.1 -1161692.8 1350432. -1349748.4 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3858817.6 -3857847.6 4483279.7 -4482259.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
12811282. -12809835. 14884547. -14883025. MAarrowhead1
% End of user PostScript
0 .989 1 r
.3238 .59614 m
.29749 .61834 L
.26705 .64447 L
.23179 .67519 L
.19096 .71125 L
.14365 .75355 L
.08882 .80311 L
.02527 .86112 L
s
.02527 .86112 m
0 .88439 L
s
1 0 0 r
.3238 .59614 m
.29749 .61834 L
s
% Start of user PostScript
-5.2861049 2.8843058 -6.0751901 3.5502481 MAarrowhead1
% End of user PostScript
1 .158 0 r
.26705 .64447 m
.23179 .67519 L
s
% Start of user PostScript
-6.9885725 4.334174 -8.0461932 5.2557008 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-21.989624 18.029727 -25.438843 21.275918 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-71.19816 65.290687 -82.557173 76.346818 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-233.68607 224.87316 -271.26088 261.99612 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-771.83693 758.68961 -896.38317 882.56177 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2556.5796 2536.9661 -2969.7795 2949.1604 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-8479.1783 8449.9184 -9850.5909 9819.8308 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-28138.489 28094.839 -32691.054 32645.165 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-93403.123 93338.004 -108517.15 108448.69 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-310079.53 309982.38 -360258.33 360156.2 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1029455.9 1029311. -1196053.1 1195900.7 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3417847.6 3417631.4 -3970966.4 3970739.2 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-11347555. 11347232. -13183969. 13183630. MAarrowhead1
% End of user PostScript
0 1 .651 r
.55752 .52966 m
.56442 .52723 L
.57231 .52403 L
.58135 .51993 L
.59172 .51476 L
.60362 .50832 L
.61729 .50038 L
.63302 .49069 L
.65113 .47892 L
.67199 .46473 L
.69605 .44768 L
.7238 .4273 L
.75584 .403 L
.79286 .37413 L
.83563 .33992 L
.8851 .29945 L
.94232 .25169 L
s
.94232 .25169 m
1 .20268 L
s
1 0 0 r
.55752 .52966 m
.56442 .52723 L
s
% Start of user PostScript
1.7256067 0.88966548 1.9325808 0.81677928 MAarrowhead1
% End of user PostScript
1 .158 0 r
.57231 .52403 m
.58135 .51993 L
s
% Start of user PostScript
2.1693441 0.72097871 2.4405274 0.59798537 MAarrowhead1
% End of user PostScript
1 .473 0 r
.69605 .44768 m
.7238 .4273 L
s
% Start of user PostScript
5.8813873 -1.5695324 6.714014 -2.1810856 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
17.556061 -11.123529 20.219432 -13.457098 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
55.348037 -45.751828 64.039998 -53.95178 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
179.37579 -165.05992 208.00923 -192.95938 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
589.00519 -567.64843 683.73608 -661.28434 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1945.8045 -1913.944 2259.8216 -2226.3276 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
6445.7358 -6398.2055 7487.5628 -7437.5956 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
21378.872 -21307.965 24836.745 -24762.203 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
70947.944 -70842.164 82426.827 -82315.623 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
235507.12 -235349.32 273615.88 -273449.98 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
781839.05 -781603.63 908360.87 -908113.38 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2595689.5 -2595338.3 3015751.2 -3015382. MAarrowhead1
% End of user PostScript
1 .498 0 r
.71394 .45844 m
.7438 .43742 L
.77825 .41226 L
.81801 .38227 L
.86394 .34661 L
.91702 .30432 L
.97839 .2543 L
s
.97839 .2543 m
1 .23632 L
s
1 0 0 r
.71394 .45844 m
.7438 .43742 L
s
% Start of user PostScript
6.418319 -1.2468494 7.3140793 -1.8774628 MAarrowhead1
% End of user PostScript
1 .158 0 r
.77825 .41226 m
.81801 .38227 L
s
% Start of user PostScript
8.3474754 -2.6321176 9.5404057 -3.5320153 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
25.102258 -16.575946 28.928989 -19.965524 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
79.445285 -66.725522 91.950668 -78.578749 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
257.95377 -238.97812 299.17503 -279.22647 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
847.76343 -819.45508 984.17812 -954.41836 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2801.7347 -2759.5036 3253.984 -3209.5877 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9282.7842 -9219.7828 10783.315 -10717.084 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
30791.133 -30697.146 35771.594 -35672.788 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
102187.2 -102046.99 118720.71 -118573.31 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
339209.37 -339000.2 394099.28 -393879.38 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1126119.2 -1125807.1 1308355.2 -1308027.1 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3738704.7 -3738239.1 4343742.2 -4343252.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
12412724. -12412029. 14421508. -14420778. MAarrowhead1
% End of user PostScript
0 .004 1 r
.54293 .52114 m
.5481 .51925 L
.55403 .51678 L
.56081 .51363 L
.5686 .50966 L
.57754 .50473 L
.58781 .49868 L
.59963 .49129 L
.61324 .48234 L
.62892 .47156 L
.64701 .45863 L
.66788 .44317 L
.69198 .42477 L
.71982 .40291 L
.75201 .37702 L
.78922 .34642 L
.83228 .31031 L
.88211 .26779 L
.93981 .21778 L
s
.93981 .21778 m
1 .16487 L
s
1 0 0 r
.54293 .52114 m
.5481 .51925 L
s
% Start of user PostScript
1.2878386 0.63432963 1.4431247 0.57759517 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55403 .51678 m
.56081 .51363 L
s
% Start of user PostScript
1.6208174 0.50350698 1.8244032 0.40883766 MAarrowhead1
% End of user PostScript
1 .473 0 r
.64701 .45863 m
.66788 .44317 L
s
% Start of user PostScript
4.4103318 -1.2412123 5.0364776 -1.7048738 MAarrowhead1
% End of user PostScript
1 .788 0 r
.93981 .21778 m
0 0 rlineto s
.93981 .21778 m
1 .16487 L
s
% Start of user PostScript
13.194298 -8.4665274 15.198908 -10.228739 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
41.645676 -34.592671 48.190422 -40.775801 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
135.04478 -124.52293 156.60881 -145.5475 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
443.55519 -427.85844 514.90374 -498.4022 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1465.4805 -1442.0637 1701.9982 -1677.3808 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
4854.8635 -4819.9298 5639.5811 -5602.8562 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
16102.747 -16050.632 18707.283 -18652.496 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
53439.183 -53361.437 62085.324 -62003.591 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
177388.8 -177272.82 206093.18 -205971.25 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
588898.55 -588725.52 684197.72 -684015.82 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1955132.9 -1954874.8 2271533.3 -2271261.9 MAarrowhead1
% End of user PostScript
0 .946 1 r
.20822 .74888 m
.16218 .79272 L
.10876 .84383 L
.04676 .9034 L
s
.04676 .9034 m
0 .9485 L
s
1 0 0 r
.20822 .74888 m
.16218 .79272 L
s
% Start of user PostScript
-8.7534399 7.4664529 -10.134473 8.7815007 MAarrowhead1
% End of user PostScript
1 .158 0 r
.10876 .84383 m
.04676 .9034 L
s
% Start of user PostScript
-11.73718 10.31484 -13.597344 12.102078 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-38.318698 36.196815 -44.461325 42.230651 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-126.2527 123.08722 -146.59722 143.26944 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-417.72688 413.00454 -485.19886 480.2344 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1384.7436 1377.6987 -1608.6478 1601.2417 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-4594.2907 4583.7809 -5337.5138 5326.4652 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-15248.779 15233.1 -17716.12 17699.637 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-50620.561 50597.172 -58812.055 58787.466 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-168055.49 168020.6 -195251.66 195214.98 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-557947.93 557895.88 -648241.58 648186.85 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1852428.6 1852350.9 -2152212.8 2152131.2 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-6150244. 6150128.1 -7145560.9 7145439.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-20419476. 20419303. -23724042. 23723860. MAarrowhead1
% End of user PostScript
1 .731 0 r
.78101 .59257 m
.81617 .57657 L
.85648 .55639 L
.90276 .53128 L
.95594 .50036 L
s
.95594 .50036 m
1 .47314 L
s
1 0 0 r
.78101 .59257 m
.81617 .57657 L
s
% Start of user PostScript
8.4304318 2.7770132 9.4849817 2.2970813 MAarrowhead1
% End of user PostScript
1 .158 0 r
.85648 .55639 m
.90276 .53128 L
s
% Start of user PostScript
10.694311 1.6918312 12.082654 0.93853927 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
29.844991 -11.367038 34.164188 -14.73885 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
90.643086 -63.077219 104.5503 -75.5711 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
288.34603 -247.22259 333.87361 -290.64172 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
938.54611 -877.19715 1088.7393 -1024.2449 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3088.0419 -2996.52 3585.2631 -3489.0487 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
10210.828 -10074.293 11859.516 -11715.981 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
33838.736 -33635.05 39309.372 -39095.243 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
112255.46 -111951.6 130413.84 -130094.4 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
372562.37 -372109.06 432843.19 -432366.64 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1236743.4 -1236067.2 1436872.2 -1436161.2 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4105823.7 -4104814.8 4770258.7 -4769198.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
13631354. -13629849. 15837332. -15835750. MAarrowhead1
% End of user PostScript
.772 1 0 r
.30506 .76463 m
.27159 .80168 L
.2326 .84443 L
.18719 .89378 L
.13433 .95079 L
s
.13433 .95079 m
.08838 1 L
s
1 0 0 r
.30506 .76463 m
.27159 .80168 L
s
% Start of user PostScript
-5.8481786 7.9389793 -6.8524055 9.0504039 MAarrowhead1
% End of user PostScript
1 .158 0 r
.2326 .84443 m
.18719 .89378 L
s
% Start of user PostScript
-8.0221138 10.332806 -9.3842358 11.8134 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-27.690511 31.137659 -32.267066 35.890952 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-93.511332 98.653872 -108.78681 114.19302 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-312.81907 320.49084 -363.65596 371.72107 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1042.1025 1053.5474 -1211.0667 1223.0984 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3465.1332 3482.207 -4026.3823 4044.3315 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-11512.451 11537.922 -13376.264 13403.041 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-38234.326 38272.325 -44423. 44462.947 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-126959.8 127016.49 -147507.81 147567.41 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-421547.3 421631.86 -489770.42 489859.33 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1399625. 1399751.1 -1626135.7 1626268.3 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4646976.2 4647164.4 -5399021.3 5399219.1 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-15428590. 15428871. -17925472. 17925768. MAarrowhead1
% End of user PostScript
.726 0 1 r
.67802 .33688 m
.70642 .30925 L
.73939 .27708 L
.77767 .23964 L
.82213 .19607 L
.87376 .14537 L
.93372 .08639 L
s
.93372 .08639 m
1 .02109 L
s
1 0 0 r
.67802 .33688 m
.70642 .30925 L
s
% Start of user PostScript
5.3405368 -4.8935414 6.1924632 -5.7225499 MAarrowhead1
% End of user PostScript
1 .158 0 r
.73939 .27708 m
.77767 .23964 L
s
% Start of user PostScript
7.181627 -6.6876207 8.3302055 -7.810871 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
23.618044 -22.881074 27.419882 -26.645126 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
78.07782 -76.978388 90.683095 -89.527295 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
258.72497 -257.08481 300.55019 -298.82594 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
858.24748 -855.80065 997.07368 -994.5014 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2848.3636 -2844.7134 3309.2255 -3305.3881 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9455.2318 -9449.7862 10985.262 -10979.537 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
31389.986 -31381.862 36469.736 -36461.196 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
104214.71 -104202.59 121079.88 -121067.14 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
345999.48 -345981.4 401993.55 -401974.54 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1148750.5 -1148723.5 1334656.9 -1334628.5 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3813973.6 -3813933.3 4431204. -4431161.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
12662820. -12662760. 14712096. -14712033. MAarrowhead1
% End of user PostScript
1 .042 0 r
.47313 .67283 m
.46475 .6887 L
.4548 .70651 L
.44303 .72656 L
.42912 .74916 L
.41273 .7747 L
.39342 .80361 L
.37073 .83641 L
.34408 .87367 L
.31283 .91609 L
.27621 .96444 L
s
.27621 .96444 m
.2486 1 L
s
1 0 0 r
.47313 .67283 m
.46475 .6887 L
s
% Start of user PostScript
-0.80601608 5.1849668 -1.0574947 5.6609591 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4548 .70651 m
.44303 .72656 L
s
% Start of user PostScript
-1.355877 6.195366 -1.7090716 6.7966865 MAarrowhead1
% End of user PostScript
1 .473 0 r
.27621 .96444 m
0 0 rlineto s
.27621 .96444 m
.2486 1 L
s
% Start of user PostScript
-6.7136701 13.933339 -7.9997291 15.589559 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-25.590086 36.360567 -30.029143 41.351838 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-89.884974 105.95264 -104.87556 121.76704 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-305.77272 329.74287 -355.91977 381.11889 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1026.1573 1061.9165 -1193.2131 1230.8058 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3423.3068 3476.6533 -3978.7896 4034.8713 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-11390.162 11469.746 -13235.68 13319.344 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-37853.045 37971.77 -43982.246 44107.058 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-125730.8 125907.92 -146083.25 146269.45 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-417521.92 417786.15 -485098.57 485376.34 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1386342.4 1386736.5 -1610710.9 1611125.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-4602998.9 4603587. -5347938. 5348556.2 MAarrowhead1
% End of user PostScript
1 .825 0 r
.50007 .6499 m
.49594 .66172 L
.49092 .67482 L
.48487 .68937 L
.47761 .70557 L
.46892 .72365 L
.45857 .74387 L
.44627 .76655 L
.43169 .79204 L
.41445 .82075 L
.3941 .85316 L
.37013 .8898 L
.34193 .93133 L
.3088 .97848 L
s
.3088 .97848 m
.29319 1 L
s
1 0 0 r
.50007 .6499 m
.49594 .66172 L
s
% Start of user PostScript
0.0021358638 4.4969763 -0.12187748 4.851664 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49092 .67482 m
.48487 .68937 L
s
% Start of user PostScript
-0.27233645 5.2446243 -0.45384776 5.6810703 MAarrowhead1
% End of user PostScript
1 .473 0 r
.3941 .85316 m
.37013 .8898 L
s
% Start of user PostScript
-3.1768877 10.59467 -3.8960502 11.69415 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-13.938107 25.004137 -16.499643 28.133041 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-51.334128 67.842705 -60.098058 77.453048 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-177.98093 202.60884 -207.46508 233.35568 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-602.17426 638.91478 -700.64221 739.26645 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2016.0821 2070.8925 -2343.8682 2401.4888 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6718.6805 6800.448 -7808.2532 7894.213 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-22344.179 22466.161 -25963.604 26091.84 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-74241.04 74423.017 -86260.813 86452.12 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-246572.11 246843.59 -286483.43 286768.82 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-818772.33 819177.32 -951288.92 951714.68 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2718605. 2719209.2 -3158585. 3159220.2 MAarrowhead1
% End of user PostScript
1 0 .628 r
.65322 .28059 m
.67984 .25057 L
.71087 .21597 L
.74702 .17608 L
.78912 .13003 L
.83814 .07686 L
.89521 .01543 L
s
.89521 .01543 m
.90965 0 L
s
1 0 0 r
.65322 .28059 m
.67984 .25057 L
s
% Start of user PostScript
4.5964709 -6.5823353 5.3952282 -7.48291 MAarrowhead1
% End of user PostScript
1 .158 0 r
.71087 .21597 m
.74702 .17608 L
s
% Start of user PostScript
6.326066 -8.5207856 7.4105039 -9.7177491 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
22.006426 -25.280563 25.658319 -29.100324 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
74.560427 -79.444865 86.761867 -91.896736 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
249.78188 -257.06861 290.40655 -298.06688 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
832.63561 -843.50613 967.68504 -979.1129 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2769.4162 -2785.6331 3218.0508 -3235.0992 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9202.1979 -9226.3907 10692.097 -10717.531 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
30563.431 -30599.522 35510.638 -35548.58 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
101490.66 -101544.5 117916.81 -117973.42 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
336985.47 -337065.79 391523.48 -391607.92 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1118867.9 -1118987.7 1299942.3 -1300068.3 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3714826.9 -3715005.7 4316018.1 -4316206. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
12333742. -12334008. 14329771. -14330051. MAarrowhead1
% End of user PostScript
1 .451 0 r
.62472 .76991 m
.63399 .78086 L
.64421 .79191 L
.65549 .80299 L
.66799 .81401 L
.68185 .82486 L
.69727 .83541 L
.71447 .84552 L
.7337 .855 L
.75525 .86364 L
.77945 .87117 L
.8067 .87728 L
.83742 .88162 L
.87216 .88376 L
.91149 .88318 L
.95612 .8793 L
s
.95612 .8793 m
1 .87247 L
s
1 0 0 r
.62472 .76991 m
.63399 .78086 L
s
% Start of user PostScript
3.7415075 8.0971624 4.0197814 8.4258701 MAarrowhead1
% End of user PostScript
1 .158 0 r
.64421 .79191 m
.65549 .80299 L
s
% Start of user PostScript
4.3263121 8.7574416 4.6648123 9.0897598 MAarrowhead1
% End of user PostScript
1 .473 0 r
.77945 .87117 m
.8067 .87728 L
s
% Start of user PostScript
8.3836306 11.135036 9.2008779 11.318532 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
18.913177 10.205252 21.169121 9.4422425 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
49.48471 -6.0451183 56.292326 -10.625539 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
144.43996 -79.635701 166.02405 -97.897206 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
449.93727 -353.26068 520.08031 -418.447 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1449.6561 -1305.4315 1680.2736 -1528.6545 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
4747.1065 -4531.9488 5509.4038 -5283.2147 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
15662.606 -15341.628 18188.48 -17851.045 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
51854.972 -51376.13 60233.647 -59730.254 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
171945.71 -171231.36 199752.66 -199001.69 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
570553.34 -569487.65 662858.95 -661738.63 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1893816.7 -1892226.9 2200257.1 -2198585.8 MAarrowhead1
% End of user PostScript
.001 1 0 r
.55681 .69563 m
.55903 .70635 L
.56125 .71774 L
.56345 .72985 L
.56561 .74272 L
.56771 .75644 L
.5697 .77106 L
.57157 .78667 L
.57324 .80335 L
.57469 .82122 L
.57583 .84037 L
.5766 .86095 L
.5769 .88308 L
.57664 .90693 L
.57567 .93269 L
.57387 .96055 L
.57105 .99077 L
s
.57105 .99077 m
.56992 1 L
s
1 0 0 r
.55681 .69563 m
.55903 .70635 L
s
% Start of user PostScript
1.7044239 5.8688448 1.7709269 6.1906315 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56125 .71774 m
.56345 .72985 L
s
% Start of user PostScript
1.8374598 6.5322964 1.9034771 6.8954057 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57583 .84037 m
.5766 .86095 L
s
% Start of user PostScript
2.2749914 10.211218 2.2980343 10.828356 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.8461277 16.781107 1.6300229 17.952251 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-2.3846476 30.173217 -3.5386632 32.751983 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-20.618715 62.074389 -25.101397 68.682549 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-87.404817 149.24942 -103.25934 168.27478 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-318.46171 410.72301 -372.5499 469.54153 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-1099.5003 1237.138 -1281.2415 1425.936 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-3713.3799 3918.7112 -4320.0075 4535.8663 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-12422.707 12729.025 -14441.593 14763.617 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-41384.849 41841.823 -48094.966 48575.369 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-137611.41 138293.13 -159900.49 160617.17 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-457197.57 458214.58 -531215.9 532285.06 MAarrowhead1
% End of user PostScript
0 1 .406 r
.81874 .82482 m
.85254 .82402 L
.89089 .82036 L
.93449 .81323 L
.98413 .80192 L
s
.98413 .80192 m
1 .79734 L
s
1 0 0 r
.81874 .82482 m
.85254 .82402 L
s
% Start of user PostScript
9.5622319 9.7446642 10.576071 9.7207111 MAarrowhead1
% End of user PostScript
1 .158 0 r
.89089 .82036 m
.93449 .81323 L
s
% Start of user PostScript
11.726622 9.610798 13.034608 9.396805 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
29.180996 2.6506938 33.023628 0.44010799 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
82.334912 -34.84761 94.346933 -44.424906 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
251.65637 -180.81364 290.42484 -215.94992 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
803.14826 -697.46333 930.20394 -819.10042 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2618.2404 -2460.577 3037.6034 -2871.8564 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8620.8006 -8385.5944 10009.44 -9762.1746 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
28514.56 -28163.673 33119.493 -32750.616 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
94511.291 -93987.83 109791.99 -109241.69 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
313549.28 -312768.36 364270.7 -363449.75 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1040663.3 -1039498.3 1209046.1 -1207821.4 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3454591.4 -3452853.5 4013614.6 -4011787.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
11468853. -11466260. 13324835. -13322109. MAarrowhead1
% End of user PostScript
1 .636 0 r
.32761 .45711 m
.30566 .46802 L
.28046 .48161 L
.25151 .49837 L
.21821 .51884 L
.17988 .5437 L
.13571 .57369 L
.08479 .60971 L
.02604 .6528 L
s
.02604 .6528 m
0 .67252 L
s
1 0 0 r
.32761 .45711 m
.30566 .46802 L
s
% Start of user PostScript
-5.1717589 -1.2866977 -5.8302097 -0.95937894 MAarrowhead1
% End of user PostScript
1 .158 0 r
.28046 .48161 m
.25151 .49837 L
s
% Start of user PostScript
-6.5860677 -0.55163059 -7.4546274 -0.04902852 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-18.604065 7.9558707 -21.320516 10.126376 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-56.900669 41.01543 -65.670066 48.970372 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-181.65616 157.95817 -210.39932 185.4863 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-592.28798 556.93473 -687.16326 649.99741 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1950.3063 1897.5655 -2264.4749 2209.0299 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6451.1386 6372.4585 -7492.9789 7410.2648 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-21382.572 21265.195 -24839.76 24716.365 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-70938.989 70763.883 -82414.506 82230.423 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-235445.7 235184.47 -273541.66 273267.04 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-781587.86 781198.15 -908064.76 907655.08 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2594784.9 2594203.6 -3014693.9 3014082.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-8614723.7 8613856.4 -10008857. 10007945. MAarrowhead1
% End of user PostScript
1 .695 0 r
.40475 .23809 m
.39921 .22532 L
.39328 .212 L
.38692 .19812 L
.38009 .18368 L
.37274 .16866 L
.36482 .15307 L
.35627 .1369 L
.34702 .12017 L
.33699 .10288 L
.32609 .08506 L
.31422 .06674 L
.30126 .04795 L
.28709 .02876 L
.27154 .00923 L
s
.27154 .00923 m
.26357 0 L
s
1 0 0 r
.40475 .23809 m
.39921 .22532 L
s
% Start of user PostScript
-2.8574068 -7.8573164 -3.0236697 -8.2404091 MAarrowhead1
% End of user PostScript
1 .158 0 r
.39328 .212 m
.38692 .19812 L
s
% Start of user PostScript
-3.201655 -8.6399455 -3.3924812 -9.0562511 MAarrowhead1
% End of user PostScript
1 .473 0 r
.32609 .08506 m
.31422 .06674 L
s
% Start of user PostScript
-5.2173924 -12.4482 -5.5734542 -12.997872 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-9.2478865 -17.10608 -10.016067 -17.689096 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-18.658376 -20.657122 -20.591229 -20.740018 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-43.977937 -14.673895 -49.47389 -12.185085 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-119.20372 31.705469 -136.07644 44.092061 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-355.77719 225.24514 -409.74612 272.52155 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-1121.5592 926.82826 -1297.6834 1092.9684 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-3634.7014 3344.197 -4214.8908 3909.4919 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-11934.852 11501.47 -13854.341 13398.739 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-39427.017 38780.487 -45789.788 45110.11 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-130606.79 129642.29 -151716.79 150702.83 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-433188.98 431750.1 -503254.01 501741.36 MAarrowhead1
% End of user PostScript
0 .672 1 r
.26351 .18242 m
.24055 .17697 L
.21466 .17299 L
.18541 .17085 L
.1523 .17096 L
.11473 .17382 L
.07205 .18003 L
.02346 .19027 L
s
.02346 .19027 m
0 .19666 L
s
1 0 0 r
.26351 .18242 m
.24055 .17697 L
s
% Start of user PostScript
-7.0947387 -9.5274736 -7.7834593 -9.690992 MAarrowhead1
% End of user PostScript
1 .158 0 r
.21466 .17299 m
.18541 .17085 L
s
% Start of user PostScript
-8.560082 -9.8103036 -9.4376244 -9.874631 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-20.023865 -7.3815302 -22.506905 -6.3035946 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-53.955304 13.071259 -61.557053 18.576838 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-160.45092 99.459096 -184.73152 120.61257 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-504.83811 413.84899 -584.02319 488.36896 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1634.5329 1498.7931 -1895.3043 1752.605 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5364.7972 5162.2972 -6227.4079 6014.5255 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-17719.197 17417.102 -20578.419 20260.836 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-58691.726 58241.054 -68177.6 67703.821 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-194657.4 193985.08 -226141.05 225434.26 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-645978.03 644975.04 -750491.67 749437.26 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2144264.2 2142767.9 -2491238.2 2489665.2 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-7118523.8 7116291.6 -8270483. 8268136.4 MAarrowhead1
% End of user PostScript
.433 1 0 r
.73034 .57765 m
.7591 .56468 L
.79208 .54829 L
.82994 .52788 L
.87345 .50273 L
.92349 .47197 L
.98109 .43465 L
s
.98109 .43465 m
1 .42181 L
s
1 0 0 r
.73034 .57765 m
.7591 .56468 L
s
% Start of user PostScript
6.910105 2.3294454 7.7730082 1.9402641 MAarrowhead1
% End of user PostScript
1 .158 0 r
.79208 .54829 m
.82994 .52788 L
s
% Start of user PostScript
8.7624646 1.4488178 9.8982836 0.83654249 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
24.425105 -9.1916617 27.956859 -11.94238 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
74.131408 -51.405781 85.500254 -61.609459 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
235.73767 -201.83502 272.951 -237.31012 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
767.18064 -716.60383 889.93875 -836.76881 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2524.0121 -2448.5604 2930.3982 -2851.0779 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8345.5284 -8232.9676 9693.0094 -9574.6775 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
27656.682 -27488.761 32127.838 -31951.308 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
91746.665 -91496.156 106587.49 -106324.14 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
304495.15 -304121.44 353762.57 -353369.69 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1010788.7 -1010231.2 1174353.5 -1173767.4 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3355681.8 -3354850.1 3898723.1 -3897848.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
11140876. -11139635. 12943817. -12942512. MAarrowhead1
% End of user PostScript
1 .549 0 r
.33474 .74153 m
.30589 .7743 L
.27225 .81204 L
.23307 .85555 L
.18742 .90574 L
.13426 .96368 L
s
.13426 .96368 m
.10066 1 L
s
1 0 0 r
.33474 .74153 m
.30589 .7743 L
s
% Start of user PostScript
-4.9578375 7.2459875 -5.8234317 8.2288976 MAarrowhead1
% End of user PostScript
1 .158 0 r
.27225 .81204 m
.23307 .85555 L
s
% Start of user PostScript
-6.8323513 9.3611481 -8.0079576 10.666409 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-23.84005 27.612571 -27.802462 31.768405 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-80.876071 86.504012 -94.12015 100.03664 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-271.09039 279.48629 -315.19417 324.02054 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-903.88934 916.41455 -1050.5158 1063.6832 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3006.7432 3025.4287 -3493.8537 3513.4972 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-9991.2797 10019.155 -11608.981 11638.286 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-33184.958 33226.543 -38556.57 38600.287 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-110196.95 110258.99 -128032.3 128097.52 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-365895.11 365987.66 -425112.02 425209.32 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1214856.8 1214994.9 -1411466.1 1411611.2 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4033529.9 4033735.8 -4686298.8 4686515.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-13391885. 13392192. -15559159. 15559482. MAarrowhead1
% End of user PostScript
.311 0 1 r
.65539 .47968 m
.6768 .4652 L
.70149 .44779 L
.72997 .42696 L
.76285 .40213 L
.80083 .37261 L
.84472 .33761 L
.89546 .29621 L
.95416 .24734 L
s
.95416 .24734 m
1 .20847 L
s
1 0 0 r
.65539 .47968 m
.6768 .4652 L
s
% Start of user PostScript
4.6615991 -0.60948232 5.3040017 -1.0441285 MAarrowhead1
% End of user PostScript
1 .158 0 r
.70149 .44779 m
.72997 .42696 L
s
% Start of user PostScript
6.0446246 -1.566343 6.8990686 -2.1911806 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
18.021959 -11.341147 20.753866 -13.730522 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
56.781391 -46.814792 65.69508 -55.217482 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
183.96539 -169.09697 213.32632 -197.69558 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
603.99066 -581.80959 701.12393 -677.80561 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1995.1812 -1962.091 2317.1552 -2282.3684 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6609.1103 -6559.7455 7677.3262 -7625.4303 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
21920.456 -21846.812 25465.901 -25388.481 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
72744.815 -72634.952 84514.381 -84398.884 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
241471.08 -241307.18 280544.84 -280372.54 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
801637.3 -801392.79 931362.9 -931105.86 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2661417.8 -2661053. 3092116.2 -3091732.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
8836051.5 -8835507.4 10266012. -10265440. MAarrowhead1
% End of user PostScript
.286 1 0 r
.34675 .44109 m
.32781 .44915 L
.30611 .45941 L
.28122 .47229 L
.25262 .48825 L
.21975 .50783 L
.18193 .53169 L
.13837 .56056 L
.08816 .59533 L
.03026 .637 L
s
.03026 .637 m
0 .65954 L
s
1 0 0 r
.34675 .44109 m
.32781 .44915 L
s
% Start of user PostScript
-4.597513 -1.7673021 -5.1656195 -1.5255266 MAarrowhead1
% End of user PostScript
1 .158 0 r
.30611 .45941 m
.28122 .47229 L
s
% Start of user PostScript
-5.8166451 -1.2175634 -6.5635464 -0.83131372 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-16.096795 5.6029886 -18.41175 7.3799152 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-48.646804 32.991885 -56.086809 39.629245 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-154.35764 131.00324 -178.69245 154.14065 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-501.81074 466.97007 -582.05787 545.43089 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1650.1456 1598.1694 -1915.759 1861.118 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5454.9194 5377.3801 -6335.5689 6254.0541 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-18075.529 17959.854 -20997.571 20875.965 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-59959.998 59787.431 -69658.809 69477.394 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-198995.33 198737.89 -231192.47 230921.83 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-660570.09 660186.03 -767462.33 767058.59 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2192994.4 2192421.4 -2547880.1 2547277.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-7280735.9 7279881.2 -8458984.7 8458086.1 MAarrowhead1
% End of user PostScript
0 .362 1 r
.29131 .28667 m
.2692 .28714 L
.24412 .28948 L
.2156 .29409 L
.18312 .30143 L
.14609 .31203 L
.10379 .32655 L
.05542 .34571 L
2e-05 .3704 L
s
2e-05 .3704 m
0 .37042 L
s
1 0 0 r
.29131 .28667 m
.2692 .28714 L
s
% Start of user PostScript
-6.2606284 -6.3998139 -6.9238678 -6.3856892 MAarrowhead1
% End of user PostScript
1 .158 0 r
.24412 .28948 m
.2156 .29409 L
s
% Start of user PostScript
-7.6765001 -6.3154524 -8.5320721 -6.1772632 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-19.091533 -1.782007 -21.604236 -0.33951352 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-53.84539 22.705727 -61.698693 28.962466 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-164.53989 118.08497 -189.88403 141.04732 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-525.05838 455.75579 -608.11523 535.25942 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1711.5789 1608.1915 -1985.7132 1877.0251 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5635.3864 5481.1507 -6543.1217 6380.9781 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-18639.645 18409.552 -21649.818 21407.928 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-61780.631 61437.373 -71769.365 71408.507 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-204962.02 204449.94 -238117.74 237579.41 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-680263.83 679499.89 -790332.69 789529.59 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2258206.3 2257066.6 -2623629.9 2622431.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-7496987.9 7495287.8 -8710210.3 8708423. MAarrowhead1
% End of user PostScript
.946 0 1 r
.73693 .58171 m
.76647 .56851 L
.80033 .55182 L
.8392 .531 L
.88387 .50532 L
.93523 .47391 L
.99436 .43576 L
s
.99436 .43576 m
1 .43194 L
s
1 0 0 r
.73693 .58171 m
.76647 .56851 L
s
% Start of user PostScript
7.107953 2.4511801 7.9940412 2.0551991 MAarrowhead1
% End of user PostScript
1 .158 0 r
.80033 .55182 m
.8392 .531 L
s
% Start of user PostScript
9.0099819 1.5544939 10.176095 0.93003301 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
25.085456 -9.3251102 28.709514 -12.141117 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
76.083018 -52.571345 87.745974 -63.028832 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
241.85796 -206.78267 280.02935 -243.15571 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
786.96474 -734.63855 912.87625 -857.86724 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2588.8981 -2510.8366 3005.7127 -2923.6489 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8559.7645 -8443.3104 9941.8086 -9819.3838 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
28366.191 -28192.462 32952.01 -32769.374 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
94099.664 -93840.49 109321.05 -109048.59 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
312303.42 -311916.78 362834.13 -362427.66 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1036707.2 -1036130.4 1204465.9 -1203859.6 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3441725.3 -3440864.9 3998690.6 -3997786. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
11426537. -11425254. 13275707. -13274357. MAarrowhead1
% End of user PostScript
.691 0 1 r
.36069 .22158 m
.34969 .21116 L
.33751 .20084 L
.32397 .1907 L
.3089 .18089 L
.29207 .17156 L
.27325 .16288 L
.25214 .15508 L
.22841 .14842 L
.20168 .14319 L
.17151 .13978 L
.13739 .13859 L
.09872 .14014 L
.05481 .14502 L
.00488 .15392 L
s
.00488 .15392 m
0 .1551 L
s
1 0 0 r
.36069 .22158 m
.34969 .21116 L
s
% Start of user PostScript
-4.1792757 -8.3524982 -4.5092375 -8.6650542 MAarrowhead1
% End of user PostScript
1 .158 0 r
.33751 .20084 m
.32397 .1907 L
s
% Start of user PostScript
-4.8748387 -8.9749133 -5.2809365 -9.2789075 MAarrowhead1
% End of user PostScript
1 .473 0 r
.17151 .13978 m
.13739 .13859 L
s
% Start of user PostScript
-9.8546861 -10.806716 -10.878414 -10.842321 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-23.27494 -7.5482504 -26.189645 -6.2138841 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-63.187071 17.204275 -72.141903 23.801518 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-188.77097 120.1727 -217.42446 145.30908 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-595.38726 493.05067 -688.91265 581.32914 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1929.98 1777.3118 -2238.097 2077.6013 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6337.9788 6110.2245 -7357.3855 7117.954 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-20938.73 20598.961 -24317.942 23960.753 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-69363.734 68856.857 -80575.15 80042.286 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-230064.03 229307.86 -267275.36 266480.42 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-763493.84 762365.77 -887022.11 885836.2 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2534373.2 2532690.3 -2944475.1 2942705.9 MAarrowhead1
% End of user PostScript
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0333333 0.5 0.0333333 [
[0 .4875 -18.4688 -20 ]
[0 .4875 18.4688 0 ]
[.16667 .4875 -18.4688 -20 ]
[.16667 .4875 18.4688 0 ]
[.33333 .4875 -13.4688 -20 ]
[.33333 .4875 13.4688 0 ]
[.66667 .4875 -7 -20 ]
[.66667 .4875 7 0 ]
[.83333 .4875 -12 -20 ]
[.83333 .4875 12 0 ]
[1 .4875 -12 -20 ]
[1 .4875 12 0 ]
[.4875 0 -36.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .16667 -36.9375 -10 ]
[.4875 .16667 0 10 ]
[.4875 .33333 -26.9375 -10 ]
[.4875 .33333 0 10 ]
[.4875 .66667 -14 -10 ]
[.4875 .66667 0 10 ]
[.4875 .83333 -24 -10 ]
[.4875 .83333 0 10 ]
[.4875 1 -24 -10 ]
[.4875 1 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.16667 .5 m
.16667 .50625 L
s
gsave
.16667 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.33333 .5 m
.33333 .50625 L
s
gsave
.33333 .4875 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.66667 .5 m
.66667 .50625 L
s
gsave
.66667 .4875 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.83333 .5 m
.83333 .50625 L
s
gsave
.83333 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.5 .16667 m
.50625 .16667 L
s
gsave
.4875 .16667 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 .33333 m
.50625 .33333 L
s
gsave
.4875 .33333 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .66667 m
.50625 .66667 L
s
gsave
.4875 .66667 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .83333 m
.50625 .83333 L
s
gsave
.4875 .83333 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.01 w
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.918 0 1 r
.5 Mabswid
.61999 .17145 m
.64517 .13557 L
.67472 .09477 L
.70937 .04831 L
s
.70937 .04831 m
.74635 0 L
s
.175 1 0 r
.24773 .24782 m
.22084 .24884 L
.19033 .25217 L
.15562 .25829 L
.11609 .26777 L
.07099 .28128 L
.01946 .2996 L
s
.01946 .2996 m
0 .30753 L
s
.341 1 0 r
.17713 .49874 m
.13384 .52541 L
.084 .55778 L
.02658 .59684 L
s
.02658 .59684 m
0 .61567 L
s
0 .834 1 r
.35836 .6271 m
.33585 .64887 L
.3097 .67423 L
.27935 .70376 L
.24411 .73814 L
.20319 .77815 L
.15567 .82471 L
.10048 .87889 L
.0364 .94191 L
s
.0364 .94191 m
0 .97777 L
s
1 .716 0 r
.34233 .38408 m
.32438 .38801 L
.30391 .39373 L
.28053 .40161 L
.2538 .41204 L
.22319 .42552 L
.18811 .44259 L
.14784 .46393 L
.10158 .49028 L
.04838 .52255 L
s
.04838 .52255 m
0 .55355 L
s
1 .182 0 r
.19377 .30708 m
.15801 .31725 L
.11717 .33118 L
.07046 .34961 L
.01697 .37336 L
s
.01697 .37336 m
0 .38168 L
s
1 0 .955 r
.74012 .31438 m
.77747 .27982 L
.82079 .23943 L
.87104 .19227 L
.92933 .13722 L
.99698 .07299 L
s
.99698 .07299 m
1 .07011 L
s
.642 0 1 r
.56845 .82367 m
.56869 .84354 L
.56841 .86495 L
.5675 .88808 L
.56583 .91311 L
.56325 .94025 L
.55957 .96974 L
s
.55957 .96974 m
.55487 1 L
s
1 .482 0 r
.39678 .65395 m
.37867 .67466 L
.35757 .69851 L
.33297 .72598 L
.3043 .75766 L
.27092 .79422 L
.23205 .83644 L
.18679 .88521 L
.13411 .94158 L
s
.13411 .94158 m
.07917 1 L
s
0 1 .547 r
.20894 .65526 m
.16559 .69164 L
.11541 .7345 L
.05732 .78489 L
s
.05732 .78489 m
0 .83532 L
s
0 .093 1 r
.21577 .64766 m
.17355 .68288 L
.12469 .72438 L
.06812 .77321 L
.00262 .83058 L
s
.00262 .83058 m
0 .8329 L
s
0 .075 1 r
.39313 .36492 m
.38252 .36312 L
.37054 .36206 L
.35698 .36191 L
.34161 .36287 L
.32415 .36518 L
.30427 .36913 L
.28163 .37503 L
.25578 .38328 L
.22623 .39432 L
.19241 .40868 L
.15366 .42698 L
.1092 .44994 L
.05814 .47839 L
s
.05814 .47839 m
0 .513 L
s
0 1 .968 r
.39048 .49396 m
.37595 .50257 L
.35923 .51306 L
.33998 .52576 L
.3178 .54106 L
.29221 .55941 L
.26269 .58133 L
.22859 .60742 L
.1892 .63841 L
.14367 .6751 L
.09101 .71846 L
.03009 .76962 L
s
.03009 .76962 m
0 .79533 L
s
1 .536 0 r
.2773 .54594 m
.24615 .56803 L
.2102 .59445 L
.16871 .62594 L
.12077 .66335 L
.06536 .70768 L
.00129 .76011 L
s
.00129 .76011 m
0 .7612 L
s
.042 1 0 r
.33187 .71867 m
.30326 .74987 L
.26995 .7859 L
.23118 .82754 L
.18605 .87568 L
.13354 .93136 L
.07244 .99578 L
s
.07244 .99578 m
.06842 1 L
s
.388 1 0 r
.66874 .51331 m
.69101 .50037 L
.71663 .48456 L
.74613 .46538 L
.78012 .44224 L
.81931 .41445 L
.86452 .38122 L
.91672 .34162 L
.97702 .29457 L
s
.97702 .29457 m
1 .27618 L
s
1 .402 0 r
.56445 .76363 m
.56581 .77909 L
.56693 .79565 L
.56774 .81343 L
.56816 .83255 L
.56812 .85314 L
.5675 .87536 L
.56618 .89938 L
.56402 .92541 L
.56085 .95367 L
.55648 .98443 L
s
.55648 .98443 m
.55378 1 L
s
0 .105 1 r
.54135 .68326 m
.54183 .6943 L
.54207 .70616 L
.54202 .71894 L
.54161 .73273 L
.54076 .74765 L
.53938 .76381 L
.53738 .78136 L
.53462 .80047 L
.53096 .82131 L
.52623 .8441 L
.52024 .86907 L
.51275 .89652 L
.5035 .92675 L
.49218 .96014 L
.47841 .9971 L
s
.47841 .9971 m
.47723 1 L
s
0 1 .711 r
.49 .50624 m
.48848 .50757 L
.48673 .50912 L
.4847 .51094 L
.48234 .51307 L
.47961 .51557 L
.47644 .51848 L
.47277 .5219 L
.46851 .52588 L
.46357 .53054 L
.45784 .53597 L
.45119 .5423 L
.44347 .54969 L
.43451 .55829 L
.42411 .56832 L
.41204 .58001 L
.39802 .59362 L
.38175 .60946 L
.36286 .6279 L
.34092 .64937 L
.31544 .67435 L
.28586 .70341 L
.2515 .73722 L
.2116 .77654 L
.16525 .82228 L
.11142 .87547 L
.0489 .93732 L
s
.0489 .93732 m
0 .98574 L
s
.495 0 1 r
.47382 .66492 m
.46575 .6801 L
.45617 .69715 L
.44484 .71634 L
.43146 .73799 L
.41569 .76245 L
.39712 .79016 L
.37529 .82158 L
.34967 .8573 L
.31962 .89796 L
.28441 .94433 L
.2432 .99727 L
s
.2432 .99727 m
.24102 1 L
s
0 .715 1 r
.65233 .82704 m
.66373 .84022 L
.6763 .85349 L
.69018 .86676 L
.70557 .87993 L
.72265 .89287 L
.74167 .90541 L
.7629 .91736 L
.78664 .92849 L
.81326 .93854 L
.84317 .94717 L
.87687 .954 L
.91489 .95857 L
.95789 .96035 L
s
.95789 .96035 m
1 .95894 L
s
0 .897 1 r
.35086 .54299 m
.32966 .55875 L
.30518 .57751 L
.27689 .59979 L
.24419 .62616 L
.20638 .65733 L
.16263 .69409 L
.11199 .73738 L
.05336 .78829 L
s
.05336 .78829 m
0 .83527 L
s
1 0 .639 r
.34137 .67964 m
.31512 .70696 L
.28459 .73863 L
.24909 .77532 L
.20781 .81785 L
.15981 .86716 L
.10401 .92435 L
.03914 .99067 L
s
.03914 .99067 m
.03 1 L
s
1 0 .666 r
.71751 .34769 m
.7509 .31764 L
.78961 .28244 L
.83449 .24126 L
.88653 .1931 L
.94688 .13683 L
s
.94688 .13683 m
1 .08697 L
s
.202 1 0 r
.77472 .39138 m
.81459 .36003 L
.86067 .32289 L
.91397 .27901 L
.97563 .22725 L
s
.97563 .22725 m
1 .20642 L
s
.357 0 1 r
.5581 .8007 m
.55758 .81961 L
.55648 .84006 L
.55466 .86221 L
.55198 .88626 L
.54828 .91243 L
.54336 .94098 L
.53699 .97218 L
s
.53699 .97218 m
.5304 1 L
s
0 .614 1 r
.39925 .21162 m
.3937 .19722 L
.3878 .18214 L
.38153 .16636 L
.37486 .14986 L
.36774 .1326 L
.36015 .11458 L
.35204 .09576 L
.34335 .07613 L
.33405 .05567 L
.32406 .03437 L
.31332 .01222 L
s
.31332 .01222 m
.30718 0 L
s
.524 1 0 r
.70594 .33662 m
.7381 .30665 L
.77539 .27165 L
.81866 .23079 L
.86886 .18312 L
.92712 .12753 L
.99473 .06272 L
s
.99473 .06272 m
1 .05765 L
s
1 0 .234 r
.75888 .57595 m
.79153 .56048 L
.82898 .54107 L
.87199 .51704 L
.92143 .48753 L
.97833 .4516 L
s
.97833 .4516 m
1 .43722 L
s
0 1 .365 r
.76581 .81498 m
.79277 .8178 L
.82327 .8186 L
.85785 .81694 L
.89711 .81227 L
.94176 .80398 L
.99264 .79134 L
s
.99264 .79134 m
1 .78908 L
s
.862 0 1 r
.32899 .48746 m
.30639 .50065 L
.28039 .51676 L
.25046 .53629 L
.21597 .55985 L
.1762 .58812 L
.13032 .62193 L
.07734 .6622 L
.01613 .71005 L
s
.01613 .71005 m
0 .72298 L
s
1 0 .718 r
.71038 .71141 m
.73276 .71065 L
.75818 .70797 L
.78707 .70297 L
.81999 .69519 L
.85753 .68405 L
.90042 .66893 L
.94949 .64906 L
s
.94949 .64906 m
1 .62613 L
s
0 1 .487 r
.52238 .68593 m
.52024 .69875 L
.51747 .71275 L
.51393 .72809 L
.50949 .74493 L
.504 .76348 L
.49725 .78394 L
.48904 .80657 L
.47909 .83167 L
.46712 .85958 L
.45277 .89068 L
.43563 .92542 L
.41523 .96433 L
s
.41523 .96433 m
.39546 1 L
s
0 .011 1 r
.53331 .63803 m
.53396 .64616 L
.53448 .65488 L
.53483 .66424 L
.53496 .67432 L
.53484 .68517 L
.53439 .6969 L
.53357 .70958 L
.53228 .72334 L
.53044 .73828 L
.52793 .75456 L
.52465 .77233 L
.52043 .79178 L
.5151 .81311 L
.50847 .83657 L
.50031 .86242 L
.49033 .891 L
.47823 .92266 L
.46362 .95781 L
.44608 .99696 L
s
.44608 .99696 m
.44462 1 L
s
.052 0 1 r
.60001 .54508 m
.61219 .54034 L
.62613 .53422 L
.64211 .52646 L
.66044 .51677 L
.68151 .50479 L
.70574 .49011 L
.73362 .47227 L
.76574 .45071 L
.80276 .42479 L
.84546 .39375 L
.89476 .35671 L
.9517 .31267 L
s
.9517 .31267 m
1 .27432 L
s
0 .312 1 r
.67393 .61968 m
.69396 .6147 L
.71682 .60767 L
.74294 .59818 L
.77282 .58579 L
.80706 .56993 L
.84633 .54999 L
.89143 .52522 L
.94326 .49475 L
s
.94326 .49475 m
1 .45938 L
s
0 .567 1 r
.45786 .65358 m
.44796 .66919 L
.4363 .68686 L
.42259 .70688 L
.40649 .72963 L
.38759 .7555 L
.36544 .78498 L
.33951 .81863 L
.30916 .85708 L
.27369 .90109 L
.23223 .9515 L
s
.23223 .9515 m
.19163 1 L
s
0 .641 1 r
.31451 .36925 m
.29323 .37431 L
.26896 .38154 L
.24123 .39135 L
.20951 .40423 L
.17318 .42077 L
.13151 .44161 L
.08367 .46756 L
.0287 .49953 L
s
.0287 .49953 m
0 .51725 L
s
1 .753 0 r
.5263 .53099 m
.52898 .53126 L
.532 .53132 L
.53543 .53114 L
.53932 .53066 L
.54375 .52982 L
.5488 .52854 L
.55456 .52675 L
.56114 .52434 L
.56867 .52119 L
.5773 .51717 L
.5872 .51211 L
.59857 .50584 L
.61163 .49812 L
.62666 .48872 L
.64397 .47732 L
.66392 .4636 L
.68692 .44713 L
.71347 .42746 L
.74412 .40403 L
.77953 .37622 L
.82047 .34327 L
.8678 .30433 L
.92257 .25839 L
.98595 .20428 L
s
.98595 .20428 m
1 .1921 L
s
0 1 .882 r
.22653 .64503 m
.18582 .67915 L
.13871 .71934 L
.08416 .76661 L
.02099 .82213 L
s
.02099 .82213 m
0 .84082 L
s
0 1 .883 r
.40344 .74485 m
.38372 .77217 L
.36059 .80329 L
.3335 .83879 L
.30179 .87933 L
.26471 .9257 L
.22137 .9788 L
s
.22137 .9788 m
.20374 1 L
s
1 0 .791 r
.7779 .72976 m
.80885 .72485 L
.84408 .71698 L
.88425 .70557 L
.93013 .68993 L
.9826 .66925 L
s
.9826 .66925 m
1 .66153 L
s
0 1 .65 r
.36005 .36513 m
.345 .3661 L
.3279 .36838 L
.30844 .37227 L
.28627 .37807 L
.26096 .38617 L
.23203 .39701 L
.19891 .41111 L
.16097 .42906 L
.11743 .45158 L
.06743 .47948 L
.00995 .51373 L
s
.00995 .51373 m
0 .52 L
s
1 .839 0 r
.65627 .75995 m
.67005 .76751 L
.68548 .77452 L
.70278 .7808 L
.72223 .78614 L
.74414 .7903 L
.76888 .79296 L
.79687 .79378 L
.82858 .79235 L
.8646 .78817 L
.90556 .78068 L
.95222 .7692 L
s
.95222 .7692 m
1 .75461 L
s
.513 0 1 r
.2443 .69248 m
.20467 .72887 L
.15871 .77142 L
.10541 .82114 L
.04358 .87921 L
s
.04358 .87921 m
0 .92038 L
s
.747 1 0 r
.30728 .81498 m
.27272 .85581 L
.23238 .90274 L
.18534 .95671 L
s
.18534 .95671 m
.14712 1 L
s
.025 0 1 r
.69118 .27517 m
.72305 .24157 L
.76013 .20268 L
.80326 .15765 L
.85341 .10549 L
.91174 .04505 L
s
.91174 .04505 m
.95537 0 L
s
0 1 .142 r
.47392 .58291 m
.46813 .59161 L
.46132 .60148 L
.45332 .6127 L
.44394 .62546 L
.43295 .64001 L
.42008 .65662 L
.40503 .67561 L
.38743 .69734 L
.36687 .72225 L
.34287 .75082 L
.31485 .78365 L
.28216 .82138 L
.24404 .86481 L
.19961 .91482 L
.14784 .97246 L
s
.14784 .97246 m
.12285 1 L
s
0 .032 1 r
.23511 .71075 m
.19373 .74935 L
.14574 .79442 L
.09007 .84703 L
.02546 .90841 L
s
.02546 .90841 m
0 .93272 L
s
.008 0 1 r
.74535 .44245 m
.77986 .41756 L
.8197 .38785 L
.8657 .35249 L
.91885 .31052 L
.9803 .26084 L
s
.9803 .26084 m
1 .24457 L
s
.524 1 0 r
.71047 .38052 m
.74202 .35364 L
.77854 .32202 L
.82084 .28488 L
.86984 .24129 L
.92662 .19021 L
.99244 .13039 L
s
.99244 .13039 m
1 .12345 L
s
0 .194 1 r
.71804 .25139 m
.75417 .2137 L
.7962 .17003 L
.84506 .11943 L
.90189 .06078 L
s
.90189 .06078 m
.96096 0 L
s
0 1 .721 r
.78994 .45362 m
.83013 .42592 L
.87648 .3927 L
.92997 .35301 L
.99173 .30576 L
s
.99173 .30576 m
1 .29926 L
s
.376 1 0 r
.7117 .19686 m
.74848 .15539 L
.79136 .10759 L
.8413 .05246 L
s
.8413 .05246 m
.88927 0 L
s
1 0 .811 r
.71758 .49401 m
.74694 .4755 L
.78076 .45309 L
.81973 .4261 L
.86468 .39376 L
.91655 .35514 L
.97646 .30916 L
s
.97646 .30916 m
1 .2906 L
s
.405 0 1 r
.48435 .22169 m
.48994 .20103 L
.49686 .17827 L
.50533 .15314 L
.51563 .12533 L
.52808 .09446 L
.54306 .06013 L
.561 .02185 L
s
.561 .02185 m
.57193 0 L
s
1 .947 0 r
.61355 .41602 m
.63111 .39998 L
.65147 .38121 L
.67508 .35928 L
.70246 .33365 L
.73423 .30374 L
.77109 .26883 L
.81386 .22811 L
.86349 .18062 L
.9211 .12528 L
.98796 .06079 L
s
.98796 .06079 m
1 .04914 L
s
1 0 .63 r
.3333 .60126 m
.30813 .62308 L
.27898 .6487 L
.24521 .67876 L
.20608 .71399 L
.16073 .75525 L
.10814 .80353 L
.04717 .85997 L
s
.04717 .85997 m
0 .90397 L
s
0 1 .701 r
.37726 .60225 m
.35796 .6205 L
.33557 .64179 L
.30958 .66661 L
.27942 .69555 L
.24442 .72927 L
.20378 .76855 L
.15661 .81431 L
.10184 .86759 L
.03825 .92961 L
s
.03825 .92961 m
0 .96701 L
s
1 0 .805 r
.4381 .69288 m
.42446 .71323 L
.40843 .73632 L
.38961 .76256 L
.36754 .79243 L
.34168 .8265 L
.31141 .86539 L
.276 .90986 L
.23461 .96078 L
s
.23461 .96078 m
.20212 1 L
s
1 0 .55 r
.64203 .5031 m
.66101 .49157 L
.68285 .47755 L
.708 .46062 L
.73701 .44026 L
.77046 .41589 L
.80908 .38683 L
.85369 .35227 L
.90523 .31128 L
.96483 .26279 L
s
.96483 .26279 m
1 .23357 L
s
.15 1 0 r
.80603 .64228 m
.84316 .62813 L
.88567 .60979 L
.93439 .58647 L
.99029 .55727 L
s
.99029 .55727 m
1 .55181 L
s
.103 1 0 r
.24614 .23977 m
.21926 .24029 L
.18877 .24307 L
.1541 .24861 L
.11464 .25745 L
.06963 .27026 L
.01822 .28782 L
s
.01822 .28782 m
0 .29502 L
s
0 .043 1 r
.82699 .7788 m
.86316 .77369 L
.90433 .76517 L
.95126 .75257 L
s
.95126 .75257 m
1 .73666 L
s
.37 1 0 r
.76097 .20706 m
.80409 .1623 L
.85423 .11044 L
.91253 .05032 L
s
.91253 .05032 m
.96148 0 L
s
0 1 .045 r
.60598 .1915 m
.62873 .15836 L
.65545 .12073 L
.6868 .07791 L
.72353 .02911 L
s
.72353 .02911 m
.74601 0 L
s
.625 1 0 r
.72931 .75534 m
.75302 .75647 L
.77988 .75573 L
.81037 .7527 L
.84504 .74691 L
.88452 .73778 L
.92954 .72466 L
.98098 .70677 L
s
.98098 .70677 m
1 .69915 L
s
.697 1 0 r
.68229 .54624 m
.70547 .53477 L
.73208 .52048 L
.76266 .50285 L
.79783 .48129 L
.83831 .45512 L
.88495 .42352 L
.93872 .38557 L
s
.93872 .38557 m
1 .34071 L
s
1 0 .545 r
.59704 .3529 m
.61412 .33324 L
.63405 .31062 L
.65727 .28456 L
.68433 .25452 L
.71585 .21986 L
.75256 .17986 L
.7953 .13365 L
.84506 .08026 L
.90296 .01852 L
s
.90296 .01852 m
.92044 0 L
s
0 1 .755 r
.27146 .25828 m
.24748 .25816 L
.22027 .26001 L
.18937 .26427 L
.1542 .27143 L
.11411 .28207 L
.06835 .29687 L
.01604 .31663 L
s
.01604 .31663 m
0 .32351 L
s
0 .548 1 r
.43144 .73418 m
.41577 .75835 L
.39733 .78572 L
.37565 .81678 L
.35021 .85209 L
.32038 .89229 L
.28543 .93814 L
.24453 .99051 L
s
.24453 .99051 m
.23694 1 L
s
.336 1 0 r
.5346 .78274 m
.53142 .80218 L
.52729 .82342 L
.52201 .84668 L
.51538 .87221 L
.50716 .90031 L
.49705 .9313 L
.48473 .96558 L
s
.48473 .96558 m
.47122 1 L
s
.753 0 1 r
.43744 .57 m
.42711 .58072 L
.41509 .59313 L
.40112 .60752 L
.38488 .6242 L
.366 .64355 L
.34405 .66599 L
.31854 .69202 L
.28888 .72222 L
.25441 .75726 L
.21434 .79793 L
.16777 .84513 L
.11365 .89991 L
.05075 .96351 L
s
.05075 .96351 m
.01461 1 L
s
0 .385 1 r
.18763 .30319 m
.15115 .31356 L
.10949 .32777 L
.06185 .34657 L
.00729 .37079 L
s
.00729 .37079 m
0 .37436 L
s
0 .287 1 r
.6815 .80062 m
.69755 .80929 L
.71551 .81732 L
.73566 .82449 L
.75831 .83055 L
.78384 .83522 L
.81266 .83813 L
.84527 .83889 L
.88224 .837 L
.92422 .8319 L
.97197 .82291 L
s
.97197 .82291 m
1 .81587 L
s
1 .599 0 r
.61233 .24603 m
.63442 .21667 L
.66029 .18317 L
.69056 .14487 L
.72595 .10105 L
.7673 .05083 L
s
.7673 .05083 m
.8099 0 L
s
.226 0 1 r
.80167 .71495 m
.83621 .7069 L
.87561 .69534 L
.92061 .67961 L
.97209 .65891 L
s
.97209 .65891 m
1 .64631 L
s
0 .254 1 r
.24297 .52141 m
.20788 .54441 L
.16746 .57214 L
.12084 .60541 L
.06704 .64517 L
.00493 .69252 L
s
.00493 .69252 m
0 .69639 L
s
0 .488 1 r
.70106 .43089 m
.72996 .40877 L
.76334 .3825 L
.80192 .35139 L
.84655 .31463 L
.89817 .27126 L
.95793 .2202 L
s
.95793 .2202 m
1 .18368 L
s
1 .789 0 r
.42251 .54538 m
.41086 .55538 L
.39736 .56715 L
.38173 .58096 L
.36363 .59715 L
.34264 .61612 L
.31831 .63834 L
.29011 .66432 L
.2574 .69469 L
.21946 .73017 L
.17546 .7716 L
.1244 .81994 L
.06515 .87633 L
s
.06515 .87633 m
0 .93864 L
s
.503 0 1 r
.66774 .54795 m
.68893 .53782 L
.71323 .52514 L
.74115 .50944 L
.77325 .49019 L
.81019 .46676 L
.85274 .43841 L
.90177 .40431 L
.95834 .36344 L
s
.95834 .36344 m
1 .3323 L
s
0 1 .48 r
.4298 .69112 m
.4151 .71202 L
.39784 .7358 L
.37762 .76287 L
.35393 .79377 L
.3262 .82906 L
.29379 .86944 L
.2559 .91569 L
.21166 .96874 L
s
.21166 .96874 m
.18514 1 L
s
1 0 .805 r
.17266 .66916 m
.12406 .70965 L
.06781 .75737 L
.0027 .81351 L
s
.0027 .81351 m
0 .81588 L
s
.762 0 1 r
.48637 .35378 m
.48858 .34338 L
.49138 .33196 L
.49486 .31942 L
.49917 .3056 L
.50443 .29032 L
.51082 .27341 L
.51853 .25463 L
.5278 .23373 L
.53889 .21042 L
.55211 .18434 L
.56783 .15511 L
.58647 .12227 L
.60851 .08529 L
.63453 .04357 L
s
.63453 .04357 m
.66286 0 L
s
0 1 .18 r
.41073 .39728 m
.40159 .39658 L
.39124 .39658 L
.37951 .39743 L
.36617 .39933 L
.351 .40249 L
.3337 .40715 L
.31395 .41361 L
.29137 .42222 L
.26552 .43338 L
.2359 .44757 L
.20191 .46533 L
.16286 .48731 L
.11797 .51427 L
.06631 .54707 L
.00682 .58675 L
s
.00682 .58675 m
0 .59149 L
s
1 .195 0 r
.59137 .77617 m
.59599 .79039 L
.60085 .80535 L
.60594 .82108 L
.61128 .83763 L
.61689 .85505 L
.62276 .87337 L
.62891 .89266 L
.63536 .91295 L
.64211 .93431 L
.64917 .9568 L
.65656 .98048 L
s
.65656 .98048 m
.66261 1 L
s
1 0 .522 r
.28683 .74766 m
.25138 .78488 L
.21015 .82798 L
.16218 .8779 L
.10641 .93573 L
s
.10641 .93573 m
.04421 1 L
s
0 .654 1 r
.46397 .44205 m
.46074 .44046 L
.45712 .43902 L
.45305 .43776 L
.44847 .43675 L
.4433 .43603 L
.43746 .43568 L
.43084 .43579 L
.42334 .43646 L
.41481 .4378 L
.40509 .43996 L
.39402 .44309 L
.38137 .44739 L
.3669 .45307 L
.35034 .46041 L
.33135 .46969 L
.30956 .48129 L
.28452 .4956 L
.25572 .51312 L
.22258 .53441 L
.1844 .56013 L
.14039 .59105 L
.08961 .62805 L
.031 .67219 L
s
.031 .67219 m
0 .69622 L
s
0 .175 1 r
.73273 .54928 m
.7626 .53387 L
.7969 .51476 L
.83633 .49131 L
.88171 .46273 L
.93396 .42814 L
.99418 .38649 L
s
.99418 .38649 m
1 .3823 L
s
1 .71 0 r
.34621 .19063 m
.33412 .17897 L
.32073 .1674 L
.30587 .15601 L
.28933 .14497 L
.27087 .13442 L
.25023 .12457 L
.22709 .11566 L
.20109 .10796 L
.17181 .10181 L
.13878 .0976 L
.10143 .0958 L
.05912 .09695 L
.01109 .10171 L
s
.01109 .10171 m
0 .10356 L
s
0 1 .077 r
.80001 .28372 m
.84625 .24178 L
.89985 .19269 L
.962 .13528 L
s
.962 .13528 m
1 .09991 L
s
1 .361 0 r
.17396 .31241 m
.13539 .32464 L
.09131 .34104 L
.04086 .36239 L
s
.04086 .36239 m
0 .38162 L
s
1 0 .702 r
.33825 .28787 m
.32241 .28455 L
.30453 .28227 L
.28432 .2813 L
.26142 .28193 L
.23543 .2845 L
.20589 .28943 L
.17224 .29721 L
.13386 .30838 L
.09002 .32362 L
.03988 .3437 L
s
.03988 .3437 m
0 .36163 L
s
1 .86 0 r
.22323 .496 m
.1862 .51863 L
.14358 .54612 L
.09448 .57932 L
.03787 .6192 L
s
.03787 .6192 m
0 .64687 L
s
1 .262 0 r
.40474 .56146 m
.39026 .57421 L
.37348 .58916 L
.35404 .60669 L
.3315 .62721 L
.30537 .65123 L
.27508 .6793 L
.23994 .7121 L
.19918 .7504 L
.15189 .7951 L
.09701 .84726 L
.03334 .90808 L
s
.03334 .90808 m
0 .94006 L
s
.935 0 1 r
.27167 .58906 m
.23856 .61502 L
.2003 .64577 L
.15606 .68213 L
.10487 .72502 L
.04562 .77554 L
s
.04562 .77554 m
0 .81507 L
s
1 0 .527 r
.70944 .51705 m
.73707 .50103 L
.76885 .48145 L
.80545 .45769 L
.8476 .42902 L
.89621 .3946 L
.9523 .35343 L
s
.9523 .35343 m
1 .31727 L
s
1 .13 0 r
.70594 .49921 m
.7336 .48207 L
.76544 .46128 L
.80213 .43622 L
.84444 .40613 L
.89325 .37016 L
.94961 .32731 L
s
.94961 .32731 m
1 .2879 L
s
1 0 .201 r
.61256 .63495 m
.62394 .63626 L
.6368 .63674 L
.65138 .63618 L
.66793 .63438 L
.68675 .63106 L
.70819 .62591 L
.73264 .61859 L
.76059 .60865 L
.79255 .59562 L
.82917 .5789 L
.87116 .55783 L
.91937 .53162 L
.97477 .49934 L
s
.97477 .49934 m
1 .48373 L
s
1 .19 0 r
.71557 .58192 m
.74223 .57051 L
.77279 .55599 L
.80785 .53778 L
.84812 .51524 L
.89441 .48757 L
.94768 .45389 L
s
.94768 .45389 m
1 .41913 L
s
1 .277 0 r
.23395 .56778 m
.19637 .59519 L
.153 .62788 L
.1029 .66674 L
.045 .71283 L
s
.045 .71283 m
0 .74948 L
s
.735 0 1 r
.66108 .28844 m
.68855 .25839 L
.72053 .22369 L
.75776 .1836 L
.80109 .13726 L
.85152 .08367 L
.9102 .02167 L
s
.9102 .02167 m
.93081 0 L
s
.317 1 0 r
.37157 .17082 m
.36344 .15549 L
.35463 .13963 L
.34509 .12324 L
.33471 .10636 L
.32341 .089 L
.31108 .07121 L
.29758 .05304 L
.28277 .03456 L
.26648 .01584 L
s
.26648 .01584 m
.25138 0 L
s
0 .027 1 r
.21594 .35025 m
.18196 .36199 L
.1431 .37747 L
.09859 .3974 L
.04756 .42258 L
s
.04756 .42258 m
0 .44809 L
s
0 .322 1 r
.23316 .44025 m
.199 .45767 L
.15978 .47928 L
.1147 .50586 L
.06283 .53827 L
.0031 .57755 L
s
.0031 .57755 m
0 .57968 L
s
0 .285 1 r
.2151 .25973 m
.18351 .26439 L
.14755 .27204 L
.10655 .28328 L
.05975 .29881 L
.00623 .31944 L
s
.00623 .31944 m
0 .32215 L
s
1 .283 0 r
.47136 .78892 m
.45953 .8141 L
.44542 .84224 L
.42864 .87377 L
.40873 .90918 L
.38517 .94904 L
.35735 .994 L
s
.35735 .994 m
.35348 1 L
s
.584 0 1 r
.60094 .74348 m
.60775 .75433 L
.61518 .76546 L
.6233 .77686 L
.6322 .78848 L
.64196 .80028 L
.65271 .81221 L
.66458 .82418 L
.6777 .83612 L
.69226 .8479 L
.70844 .85942 L
.72648 .87049 L
.74663 .88095 L
.76919 .89056 L
.79452 .89906 L
.82301 .90613 L
.85514 .91139 L
.89142 .9144 L
.93249 .91465 L
.97907 .91151 L
s
.97907 .91151 m
1 .90864 L
s
.356 1 0 r
.73646 .28456 m
.77414 .24796 L
.8179 .20533 L
.8687 .15572 L
.9277 .09798 L
.9962 .03079 L
s
.9962 .03079 m
1 .02706 L
s
1 .515 0 r
.1763 .24938 m
.13979 .25644 L
.09818 .26709 L
.0507 .28204 L
s
.0507 .28204 m
0 .30077 L
s
0 1 .599 r
.45472 .76617 m
.44129 .79092 L
.42537 .81875 L
.40654 .85009 L
.38432 .88547 L
.35815 .92548 L
.32735 .97082 L
s
.32735 .97082 m
.30684 1 L
s
0 .984 1 r
.77885 .53986 m
.81516 .51988 L
.85691 .49532 L
.90493 .46535 L
.96023 .42904 L
s
.96023 .42904 m
1 .40172 L
s
.527 1 0 r
.30429 .43637 m
.27979 .44758 L
.25168 .4617 L
.21942 .47927 L
.18234 .5009 L
.13969 .52731 L
.09058 .55935 L
.034 .59798 L
s
.034 .59798 m
0 .62215 L
s
1 .15 0 r
.3882 .22847 m
.3807 .21632 L
.37253 .20382 L
.36361 .19102 L
.35385 .17795 L
.34314 .16466 L
.33135 .1512 L
.31836 .13766 L
.30401 .12413 L
.28809 .11072 L
.27042 .09758 L
.25073 .08486 L
.22876 .07277 L
.20417 .06155 L
.17659 .05148 L
.14558 .0429 L
.11066 .03622 L
.07123 .03191 L
.02663 .03052 L
s
.02663 .03052 m
0 .03169 L
s
.185 0 1 r
.69492 .4361 m
.72284 .4149 L
.7551 .3897 L
.79238 .35985 L
.83549 .32454 L
.88536 .28288 L
.94307 .23379 L
s
.94307 .23379 m
1 .18459 L
s
.574 0 1 r
.83249 .74281 m
.8704 .7344 L
.91362 .72218 L
.96298 .70542 L
s
.96298 .70542 m
1 .69087 L
s
1 .175 0 r
.40487 .51534 m
.39168 .52444 L
.37647 .53535 L
.35892 .54838 L
.33865 .56389 L
.31523 .58232 L
.28816 .60413 L
.25685 .62992 L
.22063 .66033 L
.17871 .69615 L
.13018 .73827 L
.07396 .78774 L
.00884 .84577 L
s
.00884 .84577 m
0 .85374 L
s
1 0 .73 r
.55251 .65042 m
.55539 .65794 L
.55846 .66581 L
.56172 .67405 L
.5652 .68266 L
.5689 .69167 L
.57284 .70108 L
.57706 .71091 L
.58157 .72116 L
.5864 .73185 L
.59159 .74298 L
.59717 .75456 L
.60317 .76659 L
.60964 .77907 L
.61664 .792 L
.62423 .80537 L
.63246 .81917 L
.64141 .83337 L
.65117 .84795 L
.66184 .86287 L
.67353 .87809 L
.68636 .89354 L
.70049 .90914 L
.71609 .9248 L
.73334 .9404 L
.75248 .9558 L
.77377 .97084 L
.79749 .98529 L
.824 .99892 L
s
.824 .99892 m
.82657 1 L
s
1 0 .463 r
.43176 .32898 m
.42733 .32114 L
.42252 .31305 L
.41729 .30472 L
.41159 .29617 L
.40536 .28742 L
.39854 .27849 L
.39105 .26942 L
.3828 .26026 L
.3737 .25106 L
.36363 .24189 L
.35247 .23283 L
.34006 .22398 L
.32622 .21546 L
.31077 .20742 L
.29346 .20002 L
.27403 .19348 L
.25218 .18803 L
.22755 .18396 L
.19973 .18161 L
.16823 .18138 L
.13252 .18375 L
.09195 .18927 L
.04578 .19858 L
s
.04578 .19858 m
0 .21066 L
s
.745 1 0 r
.40869 .33923 m
.40088 .33411 L
.39217 .32924 L
.38242 .32471 L
.37148 .32063 L
.3592 .31713 L
.34536 .31437 L
.32974 .31255 L
.31207 .31187 L
.29205 .31261 L
.26932 .31507 L
.24348 .31961 L
.21404 .32664 L
.18046 .33667 L
.14209 .35028 L
.0982 .36815 L
.04793 .39106 L
s
.04793 .39106 m
0 .41508 L
s
1 .804 0 r
.5516 .64827 m
.55442 .65569 L
.55742 .66346 L
.56061 .6716 L
.564 .68012 L
.56761 .68902 L
.57146 .69833 L
.57557 .70806 L
.57995 .71821 L
.58465 .7288 L
.58969 .73983 L
.59509 .75132 L
.60091 .76327 L
.60717 .77568 L
.61394 .78854 L
.62125 .80187 L
.62918 .81563 L
.63779 .82983 L
.64716 .84443 L
.65739 .85941 L
.66857 .87472 L
.68084 .89031 L
.69432 .90611 L
.70917 .92204 L
.72557 .938 L
.74374 .95386 L
.7639 .96947 L
.78634 .98463 L
.81136 .99913 L
s
.81136 .99913 m
.81316 1 L
s
.605 0 1 r
.76921 .45715 m
.80653 .43144 L
.84955 .40061 L
.89921 .36378 L
.95655 .31993 L
s
.95655 .31993 m
1 .28578 L
s
.115 1 0 r
.6829 .50354 m
.70735 .48865 L
.73549 .47056 L
.7679 .44871 L
.80527 .42245 L
.84838 .39101 L
.89814 .35353 L
.95562 .30895 L
s
.95562 .30895 m
1 .27363 L
s
0 .217 1 r
.44268 .52195 m
.43438 .52843 L
.42479 .53612 L
.4137 .5452 L
.40087 .55593 L
.38602 .56856 L
.36883 .58342 L
.34893 .60088 L
.32587 .62137 L
.29914 .64539 L
.26817 .67351 L
.23227 .70643 L
.19063 .74492 L
.14235 .7899 L
.08634 .84243 L
.02136 .90376 L
s
.02136 .90376 m
0 .92403 L
s
0 .599 1 r
.5573 .83306 m
.55578 .8546 L
.55346 .87795 L
.55019 .90335 L
.54577 .93101 L
.54 .96123 L
.53262 .99431 L
s
.53262 .99431 m
.53117 1 L
s
.98 0 1 r
.61096 .681 m
.62085 .68609 L
.63192 .69075 L
.64435 .69486 L
.65834 .69827 L
.6741 .70079 L
.69192 .70219 L
.71208 .70223 L
.73495 .70061 L
.76094 .69695 L
.79051 .69086 L
.82422 .68183 L
.8627 .66929 L
.90669 .65258 L
.95705 .63089 L
s
.95705 .63089 m
1 .61038 L
s
.599 0 1 r
.54329 .2459 m
.55612 .22226 L
.57133 .19569 L
.58931 .16576 L
.61053 .13198 L
.63554 .09377 L
.66496 .05048 L
.69952 .00133 L
s
.69952 .00133 m
.70048 0 L
s
1 .611 0 r
.55335 .74095 m
.55385 .75554 L
.55401 .77124 L
.55376 .78816 L
.55301 .80644 L
.55166 .82623 L
.54957 .84769 L
.54661 .87101 L
.54261 .89642 L
.53737 .92417 L
.53067 .95455 L
.52222 .98787 L
s
.52222 .98787 m
.51874 1 L
s
0 .033 1 r
.19356 .64697 m
.14837 .68398 L
.0961 .72766 L
.03561 .77911 L
s
.03561 .77911 m
0 .80989 L
s
0 1 .801 r
.68952 .52214 m
.71434 .50817 L
.74288 .49104 L
.77572 .47019 L
.81354 .44498 L
.85714 .41464 L
.90742 .37829 L
.96546 .3349 L
s
.96546 .3349 m
1 .3083 L
s
0 1 .317 r
.2865 .48596 m
.25824 .50256 L
.22573 .5228 L
.18829 .54735 L
.14515 .57693 L
.09541 .61243 L
.03801 .65485 L
s
.03801 .65485 m
0 .68382 L
s
.432 0 1 r
.52719 .28458 m
.53679 .26533 L
.54821 .24376 L
.56177 .21954 L
.57781 .19229 L
.59675 .16156 L
.61909 .12683 L
.64539 .0875 L
.6763 .0429 L
s
.6763 .0429 m
.70701 0 L
s
1 0 .171 r
.29797 .6886 m
.26565 .72024 L
.22811 .75705 L
.18452 .79988 L
.1339 .84971 L
.0751 .90766 L
.00682 .97506 L
s
.00682 .97506 m
0 .9818 L
s
1 0 .365 r
.5068 .23147 m
.51514 .20971 L
.52519 .18555 L
.53726 .15865 L
.5517 .12862 L
.5689 .09503 L
.58934 .05736 L
.61357 .01502 L
s
.61357 .01502 m
.62259 0 L
s
.414 1 0 r
.70773 .49619 m
.73571 .47867 L
.76793 .45744 L
.80506 .43186 L
.84788 .40119 L
.89729 .36455 L
.95435 .32091 L
s
.95435 .32091 m
1 .28504 L
s
.442 1 0 r
.33494 .32572 m
.31761 .32566 L
.29796 .32702 L
.27562 .33013 L
.25021 .33533 L
.22124 .34305 L
.18817 .35378 L
.15037 .3681 L
.1071 .38668 L
.0575 .41032 L
.0006 .43993 L
s
.0006 .43993 m
0 .44027 L
s
.702 0 1 r
.81933 .24617 m
.86919 .19966 L
.92704 .14535 L
.99415 .08195 L
s
.99415 .08195 m
1 .07639 L
s
1 0 .88 r
.77572 .22661 m
.82028 .18217 L
.87204 .13053 L
.93218 .07053 L
s
.93218 .07053 m
1 .00284 L
s
.648 1 0 r
.4836 .56774 m
.47953 .57444 L
.47473 .58201 L
.46907 .59058 L
.46241 .6003 L
.4546 .61133 L
.44543 .62388 L
.43468 .63818 L
.42209 .6545 L
.40737 .67315 L
.39015 .6945 L
.37003 .71895 L
.34654 .74701 L
.31912 .77922 L
.28713 .81626 L
.24982 .85887 L
.20633 .90793 L
.15565 .96447 L
s
.15565 .96447 m
.12347 1 L
s
0 1 .681 r
.30284 .61453 m
.27321 .63991 L
.23891 .66976 L
.19918 .70481 L
.15316 .74591 L
.09981 .79408 L
.03798 .85047 L
s
.03798 .85047 m
0 .88542 L
s
1 .628 0 r
.25961 .67232 m
.22259 .70585 L
.17967 .7451 L
.12991 .791 L
.07221 .84466 L
.00527 .90733 L
s
.00527 .90733 m
0 .9123 L
s
1 0 .665 r
.671 .59578 m
.6913 .58916 L
.71451 .58033 L
.74107 .56888 L
.77152 .55433 L
.80645 .5361 L
.84658 .51353 L
.89271 .48586 L
.94581 .45218 L
s
.94581 .45218 m
1 .41607 L
s
0 1 .347 r
.17814 .36931 m
.13856 .38569 L
.09321 .40664 L
.04121 .433 L
s
.04121 .433 m
0 .45561 L
s
0 1 .529 r
.81295 .78022 m
.8472 .77638 L
.88615 .7694 L
.93052 .75864 L
.98114 .74335 L
s
.98114 .74335 m
1 .7366 L
s
0 1 .597 r
.57642 .64092 m
.58278 .64571 L
.58986 .65034 L
.59777 .65475 L
.60661 .65886 L
.61652 .66255 L
.62767 .66572 L
.64022 .66821 L
.65439 .66986 L
.67041 .67046 L
.68856 .66978 L
.70918 .66754 L
.73262 .66342 L
.75931 .65702 L
.78977 .64791 L
.82457 .63555 L
.86438 .61934 L
.90998 .59854 L
.96227 .57232 L
s
.96227 .57232 m
1 .55181 L
s
1 .375 0 r
.66148 .26092 m
.68975 .22867 L
.72272 .19152 L
.76113 .14871 L
.80588 .09933 L
.85801 .04235 L
s
.85801 .04235 m
.89707 0 L
s
0 1 .715 r
.27827 .58331 m
.24621 .60827 L
.20916 .63786 L
.16632 .67285 L
.11676 .71416 L
.05941 .76284 L
s
.05941 .76284 m
0 .8141 L
s
0 1 .828 r
.60745 .73422 m
.61539 .74379 L
.62414 .75346 L
.63379 .76317 L
.64447 .77284 L
.65631 .78239 L
.66948 .79172 L
.68416 .80068 L
.70057 .80914 L
.71894 .8169 L
.73956 .82375 L
.76275 .82944 L
.78891 .83365 L
.81845 .83602 L
.8519 .83613 L
.88983 .83347 L
.93293 .82746 L
.98197 .8174 L
s
.98197 .8174 m
1 .81259 L
s
1 .566 0 r
.49761 .48823 m
.49762 .4875 L
.49764 .48672 L
.49769 .48586 L
.49777 .48494 L
.49789 .48394 L
.49805 .48284 L
.49826 .48165 L
.49854 .48035 L
.49888 .47892 L
.49932 .47735 L
.49985 .47562 L
.5005 .4737 L
.5013 .47159 L
.50226 .46924 L
.50341 .46662 L
.50479 .46371 L
.50644 .46044 L
.5084 .45679 L
.51072 .45268 L
.51346 .44806 L
.51671 .44284 L
.52053 .43695 L
.52503 .43027 L
.53031 .42269 L
.53652 .41408 L
.54379 .40427 L
.55231 .39308 L
.56229 .38031 L
.57396 .3657 L
.58759 .34897 L
.60352 .32979 L
.62212 .30777 L
.64382 .28248 L
.66913 .25338 L
.69865 .2199 L
.73305 .18132 L
.77313 .13685 L
.81982 .08555 L
.87419 .02632 L
s
.87419 .02632 m
.89855 0 L
s
0 .179 1 r
.36045 .55458 m
.34021 .57046 L
.31682 .58927 L
.28977 .61151 L
.25848 .63774 L
.22226 .66864 L
.18033 .70498 L
.13177 .74766 L
.07551 .79774 L
.01031 .85643 L
s
.01031 .85643 m
0 .86581 L
s
0 .283 1 r
.60934 .27125 m
.63034 .24413 L
.6549 .21313 L
.68362 .17765 L
.71717 .13699 L
.75635 .09033 L
.80207 .03675 L
s
.80207 .03675 m
.83389 0 L
s
0 .179 1 r
.53483 .81459 m
.53081 .83652 L
.52564 .86052 L
.51912 .88685 L
.51099 .91579 L
.50097 .94769 L
.48873 .98293 L
s
.48873 .98293 m
.48223 1 L
s
.138 1 0 r
.75186 .53032 m
.78482 .51183 L
.82271 .48915 L
.86632 .46153 L
.91654 .42812 L
.97442 .38791 L
s
.97442 .38791 m
1 .36944 L
s
0 1 .834 r
.30861 .3511 m
.28704 .35522 L
.26247 .36146 L
.23442 .37022 L
.20237 .382 L
.16569 .39737 L
.12367 .417 L
.07546 .44165 L
.0201 .47225 L
s
.0201 .47225 m
0 .48413 L
s
1 0 .731 r
.56495 .43828 m
.57537 .42803 L
.58748 .4161 L
.60154 .40222 L
.61786 .38608 L
.63683 .36732 L
.65886 .34551 L
.68445 .32014 L
.71417 .29065 L
.7487 .25637 L
.78881 .21653 L
.8354 .17021 L
.88952 .11637 L
.95239 .0538 L
s
.95239 .0538 m
1 .0064 L
s
0 .874 1 r
.68186 .31404 m
.71141 .28428 L
.74574 .24973 L
.78564 .2096 L
.83199 .163 L
.88586 .10888 L
.94845 .04602 L
s
.94845 .04602 m
.99429 0 L
s
.873 0 1 r
.53518 .77572 m
.53228 .79456 L
.52847 .81513 L
.52358 .83763 L
.51741 .86232 L
.50973 .88947 L
.50027 .9194 L
.48871 .95247 L
.47469 .98911 L
s
.47469 .98911 m
.47016 1 L
s
1 0 .515 r
.7793 .63996 m
.81291 .62785 L
.85137 .61199 L
.89543 .59169 L
.94596 .56614 L
s
.94596 .56614 m
1 .53655 L
s
1 0 .233 r
.38601 .73826 m
.36413 .76651 L
.33853 .79881 L
.3086 .83578 L
.27364 .87815 L
.23281 .92676 L
.18516 .98259 L
s
.18516 .98259 m
.17008 1 L
s
.878 1 0 r
.58634 .6537 m
.59367 .65867 L
.60186 .66342 L
.61101 .66787 L
.62127 .67191 L
.63279 .67542 L
.64576 .67826 L
.66039 .68024 L
.67693 .68116 L
.69567 .68078 L
.71693 .67882 L
.74109 .67495 L
.76861 .66876 L
.79999 .6598 L
.83583 .64754 L
.87682 .63133 L
.92376 .61045 L
.97757 .58403 L
s
.97757 .58403 m
1 .57205 L
s
.073 1 0 r
.2784 .61635 m
.24545 .64391 L
.20731 .67637 L
.16316 .71456 L
.11202 .75942 L
.05279 .81206 L
s
.05279 .81206 m
0 .85953 L
s
1 .215 0 r
.34105 .42667 m
.32175 .43406 L
.29965 .44364 L
.27432 .45581 L
.24526 .47103 L
.21187 .48987 L
.17349 .51296 L
.12931 .54106 L
.07844 .57504 L
.01979 .61592 L
s
.01979 .61592 m
0 .63024 L
s
1 .995 0 r
.30918 .42574 m
.28563 .4357 L
.25864 .4484 L
.22767 .46435 L
.19211 .48411 L
.15124 .50839 L
.1042 .53797 L
.05004 .57379 L
s
.05004 .57379 m
0 .60837 L
s
1 0 .152 r
.60712 .36985 m
.62509 .3507 L
.646 .32855 L
.67033 .30291 L
.69864 .27323 L
.73156 .23887 L
.76985 .19906 L
.81438 .15293 L
.86616 .09948 L
.92637 .03751 L
s
.92637 .03751 m
.96291 0 L
s
.031 1 0 r
.64643 .74129 m
.65941 .74819 L
.67394 .75456 L
.69025 .76022 L
.70858 .76498 L
.72925 .7686 L
.75259 .77078 L
.779 .7712 L
.80894 .76947 L
.84295 .76512 L
.88165 .7576 L
.92574 .74628 L
.97606 .73041 L
s
.97606 .73041 m
1 .72155 L
s
.96 1 0 r
.53992 .79627 m
.53709 .81634 L
.53332 .83823 L
.52844 .86215 L
.52225 .88837 L
.5145 .91717 L
.50491 .94889 L
.49316 .98391 L
s
.49316 .98391 m
.48723 1 L
s
1 .367 0 r
.80356 .5041 m
.84418 .47926 L
.89094 .44908 L
.94481 .41264 L
s
.94481 .41264 m
1 .37374 L
s
1 .299 0 r
.26411 .49259 m
.23265 .51157 L
.19646 .53465 L
.15477 .56255 L
.10671 .59612 L
.05128 .63631 L
s
.05128 .63631 m
0 .67475 L
s
0 .032 1 r
.68417 .79587 m
.7007 .80395 L
.71924 .81129 L
.74005 .81768 L
.76348 .82284 L
.78992 .82647 L
.8198 .82819 L
.85364 .82757 L
.89205 .82409 L
.9357 .81716 L
.9854 .80606 L
s
.9854 .80606 m
1 .80191 L
s
0 .554 1 r
.64037 .1804 m
.66804 .14354 L
.70044 .10148 L
.73835 .05341 L
s
.73835 .05341 m
.7814 0 L
s
.997 1 0 r
.72572 .71142 m
.75017 .70939 L
.77795 .70517 L
.80958 .69831 L
.84564 .68829 L
.88682 .67449 L
.9339 .65618 L
.98781 .63252 L
s
.98781 .63252 m
1 .62661 L
s
1 .994 0 r
.58805 .6063 m
.59692 .60739 L
.60696 .60783 L
.61834 .60747 L
.63125 .60613 L
.64592 .60363 L
.66264 .5997 L
.68171 .59408 L
.7035 .58644 L
.72841 .57639 L
.75696 .56347 L
.78968 .54718 L
.82725 .52688 L
.87042 .50186 L
.92008 .47129 L
.97725 .43419 L
s
.97725 .43419 m
1 .41873 L
s
.703 1 0 r
.19745 .64272 m
.1529 .67907 L
.10137 .72199 L
.04175 .77256 L
s
.04175 .77256 m
0 .80855 L
s
1 0 .987 r
.43273 .77652 m
.41606 .80392 L
.3964 .83486 L
.37324 .86987 L
.34601 .90957 L
.31402 .95466 L
s
.31402 .95466 m
.28086 1 L
s
.448 1 0 r
.50391 .48222 m
.50493 .48049 L
.50613 .47855 L
.50755 .47634 L
.50921 .47385 L
.51117 .47102 L
.51347 .46781 L
.51617 .46415 L
.51933 .45998 L
.52303 .45522 L
.52736 .44978 L
.53242 .44355 L
.53833 .4364 L
.54523 .42821 L
.55329 .41879 L
.56268 .40796 L
.57364 .3955 L
.58641 .38115 L
.60129 .36461 L
.61863 .34552 L
.63881 .3235 L
.66232 .29806 L
.68969 .26866 L
.72153 .23468 L
.7586 .19537 L
.80172 .14989 L
.85188 .09724 L
.91024 .03628 L
s
.91024 .03628 m
.94511 0 L
s
1 0 .695 r
.76614 .59308 m
.79928 .57836 L
.83727 .55973 L
.88088 .53647 L
.93099 .50777 L
.98861 .47264 L
s
.98861 .47264 m
1 .46531 L
s
0 .989 1 r
.3238 .59614 m
.29749 .61834 L
.26705 .64447 L
.23179 .67519 L
.19096 .71125 L
.14365 .75355 L
.08882 .80311 L
.02527 .86112 L
s
.02527 .86112 m
0 .88439 L
s
0 1 .651 r
.55752 .52966 m
.56442 .52723 L
.57231 .52403 L
.58135 .51993 L
.59172 .51476 L
.60362 .50832 L
.61729 .50038 L
.63302 .49069 L
.65113 .47892 L
.67199 .46473 L
.69605 .44768 L
.7238 .4273 L
.75584 .403 L
.79286 .37413 L
.83563 .33992 L
.8851 .29945 L
.94232 .25169 L
s
.94232 .25169 m
1 .20268 L
s
1 .498 0 r
.71394 .45844 m
.7438 .43742 L
.77825 .41226 L
.81801 .38227 L
.86394 .34661 L
.91702 .30432 L
.97839 .2543 L
s
.97839 .2543 m
1 .23632 L
s
0 .004 1 r
.54293 .52114 m
.5481 .51925 L
.55403 .51678 L
.56081 .51363 L
.5686 .50966 L
.57754 .50473 L
.58781 .49868 L
.59963 .49129 L
.61324 .48234 L
.62892 .47156 L
.64701 .45863 L
.66788 .44317 L
.69198 .42477 L
.71982 .40291 L
.75201 .37702 L
.78922 .34642 L
.83228 .31031 L
.88211 .26779 L
.93981 .21778 L
s
.93981 .21778 m
1 .16487 L
s
0 .946 1 r
.20822 .74888 m
.16218 .79272 L
.10876 .84383 L
.04676 .9034 L
s
.04676 .9034 m
0 .9485 L
s
1 .731 0 r
.78101 .59257 m
.81617 .57657 L
.85648 .55639 L
.90276 .53128 L
.95594 .50036 L
s
.95594 .50036 m
1 .47314 L
s
.772 1 0 r
.30506 .76463 m
.27159 .80168 L
.2326 .84443 L
.18719 .89378 L
.13433 .95079 L
s
.13433 .95079 m
.08838 1 L
s
.726 0 1 r
.67802 .33688 m
.70642 .30925 L
.73939 .27708 L
.77767 .23964 L
.82213 .19607 L
.87376 .14537 L
.93372 .08639 L
s
.93372 .08639 m
1 .02109 L
s
1 .042 0 r
.47313 .67283 m
.46475 .6887 L
.4548 .70651 L
.44303 .72656 L
.42912 .74916 L
.41273 .7747 L
.39342 .80361 L
.37073 .83641 L
.34408 .87367 L
.31283 .91609 L
.27621 .96444 L
s
.27621 .96444 m
.2486 1 L
s
1 .825 0 r
.50007 .6499 m
.49594 .66172 L
.49092 .67482 L
.48487 .68937 L
.47761 .70557 L
.46892 .72365 L
.45857 .74387 L
.44627 .76655 L
.43169 .79204 L
.41445 .82075 L
.3941 .85316 L
.37013 .8898 L
.34193 .93133 L
.3088 .97848 L
s
.3088 .97848 m
.29319 1 L
s
1 0 .628 r
.65322 .28059 m
.67984 .25057 L
.71087 .21597 L
.74702 .17608 L
.78912 .13003 L
.83814 .07686 L
.89521 .01543 L
s
.89521 .01543 m
.90965 0 L
s
1 .451 0 r
.62472 .76991 m
.63399 .78086 L
.64421 .79191 L
.65549 .80299 L
.66799 .81401 L
.68185 .82486 L
.69727 .83541 L
.71447 .84552 L
.7337 .855 L
.75525 .86364 L
.77945 .87117 L
.8067 .87728 L
.83742 .88162 L
.87216 .88376 L
.91149 .88318 L
.95612 .8793 L
s
.95612 .8793 m
1 .87247 L
s
.001 1 0 r
.55681 .69563 m
.55903 .70635 L
.56125 .71774 L
.56345 .72985 L
.56561 .74272 L
.56771 .75644 L
.5697 .77106 L
.57157 .78667 L
.57324 .80335 L
.57469 .82122 L
.57583 .84037 L
.5766 .86095 L
.5769 .88308 L
.57664 .90693 L
.57567 .93269 L
.57387 .96055 L
.57105 .99077 L
s
.57105 .99077 m
.56992 1 L
s
0 1 .406 r
.81874 .82482 m
.85254 .82402 L
.89089 .82036 L
.93449 .81323 L
.98413 .80192 L
s
.98413 .80192 m
1 .79734 L
s
1 .636 0 r
.32761 .45711 m
.30566 .46802 L
.28046 .48161 L
.25151 .49837 L
.21821 .51884 L
.17988 .5437 L
.13571 .57369 L
.08479 .60971 L
.02604 .6528 L
s
.02604 .6528 m
0 .67252 L
s
1 .695 0 r
.40475 .23809 m
.39921 .22532 L
.39328 .212 L
.38692 .19812 L
.38009 .18368 L
.37274 .16866 L
.36482 .15307 L
.35627 .1369 L
.34702 .12017 L
.33699 .10288 L
.32609 .08506 L
.31422 .06674 L
.30126 .04795 L
.28709 .02876 L
.27154 .00923 L
s
.27154 .00923 m
.26357 0 L
s
0 .672 1 r
.26351 .18242 m
.24055 .17697 L
.21466 .17299 L
.18541 .17085 L
.1523 .17096 L
.11473 .17382 L
.07205 .18003 L
.02346 .19027 L
s
.02346 .19027 m
0 .19666 L
s
.433 1 0 r
.73034 .57765 m
.7591 .56468 L
.79208 .54829 L
.82994 .52788 L
.87345 .50273 L
.92349 .47197 L
.98109 .43465 L
s
.98109 .43465 m
1 .42181 L
s
1 .549 0 r
.33474 .74153 m
.30589 .7743 L
.27225 .81204 L
.23307 .85555 L
.18742 .90574 L
.13426 .96368 L
s
.13426 .96368 m
.10066 1 L
s
.311 0 1 r
.65539 .47968 m
.6768 .4652 L
.70149 .44779 L
.72997 .42696 L
.76285 .40213 L
.80083 .37261 L
.84472 .33761 L
.89546 .29621 L
.95416 .24734 L
s
.95416 .24734 m
1 .20847 L
s
.286 1 0 r
.34675 .44109 m
.32781 .44915 L
.30611 .45941 L
.28122 .47229 L
.25262 .48825 L
.21975 .50783 L
.18193 .53169 L
.13837 .56056 L
.08816 .59533 L
.03026 .637 L
s
.03026 .637 m
0 .65954 L
s
0 .362 1 r
.29131 .28667 m
.2692 .28714 L
.24412 .28948 L
.2156 .29409 L
.18312 .30143 L
.14609 .31203 L
.10379 .32655 L
.05542 .34571 L
2e-05 .3704 L
s
2e-05 .3704 m
0 .37042 L
s
.946 0 1 r
.73693 .58171 m
.76647 .56851 L
.80033 .55182 L
.8392 .531 L
.88387 .50532 L
.93523 .47391 L
.99436 .43576 L
s
.99436 .43576 m
1 .43194 L
s
.691 0 1 r
.36069 .22158 m
.34969 .21116 L
.33751 .20084 L
.32397 .1907 L
.3089 .18089 L
.29207 .17156 L
.27325 .16288 L
.25214 .15508 L
.22841 .14842 L
.20168 .14319 L
.17151 .13978 L
.13739 .13859 L
.09872 .14014 L
.05481 .14502 L
.00488 .15392 L
s
.00488 .15392 m
0 .1551 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{1000, 1000},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000?X0003j2000`400?l00000o`00003ooooonf[o
oookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00
oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[
oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Z
oooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooook
J_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z
003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooook
J^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooo
nf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oo
oo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]Zjooo
nfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oo
oo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[o
oookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00
oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[
oookJP00i?oonfX5o`00O`Gooo]Z1Ol007oooookJ^Cooo]Z1Ol007l5oookJPGo001ooooonfX4oook
JP00hooonfX7o`00O`?ooo]Z1ol007oooookJ^;ooo]Z1ol007l3oookJPOo001ooooonfX3oookJP00
hooonfX3o`00O`;ooo]Z0ol007l2oookJP?o001o00Cooo]Zo`00Ool007oo001ooooonf[RoookJP?o
001o0_oonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007oooookJP?ooo]Z003FoookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX4o`00
0?oooo]Zb_oonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`Kooo]Z1?l0003goookJP00e_oonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`Kooo]Z1_l0001foookJP03ofL0oooonf[ooo]Z00_ooo]Z00?oo`1M
oookJ_oonfX01_oonfX2ol<0o`;ooo]Z1ooob@000om^0?ooolT0oookJP05oookJP03o`3o2ooonf[o
oo]Z00Gooo]Z00?o08gooookJ_oonfX00_oonfX01?ooV@3ooo]ZoookJ_oonfX2o`18o`Wooo]Z00?o
H?l0oomO0?ooT0000_oo0:001?oob@3oo`2;ok`0oooonfX2og;o0003o`H0oooob@3oolT000Cooo]Z
00?o0=ooool0hOoonfX0m_oonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`Kooo]Z1_l0001goookJP03ofL0oooonf[ooo]Z00[ooo]Z00?oo`1MoookJ_oo
nfX01ooonfX00oo30?oooo]ZoookJP06oookJP03oiT0oom^0?oooo]Z00Kooo]Z00?oj`3oo`3o2ooo
nfX01OoonfX00ol0SOoooo]ZoookJP03oookJP03oonI0?oonf[ooo]Z00;o04So2OoonfX00omPo`3o
oo]Zoon@0002ool0X0;oo`2;00Oooo]Zok`0oooonf[oL_l0oookJ_mNo`3oo`0V00Cooo]Z0_l0gol0
0ooo0>7ooo]ZoookJP0RoookJP00h_oonfX4o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJP?o001o1_oonfX4o`0007Oooo]Z00?oI`3ooookJ_oonfX02ooonfX00ooo05gooo]ZoookJP06
oookJP04ol<0oooonf[ooo]ZoookJPSoolT000?oKP3oooo90?oonfX01?oonfX00oo[0?oo0?l;oook
JP05oookJP03o`2=oooonf[ooo]Z00?ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`0:oookJP03of3o
0?ooT03oo`2P00?oolT000Co_03ooookJ_mbo`3ooo]Z1?oob@03oookJP03o`3Ooooo0>7oo`2k0?oo
oo]Z1?oonfX4o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX4o`00
07Sooo]Z00?oI`3ooookJ_oonfX02_oonfX00ooo05gooo]ZoookJP07oookJP03ol<0oooonf[ooo]Z
00Oooo]Z00?oV@3oofh0oooonfX01OoonfX00oo[0?oooo]Zo`3o2`06oookJP03o`2=oooonf[ooo]Z
00;ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`0:oookJP03of3o0?ooT03oo`2P00;ooo]Z00Soo`2;
oookJ_nl0?oooo]Zog;o0?oonf[oG_l0ool09PCooo]Z00Co0=oooookJ_oo0;_oo`2k9?oonfX00>;o
oo]Z2?l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0001foookJP03ofL0oooonf[ooo]Z00co
oo]Z00?oo`1MoookJ_oonfX01?oonfX2onGo00Kooo]Z1Ooob@000om^0?ooolT0oookJP04oookJP03
on/0ool0o`_ooo]Z00Gooo]Z00?o08gooookJ_oonfX00ooonfX01OooV@3ooo]ZoookJ_oonf[o04So
00[ooo]Z00CoH?l0oon@0?oob@3oo`2P0_oob@001?nl0?oooo]Zog;o0?oonfX4ooo900?ooo]Z00?o
0=ooool0hOoo0;/0oooonfX5oookJPSo001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000Mooo
nfX00omW0?oooo]ZoookJP0;oookJP03ool0GOoonf[ooo]Z00Kooo]Z00?o``3ooookJ_oonfX01ooo
nfX00onI0?ooKP3ooookJP05oookJP03on/0oooonf[o0?l;00Kooo]Z00?o08gooookJ_oonfX00_oo
nfX01OooV@3ooo]ZoookJ_oonf[o04So00[ooo]Z00goH?l0oon@0?oonf[oo`2PoookJ_oo08_ooo]Z
ok`0oooonf[oL_l0oookJ_mNo`3oo`0V00Cooo]Z00?o0=oooookJ_oo0;/09_oonfX00>;ooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0001foookJP03ofL0
oooonf[ooo]Z00_ooo]Z00?oo`1MoookJ_oonfX01?oonfX3onGo00Oooo]Z0ooob@000om^0?ooolT0
ooo90004oookJP03on/0ool0o`_ooo]Z00Gooo]Z00?o08gooookJ_oonfX00ooonfX01OooV@3ooo]Z
oookJ_oonf[o04So00[ooo]Z00CoH?l0oon@0?oob@3oo`2P0_oob@000onl0?oooo]Zog;o0005ooo9
00?ooo]Z00Go0=ooool0hOoo0;_ooo]ZokT0o`3ooookJPCooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0001goookJP03ofL0oooonf[ooo]Z00[ooo]Z00?o
o`1MoookJ_oonfX01ooonfX00oo30?oooo]ZoookJP06oookJP03oiT0oom^0?oooo]Z00Gooo]Z00?o
j`3ooookJ_l0o`/01_oonfX00ol0SOoooo]ZoookJP02oookJP05oonI0?oonf[ooo]ZoookJ_l0B?l0
2_oonfX03OmPo`3ooi00oookJ_oo0:3ooo]Zool0Rooonf[o_03ooookJ_mbo`3ooo]Zoeko0?oo02H0
1?oonfX01?l0gooooo]Zool0^ooonfX2okT0obCooo]Z003RoookJP?o001o1ooonfX3o`00O`?ooo]Z
0ol007l6oookJPCo0000MOoonfX00omW0?oooo]ZoookJP0;oookJP03ool0GOoonf[ooo]Z00Cooo]Z
0ooUo`08oookJP;oolT000?oKP3oooo90?oob@001OoonfX00ol0o`_ooo]ZoookJP04oookJP03o`2=
oooonf[ooo]Z00?ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`0:oookJP04of3o0?ooT03oolT0ool0
X0;oolT000Co_03ooookJ_oob@3oL_l01Ooob@02oookJP06o`3Ooooo0>7oo`2koookJ_ni0?ooFol0
oooonfX4oookJP?o001o1ooonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000M_oonfX00omW0?oooo]Z
oookJP0:oookJP03ool0GOoonf[ooo]Z00Oooo]Z00?o``3ooookJ_oonfX01_oonfX00onI0?ooKP3o
oookJP06oookJP03on/0ool0o`_ooo]Z00Gooo]Z00?o08gooookJ_oonfX00_oonfX01OooV@3ooo]Z
oookJ_oonf[o04So00[ooo]Z00SoH?l0oon@0?oonf[oo`2PoookJ_oo08_ooo]Zok`0o`;ooo]Z00?o
L_l0oeko0?oo02H01?oonfX01ol0gooooo]Zool0^ooonf[o^@3ooookJ_mKo`009?oonfX00>;ooo]Z
0ol007l7oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0001doookJP03ofL0oooonf[ooo]Z00_ooo]Z
00?oo`1MoookJ_oonfX00ooonfX5onGo00Oooo]Z00?oolT0oookJ_m^0?l00ooob@04oookJP03o`3o
2ooonf[ooo]Z00Cooo]Z00?o08gooookJ_oonfX00ooonfX01OooV@3ooo]ZoookJ_oonf[o04So00[o
oo]Z00CoolT0oon@0?oob@3oo`2P0_oob@001?nl0?ooolT0ooo90?mbo`05ooo900;ooo]Z00Oo0=oo
ool0hOoo0;_ooo]ZokT0oooonf[oFol00?oooo]Z1?oonfX3o`00O`Oooo]Z0ol007l3oookJP?o001o
1_oonfX4o`0007Gooo]Z00?oI`3ooookJ_oonfX02_oonfX00ooo05gooo]ZoookJP07oookJP03ol<0
oooonf[ooo]Z00Kooo]Z00?oV@3oofh0oooonfX01_oonfX00oo[0?oo0?l;oookJP05oookJP03o`2=
oooonf[ooo]Z00;ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`0:oookJP08of3o0?ooT03ooo]Zool0
X?oonf[oo`2;oookJ_nl0?l2oookJP03og;o0?mNo`3oo`0V00Cooo]Z00Oo0=oooookJ_oo0;_ooo]Z
okT0oooonf[oFol002Gooo]Z003SoookJP?o001o0_oonfX3o`00O`;ooo]Z0ol007l01?oonf[o001o
o`00Ool007l7oookJPCo0000LooonfX00omW0?oooo]ZoookJP0;oookJP03ool0GOoonf[ooo]Z00?o
oo]Z1OoUo`07oookJP03ooo90?oonf[oKP3o00;ooo]Z00?oolT0oookJ_oonfX00_oonfX00ol0o`_o
oo]ZoookJP04oookJP03o`2=oooonf[ooo]Z00?ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`0:oook
JP04ooo90?ooT03oolT0ool0X0;oolT000Co_03oooo90?oob@3oL_l01_oob@002?oonf[o0=ooool0
hOoo0;_ooo]ZokT0oooonf[oFol0oooonfX6oookJP?o001o0_oonfX3o`00O`;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l7oookJPCo0000M?oonfX00omW0?oooo]ZoookJP0:oookJP03ool0GOoonf[o
oo]Z00Oooo]Z00?o``3ooookJ_oonfX01_oonfX00onI0?ooKP3ooookJP06oookJP03on/0ool0o`_o
oo]Z00Gooo]Z00?o08gooookJ_oonfX00_oonfX01OooV@3ooo]ZoookJ_oonf[o04So00[ooo]Z00So
H?l0oon@0?oonf[oo`2PoookJ_oo08_ooo]Zok`0o`;ooo]Z00?oL_l0oeko0?oo02H01?oonfX01ol0
gooooo]Zool0^ooonf[o^@3ooookJ_mKo`009_oonfX00>?ooo]Z1ol007l3oookJPOo001o1ooonfX4
o`0007;ooo]Z00?oI`3ooookJ_oonfX02ooonfX00ooo05gooo]ZoookJP03oookJPKoiOl01_oonfX0
0ooob@3ooo]Zofh0o`07oookJP03o`3o2ooonf[ooo]Z00Cooo]Z00?o08gooookJ_oonfX00ooonfX0
1OooV@3ooo]ZoookJ_oonf[o04So00Wooo]Z0_oob@000oooT03oolT0ool0X005ooo90003og;o0?oo
b@3oolT000CoolT000Sooo]Zo`3Ooooo0>7oo`2koookJ_ni0?oooo]Zoe_o0?oooo]Z1ooonfX7o`00
O`?ooo]Z1ol007l7oookJPCo0000LooonfX00omW0?oooo]ZoookJP0:oookJP03ool0GOoonf[ooo]Z
00Oooo]Z00?o``3ooookJ_oonfX01_oonfX00onI0?ooKP3ooookJP06oookJP03on/0ool0o`_ooo]Z
00Gooo]Z00?o08gooookJ_oonfX00_oonfX01OooV@3ooo]ZoookJ_oonf[o04So00[ooo]Z00SoH?l0
oon@0?oonf[oo`2PoookJ_oo08_ooo]Zok`0o`;ooo]Z00?oL_l0o`0aoooo02H01?oonfX01ol0gooo
o`3Qool0^ooonf[o^@3ooookJ_mKo`009ooonfX00>Gooo]Z1?l007l5oookJPGo001o2?oonfX4o`00
07;ooo]Z00?oI`3ooookJ_oonfX02_oonfX00ooo05gooo]ZoookJP02oookJPOoiOl01_oonfX00ooo
b@3ooo]Zofh0o`07oookJP03o`3o2ooonf[ooo]Z00Cooo]Z00?o08gooookJ_oonfX00ooonfX01Ooo
V@3ooo]ZoookJ_oonf[o04So00Wooo]Z0_oob@000oooT03oolT0ool0X005ooo90003og;o0?oob@3o
olT000CoolT000Sooo]Zo`3Ooooo0>7oo`2koookJ_ni0?oooo]Zoe_o00;ooo]Z00?ooo80oookJ_oo
nfX0oooonfX5oookJPCo001o1OoonfX5o`00O`Sooo]Z1?l0001boookJP03ofL0oooonf[ooo]Z00[o
oo]Z00?oo`1MoookJ_oonfX01ooonfX00oo30?oooo]ZoookJP06oookJP03oiT0oom^0?oooo]Z00Ko
oo]Z00?oj`3oo`3o2ooonfX01OoonfX00ol0SOoooo]ZoookJP02oookJP05oonI0?oonf[ooo]Zoook
J_l0B?l02_oonfX02?mPo`3ooi00oookJ_oo0:3ooo]Zool0Rooonf[o_03o0_oonfX00ombo`3o037o
ool09P04oookJP07o`3Ooooo0>7oo`2koookJ_ni0?oooo]Zoe_o0002oookJP;ooo809?oonfX00?_o
oo]Z1?l0001aoookJP03ofL0oooonf[ooo]Z00[ooo]Z00?oo`1MoookJ_oonfX00_oonfX8onGo00Go
oo]Z00?oolT0oookJ_m^0?l01ooonfX00ol0o`_ooo]ZoookJP04oookJP03o`2=oooonf[ooo]Z00?o
oo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`09oookJP;oolT000?ooi00ooo90?oo0:000_oob@001?nl
0?ooolT0ooo90?mbo`07ooo90007o`3Ooooo0>7oo`2koookJ_ni0?oooo]Zoe_o0002oookJP03ooob
0?n6o`3ooo]Z0?oooo]Z7?oonfX4o`0007;ooo]Z00?oI`3ooookJ_oonfX02OoonfX00ooo05gooo]Z
oookJP07oookJP03ol<0oooonf[ooo]Z00Kooo]Z00?oV@3oofh0oooonfX01_oonfX00oo[0?oo0?l;
oookJP05oookJP03o`2=oooonf[ooo]Z00;ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`0:oookJP08
of3o0?ooT03ooo]Zool0X?oonf[oo`2;oookJ_nl0?l2oookJP03og;o0?l0<Oooo`0V00Cooo]Z00Oo
0=ooool0hOoo0;_ooo]ZokT0oooonf[oFol000;ooo]Z00?ooo80oookJ_n6o`009?oonfX00?_ooo]Z
1?l0001`oookJP03ofL0oooonf[ooo]Z00_ooo]Z00Coo`1MoookJ_oonf[ooo]Z2?oUo`05oookJP03
ooo90?oonf[oKP3o00Oooo]Z00?o0?l;oookJ_oonfX01?oonfX00ol0SOoooo]ZoookJP03oookJP05
oonI0?oonf[ooo]ZoookJ_l0B?l02_oonfX01?mPo`3ooel0oon@0?oo0:02ooo90005ok`0oooob@3o
olT0og;o0?l60?l01_oob@001ol0goooo`3Qool0^ooonf[o^@3ooookJ_mKo`000_oonfX00ooolP3o
Q_l0oookJP3ooookJQgooo]Z1?l0001aoookJP03ofL0oooonf[ooo]Z00[ooo]Z00?oo`1MoookJ_oo
nfX01_oonfX00oo30?oooo]ZoookJP06oookJP03oiT0oom^0?oooo]Z00Kooo]Z00?oj`3oo`3o2ooo
nfX01OoonfX00ol0SOoooo]ZoookJP02oookJP05oonI0?oonf[ooo]ZoookJ_l0B?l02_oonfX02?mP
o`3ooel0oon@0?oo0:3ooo]Zool0Rooonf[o_03o0_oonfX00ombo`3o037oool09P04oookJP07o`3O
oooo0>7oo`2koookJ_ni0?oooo]Zoe_o0002oookJP03ooob0?oonf[oQ_l002Gooo]Z003koookJPCo
0000KooonfX00omW0?oooo]ZoookJP0;oookJP04ool0GOoonf[ooo]ZoookJPWoiOl01OoonfX00ooo
b@3oKP3ooookJP06oookJP03on/0ool0o`_ooo]Z00Cooo]Z00?o08gooookJ_oonfX00ooonfX01Ooo
V@3ooo]ZoookJ_oonf[o04So00[ooo]Z00CoH?l0oomO0?ooT03oo`2P0_oob@001_nl0?ooolT0ooo9
0?mbo`3o1P3ooeko00KoolT000Koo`3Qool0^ooonf[ooo]ZokT0oomKo`02oookJP04ooob0?n6o`3o
oo]Zool0m?oooo]Z7OoonfX4o`00073ooo]Z00?oI`3ooookJ_oonfX02_oonfX00ooo05gooo]Zoook
JP07oookJP03ol<0oooonf[ooo]Z00Kooo]Z00?oKP3ooookJ_oonfX01OoonfX00oo[0?oo0?l;oook
JP05oookJP03o`2=oooonf[ooo]Z00;ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`0:oookJP08of3o
0?ooG`3ooi00ool0X?oonf[oo`2;oookJ_nl0?l2oookJP03og;o0?l0<Oooo`0V00Cooo]Z00?o0=oo
ool0hOoo0;/00_oonfX02Oni0?ooFol0oookJ_oonf[ooo80oookJ_n6o`3ooo]Zool0m00ToookJP00
nooonfX4o`0006oooo]Z00?oI`3ooookJ_oonfX02_oonfX00ooo05gooo]ZoookJP03oookJPOoiOl0
1OoonfX00ooob@3oKP3ooookJP06oookJP03on/0ool0o`_ooo]Z00Cooo]Z00?o08gooookJ_oonfX0
0ooonfX01OooV@3ooo]ZoookJ_oonf[o04So00[ooo]Z00OoH?l0oomO0?ooT03oo`2PoookJ_oob@3o
_03o00;oolT000CoL_l0o`H0oomNo`3oolT00_oonfX3ooo90006ool0hOoo0;_ooo]ZoookJ_ni0?oo
Fol00_oonfX01OoolP3oQ_l0oookJ_oo0?Co/`3o0?oooo]Z7OoonfX4o`0006oooo]Z00?oI`3ooook
J_oonfX02_oonfX00ooo05gooo]ZoookJP07oookJP03ol<0oooonf[ooo]Z00Kooo]Z00?oKP3ooook
J_oonfX01OoonfX00oo[0?oo0?l;oookJP05oookJP03o`2=oooonf[ooo]Z00;ooo]Z00GooiT0oook
J_oonf[ooo]Zo`18o`0:oookJP08of3o0?ooG`3ooi00ool0X?oonf[oo`2;oookJ_nl0?l2oookJP03
og;o0?l60?ooo`0V00Cooo]Z00?o0=ooool0hOoo0;/00_oonfX02_ni0?ooFol0oookJ_oonf[ooo80
oookJ_n6o`3ooo]Zool0m?nc0?lToookJP00nooonfX4o`0006kooo]Z00?oI`3ooookJ_oonfX02_oo
nfX00ooo05gooo]ZoookJP05oookJPKoiOl01?oonfX00ooob@3oKP3ooookJP06oookJP03on/0ool0
o`_ooo]Z00Cooo]Z00?o08gooookJ_oonfX00ooonfX01OooV@3ooo]ZoookJ_oonf[o04So00[ooo]Z
00goH?l0oomO0?ooT03oo`2PoookJ_oob@3o_03ooookJ_oob@3oL_l0ooo90?mNo`3oolT000Cooo]Z
00?oolT0ool0hOoo0;/00_oonfX02_ni0?ooFol0oookJ_oonf[ooo80ohKo0?oonf[oo`3doookJ_nc
0?oooookJQgooo]Z1?l0001^oookJP03ofL0oooonf[ooo]Z00[ooo]Z00?oo`1MoookJ_oonfX01ooo
nfX00oo30?oooo]ZoookJP06oookJP03ofh0oooonf[ooo]Z00Kooo]Z00?o0?l;oookJ_oonfX01?oo
nfX00ol0SOoooo]ZoookJP02oookJP05oonI0?oonf[ooo]ZoookJ_l0B?l02_oonfX02?mPo`3ooel0
oon@0?oo0:3ooo]Zool0Rooonf[o_03o0_oonfX00ombo`3o1P3oool09P04oookJP03o`3Ooooo0>7o
o`2k00;ooo]Z00[o^@3ooe_o0?oonf[ooo]Zooob0?oonf[oQ_l0oookJ_oo0?Co/`3o9OoonfX00?_o
oo]Z1?l0001]oookJP03ofL0oooonf[ooo]Z00[ooo]Z00?oo`1MoookJ_oonfX01_oonfX5onGo00Co
oo]Z00?oolT0oookJ_m^0?l01_oonfX00oo[0?oo0?l;oookJP04oookJP03o`2=oooonf[ooo]Z00?o
oo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`0:oookJP07of3o0?ooG`3ooi00ool0X?oonf[oolT0ok`0
o`02oookJP04og;o0?oob@3oG_l0ooo900Cooo]Z00?o0=ooool0hOoo0;/00_oonfX02oni0?ooFol0
oookJ_oonf[ooo80ohKo0?oonf[oo`3doookJ_nc0?ooo`2Z0?oooo]Z7OoonfX4o`0006gooo]Z00?o
I`3ooookJ_oonfX02_oonfX00ooo05gooo]ZoookJP07oookJP03ol<0oooonf[ooo]Z00Kooo]Z00?o
V@3oofh0oooonfX01_oonfX00ol0o`_ooo]ZoookJP04oookJP03o`2=oooonf[ooo]Z00;ooo]Z00Go
oiT0oookJ_oonf[ooo]Zo`18o`0:oookJP08of3o0?ooG`3ooi00ool0X?oonf[oo`2;oookJ_nl0?l2
oookJP03og;o0?l60?ooo`0V00Cooo]Z00?o0=ooool0hOoo0;/00_oonfX03?ni0?ooFol0oookJ_oo
nf[ooo80oookJ_n6o`3ooo]Zool0m?nc0?oooo]Zool0ZRCooo]Z003koookJPCo0000K?oonfX00omW
0?oooo]ZoookJP0:oookJP03ool0GOoonf[ooo]Z00Kooo]Z00?oiOl0oookJ_oonfX00ooUo`03oook
JP03ooo90?oonf[oKP3o00Kooo]Z00?oj`3oo`3o2ooonfX01?oonfX00ol0SOoooo]ZoookJP04oook
JP05oonI0?oonf[ooo]ZoookJ_l0B?l02OoonfX01omPo`3ooel0oon@0?oo0:3ooo]Zooo90?nl0?l0
0_oonfX01?mbo`3o1P3ooeko0?oob@04oookJP03o`3Ooooo0>7oo`2k00;ooo]Z00_o^@3ooe_o0?oo
nf[ooo]Zooob0?n6o`3ooo]Zool0m?oonf[o/`3oool0ZP3ooookJQkooo]Z1?l0001]oookJP03ofL0
oooonf[ooo]Z00Wooo]Z00?oo`1MoookJ_oonfX01ooonfX00oo30?oooo]ZoookJP06oookJP03oiT0
oom^0?oooo]Z00Kooo]Z00?o0?l;oookJ_oonfX01?oonfX00ol0SOoooo]ZoookJP03oookJP05oonI
0?oonf[ooo]ZoookJ_l0B?l02OoonfX02?mPo`3ooel0oon@0?oo0:3ooo]Zool0Rooonf[o_03o0_oo
nfX00ombo`3o1P3oool09P04oookJP03o`3Ooooo0>7oo`2k00;ooo]Z00co^@3ooe_o0?oonf[ooo]Z
ooob0?oonf[oQ_l0oookJ_oo0?Co/`3ooookJ_oo0:XUoookJP00nooonfX4o`0006_ooo]Z00?oI`3o
oookJ_oonfX02_oonfX00ooo05gooo]ZoookJP07oookJP05onGo0?oonf[ooo]ZoookJ_oUo`000ooo
nfX00ooob@3ooo]Zofh0o`06oookJP03on/0ool0o`_ooo]Z00Cooo]Z00?o08gooookJ_oonfX01?oo
nfX01OooV@3ooo]ZoookJ_oonf[o04So00Wooo]Z00OoH?l0oomO0?ooT03oo`2PoookJ_oob@3o_03o
00;ooo]Z00CoL_l0o`H0oomNo`3oolT01?oonfX00ol0goooo`3Qool0^`02oookJP0=okT0oooonf[o
oo]ZoookJ_oolP3oQ_l0oookJ_oo0?Cooo]Zok<0oooo0:[ooo]Zo`3o4`3ooookJQgooo]Z1?l0001/
oookJP03ofL0oooonf[ooo]Z00Wooo]Z00?oo`1MoookJ_oonfX01ooonfX00oo30?oooo]ZoookJP06
oookJP03oiT0oom^0?oooo]Z00Kooo]Z00?o0?l;oookJ_oonfX01?oonfX00ol0SOoooo]ZoookJP03
oookJP05oonI0?oonf[ooo]ZoookJ_l0B?l02OoonfX02?mPo`3ooel0oon@0?oo0:3ooo]Zool0Rooo
nf[o_03o0_oonfX00ombo`3o1P3oool09P04oookJP03o`3Ooooo0>7oo`2k00;ooo]Z00ko^@3ooook
J_oonf[ooo]Zooob0?oonf[oQ_l0oookJ_oo0?Co/`3ooookJ_oo0:[ooo]Zo`3o4bCooo]Z003koook
JPGo0000J_oonfX00omW0?oooo]ZoookJP09oookJP03ool0GOoonf[ooo]Z00Oooo]Z00?oiOl0oook
J_oonfX01OoonfX00ooob@3ooo]Zofh0o`07oookJP03o`3o2ooonf[ooo]Z00?ooo]Z00?o08gooook
J_oonfX01?oonfX01OooV@3ooo]ZoookJ_oonf[o04So00Wooo]Z00OoH?l0oomO0?ooT03oo`2Poook
J_oob@3o_03o00;ooo]Z00CoL_l0o`H0oomNo`3oolT01?oonfX00ol0goooo`3Qool0^`02oookJP0=
okT0oooonf[ooo]ZoookJ_oolP3oQ_l0oookJ_oo0?Cooo]Zok<0oooo0:[ooo]Zo`3o4`3ooookJQko
oo]Z1Ol0001ZoookJP03ofL0oooonf[ooo]Z00Wooo]Z00?oo`1MoookJ_oonfX01ooonfX00oo30?oo
oo]ZoookJP06oookJP03oiT0oom^0?oooo]Z00Kooo]Z00?o0?l;oookJ_oonfX01?oonfX00ol0SOoo
oo]ZoookJP03oookJP05oonI0?oonf[ooo]ZoookJ_l0B?l02OoonfX02?mPo`3ooel0oon@0?oonf[o
o`2Pool0Rooonf[o_03o0_oonfX00ombo`3o1P3oool09P04oookJP03o`3Ooooo0>7oo`2k00;ooo]Z
00ko^@3ooookJ_oonf[ooo]Zooob0?oonf[oQ_l0oookJ_oo0?Co/`3ooookJ_oo0:[ooo]Zo`3o4bGo
oo]Z003koookJPCo0000J_oonfX00omW0?oooo]ZoookJP0:oookJP03ool0GOoonf[ooo]Z00Kooo]Z
00?oiOl0oookJ_oonfX01OoonfX00ooob@3ooo]Zofh0o`07oookJP03o`3o2ooonf[ooo]Z00?ooo]Z
00?o08gooookJ_oonfX01?oonfX01OooV@3ooo]ZoookJ_oonf[o04So00Wooo]Z00OoH?l0oomO0?oo
T03oo`2PoookJ_oob@3o_03o00;ooo]Z00CoL_l0o`H0oomNo`3oolT01?oonfX00ol0goooo`3Qool0
^`02oookJP0=okT0oooonf[ooo]ZoookJ_oolP3oQ_l0oookJ_oo0?Cooo]Zok<0oooo0:[ooo]Zo`3o
4`3ooookJQoooo]Z1?l0001ZoookJP03ofL0oooonf[ooo]Z00[ooo]Z00?oo`1MoookJ_oonfX01_oo
nfX00oo30?oooo]ZoookJP06oookJP03oiT0oom^0?oooo]Z00Kooo]Z00?o0?l;oookJ_oonfX01?oo
nfX00ol0SOoooo]ZoookJP03oookJP05oonI0?oonf[ooo]ZoookJ_l0B?l02OoonfX02?mPo`3ooel0
oon@0?oonf[oo`2Pool0Rooonf[o_03o0_oonfX00ombo`3o1P3oool09P04oookJP03o`3Ooooo0>7o
o`2k00;ooo]Z00ko^@3ooookJ_oonf[ooo]Zooob0?oonf[oQ_l0oookJ_oo0?Co/`3ooookJ_oo0:[o
oo]Zo`3o4bKooo]Z003koookJPCo0000JOoonfX00omW0?oooo]ZoookJP0:oookJP03ool0GOoonf[o
oo]Z00Kooo]Z00?oiOl0oookJ_oonfX01OoonfX00ooob@3ooo]Zofh0o`07oookJP03o`3o2ooonf[o
oo]Z00?ooo]Z00?o08gooookJ_oonfX01?oonfX01OooV@3ooo]ZoookJ_oonf[o04So00Wooo]Z00Oo
H?l0oomO0?ooT03oo`2PoookJ_oob@3o_03o00;ooo]Z00CoL_l0o`H0oomNo`3oolT01?oonfX00ol0
goooo`3Qool0^`02oookJP0=okT0oooonf[ooo]ZoookJ_oolP3oQ_l0oookJ_oo0?Cooo]Zok<0oooo
0:[ooo]Zo`3o4`3ooookJR3ooo]Z1?l0001YoookJP03ofL0oooonf[ooo]Z00[ooo]Z00?oo`1Moook
J_oonfX01_oonfX00oo30?oooo]ZoookJP06oookJP03oiT0oom^0?oooo]Z00Kooo]Z00?o0?l;oook
J_oonfX01?oonfX00ol0SOoooo]ZoookJP03oookJP05oonI0?oonf[ooo]ZoookJ_l0B?l02OoonfX0
2?mPo`3ooel0oon@0?oonf[oo`2Pool0Rooonf[o_03o0_oonfX00ombo`3o1P3oool09P04oookJP03
o`3Ooooo0>7oo`2k00;ooo]Z00ko^@3ooookJ_oonf[ooo]Zooob0?oonf[oQ_l0oookJ_oo0?Co/`3o
oookJ_oo0:[ooo]Zo`3o4bOooo]Z003koookJPCo0000J?oonfX00omW0?oooo]ZoookJP0:oookJP03
ool0GOoonf[ooo]Z00Kooo]Z00?oiOl0oookJ_oonfX01_oonfX00onI0?ooKP3ooookJP06oookJP03
o`3o2ooonf[ooo]Z00?ooo]Z00?o08gooookJ_oonfX01?oonfX01OooV@3ooo]ZoookJ_oonf[o04So
00Wooo]Z00OoH?l0oomO0?ooT03oo`2PoookJ_oob@3o_03o00;ooo]Z00CoL_l0o`H0oomNo`3oolT0
1?oonfX00ol0goooo`3Qool0^`02oookJP0=okT0oooonf[ooo]ZoookJ_oolP3oQ_l0oookJ_oo0?Co
oo]Zok<0oooo0:[ooo]Zo`3o4`3ooookJR7ooo]Z1?l0001YoookJP03ofL0oooonf[ooo]Z00Wooo]Z
00?oo`1MoookJ_oonfX01ooonfX00oo30?oooo]ZoookJP06oookJP03ofh0oooonf[ooo]Z00Gooo]Z
00?o0?l;oookJ_oonfX01?oonfX00ol0SOoooo]ZoookJP03oookJP05oonI0?oonf[ooo]ZoookJ_l0
B?l02OoonfX02?mPo`3ooel0oon@0?oonf[oo`2Pool0Rooonf[o_03o0_oonfX00ombo`3o1P3oool0
9P04oookJP03o`3Ooooo0>7oo`2k00;ooo]Z00[o^@3ooookJ_oonf[ooo]Zooob0?oonf[oQ_l0oook
J_oo0?Co/`3o0_oo0:X00ooonf[o0?lCoookJP0WoookJP00nooonfX4o`0006Sooo]Z00?oI`3ooook
J_oonfX02OoonfX00ooo05gooo]ZoookJP06oookJP03onGo0?oonf[ooo]Z00Kooo]Z00?oV@3oofh0
oooonfX01_oonfX00oo[0?oo0?l;oookJP03oookJP03o`2=oooonf[ooo]Z00Cooo]Z00GooiT0oook
J_oonf[ooo]Zo`18o`09oookJP07of3o0?ooG`3ooi00ool0X?oonf[oolT0ok`0o`02oookJP04og;o
0?l60?ooG_l0ooo900Cooo]Z00?o0=ooool0hOoo0;/00_oonfX03Oni0?oooo]ZoookJ_oonf[ooo80
ohKo0?oonf[oo`3doookJ_nc0?ooo`2ZoookJ_l0oa<00ooonfX2ohKo0?oooo]Z7OoonfX4o`0006So
oo]Z00?oI`3ooookJ_oonfX02OoonfX00ooo05gooo]ZoookJP07oookJP03ol<0oooonf[ooo]Z00Ko
oo]Z00?oKP3ooookJ_oonfX01_oonfX00ol0o`_ooo]ZoookJP03oookJP03o`2=oooonf[ooo]Z00?o
oo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`09oookJP08of3o0?ooG`3ooi00oookJ_oo0:3oo`2;oook
J_nl0?l2oookJP03og;o0?l60?ooo`0V00Cooo]Z00?o0=ooool0hOoo0;/00_oonfX02oni0?oooo]Z
oookJ_oonf[ooo80oookJ_n6o`3ooo]Zool0m?nc0?ooo`2Z00;ooo]Z00Co0?lCoookJ_oonf[ooo]Z
0_n6o`0ToookJP00nooonfX4o`0006Oooo]Z00?oI`3ooookJ_oonfX02OoonfX00ooo05gooo]Zoook
JP07oookJP03onGo0?oonf[ooo]Z00Gooo]Z00?oV@3ooookJ_m^0?l01_oonfX00oo[0?oo0?l;oook
JP03oookJP03o`2=oooonf[ooo]Z00Cooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`09oookJP07of3o
0?ooG`3ooi00ool0X?oonf[oolT0ok`0o`02oookJP04og;o0?l60?ooG_l0ooo900Cooo]Z00?o0=oo
ool0hOoo0;/00_oonfX03Oni0?oooo]ZoookJ_oonf[ooo80ohKo0?oonf[oo`3doookJ_nc0?ooo`2Z
oookJ_l0oa<00ooonfX00on6o`3ooo]ZoookJP3ooookJQgooo]Z1?l0001WoookJP03ofL0oooonf[o
oo]Z00Wooo]Z00?oo`1MoookJ_oonfX01ooonfX00oo30?oooo]ZoookJP06oookJP03oiT0oom^0?oo
oo]Z00Kooo]Z00?o0?l;oookJ_oonfX00ooonfX00ol0SOoooo]ZoookJP03oookJP05oonI0?oonf[o
oo]ZoookJ_l0B?l02OoonfX02?mPo`3ooel0oon@0?oonf[oo`2Pool0Rooonf[o_03o0_oonfX00omb
o`3o1P3oool09P04oookJP03o`3Ooooo0>7oo`2k00;ooo]Z00Go^@3ooookJ_oonf[ooo]Zooob0002
ohKo0004oookJ_oo0?Co/`3oool0ZP;ooo]Z00Go0?lCoookJ_oonf[ooo]ZohKo000VoookJP00nooo
nfX4o`0006Kooo]Z00?oI`3ooookJ_oonfX02OoonfX00ooo05gooo]ZoookJP07oookJP03onGo0?oo
nf[ooo]Z00Gooo]Z00?oV@3ooookJ_m^0?l01_oonfX00oo[0?oo0?l;oookJP04oookJP03o`2=oooo
nf[ooo]Z00?ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`09oookJP07of3o0?ooG`3ooi00ool0X?oo
nf[oolT0ok`0o`02oookJP04og;o0?l60?ooG_l0ooo900Cooo]Z00?o0=ooool0hOoo0;/00_oonfX0
0oni0?oooo]ZoookJP02ooo90008ohKo0?oonf[oo`3doookJ_nc0?ooo`2ZoookJ_l0oa<3oookJP03
ohKo0?oonf[ooo]Z0?oooo]Z7_oonfX4o`0006Kooo]Z00?oI`3ooookJ_oonfX02OoonfX00ooo05go
oo]ZoookJP07oookJP03ol<0oooonf[ooo]Z00Kooo]Z00?oV@3oofh0oooonfX01_oonfX00ol0o`_o
oo]ZoookJP04oookJP03o`2=oooonf[ooo]Z00;ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`09oook
JP08of3o0?ooG`3ooi00oookJ_oo0:3oo`2;oookJ_nl0?l2oookJP03og;o0?l60?ooo`0V00Cooo]Z
00?o0=ooool0hOoo0;/00_oonfX01_ni0?oooo]ZoookJ_oonf[ooo80ohKo00;ooo]Z00?oo`3dok<0
oooo0:X00_oonfX01Ol0oa?ooo]ZoookJ_oonf[oQ_l002Oooo]Z003koookJPCo0000IOoonfX00omW
0?oooo]ZoookJP09oookJP03ool0GOoonf[ooo]Z00Oooo]Z00?oiOl0oookJ_oonfX01OoonfX00onI
0?oooo]Zofh0o`06oookJP03on/0ool0o`_ooo]Z00Cooo]Z00?o08gooookJ_oonfX00ooonfX01Ooo
V@3ooo]ZoookJ_oonf[o04So00[ooo]Z00Kooel0oon@0?oo0:3ooo]Zooo90?nl0?l2oookJP04og;o
0?l60?ooG_l0ooo900Cooo]Z00?o0=ooool0hOoo0;/00_oonfX00oni0?oooo]ZoookJP03ooo90007
oookJ_oo0?Cooo]Zok<0oooo0:[ooo]Zo`3o4`03oookJP03ohKo0?oonf[ooo]Z0?oooo]Z7ooonfX4
o`0006Gooo]Z00?oI`3ooookJ_oonfX02OoonfX00ooo05gooo]ZoookJP07oookJP03ol<0oooonf[o
oo]Z00Kooo]Z00?oV@3oofh0oooonfX01_oonfX00ol0o`_ooo]ZoookJP04oookJP03o`2=oooonf[o
oo]Z00;ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`0:oookJP07oomO0?ooT03ooo]Zool0X?oo08_o
oo]Zok`0o`02oookJP03og;o0?l60?ooo`0V00Cooo]Z00?o0=ooool0hOoo0;/00_oonfX01oni0?oo
oo]ZoookJ_oonf[ooo80ohKo0?oonfX00_oo0?@01Onc0?ooo`2ZoookJ_oonf[o0?lC00?ooo]Z00?o
Q_l0oookJ_oonfX09_oonfX00?_ooo]Z1?l0001ToookJP03ofL0oooonf[ooo]Z00Sooo]Z0_oob@09
oookJP03onGo0?oonf[ooo]Z00Gooo]Z00?oV@3ooookJ_m^0?l01_oonfX00oo[0?oo0?l;oookJP04
oookJP03o`2=oooonf[ooo]Z00?ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`0:oookJP06oomO0?oo
T03oo`2PoookJ_oob@3o_03o0_oonfX01?mbo`3o1P3ooeko0?oob@04oookJP03o`3Ooooo0>7oo`2k
00;ooo]Z00?o^@3ooookJ_oob@000ooob@001ooonf[oo`3doookJ_nc0?ooo`2ZoookJ_l0oa<00ooo
nfX00on6o`3ooo]ZoookJP3ooookJR3ooo]Z1?l0001ToookJP03ofL0oooonf[ooo]Z00Wooo]Z00?o
o`1MoookJ_oonfX01ooonfX00oo30?oooo]ZoookJP06oookJP03oiT0oom^0?oooo]Z00Kooo]Z00?o
0?l;oookJ_oonfX01?oonfX00ol0SOoooo]ZoookJP02oookJP05oonI0?oonf[ooo]ZoookJ_l0B?l0
2_oonfX01oooG`3ooi00oookJ_oo0:3oo`2;oookJ_nl0?l00_oonfX00ombo`3o1P3oool09P04oook
JP03o`3Ooooo0>7oo`2k00;ooo]Z00_o^@3ooookJ_oonf[ooo]Zooob0?n6o`3ooo]Zool0m?oonf[o
/`3oool0ZP02oookJP05o`3o4ooonf[ooo]ZoookJ_n6o`00:OoonfX00?_ooo]Z1?l0001ToookJP03
ofL0oooonf[ooo]Z00Oooo]Z0ooob@08oookJP03onGo0?oonf[ooo]Z00Gooo]Z00?oV@3ooookJ_m^
0?l01_oonfX00oo[0?oo0?l;oookJP04oookJP03o`2=oooonf[ooo]Z00?ooo]Z00GooiT0oookJ_oo
nf[ooo]Zo`18o`0:oookJP06oomO0?ooT03oo`2PoookJ_oob@3o_03o0_oonfX01?mbo`3o1P3ooeko
0?oob@04oookJP03o`3Ooooo0>7oo`2k00;ooo]Z00?o^@3oooo90?oob@000ooob@001ooonf[oo`3d
oookJ_nc0?ooo`2ZoookJ_l0oa<00ooonfX00on6o`3ooo]ZoookJP3ooookJR7ooo]Z1?l0001Toook
JP03ofL0oooonf[ooo]Z00Wooo]Z00?oo`1MoookJ_oonfX01_oonfX00oo30?oooo]ZoookJP06oook
JP03oiT0oom^0?oooo]Z00Kooo]Z00?o0?l;oookJ_oonfX01?oonfX00ol0SOoooo]ZoookJP02oook
JP05oonI0?oonf[ooo]ZoookJ_l0B?l02_oonfX01oooG`3ooi00oookJ_oo0:3oo`2;oookJ_nl0?l0
0_oonfX00ombo`3o1P3oool09P04oookJP03o`3Ooooo0>7oo`2k00;ooo]Z00_o^@3ooookJ_oonf[o
oo]Zooob0?n6o`3ooo]Zool0m?oonf[o/`3oool0ZP02oookJP05o`3o4ooonf[ooo]ZoookJ_n6o`00
:_oonfX00?_ooo]Z1?l0001SoookJP03ofL0oooonf[ooo]Z00Oooo]Z0ooob@08oookJP03onGo0?oo
nf[ooo]Z00Gooo]Z00?oV@3ooookJ_m^0?l01_oonfX00oo[0?oo0?l;oookJP04oookJP03o`2=oooo
nf[ooo]Z00?ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`0:oookJP06oomO0?ooT03oo`2PoookJ_oo
b@3o_03o0_oonfX01?mbo`3o1P3ooeko0?oob@04oookJP03o`3Ooooo0>7oo`2k00;ooo]Z00?o^@3o
ooo90?oob@001?oob@001_oo0?Co/`3ook<0oooo0:[ooo]Zo`3o4`?ooo]Z00?oQ_l0oookJ_oonfX0
oooonfXRoookJPCo0000HooonfX00omW0?oooo]ZoookJP09oookJP03ool0GOoonf[ooo]Z00Kooo]Z
00?o``3ooookJ_oonfX01_oonfX00onI0?ooKP3ooookJP06oookJP03o`3o2ooonf[ooo]Z00Cooo]Z
00?o08gooookJ_oonfX00_oonfX01OooV@3ooo]ZoookJ_oonf[o04So00[ooo]Z00Oooel0oon@0?oo
nf[oo`2Pool0Rooonf[o_03o00;ooo]Z00?oL_l0o`H0oooo02H01?oonfX00ol0goooo`3Qool0^`02
oookJP08okT0oooonf[ooo]ZoookJ_oolP3oQ_l0oookJ_oo0?@2ok<0o`04ool0Z_oonf[ooo]Zo`3o
4`?ooo]Z00?oQ_l0oookJ_oonfX0:OoonfX00?_ooo]Z1?l0001RoookJP03ofL0oooonf[ooo]Z00Ko
oo]Z1Ooob@08oookJP03ol<0oooonf[ooo]Z00Gooo]Z00?oV@3oofh0oooonfX01OoonfX00oo[0?oo
0?l;oookJP04oookJP03o`2=oooonf[ooo]Z00?ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`0:oook
JP06oomO0?ooT03oo`2PoookJ_oob@3o_03o0_oonfX01?mbo`3o1P3ooeko0?oob@04oookJP03o`3O
oooo0;_oo`2k00;ooo]Z00?o^@3oooo90?oob@001?oob@001_oo0?Co/`3ooookJ_oo0:[ooo]Zo`3o
4`?ooo]Z00?oQ_l0oookJ_oonfX01?oonfX2o`01oooooo]Z7OoonfX4o`0006;ooo]Z00?oI`3ooook
J_oonfX02OoonfX00ooo05gooo]ZoookJP07oookJP03ol<0oooonf[ooo]Z00Gooo]Z00?oV@3oofh0
oooonfX01_oonfX00ol0o`_ooo]ZoookJP04oookJP03o`2=oooonf[ooo]Z00?ooo]Z00CooiT0oook
J_oonf[o04So2_oonfX01oooG`3ooi00oookJ_oo0:3oo`2;oookJ_nl0?l00_oonfX00ombo`3o1P3o
ool09P04oookJP03o`3Ooooo0>7oo`2k00;ooo]Z00_o^@3ooookJ_oonf[ooo]Zooob0?n6o`3ooo]Z
ool0m?nc0?oooo]Zool0ZP02oookJP05o`3o4ooonf[ooo]ZoookJ_n6o`001_oonfX2o`01obCooo]Z
003koookJPCo0000HOoonfX00omW0?oooo]ZoookJP06oookJPGoolT02?oonfX00oo30?oooo]Zoook
JP05oookJP03oiT0oom^0?oooo]Z00Gooo]Z00?oj`3oo`3o2ooonfX01?oonfX00ol0SOoooo]Zoook
JP03oookJP03oonI0?oonf[ooo]Z00;ooo]Z00?o04SooookJ_oonfX01ooonfX03?ooG`3ooi00ool0
X?oonf[oolT0oookJ_nl0?oooo]Zog;o0?l60?ooG_l0ooo900Cooo]Z00Ko0=ooool0^ooonf[ooo]Z
ooo90?ni0?l7ooo90005ok<0oooonf[oo`2ZoookJ_l0oa<00ooonfX00on6o`3ooo]ZoookJP04oook
JP03o`01oooonf[ooo]Z0?oooo]Z7OoonfX4o`00067ooo]Z00?oI`3ooookJ_oonfX02OoonfX00ooo
05gooo]ZoookJP07oookJP03ol<0oooonf[ooo]Z00Gooo]Z00?oV@3oofh0oooonfX01_oonfX00ol0
o`_ooo]ZoookJP04oookJP03o`2=oooonf[ooo]Z00?ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`09
oookJP05oomO0?ooT03ooo]Zool0X?oo08/00_oonfX01Onl0?oooo]Zog;o0?l60?ooo`0V00Cooo]Z
00?o0=ooool0hOoo0;/00_oonfX02oni0?oooo]ZoookJ_oonf[ooo80ohKo0?oonf[oo`3dok<0oooo
nf[oo`2Z00;ooo]Z00Go0?lCoookJ_oonf[ooo]ZohKo0006oookJP03o`01oooonf[ooo]Z02Cooo]Z
003koookJPCo0000H?oonfX00omW0?oooo]ZoookJP06oookJPKoolT01ooonfX00oo30?oooo]Zoook
JP05oookJP03oiT0oooonf[oKP3o00Kooo]Z00?o0?l;oookJ_oonfX00ooonfX00ol0SOoooo]Zoook
JP03oookJP03oonI0?oonf[ooo]Z00;ooo]Z00?o04SooookJ_oonfX01ooonfX03?ooG`3ooi00ool0
X?oonf[oo`2;oookJ_nl0?oooo]Zog;o0?l60?ooG_l0ool09PCooo]Z00Ko0=ooool0^ooonf[ooo]Z
ooo90?ni0?l7ooo90005ok<0oooonf[oo`2ZoookJ_l0oa<00ooonfX00on6o`3ooo]ZoookJP04oook
JP03o`01oooonf[ooo]Z0?oooo]Z7_oonfX4o`00063ooo]Z00?oI`3ooookJ_oonfX02OoonfX00ooo
05gooo]ZoookJP07oookJP03ol<0oooonf[ooo]Z00Gooo]Z00?oV@3ooookJ_m^0?l01_oonfX00ol0
o`_oj`3ooookJP04oookJP03o`2=oooonf[ooo]Z00?ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`09
oookJP0=oomO0?ooT03ooo]Zool0X?oonf[oo`2;oookJ_nl0?oooo]Zog;o0?l60?ooG_l0ool09P03
oookJP03o`3Ooooo0>7oo`2k00;ooo]Z00_o^@3ooookJ_oonf[ooo]Zooob0?n6o`3ooo]Zool0m?nc
0?oooo]Zool0ZP02oookJP05o`3o4ooonf[ooo]ZoookJ_n6o`001_oonfX00ol00Ooooo]ZoookJP0U
oookJP00nooonfX4o`00063ooo]Z00?oI`3ooookJ_oonfX01?oonfX7ooo900Oooo]Z00?o``3ooook
J_oonfX01OoonfX00onI0?oooo]Zofh0o`06oookJP03o`3o2ooonf[ooo]Z00?ooo]Z00?o08gooook
J_oonfX00ooonfX00oooV@3ooo]ZoookJP02oookJP03o`18oooonf[ooo]Z00Oooo]Z00cooel0oon@
0?oonf[oo`2Pool0Rooonf[o_03ooookJ_mbo`3o1P3ooeko0?oo02H4oookJP06o`3Ooooo0;_ooo]Z
oookJ_oob@3o^@3o1ooob@001Onc0?oooo]Zool0Z_oonf[o0?lC00?ooo]Z00?oQ_l0oookJ_oonfX0
1?oonfX01Ol00Ooooo]ZoookJ_oonf[o;`3o0?oooo]Z7OoonfX4o`00063ooo]Z00?oI`3ooookJ_oo
nfX02OoonfX00ooo05gooo]ZoookJP06oookJP03ol<0oooonf[ooo]Z00Gooo]Z00?oV@3ooookJ_m^
0?l01_oonfX00ol0o`_oj`3ooookJP04oookJP03o`2=oooonf[ooo]Z00?ooo]Z00GooiT0oookJ_oo
nf[ooo]Zo`18o`09oookJP0=oomO0?ooT03ooo]Zool0X?oonf[oo`2;oookJ_nl0?oooo]Zog;o0?l6
0?ooG_l0ool09P03oookJP03o`3Ooooo0>7oo`2k00;ooo]Z00_o^@3ooookJ_oonf[ooo]Zooob0?n6
o`3ooo]Zool0m?nc0?oooo]Zool0ZP02oookJP05o`3o4ooonf[ooo]ZoookJ_n6o`001_oonfX00ol0
0Ooooo]ZoookJP02obl0obCooo]Z003koookJPCo0000GooonfX00omW0?oooo]ZoookJP04oookJPSo
olT01_oonfX00oo30?oooo]ZoookJP05oookJP03oiT0oooonf[oKP3o00Kooo]Z00?o0?l;oookJ_oo
nfX00ooonfX00ol0SOoooo]ZoookJP03oookJP03oonI0?oonf[ooo]Z00;ooo]Z00?o04SooookJ_oo
nfX01ooonfX03?ooG`3ooi00oookJ_oo0:3oo`2;oookJ_nl0?oooo]Zog;o0?l60?ooG_l0ool09PCo
oo]Z00?o0=ooool0^ooonfX00_oonfX00oni0?ooolT0ooo90005ooo90005ok<0oooonf[oo`2Zoook
J_l0oa<00ooonfX00on6o`3ooo]ZoookJP04oookJP06o`01oooonf[ooo]ZoookJ_l_0?oool00oooo
nfXMoookJPCo0000GooonfX00omW0?oooo]ZoookJP09oookJP03ool0GOoonf[ooo]Z00Kooo]Z00?o
``3ooookJ_oonfX01_oonfX00onI0?ooKP3ooookJP05oookJP03o`3o2oo[0?oooo]Z00Cooo]Z00?o
08gooookJ_oonfX00ooonfX01OooV@3ooo]ZoookJ_oonf[o04So00Wooo]Z00gooel0oon@0?oonf[o
o`2PoookJ_oo08_ooo]Zok`0oooonf[oL_l0o`H0oomNo`3oo`0V00?ooo]Z00?o0=ooool0hOoo0;/0
0_oonfX02oni0?oooo]ZoookJ_oonf[ooo80ohKo0?oonf[oo`3dok<0oooonf[oo`2Z00;ooo]Z00Go
0?lCoookJ_oonf[ooo]ZohKo0006oookJP04o`01oooonf[ooo]Zobl0o`;ool009?oonfX00?_ooo]Z
1?l0001NoookJP03ofL0oooonf[ooo]Z00Cooo]Z2?oob@06oookJP03ol<0oooonf[ooo]Z00Gooo]Z
00?oV@3ooookJ_m^0?l01_oonfX00ol0o`_ooo]ZoookJP03oookJP03o`2=oooonf[ooo]Z00?ooo]Z
00?ooiT0oookJ_oonfX00_oonfX00ol0B?oooo]ZoookJP07oookJP0<oomO0?ooT03ooo]Zool0X?oo
08_ooo]Zok`0oooonf[oL_l0o`H0oomNo`3oo`0V1?oonfX00ol0goooo`2koookJP02oookJP03okT0
oooonf[ooo]Z00GoolT000Go/`3ooookJ_oo0:[ooo]Zo`3o4`03oookJP03ohKo0?oonf[ooo]Z00Co
oo]Z00Ko007ooookJ_oonf[ooo]Zobl0oooo`03ooookJQkooo]Z1?l0001NoookJP03ofL0oooonf[o
oo]Z00Wooo]Z00?oo`1MoookJ_oonfX01_oonfX00oo30?oooo]ZoookJP06oookJP03oiT0oom^0?oo
oo]Z00Kooo]Z00?o0?l;oookJ_oonfX00ooonfX00ol0SOoooo]ZoookJP03oookJP05oonI0?oonf[o
oo]ZoookJ_l0B?l02OoonfX03OooG`3ooi00oookJ_oo0:3ooo]Zool0Rooonf[o_03ooookJ_mbo`3o
1P3ooeko0?oo02H00ooonfX00ol0goooo`3Qool0^`02oookJP0;okT0oooonf[ooo]ZoookJ_oolP3o
Q_l0oookJ_oo0?Co/`3ooookJ_oo0:X00_oonfX01Ol0oa?ooo]ZoookJ_oonf[oQ_l000Kooo]Z00Go
007ooookJ_oonf[o;`3oooo0000VoookJP00nooonfX4o`0005gooo]Z00?oI`3ooookJ_oonfX01?oo
nfX9ooo900Gooo]Z00?o``3ooookJ_oonfX01OoonfX00onI0?oooo]Zofh0o`06oookJP03o`3o2ooo
nf[ooo]Z00?ooo]Z00?o08gooookJ_oonfX00ooonfX00oooV@3ooo]ZoookJP02oookJP03o`18oooo
nf[ooo]Z00Oooo]Z00cooel0oon@0?oonf[oo`2Pool0Rooonf[o_03ooookJ_mbo`3ooo]Zoeko0?oo
02H4oookJP03o`3Ooooo0;_ooo]Z00;ooo]Z00Co^@3ooookJ_oonf[ooo]Z1?oob@001Onc0?ooolT0
ool0Z_oonf[o0?lC00?ooo]Z00?oQ_l0oookJ_oonfX01?oonfX02?l00Ooooo]ZoookJ_oonf[o;`3o
ooo00?oonf[oiOl0oooonfXMoookJPCo0000GOoonfX00omW0?oooo]ZoookJP09oookJP03ool0GOoo
nf[ooo]Z00Kooo]Z00?o``3ooookJ_oonfX01_oonfX00onI0?ooKP3ooookJP06oookJP03o`3o2ooo
nf[ooo]Z00?ooo]Z00?o08gooookJ_oonfX00ooonfX01OooV@3ooo]ZoookJ_oonf[o04So00Wooo]Z
00gooel0oon@0?oonf[oo`2PoookJ_oo08_ooo]Zok`0oooonf[oL_l0oookJ_mNo`3oo`0V00?ooo]Z
00?o0=ooool0hOoo0;/00_oonfX02oni0?oooo]ZoookJ_oonf[ooo80ohKo0?oonf[oo`3dok<0oooo
nf[oo`2Z00;ooo]Z00Go0?lCoookJ_oonf[ooo]ZohKo0006oookJP06o`01oooonf[ooo]Zobl0oooo
`03ooo]Z0_l0ojHToookJP00nooonfX5o`0005_ooo]Z00?oI`3ooookJ_oonfX01_oonfX7ooo900Ko
oo]Z00?o``3ooookJ_oonfX01OoonfX00onI0?ooKP3ooookJP05oookJP03o`3o2ooonf[ooo]Z00Co
oo]Z00?o08gooookJ_oonfX00_oonfX00oooV@3ooo]ZoookJP02oookJP03o`18oooonf[ooo]Z00Oo
oo]Z00cooel0oon@0?oonf[oo`2Pool0Rooonf[o_03ooookJ_mbo`3ooo]Zo`H0oooo02H4oookJP03
o`3Ooooo0;_ooo]Z00;ooo]Z00go^@3ooookJ_oonf[ooo]Zooo90?n6o`3ooo]Zooo90?nc0?ooolT0
ool0Z_oonf[o0?lC00?ooo]Z00?oQ_l0oookJ_oonfX01?oonfX02Ol00Ooooo]ZoookJ_oonf[o;`3o
ooo00?oonf[oiOl0ooo9003ooookJQgooo]Z1Ol0001KoookJP03ofL0oooonf[ooo]Z00Wooo]Z00?o
o`1MoookJ_oonfX01ooonfX00oo30?oooo]ZoookJP05oookJP03oiT0oom^0?oooo]Z00Kooo]Z00?o
0?l;oookJ_oonfX01?oonfX00ol0SOoooo]ZoookJP02oookJP05oonI0?oonf[ooo]ZoookJ_l0B?l0
2OoonfX03OooG`3ooi00oookJ_oo0:3ooo]Zool0Rooonf[o_03ooookJ_mbo`3ooo]Zoeko0?oo02H0
0ooonfX00ol0goooo`3Qool0^`02oookJP0;okT0oooonf[ooo]ZoookJ_oolP3oQ_l0oookJ_oo0?Co
/`3ooookJ_oo0:X00_oonfX01Ol0oa?ooo]ZoookJ_oonf[oQ_l000Kooo]Z00Oo007ooookJ_oonf[o
;`3oooo00?oonf[o0?nV00;oC`3o9?oonfX00?_ooo]Z1?l0001LoookJP03ofL0oooonf[ooo]Z00Oo
oo]Z1_oob@05oookJP03ol<0oooonf[ooo]Z00Gooo]Z00?oV@3oofh0oooonfX01OoonfX00ol0o`_o
oo]ZoookJP04oookJP03o`2=oooonf[ooo]Z00;ooo]Z00?ooiT0oookJ_oonfX00_oonfX00ol0B?oo
oo]ZoookJP07oookJP0<oomO0?ooT03ooo]Zool0X?oo08_ooo]Zok`0oooonf[oL_l0oookJ_l60?oo
o`0V1?oonfX00ol0goooo`2koookJP02oookJP0=okT0oooonf[ooo]ZoookJ_oob@3oQ_l0oookJ_oo
0?Co/`3oooo90?oo0:[ooo]Zo`3o4`03oookJP03ohKo0?oonf[ooo]Z00Cooo]Z00Wo007ooookJ_oo
nf[ooo]Zobl0oooo`03ooo]ZonGo0?oob@00oooonfXNoookJPCo0000G?oonfX00omW0?oooo]Zoook
JP08oookJP03ool0GOoonf[ooo]Z00Oooo]Z00?o``3ooookJ_oonfX01OoonfX00onI0?ooKP3ooook
JP06oookJP03o`3o2ooonf[ooo]Z00Cooo]Z00?o08gooookJ_oonfX00_oonfX01OooV@3ooo]Zoook
J_oonf[o04So00Wooo]Z00gooel0oon@0?oonf[oo`2PoookJ_oo08_ooo]Zok`0oooonf[oL_l0oook
J_mNo`3oo`0V00?ooo]Z00?o0=oooookJ_oo0;/00_oonfX02oni0?oooo]ZoookJ_oonf[ooo80ohKo
0?oonf[oo`3dok<0oooonf[oo`2Z00;ooo]Z00Go0?lCoookJ_oonf[ooo]ZohKo0006oookJP08o`01
oooonf[ooo]Zobl0oooo`03ooo]Zo`3oY_m?0?lVoookJP00nooonfX4o`0005_ooo]Z00?oI`3ooook
J_oonfX02OoonfX4ooo900Gooo]Z00?o``3ooookJ_oonfX01OoonfX2ooo900Kooo]Z00?o0?l;oook
J_oonfX01?oonfX00ol0SOoooo]ZoookJP02oookJP03oonI0?oonf[ooo]Z00;ooo]Z00?o04Sooook
J_oonfX01ooonfX03?ooG`3ooi00oookJ_oo0:3oo`2;oookJ_nl0?oooo]Zog;o0?oonf[o1P3oool0
9PCooo]Z00?o0=ooool0^ooonfX00_oonfX03Oni0?oooo]ZoookJ_oonf[oolT0ohKo0?oonf[oo`3d
ok<0oooonf[oo`2ZoookJ_l0oa<00ooonfX00on6o`3ooo]ZoookJP04oookJP09o`01oooonf[ooo]Z
oookJ_l_0?oool00oookJ_oUo`3oolT00?oooo]Z7ooonfX4o`0005_ooo]Z00?oI`3ooookJ_oonfX0
2OoonfX00ooo05gooo]ZoookJP06oookJP03ol<0oooonf[ooo]Z00Gooo]Z00?oV@3oofh0oooonfX0
1_oonfX00ol0o`_ooo]ZoookJP04oookJP03o`2=oooonf[ooo]Z00;ooo]Z00GooiT0oookJ_oonf[o
oo]Zo`18o`09oookJP0=oomO0?ooT03ooo]Zool0X?oonf[oo`2;oookJ_nl0?oooo]Zog;o0?oonf[o
G_l0ool09P03oookJP03o`3Ooooonf[oo`2k00;ooo]Z00_o^@3ooookJ_oonf[ooo]Zooob0?n6o`3o
oo]Zool0m?nc0?oooo]Zool0ZP02oookJP05o`3o4ooonf[ooo]ZoookJ_n6o`001_oonfX02?l00Ooo
oo]ZoookJ_l_0?oool00oookJ_l0ojKoC`3o9ooonfX00?_ooo]Z1?l0001JoookJP03ofL0oooonf[o
oo]Z00Wooo]Z00?oolT0oookJ_oob@000_oob@04oookJP03ol<0oooonf[ooo]Z00Gooo]Z0ooob@05
oookJP03o`3o2ooonf[ooo]Z00Cooo]Z00?o08gooookJ_oonfX00_oonfX00oooV@3ooo]ZoookJP02
oookJP03o`18oooonf[ooo]Z00Oooo]Z00cooel0oon@0?oonf[oo`2Pool0Rooonf[o_03ooookJ_mb
o`3ooo]Zo`H0oooo02H4oookJP03o`3Ooooo0;_ooo]Z00;ooo]Z00go^@3ooookJ_oonf[ooo]Zooo9
0?n6o`3ooo]Zool0m?nc0?oooo]Zool0Z_oonf[o0?lC00;ooo]Z0_n6o`06oookJP09o`01oooonf[o
oo]Zo`1lool_0?oool00oookJ_oUo`3oolT00?oooo]Z8?oonfX4o`0005[ooo]Z00?oI`3ooookJ_oo
nfX02OoonfX00ooo05gooo]ZoookJP06oookJP03ol<0oooonf[ooo]Z00Gooo]Z00?oV@3ooookJ_m^
0?l01_oonfX00ol0o`_ooo]ZoookJP04oookJP03o`2=oooonf[ooo]Z00;ooo]Z00GooiT0oookJ_oo
nf[ooo]Zo`18o`09oookJP0=oomO0?ooT03ooo]Zool0X?oonf[oo`2;oookJ_nl0?oooo]Zog;o0?oo
nf[oG_l0ool09P03oookJP03o`3Ooooonf[oo`2k00;ooo]Z00_o^@3ooookJ_oonf[ooo]Zooob0?n6
o`3ooo]Zool0m?nc0?oooo]Zool0ZP02oookJP03o`3o4ooonf[ooo]Z00;oQ_l01_oonfX02?l00Ooo
oo]Zo`1lool_0?oool00oookJ_l0ojKoC`3o:?oonfX00?_ooo]Z1?l0001IoookJP03ofL0oooonf[o
oo]Z00Wooo]Z00GoolT0oookJ_oonf[ooo]Zooo90004oookJP03ol<0oooonf[ooo]Z00Cooo]Z1?oo
b@05oookJP03o`3o2ooonf[ooo]Z00Cooo]Z00?o08gooookJ_oonfX00_oonfX00oooV@3ooo]Zoook
JP02oookJP03o`18oooonf[ooo]Z00Oooo]Z00cooel0oon@0?oonf[oo`2Pool0Rooonf[o_03ooook
J_mbo`3ooo]Zo`H0oooo02H4oookJP04o`3Ooooo0;_ooo]ZoookJP;o^@3o0ooonfX02Ooob@3oQ_l0
oookJ_oo0?Co/`3ooookJ_oo0:[ooo]Zo`3o4`02oookJP03ohKo0?oonf[ooo]Z00Gooo]Z00Wo007o
oookJ_oonf[o07coobl0oooo`03ooo]ZonGo0?oob@00oooonfXQoookJPCo0000FOoonfX00omW0?oo
oo]ZoookJP09oookJP03ool0GOoonf[ooo]Z00Kooo]Z00?o``3ooookJ_oonfX01OoonfX00onI0?oo
oo]Zofh0o`06oookJP03o`3o2ooonf[ooo]Z00Cooo]Z00?o08gooookJ_oonfX00_oonfX01OooV@3o
oo]ZoookJ_oonf[o04So00Wooo]Z00gooel0oon@0?oonf[oo`2PoookJ_oo08_ooo]Zok`0oooonf[o
L_l0oookJ_mNo`3oo`0V00?ooo]Z00?o0=oooookJ_oo0;/00_oonfX02oni0?oooo]ZoookJ_oonf[o
oo80ohKo0?oonf[oo`3dok<0oooonf[oo`2Z00;ooo]Z00Co0?lCoookJ_oonf[oQ_l01ooonfX02?l0
0Ooooo]Zo`1lool_0?oool00oookJ_l0ojKoC`3o:OoonfX00?_ooo]Z1?l0001HoookJP03ofL0oooo
nf[ooo]Z00Wooo]Z00?oolT0oookJ_oonfX01_oonfX00oo30?oooo]ZoookJP03oookJPKoolT01?oo
nfX00ol0o`_ooo]ZoookJP04oookJP03o`2=oooonf[ooo]Z00?ooo]Z00GooiT0oookJ_oonf[ooo]Z
o`18o`09oookJP0<oomO0?ooT03ooo]Zool0X?oo08_ooo]Zok`0oooonf[oL_l0oookJ_l60?ooo`0V
1?oonfX01_l0goooo`2koookJ_oonf[o^@3ooe_o00?ooo]Z00WoolT0ohKo0?oonf[oo`3dok<0oooo
nf[oo`2ZoookJ_l0oa<00_oonfX00on6o`3ooo]ZoookJP05oookJP09o`01oooonf[ooo]Zo`1lool_
0?oool00oookJ_oUo`3oolT000?ooo]Z00?oo`2<oomo0?oonfX0oooonfXLoookJPCo0000F?oonfX0
0omW0?oooo]ZoookJP09oookJP03ool0GOoonf[ooo]Z00Kooo]Z00?o``3ooookJ_oonfX01OoonfX0
0onI0?oooo]Zofh0o`06oookJP03o`3o2ooonf[ooo]Z00Cooo]Z00?o08gooookJ_oonfX00ooonfX0
1?ooV@3ooo]ZoookJ_l0B?l9oookJP0=oomO0?ooT03ooo]Zool0X?oonf[oo`2;oookJ_nl0?oooo]Z
og;o0?oonf[oG_l0ool09P03oookJP03o`3Ooooonf[oo`2k00;ooo]Z00_o^@3ooookJ_oonf[ooo]Z
ooob0?n6o`3ooo]Zool0m?nc0?oooo]Zool0ZP02oookJP04o`3o4ooonf[ooo]ZohKo00Oooo]Z00So
007ooookJ_l0O?oo;`3oooo00?oonf[o0?nVodl0o`Cooo]Z0_ooO`0ToookJP00nooonfX4o`0005So
oo]Z00?oI`3ooookJ_oonfX02?oonfX00ooob@3ooo]ZoookJP06oookJP03ol<0oooonf[ooo]Z00?o
oo]Z1_oob@04oookJP03o`3o2oo[0?oooo]Z00Cooo]Z00?o08gooookJ_oonfX00ooonfX01OooV@3o
oo]ZoookJ_oonf[o04So00Wooo]Z00cooel0oon@0?oonf[oo`2Pool0Rooonf[o_03ooookJ_mbo`3o
oo]Zo`H0oooo02H4oookJP06o`3Ooooo0;_ooo]ZoookJ_ni0?ooFol00ooonfX02Ooob@3oQ_l0oook
J_oo0?Co/`3ooookJ_oo0:[ooo]Zo`3o4`02oookJP03ohKo0?oonf[ooo]Z00Gooo]Z00Wo007ooook
J_oonf[o07coobl0oooo`03ooo]ZonGo0?oob@000ooonfX00ooo08coogl0oookJP3ooookJQgooo]Z
1?l0001HoookJP03ofL0oooonf[ooo]Z00Sooo]Z00?oo`1MoookJ_oonfX01_oonfX00oo30?oooo]Z
oookJP05oookJP03oiT0oooonf[oKP3o00Kooo]Z00?o0?l;on/0oooonfX01?oonfX00ol0SOoooo]Z
oookJP03oookJP04oonI0?oonf[ooo]Zo`18o`Wooo]Z00gooel0oon@0?oonf[oo`2PoookJ_oo08_o
oo]Zok`0oooonf[oL_l0oookJ_mNo`3oo`0V00?ooo]Z00?o0=oooookJ_oo0;/00_oonfX02oni0?oo
oo]ZoookJ_oonf[ooo80ohKo0?oonf[oo`3dok<0oooonf[oo`2Z00;ooo]Z00Co0?lCoookJ_oonf[o
Q_l01ooonfX02?l00Ooooo]Zo`1lool_0?oool00oookJ_l0ojKoC`3o1?oonfX00oooO`3ooo]Zoook
JP0ToookJP00nooonfX4o`0005Oooo]Z00?oI`3ooookJ_oonfX02OoonfX00ooob@3ooo]ZoookJP06
oookJP04ol<0oooonf[ooo]ZoookJPSoolT00ooonfX00ol0o`_oj`3ooookJP04oookJP03o`2=oooo
nf[ooo]Z00?ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`09oookJP0<oomO0?ooT03ooo]Zool0X?oo
08_ooo]Zok`0oooonf[oL_l0oookJ_l60?ooo`0V1?oonfX01_l0goooo`2koookJ_oonf[o^@3ooe_o
00?ooo]Z00WoolT0ohKo0?oonf[oo`3dok<0oooonf[oo`2ZoookJ_l0oa<00_oonfX00on6o`3ooo]Z
oookJP04oookJP;o007o0_oonfX01_l0O?oo;`3oooo00?oonf[oiOl0ooo900?ooo]Z0_ooO`02o`80
oooooo]Z7OoonfX4o`0005Oooo]Z00?oI`3ooookJ_oonfX02OoonfX00ooo05gooo]ZoookJP06oook
JP03ol<0oooonf[ooo]Z00Cooo]Z00?oV@3ooookJ_m^0?l01_oonfX00ol0o`_oj`3ooookJP04oook
JP03o`2=oooonf[ooo]Z00?ooo]Z00CooiT0oookJ_oonf[o04So2OoonfX03OooG`3ooi00oookJ_oo
0:3ooo]Zool0Rooonf[o_03ooookJ_mbo`3ooo]Zoeko0?oo02H00ooonfX00ol0gooooo]Zool0^`02
oookJP0;okT0oooonf[ooo]ZoookJ_oolP3oQ_l0oookJ_oo0?Co/`3ooookJ_oo0:X00_oonfX01?l0
oa?ooo]ZoookJ_n6o`06oookJP;o007o00Oooo]Zo`1lool_0?oool00oookJ_l0ojKoC`3o00?ooo]Z
0_ooO`000ooonf[o0P3oo`80o`0ToookJP00nooonfX4o`0005Kooo]Z00?oI`3ooookJ_oonfX02Ooo
nfX00ooob@3ooo]ZoookJP06oookJP03ol<0oooonf[ooo]Z00WoolT00ooonfX00ol0o`_oj`3ooook
JP04oookJP03o`2=oooonf[ooo]Z00?ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`09oookJP0<of3o
0?ooT03ooo]Zool0X?oo08_ooo]Zok`0oooonf[oL_l0oookJ_l60?ooo`0V1?oonfX01_l0goooo`2k
oookJ_oonf[o^@3ooe_o00?ooo]Z00WoolT0ohKo0?oonf[oo`3dok<0oooonf[oo`2ZoookJ_l0oa<0
0_oonfX00on6o`3ooo]ZoookJP04oookJP0:o`01oooonf[ooo]ZoookJ_l0O?oo;`3oooo00?oonf[o
iOl0ooo900?ooo]Z00?oogl0o`80ool20?l0oooonfXOoookJPCo0000E_oonfX00omW0?oooo]Zoook
JP09oookJP03ool0GOoonf[ooo]Z00Kooo]Z00?o``3ooookJ_oonfX01OoonfX00onI0?ooKP3ooook
JP05oookJP03o`3o2oo[0?oooo]Z00Cooo]Z00?o08gooookJ_oonfX00ooonfX01?ooV@3ooo]Zoook
J_l0B?l9oookJP0=of3o0?ooT03ooo]Zool0X?oonf[oo`2;oookJ_nl0?oooo]Zog;o0?oonf[oG_l0
ool09P03oookJP03o`3Ooooonf[oo`2k00;ooo]Z00_o^@3ooookJ_oonf[ooo]Zooob0?n6o`3ooo]Z
ool0m?nc0?oooo]Zool0ZP02oookJP04o`3o4ooonf[ooo]ZohKo00Kooo]Z00Wo007ooookJ_oonf[o
07coobl0oooo`03ooo]Zo`3oY_m?0?l00ooonfX01?ooO`3oo`2<o`80ool20?lVoookJP00nooonfX4
o`0005Gooo]Z00?oI`3ooookJ_oonfX02OoonfX00ooob@3ooo]ZoookJP06oookJP03ol<0oooonf[o
oo]Z00WoolT01?oonfX00ol0o`_ooo]ZoookJP03oookJP03o`2=oooonf[ooo]Z00?ooo]Z00GooiT0
oookJ_oonf[ooo]Zo`18o`09oookJP0<of3o0?ooT03ooo]Zool0X?oo08_ooo]Zok`0oooonf[oL_l0
oookJ_l60?ooo`0V1?oonfX01_l0goooo`2koookJ_oonf[o^@3ooe_o00?ooo]Z00WoolT0ohKo0?oo
nf[oo`3dok<0oooonf[oo`2ZoookJ_l0oa<00_oonfX00on6o`3ooo]ZoookJP04oookJP0:o`01oooo
nf[ooo]ZoookJ_l0O?oo;`3oooo00?oonf[oiOl0ooo900?ooo]Z00?oogl0o`80oooonfX0oooonfXP
oookJPCo0000EOoonfX00omW0?oooo]ZoookJP09oookJP03ool0GOoonf[ooo]Z00Kooo]Z00?o``3o
oookJ_oonfX01OoonfX00onI0?ooKP3ooookJP06oookJP03o`3o2ooonf[ooo]Z00?ooo]Z00?o08go
oookJ_oonfX00ooonfX01?ooV@3ooo]ZoookJ_l0B?l9oookJP0=of3o0?ooT03ooo]Zool0X?oonf[o
o`2;oookJ_nl0?oooo]Zog;o0?oonf[oG_l0ool09P03oookJP03o`3Ooooonf[oo`2k00;ooo]Z00_o
^@3ooookJ_oonf[ooo]Zooob0?n6o`3ooo]Zool0m?nc0?oooo]Zool0ZP02oookJP04o`3o4ooonf[o
oo]ZohKo00Kooo]Z00Wo007ooookJ_oonf[o07coobl0oooo`03ooo]Zo`3oY_m?0?l00ooonfX00ooo
O`3ooo]Zo`80o`0XoookJP00nooonfX4o`0005?ooo]Z0_oob@0;oookJP03ooo90?oonf[ooo]Z00Ko
oo]Z00?o``3ooookJ_oonfX02_oob@03oookJP03o`3o2ooonf[ooo]Z00?ooo]Z00?o08gooookJ_oo
nfX00ooonfX01OooV@3ooo]ZoookJ_oonf[o04So00Wooo]Z00coH?l0oon@0?oonf[oo`2Pool0Rooo
nf[o_03ooookJ_mbo`3ooo]Zo`H0oooo02H4oookJP06o`3Ooooo0;_ooo]ZoookJ_ni0?ooFol00ooo
nfX01ooob@3oQ_l0oookJ_oo0?Co/`3ooookJ_oo0:X00_l0oa<2oookJP03ohKo0?oonf[ooo]Z00Co
oo]Z00Co007ooookJ_oonf[ooo]Z0_l_0?l01?oo`03ooo]ZonGo0?oob@03oookJP03oomo0?l20?oo
oo]Z0?oooo]Z8OoonfX4o`0005Cooo]Z00?oI`3ooookJ_oonfX02OoonfX00ooo05gooo]ZoookJP06
oookJP03ol<0oooonf[ooo]Z00Gooo]Z00?oV@3oofh0oooonfX01_oonfX00ol0o`_ooo]ZoookJP03
oookJP03o`2=oooonf[ooo]Z00?ooo]Z00CooiT0oookJ_oonf[o04So2OoonfX03OmPo`3ooi00oook
J_oo0:3ooo]Zool0Rooonf[o_03ooookJ_mbo`3ooo]Zoeko0?oo02H00ooonfX00ol0gooooo]Zool0
^`02oookJP0<okT0oooonf[ooo]ZoookJ_oolP3oQ_l0oookJ_oo0?Co/`3ooookJ_oo0:[ooo]Z0_l0
oa<2oookJP03ohKo0?oonf[ooo]Z00Cooo]Z00?o007ooookJ_oonfX00_l_0?l01?oo`03ooo]Zo`3o
Y_m?0?l3oookJP03oomo0?oonf[o0P3o02Wooo]Z003koookJPCo0000D_oonfX3ooo900[ooo]Z00?o
olT0oookJ_oonfX01_oonfX00oo30?oooo]ZoookJP03oookJPOoolT00ooonfX00ol0o`_ooo]Zoook
JP03oookJP03o`2=oooonf[ooo]Z00?ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`09oookJP0<of3o
0?ooT03ooo]Zool0X?oo08_ooo]Zok`0oooonf[oL_l0oookJ_l60?ooo`0V1?oonfX01_l0goooo`2k
oookJ_oonf[o^@3ooe_o00?ooo]Z00SoolT0ohKo0?oonf[oo`3dok<0oooonf[oo`2Zo`3o4`?ooo]Z
00?oQ_l0oookJ_oonfX01?oonfX02_l00Ooooo]ZoookJ_oonf[o;`3ooookJ_oo`03ooo]Zodl0oooo
b@03oookJP03oomo0?l20?oooo]Z0?oooo]Z8_oonfX4o`0005Cooo]Z00?oI`3ooookJ_oonfX02?oo
nfX00ooo05gooo]ZoookJP06oookJP03ol<0oooonf[ooo]Z00Gooo]Z00?oV@3oofh0oooonfX01_oo
nfX00ol0o`_ooo]ZoookJP03oookJP03o`2=oooonf[ooo]Z00?ooo]Z00CooiT0oookJ_oonf[o04So
2OoonfX03OmPo`3ooi00oookJ_oo0:3ooo]Zool0Rooonf[o_03ooookJ_mbo`3ooo]Zoeko0?oo02H0
0ooonfX00ol0gooooo]Zool0^`02oookJP0=okT0oooonf[ooo]ZoookJ_oolP3oQ_l0oookJ_oo0?Co
/`3ooookJ_oo0:[ooo]Zo`3o4`03oookJP03ohKo0?oonf[ooo]Z00Cooo]Z00Oo007ooookJ_oonf[o
;`3ooookJ_oo`03ooo]Z00;oC`3o0ooonfX00oooO`3ooo]Zo`80o`0ZoookJP00nooonfX4o`00057o
oo]Z0ooob@0;oookJP03ool0GOoonf[ooo]Z00Gooo]Z00?o``3ooookJ_oonfX01OoonfX6ooo900;o
oo]Z00?o0?l;oookJ_oonfX01?oonfX00ol0SOoooo]ZoookJP02oookJP05oonI0?oonf[ooo]Zoook
J_l0B?l02OoonfX02OmPo`3ooi00oookJ_oo0:3oo`2;oookJ_nl0?oooo]Zog;o0002oookJP03ool0
9_oonf[ooo]Z00;ooo]Z00Ko0=ooool0^ooonf[ooo]ZokT0oomKo`03oookJP08ooo90?n6o`3ooo]Z
ool0m?nc0?oooo]Zool0Z_l0oa<3oookJP03ohKo0?oonf[ooo]Z00Cooo]Z00Wo007ooookJ_oonf[o
oo]Zobl0oooonf[ool00oookJ_m?0?l00ooonfX00ooob@3oogl0o`80o`05oookJP;o7Ol0oooonfXM
oookJPCo0000DooonfX00omW0?oooo]ZoookJP09oookJP03ool0GOoonf[ooo]Z00Gooo]Z00?o``3o
oookJ_oonfX01OoonfX00onI0?ooKP3ooookJP06oookJP03o`3o2ooonf[ooo]Z00Cooo]Z00?o08go
oookJ_oonfX00_oonfX01?ooV@3ooo]ZoookJ_l0B?l9oookJP0=of3o0?ooT03ooo]Zool0X?oonf[o
o`2;oookJ_nl0?oooo]Zog;o0?oonf[oG_l0ool09P03oookJP03o`3Ooooonf[oo`2k00;ooo]Z00go
^@3ooookJ_oonf[ooo]Zooob0?n6o`3ooo]Zool0m?nc0?oooo]Zool0Z_oonf[o0?lC00?ooo]Z00?o
Q_l0oookJ_oonfX01?oonfX02?l00Ooooo]ZoookJ_l_0?oooo]Zooo00?oonf[oC`3o0ooonfX01?oo
08coogl0oookJ_l20?l5oookJP;o7Ol09?oonfX00?_ooo]Z1?l0001?oookJPGoolT02_oonfX00ooo
05gooo]ZoookJP05oookJP03ol<0oooonf[ooo]Z00Gooo]Z00?oV@3ooookJ_oob@000ooob@02oook
JP03o`3o2ooonf[ooo]Z00Cooo]Z00?o08gooookJ_oonfX00_oonfX01OooV@3ooo]ZoookJ_oonf[o
04So00Wooo]Z00WoH?l0oon@0?oonf[oo`2Pool0Rooonf[o_03ooookJ_mbo`000_oonfX00ooo02Ko
oo]ZoookJP02oookJP06o`3Ooooo0;_ooo]ZoookJ_ni0?ooFol00ooonfX01Ooob@3oQ_l0oookJ_oo
0?Co/`3o00;oo`2Z00Go0?lCoookJ_oonf[ooo]ZohKo0006oookJP09o`01oooonf[ooo]ZoookJ_l_
0?oooo]Zooo00?oonf[oC`3o00?ooo]Z00?oolT0oomo0?oob@001OoonfX00olMo`3ooo]Zooo9003o
oookJQgooo]Z1?l0001BoookJP03ofL0oooonf[ooo]Z00Wooo]Z00?oo`1MoookJ_oonfX01OoonfX0
0oo30?oooo]ZoookJP05oookJP03oiT0oooonf[oKP3o00Kooo]Z00?o0?l;oookJ_oonfX01?oonfX0
0ol0SOoooo]ZoookJP02oookJP04oonI0?oonf[ooo]Zo`18o`Wooo]Z00goH?l0oon@0?oonf[oo`2P
oookJ_oo08_ooo]Zok`0oooonf[oL_l0oookJ_mNo`3oo`0V00?ooo]Z00?o0=oooookJ_oo0;/00_oo
nfX02Oni0?oooo]ZoookJ_oonf[ooo80ohKo0?oonf[oo`3dok<0o`02ool0ZP03oookJ_l0oa?ooo]Z
00;ooo]Z00?oQ_l0oookJ_oonfX01?oonfX02?l00Ooooo]ZoookJ_l_0?oooo]Zooo00?oonf[oC`3o
0ooonfX01?oo08coogl0oookJ_l20?l5oookJP03oago0?mSo`3ooo]Z02Cooo]Z003koookJPCo0000
C_oonfX5ooo900[ooo]Z00?oo`1MoookJ_oonfX01_oonfX00oo30?oooo]ZoookJP04oookJP04oiT0
oooonf[oolT0oookJP?oolT000?ooo]Zo`3o2ooonfX01OoonfX00ol0SOoooo]ZoookJP02oookJP05
oonI0?oonf[ooo]ZoookJ_l0B?l02OoonfX02OmPo`3ooi00oookJ_oo0:3oo`2;oookJ_nl0?oooo]Z
og;o0002oookJP03ool09_oonf[ooo]Z00;ooo]Z00Ko0=ooool0^ooonf[ooo]ZokT0oomKo`03oook
JP08ooo90?n6o`3ooo]Zool0m?nc0?ooo`2ZoookJ_l0oa<3oookJP03ohKo0?oonf[ooo]Z00Cooo]Z
00Wo007ooookJ_oonf[ooo]Zobl0oooonf[ool00onGo0?m?0?l00_oonfX2ooo90003oomo0?oob@3o
oo]Z00Cooo]Z00Co7Ol0oookJ_mYo`3oJOl0oooonfXMoookJPCo0000DOoonfX00omW0?oooo]Zoook
JP09oookJP03ool0GOoonf[ooo]Z00Kooo]Z00?o``3ooookJ_oonfX01?oonfX00onI0?oooo]Zofh0
o`06oookJP03o`3o2ooonf[ooo]Z00Cooo]Z00?o08gooookJ_oonfX00_oonfX01?ooV@3ooo]Zoook
J_l0B?l9oookJP0=of3o0?ooT03ooo]Zool0X?oonf[oo`2;oookJ_nl0?oooo]Zog;o0?oonf[oG_l0
ool09P03oookJP03o`3Ooooonf[oo`2k00;ooo]Z00[o^@3ooookJ_oonf[ooo]Zooob0?n6o`3ooo]Z
ool0m?nc0?ooo`2Z0_oonfX01Ol0oa?ooo]ZoookJ_oonf[oQ_l000Kooo]Z00So007ooookJ_oonf[o
;`3ooookJ_oo`03ooo]Zodl0o`?ooo]Z00Coo`2<oomo0?oonf[o0P3o1OoonfX01?lMo`3oHol0ofWo
0?mYo`0ToookJP00nooonfX4o`0004gooo]Z1_oob@09oookJP03ool0GOoonf[ooo]Z00Kooo]Z00?o
``3ooookJ_oonfX01?oonfX00onI0?oooo]Zooo90003oookJP03ooo90?oonf[o0?l;00Kooo]Z00?o
08gooookJ_oonfX00_oonfX01OooV@3ooo]ZoookJ_oonf[o04So00Wooo]Z00WoH?l0oon@0?oonf[o
o`2Pool0Rooonf[o_03ooookJ_mbo`000_oonfX00ooo02Kooo]ZoookJP02oookJP06o`3Ooooo0;_o
oo]ZoookJ_ni0?ooFol00_oonfX02OoolP3oolT0oookJ_oonf[oo`3dok<0oooo0:[ooo]Zo`3o4`03
oookJP03ohKo0?oonf[ooo]Z00Cooo]Z00[o007ooookJ_oonf[ooo]Zobl0oooonf[ool00o`3oY_m?
0?oooo]Z0ooob@000oooO`3oolT0oookJP04oookJP03oago0?oonf[oJOl000;oo`3?oooonfXMoook
JPCo0000D?oonfX00omW0?oooo]ZoookJP09oookJP03ool0GOoonf[ooo]Z00Kooo]Z00?o``3ooook
J_oonfX01OoonfX00onI0?ooKP3ooookJP05oookJP03o`3o2ooonf[ooo]Z00Cooo]Z00?o08gooook
J_oonfX00_oonfX01?ooV@3ooo]ZoookJ_l0B?l9oookJP0=of3o0?ooT03ooo]Zool0X?oonf[oo`2;
oookJ_nl0?oooo]Zog;o0?oonf[oG_l0ool09P03oookJP03o`3Ooooonf[oo`2k00;ooo]Z00[o^@3o
oookJ_oonf[ooo]Zooob0?n6o`3ooo]Zool0m?nc0?ooo`2Z0_oonfX00ol0oa?ooo]ZoookJP02ohKo
00Kooo]Z00So007ooookJ_oonf[o;`3ooookJ_oo`03o0?nVodl0o`?ooo]Z00Coo`2<oomo0?oonf[o
0P3o1OoonfX00olMo`3oHol0ofWo0002ool0cbCooo]Z003koookJPCo0000C?oonfX6ooo900Wooo]Z
00?oo`1MoookJ_oonfX01_oonfX00oo30?oooo]ZoookJP04oookJP03oiT0oooonf[oolT000Gooo]Z
00?oj`3oo`3o2ooonfX01?oonfX00ol0SOoooo]ZoookJP03oookJP04oonI0?oonf[ooo]Zo`18o`Wo
oo]Z00WoH?l0oon@0?oonf[oo`2Pool0Rooonf[o_03ooookJ_mbo`000_oonfX00ooo02Kooo]Zoook
JP02oookJP06o`3Ooooo0;_ooo]ZoookJ_ni0?ooFol00_oonfX00ooolP3oQ_l0oookJP02ool0m004
ok<0oooo0:[ooo]Zo`3o4`?ooo]Z00?oQ_l0oookJ_oonfX01?oonfX02_l00Ooooo]ZoookJ_oonf[o
;`3ooookJ_oo`03o0?nVodl0oooonfX3ooo90003oomo0?oob@3oolT000Cooo]Z00Ko7Ol0oookJ_mY
o`3oo`3?oookJ_l0okSooookJQgooo]Z1?l0001@oookJP03ofL0oooonf[ooo]Z00Sooo]Z00?oo`1M
oookJ_oonfX01_oonfX00oo30?oooo]ZoookJP05oookJP03oiT0oom^0?oooo]Z00Gooo]Z00?o0?l;
oookJ_oonfX01?oonfX00ol0SOoooo]ZoookJP02oookJP04oonI0?oonf[ooo]Zo`18o`Wooo]Z00go
H?l0oon@0?oonf[oo`2PoookJ_oo08_ooo]Zok`0oooonf[oL_l0oookJ_mNo`3oo`0V00?ooo]Z00?o
0=oooookJ_oo0;/00_oonfX02_ni0?oooo]ZoookJ_oonf[ooo80ohKo0?oonf[oo`3dok<0oooo0:X2
oookJP04o`3o4ooonf[ooo]ZohKo00Oooo]Z00So007ooookJ_oonf[o;`3ooookJ_oo`03o0?nVodl0
o`?ooo]Z00Coo`2<oomo0?oonf[o0P3o1OoonfX01_lMo`3oHol0ofWo0?oo0<oooo]Zo`3o^2Cooo]Z
003koookJPGo0000BOoonfX8ooo900Wooo]Z00?oo`1MoookJ_oonfX01OoonfX00oo30?oooo]Zoook
JP04oookJP03oiT0oooonf[oolT000Kooo]Z00?o0?l;oookJ_oonfX00ooonfX00ol0SOoooo]Zoook
JP03oookJP05oonI0?oonf[ooo]ZoookJ_l0B?l02?oonfX02OmPo`3ooi00oookJ_oo0:3oo`2;oook
J_nl0?oooo]Zog;o0002oookJP03ool09_oonf[ooo]Z00;ooo]Z00Ko0=ooool0^ooonf[ooo]ZokT0
oomKo`02oookJP09ooob0?n6o`3ooo]Zool0m?oonf[o/`3oool0Z_oonf[o0?lC00?ooo]Z00?oQ_l0
oookJ_oonfX01?oonfX02Ol00Ooooo]ZoookJ_oonf[o;`3ooookJ_oo`03o0?nVodl0o`04ooo90003
oomo0?oob@3oolT000Cooo]Z00Go7Ol0ooo90?mYo`3oo`3?oookJP02o`3o^?oooo]Z7OoonfX5o`00
04kooo]Z00?oI`3ooookJ_oonfX02OoonfX00ooo05gooo]ZoookJP05oookJP03ol<0oooonf[ooo]Z
00Gooo]Z00?oV@3oofh0oooonfX01OoonfX00ol0o`_oj`3ooookJP04oookJP03o`2=oooonf[ooo]Z
00;ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`08oookJP0=of3o0?ooT03ooo]Zool0X?oonf[oo`2;
oookJ_nl0?oooo]Zog;o0?oonf[oG_l0ool09P03oookJP03o`3Ooooonf[oo`2k00;ooo]Z00[o^@3o
oookJ_oonf[ooo]Zooob0?n6o`3ooo]Zool0m?nc0?ooo`2Z0_oonfX01?l0oa?ooo]ZoookJ_n6o`07
oookJP08o`01oooonf[ooo]Zobl0oooonf[ool00o`3oY_m?0?l3oookJP04ool0S?ooO`3ooo]Zo`80
o`Gooo]Z00Co7Ol0of?o0?mYo`3oo`3?0_l0okPUoookJP00nooonfX4o`0004Wooo]Z2?oob@09oook
JP03ool0GOoonf[ooo]Z00Gooo]Z00?o``3ooookJ_oonfX01OoonfX00onI0?ooolT0oookJP05oook
JP03o`3o2ooonf[ooo]Z00?ooo]Z00?o08gooookJ_oonfX00ooonfX01OooV@3ooo]ZoookJ_oonf[o
04So00Sooo]Z00WoH?l0oon@0?oonf[oo`2Pool0Rooonf[o_03ooookJ_mbo`000_oonfX00ooo02Ko
oo]ZoookJP02oookJP06o`3Ooooo0;_ooo]ZoookJ_ni0?ooFol00_oonfX01?oolP3oQ_l0oookJ_oo
0?@2oomi0003ool0Z_oonf[o0?lC00?ooo]Z00?oQ_l0oookJ_oonfX01?oonfX02Ol00Ooooo]Zoook
J_oonf[o;`3ooookJ_oo`03o0?nVodl0o`04ooo90004oomo0?oob@3oolT0ooo900?ooo]Z00Ko7Ol0
of?o0?mYo`3oo`3?oookJ_l0okP2o`3ocOoooo]Z7OoonfX4o`0004kooo]Z00?oI`3ooookJ_oonfX0
2OoonfX00ooo05gooo]ZoookJP05oookJP03ol<0oooonf[ooo]Z00Gooo]Z00?oV@3oofh0oooonfX0
1OoonfX00ol0o`_oj`3ooookJP04oookJP03o`2=oooonf[ooo]Z00;ooo]Z00GooiT0oookJ_oonf[o
oo]Zo`18o`08oookJP0=of3o0?ooT03ooo]Zool0X?oonf[oo`2;oookJ_nl0?oooo]Zog;o0?oonf[o
G_l0ool09P03oookJP03o`3Ooooonf[oo`2k00;ooo]Z00[o^@3ooookJ_oonf[ooo]Zooob0?n6o`3o
oo]Zool0m?nc0?ooo`2Z0_oonfX01?l0oa?ooo]ZoookJ_n6o`07oookJP08o`01oooonf[ooo]Zobl0
oooonf[ool00o`3oY_m?0?l3oookJP04ool0S?ooO`3ooo]Zo`80o`Gooo]Z00Ko7Ol0of?o0?mYo`3o
o`3?o`3o^?oonfX2o`3ocBCooo]Z003koookJPCo0000B?oonfX9ooo900Sooo]Z00?oo`1MoookJ_oo
nfX01OoonfX00oo30?oooo]ZoookJP05oookJP03oiT0oooob@3ooo]Z00Gooo]Z00?o0?l;oookJ_oo
nfX01?oonfX00ol0SOoooo]ZoookJP02oookJP05oonI0?oonf[ooo]ZoookJ_l0B?l02?oonfX02OmP
o`3ooi00oookJ_oo0:3ooo]Zool0Ronl0?oooo]Zog;o0002oookJP03ool09_oonf[ooo]Z00;ooo]Z
00Ko0=ooool0^ooonf[ooo]ZokT0oomKo`02oookJP03ooob0?n6o`3ooo]Z00CoogT000?ooo]Zo`3o
4ooonfX00_oonfX00on6o`3ooo]ZoookJP04oookJP09o`01oooonf[ooo]ZoookJ_l_0?oooo]Zooo0
0?l0ojKoC`3o00CoolT000Coogl0ooo90?oob@3oolT00ooonfX01olMo`3oHol0ofWo0?oo0<oooo]Z
o`3o^?l0old00_oob@3ooookJQgooo]Z1?l0001=oookJP03ofL0oooonf[ooo]Z00Wooo]Z00?oo`1M
oookJ_oonfX01OoonfX00oo30?oooo]ZoookJP05oookJP03oiT0oom^0?oooo]Z00Gooo]Z00?o0?l;
on/0oooonfX01?oonfX00ol0SOoooo]ZoookJP02oookJP05oonI0?oonf[ooo]ZoookJ_l0B?l02?oo
nfX02omPo`3ooi00oookJ_oo0:3ooo]Zool0Rooonf[o_03ooookJ_mbo`3ooo]Z00;oo`0V0ooonfX0
0ol0gooooo]Zool0^`02oookJP0:okT0oooonf[ooo]ZoookJ_oolP3oQ_l0oookJ_oo0?Co/`3oool0
ZP;ooo]Z00Co0?lCoookJ_oonf[oQ_l01_oonfX2o`01o`;ooo]Z00Go;`3ooookJ_oo`03o0?nVodl0
o`03oookJP04ool0S?ooO`3ooo]Zo`80o`Cooo]Z0_lMo`001_oonf[oJOl0ool0col0okSooo]Zo`3o
cBKooo]Z003koookJPCo0000AooonfX9ooo900Sooo]Z00?oo`1MoookJ_oonfX01_oonfX00oo30?oo
oo]ZoookJP04oookJP03oiT0oooob@3ooo]Z00Gooo]Z00?o0?l;oookJ_oonfX01?oonfX00ol0SOoo
oo]ZoookJP02oookJP05oonI0?oonf[ooo]ZoookJ_l0B?l02?oonfX02OmPo`3ooi00oookJ_oonf[o
o`2Pool0Ronl0?oooo]Zog;o0002oookJP03ool09_oonf[ooo]Z00;ooo]Z00Ko0=ooool0^ooonf[o
oo]ZokT0oomKo`02oookJP03ooob0?n6o`3ooo]Z00CoogT000?ooo]Zo`3o4ooonfX00_oonfX00on6
o`3ooo]ZoookJP04oookJP09o`01oooonf[ooo]ZoookJ_l_0?oooo]Zooo00?l0ojKoC`3o00CoolT0
00Coogl0ooo90?oob@3oolT00ooonfX02?lMo`3oHol0ofWo0?oo0<oooo]Zo`3o^?l0olgoolT00_oo
08KooookJQgooo]Z1?l0001=oookJP03ofL0oooonf[ooo]Z00Sooo]Z00?oo`1MoookJ_oonfX01_oo
nfX00oo30?oooo]ZoookJP04oookJP03oiT0oom^0?oooo]Z00Kooo]Z00?o0?l;oookJ_oonfX00ooo
nfX00ol0SOoooo]ZoookJP02oookJP05oonI0?oonf[ooo]ZoookJ_l0B?l02?oonfX03?mPo`3ooi00
oomO0?oonf[oo`2Pool0Rooonf[o_03ooookJ_mbo`3ooo]Zool09PCooo]Z00?o0=oooookJ_oo0;/0
0_oonfX02_ni0?oooo]ZoookJ_oonf[ooo80ohKo0?oonf[oo`3dok<0oooo0:X2oookJP04o`3o4ooo
nf[ooo]ZohKo00Kooo]Z00Wo007ooookJ_oonf[ooo]Zobl0oooonf[ool00o`3oY_m?0?l00ooonfX0
1?oo08coogl0oookJ_l20?l4oookJP09oago0?l=0?oooo]ZofWo0?oo0<oo0?nhoookJ_l0olgooo]Z
00;oo`269?oonfX00?_ooo]Z1?l00019oookJPOoolT01ooonfX00ooo05gooo]ZoookJP06oookJP03
ol<0oooonf[ooo]Z00Cooo]Z00?oV@3oooo90?oonfX01OoonfX00ol0o`_ooo]ZoookJP04oookJP03
o`2=oooonf[ooo]Z00;ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`08oookJP07of3o0?ooT03ooo]Z
oookJ_oo0:3oo`2;ok`0o`02oiCo00;ooo]Z00?oo`0VoookJ_oonfX00_oonfX01_l0goooo`2koook
J_oonf[o^@3ooe_o00;ooo]Z00?ooo80ohKo0?ooN@001?ooN@000ooonf[o0?lCoookJP02oookJP03
ohKo0?oonf[ooo]Z00Cooo]Z00Go007ooookJ_oonf[ooo]Zobl0o`02ooo00003o`3oY_m?0?oooo]Z
00?oolT000?oogl0ooo90?oob@000_oob@02oookJP09oago0?mSo`3oJOl0ool0cooonf[o0?nho`3o
cOoonf[oo`2600;oolT0oooonfXMoookJPCo0000C?oonfX00omW0?oooo]ZoookJP08oookJP03ool0
GOoonf[ooo]Z00Kooo]Z00?o``3ooookJ_oonfX01OoonfX00om^0?oooo]ZoookJP05oookJP03o`3o
2ooonf[ooo]Z00?ooo]Z00?o08gooookJ_oonfX00_oonfX01OooV@3ooo]ZoookJ_oonf[o04So00So
oo]Z00coH?l0oon@0?ooG`3ooo]Zool0X?oo08_ooo]Zok`0oooonf[oL_l0oookJ_oo02H4oookJP03
o`3Ooooonf[oo`2k00;ooo]Z00[o^@3ooookJ_oonf[ooo]Zooob0?n6o`3ooo]Zool0m?nc0?ooo`2Z
0_oonfX01?l0oa?ooo]ZoookJ_n6o`06oookJP05o`01oooonf[ooo]ZoookJ_l_0?l00_oo`0000ol0
ojKoC`3ooookJP02oookJP04ool0S?ooO`3ooo]Zo`80o`Cooo]Z00[o7Ol0of?o0?mYo`3oJOl0ool0
col0okSooo]Zo`3ocOoonf[oo`269_oonfX00?_ooo]Z1?l0001:oookJPGoolT02?oonfX00ooo05go
oo]ZoookJP05oookJP03ol<0oooonf[ooo]Z00Cooo]Z00?oV@3oooo90?oonfX01OoonfX00ol0o`_o
oo]ZoookJP04oookJP03o`2=oooonf[ooo]Z00;ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`08oook
JP07of3o0?ooT03ooo]ZoookJ_oo0:3oo`2;ok`0o`03oiCo0003oookJ_oo02Kooo]Z00?ooo]Z00Ko
0=ooool0^ooonf[ooo]ZokT0oomKo`02oookJP03ooob0?ooN@3oogT000GoogT000Go0?lCoookJ_oo
nf[ooo]ZohKo0006oookJP03o`01oooonf[ooo]Z00;o;`3o00Cool00oookJ_l0ojKoC`3o0ooonfX0
0ooob@3oogl0ooo90003ooo900;ooo]Z00?o7Ol0of?o0?mYo`000_oonfX01Ol0okSo0?o=oookJ_oo
08Kooo]Z00;oolT0oooonfXMoookJPCo0000BooonfX00omW0?oooo]ZoookJP09oookJP03ool0GOoo
nf[ooo]Z00Gooo]Z00?o``3ooookJ_oonfX01OoonfX00om^0?oooo]ZoookJP05oookJP03o`3o2ooo
nf[ooo]Z00?ooo]Z00?o08gooookJ_oonfX00_oonfX01OooV@3ooo]ZoookJ_oonf[o04So00Sooo]Z
00coH?l0oon@0?ooG`3ooo]Zool0X?oo08_ooo]Zok`0oooonf[oL_l0oookJ_oo02H4oookJP03o`3O
oooonf[oo`2k00;ooo]Z00[o^@3ooookJ_oonf[ooo]Zooob0?n6o`3ooo]Zool0m?nc0?ooo`2Z0_oo
nfX01?l0oa?ooo]ZoookJ_n6o`06oookJP03o`01oooonf[ooo]Z00;o;`3o00Cool00oookJ_l0ojKo
C`3o0ooonfX01?oo08coogl0oookJ_l20?l4oookJP0;oago0?mSo`3oJOl0oiX0oooonf[o0?nhoook
J_l0olgooo]Zool0Q_oonfX00_n00?lToookJP00nooonfX4o`0004[ooo]Z00?oolT0oookJ_oob@00
0_oob@07oookJP03ool0GOoonf[ooo]Z00Gooo]Z00?o``3ooookJ_oonfX01?oonfX00onI0?oooo]Z
ofh0o`05oookJP03on/0ool0o`_ooo]Z00Cooo]Z00?o08gooookJ_oonfX00_oonfX01OooV@3ooo]Z
oookJ_oonf[o04So00Sooo]Z00KoH?l0oon@0?oonf[ooo]Zool0X?oo08/4oiCo0003oomi0?oo02Ko
oo]Z00?ooo]Z00Ko0=ooool0^ooonf[ooo]ZokT0oomKo`02oookJPSoogT000Go0?lCoookJ_oonf[o
oo]ZohKo0006oookJP07o`01oooonf[ooo]Zobl0ool0O?oool00oookJP02odl0o`?ooo]Z00?oolT0
oomo0?oob@001?oob@001?oonf[o7Ol0of?o0?mYo`02oookJP06o`3o^?l0olgooo]Zool0Q_oonf[o
olT0oooonfXOoookJPCo0000B_oonfX00omW0?oooo]ZoookJP09oookJP03ool0GOoonf[ooo]Z00Go
oo]Z00?o``3ooookJ_oonfX01OoonfX00onI0?ooKP3ooookJP05oookJP03o`3o2ooonf[ooo]Z00Co
oo]Z00Go08gooookJ_oonf[ooo]ZoonI0003oookJP03o`18oooonf[ooo]Z00Kooo]Z00coH?l0oon@
0?ooG`3ooo]Zool0X?oo08_ooo]Zok`0oooonf[oL_l0o`H0oooo02H4oookJP03o`3Ooooonf[oo`2k
00;ooo]Z00[o^@3ooookJ_oonf[ooo]Zooob0?n6o`3ooo]Zool0m?nc0?ooo`2Z0_oonfX01?l0oa?o
oo]ZoookJ_n6o`06oookJP07o`01oooonf[ooo]Zobl0ool0O?oool00oookJP02odl0o`?ooo]Z00Co
o`2<oomo0?oonf[o0P3o1?oonfX03?lMo`3oHol0ofWo0?nJ0?oooo]Zo`3o^?oonf[o0?o=oookJ_oo
08Kooo]Zoh00obKooo]Z003koookJPCo0000BOoonfX01Ooob@3ooo]ZoookJ_oonf[oolT000Oooo]Z
00?oo`1MoookJ_oonfX01OoonfX00oo30?oooo]ZoookJP04oookJP03oiT0oooonf[oKP3o00Kooo]Z
00?o0?l;oookJ_oonfX00ooonfX00ol0SOoooo]ZoookJP02oookJP05oonI0?oonf[ooo]ZoookJ_l0
B?l02?oonfX01OmPo`3ooi00oookJ_oonf[oo`2P00KoU?l000?oo`0Voomi0?oonfX00_oonfX01_l0
goooo`2koookJ_oonf[o^@3ooe_o00;ooo]Z2OooN@03oookJP03ohKo0?oonf[ooo]Z00Cooo]Z00Wo
007ooookJ_oonf[o;`3oo`1loooo`03ooo]Zodl0oolco`000ooonfX01?oob@3oogl0o`80oooonfX3
ooo90004oookJ_lMo`3oHol0ofWo00;ooo]Z00Oo0?nho`3ocOoonf[oo`26oookJ_oob@3ooo]Z00;o
/_l0oooonfXMoookJPCo0000BOoonfX00omW0?oooo]ZoookJP09oookJP03ool0GOoonf[ooo]Z00Go
oo]Z00?o``3ooookJ_oonfX01OoonfX00onI0?ooKP3ooookJP05oookJP03o`3o2ooonf[ooo]Z00Co
oo]Z00Go08gooookJ_oonf[ooo]ZoonI0003oookJP03o`18oooonf[ooo]Z00Kooo]Z00coH?l0oon@
0?ooG`3ooo]Zool0X?oo08_ooo]Zok`0oooonf[oL_l0o`H0oooo02H4oookJP03o`3Ooooonf[oo`2k
00;ooo]Z00[o^@3ooookJ_oonf[ooo]Zooob0?n6o`3ooo]Zool0m?nc0?ooo`2Z0_oonfX01?l0oa?o
oo]ZoookJ_n6o`06oookJP09o`01oooonf[ooo]Zobl0ool0O?oool00oookJ_m?0?oo<ol000?ooo]Z
00Coo`2<oomo0?oonf[o0P3o1?oonfX01_lMo`3oHol0ofWo0?nJ0?oooo]Zo`3o^0;o0?o=00Gooo]Z
ool0Q_oonf[oP03ooookJP02ok;o02Cooo]Z003koookJPCo0000BOoonfX00ooob@3ooo]ZoookJP08
oookJP03ool0GOoonf[ooo]Z00Gooo]Z00?o``3ooookJ_oonfX01?oonfX00onI0?oooo]Zofh0o`06
oookJP03o`3o2ooonf[ooo]Z00?ooo]Z00?o08gooookJ_oonfX00_oonfX01OooV@3ooo]ZoookJ_oo
nf[o04So00Sooo]Z00GoH?l0oomO0?ooT03ooo]Zool0X006oiCo0003ool09_ooN@3ooo]Z00;ooo]Z
00Oo0=ooool0^ooonf[ooo]ZokT0oomKo`3ooo]Z00[oogT00ooonfX00on6o`3ooo]ZoookJP04oook
JP09o`01oooonf[ooo]Zobl0ool0O?oool00oookJ_m?0?oo<ol000?ooo]Z00?oolT0oomo0?l20?l0
0ooonfX01Ooob@3ooo]Zoago0?mSo`3oJOl000;ooo]Z00So0?nho`3ocOoonf[oo`26oookJ_oob@3o
oo]Zok;o0?oooo]Z7ooonfX4o`0004Wooo]Z00?oI`3ooookJ_oonfX02?oonfX00ooo05gooo]Zoook
JP05oookJP03ol<0oooonf[ooo]Z00Gooo]Z00?oV@3oofh0oooonfX01OoonfX00ol0o`_ooo]Zoook
JP04oookJP05o`2=oooonf[ooo]ZoookJ_ooV@000ooonfX00ol0B?oooo]ZoookJP06oookJP0<of3o
0?oonf[ooi00oookJ_oo0:3oo`2;oookJ_nl0?oooo]Zog;o0?l60?ooo`0V1?oonfX00ol0gooooo]Z
ool0^`02oookJP0:okT0oooonf[ooo]ZoookJ_oolP3oQ_l0oookJ_oo0?Co/`3oool0ZP;ooo]Z00Co
0?lCoookJ_oonf[oQ_l01_oonfX02Ol00Ooooo]ZoookJ_l_0?oo07coooo00?oonf[oC`3ooc?o0003
oookJP04ool0S?ooO`3ooo]Zo`80o`Cooo]Z00Oo7Ol0of?o0?mYo`3oVP3ooookJ_l0okSo0?o=00;o
oo]Z00Goo`26oookJ_n00?oooo]Zok;o000VoookJP00nooonfX4o`0004Sooo]Z00?oolT0oookJ_oo
nfX02OoonfX00ooo05gooo]ZoookJP04oookJP03ol<0oooonf[ooo]Z00Cooo]Z00?oV@3ooookJ_m^
0?l01_oonfX00ol0o`_ooo]ZoookJP04oookJP05o`2=oooonf[ooo]ZoookJ_ooV@000ooonfX00ol0
B?oooo]ZoookJP06oookJP05of3o0?ooG`3ooi00oookJ_oo0:001onDo`02oomi00;ooo]Z00Oo0=oo
ool0^oooN@3ooo]ZokT0oomKo`3ooo]Z00[oogT00ooonfX00on6o`3ooo]ZoookJP04oookJP09o`01
oooonf[ooo]Zobl0ool0O?oool00oookJ_m?0?oo<ol000?ooo]Z00?oolT0oomo0?l20?l01?oonfX2
oago0003of?o0?mYo`3ooo]Z00;o0?nh00Oo0?o=oookJ_oo08Kooo]Zooo90?oonf[o/_l00?oooo]Z
8?oonfX4o`0004Sooo]Z00?oI`3ooookJ_oonfX02OoonfX00ooo05gooo]ZoookJP04oookJP03ol<0
oooonf[ooo]Z00Gooo]Z00?oV@3oofh0oooonfX01OoonfX00ol0o`_ooo]ZoookJP04oookJP05o`2=
oooonf[ooo]ZoookJ_ooV@000ooonfX00ol0B?oooo]ZoookJP06oookJP0<of3o0?oonf[ooi00oook
J_oo0:3oo`2;oookJ_nl0?oooo]Zog;o0?l60?ooo`0V1?oonfX00ol0gooooo]Zool0^`02oookJP0:
okT0oooonf[ooo]ZoookJ_oolP3oQ_l0oookJ_oo0?Co/`3oool0ZP;ooo]Z00Co0?lCoookJ_oonf[o
Q_l01_oonfX02Ol00Ooooo]ZoookJ_l_0?oo07coooo00?oonf[oC`3ooc?o0003oookJP04ool0S?oo
O`3ooo]Zo`80o`?ooo]Z0_lMo`001_mSo`3oJOl0oiX0oooonf[o0?nho`3oc@;ooo]Z00Goo`26oook
J_n00?oooo]Zok;o000WoookJP00nooonfX4o`0004Oooo]Z00?oolT0oookJ_oonfX02OoonfX00ooo
05gooo]ZoookJP05oookJP03ol<0oooonf[ooo]Z00?ooo]Z00?oV@3ooookJ_m^0?l01_oonfX00ol0
o`_ooo]ZoookJP04oookJP03o`2=oooonf[ooo]Z00;ooo]Z00CooiT0oookJ_oonf[o04So2?oonfX0
1OmPo`3ooel0oon@0?nDo`3oo`2P00OoU?l00_ooN@002?oonf[oogT0o`3Ooooo0;_oogT0oookJ_ni
0?ooFol00_oonfX00ooolP3oQ_l0oomi0007oomi00;ooo]Z00?oQ_l0oookJ_oonfX01?oonfX02Ol0
0Ooooo]ZoookJ_l_0?oo07coooo00?l0ojKoC`3ooc?o0003oookJP03ooo90?ooO`3o0P3o00Cooo]Z
00ko7Ol0o`d0oooonf[oJOl0oookJ_l0okSooo]Zo`3ocOoonf[oo`26oookJ_oob@3ooo]Zok;o0?oo
oo]Z8OoonfX4o`0004Oooo]Z00?oI`3ooookJ_oonfX02OoonfX00ooo05gooo]ZoookJP05oookJP03
ol<0oooonf[ooo]Z00Cooo]Z00?oV@3oofh0oooonfX01OoonfX00ol0o`_oj`3ooookJP04oookJP03
o`2=oooonf[ooo]Z00;ooo]Z00CooiT0oookJ_oonf[o04So2?oonfX03?mPo`3ooo]Zoon@0?oonf[o
o`2Pool0Rooonf[o_03ooookJ_mbo`3o1P3oool09PCooo]Z00?o0=oooookJ_oo0;/00_oonfX02_ni
0?oooo]ZoookJ_oonf[ooo80ohKo0?oonf[oo`3dok<0oooo0:X2oookJP04o`3o4ooonf[ooo]ZohKo
00Kooo]Z00Wo007ooookJ_oonf[o;`3oo`1loooo`03o0?nVodl0oolco`000ooonfX01?oo08coogl0
oookJ_l20?l3oookJP08oago0?l=0?oooo]ZofWo0?nJ0?oooo]Zo`3o^?l0old2oookJP05ool0Q_oo
nf[oP03ooookJ_nbo`00:?oonfX00?_ooo]Z1?l00016oookJP03ooo90?oonf[ooo]Z00Wooo]Z00?o
o`1MoookJ_oonfX01OoonfX00oo30?oooo]ZoookJP04oookJP03oiT0oom^0?oooo]Z00Gooo]Z00?o
0?l;oookJ_oonfX01?oonfX00ol0SOoooo]ZoookJP02oookJP05oonI0?oonf[ooo]ZoookJ_l0B?l0
1ooonfX01OmPo`3ooel0oon@0?nDo`3oo`2P00OoU?l01?ooN@001_l0goooo`2koomi0?oonf[o^@3o
oe_o00;ooo]Z00Cooo80ohKo0?oonf[oo`3d1_ooN@000ooonf[oQ_l0ohKo0006oookJP09o`01oooo
nf[ooo]Zobl0ool0O?oool00o`3oY_m?0?oo<ol000?ooo]Z00?oolT0oomo0?l20?l01?oonfX03_lM
o`3o3@3ooookJ_mYo`3ooo]Zo`3o^?oonf[o0?o=oookJ_oo08Kooo]Zooo90?oonf[o/_l0oooonfXR
oookJPCo0000A_oonfX00omW0?oooo]ZoookJP09oookJP03ool0GOoonf[ooo]Z00Gooo]Z00?o``3o
oookJ_oonfX01OoonfX00om^0?oooo]ZoookJP04oookJP03o`3o2oo[0?oooo]Z00Cooo]Z00?o08go
oookJ_oonfX00_oonfX01OooV@3ooo]ZoookJ_oonf[o04So00Oooo]Z00coH?l0oookJ_ooT03ooo]Z
ool0X?oo08_ooo]Zok`0oooonf[oL_l0o`H0oooo02H4oookJP03o`3Ooooonf[oo`2k00;ooo]Z00[o
^@3ooookJ_oonf[ooo]Zooob0?n6o`3ooo]Zool0m?nc0?ooo`2Z0_oonfX01?l0oa?ooo]ZohKo0?n6
o`06oookJP09o`01oooonf[ooo]Zobl0ool0O?oool00o`3oY_m?0?oo<ol000?ooo]Z00Coo`2<oomo
0?oonf[o0P3o0ooonfX02?lMo`3o3@3ooookJ_mYo`3oVP3ooookJ_l0okSo0?o=0_oonfX01Ooo08Ko
oo]Zoh00oooonf[o/_l002Wooo]Z003koookJPCo0000A_oonfX00omW0?oooo]ZoookJP08oookJP03
ool0GOoonf[ooo]Z00Gooo]Z00?o``3ooookJ_oonfX01?oonfX00onI0?ooKP3ooookJP05oookJP03
o`3o2ooonf[ooo]Z00Cooo]Z00?o08gooookJ_oonfX00_oonfX01OooV@3ooo]ZoookJ_oonf[o04So
00Oooo]Z00GoH?l0oomO0?ooT03oU?l0ool0X008oiCo00?oogT000Ko0=ooool0^oooN@3oogT0okT0
oomKo`02oookJP06ooob0?n6o`3ooo]Zool0m?ooN@3ooo]Z1OooN@000on6o`3ooo]ZoookJP05oook
JP08o`01oooonf[ooo]Zobl0ool0O?oool00o`3oY_m?0?l4oookJP03ooo90?ooO`3o0P3o00Cooo]Z
00So7Ol0of?o0?mYo`3oJOl0oookJ_l0okSooo]Zo`3oc@;oo`2600Cooo]Zooo90?oonf[o/_l01?oo
nfX2ob?o0?oooo]Z7OoonfX4o`0004Kooo]Z00?oI`3ooookJ_oonfX02?oonfX00ooo05gooo]Zoook
JP05oookJP03ol<0oooonf[ooo]Z00Gooo]Z00?oKP3ooookJ_oonfX01?oonfX00ol0o`_oj`3ooook
JP04oookJP03o`2=oooonf[ooo]Z00;ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`07oookJP0<of3o
0?oonf[ooi00oookJ_oo0:3oo`2;oookJ_nl0?oooo]Zog;o0?l60?ooo`0V1?oonfX00ol0gooooo]Z
ool0^`02oookJP0:okT0oooonf[ooo]ZoookJ_oolP3oQ_l0oookJ_oo0?Co/`3oool0ZP;ooo]Z00?o
0?lCoookJ_n6o`001ooonfX02?l00Ooooo]ZoookJ_l_0?oo07coooo00?l0ojKoC`3o1?oonfX01?oo
08coogl0oookJ_l20?l3oookJP09oago0?mSo`3oJOl0ofWo0?nJ0?oooo]Zo`3o^?l0olgooo]Z00;o
o`2600Cooo]Zoh00oooonf[o/_l01?oonfX2ob?o02Cooo]Z003koookJPCo0000AOoonfX00omW0?oo
oo]ZoookJP08oookJP03ool0GOoonf[ooo]Z00Gooo]Z00?o``3ooookJ_oonfX01?oonfX00onI0?oo
KP3ooookJP06oookJP03o`3o2ooonf[ooo]Z00?ooo]Z00?o08gooookJ_oonfX00_oonfX01OooV@3o
oo]ZoookJ_oonf[o04So00Oooo]Z00KoH?l0oomO0?ooT03ooo]Zool0X?oo08/7oiCo00?oogT000Ko
0=ooool0^oooN@3oogT0okT0oomKo`02oookJP08ooob0?n6o`3ooo]Zool0m?ooN@3ooo]Zool0Z_oo
nfX3oomi0003ohKo0?oonf[ooo]Z00Gooo]Z00So007ooookJ_oonf[o;`3oo`1loooo`03o0?nVodl0
o`Cooo]Z00?oolT0oomo0?l20?l01?oonfX01_lMo`3oHol0ofWo0?oo8@3ooo]Zo`3o^0;o0?o=00Ko
o`26oookJ_oonf[oolT0oookJ_nbo`04oookJP03ob?o0?ooG@3ooed00?oooo]Z7OoonfX4o`0004Go
oo]Z00?oI`3ooookJ_oonfX02?oonfX00ooo05gooo]ZoookJP05oookJP03ol<0oooonf[ooo]Z00Go
oo]Z00?oKP3ooookJ_oonfX01OoonfX00ol0o`_ooo]ZoookJP03oookJP03o`2=oooonf[ooo]Z00;o
oo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`07oookJP0<of3o0?oonf[ooi00oookJ_oo0:3oo`2;oook
J_nl0?oooo]Zog;o0?l60?ooo`0V1?oonfX00ol0gooooo]Zool0^`02oookJP0:okT0oooonf[ooo]Z
oookJ_oolP3oQ_l0oookJ_oo0?Co/`3oool0ZP;ooo]Z00?o0?lCoookJ_n6o`001ooonfX02?l00Ooo
oo]ZoookJ_l_0?oo07coooo00?l0ojKoC`3o1?oonfX01?oo08coogl0oookJ_l20?l3oookJP06oago
0?mSo`3oJOl0oiX0oooo8@3o0?nh0_l0old00ooonf[oo`26oookJP02oh00o`03oookJ_nbo`3ooo]Z
00?ooo]Z00?o8ol0oomM0?ooG@009?oonfX00>Oooo]Z0ol007l4oookJPGo001o2?oonfX4o`0004Co
oo]Z00?oI`3ooookJ_oonfX02OoonfX00ooo05gooo]ZoookJP04oookJP03ol<0oooonf[ooo]Z00Co
oo]Z00?oV@3oofh0oooonfX01_oonfX00ol0o`_ooo]ZoookJP03oookJP03o`2=oooonf[ooo]Z00;o
oo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`07oookJP08of3o0?oonf[ooi00oookJ_oo0:3oo`2;ok`0
ooooN@06oiCo00;oogT000Ko0=ooool0^oooN@3oogT0okT0oomKo`02oookJP0<ooob0?n6o`3ooo]Z
ool0m?ooN@3ooo]Zool0Z_oonf[o0?lCoookJ_ooN@3oQ_l01ooonfX02?l00Ooooo]ZoookJ_l_0?oo
oo]Zooo00?l0ojKoC`3o1?oonfX00ooob@3oogl0o`80o`04oookJP09oago0?mSo`3oJOl0oolQ0?oo
nf[o0?nho`3ocOoonf[oo`2600;ooo]Z00?oolT0oookJ_nbo`001?oonfX01?lSo`3ooed0oookJ_l0
;?oooookJPWooo]Z0ol007l4oookJPGo001o2?oonfX4o`0004Cooo]Z00?oI`3ooookJ_oonfX02Ooo
nfX00ooo05gooo]ZoookJP04oookJP03ol<0oooonf[ooo]Z00Gooo]Z00?oKP3ooookJ_oonfX01Ooo
nfX00ol0o`_ooo]ZoookJP03oookJP03o`2=oooonf[ooo]Z00;ooo]Z00GooiT0oookJ_oonf[ooo]Z
o`18o`07oookJP0<of3o0?oonf[ooi00oookJ_oo0:3oo`2;oookJ_nl0?oooo]Zog;o0?l60?ooo`0V
1?oonfX00ol0gooooo]Zool0^`02oookJP0:okT0oooonf[ooo]ZoookJ_oolP3oQ_l0oookJ_oo0?Co
/`3oool0ZP;ooo]Z00?o0?lCoookJ_n6o`001ooonfX02?l00Ooooo]ZoookJ_l_0?oooo]Zooo00?l0
ojKoC`3o1?oonfX01?oo08coogl0oookJ_l20?l3oookJP07oago0?mSo`3oJOl0oiX0oooo8@3o0?nh
o`3oc@02oookJP03ool0Q_oonf[oP03o00;ooo]Z00?o/_l0oookJ_oonfX00_oonfX01?lSo`3ooed0
oookJ_l0;?lToookJP00iooonfX3o`00O`?ooo]Z1ol007l7oookJPCo0000@ooonfX00omW0?oooo]Z
oookJP09oookJP03ool0GOoonf[ooo]Z00Cooo]Z00?o``3ooookJ_oonfX01?oonfX00onI0?oooo]Z
ofh0o`06oookJP03o`3o2ooonf[ooo]Z00?ooo]Z00?o08gooookJ_oonfX00_oonfX01OooV@3ooo]Z
oookJ_oonf[o04So00Oooo]Z00OoH?l0oookJ_ooT03ooo]Zool0X?oo08_o_03o00;oogT01OnDo`02
oomi0006o`3Ooooo0;_oogT0oomi0?ni0?ooFol00_oonfX02OoolP3oQ_l0oookJ_oo0?CoogT0oook
J_oo0:[ooo]Zo`3o4`02oookJP03ohKo0?oonf[ooo]Z00Cooo]Z0_oUo`02oookJP05obl0oooonf[o
ol00o`3oY_m?0?l01?oonfX00ooob@3oogl0o`80o`04oookJP09oago0?mSo`3oJOl0oolQ0?oonf[o
0?nho`3ocOoonf[oo`2600;ooo]Z00?oolT0ok;o0?nbo`001?oonfX01OlSo`3ooed0oookJ_oonf[o
02co0?oooo]Z2OoonfX3o`00O`?ooo]Z1ol007l7oookJPCo0000@ooonfX00omW0?oooo]ZoookJP09
oookJP03ool0GOoonf[ooo]Z00Cooo]Z00?o``3ooookJ_oonfX01OoonfX00onI0?ooKP3ooookJP05
oookJP03o`3o2ooonf[ooo]Z00?ooo]Z00?o08gooookJ_oonfX00_oonfX01OooV@3ooo]ZoookJ_oo
nf[o04So00Oooo]Z00coH?l0oookJ_ooT03ooo]Zool0X?oo08_ooo]Zok`0oooonf[oL_l0o`H0oooo
02H4oookJP03o`3Ooooonf[oo`2k00;ooo]Z00[o^@3ooe_o0?oonf[ooo]Zooob0?n6o`3ooo]Zool0
m?nc0?ooo`2Z0_oonfX00ol0oa?ooo]ZohKo0006oookJP;o007o0_oonfX01Ol_0?oooo]Zooo00?l0
ojKoC`3o00Cooo]Z00Coo`2<oomo0?oonf[o0P3o0ooonfX01olMo`3oHol0ofWo0?nJ0?ooob40o`3o
^?l0old00_oonfX01?oo08Kooo]Zoh00oooonfX2ok;o00Cooo]Z00Co8ol0oomM0?oonf[o02co9Ooo
nfX00>Oooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`0004;ooo]Z00?o
I`3ooookJ_oonfX02OoonfX00ooo05gooo]ZoookJP05oookJP03ol<0oooonf[ooo]Z00?ooo]Z00?o
V@3ooookJ_m^0?l01_oonfX00ol0o`_ooo]ZoookJP04oookJP05o`2=oooonf[ooo]ZoookJ_ooV@00
0ooonfX00ol0B?oooo]ZoookJP05oookJP07of3o0?oonf[ooi00oookJ_oo0:3oo`2;ok`0o`02oook
JP03oiCo0?ooN@3oo`0V00?oU?l000?oogT0o`3Ooooo0;/00_ooN@003Oni0?ooFol0oookJ_oonf[o
oo80ohKo0?oonf[oo`3doomi0?oonf[oo`2ZoookJ_l0oa<00_oonfX00on6o`3ooo]ZoookJP03oook
JPCoiOl000Kooo]Zobl0oooo`03ool00o`3oY_m?0?l4oookJP03ooo90?ooO`3o0P3o00Cooo]Z00Wo
7Ol0of?o0?mYo`3oo`3?oookJ_l0okSo0?o=oookJ_oo08H00_oonfX00ooob@3o/_l0oookJP04oook
JP05ob?o0?ooG@3ooo]ZoookJ_l0;?l0oooonfX:oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo
001oo`00O`Oooo]Z1?l00012oookJP03ofL0oooonf[ooo]Z00Wooo]Z00?oo`1MoookJ_oonfX01Ooo
nfX00oo30?oooo]ZoookJP04oookJP03oiT0oom^0?oooo]Z00Gooo]Z00?o0?l;oookJ_oonfX01?oo
nfX01Ol0SOoooo]ZoookJ_oonf[ooiT000?ooo]Z00?o04SooookJ_oonfX01OoonfX03?mPo`3ooo]Z
oon@0?oonf[oo`2Pool0Rooonf[o_03ooookJ_mbo`3o1P3oool09PCooo]Z00?o0=oooookJ_oo0;/0
0_oonfX02_ni0?ooFol0oookJ_oonf[ooo80ohKo0?oonf[oo`3dok<0oooo0:X2oookJP03o`3o4ooo
nf[oQ_l000Kooo]Z00Wo007ooookJ_oonf[ooo]Zobl0oooonf[ool00o`3oY_m?0?l01?oonfX01?oo
08coogl0oookJ_l20?l3oookJP07oago0?mSo`3oJOl0oiX0oooonf[o0?nho`3oc@02oookJP05ool0
Q_oonf[oP03ooookJ_nbo`001OoonfX01?lSo`3ooed0oookJ_l0;?lVoookJP00e_oonfX:o`00O`;o
oo]Z2Ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX4o`0004;ooo]Z00?oI`3ooook
J_oonfX02?oonfX00ooo05gooo]ZoookJP05oookJP03ol<0oooonf[ooo]Z00?ooo]Z00?oV@3ooook
J_m^0?l01_oonfX00ol0o`_ooo]ZoookJP04oookJP05o`2=oooonf[ooo]ZoookJ_ooV@000ooonfX0
0ol0B?oooo]ZoookJP04oookJP;oogT000Kooo]Zoon@0?oonf[oo`2Pool0Ronl0?l2oookJP03oiCo
0?l60?ooo`0V00;oogT000CoU?l0oomi0?l0goooo`2k0_ooN@002oni0?ooogT0oookJ_oonf[ooo80
ohKo0?oonf[oo`3doomi0?oonf[oo`2Z00;oogT00_oonfX00on6o`3ooo]ZoookJP03oookJPCoiOl0
00Kooo]Zobl0oooo`03ooo]Zo`3oY_m?0?l4oookJP;oogl000?o0P3ooookJ_oonfX00_oonfX01?lM
o`3oHol0ofWo0?oonfX2o`3o^003o`3ocOoonf[oo`2600;ooo]Z00?oolT0ok;o0?oonfX01?oonfX0
1OlSo`3ooed0oookJ_oonf[o02co0?Wooo]Z2_l007l2oookJPWo001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`Kooo]Z1?l00012oookJP03ofL0oooonf[ooo]Z00Sooo]Z00?oo`1MoookJ_oonfX0
1OoonfX00oo30?oooo]ZoookJP04oookJP03oiT0oom^0?oooo]Z00Gooo]Z00?o0?l;oookJ_oonfX0
1?oonfX01Ol0SOoooo]ZoookJ_oonf[ooiT000?ooo]Z00?o04SooookJ_oonfX01OoonfX03?mPo`3o
oo]Zoon@0?oonf[oo`2Pool0Rooonf[o_03ooookJ_mbo`3o1P3oool09PCooo]Z00?o0=oooookJ_oo
0;/00_oonfX02oni0?ooFol0oookJ_oonf[ooo80ohKo0?oonf[oo`3dok<0oooo0:[ooo]Z00;o0?lC
00?ooo]ZohKo0?oonfX01OoonfX02Ol00Ooooo]ZoookJ_oonf[o;`3ooookJ_oo`03o0?nVodl0o`04
oookJP;oogl000?ooo]Zo`80oooonfX00_oonfX01olMo`3oHol0ofWo0?nJ0?oooo]Zo`3o^?l0old0
0_oonfX01Ooo08Kooo]Zoh00oooonf[o/_l000Gooo]Z00Co8ol0oomM0?oonf[o02co9ooonfX00=Ko
oo]Z2_l007l2oookJPWo001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z1_l0000ooook
JP03ofL0oooonf[ooo]Z00Sooo]Z00?oo`1MoookJ_oonfX01OoonfX00oo30?oooo]ZoookJP03oook
JP03oiT0oooonf[oKP3o00Kooo]Z00?o0?l;oookJ_oonfX01?oonfX01Ol0SOoooo]ZoookJ_oonf[o
oiT000?ooo]Z00?o04SooookJ_oonfX01?oonfX3oomi0005oon@0?oonf[oo`2Pool0Ronl0?l00_oo
nfX01?nDo`3o1P3oool09_oonfX3oomi0006o`3Ooooo0;_oogT0oomi0?ni0?ooogT00_oonfX01ooo
lP3oQ_l0oookJ_oo0?CoogT0oookJ_oo0:X00oooN@000ooonf[oQ_l0oookJP03oookJPGoiOl00_l_
0?l01?oo`03ooo]Zo`3oY_m?0?l4oookJP03oomo0?l20?oo0P3o00Cooo]Z00Wo7Ol0of?o0?mYo`3o
oo]Zo`3o^?oonf[o0?o=oookJ_oo08H00_oonfX00ooob@3o/_l0oookJP04oookJP06ob?o0?ooG@3o
oo]ZoookJ_l0;?oooo]Z0_l0noogoookJP[o001o0_oonfX9o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l6oookJPKo0000?ooonfX00omW0?oooo]ZoookJP08oookJP03ool0GOoonf[ooo]Z00Go
oo]Z00?o``3ooookJ_oonfX01?oonfX00onI0?ooKP3ooookJP05oookJP03o`3o2ooonf[ooo]Z00Co
oo]Z00Go08gooookJ_oonf[ooo]ZoonI0003oookJP03o`18oooonf[ooo]Z00Kooo]Z00_oH?l0oon@
0?oonf[oo`2Pool0Rooonf[o_03ooookJ_mbo`3o1P3oool09P04oookJP03o`3Ooooonf[oo`2k00;o
oo]Z00co^@3ooe_o0?oonf[ooo]Zooob0?n6o`3ooo]Zool0m?nc0?ooo`2ZoookJ_l0oa<2oookJP03
ohKo0?oonf[ooo]Z00Cooo]Z00?o007ooookJ_oonfX00_l_0?l01?oonf[ool00o`3oY_m?0?l4oook
JP04oomo0?oonf[o0P3oo`80o`?ooo]Z00Oo7Ol0of?o0?mYo`3oVP3ooookJ_l0okSo0?o=00;ooo]Z
00Goo`26oookJ_n00?oooo]Zok;o0004oookJP;o8ol000?ooed0oookJ_l0;?l00_oonfX2o`3kobCo
oo]Z003RoookJP;o001o0ooonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX4o`00043ooo]Z
00?oI`3ooookJ_oonfX02OoonfX00ooo05gooo]ZoookJP04oookJP03ol<0oooonf[ooo]Z00?ooo]Z
00?oV@3ooookJ_m^0?l01_oonfX00ol0o`_ooo]ZoookJP04oookJP05o`2=oooonf[ooo]ZoookJ_oo
V@000ooonfX00ol0B?oooo]ZoookJP03oookJPCoogT000Gooi00oookJ_oo0:3oo`2;ok`0o`02oook
JP03oiCo0?l60?ooo`0V00?ooo]Z00?oogT0o`3Ooooo0;/00_ooN@002_ni0?ooogT0oomi0?oonf[o
oo80ohKo0?oonf[oo`3doomi0?oonfX4oomi0003oookJ_n6o`3ooo]Z00;ooo]Z1ooUo`000ol0O?oo
ol00oookJP02odl0o`Cooo]Z00?oogl0o`80oooonfX01?oonfX02OlMo`3ooo]ZofWo0?oonf[o0?nh
oookJ_l0olgooo]Zool0QP02oookJP03ooo90?nbo`3ooo]Z00Cooo]Z00Oo8ol0oomM0?oonf[ooo]Z
o`0/oooonf[o0?_o0?oooo]Z1_oonfX2o`00O`?ooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`Ko
oo]Z1?l00010oookJP03ofL0oooonf[ooo]Z00Wooo]Z00?oo`1MoookJ_oonfX01?oonfX00oo30?oo
oo]ZoookJP04oookJP03oiT0oom^0?oooo]Z00Gooo]Z00?oj`3oo`3o2ooonfX01?oonfX01Ol0SOoo
oo]ZoookJ_oonf[ooiT000?ooo]Z00?o04SooookJ_oonfX01_oonfX02omPo`3ooi00oookJ_oo0:3o
o`2;oookJ_nl0?oooo]Zog;o0?l60?ooo`0V00Cooo]Z00?o0=oooookJ_oo0;/00_oonfX03?ni0?oo
Fol0oookJ_oonf[ooo80ohKo0?oonf[oo`3dok<0oooo0:[ooo]Zo`3o4`;ooo]Z00?oQ_l0oookJ_oo
nfX01?oonfX01ol00Ooooo]ZoookJ_l_0?oo07cooookJ_oo`0000_m?0?l4oookJP03oomo0?oonf[o
0P3o00Cooo]Z00Oo7Ol0oookJ_mYo`3oVP3ooookJ_l0okSo0?o=00;ooo]Z00Goo`26oookJ_n00?oo
oo]Zok;o0004oookJP05ob?o0?ooG@3ooed0oookJ_l0;?l00_oonfX00ol0nooooo]ZoookJP0Toook
JP00hooonfX2o`00O`;ooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0000ooookJP03
ofL0oooonf[ooo]Z00Wooo]Z00?oo`1MoookJ_oonfX01?oonfX00oo30?oooo]ZoookJP04oookJP03
oiT0oom^0?oooo]Z00Gooo]Z00?o0?l;on/0oooonfX01?oonfX00ol0SOoooo]ZoookJP02oookJP04
oonI0?oonf[ooo]Zo`18o`Gooo]Z1?ooN@001OooT03ooo]Zool0X?oo08_o_03o00;ooo]Z00?oU?l0
o`H0oooo02H01?oonfX01Ol0goooo`2koookJ_oonf[o^@3o00;oogT000Gooo]Zooob0?n6o`3ooo]Z
ool0m006oomi0004oookJ_n6o`3ooo]ZoookJPSoiOl000Go07coooo00?oonf[oC`3ooc?o0004oook
JP03oomo0?l20?oooo]Z00Cooo]Z00Wo7Ol0oiX0oomYo`3ooo]Zo`3o^?oonf[o0?o=oookJ_oo08H0
0_oonfX00ooob@3o/_l0oookJP04oookJP03ob?o0?ooG@3ooo]Z00;o02co00?ooo]Zo`3koooonfX0
oooonfX7oookJP;o001o0_oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX4o`0003oooo]Z
00?oI`3ooookJ_oonfX02OoonfX00ooo05gooo]ZoookJP04oookJP03ol<0oooonf[ooo]Z00Gooo]Z
00?oKP3ooookJ_oonfX01OoonfX00ol0o`_ooo]ZoookJP03oookJP03o`2=oooonf[ooo]Z00;ooo]Z
00CooiT0oookJ_oonf[o04So2?oonfX02omPo`3ooi00oookJ_oo0:3oo`2;oookJ_nl0?oooo]Zog;o
0?l60?ooo`0V00Cooo]Z00?o0=oooookJ_oo0;/00_oonfX03?ni0?ooFol0oookJ_oonf[ooo80ohKo
0?oonf[oo`3dok<0oooo0:[ooo]Zo`3o4`;ooo]Z00?oQ_l0oookJ_oonfX01?oonfX02Ol00Ooooo]Z
oookJ_l_0?oo07cooookJ_oo`03oC`3ooc?o0004oookJP03oomo0?oonf[o0P3o00Cooo]Z00Oo7Ol0
oookJ_mYo`3oVP3ooookJ_l0okSo0?o=00;ooo]Z00Goo`26oookJ_n00?oooo]Zok;o0004oookJP03
ob?o0?ooG@3ooo]Z00;o02co0_oonfX00ol0nooooo]ZoookJP0UoookJP00hooonfX3o`00O`04oook
J_l007oo001oo`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX4o`0003kooo]Z00?oI`3ooookJ_oo
nfX02OoonfX00ooo05gooo]ZoookJP04oookJP03ol<0oooonf[ooo]Z00Cooo]Z00?oV@3oofh0oooo
nfX01OoonfX00ol0o`_oj`3ooookJP04oookJP03o`2=oooonf[ooo]Z00;ooo]Z00CooiT0oookJ_oo
nf[o04So1?oonfX5oomi0005oon@0?oonf[oo`2Pool0Ronl0?l00_oonfX00onDo`3o1P3oool09P04
oookJP07o`3Ooooo0;_ooo]ZoookJ_ni0?ooFol0oomi0002ooob0003ohKo0?oonf[oo`3d00OoogT0
00?oQ_l0oookJ_oonfX02?oUo`001Ol0O?oool00oookJ_m?0?oo<ol000?ooo]Z00?oo`2<oomo0?l2
0?l01?oonfX2oago0006oiX0oomYo`3ooo]Zo`3o^?oonf[o0?o=0_oo08H2oookJP03ooo90?nbo`3o
oo]Z00Cooo]Z0_ooG@001Ooonf[o02cooookJ_oonf[o0?_o00;ooo]Z0_oooP3ooookJPGooo]Z0ol0
07l01?oonf[o001oo`00Ool007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0000noookJP03ofL0
oooonf[ooo]Z00Wooo]Z00?oo`1MoookJ_oonfX01OoonfX00oo30?oooo]ZoookJP04oookJP03ofh0
oooonf[ooo]Z00Gooo]Z00?o0?l;oookJ_oonfX00ooonfX00ol0SOoooo]ZoookJP02oookJP05oonI
0?oonf[ooo]ZoookJ_l0B?l01ooonfX02omPo`3ooi00oookJ_oo0:3oo`2;oookJ_nl0?oooo]Zog;o
0?l60?ooo`0V00Cooo]Z00?o0=oooookJ_oo0;/00_oonfX00oni0?ooFol0oookJP02ooob00;ooo]Z
00Goo`3dok<0oooo0:[ooo]Zo`3o4`02oookJP03ohKo0?oonf[ooo]Z00Cooo]Z00Wo007ooookJ_oo
nf[o;`3oo`1loooonf[ool00odl0oolco`000ooonfX01?oo08coogl0oookJ_l20?l3oookJP;o7Ol0
00Oooo]ZofWo0?oo8@3ooo]Zo`3o^?l0olgooo]Z00;oo`2600Cooo]Zoh00oooonf[o/_l01?oonfX0
1?lSo`3ooed0oookJ_l0;?l3oookJP03o`3koooonf[ooo]Z00;oooh09?oonfX00>Cooo]Z0_l007l0
1?oonf[o001oo`00Ool007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0000noookJP03ofL0oooo
nf[ooo]Z00Sooo]Z00?oo`1MoookJ_oonfX01?oonfX00oo30?oooo]ZoookJP04oookJP03oiT0oom^
0?oooo]Z00Kooo]Z00?o0?l;oookJ_oonfX00ooonfX00ol0SOoooo]ZoookJP02oookJP04oonI0?oo
nf[ooo]Zo`18o`Cooo]Z1OooN@001OooT03ooo]Zool0X?oo08_o_03o00;ooo]Z00?oU?l0o`H0oooo
02H01?oonfX03?l0goooo`2koookJ_oonf[o^@3ooe_o0?oonf[ooo80oookJ_n6o`3ooo]Zool0m0Oo
ogT000?oQ_l0oookJ_oUo`002?oUo`001Ol0O?oool00o`3oY_m?0?oo<ol000?ooo]Z00?oo`2<oomo
0?l20?l01?oonfX02OlMo`3o3@3ooiX0oomYo`3ooo]Zo`3o^?oonf[o0?o=ool0QP02oookJP03oh00
oooob@3o/_l000Gooo]Z00Cooed0oookJ_oonf[o02co0_oonfX01?l0nooooo]ZoookJ_oooP02ofko
0?oooo]Z1_oonfX2o`00O`04oookJ_l007oo001oo`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX4
o`0003kooo]Z00?oI`3ooookJ_oonfX02?oonfX00ooo05gooo]ZoookJP05oookJP03ol<0oooonf[o
oo]Z00Cooo]Z00?oKP3ooookJ_oonfX01OoonfX00ol0o`_ooo]ZoookJP03oookJP03o`2=oooonf[o
oo]Z00;ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`07oookJP0;of3o0?ooT03ooo]Zool0X?oo08_o
oo]Zok`0oooonf[oL_l0o`H0oooo02H01?oonfX00ol0gooooo]Zool0^`02oookJP06okT0oomKo`3o
oo]Zooob0?n6o`3ooo]Z0_oo0?@01?nc0?ooo`2ZoookJ_l0oa<2oookJP03ohKo0?oonf[ooo]Z00Co
oo]Z00Wo007ooookJ_oonf[o;`3oo`1loooonf[o0?nVodl0oolco`000ooonfX01?oo08coogl0oook
J_l20?l3oookJP0;oago0?l=0?oooo]ZofWo0?oo8@3ooo]Zo`3o^?l0olgooo]Zool0Q_oonfX00_n0
0?l00ooonf[o/_l0oookJP03oookJP04ob?o0?ooG@3ooo]Zo`0/o`?ooo]Z00Co0?_ooookJ_oonf[o
ooh00_m^o`0ToookJP00iOoonfX5o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX4o`0003gooo]Z
00?oI`3ooookJ_oonfX02?oonfX00ooo05gooo]ZoookJP04oookJP03ol<0oooonf[ooo]Z00Cooo]Z
00?oV@3oofh0oooonfX01_oonfX00ol0o`_ooo]ZoookJP03oookJP03o`2=oooonf[ooo]Z00;ooo]Z
00CooiT0oookJ_oonf[o04So1?oonfX5oomi000:oon@0?ooN@3oo`2PoookJ_oo08_o_03ooookJ_nD
o`3o1P3oool09PCooo]Z00_o0=ooool0^ooonf[ooo]ZokT0oomKo`3ooo]Zooob0?oonf[oQ_l0oook
JP09oomi0003oookJ_oUo`3oiOl000SoiOl000?ool00o`3oY_m?0?l01?oonfX00ooo08coogl0o`80
o`04oookJP09oago0?l=0?ooVP3oofWo0?oonf[o0?nhoookJ_l0olgoo`2600;ooo]Z00?oP03ooook
J_nbo`001OoonfX01?ooG@3ooo]ZoookJ_l0;?l2oookJP05o`3koooonf[ooo]Zooon0?m^o`00oooo
nfX9oookJPGo001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000?OoonfX00omW0?oooo]Zoook
JP08oookJP03ool0GOoonf[ooo]Z00Gooo]Z00?o``3ooookJ_oonfX01?oonfX00om^0?oooo]Zoook
JP05oookJP03o`3o2ooonf[ooo]Z00?ooo]Z00?o08gooookJ_oonfX00_oonfX01OooV@3ooo]Zoook
J_oonf[o04So00Oooo]Z00_oH?l0oon@0?oonf[oo`2PoookJ_oo08_ooo]Zok`0oombo`3o1P3oool0
9P04oookJP03o`3Ooooonf[oo`2k00;ooo]Z00co^@3ooe_o0?oonf[ooo80ohKo0?oonf[oo`3doook
J_nc0?ooo`2ZoookJ_l0oa<2oookJP03ohKo0?oonf[ooo]Z00Cooo]Z00So007ooookJ_oonf[o;`3o
o`1loooonf[o0?nVodl0o`Cooo]Z00Coo`2<oomo0?oonf[o0P3o0ooonfX03?lMo`3o3@3ooookJ_mY
o`3oob40oookJ_l0okSo0?o=oookJ_oo08Kooo]Zoh00o`;ooo]Z00?o/_l0oookJ_oonfX00_oonfX0
1?lSo`3ooed0oookJ_l0;?l3oookJP05o`3koooonf[oo`2Zooon0?m^o`009_oonfX00>Gooo]Z1Ol0
07l3oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`0003cooo]Z00?oI`3ooookJ_oonfX0
2?oonfX00ooo05gooo]ZoookJP05oookJP03ol<0oooonf[ooo]Z00?ooo]Z00?oV@3ooookJ_m^0?l0
1_oonfX00ol0o`_ooo]ZoookJP03oookJP03o`2=oooonf[ooo]Z00;ooo]Z00CooiT0oookJ_oonf[o
04So0ooonfX6oomi000;oon@0?ooN@3oo`2PoookJ_oo08_o_03ooookJ_nDo`3o1P3ooomi0?oo02H0
0ooonfX02ol0goooo`2koookJ_oonf[o^@3ooe_o0?oonf[ooo80oookJ_n6o`3ooo]Z00WoogT00ooo
nfX8onGo0003ooo00?l0ojKoC`3o00Cooo]Z00?oo`2<oomo0?l20?l01?oonfX02OlMo`3oHol0ofWo
0?mYo`3ooo]Zo`3o^?oonf[o0?o=ool0QP02oookJP03oh00oonbo`3o/_l000Cooo]Z00Go8ol0oomM
0?oonf[ooo]Zo`0/o`02oookJP06o`3koooonf[oolT0ooon0?m^o`3oolT00_ob0?oooookJPOooo]Z
1Ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`0003cooo]Z00?oI`3ooookJ_oo
nfX02?oonfX00ooo05gooo]ZoookJP05oookJP03ol<0oooonf[ooo]Z00Cooo]Z00?oV@3oofh0oooo
nfX01OoonfX00ol0o`_ooo]ZoookJP03oookJP03o`2=oooonf[ooo]Z00;ooo]Z00GooiT0oookJ_oo
nf[ooo]Zo`18o`07oookJP0<of3o0?ooT03ooo]ZoookJ_oo0:3oo`2;oookJ_nl0?ooL_l0o`H0oomN
o`3oo`0V0ooonfX00ol0gooooo]Zool0^`02oookJP0<okT0oomKo`3ooo]Zooob0?n6o`3ooo]Zool0
m?oonf[o/`3oool0Z_oonf[o0?lC0_oonfX00on6o`3ooo]ZoookJP04oookJP08o`01oooonf[ooo]Z
obl0ool0O?oooo]Zo`3oY_m?0?l4oookJP04ool0S?ooO`3ooo]Zo`80o`?ooo]Z00Co7Ol0of?o0?mY
o`3oJOl00_oonfX01ol0okSo0?o=oookJ_oo08Kooo]Zoh00oooonfX00_nbo`03oookJP;o8ol000?o
oed0oookJ_l0;?l00ooonfX01_l0nooooo]Zool0Z_oooP3oK_l0oookJP;olP3o9?oonfX00>Kooo]Z
1?l007l3oookJPOo001o1ooonfX4o`0003_ooo]Z00?oI`3ooookJ_oonfX02OoonfX00ooo05gooo]Z
oookJP04oookJP03ol<0oooonf[ooo]Z00?ooo]Z00?oV@3ooookJ_m^0?l01_oonfX00ol0o`_ooo]Z
oookJP03oookJP03o`2=oooonf[ooo]Z00;ooo]Z00CooiT0oookJ_oonf[o04So0ooonfX6oomi000;
oon@0?ooN@3oo`2PoookJ_oo08_o_03ooookJ_nDo`3o1P3ooomi0?oo02H00ooonfX03Ol0goooo`2k
oookJ_oonf[o^@3ooe_o0?oonf[ooo80oookJ_n6o`3ooo]Zoomi0?nc0?l01oooN@05oookJPKoiOl0
00?ool00o`3oY_m?0?l01?oonfX00ooo08coogl0o`80o`04oookJP06oago0?mSo`3oJOl0oolQ0?oo
nf[o0?nh0_l0old01Ooo08Kooo]ZoookJ_n00?oo/_l000Gooo]Z00Go8ol0oomM0?oonf[ooo]Zo`0/
o`02oookJP07o`3koooob@3oolT0ooon0?m^o`3oolT0oo80o`02ool0>ooooo]Z2?oonfX4o`00O`?o
oo]Z1ol007l7oookJPCo0000>ooonfX00omW0?oooo]ZoookJP09oookJP03ool0GOoonf[ooo]Z00Co
oo]Z00?o``3ooookJ_oonfX01?oonfX00onI0?ooKP3ooookJP05oookJP03on/0ool0o`_ooo]Z00?o
oo]Z00?o08gooookJ_oonfX00_oonfX01OooV@3ooo]ZoookJ_oonf[o04So00Oooo]Z00coH?l0oon@
0?oonf[ooo]Zool0X?oo08_ooo]Zok`0oombo`3o1P3ooeko0?oo02H3oookJP03o`3Ooooonf[oo`2k
00;ooo]Z00co^@3ooe_o0?oonf[ooo80ohKo0?oonf[oo`3doookJ_nc0?ooo`2ZoookJ_l0oa<2oook
JP03ohKo0?oonf[ooo]Z00Cooo]Z00Co007ooookJ_oonf[o;`3o0_oonfX00ol0ojKoC`3ooookJP03
oookJP04ool0S?ooO`3o0P3oo`80o`?ooo]Z00Co7Ol0of?o0?mYo`3oVP3o0_oonfX2o`3oc@06oook
J_oo08Kooo]Zoh00oooonf[o/_l01?oonfX01OlSo`3ooed0oomM0?oonf[o02co00;ooo]Z0_l0nol0
1_oonf[oo`2Zooon0?m^o`3ooo]Zoo80o`;oo`0k9?oonfX00>Oooo]Z0ol007l4oookJPGo001o2?oo
nfX4o`0003[ooo]Z00?oI`3ooookJ_oonfX02OoonfX00ooo05gooo]ZoookJP04oookJP03ol<0oooo
nf[ooo]Z00?ooo]Z00?oV@3ooookJ_m^0?l01_oonfX00ol0o`_ooo]ZoookJP03oookJP03o`2=oooo
nf[ooo]Z00;ooo]Z00CooiT0oookJ_oonf[o04So0ooonfX6oomi000;oon@0?ooN@3oo`2PoookJ_oo
08_o_03ooookJ_mbo`3o1P3ooomi0?oo02H00ooonfX03Ol0goooo`2koookJ_oonf[o^@3ooe_o0?oo
nf[ooo80oookJ_n6o`3ooo]Zool0m?nc0?l02?ooN@05oookJPKoiOl000?o0?nVodl0oooonfX00ooo
nfX00ooo08coogl0o`80o`04oookJP04oago0?mSo`3oJOl0oolQ00;o0?nh00?o0?o=oookJ_oo08H0
0_oonfX00on00?oo/_l0oookJP04oookJP03ob?o0?ooG@3ooo]Z00;o02co0_oonfX3ooo90005ooon
0?m^o`3oolT0oo80oooo03/0oooonfX;oookJP?o001o1?oonfX5o`00O`Sooo]Z1?l0000joookJP03
ofL0oooonf[ooo]Z00Wooo]Z00?oo`1MoookJ_oonfX01?oonfX00oo30?oooo]ZoookJP04oookJP03
oiT0oom^0?oooo]Z00Kooo]Z00?o0?l;oookJ_oonfX00_oonfX00ol0SOoooo]ZoookJP02oookJP05
oonI0?oonf[ooo]ZoookJ_l0B?l01ooonfX03?mPo`3ooi00oookJ_oonf[oo`2Pool0Rooonf[o_03o
oookJ_mbo`3oG_l0ool09P?ooo]Z00?o0=oooookJ_oo0;/00_oonfX03?ni0?ooFol0oookJ_oolP3o
Q_l0oookJ_oo0?Cooo]Zok<0oooo0:[ooo]Zo`3o4`;ooo]Z00?oQ_l0oookJ_oonfX01?oonfX01?l0
0Ooooo]ZoookJ_l_0?l2oookJP03o`3oY_m?0?oooo]Z00?ooo]Z00?oo`2<oomo0?l20?l01?oonfX0
1olMo`3oHol0ofWo0?nJ0?oooo]Zo`3o^?l0old00_oonfX01Ooo08Kooo]Zoh00oooonf[o/_l000Co
oo]Z00Go8ol0oomM0?oonf[ooo]Zo`0/o`02oookJP09o`3koooonf[ooo]Zool0Z_oooP3oK_l0oook
J_ob0?ooo`0k02Kooo]Z003koookJPCo0000>_oonfX00omW0?oooo]ZoookJP08oookJP03ool0GOoo
nf[ooo]Z00Cooo]Z00?o``3ooookJ_oonfX00ooonfX00onI0?oooo]Zofh0o`06oookJP03o`3o2ooo
nf[ooo]Z00?ooo]Z00?o08gooookJ_oonfX00_oonfX01?ooV@3ooo]ZoookJ_l0B?l5oookJPCoogT0
00_ooi00oomi0?oo0:3oogT0ool0Ronl0?oooo]Zog;o0?l60?ooogT0ool09P03oookJP0?o`3Ooooo
0;_ooo]ZoookJ_ni0?ooFol0oookJ_oolP3ooo]ZohKo0?oonf[oo`3dok<0oooonf[oo`2Z00KoogT0
1OoonfX00ooUo`3ooo]ZoookJP03onGo0003o`3oY_m?0?oooo]Z00?ooo]Z00?oo`2<oomo0?l20?l0
1?oonfX02OlMo`3oVP3oofWo0?oo0<oo0?nhoookJ_l0olgooo]Zool0QP02oookJP03oh00oonbo`3o
oo]Z00Cooo]Z00Co8ol0oomM0?oonf[o02co0_oonfX4ooo90005ooon0?m^o`3oolT0oo80oooo03/0
oooonfXPoookJPCo0000>_oonfX00omW0?oooo]ZoookJP08oookJP03ool0GOoonf[ooo]Z00Gooo]Z
00?o``3ooookJ_oonfX00ooonfX00onI0?ooKP3ooookJP06oookJP03o`3o2ooonf[ooo]Z00;ooo]Z
00?o08gooookJ_oonfX00_oonfX01OooV@3ooo]ZoookJ_oonf[o04So00Oooo]Z00coH?l0oon@0?oo
nf[ooo]Zool0X?oo08_ooo]Zok`0oooonf[oL_l0oeko0?oo02H3oookJP03o`3Ooooonf[oo`2k00;o
oo]Z00co^@3ooe_o0?oonf[ooo80ohKo0?oonf[oo`3doookJ_nc0?ooo`2ZoookJ_l0oa<2oookJP03
ohKo0?oonf[ooo]Z00Cooo]Z00Co007ooookJ_oonf[o;`3o0_oonfX00ol0ojKoC`3ooookJP03oook
JP03ool0S?ooO`3o0P3o00Cooo]Z00Oo7Ol0oookJ_mYo`3oVP3ooookJ_l0okSo0?o=00;ooo]Z00Go
o`26oookJ_n00?oooo]Zok;o0004oookJP05ob?o0?ooG@3ooo]ZoookJ_l0;?l00_oonfX02Ol0nooo
oo]ZoookJ_oo0:[oooh0ofko0?oonf[olP3oool0>`0WoookJP00nooonfX4o`0003Wooo]Z00?oI`3o
oookJ_oonfX02?oonfX00ooo05gooo]ZoookJP04oookJP03ol<0oooonf[ooo]Z00Cooo]Z00?oV@3o
ofh0oooonfX01OoonfX00ol0o`_ooo]ZoookJP03oookJP03o`2=oooonf[ooo]Z00;ooo]Z00CooiT0
oookJ_oonf[o04So1ooonfX2oomi000;oomO0?ooT03oo`2Poomi0?oo08_o_03ooookJ_mbo`3o1P3o
oeko0?oo02H00ooonfX04?l0goooo`2koookJ_oonf[o^@3ooe_o0?oonf[ooo80oookJ_n6o`3ooo]Z
ool0m?nc0?oooo]Zool0Z_oonfX6oomi00Cooo]Z00SoiOl0oookJ_oonf[o;`3oooo00?oUo`3o0?nV
odl0o`Cooo]Z0_ooO`000ol20?oooo]ZoookJP02oookJP09oago0?nJ0?ooJOl0ool0col0okSooo]Z
o`3ocOoonf[oo`2600;ooo]Z00?oP03ook;o0?oonfX01?oonfX01OlSo`3ooed0oookJ_l0;?oooo]Z
00CoolT00_oooP001?m^o`3oolT0oo80oooo03_ooookJR7ooo]Z1?l0000ioookJP03ofL0oooonf[o
oo]Z00Sooo]Z00?oo`1MoookJ_oonfX01OoonfX00oo30?oooo]ZoookJP04oookJP03ofh0oooonf[o
oo]Z00Gooo]Z00?o0?l;oookJ_oonfX00_oonfX00ol0SOoooo]ZoookJP02oookJP05oonI0?oonf[o
oo]ZoookJ_l0B?l01ooonfX03?mPo`3ooel0oon@0?oonf[oo`2Pool0Rooonf[o_03ooookJ_mbo`3o
037oool09P?ooo]Z00?o0=oooookJ_oo0;/00_oonfX03?ni0?ooFol0oookJ_oolP3oQ_l0oookJ_oo
0?Cooo]Zok<0oooo0:[ooo]Zo`3o4`;ooo]Z00?oQ_l0oookJ_oonfX01?oonfX02?l00Ooooo]Zoook
J_l_0?oooo]Zooo00?l0ojKoC`3o1?oonfX2oomo0003o`80oooonf[ooo]Z00;ooo]Z00Oo7Ol0oook
J_mYo`3oob40oookJ_l0okSo0?o=00;ooo]Z00Goo`26oookJ_n00?oooo]Zok;o0004oookJP03ob?o
0?ooG@3ooo]Z00;o02co0_oonfX01?l0nooooo]ZoookJ_oooP02ofko00;olP3o00?oo`0koookJ_oo
nfX09_oonfX00?_ooo]Z1?l0000hoookJP03ofL0oooonf[ooo]Z00Sooo]Z00?oo`1MoookJ_oonfX0
1?oonfX00oo30?oooo]ZoookJP04oookJP03oiT0oom^0?oooo]Z00Gooo]Z00?o0?l;on/0oooonfX0
0ooonfX00ol0SOoooo]ZoookJP03oookJP03oonI0?oonf[o04So00Sooo]Z00coogT0oomO0?ooT03o
o`2Poomi0?oo08_o_03ooookJ_mbo`3o1P3ooeko0?oo02H3oookJP0Ao`3Ooooo0;_ooo]ZoookJ_ni
0?ooFol0oookJ_oolP3ooo]ZohKo0?oonf[oo`3dok<0oooonf[oo`2ZoookJ_ooN@000_oonfX3oomi
00Cooo]Z00SoiOl0oookJ_oonf[o;`3oooo00?oonf[o0?nVodl0o`Cooo]Z00?oogl0o`80ool20?l0
1?oonfX02OlMo`3oVP3oofWo0?oo0<oo0?nhoookJ_l0olgooo]Zool0QP02oookJP03oh00oonbo`3o
oo]Z00Cooo]Z0_ooG@000ooonf[o02coooo90004ooo90006ooon0?oob@3oK_l0ooo90?ob0?ooo`0k
0ooonfX2o`1?oooooo]Z7OoonfX4o`0003Sooo]Z00?oI`3ooookJ_oonfX02?oonfX00ooo05gooo]Z
oookJP05oookJP03ol<0oooonf[ooo]Z00Cooo]Z00?oV@3oofh0oooonfX01OoonfX00ol0o`_ooo]Z
oookJP02oookJP03o`2=oooonf[ooo]Z00?ooo]Z00CooiT0oookJ_oonf[o04So1ooonfX03?mPo`3o
oel0oon@0?oonf[oo`2Pool0Rooonf[o_03ooookJ_mbo`3o037oool09P?ooo]Z00?o0=oooookJ_oo
0;/00_oonfX03?ni0?ooFol0oookJ_oolP3oQ_l0oookJ_oo0?Cooo]Zok<0oooo0:[ooo]Zo`3o4`;o
oo]Z00?oQ_l0oookJ_oonfX01?oonfX02?l00Ooooo]ZoookJ_l_0?oooo]Zooo00?l0ojKoC`3o1?oo
nfX00oooO`3ooo]Zo`80o`04oookJP08oago0?oonf[oJOl0oolQ0?oonf[o0?nho`3ocOoonfX2ool0
QP04oookJ_n00?oooo]Zok;o00Cooo]Z00Co8ol0oomM0?oonf[o02co0ooonfX02Ol0nooooo]Zoook
J_oooP3oK_l0oookJ_ob0?oooo]Zool0>`03oookJP;o04oo9?oonfX00?_ooo]Z1?l0000goookJP03
ofL0oooonf[ooo]Z00Wooo]Z00?oo`1MoookJ_oonfX00ooonfX00oo30?oooo]ZoookJP04oookJP03
oiT0oom^0?oooo]Z00Gooo]Z00?o0?l;on/0oooonfX00ooonfX00ol0SOoooo]ZoookJP03oookJP03
oonI0?oonf[o04So00Sooo]Z00coogT0oomO0?ooT03oo`2Poomi0?oo08_o_03ooookJ_mbo`3oogT0
oeko0?oo02H3oookJP0Ao`3Ooooo0;_ooo]ZoookJ_ni0?ooFol0oookJ_oolP3ooo]ZohKo0?oonf[o
o`3dok<0oooonf[oo`2ZoookJ_ooN@000_oonfX00on6o`3ooo]Zoomi0004oookJP08onGo0?oonf[o
oo]Zobl0oooo`03ooo]Zo`3oY_m?0?l4oookJP03oomo0?l20?oooo]Z00Cooo]Z00[o7Ol0oiX0oomY
o`3ooo]Zo`3o^?oonf[o0?o=oookJ_oo08Kooo]Z0_n00?l00onbo`3ooo]ZoookJP02oookJP05ob?o
0?ooG@3ooo]ZoookJ_l0;?l01Ooob@001_oooP3oolT0ofko0?oob@3olP3oool0>`?ooo]Z00?o04oo
ool0/Ooo0;40oooonfXMoookJPCo0000=ooonfX00omW0?oooo]ZoookJP09oookJP03ool0GOoonf[o
oo]Z00Cooo]Z00?o``3ooookJ_oonfX01?oonfX00onI0?ooKP3ooookJP05oookJP03o`3o2ooonf[o
oo]Z00;ooo]Z00?o08gooookJ_oonfX00ooonfX01?ooV@3ooo]ZoookJ_l0B?l7oookJP0<of3o0?oo
G`3ooi00oookJ_oo0:3oo`2;oookJ_nl0?oooo]Zog;o0?l0<Oooo`0V0ooonfX00ol0gooooo]Zool0
^`02oookJP0<okT0oomKo`3ooo]Zooob0?n6o`3ooo]Zool0m?oonf[o/`3oool0Z_oonf[o0?lC0_oo
nfX00on6o`3ooo]ZoookJP04oookJP08o`01oooonf[ooo]Zobl0oooonf[ool00o`3oY_m?0?l4oook
JP03oomo0?oonf[o0P3o00Cooo]Z00Wo7Ol0oookJ_mYo`3oob40oookJ_l0okSo0?o=oookJ_oo08H0
0_oonfX00on00?oooo]Zok;o0004oookJP04ob?o0?ooG@3ooo]Zo`0/o`?ooo]Z00Oo0?_ooookJ_oo
nf[oooh0ofko0?oonf[olP3o00;oo`0k0ooonfX00ol0Coooo`2aool0/@0ToookJP00nooonfX4o`00
03Oooo]Z00?oI`3ooookJ_oonfX02?oonfX00ooo05gooo]ZoookJP03oookJP03ol<0oooonf[ooo]Z
00Cooo]Z00?oV@3oofh0oooonfX01_oonfX00ol0o`_ooo]ZoookJP02oookJP03o`2=oooonf[ooo]Z
00?ooo]Z00?ooiT0oookJ_l0B?l02?oonfX03?ooN@3ooel0oon@0?oo0:3ooo]Zool0Ronl0?oooo]Z
og;o0?ooN@3oG_l0ool09P?ooo]Z017o0=ooool0^ooonf[ooo]ZokT0oomKo`3ooo]Zooob0?oonf[o
Q_l0oookJ_oo0?Co/`3ooookJ_oo0:[ooo]Zoomi0002oookJP03ohKo0?oonf[ooo]Z00Cooo]Z00So
iOl0oookJ_oonf[o;`3oooo00?oonf[o0?nVodl0o`Cooo]Z00?oogl0o`80oooonfX01?oonfX03OlM
o`3oVP3oofWo0?oonf[o0?nhoookJ_l0olgooo]Zool0Q_oonf[oP03ooookJ_nbo`001?oonfX01_lS
o`3ooed0oookJ_oonf[o02cooookJPCoolT000Koooh0ooo90?m^o`3oolT0oo80oooob@03oookJP04
o`1?oooo0;7ooo]Zoonk0?oooo]Z7OoonfX4o`0003Oooo]Z00?oI`3ooookJ_oonfX02?oonfX00ooo
05gooo]ZoookJP04oookJP03ol<0oooonf[ooo]Z00Cooo]Z00?oV@3oofh0oooonfX01_oonfX01Ol0
o`_ooo]ZoookJ_oonf[o08go00Gooo]Z00CooiT0oookJ_oonf[o04So1ooonfX03?mPo`3ooel0oon@
0?oonf[oo`2Pool0Rooonf[o_03ooookJ_mbo`3o1P3oool09P?ooo]Z00?o0=oooookJ_oo0;/00_oo
nfX03?ni0?ooFol0oookJ_oolP3oQ_l0oookJ_oo0?Cooo]Zok<0oooo0:[ooo]Zo`3o4`;ooo]Z00?o
Q_l0oookJ_oonfX01?oonfX02?l00Ooooo]ZoookJ_l_0?oooo]Zooo00?l0ojKoC`3o1?oonfX00ooo
O`3ooo]Zo`80o`04oookJP03oago0?oonf[oJOl000;ooo]Z00Co0?nho`3ocOoonf[oo`260_oonfX0
0on00?oooo]Zok;o0004oookJP;ooed000Cooo]Zo`0/oooonf[ooo]Z0_l0nol01ooonf[oo`2Zooon
0?m^o`3ooo]Zoo80oooo03/01?oonfX01?l0Coooo`2aoonk0?oo^`0ToookJP00nooonfX4o`0003Ko
oo]Z00?oI`3ooookJ_oonfX02?oonfX00ooo05gooo]ZoookJP04oookJP03ol<0oooonf[ooo]Z00?o
oo]Z00?oV@3ooookJ_m^0?l01_oonfX01?l0o`_ooo]ZoookJ_oonfX2oomi00Gooo]Z00?ooiT0oook
J_l0B?l02?oonfX03?ooN@3ooel0oon@0?oo0:3ooo]Zool0Ronl0?oooo]Zog;o0?ooN@3oG_l0ool0
9P?ooo]Z017o0=ooool0^ooonf[ooo]ZokT0oomKo`3ooo]Zooob0?oonf[oQ_l0oookJ_oo0?Co/`3o
oookJ_oo0:[ooo]Zoomi0002oookJP03ohKo0?oonf[ooo]Z00Cooo]Z00SoiOl0oookJ_oonf[o;`3o
ooo00?oonf[o0?nVodl0o`?ooo]Z00?oo`2<oomo0?l20?l01OoonfX01olMo`3oVP3oofWo0?oonf[o
0?nhoookJ_l0old00_oo08H01?oonf[oP03ook;o0?nbo`04oookJP03ob?o0?ooG@3ooo]Z00;o02co
0_oonfX01_l0noooolT0ooo90?oooP3oolT0ofko00;olP3o00SoolT0oookJ_oonf[ooo]Zo`1?oooo
0;7ooo]Zoonk0?oooo]Z7_oonfX4o`0003Kooo]Z00?oI`3ooookJ_oonfX02?oonfX00ooo05gooo]Z
oookJP05oookJP03ol<0oooonf[ooo]Z00?ooo]Z00?oV@3oofh0oooonfX01_oonfX01Ol0o`_ooo]Z
oookJ_oonf[o08go00Gooo]Z00CooiT0oookJ_oonf[o04So1ooonfX03?mPo`3ooel0oon@0?oonf[o
o`2Pool0Rooonf[o_03ooookJ_mbo`3o1P3oool09P?ooo]Z00?o0=oooookJ_oo0;/00_oonfX03?ni
0?ooFol0oookJ_oolP3oQ_l0oookJ_oo0?Cooo]Zok<0oooo0:[ooo]Zo`3o4`;ooo]Z00?oQ_l0oook
J_oonfX01?oonfX02?l00Ooooo]ZoookJ_l_0?oooo]Zooo00?l0ojKoC`3o0ooonfX01?oo08coogl0
oookJ_l20?l4oookJP03oago0?oonf[oJOl000;ooo]Z00Co0?nho`3ocOoonf[oo`260_oonfX00on0
0?oo/_l0ok;o0003oookJP05ob?o0?ooG@3ooo]ZoookJ_l0;?l00_oonfX01_l0nooooo]ZoookJ_oo
0:[oooh0ofko00;olP3o00Coo`0koookJ_oonf[ooo]Z0_l0Col00ooo0;7ook/0oookJP0UoookJP00
nooonfX4o`0003Gooo]Z00?oI`3ooookJ_oonfX02?oonfX00ooo05gooo]ZoookJP04oookJP03ol<0
oooonf[ooo]Z00Cooo]Z00?oV@3oofh0oooonfX01OoonfX01?l0o`_ooo]ZoookJ_oonfX3oomi00Co
oo]Z00?ooiT0oookJ_l0B?l02?oonfX03OooN@3ooo]Zoon@0?oo0:3ooo]Zool0Rooonf[o_03oog;o
0?ooN@3oG_l0ool09_ooN@000_oonfX04_l0goooo`2koookJ_oonf[o^@3ooe_o0?oonf[ooo80oook
J_n6o`3ooo]Zool0m?nc0?oooo]Zool0Z_oonf[oogT0oookJP;oQ_l01_oonfX02?oUo`3ooo]Zoook
J_l_0?oool00oookJ_l0ojKoC`3o0ooonfX00ooo08coogl0o`80o`04oookJP;o7Ol000OoVP3oofWo
0?oonf[o0?nhoookJ_l0olgoo`2600;ooo]Z00?oP03ook;o0?oonfX01?oonfX01?lSo`3ooed0oook
J_l0;?l3oookJP07o`3koooonf[ooo]Zooon0?oob@3oK_l0oo80o`02ooo900?ooo]Z00Co04ooool0
/Ooo^`3ook/00_oo03?ooookJQgooo]Z1?l0000eoookJP03ofL0oooonf[ooo]Z00Sooo]Z00?oo`1M
oookJ_oonfX01OoonfX00oo30?oooo]ZoookJP03oookJP03oiT0oom^0?oooo]Z00Kooo]Z00?o0?l;
oookJ_oonfX00_oonfX00ol0SOoooo]ZoookJP02oookJP04oonI0?oonf[ooo]Zo`18o`Oooo]Z00co
H?l0oookJ_ooT03ooo]Zool0X?oo08_ooo]Zok`0oooonf[oL_l0o`H0oooo02H3oookJP03o`3Ooooo
nf[oo`2k00;ooo]Z00co^@3ooe_o0?oonf[ooo80ohKo0?oonf[oo`3doookJ_nc0?ooo`2ZoookJ_l0
oa<2oookJP03ohKo0?oonf[ooo]Z00Cooo]Z00So007ooookJ_oonf[o;`3ooookJ_oo`03o0?nVodl0
o`?ooo]Z00Coo`2<oomo0?l20?oo0P3o0ooonfX2oago0009oookJ_mYo`3ooo]ZoookJ_l0okSo0?o=
oookJ_oo08Kooo]Z00;oP03o00?o/_l0oookJ_oonfX00_oonfX01OlSo`3ooed0oookJ_oonf[o02co
00;ooo]Z00Wo0?_ooookJ_oonf[oo`2Zooon0?m^o`3olP3ooookJ_oo03/00ooonfX01Ol0Cooooo]Z
oonk0?oo^`3ooo]Z00;oo`0c9?oonfX00?_ooo]Z1?l0000eoookJP03ofL0oooonf[ooo]Z00Oooo]Z
00?oo`1MoookJ_oonfX01?oonfX00oo30?oooo]ZoookJP04oookJP03oiT0oom^0?oooo]Z00Gooo]Z
00?o0?l;oookJ_oonfX01?ooN@04oookJP03oonI0?oonf[o04So00Sooo]Z00googT0oookJ_ooT03o
o`2PoookJ_oo08_ooo]Zok`0oombo`3oogT0oeko0?oo02KoogT000;ooo]Z01?o0=ooool0^ooonf[o
oo]ZokT0oomKo`3ooo]Zooob0?oonf[oQ_l0oookJ_oo0?Co/`3ooookJ_oo0:[ooo]Zoomi0?oonf[o
Q_l000Oooo]Z00SoiOl0oookJ_oonf[o;`3oooo00?oonf[o0?nVodl0o`?ooo]Z00?oo`2<oomo0?l2
0?l01?oonfX02OlMo`3o3@3ooiX0oomYo`3ooo]Zo`3o^?oonf[o0?o=ool0QP02oookJP03oh00oonb
o`3ooo]Z00Cooo]Z00Co8ol0oomM0?oonf[o02co0ooonfX01ol0nooooo]ZoookJ_oooP3ooo]Zofko
0?ob0?l00ooob@02oookJP05o`1?oooo0;7ook/0oookJ_oo03<0oooonfXOoookJPCo0000=OoonfX0
0omW0?oooo]ZoookJP07oookJP03ool0GOoonf[ooo]Z00Gooo]Z00?o``3ooookJ_oonfX00ooonfX0
0onI0?ooKP3ooookJP06oookJP03o`3o2ooonf[ooo]Z00;ooo]Z00?o08gooookJ_oonfX00_oonfX0
1?ooV@3ooo]ZoookJ_l0B?l7oookJP0<of3o0?oonf[ooi00oookJ_oo0:3oo`2;oookJ_nl0?oooo]Z
og;o0?l60?ooo`0V0ooonfX00ol0gooooo]Zool0^`02oookJP0<okT0oomKo`3ooo]Zooob0?n6o`3o
oo]Zool0m?oonf[o/`3oool0Z_oonf[o0?lC0_oonfX00on6o`3ooo]ZoookJP04oookJP08o`01oooo
nf[ooo]Zobl0oooonf[ool00o`3oY_m?0?l3oookJP03ool0S?ooO`3o0P3o00Cooo]Z00Co7Ol0o`d0
oooonf[oJOl00_oonfX02?l0okSo0?o=oookJ_oo08Kooo]Zoh00oooonf[o/_l01?oonfX01OlSo`3o
oed0oookJ_oonf[o02co00;ooo]Z00Oo0?_ooookJ_oonf[oo`2Zooon0?m^o`3olP3o00;oo`0k0ooo
nfX00ol0Coooo`2aoonk0002oookJP03ool0<ooonf[ooo]Z02Cooo]Z003koookJPCo0000=?oonfX0
0omW0?oooo]ZoookJP08oookJP03ool0GOoonf[ooo]Z00?ooo]Z00?o``3ooookJ_oonfX01?oonfX0
0onI0?ooKP3ooookJP05oookJP03o`3o2ooonf[ooo]Z00GoogT00ooonfX00oooV@3ooo]Zo`18o`08
oookJP0=oomi0?oonf[ooi00ool0X?oonf[oo`2;oookJ_nl0?ooL_l0oomi0?mNo`3oo`0Voomi0002
oookJP0Co`3Ooooo0;_ooo]ZoookJ_ni0?ooogT0oookJ_oolP3ooo]ZohKo0?oonf[oo`3dok<0oooo
nf[oo`2ZoookJ_ooN@3ooo]ZohKo0007oookJP08onGo0?oonf[o07coobl0oooo`03ooo]Zo`3oY_m?
0?l3oookJP03ool0S?ooO`3o0P3o00Cooo]Z00Wo7Ol0oiX0oonJ0?ooJOl0oookJ_l0okSooo]Zo`3o
cOoo08H00_oonfX00on00?oo/_l0oookJP03oookJP;o8ol000?ooed0oookJ_l0;?l00ooonfX01?l0
nooooo]Zooon0?oooP02ofko0005oo80oooob@3oolT0ooo90?oonfX00_oob@001?oo0;7ook/0oook
J_oo03?ooookJR3ooo]Z1?l0000doookJP03ofL0oooonf[ooo]Z00Sooo]Z00?oo`1MoookJ_oonfX0
1?oonfX00oo30?oooo]ZoookJP03oookJP03oiT0oooonf[oKP3o00Kooo]Z00?o0?l;oookJ_oonfX0
0_oonfX00ol0SOoooo]ZoookJP02oookJP04oonI0?oonf[ooo]Zo`18o`Oooo]Z00coH?l0oookJ_oo
T03ooo]Zool0X?oo08_ooo]Zok`0oooonf[oL_l0o`H0oooo02H3oookJP03o`3Ooooonf[oo`2k00;o
oo]Z00co^@3ooe_o0?oonf[ooo80ohKo0?oonf[oo`3doookJ_nc0?ooo`2ZoookJ_l0oa<2oookJP03
ohKo0?oonf[ooo]Z00Cooo]Z00So007ooookJ_l0O?oo;`3ooookJ_oo`03o0?nVodl0o`?ooo]Z00?o
o`2<oomo0?l20?l01?oonfX01?lMo`3o3@3ooiX0oomYo`02oookJP08o`3o^?l0olgooo]Zool0Q_oo
nf[oP03ooookJ_nbo`04oookJP05ob?o0?ooG@3ooo]ZoookJ_l0;?l00_oonfX01?l0nooooo]Zoook
J_oooP02ofko0003oo80oooo03_ooo]Z00;ooo]Z0_l0Col01Ooo0;7ook/0oookJ_oonf[oo`0c02Oo
oo]Z003koookJPGo0000<_oonfX00omW0?oooo]ZoookJP08oookJP03ool0GOoonf[ooo]Z00?ooo]Z
00?o``3ooookJ_oonfX01?oonfX00onI0?ooKP3ooookJP04oookJP03oomi0?l0o`_ooo]Z00KoogT0
0ooonfX00oooV@3ooo]Zo`18o`08oookJP0<oomi0?oonf[ooi00ool0X?oonf[oo`2;oookJ_nl0?oo
L_l0oomi0?mNo`3oo`0V0_ooN@001_oonf[o0=ooool0^ooonf[oogT0okT0o`;oogT000cooo80oook
J_n6o`3ooo]Zool0m?nc0?oooo]Zool0Z_oonf[oogT0oookJ_n6o`07oookJP08onGo0?oonf[o07co
obl0oooo`03ooo]Zo`3oY_m?0?l3oookJP03ool0S?ooO`3o0P3o00Cooo]Z00Wo7Ol0oiX0oomYo`3o
JOl0oookJ_l0okSooo]Zo`3ocOoo08H00_oonfX00on00?oo/_l0oookJP03oookJP05ob?o0?oonf[o
oed0oookJ_l0;?l00ooonfX01ol0nooooo]Zooon0?oo<03oK_l0oookJ_ob0?l00_oonfX3ooo900;o
o`2a00?ook/0oookJ_oo03<0oooonfXQoookJPGo0000<_oonfX00omW0?oooo]ZoookJP08oookJP03
ool0GOoonf[ooo]Z00Cooo]Z00?o``3ooookJ_oonfX01?oonfX00onI0?ooKP3ooookJP05oookJP03
o`3o2ooonf[ooo]Z00;ooo]Z00?o08gooookJ_oonfX00_oonfX01?ooV@3ooo]ZoookJ_l0B?l7oook
JP0<of3o0?oonf[ooi00oookJ_oo0:3oo`2;oookJ_nl0?oooo]Zog;o0?l60?ooo`0V0ooonfX00ol0
gooooo]Zool0^`02oookJP0<okT0oooonf[ooo]Zooob0?n6o`3ooo]Zool0m?oonf[o/`3oool0Z_oo
nf[o0?lC0_oonfX00on6o`3ooo]ZoookJP04oookJP08o`01oooonf[o07coobl0oooonf[ool00o`3o
Y_m?0?l3oookJP03ool0S?ooO`3o0P3o00Cooo]Z00Co7Ol0of?o0?mYo`3oJOl00_oonfX02?l0okSo
0?o=ool0Q_oo08Kooo]Zoh00oooonf[o/_l01?oonfX00olSo`3ooed0oookJP02o`0/o`;ooo]Z00So
0?_ooookJ_oonf[oooh0ofko0?oonf[olP3oool0>`?ooo]Z00Co04oooookJ_oo0;7ook/00_oonfX0
0ooo03?ooo]ZoookJP0VoookJP00nooonfX4o`0003;ooo]Z00?oI`3ooookJ_oonfX02?oonfX00ooo
05gooo]ZoookJP04oookJP03ol<0oooonf[ooo]Z00?ooo]Z00?oV@3oofh0oooonfX01?oonfX00ooo
N@3o0?l;oomi0006oomi00?ooo]Z00?ooiT0oookJ_l0B?l02OoonfX02omPo`3ooi00ool0X?oonf[o
o`2;oomi0?nl0?ooL_l0oomi0?mNo`3oo`0V00;oogT000?ooo]Zo`3Ooooo0;/00_ooN@003oni0?oo
ogT0oomi0?oolP3ooo]ZohKo0?oonf[oo`3dok<0oooonf[oo`2ZoookJ_ooN@3ooo]ZohKo0006oook
JP09o`01oooUo`3ooo]Zo`1lool_0?oool00oookJ_l0ojKoC`3o00?ooo]Z00?oo`2<oomo0?l20?l0
1?oonfX01?lMo`3oVP3oofWo0?oo8@02o`3o^0;o0?o=00Goo`26oookJ_n00?ooP03ook;o0004oook
JP05ob?o0?ooG@3ooed0oookJ_l0;?l00ooonfX01ol0nooooo]Zooon0?oo<03oK_l0oookJ_ob0?l0
0_oonfX3ooo90005ool0/Ooob@3ook/0oookJ_oo03<0oooonfXRoookJPCo0000<_oonfX00omW0?oo
oo]ZoookJP08oookJP03ool0GOoonf[ooo]Z00Cooo]Z00?o``3ooookJ_oonfX01?oonfX00onI0?oo
KP3ooookJP05oookJP03o`3o2oo[0?oooo]Z00;ooo]Z00?o08gooookJ_oonfX00_oonfX01?ooV@3o
oo]ZoookJ_l0B?l8oookJP0;of3o0?ooG`3ooi00ool0X?oo08_ooo]Zok`0oooonf[oL_l0o`H0oooo
02H00ooonfX00ol0gooooo]Zool0^`02oookJP0<okT0oooonf[ooo]Zooob0?n6o`3ooo]Zool0m?oo
nf[o/`3oool0Z_oonf[o0?lC0_oonfX00on6o`3ooo]ZoookJP03oookJP;o007o00Oooo]Zo`1lool_
0?oooo]Zooo00?l0ojKoC`3o00?ooo]Z00?oo`2<oomo0?l20?l01?oonfX01_lMo`3ooo]ZofWo0?oo
8@3ooo]Zo`3o^0;o0?o=00Koo`26oookJ_oonf[oP03ooookJ_nbo`04oookJP;ooed000?ooo]Zo`0/
oooonfX00_oonfX02?l0nooooo]ZoookJ_oooP3oK_l0oookJ_ob0?ooo`0k0ooonfX01?l0Cooooo]Z
ool0/Ooo^`02oookJP03ool0<ooonf[ooo]Z02Oooo]Z003koookJPCo0000<_oonfX00omW0?oooo]Z
oookJP07oookJP03ool0GOoonf[ooo]Z00Cooo]Z00?o``3ooookJ_oonfX01?oonfX00om^0?oooo]Z
oookJP02oookJP;oogT000?o0?l;oomi0?ooN@001_ooN@02oookJP04oonI0?oonf[ooo]Zo`18o`So
oo]Z00_oH?l0oon@0?oo0:3ooo]Zool0RoooN@3o_03oog;o0?ooN@3oG_l0ool09P03oomi0005o`3O
oooo0;_oogT0oomi0?ni0?l00_ooN@003?oolP3ooo]ZohKo0?oonf[oo`3dok<0oooonf[oo`2Zo`3o
4oooN@3ooo]ZohKo00Kooo]Z00Wo007ooookJ_oonf[o07coobl0oooo`03ooo]Zo`3oY_m?0?l00ooo
nfX00ooo08coogl0o`80o`04oookJP0=oago0?nJ0?ooJOl0oolQ0?l0okSooo]Zo`3ocOoonf[oo`26
oookJ_n00?oooo]Zok;o0004oookJP03ob?o0?ooG@3ooo]Z00;o02co0_oonfX2o`3ko`04oookJ_oo
oP3ooc00ofko00;olP3o00?ooo]Zooo90?oob@000_oob@001Ooo0;7oolT0oonk0?oonf[oo`0c0?oo
oo]Z8ooonfX4o`0003;ooo]Z00?oI`3ooookJ_oonfX01ooonfX00ooo05gooo]ZoookJP04oookJP03
ol<0oooonf[ooo]Z00Cooo]Z00?oV@3oofh0oooonfX01OoonfX00ol0o`_oj`3ooookJP02oookJP03
o`2=oooonf[ooo]Z00;ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`07oookJP0;of3o0?ooG`3ooi00
ool0X?oo08_ooo]Zok`0oooonf[oL_l0o`H0oooo02H00ooonfX00ol0gooooo]Zool0^`02oookJP0<
okT0oooonf[ooo]Zooob0?n6o`3ooo]Zool0m?oonf[o/`3oool0Z_oonf[o0?lC0_oonfX00on6o`3o
oo]ZoookJP03oookJP05o`01oooonf[ooo]Zo`1lool_0?l00_oo`0000ol0ojKoC`3ooookJP02oook
JP03ool0S?ooO`3o0P3o00Cooo]Z00Wo7Ol0oookJ_mYo`3oob40oookJ_l0okSo0?o=oookJ_oo08H0
0_oonfX00on00?oooo]Zok;o0004oookJP04oomM0?oonf[ooo]Zo`0/o`;ooo]Z0_l0nol2oookJP05
ooon0?m^o`3ooo]Zoo80oooo03/00ooonfX01?l0Coooo`2aool0/Ooo^`02oookJP03ool0<ooonf[o
oo]Z02Sooo]Z003koookJPCo0000<OoonfX00omW0?oooo]ZoookJP08oookJP03ool0GOoonf[ooo]Z
00?ooo]Z00?o``3ooookJ_oonfX01?oonfX01?m^0?oooo]ZoookJ_oonfX<oomi00;ooo]Z00CooiT0
oookJ_oonf[o04So2?oonfX02omPo`3ooi00ool0X?oonf[oo`2;oomi0?nl0?ooL_l0oomi0?mNo`3o
o`0V00?oogT000Go0=ooool0^oooN@3oogT0okT0o`03oomi0008oookJ_n6o`3ooo]Zool0m?nc0?oo
oo]Zool0Z_l0oa<2oookJP03ohKo0?oonf[ooo]Z00Cooo]Z00Wo007ooookJ_oonf[o07coobl0oooo
`03ooo]Zo`3oY_m?0?l00ooonfX2oomo0003o`80oooonf[ooo]Z00;ooo]Z00_o7Ol0oiX0oomYo`3o
o`3?o`3o^?oonf[o0?o=oookJ_oo08Kooo]Zoh00o`02ok;o00Cooo]Z00Co8ol0oomM0?oonf[o02co
0ooonfX02?l0nooooo]ZoookJ_oooP3ooc00ofko0?ob0?ooo`0k1Ooob@000ooo0;7oolT0oonk0002
ool0<ooooo]Z9?oonfX4o`00037ooo]Z00?oI`3ooookJ_oonfX02?oonfX00ooo05gooo]ZoookJP04
oookJP03ol<0oooonf[ooo]Z00?ooo]Z00?oV@3oofh0oooonfX01OoonfX00ol0o`_oj`3ooookJP02
oookJP03o`2=oooonf[ooo]Z00;ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`07oookJP0;of3o0?oo
G`3ooi00ool0X?oo08_ooo]Zok`0oooonf[oL_l0o`H0oooo02H00ooonfX00ol0gooooo]Zool0^`02
oookJP0<okT0oooonf[ooo]Zooob0?n6o`3ooo]Zool0m?oonf[o/`3oool0Z_oonf[o0?lC0_oonfX0
0on6o`3ooo]ZoookJP03oookJP09o`01oooonf[ooo]Zo`1lool_0?oool00oookJ_l0ojKoC`3o00?o
oo]Z0_ooO`000ol20?oooo]ZoookJP02oookJP09oago0?oonf[oJOl0ool0cooonf[o0?nho`3ocOoo
nf[oo`2600;ooo]Z00?oP03ook;o0?nbo`000ooonfX01OlSo`3ooed0oookJ_oonf[o02co00;ooo]Z
00Wo0?_ooookJ_oonf[oo`2Zooon0?m^o`3ooo]Zoo80oooo03/00ooonfX01Ol0Coooo`2aoookJ_oo
^`3ooo]Z00;oo`0c:ooonfX00?_ooo]Z1?l0000`oookJP03ofL0oooonf[ooo]Z00Sooo]Z00?oo`1M
oookJ_oonfX00ooonfX00oo30?oooo]ZoookJP04oookJP04oiT0oom^0?oooo]ZoookJPgoogT000Go
oo]ZoonI0?oonf[ooo]Zo`18o`08oookJP0;of3o0?ooT03oo`2PoookJ_oo08_ooo]Zok`0oombo`3o
ogT0oeko0?oo02H00oooN@001Ol0goooo`2koomi0?ooN@3o^@3o00?oogT00_n6o`000ooonf[oo`3d
ok<0o`02ool0ZP04o`3o4ooonf[ooo]ZohKo00Kooo]Z00?o007ooookJ_oonfX00_l_0?l01?oo`03o
oo]Zo`3oY_m?0?l3oookJP03oomo0?l20?oo0P3o00?ooo]Z00goHol0oago0?nJ0?ooJOl0ool0col0
okSooo]Zo`3ocOoonf[oo`26oookJ_n00?oo/_l000Gooo]Z00Co8ol0oomM0?oonf[o02co0ooonfX0
1?l0nooooo]ZoookJ_oooP02ofko0003oo80oooob@3oolT000CoolT000Coo`2aooo90?oo^`3oo`0c
oooonfXVoookJPCo0000<?oonfX00omW0?oooo]ZoookJP08oookJP03ool0GOoonf[ooo]Z00Cooo]Z
00?o``3ooookJ_oonfX00ooonfX00onI0?oooo]Zofh0o`05oookJP03o`3o2oo[0?oooo]Z00;ooo]Z
00?o08gooookJ_oonfX00_oonfX01OooV@3ooo]ZoookJ_oonf[o04So00Oooo]Z00_oH?l0oomO0?oo
T03oo`2Pool0Rooonf[o_03ooookJ_mbo`3o1P3oool09P03oookJP03o`3Ooooonf[oo`2k00;ooo]Z
00co^@3ooookJ_oolP3ooo80ohKo0?oonf[oo`3doookJ_nc0?ooo`2ZoookJ_l0oa<2oookJP03ohKo
0?oonf[ooo]Z00?ooo]Z00?o007ooookJ_oonfX00_l_0?l01?oo`03ooo]Zo`3oY_m?0?l3oookJP03
oomo0?l20?oo0P3o00Cooo]Z00Wo7Ol0oookJ_mYo`3oo`3?oookJ_l0okSo0?o=oookJ_oo08H00_oo
nfX00on00?oo/_l0oookJP03oookJP05ob?o0?ooG@3ooo]ZoookJ_l0;?l00_oonfX01?l0nooooo]Z
oookJ_oooP02ofko00;olP3o1?oonfX01_l0Coooo`2aoookJ_oo^`3ooo]Zool0<bgooo]Z003koook
JPCo0000<?oonfX00omW0?oooo]ZoookJP07oookJP03ool0GOoonf[ooo]Z00Cooo]Z00?o``3ooook
J_oonfX00ooonfX00onI0?ooKP3ooookJP0>oomi0005oookJ_ooV@3ooo]ZoookJ_l0B?l02?oonfX0
1OmPo`3ooi00ool0X?oonf[oo`2;00;o_03o00CoL_l0o`H0oomNo`3oo`0V0oooN@001Ol0goooo`2k
oomi0?ooN@3o^@3o00CoogT00_oonfX01Ooo0?Co/`3oool0Z_oonf[o0?lC00;ooo]Z00?oQ_l0oook
J_oonfX01?oonfX01ol00Ooooo]ZoookJ_l_0?oooo]Zooo00?oonfX00_m?0?l3oookJP03oomo0?l2
0?oooo]Z00?ooo]Z00goHol0oago0?nJ0?ooJOl0oookJ_l0okSooo]Zo`3ocOoonf[oo`26oookJ_n0
0?oo/_l000Cooo]Z0_lSo`000oooG@3ooo]Zo`0/o`03oookJP07o`3koooonf[oolT0ooon0?m^o`3o
oo]Zoo80o`06ooo90004ool0/Ooo^`3ook/0ool0<ooooo]Z9ooonfX4o`00033ooo]Z00?oI`3ooook
J_oonfX01ooonfX00ooo05gooo]ZoookJP04oookJP03ol<0oooonf[ooo]Z00?ooo]Z00?oV@3ooook
J_m^0?l01OoonfX00ol0o`_oj`3ooookJP03oookJP05o`2=oooonf[ooo]ZoookJ_ooV@000ooonfX0
0ol0B?oooo]ZoookJP05oookJP0;of3o0?ooG`3ooi00ool0X?oo08_ooo]Zok`0oooonf[oL_l0o`H0
oooo02H00ooonfX00ol0gooooo]Zool0^`02oookJP09okT0oooonf[ooo80oookJ_n6o`3ooo]Zool0
m?oonf[o/`3o00;ooo]Z00Co0?lCoookJ_oonf[oQ_l01OoonfX01ol00Ooooo]ZoookJ_l_0?oooo]Z
ooo00?oonfX00_m?0?l3oookJP03oomo0?l20?oooo]Z00Cooo]Z00Wo7Ol0oookJ_mYo`3oo`3?oook
J_l0okSo0?o=oookJ_oo08H00_oonfX00on00?oo/_l0oookJP03oookJP05ob?o0?ooG@3ooo]Zoook
J_l0;?l00_oonfX02?l0nooooo]ZoookJ_oooP3oK_l0oookJ_ob0?ooo`0k0ooonfX2o`1?o`05ool0
/Ooo^`3ook/0oookJ_oo03<0;_oonfX00?_ooo]Z1?l0000_oookJP03ofL0oooonf[ooo]Z00Oooo]Z
00?oo`1MoookJ_oonfX01?oonfX00oo30?oooo]ZoookJP03oookJP03oiT0oom^0?ooogT000GoogT0
00?o0?l;oomi0?ooN@001oooN@001?ooV@3ooo]ZoookJ_l0B?l8oookJP0;of3o0?ooT03oo`2Poook
J_oo08_o_03ooookJ_mbo`3o1P3ooeko0?oo02H00oooN@001Ol0goooolT0oomi0?ooN@3o^@3o00Co
ogT000Oooo]Zoomi0?ooN@3o/`3oool0Z_oonf[o0?lC00;ooo]Z00?oQ_l0oookJ_oonfX01?oonfX0
2?l00Ooooo]ZoookJ_l_0?oooo]Zooo00?oonf[oC`3o1?oonfX00oooO`3o0P3ooookJP03oookJP0=
of?o0?lMo`3oVP3oofWo0?oonf[o0?nhoookJ_l0olgooo]Zool0Q_oonf[oP03ook;o0004oookJP05
ob?o0?oonf[ooed0oookJ_l0;?l00ooonfX01ol0nooooo]Zooon0?oooP3oK_l0oookJ_ob0?l01Ooo
b@02ool0/@03oonk0?oob@3oo`0c0?oooo]Z:?oonfX4o`0002oooo]Z00?oI`3ooookJ_oonfX01ooo
nfX00ooo05gooo]ZoookJP04oookJP03ol<0oooonf[ooo]Z00?ooo]Z00?oV@3ooookJ_m^0?l01Ooo
nfX00ol0o`_oj`3ooookJP03oookJP05o`2=oooonf[ooo]ZoookJ_ooV@000ooonfX00ol0B?oooo]Z
oookJP05oookJP0;of3o0?ooG`3ooi00ool0X?oo08_ooo]Zok`0oooonf[oL_l0o`H0oooo02H01?oo
nfX03Ol0goooo`2koookJ_oonf[o^@3ooookJ_oolP3ooo]ZohKo0?oonf[oo`3doookJ_nc0?l00_oo
nfX01?l0oa?ooo]ZoookJ_n6o`05oookJP08o`01oooonf[ooo]Zobl0oooonf[ool00oookJ_m?0?l4
oookJP03oomo0?l20?oooo]Z00Cooo]Z00Wo7Ol0oookJ_mYo`3oo`3?oookJ_l0okSo0?o=oookJ_oo
08H00_oonfX00on00?oo/_l0oookJP03oookJP05ob?o0?ooG@3ooo]ZoookJ_l0;?l00_oonfX02?l0
nooooo]ZoookJ_oooP3oK_l0oookJ_ob0?ooo`0k0ooonfX01?l0Coooo`2aool0/Ooo^`02oookJP03
ool0<ooonf[ooo]Z02gooo]Z003koookJPCo0000;_oonfX00omW0?oooo]ZoookJP07oookJP03ool0
GOoonf[ooo]Z00Cooo]Z00?o``3ooookJ_oonfX01?oonfX00om^0?ooogT0oomi0004oomi0004o`3o
2oooN@3oogT0oookJPKoogT000CooiT0oookJ_oonf[o04So2?oonfX02omPo`3ooi00ool0X?oonf[o
o`2;ok`0oooonf[oL_l0o`H0oomNo`3oo`0V00;ooo]Z00KoogT0o`3Ooooob@3oolT0oomi0?ni0?l4
oomi0007oookJ_ooN@3oogT0ok<0oooo0:[ooo]Zo`3o4`02oookJP03ohKo0?oonf[ooo]Z00Cooo]Z
00So007ooookJ_oonf[o;`3ooookJ_oo`03o<ol0odl0o`?ooo]Z00?oo`2<oomo0?l20?l01?oonfX2
oago00;oJOl000Wooo]Zo`3o^?oonf[o0?o=oookJ_oo08Kooo]Zoh00oonbo`001?oonfX01OlSo`3o
oo]ZoomM0?oonf[o02co00;ooo]Z0_l0nol01?oonf[oooh0ool`0?m^o`02oo80o`GoolT000Goo`2a
ooo90?oo^`3oolT0ool0<`0:oookJP;oo`23oooonfXMoookJPCo0000;_oonfX00omW0?oooo]Zoook
JP07oookJP03ool0GOoonf[ooo]Z00Cooo]Z00?o``3ooookJ_oonfX01?oonfX00onI0?ooKP3ooook
JP04oookJP03o`3o2oo[0?oooo]Z00?ooo]Z00Go08gooookJ_oonf[ooo]ZoonI0003oookJP03o`18
oooonf[ooo]Z00Gooo]Z00coH?l0oomO0?ooT03oo`2Pool0Rooonf[o_03ooookJ_mbo`3o1P3ooeko
0?oo02H3oookJP0=o`3Ooooo0;_ooo]ZoookJ_ni0?oooo]Zooob0?oonf[oQ_l0oookJ_oo0?Cooo]Z
ok<0o`02oookJP04o`3o4ooonf[ooo]ZohKo00Gooo]Z00So007ooookJ_oonf[o;`3ooookJ_oo`03o
<ol0odl0o`?ooo]Z00?oo`2<oomo0?l20?l01?oonfX2oago00;oJOl000Koo`3?oookJ_l0okSo0?o=
oookJ_oo08H2oookJP03oh00oonbo`3ooo]Z00?ooo]Z00Ko8ol0oomM0?oonf[ooo]Zo`0/oooonfX2
o`3ko`;ooo]Z00Goooh0ofko0?oonf[olP3oool0>`03oookJP04o`1?oooo0;7ooo]Zoonk00;ooo]Z
00?oo`0coookJ_oonfX02?oonfX2ool0PbCooo]Z003koookJPCo0000;_oonfX00omW0?oooo]Zoook
JP07oookJP03ool0GOoonf[ooo]Z00?ooo]Z00?o``3ooookJ_oonfX01?oonfX00om^0?ooogT0oomi
0004oomi0004o`3o2oooN@3oogT0oomi00;ooo]Z1?ooN@001?ooV@3ooo]ZoookJ_l0B?l8oookJP0;
of3o0?ooT03oo`2PoookJ_oo08_o_03ooookJ_ooN@3oL_l0oeko0?oo02H00_oonfX01_oob@3o0=oo
ooo90?oob@3oogT0okT0o`KoogT00_nc0?l00ooo0:[ooo]Zo`3o4`02oookJP03ohKo0?oonf[ooo]Z
00Cooo]Z00So007ooookJ_l0O?oo;`3ooookJ_oo`03o0?nVodl0o`?ooo]Z00?oo`2<oomo0?l20?l0
1?oonfX01_lMo`3o3@3oofWo0?oo8@3ooo]Zo`3o^0;o0?o=0_oo08H00ooonf[oP03ook;o0004oook
JP03ob?o0?ooG@3ooed000;o02co0_oonfX02?l0nooooo]ZoookJ_oooP3ooc00ofko0?ob0?ooo`0k
0_oonfX3ooo90005ool0/Ooob@3ook/0ooo90?oo03<02_oonfX00ooo08?ooo]ZoookJP3ooookJQgo
oo]Z1?l0000^oookJP03ofL0oooonf[ooo]Z00Oooo]Z00?oo`1MoookJ_oonfX00ooonfX00oo30?oo
oo]ZoookJP04oookJP03oiT0oom^0?oooo]Z00Cooo]Z00?o0?l;on/0oooonfX00ooonfX01Ol0SOoo
oo]ZoookJ_oonf[ooiT000?ooo]Z00?o04SooookJ_oonfX01OoonfX03?mPo`3ooel0oon@0?oo0:3o
o`2;oookJ_nl0?oooo]Zog;o0?l60?ooG_l0ool09P?ooo]Z00_o0=ooool0^ooonf[ooo]ZokT0oooo
nf[ooo80oookJ_n6o`3ooo]Zool0m002ok<0o`;ooo]Z00Co0?lCoookJ_oonf[oQ_l01OoonfX02?l0
0Ooooo]ZoookJ_l_0?oooo]Zooo00?l0ojKoC`3o0ooonfX00ooo08coogl0o`80o`04oookJP06oago
0?l=0?ooJOl0oiX0oooo0<oooo]Z0_l0old2ool0QP;ooo]Z00?oP03ook;o0?oonfX00ooonfX2oomM
0005oookJ_l0;?oo02cooookJ_l0nol00ooonfX01OoooP3oK_l0oookJ_ob0?ooo`0k00?ooo]Z00Co
04ooool0/Ooonf[ook/00_oonfX00ooo03?ooo]ZoookJP08oookJP03ool0Pooonf[ooo]Z02Cooo]Z
003koookJPCo0000;OoonfX00omW0?oooo]ZoookJP07oookJP03ool0GOoonf[ooo]Z00?ooo]Z00?o
``3ooookJ_oonfX01?oonfX01?nI0?ooKP3ooookJ_oonfX7oomi00;ooo]Z00?oogT0oookJ_ooN@00
0_ooN@000oooV@3ooo]Zo`18o`08oookJP0<of3o0?ooT03oo`2PoookJ_oo08_o_03ooookJ_ooN@3o
L_l0oeko0?oo02Kooo]Z0_oob@001Ol0goooolT0ooo90?oob@3o^@3o00KoogT000Go/`3ooomi0?oo
0:[ooo]Zo`3o4`02oookJP03ohKo0?oonf[ooo]Z00Cooo]Z00So007ooookJ_l0O?oo;`3ooookJ_oo
`03o0?nVodl0o`?ooo]Z00?oo`2<oomo0?l20?l01?oonfX02_lMo`3o3@3oofWo0?oo8@3ooo]Zo`3o
^?l0olgooo]Zool0Q_oonfX2oh00o`03ok;o0?oonf[ooo]Z00;ooo]Z00Co8ol0oomM0?oonf[o02co
0ooonfX02?l0nooooo]ZoookJ_oooP3ooc00ofko0?ob0?ooo`0k1?oonfX01_oob@3oo`2aooo90?oo
^`3oolT0ool0<`[ooo]Z00?oo`23oookJ_oonfX0oooonfXNoookJPCo0000;OoonfX00omW0?oooo]Z
oookJP07oookJP03ool0GOoonf[ooo]Z00?ooo]Z00?o``3ooookJ_oonfX01?oonfX00onI0?ooKP3o
oookJP04oookJP03o`3o2oo[0?oooo]Z00?ooo]Z00?o08gooookJ_oonfX00_oonfX01?ooV@3ooo]Z
oookJ_l0B?l7oookJP0<of3o0?ooT03ooi00ool0X?oo08_ooo]Zok`0oooonf[oL_l0o`H0oomNo`3o
o`0V0ooonfX03Ol0goooo`2koookJ_oonf[o^@3ooookJ_oolP3ooo]ZohKo0?oonf[oo`3dok<0oooo
0:X00_oonfX01?l0oa?ooo]ZoookJ_n6o`05oookJP08o`01oooonf[ooo]Zobl0oooonf[ool00o`3o
Y_m?0?l3oookJP03ool0S?ooO`3o0P3o00Cooo]Z00Wo7Ol0o`d0oomYo`3oVP3oool0cooonf[o0?o=
oookJ_oo08H00_oonfX2oh00o`03ok;o0?oonf[ooo]Z00;ooo]Z00Cooed0oookJ_oonf[o02co0_oo
nfX02?l0nooooo]ZoookJ_oonf[oooh0ofko0?oonf[olP3o1?oonfX01?l0Coooo`2aoookJ_oo^`02
oookJP03ool0<ooonf[ooo]Z00Sooo]Z00?oo`23oookJ_oonfX09OoonfX008[ooo]Z0_nDo`1_oook
JPCo0000;?oonfX00omW0?oooo]ZoookJP07oookJP03ool0GOoonf[ooo]Z00Cooo]Z00?o``3ooook
J_oonfX00ooonfX00onI0?ooKP3ooookJP03oookJPKoogT000?ooo]Zoomi0?oonfX00_oonfX01Ooo
N@3ooiT0oookJ_oonf[o04So00Oooo]Z00KoH?l0oon@0?oo0:3ooo]Zool0Ronl0?l2oomi0004og;o
0?ooN@3oo`0VoookJP;oolT000Ko0=ooooo90?oob@3oolT0okT0oooonfX5oomi0005ok<0ooooN@3o
o`2ZoookJ_l0oa<00_oonfX00on6o`3ooo]ZoookJP04oookJP08o`01oooonf[o07coobl0oooonf[o
ol00o`3oY_m?0?l3oookJP03ool0S?ooO`3o0P3o00Cooo]Z00_o7Ol0oookJ_mYo`3oo`3?oookJ_l0
okSo0?o=oookJ_oo08Kooo]Zoh00o`02ok;o00Cooo]Z00Co8ol0oomM0?oonf[o02co0ooonfX01?l0
nooooo]ZoookJ_oooP02ofko0003oo80oooo03_ooo]Z00;ooo]Z0_oob@000ooo0;7oolT0oonk0002
ool0<`03ooo90?oonf[ooo]Z00Oooo]Z00?oo`23oookJ_oonfX00_l0oiSooookJQgooo]Z1?l0000/
oookJP03ofL0oooonf[ooo]Z00Oooo]Z00?oo`1MoookJ_oonfX01?oonfX00oo30?oooo]ZoookJP03
oookJP03oiT0oom^0?oooo]Z00Gooo]Z00?o0?l;oookJ_oonfX00_oonfX00ol0SOoooo]ZoookJP02
oookJP05oonI0?oonf[ooo]ZoookJ_l0B?l01_oonfX03?mPo`3ooi00oookJ_oo0:3oo`2;oookJ_nl
0?oooo]Zog;o0?l60?ooG_l0ool09P?ooo]Z00go0=ooool0^ooonf[ooo]ZokT0oooonf[ooo80oook
J_n6o`3ooo]Zool0m?nc0?ooo`2Z00;ooo]Z00Co0?lCoookJ_oonf[oQ_l01OoonfX02?l00Ooooo]Z
oookJ_l_0?oooo]Zooo00?l0ojKoC`3o0ooonfX00ooo08coogl0o`80o`04oookJP09oago0?mSo`3o
JOl0oolQ0?oo0<oooo]Zo`3ocOoonf[oo`2600;ooo]Z00?oP03ook;o0?nbo`001?oonfX01?ooG@3o
oo]ZoookJ_l0;?l2oookJP04o`3koooonf[ooo]Zooon00;oK_l000?ooo]Zoo80oooonfX00_oonfX2
o`1?o`04ool0/Ooonf[ook/0oookJP;oo`0c2_oonfX00ooo08?ooo]ZoookJP02o`3oV2Cooo]Z0027
oookJPGoU?l0KooonfX4o`0002cooo]Z00?oI`3ooookJ_oonfX01_oonfX00ooo05gooo]ZoookJP04
oookJP03ol<0oooonf[ooo]Z00?ooo]Z00?oV@3oofh0oooonfX00_oonfX7oomi0003oookJ_ooN@3o
oo]Z00?ooo]Z00CooiT0oookJ_oonf[o04So1ooonfX01_mPo`3ooi00ool0X?oonf[oo`2;ok`0o`;o
ogT000?oL_l0oomi0?oo02H00ooob@001Ol0goooolT0ooo90?oob@3o^@3o00;ooo]Z00Wooo80oomi
0?ooN@3oogT0ok<0ooooN@3oo`2ZoookJ_l0oa<00_oonfX00on6o`3ooo]ZoookJP04oookJP08o`01
oooonf[o07coobl0oooonf[ool00o`3oY_m?0?l3oookJP03ool0S?ooO`3o0P3o00?ooo]Z00goHol0
oago0?oonf[oJOl0ool0cooonf[o0?nho`3ocOoonf[oo`26oookJ_n00?oo/_l000Cooo]Z0_lSo`00
0oooG@3ooo]Zo`0/o`03oookJP07o`3koooonf[oo`2Zooon0?m^o`3ooo]Zoo80o`04oookJP06ooo9
0?oo0;7oo`2aoookJ_oo^`3oo`0c0_oob@09oookJP04ool0Pooonf[ooo]Zo`3oV?oooo]Z7ooonfX4
o`0002cooo]Z00?oI`3ooookJ_oonfX01_oonfX00ooo05gooo]ZoookJP04oookJP03ol<0oooonf[o
oo]Z00?ooo]Z00?oV@3ooookJ_m^0?l01OoonfX00ol0o`_ooo]ZoookJP02oookJP03o`2=oooonf[o
oo]Z00;ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`06oookJP0<of3o0?ooT03ooo]Zool0X?oo08_o
oo]Zok`0oooonf[oL_l0o`H0oomNo`3oo`0V0ooonfX03Ol0goooo`2koookJ_oonf[o^@3ooookJ_oo
lP3ooo]ZohKo0?oonf[oo`3dok<0oooo0:X00_oonfX01?l0oa?ooo]ZoookJ_n6o`05oookJP08o`01
oooonf[ooo]Zobl0oooonf[ool00o`3oY_m?0?l3oookJP03ool0S?ooO`3o0P3o00Cooo]Z00Wo7Ol0
of?o0?mYo`3oob40ool0cooonf[o0?o=oookJ_oo08H00_oonfX00on00?oo/_l0oookJP03oookJP05
ob?o0?ooG@3ooo]ZoookJ_l0;?l00_oonfX01_l0nooooo]ZoookJ_oooP3oK_l0oookJP;olP3o0ooo
nfX01ol0Cooooo]Zool0/Ooonf[ook/0oookJ_oo03<02ooonfX01?oo08?ooo]ZoookJ_l0oiPVoook
JP00Q?oonfX8oiCo06oooo]Z1?l0000[oookJP03ofL0oooonf[ooo]Z00Kooo]Z00?oo`1MoookJ_oo
nfX01?oonfX00oo30?oooo]ZoookJP04oookJP04ofh0oooonf[ooo]ZoookJPWoogT01?oonfX01?oo
V@3ooo]ZoookJ_l0B?l7oookJP06of3o0?ooT03oo`2PoookJ_oo08_o_03o0_ooN@000ombo`3oogT0
ool09P03ooo90009o`3Ooooob@3oolT0ooo90?ni0?oooo]Zoomi0?oolP3oQ_l000;oogT000Go/`3o
oomi0?oo0:[oogT0o`3o4`02oookJP03ohKo0?oonf[ooo]Z00Cooo]Z00Co007ooookJ_l0O?oo;`3o
0_oo`0000ol0ojKoC`3ooookJP02oookJP;oogl000Wo0P3ooookJ_oonf[ooo]Zof?o0?lMo`3ooo]Z
ofWo0?oo0<l00_l0okP01_l0olgooo]Zool0Q_oonf[oP03ook;o00Cooo]Z00Go8ol0oookJ_ooG@3o
oo]Zo`0/o`02oookJP;o0?_o00Kooo]Zool0Z_oooP3oK_l0oookJ_ob0?l4oookJP08ooo90?oo0;7o
oo]ZoookJ_oo^`3oo`0coookJ_oob@08oookJP;oo`230_oonfX00ol0oiSooo]ZoookJP3ooookJQko
oo]Z1?l0000[oookJP03ofL0oooonf[ooo]Z00Oooo]Z00?oo`1MoookJ_oonfX00ooonfX00oo30?oo
oo]ZoookJP04oookJP03oiT0oom^0?oooo]Z00Cooo]Z00?o0?l;oookJ_oonfX00_oonfX00ol0SOoo
oo]ZoookJP02oookJP05oonI0?oonf[ooo]ZoookJ_l0B?l01_oonfX03?mPo`3ooi00oookJ_oo0:3o
o`2;oookJ_nl0?oooo]Zog;o0?l60?ooG_l0ool09P?ooo]Z00go0=ooool0^ooonf[ooo]ZokT0oooo
nf[ooo80oookJ_n6o`3ooo]Zool0m?nc0?ooo`2Z00;ooo]Z00Co0?lCoookJ_oonf[oQ_l01OoonfX0
1?l00Ooooo]ZoookJ_l_0?l2ooo00003o`3oY_m?0?oooo]Z00;ooo]Z0_ooO`000ol20?oooo]Zoook
JP02oookJP09oago0?oonf[oJOl0oolQ0?oo0<oo0?nho`3ocOoonf[oo`2600;ooo]Z00?oP03ook;o
0?oonfX00ooonfX01_lSo`3ooed0oookJ_oonf[o02cooookJP;o0?_o0_oonfX01OoooP3oK_l0oook
J_ob0?ooo`0k00?ooo]Z00Oo04oooookJ_oo0;7ooo]Zoonk0?oonf[oo`0c00[ooo]Z0_oo08<2oook
JP03o`3oV?oonf[ooo]Z02Gooo]Z0021oookJP_oU?l0KooonfX4o`0002[ooo]Z00?oI`3ooookJ_oo
nfX01_oonfX00ooo05gooo]ZoookJP04oookJP03ol<0oooonf[ooo]Z00Cooo]Z00?oV@3oofh0oooo
nfX01_ooN@02oookJP03oomi0?oonf[o08go00?ooo]Z00CooiT0oookJ_oonf[o04So1ooonfX01_oo
N@3ooi00ool0X?oonf[oo`2;ok`0o`;oogT000?oL_l0oomi0?oo02H00ooob@002Ol0goooolT0ooo9
0?oob@3o^@3ooookJ_ooN@3ooo80ohKo0002oomi0005ok<0ooooN@3oo`2Zoomi0?l0oa<00_oonfX0
0on6o`3ooo]ZoookJP04oookJP08o`01oooonf[o;`3oobl0oooo`03ooo]Zo`3oY_m?0?l3oookJP03
oomo0?l20?oo0P3o00?ooo]Z00goHol0oago0?mYo`3oJOl0ool0col0okSooo]Zo`3ocOoonf[oo`26
oookJ_n00?oo/_l000Cooo]Z00Go8ol0oookJ_ooG@3ooo]Zo`0/o`02oookJP06o`3koooonf[ooo]Z
ool0Z_oooP3oK_l00_ob0?l4oookJP03ooo90?oo0;7ooo]Z00;ook/000?oo`0coookJ_oonfX02?oo
nfX01Ooo08?ooo]ZoookJ_oonf[o0?nH0?oooo]Z8OoonfX4o`0002[ooo]Z00?oI`3ooookJ_oonfX0
1ooonfX00ooo05gooo]ZoookJP03oookJP03ol<0oooonf[ooo]Z00Cooo]Z00?oV@3oofh0oooonfX0
1?oonfX00ol0o`_ooo]ZoookJP03oookJP05o`2=oooonf[ooo]ZoookJ_ooV@000ooonfX00ol0B?oo
oo]ZoookJP04oookJP0<of3o0?ooT03ooo]Zool0X?oo08_ooo]Zok`0oooonf[oL_l0o`H0oomNo`3o
o`0V0ooonfX03Ol0goooo`2koookJ_oonf[o^@3ooookJ_oolP3ooo]ZohKo0?oonf[oo`3dok<0oooo
0:X00_oonfX01?l0oa?ooo]ZoookJ_n6o`05oookJP08o`01oooonf[o;`3oobl0oooo`03ooo]Zo`3o
Y_m?0?l3oookJP03oomo0?l20?oo0P3o00Cooo]Z00Wo7Ol0ofWo0?mYo`3ooo]Zool0col0okSo0?o=
oookJ_oo08H00_oonfX00on00?oo/_l0oookJP03oookJP03ob?o0?ooG@3ooo]Z00;o02co00?ooo]Z
o`3koooonfX00_oonfX01OoooP3oK_l0oookJ_ob0?ooo`0k00?ooo]Z00?o04ooool0/Ooo0;400_oo
^`000ooonf[oo`0coookJP09oookJP05ool0Pooonf[ooo]ZoookJ_l0oiP0:?oonfX007kooo]Z3_nD
o`0>o`2Mof7ooo]Z1?l0000ZoookJP03ofL0oooonf[ooo]Z00Kooo]Z00?oo`1MoookJ_oonfX01?oo
nfX00oo30?oooo]ZoookJP03oookJP03oiT0oom^0?oooo]Z00OoogT00ooonfX01Ol0SOoooo]Zoook
J_oonf[ooiT000;ooo]Z00?o04SooookJ_oonfX01OoonfX01_ooN@3ooi00ool0X?oonf[oo`2;ok`0
o`;oogT000?oL_l0oomi0?oo02H00ooob@002Ol0goooolT0ooo90?oob@3o^@3oooo90?ooN@3ooo80
ohKo0002oomi0005ok<0ooooN@3oo`2Zoomi0?l0oa<00_oonfX00on6o`3ooo]ZoookJP04oookJP06
o`01oooonf[o;`3ooookJ_oo`03ooo]Z0_m?0?l3oookJP03oomo0?l20?oooo]Z00?ooo]Z00KoHol0
oago0?mYo`3oVP3oool0col0okP2o`3oc@;oo`2600?ooo]Zoh00oonbo`001?oonfX01OlSo`3ooo]Z
oomM0?oonf[o02co00;ooo]Z00?o0?_ooookJ_oonfX00_oooP000om^o`3olP3oool0>`04oookJP06
ooo90?oo0;7ooo]Zoonk0?oonf[oo`0c2_oonfX01Ooo08?ooo]ZoookJ_oonf[o0?nH00?ooo]Z0_oP
o`2ToookJQOo09goHOoonfX4o`0002[ooo]Z00?oI`3ooookJ_oonfX01_oonfX00ooo05gooo]Zoook
JP04oookJP03ol<0oooonf[ooo]Z00?ooo]Z00?oV@3oofh0oooonfX01?oonfX00ol0o`_ooo]Zoook
JP03oookJP05o`2=oooonf[ooo]ZoookJ_ooV@000ooonfX00ol0B?oooo]ZoookJP04oookJP0<of3o
0?ooT03ooel0ool0X?oo08_ooo]Zok`0oooonf[oL_l0o`H0oomNo`3oo`0V0ooonfX00ol0goooo`2k
oookJP02okT0o`08oookJ_oolP3ooo]ZohKo0?oonf[oo`3dok<0oooo0:X2oookJP04o`3o4ooonf[o
oo]ZohKo00Gooo]Z00So007ooookJ_l_0?oo07coooo00?oonf[o0?nVodl0o`?ooo]Z00?oogl0o`80
oooonfX01?oonfX01OlMo`3oJOl0oiX0oooonf[oo`3?00;o0?o=0_oo08H2oookJP03oh00oonbo`3o
oo]Z00?ooo]Z00Co8ol0oomM0?oonf[o02co0_oonfX02Ol0nooooo]ZoookJ_oonf[oooh0ofko0?oo
nf[olP3oool0>`03oookJP04o`1?oooo0;7ooo]Zoonk00;ooo]Z00?oo`0coookJ_oonfX02?oonfX0
1Ooo08?ooo]ZoookJ_oonf[o0?nH00?ooo]Z0_oPo`0ToookJP00NOoonfX3o`2Moa3oU?l03_oonfX9
o`2MoeSooo]Z1?l0000YoookJP03ofL0oooonf[ooo]Z00Kooo]Z00?oo`1MoookJ_oonfX01?oonfX0
0oo30?oooo]ZoookJP03oookJP03oiT0oom^0?oooo]Z00OoogT00ooonfX01Ol0SOoooo]ZoookJ_oo
nf[ooiT000;ooo]Z00?o04SooookJ_oonfX01?oonfX2oomi0005oon@0?oo0:3ooo]Zool0Ronl0?l0
0_ooN@000ombo`3oogT0ool09P03ooo90009o`3Ooooob@3oolT0ooo90?ni0?ooolT0oookJ_oolP3o
Q_l000;oogT000Go/`3ooomi0?oo0:[oogT0o`3o4`02oookJP03ohKo0?oonf[ooo]Z00Cooo]Z00Oo
007ooookJ_l_0?oooo]Zooo00?oonf[oC`3o00Cooo]Z00?oogl0o`80oooonfX00ooonfX02_mSo`3o
7Ol0ofWo0?nJ0?ooo`3?o`3o^?l0olgooo]Zool0Q_oonfX2oh00o`03ok;o0?oonf[ooo]Z00;ooo]Z
00?o8ol0oomM0?ooG@000_l0;?l2oookJP04o`3koooonf[ooo]Zooon00;oK_l000?olP3oool0>ooo
nfX00ooonfX01_oob@3oo`2aoookJ_oo^`3ooo]Zool0<`[ooo]Z00?oo`23oookJ_oonfX00_l0oiP3
oookJP03on3o0?oonf[ooo]Z09[ooo]Z2_l0WOlGoookJP[o09goEooonfX4o`0002Wooo]Z00?oI`3o
oookJ_oonfX01_oonfX00ooo05gooo]ZoookJP04oookJP03ol<0oooonf[ooo]Z00?ooo]Z00?oV@3o
ofh0oooonfX01?oonfX00ol0o`_oj`3ooookJP03oookJP05o`2=oooonf[ooo]ZoookJ_ooV@000ooo
nfX00ol0B?oooo]ZoookJP04oookJP0<of3o0?ooT03ooel0ool0X?oo08_ooo]Zok`0oooonf[oL_l0
o`H0oomNo`3oo`0V0ooonfX03Ol0goooo`2koookJ_ni0?ooFol0oookJ_oolP3ooo]ZohKo0?oonf[o
o`3dok<0oooo0:X00_oonfX01?l0oa?ooo]ZoookJ_n6o`05oookJP08o`01oooonf[o;`3oo`1loooo
`03ooo]Zo`3oY_m?0?l3oookJP03oomo0?l20?oooo]Z00Cooo]Z00?o7Ol0ofWo0?nJ0?l00_oo0<l0
0ol0olgooo]Zool0QP02oookJP;oP03o00?o/_l0oookJ_oonfX00_oonfX2oomM0005oookJ_l0;?oo
oo]ZoookJ_l0nol00_oonfX01OoooP3oK_l0ofko0?oonf[olP3o00Cooo]Z00Co04ooool0/Ooonf[o
ok/00_oonfX00ooo03?ooo]ZoookJP08oookJP03ool0Pooonf[ooo]Z00;o0?nH0ooonfX00ooPo`3o
oo]ZoookJP0ToookJP00L_oonfX7o`2Mo`Oooo]Z3?nDo`0GoookJPKo09goD_oonfX4o`0002Sooo]Z
00?oI`3ooookJ_oonfX01_oonfX00ooo05gooo]ZoookJP04oookJP03ol<0oooonf[ooo]Z00Cooo]Z
00?oKP3ooomi0?ooN@001oooN@02oookJP05o`2=oooonf[ooo]ZoookJ_ooV@000_oonfX00ol0B?oo
oo]ZoookJP03oookJP?oogT000Gooi00ool0X?oonf[oo`2;ok`0o`02oomi0003og;o0?ooN@3oo`0V
00;oogT000?oolT0o`3Ooooob@000_oob@003Oni0?ooolT0ooo90?oolP3oQ_l0oookJ_ooN@3o/`3o
oomi0?oo0:[oogT0o`3o4ooonfX00_n6o`06oookJP07o`01oooonf[o;`3ooookJ_oo`03ooo]Zodl0
o`03oookJP03ool0S?ooO`3o0P3o00Cooo]Z00goHol0oago0?mYo`3oVP3ooookJ_l0okSo0?o=oook
J_oo08Kooo]Zoh00oooonf[o/_l000Cooo]Z00Co8ol0oomM0?oonf[o02co0ooonfX02?l0nooooo]Z
oookJ_oooP3oK_l0oookJ_ob0?ooo`0k0ooonfX2ooo90003ool0/Ooonf[ook/000;oo`0c2_oonfX0
1Ooo08?ooo]ZoookJ_l0oiSo9_l000?ooo]Z00?oh?l0oookJ_oonfX0U?oonfX7o`2Mob_ooo]Z1_l0
WOmAoookJPCo0000:?oonfX00omW0?oooo]ZoookJP07oookJP03ool0GOoonf[ooo]Z00?ooo]Z00?o
``3ooookJ_oonfX01?oonfX00om^0?oooo]ZoookJP03oookJP03o`3o2oo[0?oooo]Z00?ooo]Z00Go
08gooookJ_oonf[ooo]ZoonI0003oookJP03o`18oooonf[ooo]Z00Cooo]Z00coH?l0oon@0?ooG`3o
o`2Pool0Rooonf[o_03ooookJ_mbo`3o1P3ooeko0?oo02H3oookJP0:o`3Ooooo0;_ooo]ZokT0oomK
o`3ooo]Zooob0?oonf[oQ_l0oookJP;o/`3o00Goo`2ZoookJ_oonf[o0?lCoookJP02ohKo00Gooo]Z
00So007ooookJ_l_0?oo07coooo00?oonf[o0?nVodl0o`;ooo]Z00?oo`2<oomo0?l20?l01OoonfX0
2?lMo`3oJOl0oiX0oooo0<oooo]Zo`3ocOoonf[oo`260_oonfX00on00?oooo]Zok;o0004oookJP04
oomM0?oonf[ooo]Zo`0/o`;ooo]Z00Go0?_ooookJ_oonf[oooh0ofko0002oookJP04oo80oooonf[o
oo]ZoookJP;o04oo00Coo`2aoookJ_oo^`3ooo]Z0_oo03<:oookJP05ool0Pooonf[ooo]Zo`3oV?lV
o`000ooonfX00ooPo`3ooo]ZoookJP0UoookJP00K?oonfX6o`2Moa?ooo]Z1onDo`0MoookJPCo09go
C_oonfX5o`0002Oooo]Z00?oI`3ooookJ_oonfX01OoonfX00ooo05gooo]ZoookJP04oookJP03ol<0
oooonf[ooo]Z00Cooo]Z00?oKP3ooomi0?ooN@001oooN@02oookJP05o`2=oooonf[ooo]ZoookJ_oo
V@000_oonfX00ol0B?oooo]ZoookJP03oookJP?oogT000Gooi00ool0X?ooN@3oo`2;ok`0o`02oomi
0003og;o0?ooN@3oo`0V00;oogT000?ooo]Zo`3Ooooob@000_oob@001Oni0?ooolT0ooo90?oolP3o
Q_l000;ooo]Z00Oo/`3ooomi0?oo0:[oogT0o`3o4oooN@3oQ_l000Oooo]Z00Oo007ooookJ_l_0?oo
oo]Zooo00?l0ojKoC`3o00?ooo]Z00?oo`2<oomo0?l20?l01?oonfX02omSo`3o7Ol0ofWo0?nJ0?oo
oo]Zo`3o^?l0olgooo]Zool0Q_oonf[oP03o00;o/_l01?oonfX01?lSo`3ooed0oookJ_l0;?l3oook
JP08o`3koooonf[ooo]Zooon0?m^o`3ooo]Zoo80oooo03/3oookJP06ooo90?oo0;7oo`2aoookJ_oo
^`3oo`0c2ooonfX01?oo08?ooo]ZoookJ_l0oiP4oookJP03on3o0?oonf[ooo]Z08oooo]Z1_l0WOlh
oookJP?o09goC_oonfX5o`0002Oooo]Z00?oI`3ooookJ_oonfX01_oonfX00ooo05gooo]ZoookJP03
oookJP03ol<0oooonf[ooo]Z00Cooo]Z00?oKP3ooookJ_oonfX01?oonfX00ol0o`_ooo]ZoookJP02
oookJP05o`2=oooonf[ooo]ZoookJ_ooV@000ooonfX00ol0B?oooo]ZoookJP05oookJP0;oon@0?oo
G`3oo`2Pool0Rooonf[o_03ooookJ_mbo`3o1P3ooeko0?oo02H00ooonfX01?l0goooo`2koookJ_ni
0?l2oookJP07ooob0?oonf[oQ_l0oookJ_nc0?oooo]Zool0ZP02oookJP03o`3o4ooonf[oQ_l000Ko
oo]Z00So007ooookJ_l_0?oo07coooo00?lco`3o0?nVodl0o`;ooo]Z00?oo`2<oomo0?l20?l01Ooo
nfX02?lMo`3oJOl0oiX0oooo0<oooo]Zo`3ocOoonf[oo`260_oonfX00on00?oo/_l0ok;o0004oook
JP04oomM0?oonf[ooo]Zo`0/o`;ooo]Z00Go0?_ooookJ_oonf[oooh0ofko0002oookJP0;oo80oooo
nf[ooo]ZoookJ_l0Cooooo]Zool0/Ooonf[ook/0oookJ_oo03<02ooonfX01?oo08?ooo]ZoookJ_l0
oiP4oookJP03on3o0?oonf[ooo]Z02Kooo]Z001XoookJPCo09go7_oonfX2oiCo027ooo]Z1?l0WOm:
oookJPCo00009ooonfX00omW0?oooo]ZoookJP05oookJP03ool0GOoonf[ooo]Z00Cooo]Z00?o``3o
oookJ_oonfX01?oonfX00onI0?ooKP3ooomi0008oomi0003oookJ_l0SOoooo]Z00;ooo]Z00GooiT0
oookJ_oonf[ooo]Zo`18o`03oookJPCoogT000Gooi00ool0X?ooN@3oo`2;ok`0o`02oomi0003og;o
0?ooN@3oo`0V00?oogT000Go0=oooookJ_oob@3oolT0okT0o`02ooo9000;ooob0?n6o`3ooo]Zoook
J_nc0?oooo]Zool0Z_ooN@3o0?lCoomi0?n6o`001ooonfX02?l00Ooo07coobl0oooonf[ool00o`3o
Y_m?0?ooogT00_oonfX00ooo08coogl0o`80o`04oookJP;o7Ol000[oJOl0oiX0ool0okSo0?nho`3o
cOoonf[oo`26oookJ_n00?oo/_l01OoonfX01?lSo`3ooed0oookJ_l0;?l2oookJP;o0?_o00Oooo]Z
ool0Z_oooP3oK_l0oookJ_ob0?ooo`0k00?ooo]Z00KoolT0ool0/Ooonf[ooo]Zoonk0?oo03<:oook
JP;oo`230_oonfX00ol0oiSooo]ZoookJP02oookJP03on3o0?oonf[ooo]Z08cooo]Z1?l0WOm1oook
JPCo09goB_oonfX4o`0002Oooo]Z00?oI`3ooookJ_oonfX01_oonfX00ooo05gooo]ZoookJP03oook
JP03ol<0oooonf[ooo]Z00Cooo]Z00?oV@3oofh0oooonfX01?oonfX00ol0o`_ooo]ZoookJP02oook
JP05o`2=oooonf[ooo]ZoookJ_ooV@000ooonfX00ol0B?oooo]ZoookJP05oookJP0;oon@0?ooG`3o
o`2Pool0Rooonf[o_03ooookJ_mbo`3o1P3ooeko0?oo02H00ooonfX01?l0goooo`2koookJ_ni0?l2
oookJP07ooob0?oonf[oQ_l0oookJ_nc0?oooo]Zool0ZP02oookJP03o`3o4ooonf[oQ_l000Kooo]Z
00So007ooookJ_l_0?oo07coooo00?lco`3o0?nVodl0o`;ooo]Z00?oo`2<oomo0?l20?l01?oonfX2
oago0007ofWo0?nJ0?ooo`3?o`3o^?l0olgooo]Zool0QP02oookJP03oh00oonbo`3ooo]Z00?ooo]Z
00?o8ol0oomM0?oonfX00_l0;?l00ooonf[o0?_oo`3ko`02oookJP05ooon0?m^o`3ooo]ZoookJ_ob
0?l00ooonfX01ol0Cooooo]Zool0/Ooonf[ook/0oookJ_oo03<02_oonfX2ool0P`;ooo]Z00?o0?nH
oookJ_oonfX00_oonfX00ooPo`3ooo]ZoookJP0WoookJP00HooonfX5o`2ModWooo]Z0ol0WOm7oook
JPCo00009_oonfX00omW0?oooo]ZoookJP05oookJP03ool0GOoonf[ooo]Z00Gooo]Z00?o``3ooook
J_oonfX00ooonfX01?nI0?ooKP3ooookJ_oonfX7oomi0003oookJ_l0SOoooo]Z00;ooo]Z00GooiT0
oookJ_oonf[ooo]Zo`18o`02oookJPGoogT000Gooi00ool0X?ooN@3oogT0ok`0o`02oookJP03og;o
0?ooN@3oo`0V00?oogT000Go0=oooookJ_oob@3ooo]ZokT0o`03ooo9000:ohKo0?oonf[ooo]Zok<0
oooonf[oo`2ZoookJ_l0oa?oogT0ohKo00Oooo]Z00So007oo`1lool_0?oooo]Zooo00?l0ojKoC`3o
oomi00;ooo]Z00?oo`2<oomo0?l20?l01?oonfX03?lMo`3o3@3oofWo0?nJ0?oo0?nhoookJ_l0olgo
oo]Zool0Q_oonf[oP03ook;o00Gooo]Z00Co8ol0oomM0?oonf[o02co0_oonfX01_l0nooooo]Zoook
J_oo0:[oooh0ofko00;olP3o1?oonfX01_oob@3oo`2aoookJ_oonf[ook/0ool0<`[ooo]Z00Goo`23
oookJ_oonf[ooo]Zo`3oV004oookJP03on3o0?oonf[ooo]Z08Wooo]Z1?l0WOm9oookJP?o09goAooo
nfX4o`0002Kooo]Z00?oI`3ooookJ_oonfX01_oonfX00ooo05gooo]ZoookJP04oookJP03ol<0oooo
nf[ooo]Z00?ooo]Z00?oV@3oofh0oooonfX01?oonfX00ol0o`_ooo]ZoookJP02oookJP05o`2=oooo
nf[ooo]ZoookJ_ooV@000ooonfX00ol0B?oooo]ZoookJP05oookJP0;oon@0?ooG`3oo`2Pool0Rooo
nf[o_03ooookJ_mbo`3o1P3ooeko0?oo02H00ooonfX01?l0goooo`2koookJ_ni0?l2oookJP07ooob
0?oonf[oQ_l0oookJ_nc0?oooo]Zool0ZP02oookJP03o`3o4ooonf[oQ_l000Kooo]Z00So007ooook
J_l_0?oooo]Zooo00?lco`3o0?nVodl0o`;ooo]Z00?oo`2<oomo0?l20?l01?oonfX02OlMo`3o3@3o
ofWo0?nJ0?ooo`3?o`3o^?l0olgooo]Zool0QP02oookJP03oh00oonbo`3ooo]Z00?ooo]Z00Co8ol0
oomM0?oonf[o02co0_oonfX01ol0nooooo]ZoookJ_oonf[oooh0ofko0?oonfX00_ob0?l3oookJP07
o`1?oooonf[oo`2aoookJ_oo^`3ooo]Zool0<`0:oookJP03ool0Pooonf[ooo]Z00;o0?nH0ooonfX2
on3o02[ooo]Z001OoookJPCo09goDOoonfX4o`2Mod?ooo]Z1?l0000UoookJP03ofL0oooonf[ooo]Z
00Kooo]Z00?oo`1MoookJ_oonfX01?oonfX00oo30?oooo]ZoookJP03oookJP03oiT0oom^0?oooo]Z
00?ooo]Z1_ooN@001Ol0SOoooo]ZoookJ_oonf[ooiT000?ooo]Z00?o04SooookJ_oonfX02_ooN@02
oookJP03og;o0?ooN@3oo`0V00?oogT000Go0=oooookJ_oob@3ooo]ZokT0o`02oookJP07ooo90?n6
o`3ooo]ZoookJ_nc0?oooo]Zool0ZP02o`3o4`03oookJ_n6o`3ooo]Z00Gooo]Z0_l00Ol01ol0O?oo
;`3oooo00?oo`03o0?nVodl0ooooN@000_oonfX00ooo08coogl0o`80o`04oookJP0<oago0?mYo`3o
JOl0oiX0ool0okSooo]Zo`3ocOoonf[oo`26oookJ_n00?oo/_l01OoonfX01?lSo`3ooed0oookJ_l0
;?l2oookJP08o`3koooonf[ooo]Zool0Z_oooP3oK_l0oo80oooo03/4oookJP06ooo90?oo0;7ooo]Z
oookJ_oo^`3oo`0c2_oonfX00ooo08?ooo]ZoookJP02o`3oV0?ooo]Z0_oPo`28oookJPCo09goD?oo
nfX4o`2Mod?ooo]Z1?l0000VoookJP03ofL0oooonf[ooo]Z00Kooo]Z00?oo`1MoookJ_oonfX00ooo
nfX00oo30?oooo]ZoookJP03oookJP03oiT0oom^0?oooo]Z00Cooo]Z00?o0?l;oookJ_oonfX00_oo
nfX01Ol0SOoooo]ZoookJ_oonf[ooiT000?ooo]Z00?o04SooookJ_oonfX01OoonfX02oooT03ooel0
ool0X?oo08_ooo]Zok`0oooonf[oL_l0o`H0oomNo`3oo`0V00?ooo]Z00Co0=ooool0^ooonf[o^@3o
0_oonfX02?oolP3ooo]ZohKo0?oonf[o/`3ooookJ_oo0:[ooo]Z0_l0oa<00ooonf[oQ_l0oookJP04
oookJP;o007o00Oooo]Zobl0oooo`03ool00oc?o0?l0ojKoC`3o00;ooo]Z00?oo`2<oomo0?l20?l0
1?oonfX02OlMo`3oJOl0ofWo0?nJ0?ooo`3?o`3o^?l0olgooo]Zool0QP02oookJP03oh00oonbo`3o
oo]Z00?ooo]Z00Co8ol0oomM0?oonf[o02co0_oonfX02?l0nooooo]ZoookJ_oonf[oooh0ofko0?oo
nf[olP3o1?oonfX01ol0Cooooo]Zool0/Ooonf[ook/0oookJ_oo03<02_oonfX01Ooo08?ooo]Zoook
J_l0oiSo9_l000?ooo]Z00?oh?l0oookJ_oonfX0:_oonfX005_ooo]Z1?l0WOmIoookJP?o09go@?oo
nfX4o`0002Cooo]Z00?oI`3ooookJ_oonfX01_oonfX00ooo05gooo]ZoookJP04oookJP03ol<0oooo
nf[ooo]Z00Cooo]Z00?oKP3ooookJ_oonfX00_oonfX00oooN@3oj`3ooomi0003oomi0005o`2=oooo
nf[ooo]ZoookJ_ooV@000ooonfX00ol0B?oooo]ZoookJP0;oomi0005oookJ_mbo`3oogT0ool09_oo
nfX00_ooN@001Ol0gooooo]Zooo90?oonf[o^@3o00;ooo]Z00Gooo80oomi0?oonf[ooo]Zok<0o`02
oomi0004o`3o4ooonf[ooo]ZohKo00Kooo]Z00So007ooookJ_l0O?oo;`3oooo00?ooN@3o0?nVodl0
o`;oogT000Cooo]Zool0S?ooO`3o0P3o1?oonfX01OlMo`3oJOl0oiX0oooo0<oo0?nh00;o0?o=0_oo
08H00ooonf[oP03ook;o0004oookJP;o8ol000?ooed0o`0/ool0;?l00_oonfX01?l0nooooo]Zoook
J_oooP02ofko0003oo80oooo03_ooo]Z00?ooo]Z00?oolT0ool0/OoonfX00_oo^`000ooo03?ooo]Z
oookJP08oookJP05ool0Pooonf[ooo]Zo`3oV?lVo`000ooonfX00ooPo`3ooo]ZoookJP24oookJPCo
09goF?oonfX3o`2Mod3ooo]Z1?l0000UoookJP03ofL0oooonf[ooo]Z00Kooo]Z00?oo`1MoookJ_oo
nfX00ooonfX00oo30?oooo]ZoookJP04oookJP03ofh0oooonf[ooo]Z00?ooo]Z00?o0?l;oookJ_oo
nfX00_oonfX01Ol0SOoooo]ZoookJ_oonf[ooiT000?ooo]Z00?o04SooookJ_oonfX01OoonfX02ooo
T03ooel0oookJ_oo0:3oo`2;ok`0oooonf[oL_l0o`H0oomNo`3oo`0V00?ooo]Z00Co0=ooool0^ooo
nf[o^@3o0_oonfX01OoolP3ooo]ZohKo0?oonf[o/`3o00;oo`2Z00Gooo]Zo`3o4ooonf[ooo]ZohKo
0005oookJP09o`01oooonf[ooo]Zobl0oooo`03ooo]Zoc?o0?l0ojKoC`3o00;ooo]Z00?oo`2<oomo
0?l20?l01?oonfX01OlMo`3oJOl0oiX0oooo8@3oo`3?00;o0?o=0_oo08H2oookJP03oh00oonbo`3o
oo]Z00?ooo]Z00Co8ol0oomM0?oonf[o02co0_oonfX01?l0nooooo]ZoookJ_oooP02ofko0003oook
J_ob0?oooo]Z00?ooo]Z00?o04ooool0/Ooo0;400_oo^`02ool0<`[ooo]Z00Goo`23oookJ_oonf[o
0?nHobKo0003oookJP03on3o0?oonf[ooo]Z02_ooo]Z001HoookJP?o09goH?oonfX2o`2Mockooo]Z
1?l0000ToookJP03ofL0oooonf[ooo]Z00Gooo]Z00?oo`1MoookJ_oonfX01?oonfX00oo30?oooo]Z
oookJP04oookJP03ofh0oooonf[ooo]Z00;ooo]Z00CoogT0on/0oooonf[ooo]Z0_ooN@000ol0SOoo
oo]ZoookJP02oomi00?ooo]Z00?o04SooookJ_oonfX00_oonfX9oomi0004oookJ_mbo`3oogT0ool0
9P;ooo]Z0_ooN@001?oonf[oolT0oookJ_ni0?l2oookJP05ooob0?ooN@3oogT0oookJ_nc0?l00_oo
N@001?l0oa?ooo]ZoookJ_n6o`06oookJP08o`01oooonf[o;`3oobl0oooo`03oogT0o`3oY_m?0?l2
oomi0004oookJ_ooO`3oogl0o`80o`Cooo]Z00Wo7Ol0ofWo0?nJ0?ooo`3?o`3o^?l0olgooo]Zool0
Q_oonfX00_n00?l00onbo`3ooo]ZoookJP02oookJP04ob?o0?ooG@3ooed0o`0/o`?ooo]Z00So0?_o
oookJ_oonf[oooh0ofko0?oonf[olP3oool0>`?ooo]Z00Oo04ooool0/Ooo0;7ooo]Zoonk0?oonf[o
o`0c00[ooo]Z00Coo`23oookJ_oonf[o0?nH1?oonfX00ooPo`3ooo]ZoookJP05oookJP03ooo90?oj
0?oonP3o07Wooo]Z1?l0WOmOoookJP;o09go?_oonfX4o`0002Cooo]Z00?oI`3ooookJ_oonfX01_oo
nfX00ooo05gooo]ZoookJP03oookJP03ol<0oooonf[ooo]Z00Cooo]Z00?oKP3ooookJ_oonfX00ooo
nfX00ol0o`_oj`3ooookJP02oookJP05o`2=oooonf[ooo]ZoookJ_ooV@000ooonfX00ol0B?oooo]Z
oookJP05oookJP0;oon@0?ooG`3ooo]Zool0X?oo08_o_03ooookJ_mbo`3o1P3ooeko0?oo02H00ooo
nfX01?l0goooo`2koookJ_ni0?l3oookJP05ooob0?n6o`3ooo]Zok<0oooo0:X00_oonfX01?l0oa?o
oo]ZoookJ_n6o`05oookJP09o`01oooonf[o;`3oobl0oooo`03ooo]Zoc?o0?l0ojKoC`3o00;ooo]Z
0_ooO`000ol20?oooo]ZoookJP02oookJP08oago0?mYo`3oVP3ooolQ0?oonf[o0?o=oookJ_oo08H2
oookJP;oP03o00?o/_l0oookJ_oonfX00_oonfX2oomM0005oookJ_l0;?oooo]ZoookJ_l0nol00_oo
nfX01OoooP3oK_l0oookJ_oonf[olP3o00?ooo]Z0_l0Col01Ooo0;7ooo]Zoonk0?oonf[oo`0c00[o
oo]Z0_oo08<2oookJP03o`3oV?oonf[ooo]Z00;ooo]Z00?oh?l0oookJ_oonfX01_oonfX2ooX0obCo
oo]Z001DoookJPCo09goIOoonfX2o`2Moccooo]Z1?l0000SoookJP03ofL0oooonf[ooo]Z00Gooo]Z
00?oo`1MoookJ_oonfX01OoonfX00oo30?oooo]ZoookJP03oookJP03ofh0oooonf[ooo]Z00?ooo]Z
00?o0?l;oookJ_oonfX00_oonfX00ol0SOoooo]ZoookJP03oomi00;ooo]Z00?o04SooookJ_oonfX0
1?oonfX8oomi0005og;o0?ooN@3oG_l0ool09_oonfX00oooN@001_oob@3ooo]ZokT0oooonf[oogT0
ooob00;oogT000Goo`3dok<0ooooN@3oogT0o`3o4`02oookJP03ohKo0?oonf[ooo]Z00Cooo]Z00So
007ooookJ_l_0?ooogT0ooo00?ooN@3o0?nVodl0o`;oogT000Cooo]Zoomo0?l20?oo0P3o1?oonfX0
3?lMo`3oJOl0oiX0oooo0<oo0?nho`3ocOoonf[oo`26oookJ_n00?oooo]Zok;o00Cooo]Z00Co8ol0
oomM0?oonf[o02co0_oonfX2o`3ko`;ooo]Z00Goooh0ofko0?oonf[olP3oool0>`03oookJP05o`1?
oooo0;7ooo]ZoookJ_oo^`000_oo03<9oookJP;oo`230_oonfX00ol0oiSooo]ZoookJP02oookJP03
on3o0?oonf[ooo]Z00Cooo]Z0_oob@000ooj0?ooolT0ooo9001eoookJPCo09goIOoonfX2o`2Mocco
oo]Z1?l0000SoookJP03ofL0oooonf[ooo]Z00Kooo]Z00?oo`1MoookJ_oonfX01?oonfX00oo30?oo
oo]ZoookJP03oookJP03ofh0oooonf[ooo]Z00Cooo]Z00Go0?l;oookJ_oonf[ooo]Zo`2=o`04oook
JP04oonI0?oonf[ooo]Zo`18o`Oooo]Z00_ooi00oomO0?oonf[oo`2Pool0Ronl0?oooo]Zog;o0?l6
0?ooG_l0ool09P03oookJP04o`3Ooooo0;_ooo]ZokT0o`?ooo]Z00Gooo80ohKo0?oo0?Co/`3oool0
ZP02oookJP04o`3o4ooonf[ooo]ZohKo00Gooo]Z00Wo007ooookJ_l_0?oo07coooo00?oonf[o<ol0
o`3oY_m?0?l00_oonfX00oooO`3o0P3oo`80o`04oookJP08oago0?mYo`3oVP3oool0cooonf[o0?o=
oookJ_oo08H2oookJP03oh00oooonf[o/_l000Cooo]Z00Gooed0oookJ_l0;?oo02cooookJP02o`3k
o`;ooo]Z00Goooh0ofko0?oonf[ooo]Zoo80o`03oookJP07o`1?oooonf[oo`2aoookJ_oo^`3ooo]Z
ool0<`0:oookJP05ool0Pooonf[ooo]ZoookJ_l0oiP00ooonfX2on3o00Sooo]Z00?onP3ooookJ_oo
nfX09?oonfX0053ooo]Z1?l0WOm[oookJP03o`2Moooonf[ooo]Z03Wooo]Z1?l0000RoookJP03ofL0
oooonf[ooo]Z00Gooo]Z00?oo`1MoookJ_oonfX01OoonfX00oo30?oooo]ZoookJP03oookJP03oiT0
oom^0?oooo]Z00?ooo]Z00?o0?l;on/0oooonfX00_oonfX00ol0SOoooo]Zoomi0003oomi00;ooo]Z
00?o04SooookJ_oonfX00ooonfX9oomi0004og;o0?ooN@3oG_l0ool09PCoogT000?oo`2koookJ_ni
0?l00_ooN@001OoolP3oogT0oomi0?ooN@3o/`3o00;oogT000Co0?lCoookJ_oonf[oQ_l01_oonfX0
1_l00OooogT0obl0ooooN@3ool00oomi00;oC`3o0_ooN@000ooonf[oogl0o`80o`05oookJP0<oago
0?mYo`3oVP3oool0col0okSo0?o=oookJ_oo08Kooo]Zoh00oooonf[o/_l01?oonfX01?lSo`3ooed0
oookJ_l0;?l2oookJP09o`3koooonf[ooo]Zool0Z_oooP3oK_l0oookJ_ob0?ooo`0k00?ooo]Z00Ko
04ooool0/Ooonf[ooo]Zoonk0?oo03<:oookJP05ool0Pooonf[ooo]ZoookJ_l0oiP01?oonfX00ooP
o`3ooo]ZoookJP04oookJP;oolT000ConP3oooo90?oob@3oolT0L_oonfX3o`2Mof_ooo]Z0_l0WOlj
oookJPCo00008ooonfX00omW0?oooo]ZoookJP05oookJP03ool0GOoonf[ooo]Z00Cooo]Z00?o``3o
oookJ_oonfX00ooonfX00onI0?ooKP3ooookJP04oookJP05o`3o2ooonf[ooo]ZoookJ_l0SOl01?oo
nfX01?ooV@3ooo]ZoookJ_l0B?l7oookJP0;of3o0?ooT03ooo]Zool0X?oo08_o_03ooookJ_mbo`3o
1P3ooeko0?oo02H00ooonfX01?l0goooo`2koookJ_ni0?l3oookJP05ooob0?n6o`3oo`3dok<0oooo
0:X00_oonfX01?l0oa?ooo]ZoookJ_n6o`05oookJP07o`01oooonf[o;`3oo`1loooo`03ooo]Zoc?o
0002odl0o`;ooo]Z00?oogl0o`80oooonfX01?oonfX02?lMo`3oJOl0oiX0oooo0<oo0?nho`3ocOoo
nf[oo`260_oonfX00on00?oooo]Zok;o0003oookJP04ob?o0?ooG@3ooo]Zo`0/o`;ooo]Z00Oo0?_o
oookJ_oonf[ooo]Zooon0?m^o`3ooo]Z00;olP3o0ooonfX01ol0Cooooo]Zool0/Ooonf[ook/0oook
J_oo03<02_oonfX00ooo08?ooo]ZoookJP02o`3oV0?ooo]Z00?oh?l0oookJ_oonfX01ooonfX00ooj
0?oooo]ZoookJP0UoookJP00COoonfX3o`2Mog3ooo]Z0ooUo`0hoookJPCo00008OoonfX00omW0?oo
oo]ZoookJP06oookJP03ool0GOoonf[ooo]Z00Cooo]Z00?o``3ooookJ_oonfX00ooonfX00onI0?oo
KP3ooookJP03oookJP03o`3o2oo[0?oooo]Z00;ooo]Z00?o08gooookJ_ooN@001?ooN@000ooonf[o
04SooookJP04oookJPWoogT000CoL_l0o`H0oomNo`3oo`0V1?ooN@000ooo0;_ooo]ZokT0o`02oomi
0005ooob0?ooN@3oogT0oomi0?nc0?l00_ooN@001?l0oa?oogT0oookJ_n6o`06oookJP07o`01oooo
N@3o;`3ooomi0?oo`03oogT0odl0o`03oomi0003ool0S?ooO`3o0P3o00Cooo]Z00go3@3ooago0?mY
o`3oVP3oo`3o^?oonf[o0?o=oookJ_oo08Kooo]Zoh00oooonf[o/_l000Cooo]Z00Co8ol0oomM0?oo
nf[o02co0_oonfX01_l0nooooo]ZoookJ_oo0:[oooh0ofko00;olP3o00Ooo`0koookJ_oonf[ooo]Z
o`1?oooo0;7ooo]Z00;ook/000?oo`0coookJ_oonfX02?oonfX01Ooo08?ooo]ZoookJ_oonf[o0?nH
00?ooo]Z0_oPo`07oookJP04ooo90?oj0?ooolT0ooo900;oool0K_oonfX4o`2Mog3ooo]Z0_l0WOlh
oookJPCo00008_oonfX00omW0?oooo]ZoookJP06oookJP03ool0GOoonf[ooo]Z00?ooo]Z00?o``3o
oookJ_oonfX00ooonfX00onI0?ooKP3ooookJP04oookJP05o`3o2ooonf[ooo]ZoookJ_l0SOl01?oo
nfX01?ooV@3ooo]ZoookJ_l0B?l7oookJP0;of3o0?ooT03ooo]Zool0X?oo08_o_03ooookJ_mbo`3o
1P3ooeko0?oo02H00ooonfX01?l0goooo`2koookJ_ni0?l3oookJP05ooob0?n6o`3oo`3dok<0oooo
0:X00_oonfX01?l0oa?ooo]ZoookJ_n6o`05oookJP08o`01oooonf[o;`3oo`1loooo`03ooo]Zoc?o
0?m?0?l2oookJP03ool0S?ooO`3o0P3o00Gooo]Z00So7Ol0ofWo0?nJ0?ooo`3?o`3o^?l0olgooo]Z
ool0QP;ooo]Z00?oP03ooookJ_nbo`000ooonfX01?lSo`3ooed0oookJ_l0;?l2oookJP09o`3koooo
nf[ooo]ZoookJ_oooP3oK_l0oookJ_ob0?ooo`0k00?ooo]Z00Oo04oooookJ_oo0;7ooo]Zoonk0?oo
nf[oo`0c00[ooo]Z00Goo`23oookJ_oonf[o0?nHobKo0003oookJP03on3o0?oonf[ooo]Z00Oooo]Z
00?onP3ooookJ_oonfX00_ooo`0ToookJP00B_oonfX3o`2MogCooo]Z1_oUo`0doookJPCo00008?oo
nfX00omW0?oooo]ZoookJP06oookJP03ool0GOoonf[ooo]Z00Cooo]Z00?o``3ooookJ_oonfX00ooo
nfX00onI0?ooKP3ooookJP03oookJP03o`3o2oo[0?oooo]Z00?ooo]Z00?o08gooomi0?ooN@000ooo
N@000ooonf[o04SooookJP04oookJPWoogT000CoL_l0o`H0oomNo`3oo`0V1OooN@001Ooonf[o^@3o
oomi0?ooN@3ooo8000?oogT000Oo/`3ooomi0?ooN@3o0?lCoomi0?oonf[oQ_l000Kooo]Z00Oo007o
oookJ_l_0?ooogT0ooo00?l0ojKoC`3o00?oogT000?oo`2<oomo0?l20?l01?oonfX2oago0009ofWo
0?nJ0?oo0?nhoookJ_l0olgooo]Zool0Q_oonf[oP03o00;o/_l01?oonfX01?lSo`3ooed0oookJ_l0
;?l2oookJP08o`3koooonf[ooo]Zool0Z_oooP3oK_l0oo80oooo03/4oookJP06o`1?oooo0;7ooo]Z
oonk0?oonf[oo`0c2_oonfX00ooo08?ooo]ZoookJP02o`3oV0?ooo]Z00?oh?l0oookJ_oonfX01_oo
nfX2ooX0o`;oolT000?oool0ooo90?oob@00JooonfX3o`2MogKooo]Z0_l0WOlfoookJPCo00008Ooo
nfX00omW0?oooo]ZoookJP06oookJP03ool0GOoonf[ooo]Z00?ooo]Z00?o``3ooookJ_oonfX00ooo
nfX00onI0?ooKP3ooookJP04oookJP03o`3o2ooonf[ooo]Z00;ooo]Z00Go08gooookJ_oonf[ooo]Z
oonI0002oookJP03o`18oooonf[ooo]Z00Gooo]Z00_oH?l0oon@0?oonf[oo`2Pool0Ronl0?oooo]Z
og;o0?l60?ooG_l0ool09P03oookJP04o`3Ooooo0;_ooo]ZokT0o`?ooo]Z00Gooo80ohKo0?oo0?Co
/`3oool0ZP02oookJP04o`3o4ooonf[ooo]ZohKo00Gooo]Z00So007ooookJ_l_0?oo07coooo00?oo
nf[o0?nVodl0o`;ooo]Z00?oo`2<oomo0?l20?l01?oonfX2oago0007ofWo0?nJ0?ooo`3?o`3o^?l0
olgooo]Zool0QP02oookJP03oh00oonbo`3o/_l000?ooo]Z00Co8ol0oomM0?oonf[o02co0_oonfX0
2?l0nooooo]ZoookJ_oo0:[oooh0ofko0?oonf[olP3o1?oonfX00ol0Cooooo]Zool0/@02oonk00;o
o`0c2OoonfX2ool0P`;ooo]Z00?o0?nHobKo0?oonfX00_oonfX00ooPo`3ooo]ZoookJP06oookJP;o
nP3o0_oonfX00oooo`3ooo]ZoookJP0ToookJP00AooonfX3o`2MogSooo]Z2?oUo`0aoookJPCo0000
8?oonfX00omW0?oooo]ZoookJP05oookJP03ool0GOoonf[ooo]Z00Cooo]Z00?o``3ooookJ_oonfX0
0ooonfX00onI0?ooKP3ooookJP03oookJP03o`3o2oo[0?oooo]Z00?ooo]Z00?o08gooomi0?ooN@00
1?ooN@000ol0B?oooo]ZoookJP02oookJP[oogT000CoL_l0oomi0?ooN@3oo`0V1_ooN@001?ni0?oo
ogT0oomi0?oolP03oomi0007ok<0ooooN@3oogT0o`3o4oooN@3ooo]ZohKo0006oookJP07o`01oooo
nf[o;`3ooookJ_oo`03o0?nVodl0o`03oomi0003ool0S?ooO`3o0P3o00Cooo]Z00Oo7Ol0of?o0?mY
o`3oo`3?o`3o^?oonf[o0?o=00;oo`2600?ooo]Zoh00oonbo`001OoonfX01?lSo`3ooed0oookJ_l0
;?l2oookJP04o`3koooonf[ooo]Zooon00;oK_l000?olP3oool0>ooonfX00_oonfX2o`1?o`05ool0
/Ooonf[ook/0oookJ_oo03<02_oonfX01Ooo08?ooo]ZoookJ_l0oiSo9_l000?ooo]Z00?oh?l0oook
J_oonfX01_oonfX01Ooj0?oooo]ZoookJ_oonf[oool000?oolT0J?oonfX3o`2Mog_ooo]Z00?o09go
oookJ_oonfX0<ooonfX4o`00027ooo]Z00?oI`3ooookJ_oonfX01OoonfX00ooo05gooo]ZoookJP04
oookJP03ol<0oooonf[ooo]Z00?ooo]Z00?oKP3ooookJ_oonfX00ooonfX00ol0o`_ooo]ZoookJP02
oookJP05o`2=oooonf[ooo]ZoookJ_ooV@000_oonfX00ol0B?oooo]ZoookJP05oookJP0;of3o0?oo
T03ooo]Zool0X?oo08_o_03ooookJ_mbo`3o1P3ooeko0?oo02H00ooonfX01?l0goooo`2koookJ_ni
0?l3oookJP05ooob0?n6o`3oo`3dok<0oooo0:X00_oonfX01?l0oa?ooo]ZoookJ_n6o`05oookJP08
o`01oooonf[o;`3ooookJ_oo`03ooo]Zo`3oY_m?0?l2oookJP03ool0S?ooO`3o0P3o00Cooo]Z00Oo
7Ol0o`d0oomYo`3oVP3oool0col0okSo0?o=00;oo`260_oonfX00on00?oo/_l0oookJP03oookJP04
ob?o0?ooG@3ooo]Zo`0/o`;ooo]Z00Co0?_ooookJ_oonf[oooh00_m^o`000ooonf[olP3ooookJP03
oookJP06o`1?oooonf[oo`2aoonk0?oonf[oo`0c2_oonfX01_oo08?ooo]ZoookJ_oonf[o0?nHobKo
00?ooo]Z00?oh?l0oookJ_oonfX01_oonfX01Ooj0?oooo]ZoookJ_oonf[oool002Oooo]Z0014oook
JP?o09goO?oonfX;onGo02gooo]Z1?l0000OoookJP03ofL0oooonf[ooo]Z00Gooo]Z00?oo`1Moook
J_oonfX01?oonfX00oo30?oooo]ZoookJP03oookJP03oiT0oom^0?oooo]Z00?ooo]Z00?o0?l;oook
J_o[0?l00ooonfX00ol0SOooogT0oomi0004oomi0003o`18oooonf[ooo]Z00;ooo]Z2_ooN@001?mb
o`3oogT0oomi0?oo02H6oomi0004okT0ooooN@3oogT0ooob00?oogT000Oo/`3ooomi0?ooN@3o0?lC
oomi0?oonf[oQ_l000Kooo]Z00Oo007ooookJ_l_0?oooo]Zooo00?l0ojKoC`3o00?oogT000?oo`2<
oomo0?l20?l01?oonfX02OlMo`3oJOl0ofWo0?oo0<oo0?nhoookJ_l0olgoo`26oookJP02oh00o`03
ok;o0?oonf[ooo]Z00?ooo]Z0_ooG@02o`0/o`;ooo]Z00So0?_ooookJ_oonf[oooh0ofko0?oonf[o
lP3oool0>`?ooo]Z00Oo04ooool0/Ooo0;7ooo]Zoonk0?oonf[oo`0c00Wooo]Z0_oo08<2oookJP03
o`3oV?oonf[ooo]Z00;ooo]Z00?oh?l0oookJ_oonfX01_oonfX01_oj0?oooo]ZoookJ_oonf[oool0
oookJP?oolT0IOoonfX3o`2Mogoooo]Z0_l0WOlcoookJPCo00008?oonfX00omW0?oooo]ZoookJP05
oookJP03ool0GOoonf[ooo]Z00Cooo]Z00?o``3ooookJ_oonfX00ooonfX00om^0?oooo]ZoookJP03
oookJP03o`3o2oo[0?oooo]Z00;ooo]Z00Go08gooookJ_oonf[ooo]ZoonI0002oookJP03o`18oooo
nf[ooo]Z00Gooo]Z00_oH?l0oon@0?oonf[oo`2Pool0Ronl0?oooo]Zog;o0?l60?ooG_l0ool09P03
oookJP04o`3Ooooo0;_ooo]ZokT0o`?ooo]Z00Gooo80ohKo0?oo0?Co/`3oool0ZP02oookJP04o`3o
4ooonf[ooo]ZohKo00Gooo]Z00So007ooookJ_l_0?oooo]Zooo00?oonf[o0?nVodl0o`;ooo]Z00?o
o`2<oomo0?l20?l01?oonfX02?lMo`3oJOl0ofWo0?nJ0?oooo]Zo`3o^?l0olgoo`260_oonfX2oh00
o`03ok;o0?oonf[ooo]Z00;ooo]Z0_ooG@02o`0/o`;ooo]Z00Ko0?_ooookJ_oonf[oooh0ofko0?oo
nfX2oo80o`?ooo]Z0_l0Col2ool0/@03oonk0?oonf[oo`0c00[ooo]Z00?oo`23oookJ_oonfX00_l0
oiP3oookJP;oh?l02?oonfX00ooj0?oooo]ZoookJP02oooo02Sooo]Z0011oookJP?o09goP?oonfX<
onGo02_ooo]Z1?l0000NoookJP03ofL0oooonf[ooo]Z00Gooo]Z00?oo`1MoookJ_oonfX01OoonfX0
0oo30?oooo]ZoookJP02oookJP03oiT0oom^0?oooo]Z00Cooo]Z00Ko0?l;on/0oooonf[ooo]Zoomi
0?l0SOl6oomi0003o`18oooonf[ooo]Z00;ooo]Z2_ooN@001?mbo`3oogT0oomi0?oo02H9oomi0005
ooob0?ooN@3oogT0oomi0?nc0?l00_ooN@001?l0oa?oogT0oomi0?n6o`06oookJP03o`01oooonf[o
;`3o00;ool0000So0?nVodl0oooonf[ooo]Zoomi0?oo08coogl0o`80o`Cooo]Z00co7Ol0ofWo0?nJ
0?ooo`3?o`3o^?oonf[o0?o=ool0Q_oonf[oP03ooookJ_nbo`05oookJP03oomM0?oonf[o02co00?o
oo]Z00So0?_ooookJ_oonf[oooh0ofko0?oonf[olP3oool0>`?ooo]Z00?o04ooool0/OoonfX00_oo
^`000ooonf[oo`0coookJP08oookJP05ool0Pooonf[ooo]ZoookJ_l0oiP01?oonfX00ooPo`3ooo]Z
oookJP05oookJP;onP3o0_oonfX2oooo00?ooo]Z0_li0?mRoookJP?o09goQ?oonfX00ol0WOoooo]Z
oookJP0`oookJPCo00007ooonfX00omW0?oooo]ZoookJP05oookJP03ool0GOoonf[ooo]Z00Cooo]Z
00?o``3ooookJ_oonfX00ooonfX00om^0?oooo]ZoookJP04oookJP05o`3o2ooonf[ooo]ZoookJ_l0
SOl00ooonfX01?ooV@3ooo]ZoookJ_l0B?l7oookJP0;of3o0?ooT03ooo]Zool0X?oo08_o_03ooook
J_mbo`3o1P3ooeko0?oo02H00ooonfX01?l0goooo`2koookJ_ni0?l3oookJP05ooob0?n6o`3oo`3d
ok<0oooo0:X00_oonfX01?l0oa?ooo]ZoookJ_n6o`05oookJP03o`01oooonf[o;`3o00;ool0000?o
oo]Zo`3oY_m?0?l00_oonfX00ooo08coogl0o`80o`04oookJP08oago0?mYo`3oVP3ooolQ0?oonf[o
0?nho`3ocOoo08H2oookJP03oh00oooonf[o/_l000Cooo]Z00?ooed0oookJ_l0;?l00ooonfX02?l0
nooooo]ZoookJ_oooP3oK_l0oookJ_ob0?ooo`0k0ooonfX01ol0Cooooo]Zool0/Ooonf[ook/0oook
J_oo03<02_oonfX01Ooo08?ooo]ZoookJ_l0oiSo9_l000?ooo]Z00?oh?l0oookJ_oonfX01_oonfX2
ooX0o`;ooo]Z00?oool0ool0]ooonfX00_oonfX2ocT0obCooo]Z000noookJP?o09goQ?oonfX;onGo
02_ooo]Z1?l0000NoookJP03ofL0oooonf[ooo]Z00Gooo]Z00?oo`1MoookJ_oonfX01?oonfX00oo3
0?oooo]ZoookJP02oookJP03oiT0oooonf[oKP3o00Cooo]Z00Ko0?l;on/0oooonf[ooo]Zoomi0?l0
SOl7oomi00Oooo]Z1oooN@001?mbo`3oogT0oomi0?oo02H9oomi0005ooob0?ooN@3oogT0oomi0?nc
0?l00_ooN@001?l0oa?oogT0oomi0?n6o`06oookJP07o`01oooonf[o;`3oooo00?oonf[o0?nVodl0
o`03oookJP03ool0S?ooO`3o0P3o00?ooo]Z00Ko3@3ooago0?mYo`3oVP3oool0coooN@02o`3oc@05
ool0Q_oonf[oP03ooookJ_nbo`001OoonfX00oooG@3ooo]Zo`0/o`03oookJP08o`3koooonf[ooo]Z
ooon0?m^o`3ooo]Zoo80oooo03/3oookJP05o`1?oooo0;7ooo]Zoonk0?oonfX00_oo03<9oookJP05
ool0Pooonf[ooo]ZoookJ_l0oiP01?oonfX00ooPo`3ooo]ZoookJP05oookJP05ooX0oooonf[ooo]Z
oookJ_ooo`001?oonfX00oli0?oooo]Zooo9001OoookJP?o09goR?oonfX00ol0WOoooo]ZoookJP0_
oookJPCo00007_oonfX00omW0?oooo]ZoookJP06oookJP03ool0GOoonf[ooo]Z00Cooo]Z00?o``3o
oookJ_oonfX00_oonfX00onI0?ooKP3ooookJP04oookJP05o`3o2ooonf[ooo]ZoookJ_l0SOl00ooo
nfX01?ooV@3ooo]ZoookJ_l0B?l7oookJP0;of3o0?ooT03ooo]Zool0X?oo08_o_03ooookJ_mbo`3o
1P3ooeko0?oo02H00ooonfX01?l0goooo`2koookJ_ni0?l3oookJP05ooob0?n6o`3oo`3dok<0oooo
0:X00_oonfX01?l0oa?ooo]ZoookJ_n6o`05oookJP04o`01oooonf[o;`3oooo000;ooo]Z00Oo0?nV
odl0oooonf[ooo]Zool0S?ooO`3o0P3o00Cooo]Z00Co7Ol0ofWo0?nJ0?ooob400_l0okP01ol0olgo
o`26oookJ_oonf[oP03ooookJ_nbo`001?oonfX00oooG@3ooo]Zo`0/o`03oookJP08o`3koooonf[o
oo]Zooon0?m^o`3ooo]Zoo80oooo03/3oookJP03o`1?oooonf[oo`2a00;ook/000?ooo]Zool0<ooo
nfX02OoonfX01Ooo08?ooo]ZoookJ_l0oiSo9_l000?ooo]Z00?oh?l0oookJ_oonfX01_oonfX01Ooj
0?oooo]ZoookJ_oonf[oool000Cooo]Z00?o>@3ooookJ_oonfX09?oonfX003_ooo]Z0ol0WOn8oook
JPWoiOl0;?oonfX4o`0001gooo]Z00?oI`3ooookJ_oonfX01OoonfX00ooo05gooo]ZoookJP04oook
JP03ol<0oooonf[ooo]Z00;ooo]Z00?oV@3ooookJ_m^0?l01?oonfX01_l0o`_oj`3ooookJ_oonf[o
ogT0o`2=o`SoogT01_oonfX00omPo`3ooi00oomi0007oomi0003ool09_ooN@3oogT000KoogT000?o
oo]Zooob0?ooN@000_ooN@001?nc0?ooogT0oomi0?l0oa<2oomi0003ohKo0?oonf[ooo]Z00Cooo]Z
00Go007ooookJ_l_0?oool00oookJP02odl0o`?ooo]Z00?oo`2<oomo0?l20?l00ooonfX03Ol=0?oo
7Ol0ofWo0?nJ0?ooo`3?oomi0?l0olgooo]Zool0Q_oonf[oP03ooookJ_nbo`001?oonfX01?lSo`3o
oed0oookJ_l0;?l3oookJP08o`3koooonf[oo`2Zooon0?m^o`3ooo]Zoo80oooo03/2oookJP;o04oo
00Goo`2aoookJ_oo^`3ooo]Zool0<`0:oookJP03ool0Pooonf[ooo]Z00;o0?nH0ooonfX2on3o00Oo
oo]Z00GonP3ooookJ_oonf[ooo]Zoooo0004oookJP03ocT0oooonf[ooo]Z05gooo]Z0ol0WOn<oook
JP;o09go;ooonfX4o`0001gooo]Z00?oI`3ooookJ_oonfX01_oonfX00ooo05gooo]ZoookJP04oook
JP03ol<0oooonf[ooo]Z00;ooo]Z00?oV@3oofh0oooonfX01?oonfX01Ol0o`_ooo]ZoookJ_oonf[o
08go00?ooo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`07oookJP0:oon@0?oonf[oo`2Pool0Ronl0?oo
oo]Zog;o0?l60?ooG_l0ool09P?ooo]Z00Co0=ooool0^ooonf[o^@3o0ooonfX01OoolP3oQ_l0ool0
m?nc0?ooo`2Z00;ooo]Z00Co0?lCoookJ_oonf[oQ_l01OoonfX01?l00Ooooo]Zobl0oooo`002oook
JP;oC`3o0_oonfX00ooo08coogl0o`80o`04oookJP08oago0?mYo`3oVP3oool0col0okSooo]Zo`3o
cOoo08H2oookJP03oh00oooonf[o/_l000?ooo]Z00Co8ol0oomM0?oonf[o02co0ooonfX02?l0nooo
oo]Zool0Z_oooP3oK_l0oookJ_ob0?ooo`0k0ooonfX01?l0Cooooo]Zool0/Ooo^`02oookJP03ool0
<ooonf[ooo]Z00Oooo]Z0_oo08<2oookJP03o`3oV?lVo`3ooo]Z00;ooo]Z00?oh?l0oookJ_oonfX0
1_oonfX01Ooj0?oooo]ZoookJ_oonf[oool000Cooo]Z00?o>@3ooookJ_oonfX09OoonfX003Sooo]Z
0ol0WOn<oookJPSoiOl0;?oonfX4o`0001cooo]Z00?oI`3ooookJ_oonfX01OoonfX00ooo05gooo]Z
oookJP04oookJP03ol<0oooonf[ooo]Z00?ooo]Z00?oV@3oofh0oooonfX00ooonfX00ol0o`_oj`3o
oookJP03oookJP03o`2=ooooN@3oogT000GoogT01_oonfX00omPo`3ooi00oookJP07oomi0003ool0
9_oonf[oogT000KoogT000?ooo]Zooob0?ooN@000_ooN@001?nc0?ooogT0oomi0?l0oa<3oomi00Ko
oo]Z00Oo007ooookJ_l_0?oool00oookJ_m?0?ooogT000?ooo]Z00?oo`2<oomo0?oonfX00ooonfX0
3Ol=0?oo7Ol0ofWo0?ooN@3oo`3?oomi0?l0olgooo]Zool0Q_oonf[oP03ooookJ_nbo`001?oonfX0
1?lSo`3ooed0oookJ_l0;?l2oookJP;o0?_o00Cooo]Zool0Z_oooP3oK_l00_ob0?l3oookJP03o`1?
oooo0;7oo`2a00;ook/000?ooo]Zool0<ooonfX02OoonfX01Ooo08?ooo]ZoookJ_l0oiSo9_l000?o
oo]Z00?oh?l0oookJ_oonfX01_oonfX01Ooj0?oooo]ZoookJ_oob@3oool000Cooo]Z00Go>@3ooook
J_oonf[ooo]Zool0bP1IoookJP?o09goTOoonfX00ol0WOoooo]ZoookJP0/oookJPCo00007OoonfX0
0omW0?oooo]ZoookJP05oookJP03ool0GOoonf[ooo]Z00Cooo]Z00?o``3ooookJ_oonfX00ooonfX0
0om^0?oooo]ZoookJP03oookJP03o`3o2ooonf[ooo]Z00;ooo]Z00Co08gooookJ_oonf[ooiT00ooo
nfX00ol0B?oooo]ZoookJP05oookJP0:oon@0?oonf[oo`2Pool0Ronl0?oooo]Zog;o0?l60?ooG_l0
ool09P?ooo]Z00Co0=ooool0^ooonf[o^@3o0ooonfX01OoolP3oQ_l0ool0m?nc0?ooo`2Z00;ooo]Z
00Co0?lCoookJ_n6o`3oQ_l01OoonfX01?l00Ooooo]Zobl0oooo`002oookJP06odl0oooonf[ooo]Z
oookJ_oo08coogl01OoonfX02?lMo`3oJOl0oiX0oooo0<oo0?nhoookJ_l0olgoo`260_oonfX00on0
0?oooo]Zok;o0003oookJP04ob?o0?ooG@3ooo]Zo`0/o`;ooo]Z0_l0nol01_oonf[oo`2Zooon0?m^
o`3ooo]Zoo80o`Cooo]Z00Go04ooool0/Ooo0;7ook/0oookJP02ool0<`Wooo]Z00Goo`23oookJ_oo
nf[ooo]Zo`3oV003oookJP;oh?l02?oonfX00ooj0?oooo]ZoookJP02oooo00Cooo]Z00?o>@3ooook
J_oonfX00_oo0<XToookJP00=OoonfX3o`2Moi3ooo]Z1_oUo`0]oookJPCo00007?oonfX00omW0?oo
oo]ZoookJP05oookJP03ool0GOoonf[ooo]Z00?ooo]Z00?o``3ooookJ_oonfX00ooonfX00onI0?oo
KP3ooookJP03oookJP03o`3o2oo[0?oooo]Z00?ooo]Z00?o08gooookJ_oonfX01_ooN@05oookJP05
of3o0?ooT03ooo]Zoomi0?oo08/01OooN@000ooo02KoogT0oookJP07oomi0005ooob0?ooN@3ooo]Z
ool0m?nc0?l00_ooN@000ol0oa?oogT0oomi0002oomi00Gooo]Z00Oo007ooookJ_l_0?oool00o`3o
Y_m?0?ooogT000;ooo]Z0_oo08`00oooO`3ooo]ZoookJP02oookJP03o`d0oolMo`3oJOl000;oo`3?
00SoogT0o`3ocOoonf[oo`26oookJ_n00?oooo]Zok;o00Cooo]Z00Co8ol0oomM0?oonf[o02co0_oo
nfX02?l0nooooo]ZoookJ_oo0:[oooh0ofko0?ob0?ooo`0k0ooonfX01?l0Coooo`2aoookJ_oo^`02
oookJP03ool0<ooonf[ooo]Z00Sooo]Z00Coo`23oookJ_oonf[o0?nH1?oonfX00ooPo`3ooo]Zoook
JP05oookJP;onP3o0_oonfX2oooo00Cooo]Z00Go>@3ooookJ_oonf[ooo]Zool0bP1GoookJP?o09go
UOoonfX00ol0WOoooo]ZoookJP0[oookJPCo00007?oonfX00omW0?oooo]ZoookJP06oookJP03ool0
GOoonf[ooo]Z00?ooo]Z00?o``3ooookJ_oonfX00ooonfX00om^0?oooo]ZoookJP03oookJP03o`3o
2ooonf[ooo]Z00;ooo]Z00Co08gooookJ_oonf[ooiT00ooonfX00ol0B?oooo]ZoookJP05oookJP0:
oon@0?oonf[oo`2Pool0Ronl0?oooo]Zog;o0?l60?ooG_l0ool09P?ooo]Z00Co0=ooool0^ooonf[o
^@3o0ooonfX01OoolP3oQ_l0ool0m?nc0?ooo`2Z00;ooo]Z00?o0?lCoookJ_n6o`001_oonfX01ol0
0Ooooo]Zobl0oooo`03ooo]Zo`3oY_m?0?l00ooonfX00ooo08coogl0oookJP04oookJP08oago0?mY
o`3oVP3oool0col0okSooo]Zo`3ocOoo08H2oookJP03oh00oooonf[o/_l000?ooo]Z00Co8ol0oomM
0?oonf[o02co0_oonfX01_l0nooooo]ZoookJ_oo0:[oooh0ofko00;olP3o1?oonfX01_l0Coooo`2a
oookJ_oo^`3ooo]Zool0<`[ooo]Z00?oo`23oookJ_oonfX00_l0oiP3oookJP03on3o0?oonf[ooo]Z
00Kooo]Z0_oj0?l2oookJP03oooo0?oonf[ooo]Z00;ooo]Z0_li0?l2oookJP03ool0b_oonf[ooo]Z
02Cooo]Z000boookJP?o09goU?oonfX4onGo00;o09go;?oonfX4o`0001_ooo]Z00?oI`3ooookJ_oo
nfX01OoonfX00ooo05gooo]ZoookJP04oookJP03ol<0oooonf[ooo]Z00;ooo]Z00?oV@3oofh0oooo
nfX00ooonfX00ol0o`_oj`3ooookJP03oookJP03o`2=oooonf[ooo]Z00KoogT01OoonfX02omPo`3o
oi00ool0X?ooN@3oo`2;oomi0?oonf[oL_l0oomi0?mNo`3oo`0V00WoogT000Gooo80oomi0?oonf[o
o`3dok<0o`02oomi0003o`3o4oooN@3oogT000;oogT01OoonfX01ol00Ooooo]Zobl0oooo`03o0?nV
odl0ooooN@000_oonfX00ooo08cooo]Zoomo0004oookJP04oomi0?lMo`3oJOl0ool0c`;oogT000Oo
0?o=oomi0?oo08Kooo]Zoh00oooonf[o/_l000Cooo]Z0_ooG@02o`0/o`;ooo]Z00Co0?_ooookJ_oo
nf[oooh00_m^o`000oob0?ooo`0koookJP02oookJP04o`1?oooo0;7ooo]Zoonk00;ooo]Z00?oo`0c
oookJ_oonfX01ooonfX2ool0P`;ooo]Z00?o0?nHoookJ_oonfX00_oonfX00ooPo`3ooo]ZoookJP05
oookJP05ooX0oooonf[ooo]ZoookJ_ooo`001OoonfX01Oli0?oooo]ZoookJ_oonf[oo`3:05Gooo]Z
0ol0WOnIoookJP03o`2Moooonf[ooo]Z02[ooo]Z1?l0000KoookJP03ofL0oooonf[ooo]Z00Kooo]Z
00?oo`1MoookJ_oonfX01?oonfX00oo30?oooo]ZoookJP02oookJP03ofh0oooonf[ooo]Z00?ooo]Z
00?o0?l;on/0oooonfX00_oonfX01?l0SOoooo]ZoookJ_ooV@03oookJP03o`18oooonf[ooo]Z00Go
oo]Z00[ooi00oookJ_oo0:3oo`2;ok`0oooonf[oL_l0o`H0oomNo`3oo`0V0ooonfX01?l0goooo`2k
oookJ_ni0?l3oookJP05ooob0?n6o`3oo`3dok<0oooo0:X00_oonfX00ol0oa?ooo]ZohKo0006oook
JP07o`01oooonf[o;`3oooo00?oonf[o0?nVodl0o`03oookJP03ool0S?ooO`3ooo]Z00Cooo]Z00So
7Ol0ofWo0?nJ0?oooo]Zo`3o^?oonf[o0?o=ool0QP;ooo]Z00?oP03ooookJ_nbo`000ooonfX2oomM
00;o02co0_oonfX01?l0nooooo]ZoookJ_oooP02ofko0003oo80oooo03_ooo]Z00?ooo]Z00Ko04oo
ool0/Ooonf[ook/0oookJ_oo03<:oookJP05ool0Pooonf[ooo]Zo`3oV?lVo`000ooonfX00ooPo`3o
oo]ZoookJP06oookJP05ooX0oooonf[ooo]ZoookJ_ooo`001?oonfX01Oli0?oooo]ZoookJ_oonf[o
o`3:02Oooo]Z000`oookJP;o09goV?oonfX3onGo00;ooo]Z00?o09gooookJ_oonfX0:OoonfX5o`00
01Wooo]Z00?oI`3ooookJ_oonfX01_oonfX00ooo05gooo]ZoookJP03oookJP03ol<0oooonf[ooo]Z
00;ooo]Z00?oV@3ooookJ_m^0?l01?oonfX00ol0o`_ooo]ZoookJP02oookJP03o`2=oooonf[oogT0
00OoogT01?oonfX00omPo`3ooi00ool0X002oookJP07ool0Ronl0?ooL_l0o`H0oomNo`3oo`0Voook
JP0:oomi0004oookJ_oo0?Co/`3ooomi00;o0?lC1?ooN@05oookJP06o`01oooonf[o;`3oooo00?l0
ojKoC`3o0ooonfX00ooo08cooo]Zoomo0003oookJP05oomi0?lMo`3o7Ol0ofWo0?oo0<l00_ooN@00
1ol0olgoo`26ool0Q_oonf[oP03ooookJ_nbo`001?oonfX00oooG@3ooo]Zo`0/o`03oookJP08o`3k
oooonf[oo`2Zooon0?m^o`3ooo]Zoo80oooo03/3oookJP04o`1?oooo0;7ooo]Zoonk00;ooo]Z00?o
o`0coookJ_oonfX01ooonfX01Ooo08?ooo]ZoookJ_oonf[o0?nH00Cooo]Z00?oh?l0oookJ_oonfX0
1OoonfX01Ooj0?oooo]ZoookJ_oonf[oool000Gooo]Z00Go>@3ooookJ_oonf[ooo]Zool0bP1Doook
JP;o09goWOoonfX00ol0WOoooo]ZoookJP0YoookJPGo00006OoonfX00omW0?oooo]ZoookJP06oook
JP03ool0GOoonf[ooo]Z00Cooo]Z00?o``3ooookJ_oonfX00_oonfX00onI0?ooKP3ooookJP04oook
JP05o`3o2ooonf[ooo]ZoookJ_l0SOl00ooonfX01?ooV@3ooo]ZoookJ_l0B?l7oookJP0:oon@0?oo
nf[oo`2PoookJ_oo08_o_03oog;o0?l60?ooG_l0ool09P?ooo]Z00Co0=ooool0^ooonf[o^@3o0ooo
nfX01_oolP3oQ_l0ool0m?nc0?ooo`2ZoookJP;o0?lC00?ooo]ZohKo0?oonfX01OoonfX01ol00Ooo
oo]Zobl0oooo`03ooo]Zo`3oY_m?0?l00ooonfX00ooo08coogl0oookJP03oookJP;o7Ol000OoJOl0
oiX0ool0okSo0?nhoookJ_l0olgoo`2600;ooo]Z00?oP03ooookJ_nbo`000ooonfX00oooG@3ooo]Z
o`0/o`03oookJP08o`3koooonf[ooo]Zooon0?m^o`3ooo]Zoo80oooo03/3oookJP;o04oo00Goo`2a
oonk0?oo^`3ooo]Zool0<`09oookJP;oo`230_oonfX00ol0oiSo9_l0oookJP02oookJP03on3o0?oo
nf[ooo]Z00Kooo]Z00?onP3ooookJ_oonfX00_ooo`04oookJP05ocT0oooonf[ooo]ZoookJ_oo0<X0
:?oonfX002kooo]Z0_l0WOnKoookJP03onGo0?oonf[ooo]Z00;ooo]Z00?o09gooookJ_oonfX0:?oo
nfX4o`0001[ooo]Z00?oI`3ooookJ_oonfX01OoonfX00ooo05gooo]ZoookJP03oookJP03ol<0oooo
nf[ooo]Z00;ooo]Z00?oV@3ooookJ_m^0?l01?oonfX00ol0o`_ooo]ZoookJP02oookJP03o`2=oooo
N@3oogT000OoogT01?oonfX2odCo0007ool0X?oonf[ooo]Zool0Ronl0?ooL_l0o`H0o`02ool09P_o
ogT000Gooo]Zool0m?nc0?ooogT0o`3o4`06oomi00?ooo]Z0_l00Ol01Ooonf[o;`3oooo00?l0ojKo
C`3o00?ooo]Z00?oo`2<oookJ_ooO`000_oonfX2oomi0004oago0?ooN@3oJOl0ool0c`;oogT000?o
0?o=ool0Q_oonfX00_n00?l2ok;o00Cooo]Z00?ooed0oookJ_l0;?l00ooonfX02?l0nooooo]Zool0
Z_oooP3oK_l0oookJ_ob0?ooo`0k0_oonfX2o`1?o`03ool0/Ooo^`3ook/000;ooo]Z00?oo`0coook
J_oonfX01ooonfX01Ooo08?ooo]ZoookJ_oonf[o0?nH00Cooo]Z00?oh?l0oookJ_oonfX01OoonfX0
1Ooj0?oooo]ZoookJ_oob@3oool000Gooo]Z00Go>@3ooookJ_oonf[ooo]Zool0bP1CoookJP;o09go
X?oonfX00ol0WOoooo]ZoookJP0XoookJPCo00006_oonfX00omW0?oooo]ZoookJP05oookJP03ool0
GOoonf[ooo]Z00Cooo]Z00?o``3ooookJ_oonfX00_oonfX00onI0?ooKP3ooookJP04oookJP05o`3o
2ooonf[ooo]ZoookJ_l0SOl00ooonfX01?ooV@3ooo]ZoookJ_l0B?l7oookJP08oon@0?oonf[oo`2P
oookJ_oo08_o_03oog;o0?l60?l2ool09P?ooo]Z00Co0=ooool0^ooonf[o^@3o0_oonfX2ooob0006
ohKo0?oo0?Co/`3oool0Z_oonf[o0?lC0_oonfX00on6o`3ooo]ZoookJP03oookJP;o007o00Kooo]Z
obl0oooo`03ooo]Zo`3oY_m?0?l3oookJP03ool0S?ooO`3ooo]Z00?ooo]Z00Go7Ol0o`d0oomYo`3o
VP3oo`3o^002oookJP03o`3ocOoonf[ooo]Z00;oP03o0_nbo`03oookJP03oomM0?oonf[o02co00?o
oo]Z00So0?_ooookJ_oonf[oooh0ofko0?oonf[olP3oool0>`?ooo]Z00Co04oooookJ_oo0;7ook/0
0_oonfX00ooo03?ooo]ZoookJP07oookJP05ool0Pooonf[ooo]ZoookJ_l0oiP01?oonfX00ooPo`3o
oo]ZoookJP06oookJP05ooX0oooonf[ooo]Zoooo0?oo0;L01?oonfX01Oli0?oooo]ZoookJ_oonf[o
o`3:02Wooo]Z000[oookJP?o09goXooonfX00ol0WOoooo]ZoookJP0WoookJPCo00006OoonfX00omW
0?oooo]ZoookJP05oookJP03ool0GOoonf[ooo]Z00?ooo]Z00?o``3ooookJ_oonfX00ooonfX00onI
0?ooKP3ooookJP03oookJP03o`3o2ooonf[ooo]Z00;ooo]Z00?o08gooomi0?ooN@002?ooN@03oook
JP;oA?l000Woo`2PoookJ_oonf[oo`2;ok`0oooonf[oL_l0ool09_oonfX02_ooN@001_n6o`3ooo]Z
ool0m?nc0?ooo`2Zo`3o4`KoogT00ooonfX01ol00Ooooo]ZoookJ_l_0?oool00o`3oY_m?0?l00ooo
nfX00ooo08cooo]Zoomo0002oookJP;oogT000Co7Ol0ofWo0?mYo`3oo`3?0_ooN@001_l0olgoo`26
oookJ_n00?oooo]Zok;o00Cooo]Z00Co8ol0oomM0?oonf[o02co0ooonfX02?l0nooooo]Zool0Z_oo
oP3oK_l0oookJ_ob0?ooo`0k0_oonfX01?l0Coooo`2aool0/Ooo^`02oookJP;oo`0c2OoonfX00ooo
08?ooo]ZoookJP02o`3oV0?ooo]Z0_oUo`06oookJP;onP3o0_oonfX00ooob@3oool0oookJP03oook
JP;o>@3o0_oonfX2ool0bU7ooo]Z0ol0WOnSoookJP;o09go:?oonfX4o`0001Wooo]Z00?oI`3ooook
J_oonfX01_oonfX00ooo05gooo]ZoookJP03oookJP03ol<0oooonf[ooo]Z00?ooo]Z00?oKP3ooook
J_oonfX00ooonfX01Ol0o`_ooo]ZoookJ_oonf[o08go00?ooo]Z00CooiT0oookJ_oonf[o04So1ooo
nfX02OooG`3ooi00ool0X?oonf[oo`2;ok`0oooonf[oL_l0ool09P04oookJP04o`3Ooooo0;_ooo]Z
okT0o`;ooo]Z00Sooo80oookJ_n6o`3oo`3dok<0oooo0:[ooo]Zo`3o4`;ooo]Z00?oQ_l0oookJ_oo
nfX00ooonfX02?l00Ooooo]ZoookJ_l_0?oool00oookJ_l0ojKoC`3o0ooonfX00ooo08coogl0oook
JP03oookJP05oago0?mYo`3oJOl0oiX0ool0okP00_oonfX01_l0olgooo]ZoookJ_n00?oooo]Zok;o
00Cooo]Z00?ooed0oookJ_l0;?l00ooonfX02?l0nooooo]Zool0Z_oooP3oK_l0oookJ_ob0?ooo`0k
0ooonfX01Ol0Coooo`2aool0/Ooo^`3ooo]Z00;oo`0c2OoonfX00ooo08?ooo]ZoookJP02o`3oV0?o
oo]Z0_oPo`07oookJP;onP3o0_oonfX00oooo`3ooo]ZoookJP02oookJP;o>@3o0_oonfX2ool0bR[o
oo]Z000ZoookJP03o`2Moooonf[ooo]Z0:Gooo]Z00?o09gooookJ_oonfX09_oonfX4o`0001Sooo]Z
00?oI`3ooookJ_oonfX01_oonfX00ooo05gooo]ZoookJP02oookJP03ol<0oooonf[ooo]Z00?ooo]Z
00?oV@3oofh0oooonfX00ooonfX00ol0o`_ooo]ZoookJP03oookJP03o`2=ooooN@3oogT000OoogT0
0_oonfX3odCo0008ool0X?oonf[ooo]Zool0Ronl0?oooo]Zog;o0?oo02H3oookJP03o`3OooooN@3o
ogT000KoogT000Gooo]Zool0m?nc0?ooogT0o`3o4`07oomi00;ooo]Z00Oo007ooookJ_l_0?oo;`3o
ooo00?l0ojKoC`3o00?ooo]Z00Coo`2<oookJ_ooO`3ooo]Z0_oob@000oooN@3o7Ol0ofWo0004oomi
0006o`3ocOoo08KoogT0oh00oooonf[o/_l01?oonfX01?lSo`3ooed0oookJ_l0;?l3oookJP05o`3k
oooonf[oo`2Zooon0?m^o`000_ob0?l01ooo03_ooo]ZoookJ_l0Coooo`2aoookJ_oo^`000_oonfX0
0ooo03?ooo]ZoookJP08oookJP04ool0Pooonf[ooo]Zo`3oV0;ooo]Z1OoUo`05oookJP04ooX0oooo
nf[ooo]ZoookJP;oool01?oonfX01Oli0?oooo]ZoookJ_oonf[oo`3:00Gooo]Z0_nB0?m;oookJP03
o`2Moooonf[ooo]Z0:Kooo]Z00?o09gooookJ_oonfX09OoonfX4o`0001Sooo]Z00?oI`3ooookJ_oo
nfX01_oonfX00ooo05gooo]ZoookJP03oookJP03ol<0oooonf[ooo]Z00?ooo]Z00?oKP3ooookJ_oo
nfX00ooonfX00ol0o`_ooo]ZoookJP02oookJP04o`2=oooonf[ooo]ZoonI00;ooo]Z00?o04Sooook
J_oonfX01OoonfX02OooG`3ooi00ool0X?oonf[oo`2;ok`0oooonf[oL_l0ool09P04oookJP04o`3O
oooo0;_ooo]ZokT0o`;ooo]Z00Sooo80oookJ_n6o`3oo`3dok<0oooo0:[ooo]Zo`3o4`;ooo]Z00?o
Q_l0oookJ_oonfX00ooonfX02?l00Ooooo]ZoookJ_l_0?oool00oookJ_l0ojKoC`3o0ooonfX00ooo
08coogl0oookJP03oookJP05oago0?mYo`3oVP3ooolQ0?l0okP00_oonfX01_l0olgooo]ZoookJ_n0
0?oooo]Zok;o00Cooo]Z00?ooed0oookJ_l0;?l00ooonfX01Ol0nooooo]Zool0Z_oooP3oK_l000;o
lP3o00[oo`0koookJ_oonf[ooo]Zo`1?oooo0;7ooo]Zoonk0?oonf[oo`0c2_oonfX01Ooo08?ooo]Z
oookJ_l0oiSo9_l000?ooo]Z00?oh?l0oookJ_oonfX01_oonfX01Ooj0?oooo]ZoookJ_oonf[oool0
00Cooo]Z00Go>@3ooookJ_oonf[ooo]Zool0bP06oookJP;oTP3o9?oonfX00=?ooo]Z00?o09gooook
J_oonfX09OoonfX4o`0001Sooo]Z00?oI`3ooookJ_oonfX01OoonfX00ooo05gooo]ZoookJP03oook
JP03ol<0oooonf[ooo]Z00;ooo]Z00?oV@3oofh0oooonfX00ooonfX00ol0o`_oj`3ooookJP03oook
JP03o`2=oooonf[oogT000SoogT000gooo]ZodCo0?m4o`3oA?l0ool0X?m4o`3ooo]Zool0Ronl0?oo
oo]Zog;o0?oo02KoG_l000;ooo]Z00?o0=ooool0hOoo0;/01_ooN@001Ooonf[o/`3ook<0ooooN@3o
0?lC00OoogT00_oonfX01Ol00Ooooo]Zobl0ool0O?oool0000;oC`3o0ooonfX00ooo08coogl0oomo
0003ooo90003oomi0?lMo`3oJOl000?oogT00_l0old01Ooo08KoogT0oh00oooonf[o/_l000Cooo]Z
00Co8ol0oomM0?l0;?oo02co0ooonfX01ol0noooo`2Zool0Z_oooP3oK_l0oo80oooo03/00ooonfX0
1?l0Coooo`2aoookJ_oo^`02oookJP03ool0<ooonf[ooo]Z00Oooo]Z0_oo08<2oookJP03o`3oV?oo
nf[oiOl000GoiOl01OoonfX01Ooj0?oooo]ZoookJ_oonf[oool000Gooo]Z00Go>@3ooookJ_oonf[o
oo]Zool0bP05oookJP03oi80oooonf[ooo]Z0?Gooo]Z00?o09gooookJ_oonfX09?oonfX4o`0001So
oo]Z00?oI`3ooookJ_oonfX01OoonfX00ooo05gooo]ZoookJP04oookJP03ol<0oooonf[ooo]Z00;o
oo]Z00?oKP3ooookJ_oonfX00ooonfX00ol0o`_oj`3ooookJP02oookJP04o`2=oooonf[ooo]ZoonI
00;ooo]Z00?o04SooookJ_oonfX01OoonfX02_ooG`3ooi00ool0X?oonf[oo`2;ok`0oooonf[oL_l0
ool09_mNo`03oookJP04o`3Ooooo0;_ooo]ZokT0o`;ooo]Z00?ooo80oookJ_n6o`000_nc0?l00ooo
0:[ooo]Zo`3o4`02oookJP03ohKo0?oonf[ooo]Z00?ooo]Z00Ko007ooookJ_oonf[o;`3oooo00?oo
nfX2odl0o`?ooo]Z0_ooO`04oookJP06oago0?mYo`3oVP3ooolQ0?l0okSooo]Z0_l0old2oookJP03
oh00oooonf[o/_l000?ooo]Z00Co8ol0oomM0?l0;?oo02co0ooonfX01ol0nooooo]Zool0Z_oooP3o
K_l0oo80oooo03/01?oonfX01_l0Coooo`2aoookJ_oo^`3ooo]Zool0<`Wooo]Z0_oo08<2oookJP03
o`3oV?lVo`3ooo]Z00;ooo]Z00?oh?l0oookJ_oonfX01_oonfX00ooj0?oooo]ZoookJP02oooo00Co
oo]Z00Go>@3ooookJ_oonf[ooo]Zool0bP06oookJP03oi80oooonf[ooo]Z02Cooo]Z003DoookJP03
o`2Moooonf[ooo]Z02Cooo]Z1?l0000GoookJP03ofL0oooonf[ooo]Z00Kooo]Z00?oo`1MoookJ_oo
nfX00_oonfX00oo30?oooo]ZoookJP02oookJP03oiT0oooonf[oKP3o00Cooo]Z00?o0?l;oookJ_oo
nfX00_oonfX01?l0SOoooo]ZoookJ_ooV@07oomi00CoA?l000Woo`2PodCo0?oonf[oo`2;ok`0oooo
nf[oL_l0ool09_mNo`000_oonfX01Ol0goooo`3Qool0^oooN@3oFol000GoogT000Co/`3ooookJ_oo
N@3o0?lC1oooN@02oookJP07o`01oooonf[o;`3oo`1loooo`03oC`3ooc?o0003oookJP05ool0S?oo
O`3oogT0oomi0?oob@000_ooN@000olMo`3oJOl0oomi0002oomi0007o`3ocOooN@3oo`26oomi0?n0
0?oooo]Zok;o0004oookJP;oogT000?o02cooookJ_oonfX00_oonfX00ol0noooo`2Zooon0002ofko
0003oo80oooo03_ooo]Z00;ooo]Z00Co04ooool0/Ooo^`3ook/00_oonfX00ooo03?ooo]ZoookJP07
oookJP05ool0Pooonf[ooo]ZoookJ_l0oiP01ooUo`05oookJP06ooX0oooonf[ooo]Zool0]oooo`3o
olT00ooonfX2ocT0o`;ooo]Z0_oo0<X5oookJP04oi80oooonf[oolT0ooo90?Kooo]Z00?o09gooook
J_oonfX08ooonfX4o`0001Oooo]Z00?oI`3ooookJ_oonfX01_oonfX00ooo05gooo]ZoookJP03oook
JP03ol<0oooonf[ooo]Z00;ooo]Z00?oV@3oofh0oooonfX00ooonfX00ol0o`_oj`3ooookJP02oook
JP04o`2=oooonf[ooo]ZoonI00;ooo]Z00?o04SooookJ_oonfX01OoonfX02_mPo`3ooi00ool0X?oo
nf[oo`2;ok`0oooonf[oL_l0ool09_mNo`03oookJP04o`3Ooooo0;_ooo]ZokT0o`;ooo]Z00Sooo80
oookJ_n6o`3o/`3ooookJ_oo0:[ooo]Zo`3o4`;ooo]Z00?oQ_l0oookJ_oonfX00ooonfX01ol00Ooo
oo]ZoookJ_l_0?oool00oookJ_m?0?l01?oonfX00oooO`3ooo]ZoookJP03oookJP08oago0?mYo`3o
VP3oool0col0okSooo]Zo`3ocOoo08H2oookJP03oh00oooonf[o/_l000?ooo]Z0_ooG@000ol0;?oo
oo]ZoookJP02oookJP03o`3koooonf[oooh000;oK_l000?olP3oool0>ooonfX00ooonfX01_l0Cooo
o`2aoonk0?oo^`3ooo]Zool0<`Wooo]Z00Goo`23oookJ_oonf[ooo]Zo`3oV004oookJP03on3o0?oo
nf[ooo]Z00Kooo]Z00GonP3ooookJ_oonf[oool0ool0]`03oookJP;o>@3o0_oonfX2ool0bPKooo]Z
00CoTP3ooookJ_nOo`3oWol09?oonfX00=Gooo]Z00?o09gooookJ_oonfX08ooonfX4o`0001Oooo]Z
00?oI`3ooookJ_oonfX01OoonfX00ooo05gooo]ZoookJP02oookJP04ol<0oooonf[ooo]ZoookJP;o
ogT000?ooo]Zofh0oooonfX00ooonfX00ol0o`_ooo]ZoookJP02oookJP04o`2=oooonf[ooo]ZoonI
00;ooo]Z1_ooN@03odCo0009ool0X?m4o`3ooo]Zool0Ronl0?oooo]Zog;o0?oo02KoG_l000;ooo]Z
00Oo0=oooookJ_oo0;_oogT0oe_o0?oonf[ooo8000?oogT000Co/`3ooookJ_oo0:[o0?lC2?ooN@00
2?oonf[o007ooookJ_l_0?oo07coooo00?m?0?oo<ol00_oonfX2ool0S004oomo0?ooN@3oogT0ooo9
00;oogT000?o7Ol0ofWo0?ooN@000_ooN@001Ol0olgoogT0ool0Q_ooN@3oP03o00;o/_l00ooonfX4
oomi00Cooo]Z00Oo0?_oool0Z_oooP3oK_l0oookJ_ob0?ooo`0k00;ooo]Z00Co04ooool0/Ooo0;7o
ok/00_oonfX2ool0<`Wooo]Z00?oo`23oookJ_oonfX02OoUo`04oookJP;onP3o0_oonfX00ooo0;Oo
ool0oookJP03oookJP05ocT0oooonf[ooo]ZoookJ_oo0<X01OoonfX2oi80o`03oookJ_oob@3ooo]Z
0?Oooo]Z00?o09gooookJ_oonfX08ooonfX4o`0001Oooo]Z00?oI`3ooookJ_oonfX01OoonfX00ooo
05gooo]ZoookJP03oookJP03ol<0oooonf[ooo]Z00;ooo]Z00?oV@3oofh0oooonfX00ooonfX00ol0
o`_oj`3ooookJP02oookJP07o`2=oooonf[ooo]ZoookJ_ooV@3ooo]Zo`18o`07oookJP0:of3o0?oo
T03oo`2PoookJ_oo08_o_03ooookJ_mbo`3oo`0Voeko00?ooo]Z00Co0=ooool0^ooonf[o^@3o0_oo
nfX02?oolP3ooo]ZohKo0?nc0?oooo]Zool0Z_oonf[o0?lC0_oonfX00on6o`3ooo]ZoookJP03oook
JP07o`01oooonf[ooo]Zobl0oooo`03o0?nVodl0o`03oookJP03ool0S?ooO`3ooo]Z00Cooo]Z00?o
7Ol0ofWo0?nJ0?l00_l0okP00ooonf[o0?o=ool0QP02oookJP03oh00oonbo`3o/_l000?ooo]Z00?o
oed0oookJ_l0;?l01?oonfX01ol0nooooo]Zooon0?m^o`3ooo]Zoo80oooo03/00ooonfX01Ol0Cooo
o`2aool0/Ooo^`3ooo]Z00;oo`0c2OoonfX00ooo08?ooo]ZoookJP02o`3oV0?ooo]Z0_oPo`07oook
JP;onP3o0_oonfX00oooo`3ooo]ZoookJP02oookJP05ocT0oooonf[ooo]ZoookJ_oo0<X01_oonfX2
oi80o`03oookJ_nOo`3ooo]Z02Gooo]Z003FoookJP03o`2Moooonf[ooo]Z02;ooo]Z1?l0000Foook
JP03ofL0oooonf[ooo]Z00Gooo]Z00Coo`1MoookJ_oonf[ooo]Z0_oob@03oookJP?oogT000?oKP3o
oookJ_oonfX00_oonfX00ol0o`_ooo]ZoookJP02oookJP04o`2=oooonf[ooo]ZoonI00?ooo]Z00?o
04Sooomi0?ooN@000_ooN@03odCo0009ool0X?m4o`3oA?l0ool0Ronl0?oooo]Zog;o0?oo02KoG_l0
00;ooo]Z00ko0=oooookJ_oo0;_oogT0oe_o0?oonf[ooo80oookJ_n6o`3oogT0ok<0oooonf[oo`2Z
o`3o4`;ooo]Z1_ooN@02o`01o`05oookJ_l_0?oo07coooo00?m?0?l00ooonfX00ooo08coogT0oomo
0004oomi00;o7Ol000[oJOl0oomi0?ooN@3oogT0o`3ocOoonf[oo`26oomi0?n00?oo/_l00ooonfX5
oomi00?ooo]Z0_l0nol00ooo0:[oooh0ofko0002oo80o`07ool0>ooonf[ooo]Zo`1?oooo0;7ooo]Z
oonk0002oookJP03ool0<ooonf[ooo]Z00Sooo]Z00?oo`23oookJ_oUo`002_oUo`03oookJP04ooX0
oooonf[ooo]ZoookJP;oool00ooonfX2ocT0o`?ooo]Z00?oo`3:oookJ_oonfX00ooonfX01?nB0?oo
oo]ZoookJ_oob@3joookJP03o`2Moooonf[ooo]Z02;ooo]Z1?l0000FoookJP03ofL0oooonf[ooo]Z
00Gooo]Z00?oo`1MoookJ_oonfX00ooonfX00oo30?oooo]ZoookJP03oookJP03ofh0oooonf[ooo]Z
00;ooo]Z00?o0?l;on/0oooonfX00_oonfX01Ol0SOoooo]ZoookJ_oonf[ooiT000;ooo]Z00?o04So
oookJ_oonfX01?oonfX02_mPo`3ooi00ool0X?oonf[oo`2;ok`0oooonf[oL_l0ool09_mNo`03oook
JP04o`3Ooooo0;_ooo]ZokT0o`;ooo]Z00Sooo80oookJ_n6o`3o/`3ooookJ_oo0:[ooo]Zo`3o4`;o
oo]Z00?oQ_l0oookJ_oonfX00_oonfX2o`01o`;ooo]Z00Co;`3oooo00?l0ojKoC`3o0ooonfX00ooo
08coogl0oookJP03oookJP;o7Ol000?oJOl0oiX0ool0okP00_oonfX01_l0olgoo`26oookJ_oonf[o
P03ook;o00Cooo]Z00?ooed0oookJ_l0;?l00ooonfX2o`3ko`03ool0Z_oooP3oK_l000;olP3o00[o
o`0koookJ_oonf[ooo]Zo`1?oooo0;7ooo]Zoonk0?oonf[oo`0c2_oonfX01Ooo08?ooo]ZoookJ_l0
oiSo9_l000?ooo]Z00?oh?l0oookJ_oonfX01_oonfX00ooj0?oooo]ZoookJP02oooo00Cooo]Z00Go
>@3ooookJ_oonf[ooo]Zool0bP06oookJP04oi80oooonf[oWol0oioo02Oooo]Z003GoookJP03o`2M
oooonf[ooo]Z027ooo]Z1?l0000EoookJP03ofL0oooonf[ooo]Z00Gooo]Z00Coo`1MoookJ_oonf[o
oo]Z0ooob@02oookJP?oogT000?oKP3ooookJ_oonfX00_oonfX00ol0o`_ooo]ZoookJP02oookJP04
o`2=oooonf[ooo]ZoonI00?ooo]Z00?o04SooookJ_oonfX00oooN@02odCo0009ool0X?m4o`3oA?l0
ool0Ronl0?oooo]Zog;o0?oo02KoG_l000;ooo]Z00ko0=oooookJ_oo0;_ooo]ZokT0oooonf[ooo80
oookJ_n6o`3ooo]Zok<0oooonf[oo`2Zo`3o4`?ooo]Z1OooN@001ol00Ooooo]ZoookJ_l_0?oo07co
ooo00?m?0?l00_oonfX01?ooN@3oo`2<oomi0?ooO`04oomi0003oago0?ooN@3oJOl000?oogT000Ko
0?o=oookJ_oo08Kooo]Zoh00oonbo`02oookJPKoogT00ooonfX02?l0nooooo]Zool0Z_oooP3oK_l0
oo80oooonf[oo`0k0_oonfX01?l0Coooo`2aoookJ_oo^`02oookJP03ool0<ooonf[ooo]Z00Oooo]Z
0_oo08<00ooonf[oiOl0onGo0009onGo00?ooo]Z00GonP3ooookJ_oonf[ooo]Zoooo0004oookJP03
ocT0oooonf[ooo]Z00;ooo]Z00?oo`3:oookJ_oonfX00ooonfX01?nB0?oooo]Zooo90?oob@3loook
JP03o`2Moooonf[ooo]Z027ooo]Z1?l0000EoookJP03ofL0oooonf[ooo]Z00Gooo]Z00?oo`1Moook
J_oonfX01?oonfX00oo30?oooo]ZoookJP02oookJP03ofh0oooonf[ooo]Z00;ooo]Z00?o0?l;on/0
oooonfX00ooonfX01?l0SOoooo]ZoookJ_ooV@02oookJP03o`18oooonf[ooo]Z00Cooo]Z00[oH?l0
oon@0?oo0:3ooo]Zool0Ronl0?oooo]Zog;o0?oo02KoG_l00ooonfX01?l0goooo`2koookJ_ni0?l2
oookJP08ooob0?oonf[oQ_l0ok<0oooonf[oo`2ZoookJ_l0oa<2oookJP03ohKo0?oonf[ooo]Z00;o
oo]Z00So007ooookJ_oonf[ooo]Zobl0oooo`03o0?nVodl0o`?ooo]Z00?oo`2<oomo0?oonfX00ooo
nfX01OlMo`3o3@3oofWo0?nJ0?oo0?nh00;ooo]Z00Ko0?o=ool0Q_oonf[ooo]Zoh00oonbo`04oook
JP03oomM0?oonf[o02co00?ooo]Z00So0?_ooookJ_oo0:[oooh0ofko0?ob0?oooo]Zool0>`?ooo]Z
00Ko04ooool0/Ooonf[ook/0oookJ_oo03<9oookJP;oo`230_oonfX00ol0oiSo9_l0oookJP02oook
JP03on3o0?oonf[ooo]Z00Kooo]Z00GonP3ooookJ_oonf[oool0ool0]`03oookJP;o>@3o0ooonfX0
0ooo0<[ooo]ZoookJP04oookJP03oi80oooonf[oWol002Wooo]Z003HoookJP03o`2Moooonf[ooo]Z
023ooo]Z1?l0000EoookJP03ofL0oooonf[ooo]Z00Gooo]Z00?oo`1MoookJ_oonfX00ooob@02oook
JP?oogT000?oKP3ooookJ_oonfX00_oonfX00ol0o`_ooo]ZoookJP02oookJP04o`2=oooonf[ooo]Z
oonI00?ooo]Z00?o04SooookJ_oonfX00_m4o`001?ooN@3oA?l0odCo0?oo0:03odCo0005ok`0oooo
nf[oL_l0ool09_mNo`000_oonfX03_l0gooooo]Zool0^ooonf[o^@3ooookJ_oolP3ooo]ZohKo0?oo
nf[o/`3ooookJ_oo0:[o0?lC0ooonfX00oooN@3ooo]ZoookJP02oomi0008o`01oooonf[ooo]Zobl0
ool0O?oool00odl0oooonfX2oomi0003ool0S?ooN@3oogl000CoogT000?o7Ol0ofWo0?mYo`000ooo
N@001ol0olgoo`26ool0Q_oonf[oP03ook;o0?oonfX02?ooN@02oookJP03o`3koooo0:[oooh000;o
K_l000?olP3oool0>ooo03/00_oonfX01?l0Coooo`2aoookJ_oo^`02oookJP03ool0<ooonf[ooo]Z
00Oooo]Z00Coo`23oookJ_oonf[o0?nH2_oUo`03oookJP05ooX0oooonf[ooo]Zool0]oooo`001?oo
nfX01?li0?oooo]ZoookJ_oonfX2ool0bPGooo]Z00?oTP3ooookJ_oob@001?oonfX2o`Oo0?Wooo]Z
00?o09gooookJ_oonfX08?oonfX4o`0001Gooo]Z00?oI`3ooookJ_oonfX01OoonfX00ooo05gooo]Z
oookJP03oookJP03ol<0oooonf[ooo]Z00;ooo]Z00?oKP3ooookJ_oonfX00_oonfX00ol0o`_oj`3o
oookJP03oookJP04o`2=oooonf[ooo]ZoonI00;ooo]Z00?o04SooookJ_oonfX01?oonfX02_mPo`3o
oi00ool0X?oonf[oo`2;ok`0oooonf[oL_l0ool09_mNo`03oookJP04o`3Ooooo0;_ooo]ZokT0o`;o
oo]Z00Sooo80oookJ_n6o`3o/`3ooookJ_oo0:[ooo]Zo`3o4`;ooo]Z00?oQ_l0oookJ_oonfX00_oo
nfX02?l00Ooooo]ZoookJ_oonf[o;`3oooo00?l0ojKoC`3o0ooonfX00ooo08coogl0oookJP03oook
JP05oago0?mYo`3oJOl0oiX0ool0okP00_oonfX01_l0olgoo`26oookJ_oonf[oP03ook;o00Cooo]Z
00?ooed0oookJ_l0;?l00ooonfX01_l0nooooo]Zool0Z_oooP3oK_l0oo80o`;oo`0k0ooonfX01_l0
Coooo`2aoonk0?oo^`3ooo]Zool0<`Wooo]Z00?oo`23oookJ_oonfX00_l0oiP3oookJP;oh?l02?oo
nfX01?oj0?oooo]ZoookJ_ooo`04oookJP04ocT0oooonf[ooo]ZoookJP;oo`3:1_oonfX00onB0?oo
oo]Zoioo0004oookJP;o1ol09?oonfX00=Wooo]Z00?o09gooookJ_oonfX07ooonfX4o`0001Cooo]Z
00?oI`3ooookJ_oonfX01OoonfX00ooo05gooo]ZoookJP04ooo90005oookJ_ooN@3oogT0oomi0?m^
0?l01?oonfX00oo[0?oo0?l;oookJP02oookJP04o`2=oooonf[ooo]ZoonI00?ooo]Z00?o04Sooook
J_oonfX01Om4o`002Ooo0:3oA?l0odCo0?m4o`3o_03ooookJ_mbo`3oo`0Voeko0002oookJP0>o`3O
oooonf[oo`2koookJ_ni0?oooo]Zooob0?oonf[oQ_l0oookJ_nc0?oooo]Zool0Z_l0oa<3oookJP03
oomi0?oonf[ooo]Z00;ooo]Z00So007ooookJ_oonf[o;`3oo`1loooonf[oC`3ooookJP;oogT000?o
o`2<oomi0?ooO`001?ooN@000olMo`3oJOl0oomi0003oomi0003o`3ocOoo08Kooo]Z00;oP03o00?o
/_l0oomi0?ooN@001oooN@02oookJP07o`3koooo0:[oooh0ofko0?oonf[olP3oool0>`03oookJP05
o`1?oooo0;7ooo]Zoonk0?oonfX00_oo03<9oookJP06ool0Pooonf[ooo]Zo`3oV?lVo`3ooo]Z2?oU
o`02oookJP;onP3o0_oonfX00ooo0;Ooool0oookJP02oookJP;o>@3o0ooonfX00ooo0<[ooo]Zoook
JP03oookJP;oTP3o00?ooo]Zooo90?oonfX00ooonfX00ol7o`3ooo]ZoookJP3joookJP03o`2Moooo
nf[ooo]Z01oooo]Z1?l0000DoookJP03ofL0oooonf[ooo]Z00Gooo]Z00?oo`1MoookJ_oonfX00ooo
nfX00oo30?oooo]ZoookJP02oookJP03oiT0oom^0?oooo]Z00?ooo]Z00?o0?l;oookJ_oonfX00_oo
nfX01?l0SOoooo]ZoookJ_ooV@02oookJP03o`18oooonf[ooo]Z00Cooo]Z00[oH?l0oon@0?oo0:3o
oo]Zool0Ronl0?oooo]Zog;o0?oo02KoG_l00ooonfX01?l0goooo`2koookJ_ni0?l2oookJP08ooob
0?oonf[oQ_l0ok<0oooonf[oo`2ZoookJ_l0oa<2oookJP03ohKo0?oonf[ooo]Z00;ooo]Z00So007o
oookJ_oonf[ooo]Zobl0oooonf[o0?nVodl0o`?ooo]Z00?oo`2<oomo0?oonfX00ooonfX01OlMo`3o
JOl0oiX0oooo8@3o0?nh00;ooo]Z00?o0?o=oookJ_oonfX00_n00?l00onbo`3ooo]ZoookJP02oook
JP03oomM0?l0;?oo02co00?ooo]Z00?o0?_ooookJ_oooP000_m^o`000oob0?ooo`0koookJP03oook
JP04o`1?oooo0;7ook/0oookJP;oo`0c2OoonfX01Ooo08?ooo]ZoookJ_l0oiSo9_l000?ooo]Z00?o
h?l0oookJ_oonfX01_oonfX2ooX0o`;ooo]Z00?oool0oookJ_oonfX00_oonfX01Oli0?oooo]Zoook
J_oonf[oo`3:00Kooo]Z0_nB0?l2oioo00Cooo]Z00?o1ol0oookJ_oonfX09?oonfX00=[ooo]Z00?o
09gooookJ_oonfX07_oonfX4o`0001?ooo]Z00?oI`3ooookJ_oonfX01OoonfX00ooo05gooo]Zoook
JP04ooo900CoogT000?oKP3ooomi0?oonfX00_oonfX00oo[0?oo0?l;oookJP02oookJP05o`2=oooo
nf[ooo]ZoookJ_ooV@000_oonfX00ol0B?oooo]ZoookJP02oookJPCoA?l000Soo`2PodCo0?m4o`3o
A?l0oookJ_mbo`3oo`0Voeko00;ooo]Z00ko0=oooookJ_oo0;_ooo]ZokT0oooonf[ooo80oookJ_n6
o`3ooo]Zok<0oooonf[oo`2Zo`3o4`;ooo]Z00?oQ_l0oomi0?oonfX00ooonfX01ol00Ooooo]Zoook
J_l_0?oo07cooookJ_m?0?l00oooN@000ooo08coogl0oomo0003oomi0003oookJ_lMo`3oJOl000?o
ogT00_l0old01?ooN@3ooo]Zoh00oonbo`0:oomi0006oookJ_l0nooo0?_oool0Z_oooP3oK_l00_ob
0?l01?oo03_ooo]ZoookJ_oonfX2ool0/@;ook/000?ooo]Zool0<ooonfX02OoonfX01Ooo08?ooo]Z
oookJ_l0oiSo9_l000?ooo]Z1ooUo`000ooonf[onP3ooookJP02oookJP;oool00ooonfX00oli0?oo
oo]ZoookJP02oookJP03ool0b_oonf[ooo]Z00?ooo]Z00CoTP3ooookJ_oonf[oolT01?oonfX00ol7
o`3ooo]ZoookJP3loookJP03o`2Moooonf[ooo]Z01kooo]Z1?l0000DoookJP03ofL0oooonf[ooo]Z
00Cooo]Z00?oo`1MoookJ_oonfX00ooonfX00oo30?oooo]ZoookJP02oookJP03oiT0oom^0?oooo]Z
00?ooo]Z00?o0?l;oookJ_oonfX00_oonfX01ol0SOoooo]ZoookJ_oonf[ooiT0oookJ_l0B?l01_oo
nfX02_mPo`3ooi00ool0X?oonf[oo`2;ok`0oooonf[oL_l0ool09_mNo`03oookJP04o`3Ooooo0;_o
oo]ZokT0o`;ooo]Z00Sooo80oookJ_n6o`3o/`3ooookJ_oo0:[ooo]Zo`3o4`;ooo]Z00?oQ_l0oook
J_oonfX00_oonfX02?l00Ooooo]ZoookJ_oonf[o;`3ooookJ_l0ojKoC`3o0ooonfX2oomo00Cooo]Z
00Ko7Ol0ofWo0?nJ0?ooob40o`3o^?oonfX2o`3oc@;ooo]Z00?oP03ook;o0?nbo`001?oonfX00ooo
G@3o02cooookJP03oookJP04o`3koooonf[oooh0ofko00;olP3o00?oo`0koookJ_oonfX00_oonfX2
ool0/@03oonk0?oonf[oo`0c00[ooo]Z00Goo`23oookJ_oonf[o0?nHobKo0003oookJP03on3o0?oo
nf[ooo]Z00Kooo]Z00?onP3ooookJ_oonfX00_ooo`03oookJP;o>@3o0ooonfX00ooo0<[ooo]Zoook
JP04oookJP03oi80oooonf[oWol000Gooo]Z00?o1ol0oookJ_oonfX09OoonfX00<;ooo]Z0ooUo`0E
oookJP03o`2Moooonf[ooo]Z01kooo]Z1?l0000CoookJP03ofL0oooonf[ooo]Z00?ooo]Z0_ooN@00
0ooonf[oolT0ooo90003ooo900CoogT000?oKP3ooomi0?ooN@000_oonfX00oo[0?oo0?l;oookJP02
oookJP05o`2=oooonf[ooo]ZoookJ_ooV@000_oonfX00ol0B?oooo]ZoookJP04oookJP;oA?l000So
o`2PodCo0?m4o`3oA?l0oookJ_mbo`3oo`0Voeko00;ooo]Z00ko0=oooookJ_oo0;_ooo]ZokT0oooo
nf[ooo80oookJ_n6o`3ooo]Zok<0oooonf[oo`2Zo`3o4`;ooo]Z00?oQ_l0oookJ_oonfX00ooonfX0
1ol00Ooooo]ZoookJ_l_0?oo07cooookJ_m?0?l00oooN@000ooo08coogl0oomi0004oomi0003oago
0?mYo`3oogT000;oogT000Ko0?o=oomi0?ooN@3ooo]Zoh00oonbo`0:oomi0009oookJ_l0nooooo]Z
ool0Z_oooP3oK_l0oo80oooonf[oo`0k00;ooo]Z00Co04ooool0/Ooonf[ook/00_oonfX00ooo03?o
oo]ZoookJP08oookJP05ool0Pooonf[ooo]Zo`3oV?lVo`000ooonfX00ooUo`3ooo]ZonGo0004onGo
0003oookJ_oj0?oooo]Z00;ooo]Z00?oool0oookJ_oonfX00_oonfX01?li0?oooo]ZoookJ_oonfX2
ool0bPGooo]Z00CoTP3ooookJ_nOo`3oolT01?oonfX00ol7o`3ooo]ZoookJP02o`3oQo_ooo]Z00?o
09gooookJ_oonfX07_oonfX4o`0001?ooo]Z00?oI`3ooookJ_oonfX01?oonfX00ooo05gooo]Zoook
JP03oookJP03ol<0oooonf[ooo]Z00?ooo]Z00?oKP3ooookJ_oonfX00_oonfX00ol0o`_ooo]Zoook
JP02oookJP07o`2=oooonf[ooo]ZoookJ_ooV@3ooo]Zo`18o`06oookJP0:of3o0?ooT03oo`2Poook
J_oo08_o_03ooookJ_mbo`3oo`0Voeko00?ooo]Z00Co0=ooool0^ooonf[o^@3o0_oonfX02?oolP3o
oo]ZohKo0?nc0?oooo]Zool0Z_oonf[o0?lC0_oonfX00on6o`3ooo]ZoookJP02oookJP08o`01oooo
nf[ooo]ZoookJ_l_0?oooo]Zo`3oY_m?0?l3oookJP03oomo0?l20?oooo]Z00?ooo]Z00Co7Ol0ofWo
0?nJ0?ooo`3?0_oonfX01_l0olgoo`26oookJ_oonf[oP03ook;o00Gooo]Z00?ooed0o`0/oooonfX0
0_oonfX2o`3ko`06oookJ_oooP3oK_l0oo80oooonf[oo`0k0ooonfX01_l0Coooo`2aoookJ_oo^`3o
oo]Zool0<`[ooo]Z00Goo`23oookJ_oonf[o0?nHobKo0003oookJP03on3o0?oonf[ooo]Z00Kooo]Z
00ConP3ooookJ_oonf[oool01?oonfX01?li0?oooo]ZoookJ_oonfX2ool0bPKooo]Z00?oTP3ooioo
0?nOo`001?oonfX2o`Oo00;ooo]Z0_l0ohLToookJP00_OoonfX8onGo01Kooo]Z00?o09gooookJ_oo
nfX01?oonfX9o`00O`?ooo]Z1Ol007l8oookJPCo00004_oonfX00omW0?oooo]ZoookJP03oookJP?o
ogT01Ooob@04oomi0003ofh0ooooN@3oogT000?ooo]Z00?o0?l;oookJ_oonfX00_oonfX01?l0SOoo
oo]ZoookJ_ooV@02oookJP03o`18oooonf[ooo]Z00Cooo]Z00?ooel0odCo0?oo0:000om4o`001?oo
nf[oL_l0o`0aoooo02H2oookJP0>o`3Ooooonf[oo`2koookJ_ni0?oooo]Zooob0?oonf[oQ_l0oook
J_nc0?oooo]Zool0Z_l0oa<2oookJP03ohKo0?oonf[ooo]Z00?ooo]Z00Oo007ooookJ_oonf[o;`3o
o`1loolco`3oC`3o00;ooo]Z00?oogT0ool0S?ooO`001OooN@001_lMo`3oJOl0oomi0?l0okSoogT0
o`3oc@?oogT000?oP03ook;o0?oonfX02_ooN@000ol0noooo`2Zooon0002ofko0003oo80oooo03_o
o`0k00;ooo]Z00Co04ooool0/Ooonf[ook/00_oonfX00ooo03?ooo]ZoookJP07oookJP;oo`2300?o
oo]Zo`3oV?l0oiP00ooonfX2onGo00?ooo]Z0ooUo`001_oonf[onP3ooookJ_oonf[oo`2goooo00?o
oo]Z0_li0?l3oookJP03ool0b_oonf[ooo]Z00?ooo]Z0_nB0?l00ooonf[oWol0oookJP03oookJP;o
1ol00_oonfX00ol0ohOooo]Zo`0;o`3loookJP03o`2Moooonf[ooo]Z00Cooo]Z2Ol007l3oookJPGo
001o2?oonfX4o`0001?ooo]Z00?oI`3ooookJ_oonfX01?oonfX00ooo05gooo]ZoookJP02oookJP03
ol<0oooonf[ooo]Z00?ooo]Z00?oKP3ooookJ_oonfX00_oonfX00ol0o`_oj`3ooookJP03oookJP06
o`2=oooonf[ooo]ZoonI0?oonf[o04So1_oonfX02_mPo`3ooi00ool0X?oonf[oo`2;ok`0oooonf[o
L_l0o`0aoooo02H2oookJP;o0=oo00?oo`2koookJ_ni0?l00_oonfX01_oolP3ooo]ZohKo0?nc0?oo
oo]Zool0ZP;o0?lC0_oonfX00on6o`3ooo]ZoookJP02oookJP08o`01oooonf[ooo]ZoookJ_l_0?oo
oo]Zo`3oY_m?0?l2oookJP03ool0S?ooO`3o0P3o00Cooo]Z00Co7Ol0ofWo0?nJ0?ooo`3?0_oonfX0
1_l0olgoo`26oookJ_oonf[oP03ook;o00Cooo]Z0_ooG@002_l0;?oooo]ZoookJ_oonf[o0?_ooook
J_oo0:[oooh0ofko0?ob0?l2ool0>`?ooo]Z00Ko04ooool0/Ooo^`3ook/0oookJ_oo03<9oookJP;o
o`2300?ooo]Zo`3oV?l0oiP00ooonfX2on3o00Sooo]Z00ConP3ooookJ_oonf[oool01?oonfX01Oli
0?oooo]ZoookJ_oonf[oo`3:00Kooo]Z0_nB0?l00onOo`3ooo]ZoookJP03oookJP06o`Oo0?oonf[o
oo]ZoookJ_l0ohOo00_o9OoonfX00;Sooo]Z3OoUo`0GoookJP;oolT01?oonfX9o`00O`;ooo]Z1ol0
07l7oookJPCo00004_oonfX00omW0?oooo]ZoookJP02oookJP?oogT01Ooob@05oomi0003ofh0oooo
N@3oogT000;ooo]Z00?o0?l;oookJ_oonfX00_oonfX01?l0SOoooo]ZoookJ_ooV@02oookJP03o`18
oooonf[ooo]Z00Cooo]Z00Cooel0oon@0?oo0:3ooo]Z0om4o`000ombo`3o037oool09P02oookJP07
o`3Ooooo0;_oo`2koookJ_ni0?oooo]Zooob0002ohKo0005oookJ_nc0?ooo`2Zool0Z_l0oa<00_oo
nfX00on6o`3ooo]ZoookJP02oookJP;o007o0_oonfX01?l_0?ooogT0oc?o0?m?0?l3oookJP03ool0
S?ooO`3oogT000CoogT000Ko7Ol0ofWo0?ooN@3o0?nhoookJ_l0old3oomi0003oh00oonbo`3ooo]Z
00;ooo]Z2?ooN@001ol0noooo`2Zooon0?m^o`3ooo]Zoo80oooo03/00ooonfX01?l0Coooo`2aoook
J_oo^`02oookJP03ool0<ooonf[ooo]Z00Oooo]Z00Goo`23oookJ_oonf[o0?nHobKo0003oookJP03
onGo0?oonf[ooo]Z00Cooo]Z00?oiOl0ooX0oooj0?l00_oonfX2oooo00?ooo]Z00?o>@3ooookJ_oo
nfX00_oonfX00ooo0<[ooo]ZoookJP03oookJP04oi80oooonf[ooo]Zoioo00Cooo]Z00Go1ol0oook
J_oonf[ooo]Zo`3oQ`02o`0;ookooo]Z00?o09gooookJ_oonfX00ooonfX9o`00O`;ooo]Z1ol007l7
oookJPCo00004_oonfX00omW0?oooo]ZoookJP04oookJP03ool0GOoonf[ooo]Z00;ooo]Z00?o``3o
oookJ_oonfX00ooonfX00onI0?ooKP3ooookJP02oookJP03o`3o2oo[0?oooo]Z00?ooo]Z00Ko08go
oookJ_oonf[ooiT0oookJ_l0B?l6oookJP0:of3o0?ooT03oo`2PoookJ_oo08_o_03ooookJ_mbo`3o
037oool09P;ooo]Z00Go0=oooookJ_oo0;_ooo]ZokT0o`02oookJP07ooob0?n6o`3oQ_l0ok<0oooo
nf[oo`2Zo`3o4`03oookJP03ohKo0?oonf[ooo]Z00;ooo]Z00So007ooookJ_oonf[o07coobl0oooo
nf[o0?nVodl0o`;ooo]Z00?oo`2<oomo0?l20?l01?oonfX01?lMo`3oJOl0oiX0ool0okP2oookJP06
o`3ocOoo08Kooo]ZoookJ_n00?oo/_l01?oonfX00oooG@3ooo]Zo`0/o`03oookJP07o`3koooonf[o
o`2Zooon0?m^o`3olP3oool0>`04oookJP03o`1?oooo0;7ook/000;ooo]Z00?oo`0coookJ_oonfX0
1ooonfX01Ooo08?ooo]ZoookJ_l0oiSo9_l000?ooo]Z00?oh?l0oookJ_oonfX01_oonfX2ooX0o`03
oookJ_oo0;Ooool000Cooo]Z00Go>@3ooookJ_oonf[ooo]Zool0bP06oookJP03oi80oooonf[oWol0
00Cooo]Z0_l7o`03oookJP03o`3oQol02ooooo]Z02Gooo]Z002YoookJPcook404?oUo`0GoookJP?o
olT00ooonfX4o`00O`Oooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPCo00004OoonfX00omW
0?oooo]ZoookJP02oookJPCoogT01?oob@05oomi0003ofh0ooooN@3oogT000;ooo]Z00?oj`3oo`3o
2ooonfX00_oonfX01?l0SOoooo]ZoookJ_ooV@02oookJP03o`18oooonf[ooo]Z00Cooo]Z00[ooel0
oon@0?oo0:3ooo]Zool0Ronl0?ooA?l0og;o0?mNo`3oo`0V0_oonfX03_l0goooo`2kool0hOoonf[o
^@3ooookJ_oolP3oQ_l0oookJ_oo0?Co/`3oool0Z_oonf[o0?lC0_oonfX00on6o`3ooo]ZoookJP02
oookJP05o`01oooonf[ooo]Zoomi0?l_0?l00_ooN@001om?0?oooo]ZoookJ_oonf[oo`2<oomo0?oo
nfX00oooN@02oago000:ofWo0?ooN@3o0?nhoookJ_l0olgooo]Zool0Q_ooN@3oP03ook;o00Cooo]Z
00?o8ol0oomi0?ooN@001?ooN@001?oonf[oo`2Zooon0?m^o`02oo80o`09ool0>ooonf[ooo]Zoook
J_l0Coooo`2aoookJ_oo^`3ooo]Z00;oo`0c2OoonfX01Ooo08?ooo]ZoookJ_l0oiSo9_l000?ooo]Z
00?oiOl0oookJ_oonfX01OoonfX01Ooj0?oooo]ZoookJ_oonf[oool000Cooo]Z00Co>@3ooookJ_oo
nf[ooo]Z0_oo0<X5oookJP04oi80oooonf[oWol0oioo00Cooo]Z00?o1ol0oookJ_oonfX00_l0ohL0
0ol02ooooo]ZoookJP3;oookJQOook407OoonfX00ol0WOoooo]ZoookJP02oookJPCo001o1ooonfX3
o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l0000BoookJP03ofL0oooonf[ooo]Z00?ooo]Z00?o
o`1MoookJ_oonfX00_oonfX00oo30?oooo]ZoookJP03oookJP03oiT0oom^0?oooo]Z00?ooo]Z00?o
0?l;oookJ_oonfX00_oonfX01_l0SOoooo]ZoookJ_ooV@3ooo]Zo`18o`Kooo]Z00[oH?l0oon@0?oo
0:3ooo]Zool0Ronl0?oooo]Zog;o0?mNo`3oo`0V0_oonfX01Ol0gooooo]Zool0^ooonf[o^@3o00;o
oo]Z00Oooo80ohKo0?oonf[o/`3ooookJ_oo0:[o0?lC00?ooo]Z00?oQ_l0oookJ_oonfX00_oonfX0
2?l00Ooooo]ZoookJ_l0O?oo;`3ooookJ_l0ojKoC`3o0_oonfX00ooo08coogl0o`80o`03oookJP;o
7Ol000?oJOl0oiX0ool0okP00_oonfX00ol0olgoo`26oookJP02oh00o`03ok;o0?oonf[ooo]Z00;o
oo]Z00?ooed0oookJ_l0;?l00ooonfX01?l0nooooo]Zool0Z_oooP02oo80o`03ool0>ooonf[ooo]Z
00;ooo]Z0_oo0;401?oo^`3ooo]Zool0<ooo03<9oookJP05ool0Pooonf[ooo]Zo`3oV?lVo`000ooo
nfX00ooPo`3ooo]ZoookJP06oookJP03ooX0oooonf[ooo]Z00;oool00ooonfX2ocT0o`;ooo]Z0_oo
0<X6oookJP03oi80oonOo`3oWol000Cooo]Z00Co1ol0oookJ_oonf[ooo]Z0_l0ohLXoookJP00X_oo
nfX7oona00oooo]Z3?oUo`000ooo/@3ooo]ZoookJP0?oookJPOo001o0ooob@03oookJPCo001o1Ooo
nfX3o`00O`?ooo]Z0ol007l6oookJPCo00004?oonfX00oooN@3ooo]ZoookJP02oookJPGoogT00ooo
b@05oomi0007ofh0ooooN@3oogT0oomi0?oonf[oj`3oo`3o2`03oookJP04o`2=oooonf[ooo]ZoonI
00;ooo]Z00?o04SooookJ_oonfX01?oonfX02_mPo`3ooi00ool0X?oonf[oo`2;ok`0oooonf[oL_l0
oeko0?oo02H2oookJP0>o`3Ooooo0;_oo`3QoookJ_ni0?oooo]Zooob0?n6o`3ooo]Zool0m?nc0?oo
o`2ZoookJ_l0oa<2oookJP03ohKo0?oonf[ooo]Z00;ooo]Z00Go007ooookJ_ooN@3oogT0obl0o`02
oomi0006odl0oooonf[ooo]ZoookJ_oo08coogl00ooonfX02?ooN@3o7Ol0oomi0?mYo`3oogT0o`3o
^?oonf[o0?o=0_oo08H00ooonf[oP03ook;o0004oookJP03ob?o0?ooN@3o02co00GoogT000Coo`2Z
ooon0?m^o`3olP3o0_oo03/3oookJP;oo`2a0_oo^`000ooonf[oo`0coookJP09oookJP05ool0Pooo
nf[o0?nHo`3oV?lVo`000_oonfX2onGo00Oooo]Z00GonP3ooookJ_oonf[oo`2goooo0003oookJP;o
>@3o0ooonfX00ooo0<[ooo]ZoookJP04oookJP03oi80oooonf[oWol000Cooo]Z0_l7o`02oookJP03
o`3oQooonf[o00_o00;ooo]Z0_ooeP33oookJPOook405ooonfX6oona013ooo]Z2?l007l00ol0WOoo
001ooookJP02oookJPCo001o1OoonfX3o`00O`?ooo]Z0ol007l6oookJPCo00004OoonfX00omW0?oo
oo]ZoookJP03oookJP03ool0GOoonf[ooo]Z00?ooo]Z00?o``3ooookJ_oonfX00ooonfX00om^0?oo
oo]ZoookJP02oookJP03o`3o2ooonf[ooo]Z00;ooo]Z00Ko08gooookJ_oonf[ooiT0oookJ_l0B?l6
oookJP0:of3o0?ooT03oo`2PoookJ_oo08_o_03ooookJ_mbo`3oG_l0ool09P;ooo]Z00Go0=oooook
J_oo0;_ooo]ZokT0o`02oookJP07ooob0?n6o`3ooo]Zok<0oooonf[oo`2Zo`3o4`03oookJP03ohKo
0?oonf[ooo]Z00;ooo]Z00So007ooookJ_oonf[o07coobl0oooonf[o0?nVodl0o`;ooo]Z00?oo`2<
oomo0?l20?l00ooonfX01OlMo`3o3@3oofWo0?nJ0?oo0?nh00;ooo]Z00Co0?o=ool0Q_oonf[oP03o
0_nbo`04oookJP03oomM0?oonf[o02co00?ooo]Z00Go0?_ooookJ_oooP3oK_l0oo80o`02ool0>`Co
oo]Z00Goo`2aoookJ_oo^`3ooo]Zool0<`0:oookJP05ool0Pooonf[o0?nHo`3oV?lVo`000_oonfX2
on3o00Sooo]Z00ConP3ooookJ_oonf[oool01?oonfX01Oli0?oooo]ZoookJ_oonf[oo`3:00Oooo]Z
00?oTP3ooioo0?oonfX01?oonfX01_l7o`3ooo]ZoookJ_oonf[o0?n7o`0;o`?ooo]Z0_ooeP0Toook
JP00WOoonfX5oona01Wooo]Z2OoUo`000ooonf[ook40oona0003oona00cooo]Z1ol007l4ooo900?o
oo]Z1Ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z1_l0000=oookJP;oogT00ooonfX5oomi00Ko
olT00_ooN@001om^0?ooogT0oomi0?ooN@3ooo]Zon/0ool0o`/00ooonfX01?l0SOoooo]ZoookJ_oo
V@03oookJP03o`18oooonf[ooo]Z00?ooo]Z00[oH?l0oon@0?oo0:3ooo]Zool0Ronl0?oooo]Zog;o
0?mNo`3oo`0V0_oonfX03_l0goooo`2kool0hOoonf[o^@3ooookJ_oolP3oQ_l0oookJ_oo0?Co/`3o
ool0Z_oonf[o0?lC0_oonfX00on6o`3ooo]ZoookJP02oookJP03o`01ooooN@3oogT000CoogT000Ko
C`3ooookJ_oonf[ooo]Zool0S?ooO`04oookJP09oago0?mYo`3oJOl0oomi0?l0okSooo]Zo`3ocOoo
08Kooo]Z00;oP03o1OoonfX00olSo`3oogT0o`0/o`02oookJP?oogT000Goooh0ofko0?m^o`3olP3o
ool0>`03oookJP04o`1?oooo0;7ooo]Zoonk00;ooo]Z00?oo`0coookJ_oonfX01ooonfX2ool0P`03
oookJ_l0oiSo9_l000?ooo]Z00?oiOl0oookJ_oonfX01_oonfX00ooj0?oooo]ZoookJP02oooo00?o
oo]Z00?o>@3ooookJ_oonfX00_oonfX00ooo0<[ooo]ZoookJP03oookJP;oTP3o0_nOo`04oookJP05
o`Oo0?oonf[ooo]ZoookJ_l0ohL00_l02ol2oookJP03oooF0?oonf[ooo]Z0;kooo]Z1Ooo/@0Toook
JPGook402ooonfX9o`00O`03o`2Moooonf[ooo]Z00;ooo]Z1Ol007l3oookJP?o001o0ooonfX3o`00
O`Kooo]Z1_l0000?oookJP03ofL0oooonf[ooo]Z00?ooo]Z00?oo`1MoookJ_oonfX00_oonfX00oo3
0?oooo]ZoookJP03oookJP03ofh0oooonf[ooo]Z00;ooo]Z00?o0?l;oookJ_oonfX00_oonfX01?l0
SOoooo]ZoookJ_ooV@02oookJP03o`18oooonf[ooo]Z00?ooo]Z00[oH?l0oon@0?oo0:3ooo]Zool0
Ronl0?oooo]Zog;o0?mNo`3oo`0V0_oonfX01Ol0gooooo]Zool0^ooonf[o^@3o00;ooo]Z00Oooo80
ohKo0?oonf[o/`3ooookJ_oo0:[o0?lC00?ooo]Z00?oQ_l0oookJ_oonfX00_oonfX00ol00Ooooo]Z
oookJP02obl0o`03oookJ_l0ojKoC`3o00;ooo]Z00?oo`2<oomo0?l20?l00ooonfX01OlMo`3oJOl0
ofWo0?nJ0?oo0?nh00;ooo]Z00Go0?o=oookJ_oonf[oP03ook;o0005oookJP03oomM0?l0;?oo02co
00;ooo]Z0_l0nol01Ooonf[oooh0ofko0?ob0?ooo`0k00Cooo]Z00Ko04ooool0/Ooonf[ook/0oook
J_oo03<9oookJP;oo`2300?ooo]Zo`3oV?lVo`000ooonfX00ooPo`3ooo]ZoookJP07oookJP04ooX0
oooonf[ooo]Zoooo00Cooo]Z00Go>@3ooookJ_oonf[ooo]Zool0bP06oookJP;oTP3o00?oWol0oook
J_oonfX00_oonfX2o`Oo00?ooo]Z00?o0?n7o`0;oooonfX00_oonfX00oooeP3ooo]ZoookJP0Toook
JP00UooonfX6oona02;ooo]Z1OoUo`06oookJP?ook404?oonfX5ooo900Cooo]Z1?l007l2oookJP?o
001o0ooonfX3o`00O`Kooo]Z1?l0000>oookJP?oogT00_oonfX6oomi00KoolT000?ooo]Zoomi0?m^
0?l00oooN@000ooonf[o0?l;oookJP03oookJP03o`2=oooonf[ooiT000?ooo]Z00?o04SooookJ_oo
nfX00ooonfX02_mPo`3ooi00ool0X?oonf[oo`2;ok`0oooonf[oL_l0oeko0?oo02H2oookJP0>o`3O
oooo0;_oo`3QoookJ_ni0?oooo]Zooob0?n6o`3ooo]Zool0m?nc0?ooo`2ZoookJ_l0oa<2oookJP03
ohKo0?oonf[ooo]Z00;ooo]Z00?o007ooomi0?ooN@000oooN@02odl0o`?ooo]Z0_ooN@04oookJP0;
oago0?mYo`3oVP3ooolQ0?l0okSooo]Zo`3ocOoo08Kooo]Zoh00oonbo`001OoonfX00olSo`3oogT0
o`0/o`02oookJP;o0?_o00KoogT0ooon0?m^o`3ooo]Zoo80oooo03/3oookJP04o`1?oooo0;7ooo]Z
oonk00;ooo]Z00?oo`0coookJ_oonfX01ooonfX01Ooo08?ooo]ZoookJ_l0oiSo9_l000?ooo]Z00?o
iOl0oookJ_oonfX01OoonfX2ooX0o`;ooo]Z00Coool0oookJ_oonf[ooo]Z0_li0?l4oookJP03ool0
b_oonf[ooo]Z00?ooo]Z00?oTP3ooookJ_nOo`001OoonfX01_l7o`3ooo]ZoookJ_oonf[o0?n7o`0;
o`;ooo]Z0_ooeP2koookJPKook40;_oonfX3oona017ooo]Z00?o09gooookJ_oonfX01?oonfX4o`00
O`;ooo]Z0ol007l3oookJP?o001o1_oonfX4o`00013ooo]Z00?oI`3ooookJ_oonfX00ooonfX00ooo
05gooo]ZoookJP02oookJP03ol<0oooonf[ooo]Z00?ooo]Z00?oV@3oofh0oooonfX00_oonfX00ol0
o`_oj`3ooookJP02oookJP04o`2=oooonf[ooo]ZoonI00;ooo]Z00?o04SooookJ_oonfX01?oonfX0
2OooT03oo`2PoookJ_oo08_o_03ooookJ_mbo`3oG_l0ool09P02oookJP05o`3Ooooonf[oo`2koook
J_ni0?l00_oonfX01ooolP3oQ_l0oookJ_nc0?oooo]Zool0Z_l0oa<00ooonfX00on6o`3ooo]Zoook
JP02oookJP06o`01oooonf[ooo]Zobl0oooo`03ooo]Z0_m?0?l2oookJP;oogl000Wo0P3ooookJ_oo
nf[ooo]Zoago0?mYo`3oVP3ooolQ0?l0okP00_oonfX01Ol0olgooo]ZoookJ_n00?oo/_l000Cooo]Z
00?o8ol0oomM0?l0;?l00ooonfX01ol0nooooo]Zool0Z_oooP3oK_l0oo80oooo03/01?oonfX01_l0
Coooo`2aoonk0?oo^`3ooo]Zool0<`Wooo]Z00Goo`23oookJ_oonf[o0?nHobKo0003oookJP03on3o
0?oonf[ooo]Z00Kooo]Z0_oj0?l00ooonf[oool0oooo0003oookJP;o>@3o0ooonfX00ooo0<[ooo]Z
oookJP04oookJP03oi80oonOo`3oWol000Cooo]Z00?o1ol0oookJ_oonfX00_oonfX01?l0ohOooo]Z
oookJ_oonfX2oooF02Oooo]Z002BoookJPGook405_oonfXEoe7o00;oiOl02?oonfX01?oob@3ook40
oona0?oo/@05ooo900Wooo]Z1_oob@03oookJP?o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJPCo
00003OoonfX3oomi00;ooo]Z1_ooN@02oookJPGoolT000?oV@3oofh0oooonfX00oooN@000ol0o`_o
oo]ZoookJP02oookJP03o`2=oooonf[ooiT000?ooo]Z00?o04SooookJ_oonfX00ooonfX02_mPo`3o
oi00ool0X?oonf[oo`2;ok`0oooonf[oL_l0oeko0?oo02H2oookJP03o`3Ooooo0;_oo`3Q00;o^@3o
00Wooo]Zooob0?n6o`3ooo]Zool0m?nc0?ooo`2ZoookJ_l0oa<00_oonfX01_n6o`3ooo]ZoookJ_oo
nf[oogT0o`01o`GoogT000CoC`3oo`3oY_oonf[ooo]Z1?ooN@03oookJP05oago0?mYo`3oVP3ooolQ
0?oonfX00_l0old01?oo08Kooo]Zoh00oonbo`05oookJP03ob?o0?ooN@3o02co00;ooo]Z00Go0?_o
oookJ_oo0:[oooh0ofko0002oo80o`09ool0>ooonf[ooo]ZoookJ_l0Coooo`2aoookJ_oo^`3ooo]Z
00;oo`0c2OoonfX01Ooo08?ooo]ZoookJ_l0oiSo9_l000?ooo]Z00?oiOl0oookJ_oonfX01OoonfX0
1Ooj0?oooo]ZoookJ_oonf[oool000?ooo]Z00?o>@3ooookJ_oonfX00_oonfX2ool0bPGooo]Z00?o
TP3ooookJ_nOo`001OoonfX00ol7o`3ooo]ZoookJP02o`3oQ`04o`0;oooonf[ooo]ZoooF0;Sooo]Z
1Ooo/@0FoookJQKoDOl02ooonfX2oona013ooo]Z00?o09gooookJ_oonfX01?oonfX3o`00O`;ooo]Z
0ol007l3oookJP?o001o1_oonfX4o`0000oooo]Z00?oI`3ooookJ_oonfX00ooonfX00ooo05gooo]Z
oookJP03oookJP03ol<0oooonf[ooo]Z00;ooo]Z00?oV@3oofh0oooonfX00ooonfX01Ol0o`_ooo]Z
oookJ_oonf[o08go00;ooo]Z00CooiT0oookJ_oonf[o04So1_oonfX02OooT03oo`2PoookJ_oo08_o
_03ooookJ_mbo`3oG_l0ool09P02oookJP03o`3Ooooonf[oo`2k00;o^@3o0_oonfX01ooolP3oQ_l0
oookJ_nc0?oooo]Zool0Z_l0oa<00ooonfX00on6o`3ooo]ZoookJP02oookJP07o`01oooonf[ooo]Z
obl0oooo`03ooo]Zodl0o`03oookJP03oomo0?l20?oooo]Z00?ooo]Z00Ko7Ol0ofWo0?nJ0?ooob40
o`3o^?oonfX2o`3oc@04oookJ_n00?ooP03ook;o00Cooo]Z00?o8ol0oomM0?l0;?l00ooonfX01?l0
nooooo]Zool0Z_oooP02oo80o`03ool0>ooonf[ooo]Z00;ooo]Z0_oo0;401?oo^`3ooo]Zool0<ooo
03<9oookJP05ool0Pooonf[ooo]Zo`3oV?lVo`000ooonfX00ooPo`3ooo]ZoookJP06oookJP04ooX0
oooonf[ooo]Zoooo00Cooo]Z00Co>@3ooookJ_oonf[ooo]Z0_oo0<X6oookJP03oi80oonOo`3ooo]Z
00Cooo]Z00Co1ol0oookJ_oonf[ooo]Z0_l0ohL3oookJP03oooF0?oonf[ooo]Z02Oooo]Z002=oook
JPGook405?oonfX7oe7o01Gooo]Z0_mAo`0<ooo900;ook400ooob@09oookJPOoolT00ooonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJPCo00003?oonfX4oomi0003oookJ_ooN@3o
ogT000GoogT00_oonfX00oo30?oooo]Zooo90002ooo90006ofh0oooonf[ooo]ZoookJ_ooN@3o0?l;
1?oonfX01?l0SOoooo]ZoookJ_ooV@02oookJP03o`18oooonf[ooo]Z00?ooo]Z00[oH?l0oon@0?oo
0:3ooo]Zool0Ronl0?oooo]Zog;o0?mNo`3oo`0V0_oonfX03_l0goooo`2kool0hOni0?ooFol0oook
J_oolP3oQ_l0oookJ_oo0?Co/`3oool0Z_oonf[o0?lC0_oonfX00on6o`3ooo]ZoookJP02oomi0003
o`01ooooN@3oogT000?oogT000?oC`3oo`3oY_oonfX01OooN@02oookJP0<o`d0oolMo`3oJOl0oiX0
ool0okSooo]Zo`3ocOoonf[oo`26oookJ_n00?oo/_l01?oonfX2ob?o000:oomi0?l0;?oooo]Zoook
J_l0nooooo]Zool0Z_oooP3oK_l0oo80o`;oo`0k0ooonfX01_l0Coooo`2aoookJ_oo^`3ooo]Zool0
<`[ooo]Z00Goo`23oookJ_oUo`3oiOl0obKo0002oookJP03on3o0?oUo`3ooo]Z00Kooo]Z00?onP3o
oookJ_oonfX00_ooo`03oookJP03ocT0oooonf[ooo]Z00;ooo]Z00?oo`3:oookJ_oonfX00ooonfX2
oi80o`;oWol01?oonfX2o`Oo00;ooo]Z00?o0?n7o`0;oooonfX00_oonfX00oooeP3ooo]ZoookJP2b
oookJPGook405OoonfX6oe7o01Kooo]Z1_mAo`07oookJP;ook403ooonfX00ol0WOoooo]ZoookJP04
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z1?l0000?oookJP03ofL0oooo
nf[ooo]Z00?ooo]Z00?oo`1MoookJ_oonfX00_oonfX00oo30?oooo]ZoookJP03oookJP03ofh0oooo
nf[ooo]Z00;ooo]Z00Go0?l;oookJ_oonf[ooo]Zo`2=o`03oookJP03oonI0?oonf[o04So00Kooo]Z
00Wooi00ool0X?oonf[oo`2;ok`0oooonf[oL_l0oeko0?oo02H00_oonfX01Ol0gooooo]Zool0^oni
0?ooFol000;ooo]Z00Oooo80ohKo0?oonf[o/`3ooookJ_oo0:[o0?lC00?ooo]Z00?oQ_l0oookJ_oo
nfX00_oonfX01ol00Ooooo]ZoookJ_l_0?oool00o`3oY_m?0?l00_oonfX00ooo08coogl0o`80o`04
oookJP0<oago0?mYo`3oVP3ooookJ_l0okSooo]Zo`3ocOoo08Kooo]Zoh00oooonf[o/_l01?oonfX0
0olSo`3ooed0o`0/o`03oookJP05o`3koooonf[oo`2Zooon0?ob0?l00_oo03/4oookJP05ool0/Ooo
nf[ook/0oookJ_oo03<02_oonfX01Ooo08?ooo]Zo`3oV?l0oiSo9_l000;ooo]Z0_oPo`08oookJP04
ooX0oooonf[ooo]Zoooo00Cooo]Z00Go>@3ooookJ_oonf[ooo]Zool0bP06oookJP;oTP3o00?oWol0
oookJ_oonfX00_oonfX2o`Oo00?ooo]Z00?o0?n7oookJ_oonfX00_oonfX00oooeP3ooo]ZoookJP0X
oookJP00R_oonfX3oona01Cooo]Z1OmAo`0PoookJPcoolT000?ook40ooo90?oob@002_oonfX7ooo9
00;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX4o`0000_ooo]Z3OooN@02
oookJP03ol<0oooonf[ooo]Z00;oogT01?oonfX00ol0o`_ooo]ZoookJP02oookJP04o`2=oooonf[o
oo]ZoonI00;ooo]Z00?o04SooookJ_oonfX00ooonfX02_mPo`3ooi00oomO0?oo0:3oogT0ok`0oooo
nf[oL_l0oeko0?oo02H2oookJP0>o`3Ooooo0;_oo`3QokT0oomKo`3ooo]Zooob0?n6o`3ooo]Zool0
m?nc0?ooo`2ZoookJ_l0oa<2oookJP03ohKo0?oonf[ooo]Z00;oogT000?o007ooomi0?ooN@000ooo
N@000om?0?ooogT0oomi0005oomi00;ooo]Z0_lMo`002_mYo`3oVP3oo`3o^?oonf[o0?o=oookJ_oo
08Kooo]Zoh00oonbo`04oookJP03ob?o0?ooG@3oogT000?ooo]Z00?o0?_ooookJ_oooP000_m^o`00
0oob0?ooo`0koookJP03oookJP06o`1?oooo0;7ooo]Zoonk0?oonf[oo`0c2_oonfX00ooo08?oiOl0
onGo0002onGo00;ooo]Z00?oh?l0oookJ_oonfX01_oonfX01?oj0?oooo]ZoookJ_ooo`03oookJP;o
>@3o1?oonfX00ooo0<[ooo]ZoookJP03oookJP03oi80oooonf[oWol000Gooo]Z00Ko1ol0oookJ_oo
nf[ooo]Zo`3oQol02ol2oookJP;oomH0/_oonfX3oona01Gooo]Z1OmAo`0RoookJPCoDOl01OoonfX2
oona00gooo]Z00Co09goo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007l6oookJPCo00003_oonfX00omW0?oooo]ZoookJP03oookJP03ool0GOoonf[ooo]Z00?ooo]Z
00?o``3ooookJ_oonfX00_oonfX00om^0?oooo]ZoookJP02oookJP05o`3o2ooonf[ooo]ZoookJ_l0
SOl00ooonfX00oooV@3ooo]Zo`18o`06oookJP09oon@0?ooG`3oo`2Pool0Ronl0?oooo]Zog;o0?mN
o`3oo`0V00;ooo]Z00Go0=oooookJ_oo0;_o^@3ooe_o0002oookJP07ooob0?n6o`3ooo]Zok<0oooo
nf[oo`2Zo`3o4`03oookJP03ohKo0?oonf[ooo]Z00;ooo]Z00Oo007ooookJ_oonf[o;`3oooo00?l0
ojKoC`3o00;ooo]Z00?oo`2<oomo0?l20?l00ooonfX2oago000;ofWo0?nJ0?oooo]Zo`3o^?oonf[o
0?o=ool0Q_oonf[oP03ooookJ_nbo`001?oonfX2oomM000:o`0/oooonf[ooo]ZoookJ_l0nooooo]Z
ooon0?m^o`3olP3oool0>`Gooo]Z00Goo`2aoookJ_oo^`3ooo]Zool0<`0:oookJP04ool0Pooonf[o
0?nHobKo00?ooo]Z00?oh?l0oookJ_oonfX01_oonfX2ooX0o`03oookJ_oo0;Ooool000?ooo]Z0_li
0?l3oookJP03ool0b_oonf[ooo]Z00Cooo]Z00?oTP3ooioo0?nOo`001?oonfX00ol7o`3ooo]Zoook
JP02oookJP04o`3oQooonf[ooo]ZoookJP;oomH0:ooonfX008Oooo]Z0ooo/@0BoookJPGoDOl0:?oo
nfX:ooo900;ook402_oonfX8ooo90005oookJ_l007oo001oo`00OooonfX00ol007l3oookJP?o001o
1_oonfX4o`0000[ooo]Z3OooN@02oookJP03ol<0oooonf[ooo]Z00?oogT00ooonfX00ol0o`_oj`3o
oookJP02oookJP04o`2=oooonf[ooo]ZoonI00;ooo]Z00?o04SooookJ_oonfX00ooonfX01?mPo`3o
oi00oomO0?oo0:02oomi0004ok`0oombo`3oG_l0ool09P;ooo]Z00ko0=ooool0^ooo0>7o^@3ooe_o
0?oonf[ooo80ohKo0?oonf[oo`3dok<0oooo0:[ooo]Zo`3o4`;ooo]Z00KoQ_l0oookJ_oonf[ooo]Z
oomi0?l00Ol5oomi0003odl0ooooN@3oogT000GoogT00_oonfX03?lMo`3oHol0ofWo0?oo8@3o0?nh
oookJ_l0olgooo]Zool0Q_oonf[oP03ook;o00Cooo]Z00?o8ol0oomM0?l0;?l00_oonfX2oomi0006
oookJ_oooP3oK_l0oookJ_ob0?ooo`0k1?oonfX2ool0/@;ook/000?ooo]Zool0<ooonfX02?oonfX2
ool0P`CoiOl00_oonfX00ooPo`3ooo]ZoookJP05oookJP;onP3o0_oonfX01Oooo`3ooo]ZoookJ_oo
nf[o>@3o00Cooo]Z0_oo0<X5oookJP03oi80oooonf[oWol000Gooo]Z00?o1ol0oookJ_oonfX00_l0
ohL01?l02ooooo]ZoookJ_ooeP2aoookJP?ook404_oonfX6oe7o02_ooo]Z1?mAo`03oookJP;ook40
3?oonfX00ol0WOoo001oo`00O`03oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Ko
oo]Z1?l0000=oookJP03ofL0oooonf[ooo]Z00Cooo]Z00?oo`1MoookJ_oonfX00_oonfX00oo30?oo
oo]ZoookJP02oookJP03oiT0oom^0?oooo]Z00;ooo]Z00?o0?l;on/0oooonfX00_oonfX01?l0SOoo
oo]ZoookJ_ooV@02oookJP03o`18oooonf[ooo]Z00?ooo]Z00Wooi00oomO0?oo0:3oo`2;oookJ_nl
0?ooL_l0oeko0?oo02H00_oonfX01Ol0gooooo]Zool0^oni0?ooFol000;ooo]Z00Oooo80ohKo0?oo
nf[o/`3ooookJ_oo0:[o0?lC00?ooo]Z00?oQ_l0oookJ_oonfX00_oonfX01ol00Ooooo]Zobl0ool_
0?oool00o`3oY_m?0?l00_oonfX00ooo08coogl0o`80o`03oookJP0=oago0?l=0?ooJOl0oolQ0?oo
nf[o0?nhoookJ_l0olgoo`26oookJ_n00?oooo]Zok;o0003oookJP04ob?o0?ooG@3ooo]Zo`0/o`;o
oo]Z0_l0nol01Ooonf[oooh0ofko0?ob0?ooo`0k00Gooo]Z00Goo`2aoonk0?oo^`3ooo]Zool0<`09
oookJP;oo`2300?ooo]Zo`3oV?lVo`000ooonfX00ooPo`3ooo]ZoookJP06oookJP03ooX0oooonf[o
oo]Z00;oool00ooonfX01?li0?oooo]ZoookJ_oonfX2ool0bPKooo]Z00?oTP3ooioo0?oonfX01?oo
nfX01?l7o`3ooo]ZoookJ_oonfX2o`3oQ`?ooo]Z00?oomH0oookJ_oonfX0:ooonfX008Cooo]Z0ooo
/@0@oookJPGoDOl0;ooonfX9ooo90003oookJ_oo/@3ook4000Sooo]Z2Ooob@03o`00O`;ooo]Z0ol0
07l01?oonf[o001oo`00Ool007l7oookJPCo00002OoonfX>oomi0004oookJ_o30?oooo]ZoookJP?o
ogT00ooonfX00ol0o`_oj`3ooookJP02oookJP04o`2=oooonf[ooo]ZoonI00;ooo]Z00?o04Sooook
J_oonfX00ooonfX01?mPo`3ooo]Zoon@0?oo0:02oomi0004ok`0oombo`3oogT0oomi00;ooo]Z00oo
0=ooool0^ooo0>7o^@3ooe_o0?oonf[ooo80ohKo0?oonf[oo`3dok<0oooo0:[ooo]Zo`3o4ooonfX0
0_n6o`02oookJP;oogT000?o007ooomi0?ooN@000oooN@000om?0?ooogT0oomi0006oomi0008oook
J_lMo`3oHol0ofWo0?oo8@3o0?nhoookJ_l0old2ool0QP03oookJ_n00?oo/_l000Cooo]Z00Co8ol0
oomM0?l0;?oooo]Z0oooN@001_oo0:[oooh0ofko0?oonf[olP3oool0>`?ooo]Z00Go04ooool0/Ooo
nf[ook/0oookJP02ool0<`Wooo]Z00?oo`23onGo0?oUo`000ooUo`000ooonf[oh?l0on3o0007oook
JP03ooX0oooonf[ooo]Z00;oool00ooonfX00oli0?oooo]ZoookJP02oookJP03ool0b_oonf[ooo]Z
00?ooo]Z0_nB0?l2oioo00Cooo]Z0_l7o`02oookJP03o`3oQol02ooooo]Z00;ooo]Z00?oomH0oook
J_oonfX01_oonfX2o`3oGJGooo]Z0ooo/@0@oookJPGoDOl0=OoonfX3oe7o00;ooo]Z00?ook40oook
J_oonfX02OoonfX01?l0WOoo001oo`00Ool007l2oookJP?o001o0_oonfX3o`00O`04oookJ_l007oo
001oo`00O`Oooo]Z1?l0000=oookJP03ofL0oooonf[ooo]Z00?ooo]Z00?oo`1MoookJ_oonfX00_oo
nfX00oo30?oooo]ZoookJP02oookJP03oiT0oom^0?oooo]Z00;ooo]Z00?o0?l;on/0oooonfX00_oo
nfX01?l0SOoooo]ZoookJ_ooV@02oookJP03o`18oooonf[ooo]Z00?ooo]Z00WoH?l0oon@0?oo0:3o
o`2;oookJ_nl0?ooL_l0oeko0?oo02H00_oonfX01Ol0gooooo]Zool0^oni0?ooFol000;ooo]Z00Oo
oo80ohKo0?oonf[o/`3ooookJ_oo0:[o0?lC00;ooo]Z0_n6o`04oookJP07o`01oooonf[o;`3oo`1l
oooonf[o0?nVodl0o`02oookJP;oogl000[o0P3ooookJ_oonf[ooo]Zoago0?mSo`3oJOl0oolQ0?oo
nf[o0?nh0_l0old00ooo08Kooo]Zoh00o`02ok;o00?ooo]Z00Co8ol0oomM0?oonf[o02co0_oonfX0
1ol0nooooo]Zool0Z_oooP3oK_l0oo80oooo03/01?oonfX2ool0/@04oonk0?oonf[ooo]Zool0<`Wo
oo]Z00Goo`23oookJ_oonf[o0?nHobKo0003oookJP03on3o0?oonf[ooo]Z00Kooo]Z00ConP3ooook
J_oonf[oool01?oonfX01Oli0?oooo]ZoookJ_oonf[oo`3:00Kooo]Z0_nB0?l00onOo`3ooo]Zoook
JP02oookJP;o1ol00ooonfX01?l0ohOooo]ZoookJ_oonfX2oooF00Sooo]Z0_l0oedToookJP00POoo
nfX3oona0003oookJ_oUo`3oiOl000_ooo]Z1OmAo`0foookJPOoolT000?oDOl0oookJ_oonfX00_oo
/@07oookJPWoolT000Co001ooookJ_oonf[ooo]Z1ol007l7oookJPCo00002?oonfX7oomi0003oook
J_ooN@3oogT000CoogT00_oonfX00oo30?oooo]Zoomi0003oomi00;ooo]Z00?o0?l;on/0oooonfX0
0_oonfX01?l0SOoooo]ZoookJ_ooV@02oookJP03o`18oooonf[ooo]Z00?ooo]Z00CoH?l0oomi0?oo
T03oo`2P0_ooN@000onl0?ooL_l0oomi0002oomi000=oookJ_l0goooo`2kool0hOni0?ooFol0oook
J_oolP3oQ_l0oookJ_oo0?Co/`3oool0ZP02o`3o4`03oookJ_n6o`3ooo]Z00;ooo]Z0_ooN@000ol0
0OooogT0oomi0003oomi0003odl0ooooN@3oogT000KoogT000[o3@3ooago0?mSo`3oJOl0oookJ_l0
okSooo]Zo`3ocOoo08Kooo]Z0_n00?l00onbo`3ooo]ZoookJP02oookJP03ob?o0?ooG@3o02co00Co
ogT000?oo`2Zooon0?m^o`000_ob0?l02_oo03_ooo]ZoookJ_oonf[o04ooool0/Ooonf[ook/0oook
J_oo03<9oookJP03onGo0?oo08?oiOl000GoiOl000?oh?l0oookJ_oonfX01_oonfX01Ooj0?oooo]Z
oookJ_ooo`3oo`2g00;ooo]Z0_li0?l4oookJP03ool0b_oonf[ooo]Z00?ooo]Z00?oTP3ooookJ_nO
o`001OoonfX01_l7o`3ooo]ZoookJ_oonf[o0?n7o`0;o`;ooo]Z0_ooeP08oookJP03o`3oGOoonf[o
oo]Z0:;ooo]Z0ooo/@0?oookJPCoDOl0?OoonfX2oe7o0003oookJ_oo/@3ook4000Wooo]Z00?o09go
o`00Ool007l01Ol007l3oookJPOo001o1ooonfX4o`0000cooo]Z00?oI`3ooookJ_oonfX00ooonfX0
0ooo05gooo]ZoookJP03oookJP03ol<0oooonf[ooo]Z00;ooo]Z00KoKP3ooookJ_oonf[ooo]Zo`3o
2oo[0?l3oookJP04o`2=oooonf[ooo]ZoonI00;ooo]Z00?o04SooookJ_oonfX00ooonfX02OmPo`3o
oi00ool0X?oo08_ooo]Zok`0oombo`3oG_l0ool09P02oookJP05o`3Ooooonf[oo`2kokT0oomKo`00
0_oonfX01ooolP3oQ_l0oookJ_nc0?oooo]Zool0Z_l0oa<00_oonfX00on6o`3ooo]ZoookJP03oook
JP07o`01oooonf[o;`3oo`1loooonf[o0?nVodl0o`02oookJP03oomo0?l20?oo0P3o00?ooo]Z00Wo
7Ol0of?o0?mYo`3oob40oookJ_l0okSo0?o=ool0Q_oonfX00_n00?l00onbo`3ooo]ZoookJP02oook
JP04ob?o0?ooG@3ooo]Zo`0/o`;ooo]Z00Co0?_ooookJ_oo0:[oK_l00_ob0?l00ooo03_ooo]Zoook
JP02oookJP04ool0/Ooonf[ook/0oookJP;oo`0c2OoonfX01Ooo08?ooo]ZoookJ_l0oiSo9_l000;o
oo]Z0_oPo`08oookJP04ooX0oooonf[oo`2goooo00?ooo]Z0_li0?l3oookJP03ool0b_oonf[ooo]Z
00Cooo]Z00?oTP3ooookJ_nOo`001?oonfX00ol7o`3ooo]ZoookJP02oookJP05o`3oQooonf[ooo]Z
oookJ_ooeP002OoonfX00ol0oegooo]ZoookJP0ToookJP00O_oonfX3oona00?ooo]Z0ooUo`08oook
JP?oDOl0?_oonfX3ooo900;ooo]Z0_mAo`02oookJP03oona0?oonf[ooo]Z00Cooo]Z1ooob@02o`00
O`Gooo]Z1Ol007l8oookJPCo00001ooonfX8oomi00;ooo]Z1OooN@000ooonf[o``3ooookJP04oomi
00;ooo]Z00?o0?l;on/0oooonfX00_oonfX01?l0SOoooo]ZoookJ_ooV@02oookJP03o`18oooonf[o
oo]Z00?ooo]Z00CoH?l0oomi0?ooT03oo`2P0_ooN@000onl0?ooL_l0oomi0002oomi0006oookJ_l0
gooooo]Zool0^oni0?ooFol00_oonfX01_oolP3oQ_l0ool0m?nc0?ooo`2Zo`3o4`;ooo]Z00?oQ_l0
oookJ_oonfX00_oonfX00oooN@3o007ooomi0004oomi0003odl0ooooN@3oogT000KoogT000Co3@3o
oago0?nJ0?ooJOl00_l0okP2o`3oc@05ool0Q_oonf[oP03ooookJ_nbo`001?oonfX2oomM00GoogT0
00Goo`2Zofko0?m^o`3olP3oool0>`04oookJP06o`1?oooo0;7ook/0oonk0?oonf[oo`0c2?oonfX2
onGo0003ool0PooUo`3oiOl000CoiOl000?oh?l0oookJ_oonfX01_oonfX01?oj0?oooo]ZoookJ_oo
o`03oookJP03ocT0oooonf[ooo]Z00;ooo]Z0_oo0<X5oookJP03oi80oooonf[oWol000Gooo]Z00?o
1ol0oookJ_oonfX00_l0ohL01?l02ooooo]ZoookJ_ooeP09oookJP04o`3oGOoonf[o0?mWo`3oIioo
oo]Z0ooo/@0?oookJP?oDOl0@ooonfX2oe7o0003oookJ_oo/@3ooo]Z00Sooo]Z00?o09goo`00Ool0
07l00ol007l5oookJPGo001o2?oonfX4o`0000cooo]Z00?oI`3ooookJ_oonfX00ooonfX00ooo05go
oo]ZoookJP02oookJP03ol<0oooonf[ooo]Z00;ooo]Z00KoKP3ooookJ_oonf[ooo]Zo`3o2oo[0?l3
oookJP04o`2=oooonf[ooo]ZoonI00;ooo]Z00?o04SooookJ_oonfX00ooonfX02OmPo`3ooi00ool0
X?oo08_ooo]Zok`0oombo`3o1P3oool09P02oookJP05o`3Ooooonf[oo`2kokT0oomKo`000_oonfX0
1?oolP3oQ_l0oookJ_nc0?l2ool0ZP04o`3o4ooonf[ooo]ZohKo00Gooo]Z00Co007ooookJ_l_0?oo
07co0_l0ojH01Om?0?oooo]Zool0S?ooO`3o0P3o00Cooo]Z00Co7Ol0oiX0oomYo`3oob400_l0okP0
1_l0olgoo`26oookJ_n00?oooo]Zok;o00Cooo]Z0_ooG@02o`0/o`;ooo]Z00Ko0?_ooookJ_oo0:[o
K_l0oo80oooo03/5oookJP05ool0/Ooonf[ook/0oookJ_oo03<02_oonfX01Ooo08?ooo]Zo`3oV?l0
oiSo9_l000;ooo]Z00?oh?l0oookJ_oonfX01_oonfX2ooX0o`03oookJ_ooo`3oool000?ooo]Z00Co
>@3ooookJ_oonf[ooo]Z0_oo0<X6oookJP03oi80oonOo`3oWol000Cooo]Z00Co1ol0oookJ_oonf[o
oo]Z0_l0ohL3oookJP03oooF0?oonf[ooo]Z00Kooo]Z0_l0oed00ooonf[o0?mWo`3oI`0ToookJP00
NooonfX3oona00Cooo]Z1_oUo`04oookJP?oDOl0@ooonfX00ooob@3ooo]ZoookJP02oookJP;oDOl0
00?ooo]Zooo90?oob@001OoonfX5ooo901Gooo]Z1?l00006oookJPSoogT00ooonfX00ooo05gooo]Z
oomi0002oomi0003ol<0ooooN@3oogT000CoogT00_oonfX01Ol0o`_ooo]ZoookJ_oonf[o08go00;o
oo]Z00GooiT0oookJ_oonf[ooo]Zo`18o`04oookJP;oogT000?ooi00ool0X?ooN@000_ooN@002_mb
o`3oogT0oomi0?ooN@3ooo]Zo`3Ooooonf[oo`2kokT0oomKo`02oookJP06ooob0?n6o`3oo`3dok<0
oooonf[o0?lC0_oonfX00on6o`3ooo]ZoookJP02oookJP;o007o1?ooN@000ol0ojKoC`3ooomi0007
oomi000=o`d0oolMo`3oVP3oofWo0?l0okSooo]Zo`3ocOoonf[oo`26oookJ_n00?oooo]Zok;o0004
oookJP03oomM0?ooN@3oogT000CoogT000Goo`2Zofko0?oonf[olP3oool0>`03oookJP;o04oo00?o
o`2aoonk0?oonfX00_oo03<7oookJP;oiOl00_oo08<5onGo00;oh?l01ooonfX2ooX0o`03oookJ_oo
o`3oool000?ooo]Z00?o>@3ooookJ_oonfX00_oonfX00ooo0<[ooo]ZoookJP03oookJP;oTP3o0_nO
o`04oookJP;o1ol00_oonfX00ol0ohOo00_ooookJP02oookJP03oooF0?oonf[ooo]Z00Kooo]Z0_l0
oed01?oonf[o0?mWo`08ool02?nLoookJP?ook403ooonfX3oe7o04Sooo]Z00CoDOl0oookJ_oo/@3o
ok402?oonfX00ol0WOoooo]ZoookJP0DoookJPCo00002ooonfX00omW0?oooo]ZoookJP03oookJP03
ool0GOoonf[ooo]Z00;ooo]Z00?o``3ooookJ_oonfX00_oonfX00om^0?oooo]ZoookJP02oookJP05
o`3o2ooonf[ooo]ZoookJ_l0SOl00_oonfX01?ooV@3ooo]ZoookJ_l0B?l5oookJP09of3o0?ooT03o
o`2Pool0Rooonf[o_03oog;o0?l60?ooo`0V00;ooo]Z00Go0=oooookJ_oo0;_o^@3ooe_o0002oook
JP07ooob0?n6o`3oo`3dok<0oooo0:[ooo]Zo`3o4`02oookJP03ohKo0?oonf[ooo]Z00;ooo]Z0_l0
0Ol02_oonf[o;`3oo`1lool0ojKo<ol0odl0oooonf[oo`2<oomo0?l20?l4oookJP0<oago0?nJ0?oo
JOl0ool0col0okSooo]Zo`3ocOoo08Kooo]Zoh00oooonf[o/_l01?oonfX00oooG@3ooo]Zo`0/o`02
oookJP;o0?_o00Gooo]Zooon0?m^o`3olP3oool0>`04oookJP06o`1?oooo0;7ooo]Zoonk0?oonf[o
o`0c2OoonfX2ool0P`03oookJ_l0oiSo9_l000?ooo]Z00?oh?l0oookJ_oonfX01_oonfX01?oj0?oo
oo]ZoookJ_ooo`04oookJP05ocT0oooonf[ooo]ZoookJ_oo0<X01_oonfX2oi80o`03oioo0?oonf[o
oo]Z00;ooo]Z0_l7o`03oookJP04o`3oQooonf[ooo]ZoookJP;oomH02?oonfX01?l0oegooo]Zoook
J_l0ofL2o`08obCooo]Z001hoookJP?ook401_oonfX7onGo0004oookJ_mAo`3oDOl0oe7o04gooo]Z
00?oDOl0ooo90?oob@000ooob@02oookJPCoolT05_oonfX4o`0000Gooo]Z2OooN@03oookJP05ool0
GOoonf[ooo]Zoomi0?o30?l01oooN@000ooonf[o0?l;oookJP02oookJP04o`2=oooonf[ooo]ZoonI
00?ooo]Z00Co04SooookJ_oonf[ooo]Z0oooN@000oooT03oo`2Poomi0002oomi0003og;o0?ooN@3o
ogT000;oogT000Go0=ooool0hOoo0;_o^@3ooe_o0002oookJP06ooob0?n6o`3o/`3ook<0oooonf[o
0?lC0_oonfX00on6o`3ooo]ZoookJP02oookJP04o`01oooonf[ooo]Zo`1lo`;oogT000?o0?nVodl0
ooooN@002?ooN@001_lMo`3oVP3oofWo0?ooN@3ooo]Zo`3oc@;oo`2600Cooo]Zoh00oooonf[o/_l0
0ooonfX00oooN@3ooed0oomi0005oomi0005ool0Z_m^o`3ooo]Zoo80oooo03/00ooonfX01_l0Cooo
o`2aool0/Ooo^`3ooo]Zool0<`Sooo]Z0_oUo`000ooo08?oiOl0onGo0004onGo0003on3o0?oonf[o
oo]Z00Kooo]Z00GonP3ooookJ_oonf[oool0ool0]`03oookJP03ocT0oooonf[ooo]Z00;ooo]Z00?o
o`3:oookJ_oonfX00ooonfX00onB0?oooo]Zoioo0005oookJP06o`Oo0?oonf[ooo]ZoookJ_l0ohOo
00_o0_oonfX2oooF00Sooo]Z00Go0?mMoookJ_oonf[o0?mWo`08o`2KoookJP?ook403ooonfX3oe7o
04cooo]Z0_mAo`000ooonf[ook40oookJP06oookJP03o`2Moooonf[ooo]Z01Cooo]Z1?l0000;oook
JP03ofL0oooonf[ooo]Z00?ooo]Z00?oo`1MoookJ_oonfX00_oonfX01Oo30?oooo]ZoookJ_oonf[o
KP3o00Cooo]Z00Go0?l;oookJ_oonf[ooo]Zo`2=o`02oookJP04oonI0?oonf[ooo]Zo`18o`Kooo]Z
00Sooi00ool0X?oo08_ooo]Zok`0oombo`3o1P3oool09P;ooo]Z00Go0=ooool0hOoo0;_o^@3ooe_o
0002oookJP07ooob0?n6o`3oo`3dok<0oooo0:[ooo]Zo`3o4`02oookJP03ohKo0?oonf[ooo]Z00;o
oo]Z00co007ooookJ_oonf[o;`3oooo00?l0ojKo<ol0odl0oooonf[oo`2<oomo0?l20?l4oookJP05
oago0?nJ0?ooJOl0oookJ_l0okP00_l0old01Ooo08Kooo]Zoh00oooonf[o/_l000?ooo]Z00Co8ol0
oomM0?oonf[o02co0_oonfX00ol0nooooo]ZoookJP02ofko0003oo80oooo03_ooo]Z00?ooo]Z0_oo
0;42oonk0003oookJ_oo03?ooo]Z00Sooo]Z00Goo`23oookJ_oonf[o0?nHobKo0003oookJP03on3o
0?oonf[ooo]Z00Kooo]Z00ConP3ooookJ_oo0;Ooool01?oonfX01Oli0?oooo]ZoookJ_oonf[oo`3:
00Kooo]Z00?oTP3ooookJ_nOo`001?oonfX01?l7o`3ooo]ZoookJ_oonfX2o`3oQ`?ooo]Z00?oomH0
oookJ_oonfX01_oonfX2o`3oG@;ooo]Z00?o0?mWo`08oooonfX09OoonfX007Gooo]Z0ooo/@07oook
JPWoiOl000?oDOl0oookJ_oonfX0CooonfX00omAo`3oolT0ooo90007ooo90003oookJ_l0WOoooo]Z
01Cooo]Z1?l00007oookJPOoogT00_oonfX01Ooo05gooo]ZoookJ_oonf[o``3o00OoogT000?ooo]Z
o`3o2ooonfX00_oonfX01Ol0SOoooo]ZoookJ_oonf[ooiT000;ooo]Z00Co04SooookJ_oonf[ooo]Z
0oooN@000oooT03oo`2Poomi0002oomi0003og;o0?ooN@3oogT000;oogT000Go0=ooool0hOoo0;_o
^@3ooe_o0002oookJP06ooob0?n6o`3o/`3oool0Z_oonf[o0?lC0_oonfX00on6o`3ooo]ZoookJP02
oookJP08o`01oooonf[ooo]Zobl0ooooN@3ooo]Zo`3oY_m?0?l3oomi0003oookJ_ooN@3oogT000?o
ogT000So7Ol0oiX0oomYo`3oogT0oookJ_l0olgoo`26oookJP;oP03o00Cooo]Zok;o0?oonf[ooo]Z
0_ooN@000oooG@3oogT0oomi0003oomi0003ool0Z_oooP3oK_l000;olP3o00[oo`0koookJ_oonf[o
oo]Zo`1?oooo0;7ooo]Zoonk0?oonf[oo`0c2OoonfX00ooUo`3oo`23onGo0005onGo0003on3o0?oU
o`3ooo]Z00Kooo]Z00ConP3ooookJ_oonf[oool00ooonfX2ocT0o`?ooo]Z0_oo0<X5oookJP03oi80
oonOo`3oWol000Gooo]Z00?o1ol0oookJ_oonfX00_l0ohL01?l02ooooo]ZoookJ_ooeP09oookJP06
o`3oGOoonf[o0?mWo`3oIol02?oooo]Z0_l0om>FoookJP?ook403ooonfX3oe7o057ooo]Z00?oDOl0
oookJ_oo/@001ooonfX00ol0WOoooo]ZoookJP0CoookJPCo00002_oonfX00omW0?oooo]ZoookJP03
oookJP03ool0GOoonf[ooo]Z00;ooo]Z00Go``3ooookJ_oonf[ooo]Zofh0o`04oookJP05o`3o2ooo
nf[ooo]ZoookJ_l0SOl00ooonfX00oooV@3ooo]Zo`18o`06oookJP08of3o0?oo0:3oo`2;oookJ_nl
0?ooL_l0o`H0oooo02H2oookJP05o`3Ooooo0>7oo`2kokT0oomKo`000_oonfX01ooolP3oQ_l0ool0
m?nc0?ooo`2ZoookJ_l0oa<00_oonfX00on6o`3ooo]ZoookJP02oookJP0<o`01oooonf[o;`3oobl0
oooo`03o0?nVoc?o0?m?0?oooo]Zool0S?ooO`3o0P3o0ooonfX2oago000;oiX0oomYo`3ooo]Zo`3o
^?l0olgooo]Zool0Q_oonf[oP03ooookJ_nbo`000ooonfX01?lSo`3ooed0oookJ_l0;?l2oookJP04
o`3koooonf[oo`2Zofko00;olP3o00?oo`0koookJ_oonfX00_oonfX00ooo0;7ooo]Zoonk0002oook
JP03ool0<ooonf[ooo]Z00Oooo]Z00Goo`23oookJ_oonf[o0?nHobKo0002oookJP;oh?l01ooonfX2
ooX0o`03oookJ_oo0;Ooool000?ooo]Z0_li0?l3oookJP03ool0b_oonf[ooo]Z00Cooo]Z00?oTP3o
oioo0?nOo`001?oonfX01_l7o`3ooo]ZoookJ_oonf[o0?n7o`0;o`?ooo]Z00?oomH0oookJ_oonfX0
1_oonfX00ol0oegooo]ZoookJP02o`3oI`04o`08oooonf[o0?oCo`3odbCooo]Z001boookJP?ook40
2OoonfX;onGo05;ooo]Z00?oDOl0ooo90?oob@001Ooob@02oookJP03o`2Moooonf[ooo]Z01?ooo]Z
1?l00009oookJP04ofL0ooooN@3oogT0oomi00;ooo]Z00Goo`1MoookJ_oonf[ooo]Zol<0o`08oomi
0003o`3o2oo[0?oooo]Z00;ooo]Z00Co08gooookJ_oonf[ooiT00_oonfX01?l0B?oooo]ZoookJ_oo
nfX3oomi0003oon@0?oo0:3oogT000;oogT000?oL_l0oomi0?ooN@000oooN@001?oo0>7oo`2kokT0
oomKo`02oookJP06ooob0?n6o`3o/`3oool0Z_oonf[o0?lC0_oonfX00on6o`3ooo]ZoookJP02oook
JP08o`01oooonf[ooo]Zobl0oooo`03ooo]Zo`3oY_m?0?l3oomi0003oookJ_l20?oooo]Z00?oogT0
0_nJ0?l01omYo`3oogT0oookJ_l0olgoo`26oookJ_n00?l00_oonfX00onbo`3ooo]Zoomi0002oomi
0003oomM0?ooN@3oogT000?oogT000Goo`2Zooon0?m^o`3olP3oool0>`03oookJP;o04oo00Goo`2a
oonk0?oo^`3ooo]Zool0<`09oookJP;oo`231_oUo`000ooPo`3oiOl0oookJP06oookJP04ooX0oooo
nf[oool0oooo00?ooo]Z00?o>@3ooookJ_oonfX00_oonfX00ooo0<[ooo]ZoookJP03oookJP;oTP3o
00?oWol0oookJ_oonfX00ooonfX2o`Oo00;ooo]Z00?o0?n7o`0;oooonfX00_oonfX00oooeP3ooo]Z
oookJP06oookJP;o0?mM00?ooo]Zo`3oIol02?l00_oonfX00ol0om?o04Woo`19o`2CoookJP?ook40
3ooonfX3oe7o05Gooo]Z00?oDOl0oookJ_oo/@001ooonfX00ol0WOoooo]ZoookJP0BoookJPCo0000
2_oonfX00omW0?oooo]ZoookJP02oookJP03ool0GOoonf[ooo]Z00;ooo]Z00Ko``3ooookJ_oonf[o
oo]ZoiT0oom^0?l3oookJP03o`3o2oo[0?oooo]Z00;ooo]Z00Ko08gooookJ_oonf[ooiT0oookJ_l0
B?l6oookJP08of3o0?oo0:3oo`2;oookJ_nl0?ooL_l0o`H0oooo02H2oookJP05o`3Ooooo0>7oo`2k
oookJ_ni0?l00_oonfX01ooolP3oQ_l0ool0m?nc0?ooo`2ZoookJ_l0oa<00_oonfX00on6o`3ooo]Z
oookJP02oookJP09o`01oooonf[o;`3oo`1loooo`03o0?nVoc?o0?m?0?oooo]Z00;oogl000Go0P3o
oookJ_oonf[ooo]Zoago0002oiX0o`04ofWo0?l0okSo0?nho`3oc@;oo`2600Cooo]Zoh00oooonf[o
/_l00ooonfX01?lSo`3ooed0o`0/ool0;?l2oookJP06o`3koooonf[oo`2Zofko0?ob0?ooo`0k1?oo
nfX01Ol0Coooo`2aoookJ_oo^`3ooo]Z00;oo`0c2?oonfX2ool0P`;ooo]Z00Go0?nHobKo0?oonf[o
oo]Zon3o0008oookJP03ooX0oooonf[ooo]Z00;oool00ooonfX01?li0?oooo]ZoookJ_oonfX2ool0
bPGooo]Z0_nB0?l00onOo`3ooo]ZoookJP02oookJP;o1ol00ooonfX01?l0ohOooo]ZoookJ_oonfX2
oooF00Sooo]Z00Go0?mMoookJ_oonf[o0?mWo`08o`02oookJP03o`3odol0BOoo04Wo02Cooo]Z001_
oookJP?ook402ooonfX<onGo05Cooo]Z2Ooob@000ol0WOoooo]ZoookJP0BoookJPCo00002?oonfX0
1OmW0?oooo]ZoookJ_oonf[oogT000;ooo]Z00Coo`1MoookJ_oonf[ooo]Z2?ooN@000ooonf[o0?l;
oookJP02oookJP04o`2=oooonf[ooo]ZoonI00;ooo]Z00?o04SooookJ_oonfX00ooonfX01?ooN@3o
oi00oomi0?oo0:02oomi0003og;o0?ooN@3oogT000?oogT000Coo`3Qool0^oni0?ooFol00_oonfX0
1_oolP3oQ_l0ok<0oooo0:[ooo]Zo`3o4`;ooo]Z00?oQ_l0oookJ_oonfX00_oonfX01_l00Ooooo]Z
oookJ_l_0?oool00oookJP;oC`3o0_oonfX01?ooO`3o0P3oo`80oooonfX3oomi0003oiX0ooooN@3o
ogT000;oogT000Go0?o=ool0Q_oonf[oP03ooookJP02ok;o00?oogT00_ooG@05oomi0005ool0Z_m^
o`3oK_l0oo80oooo03/00ooonfX01Ol0Coooo`2aool0/Ooo^`3ooo]Z00;oo`0c2OoonfX00ooo08?o
oo]ZoookJP04onGo00;oh?l000?oiOl0oookJ_oonfX01OoonfX01?oj0?oooo]Zoooo0?oo0;L3oook
JP04ocT0oooonf[ooo]ZoookJP;oo`3:1OoonfX00onB0?oooo]Zoioo0005oookJP06o`Oo0?oonf[o
oo]ZoookJ_l0ohOo00_o0ooonfX00oooeP3ooo]ZoookJP06oookJP05o`3oGOoonf[ooo]Zo`3oIol0
2?l00_oonfX00ol0om?o04WooookJP2BoookJP;ook403ooonfX3oe7o05Wooo]Z00?oDOl0oookJ_oo
/@001_oonfX00ol0WOoooo]ZoookJP0BoookJPCo00002OoonfX00omW0?oooo]ZoookJP03oookJP03
ool0GOoonf[ooo]Z00;ooo]Z00Go``3ooookJ_oonf[ooo]Zofh0o`04oookJP05o`3o2ooonf[ooo]Z
oookJ_l0SOl00_oonfX00oooV@3ooo]Zo`18o`06oookJP08of3o0?ooT03oo`2Pool0Ronl0?ooL_l0
o`H0oooo02H2oookJP05o`3Ooooo0>7oo`2koookJ_ni0?l00_oonfX01ooolP3oQ_l0ool0m?nc0?oo
o`2ZoookJ_l0oa<00_oonfX00on6o`3ooo]ZoookJP02oookJP06o`01oooonf[o;`3oo`1loooo`03o
0?nV0_m?0?l01?oonf[oogl0o`80ool20?l3oookJP09oago0?nJ0?ooJOl0ofWo0?l0okSooo]Zo`3o
cOoo08Kooo]Z00;oP03o0_nbo`03oookJP;ooed000[o02cooookJ_oonf[ooo]Zo`3koooonf[oooh0
ofko0?ob0?ooo`0k1?oonfX01_l0Coooo`2aoookJ_oo^`3ooo]Zool0<`Wooo]Z00Goo`23oookJ_oo
nf[ooo]Zo`3oV003oookJP03on3o0?oonf[ooo]Z00Kooo]Z00ConP3ooookJ_oo0;Ooool01?oonfX0
1Oli0?oooo]ZoookJ_oonf[oo`3:00Kooo]Z00?oTP3ooookJ_nOo`001?oonfX01?l7o`3ooo]Zoook
J_oonfX2o`3oQ`?ooo]Z00?oomH0oookJ_oonfX01_oonfX2o`3oG@;ooo]Z00?o0?mWo`08oooonfX0
0_l0om<00ol0BOoooo]ZoookJP0ToookJP00KOoonfX2oona00cooo]Z3_oUo`1DoookJP_oolT04ooo
nfX4o`0000Sooo]Z00?oI`3ooookJ_oonfX00ooonfX01?oo05gooo]ZoookJ_oonfX9oomi0005o`3o
2ooonf[ooo]ZoookJ_l0SOl00_oonfX01?ooV@3ooo]ZoookJ_l0B?l5oookJP04of3o0?ooT03oogT0
ool0X0;oogT000?oL_l0oomi0?ooN@000oooN@000ooo0>7oo`2kokT0o`03oookJP06ooob0?n6o`3o
/`3oool0Z_oonf[o0?lC0_oonfX00on6o`3ooo]ZoookJP02oookJP07o`01oooonf[ooo]Zobl0oooo
`03o0?nVodl0o`02oookJP04ool0S?ooO`3o0P3ooookJP?oogT000?o7Ol0oomi0?ooN@000_ooN@02
o`3oc@05ool0Q_oonf[oP03ooookJ_nbo`001?ooN@001?ooG@3oogT0oomi0?oonfX3oomi0005ool0
Z_m^o`3oogT0oo80oooo03/00ooonfX01_l0Coooo`2aoookJ_oo^`3ooo]Zool0<`[ooo]Z00Soo`23
oookJ_oonf[oiOl0obKo0?oonf[oiOl0on3o00?oiOl01OoonfX2ooX0o`03oookJ_ooo`3ooo]Z00;o
oo]Z0_li0?l3oookJP03ool0b_oonf[ooo]Z00Cooo]Z00?oTP3ooioo0?nOo`001OoonfX00ol7o`3o
oo]ZoookJP02o`3oQ`?ooo]Z0_ooeP08oookJP06o`3oGOoonf[o0?mWo`3oIol02?oooo]Z0_l0om<0
0ol0BOoooo]ZoookJP2?oookJP?ook403_oonfX3oe7o05gooo]Z0_mAo`000ooo/@3ooo]ZoookJP04
oookJP03o`2Moooonf[ooo]Z017ooo]Z1?l00008oookJP03ofL0oooonf[ooo]Z00?ooo]Z00?oo`1M
oookJ_oonfX00_oonfX01Oo30?oooo]ZoookJ_oonf[oKP3o00Cooo]Z00Go0?l;oookJ_oonf[ooo]Z
o`2=o`02oookJP03oonI0?oonf[o04So00Kooo]Z00SoH?l0oon@0?oo0:3oo`2;ok`0oombo`3o1P3o
ool09P;ooo]Z00Go0=ooool0hOoo0;_ooo]ZokT0o`02oookJP07ooob0?n6o`3oo`3dok<0oooo0:[o
oo]Zo`3o4`02oookJP03ohKo0?oonf[ooo]Z00;ooo]Z00Co007ooookJ_l_0?oo07co0_l0ojH01Om?
0?oooo]Zool0S?ooO`3o0P3o00Cooo]Z00Go7Ol0oiX0oomYo`3oob40o`3o^002o`3oc@05ool0Q_oo
nf[oP03ooookJ_nbo`001?oonfX00oooG@3ooo]Zo`0/o`02oookJP;o0?_o00Gooo]Zofko0?m^o`3o
lP3oool0>`04oookJP;oo`2a0_oo^`000ooonf[oo`0coookJP08oookJP03ool0Pooonf[ooo]Z00;o
0?nH0ooonfX00ooPo`3ooo]ZoookJP06oookJP04ooX0oooonf[oo`2goooo00?ooo]Z0_li0?l3oook
JP03ool0b_oonf[ooo]Z00Cooo]Z00?oTP3ooioo0?nOo`001?oonfX01Ol7o`3ooo]ZoookJ_oonf[o
0?n700Cooo]Z00?oomH0oookJ_oonfX01_oonfX00ol0oegooo]ZoookJP02o`3oI`05o`08oooonf[o
0?oCoookJ_l0BOl09ooonfX006[ooo]Z0ooo/@0=oookJQ3oiOl0E?oonfX;ooo901;ooo]Z1?l00008
oookJP03ofL0oooonf[ooo]Z00;ooo]Z00Goo`1MoookJ_oonf[ooo]Zol<0o`02oookJPKoogT000Go
0?l;oookJ_oonf[ooo]Zo`2=o`02oookJP04oonI0?oonf[ooo]Zo`18o`Gooo]Z00OoH?l0oomO0?oo
T03oo`2Pok`0ooooN@3oL_l000KoogT000?oo`2kokT0oooonfX00_oonfX01_oolP3oQ_l0ok<0oooo
0:[ooo]Zo`3o4`;ooo]Z00?oQ_l0oookJ_oonfX00_oonfX01ol00Ooooo]ZoookJ_l_0?oool00o`3o
Y_m?0?l00_oonfX00ooo08coogl0o`80o`09oomi0003o`3ocOoo08Kooo]Z00;oP03o00?ooo]Zoomi
0?ooN@000oooN@001_ooG@3oogT0oomi0?oonf[oogT0oookJP;oo`2Z00CoK_l0oomi0?ob0?ooo`0k
0ooonfX01_l0Coooo`2aoonk0?oo^`3ooo]Zool0<`[ooo]Z00Goo`23oookJ_oUo`3oiOl0obKo0002
oookJP04on3o0?oUo`3oiOl0onGo00Gooo]Z00ConP3ooookJ_ooo`3oool00ooonfX00oli0?oooo]Z
oookJP02oookJP03ool0b_oonf[ooo]Z00?ooo]Z0_nB0?l00onOo`3ooo]ZoookJP03oookJP;o1ol0
0_oonfX00ol0ohOo00_ooookJP02oookJP03oooF0?oonf[ooo]Z00Kooo]Z0_l0oed00ooonf[o0?mW
o`08o`02oookJP03o`3odol0BOoo04Wo093ooo]Z0_oo/@0>oookJP?oDOl0H_oonfX00omAo`3ook40
oookJP04oookJP03o`2Moooonf[ooo]Z017ooo]Z1?l00008oookJP03ofL0oooonf[ooo]Z00;ooo]Z
00?oo`1MoookJ_oonfX00_oonfX01_o30?oooo]ZoookJ_oonf[oV@3oofh0o`?ooo]Z00Go0?l;oook
J_oonf[ooo]Zo`2=o`02oookJP03oonI0?oonf[o04So00Kooo]Z00SoH?l0oon@0?oo0:3oo`2;ok`0
oooonf[oL_l0ool09P;ooo]Z00Go0=ooool0hOoo0;_ooo]ZokT0o`02oookJP07ooob0?n6o`3oo`3d
ok<0oooo0:[ooo]Zo`3o4`02oookJP03ohKo0?oonf[ooo]Z00;ooo]Z00_o007ooookJ_l_0?oooo]Z
o`3oY_lco`3oC`3ooookJ_oo08coogl0o`80o`04oookJP0<oago0?nJ0?ooJOl0ool0col0okSo0?o=
oookJ_oo08Kooo]Zoh00oooonf[o/_l01?oonfX00oooG@3ooo]Zo`0/o`02oookJP07o`3koooonf[o
o`2Zofko0?oonf[olP3oool0>`04oookJP03ool0/Ooonf[ook/000;ooo]Z00?oo`0coookJ_oonfX0
1ooonfX01Ooo08?ooo]ZoookJ_l0oiSo9_l000;ooo]Z0_oPo`07oookJP;onP3o00?ooo]Zoooo0?oo
o`000ooonfX01?li0?oooo]ZoookJ_oonfX2ool0bPGooo]Z0_nB0?l00onOo`3ooo]ZoookJP02oook
JP;o1ol00_oonfX2o`3oQ`?ooo]Z0_ooeP07oookJP;o0?mM0_oonfX01Ol0ofOo00SooookJ_oonf[o
0?oC00;o04Wo:?oonfX006Sooo]Z0_oo/@0>oookJP03oe7o0?oUo`3oiOl000KoiOl0G_oonfX:ooo9
01;ooo]Z1?l00007oookJP03ofL0oooonf[ooo]Z00?ooo]Z00Goo`1MoookJ_oonf[ooo]Zol<0o`03
oookJPGoogT000Oo0?l;oookJ_oonf[ooo]Zo`2=oooonf[ooiT000?ooo]Z00?o04SooookJ_oonfX0
0_oonfX01omPo`3ooel0oon@0?oo0:3o_03ooookJ_mbo`001_ooN@000ooo0;_o^@3ooookJP02oook
JP07ooob0?n6o`3o/`3oool0Z_oonf[o0?lCoookJP02ohKo00Cooo]Z00Oo007ooookJ_oonf[o;`3o
onGo0?l0ojKoC`3o00;ooo]Z00?oo`2<oomo0?l20?l02OooN@001Ol0olgoo`26oookJ_n00?oooo]Z
00KoogT000Wooed0oomi0?ooN@3ooo]Zoomi0?oonf[oo`2ZoookJ_m^o`000_ob0?l01?oo03_ooo]Z
oookJ_l0Col2ool0/@04oonk0?oonf[ooo]Zool0<`Wooo]Z0_oo08<00ooonf[oiOl0obKo0002oook
JP;oh?l00_oonfX00ooUo`3ooo]ZoookJP03oookJP04ooX0oooonf[oool0ool0]`?ooo]Z00Co>@3o
oookJ_oonf[ooo]Z0_oo0<X5oookJP03oi80oooonf[oWol000Gooo]Z00Ko1ol0oookJ_oonf[ooo]Z
o`3oQol02ol3oookJP03oooF0?oonf[ooo]Z00Kooo]Z00Go0?mMoookJ_oonf[o0?mWo`08o`02oook
JP03o`3odol0BOoooo]Z08oooo]Z0_oo/@0>oookJP;oDOl0I_oonfX00omAo`3ook40oookJP04oook
JP03o`2Moooonf[ooo]Z013ooo]Z1?l00007oookJP03ofL0oooonf[ooo]Z00?ooo]Z00?oo`1Moook
J_oonfX00_oonfX01Oo30?oooo]ZoookJ_nI0?ooKP3o00Cooo]Z00Co0?l;oookJ_oonf[o08go0_oo
nfX01?ooV@3ooo]ZoookJ_l0B?l5oookJP08oomO0?ooT03oo`2Pool0Ronl0?oooo]Zog;o0?oo02H3
oookJP04o`3Ooooo0;_ooo]ZokT0o`;ooo]Z00Sooo80ohKo0?oo0?Co/`3oool0Z_oonf[o0?lCoook
JP;oQ_l01?oonfX01Ol00Ooooo]Zobl0oooo`03o0?nV00;oC`3o00Cooo]Zool0S?ooO`3o0P3o0ooo
nfX2oago00;oJOl000Woo`3?oookJ_l0olgooo]Zool0Q_oonf[oP03ooookJ_nbo`000ooonfX01?lS
o`3ooed0o`0/ool0;?l2oookJP04o`3koooonf[oo`2Zofko00;olP3o00Soo`0koookJ_oonf[ooo]Z
o`1?oooo0;7ooo]Zoonk00;ooo]Z00?oo`0coookJ_oonfX01_oonfX2ool0P`;ooo]Z00Go0?nHoook
J_oonf[ooo]Zon3o0008oookJP04ooX0oooonf[ooo]Zoooo00Cooo]Z00Go>@3ooookJ_oonf[ooo]Z
ool0bP06oookJP03oi80oooonf[oWol000Cooo]Z00Ko1ol0oookJ_oonf[ooo]Zo`3oQol02ol3oook
JP03oooF0?oonf[ooo]Z00Kooo]Z00Oo0?mMoookJ_oonf[ooo]Zo`3oIol02?oooo]Z00;o0?oC00?o
04WooookJ_oonfX0:?oonfX006Kooo]Z0_oo/@0>oookJP;oDOl0F_oonfX3ooo900_ooo]Z2?oob@00
0ol0WOoooo]ZoookJP0@oookJPCo00001ooonfX00omW0?oooo]ZoookJP02oookJP05ool0GOoonf[o
oo]ZoookJ_o30?l00ooonfX00om^0?oooo]ZoookJP03oomi00?ooo]Z00?o08gooookJ_ooV@000ooo
nfX00ol0B?oooo]ZoookJP02oookJP09of3o0?ooG`3ooi00ool0X?nl0?oooo]Zog;o0?l0<Oooo`0V
00GoogT000?o^@3ooookJ_oonfX00_ooN@000on6o`3o/`3oool0ZP02o`3o4`03oookJ_n6o`3ooo]Z
00Cooo]Z00Go007ooookJ_oUo`3o;`3oonGo0002odl0o`;ooo]Z00Coo`2<oomo0?l20?oooo]Z2?oo
N@001Ol0olgoo`26oookJ_n00?oooo]Z00GoogT00_ooG@04oomi0006oookJ_oo0:[oK_l0ofko0?ob
0?ooogT00ooonfX01Ol0Coooo`2aoookJ_oo^`3ooo]Z00;oo`0c2OoonfX01Ooo08?ooo]ZoookJ_oU
o`3o9_l000;ooo]Z00?oh?l0oookJ_oonfX01ooonfX01?oj0?oooo]Zoooo0?oo0;L3oookJP05ocT0
oooonf[ooo]ZoookJ_oo0<X01_oonfX00onB0?ooWol0oioo0005oookJP03o`Oo0?oonf[ooo]Z00;o
0?n70ooonfX2oooF00Sooo]Z00Co0?mMoookJ_oonf[o0?mW0_oonfX2o`3od`03o`19oooonf[ooo]Z
08cooo]Z0ooo/@0>oookJP;oDOl0JOoonfX00omAo`3ook40oookJP03oookJP03o`2Moooonf[ooo]Z
013ooo]Z1?l00007oookJP03ofL0oooonf[ooo]Z00;ooo]Z00?oo`1MoookJ_oonfX00_oonfX01Oo3
0?oooo]ZoookJ_nI0?ooKP3o00Cooo]Z00Co0?l;oookJ_oonf[o08go0_oonfX01?ooV@3ooo]Zoook
J_l0B?l5oookJP08oomO0?ooT03oo`2Pool0Ronl0?oooo]Zog;o0?oo02H3oookJP05o`3Ooooo0;_o
oo]ZokT0oooonfX00_oolP001?n6o`3oo`3dok<0oooo0:X2o`3o4`03oookJ_n6o`3ooo]Z00Cooo]Z
00Ko007ooookJ_l_0?oool00o`3oY_m?0?l2oookJP03ool0S?ooO`3o0P3o00?ooo]Z00_o7Ol0of?o
0?mYo`3oob40ool0cooonf[o0?o=oookJ_oo08Kooo]Zoh00o`02ok;o00?ooo]Z0_ooG@001_l0;?oo
oo]ZoookJ_oonf[o0?_ooookJP;oK_l000?olP3oool0>ooonfX00ooonfX01Ol0Coooo`2aoookJ_oo
^`3ooo]Z00;oo`0c2?oonfX01Ooo08?ooo]ZoookJ_oonf[o0?nH00?ooo]Z00?oh?l0oookJ_oonfX0
1_oonfX01?oj0?oooo]Zool0]oooo`04oookJP05ocT0oooonf[ooo]ZoookJ_oo0<X01_oonfX00onB
0?ooWol0oioo0004oookJP05o`Oo0?oonf[ooo]ZoookJ_l0ohL00ooonfX2oooF00Sooo]Z00Go0?mM
oookJ_oonf[ooo]Zo`3oI`02oookJP03o`3odol0BOoo04Wo02_ooo]Z001JoookJP;oU?l01ooonfX3
oona00gooo]Z0omAo`1IoookJPKoolT02ooonfX7ooo90003oookJ_l0WOoooo]Z017ooo]Z1Ol00005
oookJP03ofL0oooonf[ooo]Z00;ooo]Z00Goo`1MoookJ_oonf[ooo]Zol<0o`03oookJP03oiT0oom^
0?oooo]Z00;ooo]Z00GoogT0oookJ_oonf[ooo]Zo`2=o`02oookJP04oonI0?oonf[ooo]Zo`18o`Go
oo]Z00Sooel0oon@0?oo0:3o_03ooookJ_mbo`3o037oool09P;ooo]Z0oooN@000oni0?oooo]Zoomi
0003oomi0003ok<0oooonf[o0?lC00;ooo]Z00?oQ_l0oookJ_oonfX00ooonfX01ol00OooiOl0onGo
0?l_0?oo0?nVodl0oolco`000_oonfX01?oo08coogl0o`80oooonfX:oomi0004oookJ_n00?oooo]Z
ok;o00CoogT000?ooed0oomi0?ooN@000oooN@001_oonf[oo`2Zofko0?oooP3olP3oool0>`?ooo]Z
00Ko04ooool0/Ooonf[ook/0oookJ_oo03<:oookJP05ool0Pooonf[ooo]ZonGo0?lVo`000_oonfX0
0ooPo`3ooo]ZoookJP06oookJP;onP3o0_ooo`03oookJP;o>@3o0ooonfX00ooo0<[ooo]ZoookJP03
oookJP;oTP3o00?oWol0oookJ_oonfX00ooonfX2o`Oo00;ooo]Z00?o0?n7o`0;oooonfX00_oonfX0
0oooeP3ooo]ZoookJP06oookJP;o0?mM00?ooo]Zo`3oIol0ofL00_oonfX00ol0om?o04Woo`19o`2=
oookJP;ook403_oonfX3oe7o06cooo]Z00?oDOl0oona0?oonfX00ooonfX00ol0WOoooo]ZoookJP0?
oookJPGo00001OoonfX00omW0?oooo]ZoookJP02oookJP03ool0GOoonf[ooo]Z00;ooo]Z00Ko``3o
oookJ_oonf[oV@3ooookJ_m^0?l3oookJP04o`3o2ooonf[ooo]Zo`2=o`?ooo]Z00?ooiT0oookJ_l0
B?l01OoonfX02?ooG`3ooi00ool0X?oo08_o_03ooookJ_mbo`3oo`0V0ooonfX03?l0goooo`2koook
J_ni0?oooo]Zooob0?oonf[oQ_l0ool0m?nc0?ooo`2Zo`3o4`;ooo]Z00?oQ_l0oookJ_oonfX00ooo
nfX01_l00Ooooo]Zobl0oooo`03o0?nVodl0o`;ooo]Z00?oo`2<oomo0?l20?l00ooonfX01olMo`3o
Hol0ofWo0?oo8@3oo`3?oookJ_l0old00_oo08H00ooonf[oP03ook;o0004oookJP03oomM0?oonf[o
02co00;ooo]Z0_l0nol01Ooonf[oK_l0ooon0?ob0?ooo`0k00Cooo]Z00Ko04ooool0/Ooonf[ook/0
oookJ_oo03<9oookJP05ool0Pooonf[ooo]ZoookJ_l0oiP00ooonfX00ooPo`3ooo]ZoookJP05oook
JP;onP3o00?ooo]Zoooo0?ooo`000ooonfX2ocT0o`?ooo]Z00?oo`3:oookJ_oonfX00ooonfX2oi80
o`03oioo0?oonf[ooo]Z00;ooo]Z0_l7o`02oookJP;o0?n70ooonfX00oooeP3ooo]ZoookJP06oook
JP;o0?mM0_oonfX2o`3oI`04oookJ_l0om?o0?oCo`19obgooo]Z001IoookJP?oU?l01OoonfX2oiCo
00kooo]Z0_mAo`1HoookJP[oolT03?oonfX5ooo900;oogT000?ooo]Zoomi0?oonfX04?oonfX4o`00
00Gooo]Z00?oI`3ooookJ_oonfX00ooonfX01Ooo05gooo]ZoookJ_oonf[o``3o00?ooo]Z00?oKP3o
oookJ_oonfX00_oonfX01ol0o`_ooo]ZoookJ_oonf[o08gooookJ_ooV@000_oonfX00ol0B?oooo]Z
oookJP03oookJP08oomO0?ooT03oo`2Pok`0oooonf[oL_l0o`0aoooo02H2oookJP04o`3Ooooo0>7o
ogT0okT0o`GoogT000?o/`3ooookJ_l0oa<00_oonfX00on6o`3ooo]ZoookJP03oookJP07o`01oooU
o`3o07coobl0ool0ojKoC`3ooc?o0002oookJP03ool0S?ooO`3ooo]Z00coogT000?oP03ooookJ_nb
o`000_oonfX2oomi0003oomM0?ooN@3oogT000;oogT000Oooo]Zool0Z_oo0:[oK_l0oookJ_ob0?oo
o`0k00;ooo]Z0_l0Col01Ooo0;7oogT0oomi0?oonf[oo`0c00[ooo]Z00Coo`23oookJ_l0oiSoiOl0
0_oonfX2on3o00Sooo]Z00ConP3ooookJ_ooo`3oo`2g0ooonfX01?li0?oooo]ZoookJ_oonfX2ool0
bPGooo]Z00?oTP3ooioo0?nOo`001OoonfX01Ol7o`3ooo]ZoookJ_oonf[o0?n700Cooo]Z00?oomH0
oookJ_oonfX01_oonfX01_l0oegooo]ZoookJ_l0ofOo00SooookJP;o0?oC00?o04WooookJ_oonfX0
RooonfX2oona00kooo]Z0_mAo`1`oookJP03oe7o0?oo/@3ooo]Z00?ooo]Z00?o09gooookJ_oonfX0
3_oonfX4o`0000Kooo]Z00?oI`3ooookJ_oonfX00_oonfX00ooo05gooo]ZoookJP02oookJP05ol<0
oooonf[ooo]ZoiT0oom^0?l00ooonfX01Ol0o`_oj`3ooookJ_oonf[o08go00;ooo]Z00?ooiT0oook
J_l0B?l01OoonfX02?ooG`3ooi00ool0X?oo08_o_03ooookJ_mbo`3oo`0V0ooonfX03?l0goooo`2k
oookJ_ni0?oooo]Zooob0?oonf[oQ_l0ool0m?nc0?ooo`2Zo`3o4`;ooo]Z00?oQ_l0oookJ_oonfX0
0_oonfX2o`01o`03o`1lool_0?oool0000;oC`3o0_oonfX00ooo08coogl0oookJP03oookJP05oago
0?oonf[oJOl0oolQ0?oo0<l00_l0old01Ooo08Kooo]Zoh00oon00?oo/_l000Cooo]Z00?ooed0oook
J_l0;?l00_oonfX01ol0nooooo]Zool0Z_m^o`3ooo]Zoo80oooo03/00ooonfX00ol0Coooo`2aool0
/@02oonk0003oookJ_oo03?ooo]Z00Sooo]Z00?oo`23oookJ_oonfX00_l0oiP2oookJP;oh?l01ooo
nfX01?oj0?oooo]ZoookJ_ooo`04oookJP04ocT0oooonf[ooo]ZoookJP;oo`3:1OoonfX00onB0?oo
Wol0oioo0004oookJP05o`Oo0?oonf[ooo]ZoookJ_l0ohL01?oonfX00oooeP3ooo]ZoookJP06oook
JP0:o`3oGOoonf[ooo]ZoookJ_l0ofOo00SooookJ_l0om?ooo]Zo`19obkooo]Z001HoookJPGoU?l0
0_oonfX2oiCo00kooo]Z0_mAo`1GoookJPgoolT03OoonfX3ooo90003oomi0?oo/@3oogT000;oogT0
4OoonfX4o`0000Cooo]Z00?oI`3ooookJ_oonfX00ooonfX01Ooo05gooo]ZoookJ_oonf[o``3o00?o
oo]Z00?oV@3oofh0oooonfX00_oonfX01ol0o`_ooo]ZoookJ_oonf[o08gooookJ_ooV@000_oonfX0
0ol0B?oooo]ZoookJP03oookJP08oomO0?ooT03oo`2Pok`0oooonf[oL_l0o`0aoooo02H2oookJP04
o`3Ooooo0>7oo`2kokT0o`GoogT000?o/`3ooookJ_l0oa<00_oonfX00on6o`3ooo]ZoookJP03oook
JP07o`01oooUo`3o07coobl0ool0ojKoC`3oonGo0002oookJP03ool0S?ooO`3ooo]Z00coogT000?o
oo]Zok;o0?nbo`000ooonfX00oooN@3ooed0oomi0003oomi0004oookJ_oo0:[ooo]Zofko00;olP3o
00CoogT0oookJ_oonf[o04oo1OooN@000ooo03?ooo]ZoookJP07oookJP;oo`2300?ooo]Zo`3oV?lV
o`000_oonfX00ooPo`3ooo]ZoookJP07oookJP04ooX0oooonf[oool0ool0]`?ooo]Z00Go>@3ooook
J_oonf[ooo]Zool0bP05oookJP;oTP3o00?oWol0oookJ_oonfX01?oonfX00ol7o`3ooo]ZoookJP02
o`3oQ`?ooo]Z0_ooeP08oookJP04o`3oGOoonf[ooo]Zo`3oI`;ooo]Z00?o0?oCoookJ_l0BOl0S?oo
nfX2oona00kooo]Z0_mAo`1coookJP03oe7o0?oo/@3ooo]Z00;ooo]Z00?o09gooookJ_oonfX03_oo
nfX4o`0000Gooo]Z00?oI`3ooookJ_oonfX00_oonfX00ooo05gooo]ZoookJP02oookJP05ol<0oooo
nf[ooo]ZoiT0oom^0?l00ooonfX01Ol0o`_oj`3ooookJ_oonf[o08go00;ooo]Z00?ooiT0oookJ_l0
B?l01OoonfX02?ooG`3ooi00ool0X?oo08_o_03ooookJ_mbo`3oo`0V0ooonfX03Ol0goooo`2kokT0
ooni0?oooo]Zooob0?oonf[oQ_l0ool0m?nc0?ooo`2Zo`3o4ooonfX00_n6o`04oookJP06o`01oooo
nf[o07coobl0oooo`03oC`3o0ooonfX00ooo08coogl0oookJP03oookJP0:oago0?mYo`3oJOl0o`3o
^?oo0<oo0?o=oookJ_oo08Kooo]Zoh00o`;o/_l01?oonfX00oooG@3o02coo`0/o`02oookJP04o`3k
oooonf[oo`2Zofko00;olP3o00Woo`0koookJ_oonf[ooo]Zo`1?oooo0;7ooo]Zoonk0?oonfX00_oo
03<8oookJP;oo`230_oonfX01Ol0oiSooo]ZoookJ_oonf[oh?l000Sooo]Z00ConP3ooookJ_oo0;Oo
ool01?oonfX01Oli0?oooo]ZoookJ_oonf[oo`3:00Gooo]Z0_nB0?l00onOo`3ooo]ZoookJP03oook
JP03o`Oo0?oonf[ooo]Z00;o0?n70ooonfX2oooF00Sooo]Z00Ko0?mMoookJ_oonf[ooo]Zo`3oIooo
nfX2o`3od`;o04Wo;ooonfX005Oooo]Z2?nDo`0=oookJP?oDOl0E?oonfX3oolV00ooolT03_oonfX0
1Ooob@3oogT0oomi0?ooN@3ook4000CoogT03ooonfX4o`0000Cooo]Z00?oI`3ooookJ_oonfX00ooo
nfX01?oo05gooo]ZoookJ_o30?l3oookJP03oiT0oom^0?oooo]Z00;ooo]Z00Oo0?l;oookJ_oonf[o
oo]Zo`2=oooonf[ooiT000;ooo]Z00?o04SooookJ_oonfX00ooonfX02?ooG`3ooi00ool0X?oonf[o
_03oog;o0?l0<Oooo`0V0_oonfX01?l0goooo`3Qool0^oni0?l5oomi0003ok<0oooonf[o0?lC00;o
oo]Z00?oQ_l0oookJ_oonfX00_oonfX00ooUo`3o007oonGo0002obl0o`03o`3oY_m?0?ooiOl000;o
oo]Z00?oo`2<oomo0?oonfX03?ooN@000ooonf[o/_l0oookJP03oookJP03oomi0?ooG@3oogT000?o
ogT000Gooo]Zool0Z_m^o`3oK_l0oo80o`03oomi0003oookJ_ooN@3oogT000CoogT02_oonfX01?oo
08?ooo]ZoookJ_l0oiP3oookJP03on3o0?oonf[ooo]Z00Kooo]Z0_oj0?l2oooo00?ooo]Z0_li0?l3
oookJP03ool0b_oonf[ooo]Z00?ooo]Z00?oTP3ooookJ_nOo`001OoonfX2o`Oo00;ooo]Z00?o0?n7
o`0;oooonfX00_oonfX00oooeP3ooo]ZoookJP06oookJP;o0?mM00?ooo]Zo`3oIol0ofL00_oonfX0
0ol0om?o04Woo`19o`2:oookJP?ook403OoonfX3oe7o05?ooo]Z4?oo9P0BoookJP03oe7o0?oonf[o
ok4000?ooo]Z00?o09gooookJ_oonfX03OoonfX4o`0000Gooo]Z00?oI`3ooookJ_oonfX00_oonfX0
1Ooo05gooo]ZoookJ_oonf[o``3o00;ooo]Z00?oV@3ooookJ_m^0?l00_oonfX01Ol0o`_oj`3ooook
J_oonf[o08go00;ooo]Z00?ooiT0oookJ_l0B?l01OoonfX02?ooG`3ooi00ool0X?oo08_ooo]Zok`0
oombo`3oo`0V0ooonfX03_l0goooo`2kokT0oomKo`3ooo]Zooob0?oonf[oQ_l0ool0m?nc0?ooo`2Z
o`3o4ooonf[oQ_l01OoonfX01_l00Ooooo]Zobl0ool_0?oooo]Zodl0o`?ooo]Z00?oo`2<oomo0?oo
nfX00_oonfX2oago000:ofWo0?nJ0?ooo`3?ool0col0olgooo]Zool0Q_oonf[oP03ook;o00Gooo]Z
00?ooed0o`0/oooonfX00_oonfX01_l0nooooo]Zool0Z_m^o`3olP3oool0>`Cooo]Z00Ko04ooool0
/Ooonf[ook/0oookJ_oo03<9oookJP05ool0Pooonf[ooo]ZoookJ_l0oiP00ooonfX00ooPo`3ooo]Z
oookJP05oookJP;onP3o00?ooo]Zoooo0?ooo`000ooonfX2ocT0o`?ooo]Z00?oo`3:oookJ_oonfX0
0ooonfX00onB0?oooo]Zoioo0004oookJP;o1ol00_oonfX00ol0ohOo00_ooookJP02oookJP03oooF
0?oonf[ooo]Z00Kooo]Z0_l0oed2oookJP;o0?mW00Cooo]Zo`3odooonf[o04Wo<OoonfX005Kooo]Z
2?nDo`0<oookJP;oDOl0DOoonfX6oolV00Kooo]Z3Ooob@000ooo9P3ooo]ZoookJP0;oookJP?oogT0
00?ook40oomi0?ooN@001?ooN@0=oookJPCo00001?oonfX00omW0?oooo]ZoookJP02oookJP05ool0
GOoonf[ooo]ZoookJ_o30?l00_oonfX00onI0?oooo]Zofh0o`02oookJP07on/0ool0o`_ooo]Zoook
J_l0SOoooo]ZoonI0002oookJP03o`18oooonf[ooo]Z00?ooo]Z00Cooel0oon@0?oo0:3ooo]Z0_oU
o`002?l0<Oooo`0VoookJ_oonf[o0=ooool0hOoo0;_o^@3o1OooN@000onc0?oooo]Zo`3o4`02oook
JP04ohKo0?oonf[ooo]ZoookJP;oiOl000Co007oonGo0?l_0?ooiOl00_ooN@02onGo0003oookJ_oo
08coogl000;ooo]Z2oooN@000ooonf[o/_l0oookJP02oookJP03ob?o0?ooG@3ooed000;oogT000Oo
0?_ooomi0?oonf[oo`2Zofko0?oooP3olP3o00[oogT02OoonfX2ool0P`03oookJ_l0oiSo0?nH00;o
oo]Z0_oPo`08oookJP04ooX0oooonf[oool0ool0]`?ooo]Z00Co>@3ooookJ_oonf[ooo]Z0_oo0<X5
oookJP03oi80oonOo`3oWol000Gooo]Z00Go1ol0oookJ_oonf[ooo]Zo`3oQ`03oookJP;oomH02?oo
nfX01?l0oegooo]ZoookJ_l0ofL2oookJP;o0?oC00?o04WooookJ_oonfX0R?oonfX2oona00kooo]Z
0_mAo`1@oookJPKoobH04?oonfX4oolV00oooo]Z00?oDOl0oona0?oonfX00_oonfX00ol0WOoooo]Z
oookJP0=oookJPCo00001?oonfX00omW0?oooo]ZoookJP02oookJP03ool0GOoonf[ooo]Z00;ooo]Z
00Go``3ooookJ_oonf[oV@3oofh0o`03oookJP09o`3o2ooonf[ooo]ZoookJ_l0SOoooo]ZoonI0?oo
nf[o04So00Gooo]Z00Sooel0oon@0?oo0:3oo`2;oookJ_nl0?ooL_l0ool09P?ooo]Z00ko0=ooool0
^oni0?ooFol0oookJ_oolP3ooo]ZohKo0?oo0?Co/`3oool0Z_l0oa?ooo]ZohKo00Gooo]Z00Ko007o
oookJ_l_0?oool00oookJ_m?0?l3oookJP03ool0S?ooO`3ooo]Z00;ooo]Z00co7Ol0o`d0oomYo`3o
VP3oool0cooonf[o0?o=oookJ_oo08Kooo]Zoh00oonbo`04oookJP;ooed000?o02cooookJ_oonfX0
0_l0nol01Ooonf[oooh0ofko0?ob0?ooo`0k00Cooo]Z00Ko04ooool0/Ooo^`3ook/0oookJ_oo03<9
oookJP03ool0Pooonf[ooo]Z00;o0?nH0_oonfX2on3o00Oooo]Z00ConP3ooookJ_oonf[oool01?oo
nfX01?li0?oooo]ZoookJ_oonfX2ool0bPGooo]Z00?oTP3ooioo0?nOo`001?oonfX01Ol7o`3ooo]Z
oookJ_oonf[o0?n700Cooo]Z00?oomH0oookJ_oonfX01_oonfX01Ol0oegooo]ZoookJ_oonf[o0?mW
00;ooo]Z00?o0?oCo`19ool0BOl0<_oonfX005Cooo]Z2_nDo`0:oookJP;oDOl0COoonfX6oolV013o
oo]Z2Ooob@000ooonf[oobH0oolV0004oolV00Sooo]Z0oooN@000ooo/@3oogT0oomi0004oomi00co
oo]Z1?l00003oookJP03ofL0oooonf[ooo]Z00;ooo]Z00Goo`1MoookJ_oonf[ooo]Zol<0o`02oook
JP04oiT0oooonf[oKP3ooookJP;oobP000Ko0?l;oookJ_oonf[o08gooookJ_ooV@03oookJP03o`18
oooonf[ooo]Z00;ooo]Z00CoH?l0oon@0?oo0:3ooo]Z0ooUo`001ooo:03oo`0VoookJ_l0goooo`3Q
ool0^oni0?l01OooN@000onc0?ooogT0o`3o4`02oookJP04ohKo0?oonf[ooo]ZoookJP;oiOl000?o
007oo`1lool_0?l01?ooN@001OoUo`3ooo]Zoomo0?ooO`3ooo]Z00?oogT000?oJOl0oomi0?nJ0?l0
1oooN@001_nbo`3ooo]ZoookJ_ooN@3o8ol0oomM00?oogT000Oo0?_ooookJ_oo0:[oo`2Zofko0?oo
<03olP3o00[oogT02OoonfX01Ooo08?ooo]ZoookJ_l0oiSo9_l000;ooo]Z00?oh?l0oookJ_oonfX0
1ooonfX01?oj0?oooo]Zoooo0?oo0;L3oookJP05ocT0oooonf[ooo]ZoookJ_oo0<X01OoonfX2oi80
o`03oioo0?oonf[ooo]Z00Cooo]Z00?o1ol0oookJ_oonfX00_l0ohL3oookJP03oooF0?oonf[ooo]Z
00Oooo]Z00Co0?mMoookJ_l0ofOo0?mW0_oonfX00ol0om?ooo]Zo`19o`29oookJP;ook403_oonfX2
oe7o04cooo]Z1_oo9P0JoookJPKoobH02_oonfX01OmAo`3ook40oookJ_oonf[o09go00oooo]Z1?l0
0004oookJP03ofL0oooonf[ooo]Z00;ooo]Z00Goo`1MoookJ_oonf[ooo]Zol<0o`02oookJP03oiT0
oom^0?oooo]Z00;ooo]Z00Oo0?l;oookJ_oonf[ooo]Zo`2=oooonf[ooiT000;ooo]Z00?o04Sooook
J_oonfX00_oonfX02OmPo`3ooi00ool0X?oo08_ooo]Zok`0oombo`3oG_l0ool09P02oookJP0>o`3O
oooo0;_o^@3ooe_o0?oonf[ooo80oookJ_n6o`3oo`3dok<0oooo0:[o0?lCoookJ_n6o`05oookJP06
o`01oooonf[o;`3oooo00?l0ojKoC`3o0ooonfX2oomo00?ooo]Z00Oo7Ol0ofWo0?mYo`3oVP3oool0
cooonf[o0?o=00;oo`2600?ooo]Zoh00oonbo`001?oonfX00oooG@3ooo]Zo`0/o`02oookJP03o`3k
oooonf[oo`2Z00;oK_l000?olP3oool0>ooonfX00_oonfX01Ol0Coooo`2aool0/Ooo^`3ooo]Z00;o
o`0c2?oonfX2ool0P`;ooo]Z00Go0?nHoookJ_oonf[ooo]Zon3o0008oookJP04ooX0oooonf[oo`2g
oooo00Cooo]Z00Go>@3ooookJ_oonf[ooo]Zool0bP05oookJP;oTP3o00?oWol0oookJ_oonfX00ooo
nfX00ol7o`3ooo]ZoookJP02o`3oQ`?ooo]Z0_ooeP08oookJP03o`3oGOoonf[ooo]Z00;o0?mW00Co
oo]Zo`3odol0om?o04Wo=?oonfX005?ooo]Z2onDo`08oookJP;oDOl0BooonfX4oolV01Wooo]Z1_oo
b@07oookJP03oolV0?oonf[ooo]Z00Gooo]Z0oooN@000ooo/@3oogT0oomi0004oomi00cooo]Z1?l0
0003oookJP05ofL0oooonf[ooo]ZoookJ_oo05d01?oonfX01_o30?oooo]ZoookJ_nI0?ooKP3ooook
JP;oobP000Co0?l;oookJ_oo:03oobP00_oonfX01?ooV@3ooo]ZoookJ_l0B?l3oookJP;oobP000?o
oi00ool0X?oUo`000ooUo`001ooo:03oo`0VoookJ_ooN@3o0=ooool0^oni0?l01OooN@000onc0?oo
ogT0o`3o4`02oookJP03ohKo0?oonf[ooo]Z00;ooo]Z00CoiOl0o`01ool0O?ooolT01?ooN@001?oU
o`3oo`2<oomo0?oonfX4oomi0003ofWo0?ooN@3oogT000OoogT000Ko/_l0oookJ_ooN@3oogT0ob?o
0?ooG@03oomi0005o`3koooonf[oo`2Zoomi0?m^o`000_ob0?l;oomi00Sooo]Z00Coo`23oookJ_oo
nf[o0?nH0ooonfX00ooPo`3ooo]ZoookJP06oookJP;onP3o0_ooo`03oookJP;o>@3o0ooonfX00ooo
0<[ooo]ZoookJP03oookJP03oi80oooonf[oWol000Gooo]Z0_l7o`02oookJP03o`3oQooonf[ooo]Z
00;ooo]Z00?oomH0oookJ_oonfX01_oonfX2o`3oG@03oookJ_l0ofOo00So00;ooo]Z00?o0?oCo`19
ool0BOl03_oonfX2oomc07Sooo]Z0_oo/@0=oookJP?oDOl0B_oonfX4oolV02Kooo]Z00?oobH0oook
J_oonfX02?oonfX01OmAo`3ook40oookJ_oonf[o09go00kooo]Z1?l00003oookJP03ofL0oooonf[o
oo]Z00;ooo]Z00?oo`1MoookJ_oonfX00_oonfX01Oo30?oooo]ZoookJ_nI0?ooKP3o00;ooo]Z00Go
0?l;on/0oooonf[ooo]Zo`2=o`02oookJP03oonI0?oonf[o04So00Cooo]Z00WoH?l0oon@0?oo0:3o
o`2;oookJ_nl0?ooL_l0o`0aoooo02H00_oonfX03_l0goooo`2kokT0oomKo`3ooo]Zooob0?oonf[o
Q_l0ool0m?nc0?ooo`2Zo`3o4ooonf[oQ_l01OoonfX01_l00Ooooo]Zobl0oooo`03o0?nVodl0o`;o
oo]Z00?oo`2<oomo0?oonfX00ooonfX02OlMo`3oJOl0oiX0oooo8@3oo`3?oookJ_l0olgoo`26oook
JP02oh00o`03ok;o0?oonf[ooo]Z00;ooo]Z00?ooed0o`0/ool0;?l00_oonfX01?l0nooooo]Zool0
Z_m^o`02oo80o`0:ool0>ooonf[ooo]ZoookJ_l0Coooo`2aoookJ_oo^`3ooo]Zool0<`Wooo]Z00Go
o`23oookJ_oonf[ooo]Zo`3oV002oookJP;oh?l01ooonfX2ooX0o`03oookJ_ooo`3oool000?ooo]Z
0_li0?l2oookJP;oo`3:1OoonfX00onB0?oooo]Zoioo0004oookJP;o1ol00_oonfX00ol0ohOooo]Z
oookJP02oookJP03oooF0?oonf[ooo]Z00Kooo]Z0_l0oed2oookJP06o`3oIooonf[ooo]Zo`3odooo
nf[o04Wo3ooonfX2oomc02Cooo]Z001BoookJPgoU?l01?oonfX3oe7o04[ooo]Z0ooo9P0QoookJP;o
olT02?oonfX2oolV00?oogT00ooonfX9oomi00cooo]Z1?l00003oookJP05ofL0oooonf[ooo]Zoook
J_oo05d00ooonfX01_o30?oooo]ZoookJ_nI0?ooKP3ooookJP;oobP000?o0?l;oookJ_oo:0000_oo
:0001Ooonf[ooiT0oookJ_oonf[o04So00?ooo]Z0_oo:0000oooT03oo`2PonGo0004onGo0006ool0
9_oonf[oobP0o`3OooooN@3o^@3o1OooN@000onc0?ooogT0o`3o4`02oookJP03ohKo0?oonf[ooo]Z
00?ooo]Z00?o007oobl0ooooN@001?ooN@000ooUo`3oo`2<oomo0005oomi0003ofWo0?ooN@3oogT0
00OoogT000Kooo]Zoomi0?ooN@3oogT0ob?o0?ooG@02oomi00;o0?_o00Gooo]Zool0Z_m^o`3oK_l0
oo80o`0<oomi00Oooo]Z0_oo08<00ooonf[o0?nHo`3oV002oookJP;oh?l02?oonfX01?oj0?oooo]Z
oooo0?oo0;L3oookJP04ocT0oooonf[ooo]ZoookJP;oo`3:1?oonfX2oi80o`;oWol01OoonfX01Ol7
o`3ooo]ZoookJ_l02ooo0?n700?ooo]Z0_ooeP08oookJP04o`3oGOoonf[o0?mWo`3oI`;ooo]Z0_l0
om<00ol0BOoooo]ZoookJP0=oookJP03oomc0?oonf[ooo]Z07Kooo]Z0_oo/@0=oookJP;oDOl0B_oo
nfX3oolV02_ooo]Z0ooo9P07oookJP05oe7o0?oonf[ook40oookJ_l0WOl03_oonfX4o`0000?ooo]Z
00?oI`3ooookJ_oonfX00_oonfX01Ooo05gooo]ZoookJ_oonf[o``3o00;ooo]Z00KoV@3oofh0oooo
nf[ooo]Zo`3o2oo[0?l3oookJP05o`2=oooonf[ooiT0oookJ_l0B?l01?oonfX02OmPo`3ooi00ool0
X?oo08_ooo]Zok`0oombo`3o1P3oool09P02oookJP06o`3Ooooo0;_o^@3ooe_o0?oonf[ooo800_n6
o`001_oo0?Co/`3oo`3o4ol0oa?ooo]ZohKo00Gooo]Z00Ko007oobl0ool_0?oool00o`3oY_m?0?l2
oookJP03ool0S?ooO`3ooo]Z00?ooo]Z00Go7Ol0ofWo0?nJ0?ooo`3?o`3o^002o`3oc@04ool0Q_oo
nf[oP03ook;o00Cooo]Z00?o8ol0oomM0?l0;?l00_oonfX2o`3ko`06oookJ_oooP3oK_l0oo80oooo
nf[oo`0k0ooonfX01_l0Coooo`2aoonk0?oo^`3ooo]Zool0<`Wooo]Z00?oo`23oookJ_oonfX00_l0
oiP2oookJP03on3o0?oonf[ooo]Z00Kooo]Z00ConP3ooookJ_oonf[oool01?oonfX01Oli0?oooo]Z
oookJ_oonf[oo`3:00Gooo]Z0_nB0?l2oioo00Cooo]Z00Go1ol0oookJ_oonf[o00_oo`3oQ`03oook
JP;oomH02?oonfX00ol0oegooo]ZoookJP02o`3oI`03oookJ_l0om?o0?oC00;o04Wo3ooonfX00ooo
L`3ooo]ZoookJP0ToookJP00DOoonfX;oiCo00Gooo]Z0_mAo`1:oookJP?oobH0:ooonfX5oomi00?o
obH01?oonfX8oomi00cooo]Z1?l00002oookJP05ofL0oooonf[ooo]ZoookJ_oo05d00ooonfX01_o3
0?oooo]ZoookJ_nI0?ooKP3ooookJPOoobP000Gooo]ZoonI0?oonf[ooo]Zo`18o`02oookJP?oobP0
00?ooi00ool0X?oUo`001?oUo`001_oo02KoobP0oolX0?l0goooobP0okT0o`GoogT000?o/`3ooomi
0?l0oa<00_oonfX00on6o`3ooo]ZoookJP03oookJP03o`01ooooN@3oogT000GoogT000?oo`2<oomo
0?ooN@001?ooN@000omYo`3oogT0oomi000;oomi0005ob?o0?ooG@3oogT0oomi0?l0nol00_ooN@00
1?oo0:[oK_l0ool`0?ob0?l<oomi00Oooo]Z00Goo`23oookJ_oonf[o0?nHoomi0002oookJP03on3o
0?oonf[ooo]Z00Kooo]Z0_oj0?l00ooonf[oool0ool0]`03oookJP05ocT0oooonf[ooo]ZoookJ_oo
0<X01OoonfX00onB0?oooo]Zoioo0005oookJP;o1ol00_oonfX2o`3oQ`?ooo]Z00?oomH0oookJ_oo
nfX01ooonfX01?l0oegooo]Zo`3oIol02?l2oookJP03o`3odooonf[o04Wo00kooo]Z0_ooL`1foook
JP?ook403OoonfX2oe7o04Wooo]Z0ooo9P0aoookJP;oobH01_oonfX01OmAo`3ook40oookJ_oonf[o
09go00gooo]Z1?l00002oookJP03ofL0oooonf[ooo]Z00;ooo]Z00Goo`1MoookJ_oonf[ooo]Zol<0
o`02oookJP06oiT0oom^0?oooo]ZoookJ_l0o`_oj`3o0ooonfX01Ol0SOoooo]ZoonI0?oonf[o04So
00Cooo]Z00WoH?l0oon@0?oo0:3oo`2;oookJ_nl0?ooL_l0o`H0oooo02H00_oonfX02ol0goooo`2k
okT0oomKo`3ooo]Zooob0?n6o`3ooo]Zool0m?nc0?oo0?lC00;ooo]Z00?oQ_l0oookJ_oonfX00ooo
nfX01_l00Ooo;`3oo`1loooonf[o0?nVodl0o`;ooo]Z00?oo`2<oomo0?oonfX00_oonfX03?l=0?oo
7Ol0ofWo0?nJ0?ooo`3?o`3o^?l0olgooo]Zool0Q_oonf[oP03ook;o00Cooo]Z00?o8ol0oomM0?l0
;?l00_oonfX01_l0nooooo]ZoookJ_oooP3oK_l0oo80o`;oo`0k0ooonfX01?l0Coooo`2aoonk0?oo
nfX2ool0<`Sooo]Z0_oo08<2oookJP05o`3oV?lVo`3ooo]ZoookJ_oPo`001ooonfX2ooX0o`03oook
J_oo0;Ooool000Cooo]Z00Go>@3ooookJ_oonf[ooo]Zool0bP05oookJP03oi80oooonf[oWol000Go
oo]Z00?o1ol0oookJ_oonfX00_l0ohL3oookJP03oooF0?oonf[ooo]Z00Oooo]Z00Wo0?mMoookJ_oo
nf[o0?mWo`08oooonf[o0?oCoookJ_l0BOl03ooonfX2oomc02Oooo]Z001@oookJPOoU?l02?oonfX2
oe7o04Wooo]Z0ooo9P0YoookJPooogT00_oonfX9oomi00_ooo]Z1?l00002oookJP05ofL0oooonf[o
oo]ZoookJ_oo05d00_oonfX01_o30?oooo]ZoookJ_oonf[oKP3ooookJPSoobP000Gooo]ZoonI0?oo
nf[o04SooookJP04oolX00;oiOl000?oo`2PonGo0?oUo`000ooUo`02oolX0003o`3Ooooo:03o^@3o
00;ooo]Z0_ooN@02oolX0005oomi0?l0oa?ooo]ZoookJ_n6o`001OoonfX8oomi00;oogl01?ooN@02
ofWo00coogT00_lSo`001?ooG@3oogT0oomi0?l0nol2oomi0004ool0Z_m^o`3oogT0oo80o`coogT0
1_oonfX2ool0P`;oogT000Go0?nHoomi0?ooN@3ooo]Zon3o0008oookJP04ooX0oooonf[oool0oooo
00?ooo]Z0_li0?l3oookJP03ool0b_oonf[ooo]Z00?ooo]Z00?oTP3ooioo0?nOo`001OoonfX01Ol7
o`3ooo]ZoookJ_l02ooo0?n700?ooo]Z0_ooeP08oookJP;o0?mM0_l0ofL01?l02?oooo]Zo`3odol0
om<2o`19o`kooo]Z00?oog<0oookJ_oonfX0M?oonfX2oona00gooo]Z0omAo`18oookJP?oobH0=_oo
nfX2oolV00Kooo]Z00?ook40oookJ_l0WOl03OoonfX4o`0000;ooo]Z00?oI`3ooookJ_oonfX00_oo
nfX01?oo05gooo]ZoookJ_o30?l3oookJP05ofh0oooonf[ooo]ZoookJ_l0o`/00ooonfX01Ol0SOoo
oo]ZoonI0?oonf[o04So00Cooo]Z00WoH?l0oon@0?ooG`3oo`2Pool0Ronl0?ooL_l0o`H0oooo02H0
0_oonfX02?l0goooo`2kokT0oomKo`3ooo]Zooob0?n6o`3ooo]Z0_nc0?l01?l0oa?ooo]ZoookJ_n6
o`05oookJP06o`01ool_0?oo07cooookJ_l0ojKoC`3o0_oonfX2oomo00?ooo]Z00co3@3ooago0?mY
o`3oVP3oool0col0okSo0?o=oookJ_oo08Kooo]Zoh00oonbo`04oookJP03ob?o0?ooG@3o02co00;o
oo]Z00Oo0?_ooookJ_oo0:[oooh0ofko0?ob0?ooo`0k00?ooo]Z00Ko04ooool0/Ooo0;7ook/0oook
J_oo03<9oookJP05ool0Pooonf[ooo]ZoookJ_l0oiP00_oonfX2on3o00Oooo]Z00?onP3ooookJ_oo
nfX00_ooo`03oookJP;o>@3o0_oonfX2ool0bPGooo]Z00?oTP3ooioo0?nOo`001?oonfX2o`Oo0003
oookJ_l02ooo0?n700Cooo]Z00?oomH0oookJ_oonfX01_oonfX2o`3oG@03oookJ_l0ofOo0?mW00;o
oo]Z00?o0?oCo`19ool0BOl03ooonfX00oooL`3ooo]ZoookJP0WoookJP00C_oonfX01?oo/@3oU?l0
oiCo0?nDo`0;oookJP;oDOl0B?oonfX3oolV02;ooo]Z1ooo]@0Noomi00[ooo]Z1?l000000ooonf[o
I`3ooookJP02oookJP05ool0GOoonf[ooo]ZoookJ_o30?l00_oonfX00onI0?ooKP3ooolX0007oolX
0005oookJ_ooV@3ooo]Zo`18oooonfX00ooo:003onGo0003ool0X?oUo`3oiOl000?oiOl00_oo:000
0ol0goooobP0okT0o`02oookJP03ooob0?oo:03oobP000;oobP000Co0?lCoomi0?oonf[oQ_l01?oo
nfX00ol00OooogT0oomi0006oomi0003oomo0?ooN@3oogT000?oogT000?oJOl0oomi0?ooN@002ooo
N@000olSo`3ooed0oomM0002oomi0005o`3kooooN@3oo`2Zool0Z_m^o`003oooN@05oookJP05ool0
PoooN@3oogT0oomi0?l0oiP00_ooN@000ooonf[oh?l0oookJP07oookJP04ooX0oooonf[oool0ool0
]`?ooo]Z00Co>@3ooookJ_oonf[ooo]Z0_oo0<X4oookJP;oTP3o00?oWol0oookJ_oonfX01?oonfX0
0ol7o`3ooo]ZoookJP02o`3oQ`?ooo]Z00?oomH0oookJ_oonfX01ooonfX01?l0oegooo]Zo`3oIol0
2?l2oookJP03o`3odooonf[o04Wo00kooo]Z0_ooL`1eoookJP;ook403OoonfX2oe7o04Sooo]Z0ooo
9P0SoookJPgookD02ooonfX00ooo9P3ooo]ZoookJP03oookJP04oona0?oonf[ooo]Zo`2Mo`cooo]Z
1?l000000ooonf[oI`3ooookJP03oookJP05ool0GOoonf[ooo]ZoookJ_o30?l00_oonfX01OnI0?oo
KP3ooookJ_oonf[o0?l;00?ooo]Z00Go08gooookJ_ooV@3ooo]Zo`18o`04oookJP09of3o0?ooT03o
oel0ool0X?oo08_o_03oog;o0?l60?ooo`0V00;ooo]Z00_o0=ooool0^oni0?ooFol0oookJ_oolP3o
Q_l0oookJ_nc0?ooo`2Zo`3o4`02oookJP03ohKo0?oonf[ooo]Z00;ooo]Z0_l00Ol01Ol_0?oool00
oookJ_l0ojKoC`3o00;ooo]Z00?oogl0o`80oooonfX00_oonfX01ol=0?oo7Ol0ofWo0?oo8@3ooo]Z
o`3o^?l0old00_oo08H00ooonf[oP03ook;o0004oookJP;ooed00ooonfX01?l0nooooo]Zool0Z_oo
oP02oo80o`06ool0>ooonf[ooo]ZoookJ_l0Coooo`2a0_oo^`000ooonf[oo`0coookJP08oookJP05
ool0Pooonf[ooo]ZoookJ_l0oiP00_oonfX00ooPo`3ooo]ZoookJP06oookJP04ooX0oooonf[oo`2g
oooo00Cooo]Z00Go>@3ooookJ_oonf[ooo]Zool0bP05oookJP;oTP3o00?oWol0oookJ_oonfX00ooo
nfX01Ol7o`3ooo]ZoookJ_l02ooo0?n700?ooo]Z0_ooeP08oookJP06o`3oGOoonf[ooo]Zo`3oIol0
2?oooo]Z0_l0om<00ol0BOoooo]ZoookJP0=oookJP;oog<0:_oonfX004cooo]Z0_oo/@0<oookJP?o
DOl0AooonfX3oolV023ooo]Z1Ooo]@0:oookJPgoogT000?ooo]Zoomi0?ooN@003?ooN@09oookJPCo
000000?ooo]ZofL0oooonfX00_oonfX01?oo05gooo]ZoookJ_o30?l3oookJP03ofh0oooo:03oobP0
00OoobP000?ooiT0oookJ_l0B?l01?oo:003onGo0003ool0X?oUo`3oiOl000?oiOl00_oo:0000ol0
goooobP0okT0o`02oookJPGoobP000Co0?lCoomi0?oonf[oQ_l01?oonfX9oomi0003oomo0?ooN@3o
ogT000?oogT000?oJOl0oomi0?ooN@001OooN@001?n00?ooogT0oomi0?ooN@02oookJP04ob?o0?oo
G@3oogT0oomi00;o0?_o00?oogT0ool0Z_ooN@004?ooN@05oookJP03ool0PoooN@3oogT000;o0?nH
0_ooN@02on3o00Oooo]Z0_oj0?l00ooonf[oool0oookJP02oookJP;o>@3o0ooonfX00ooo0<[ooo]Z
oookJP03oookJP03oi80oooonf[oWol000Gooo]Z0_l7o`02oookJP04o`3oQooonf[ooo]ZoookJP;o
omH02OoonfX01?l0oego0?mWo`3oIol02?l2oookJP03o`3odooonf[o04Wo00kooo]Z00?oog<0oook
J_oonfX0LooonfX2oona00gooo]Z0_mAo`17oookJP?oobH08?oonfX6oone00gooo]Z1ooo]@05oook
JP03oolV0?oonf[ooo]Z00?ooo]Z00?ook40oookJ_l0WOl03?oonfX4o`000003oookJ_mW0?oooo]Z
00?ooo]Z00Coo`1MoookJ_oonf[o``3o0ooonfX01Om^0?oooo]ZoookJ_l0o`_oj`3o00;ooo]Z00Go
08gooookJ_ooV@3ooo]Zo`18o`04oookJP09of3o0?ooT03ooel0ool0X?oo08_o_03oog;o0?l60?oo
o`0V00;ooo]Z00?o0=ooool0^oni0?l00_oonfX01_oolP3oQ_l0oookJ_nc0?ooo`2Zo`3o4`;ooo]Z
00?oQ_l0oookJ_oonfX00_oonfX01ol00Ooooo]Zobl0oooo`03ooo]Zo`3oY_m?0?l00_oonfX00ooo
O`3o0P3ooookJP02oookJP05o`d0oolMo`3oJOl0ool0col0okP00_l0old01?oo08Kooo]Zoh00oon0
0?l4oookJP03ob?o0?ooG@3o02co00;ooo]Z0_l0nol01_oonf[oooh0ofko0?ob0?oooo]Zool0>`?o
oo]Z00Co04ooool0/Ooo^`3ooo]Z0_oo03<8oookJP;oo`230_oonfX2o`3oV003oookJ_oPo`3oh?l0
00Oooo]Z0_oj0?l00ooonf[oo`2goooo0003oookJP;o>@3o0_oonfX2ool0bPGooo]Z00?oTP3ooook
J_nOo`001OoonfX00ol7o`3ooo]ZoookJP02o`3oQ`?ooo]Z00?oomH0oookJ_oonfX01ooonfX01?l0
oegooo]Zo`3oIol0ofL2oookJP03o`3odooonf[o04Wo00oooo]Z00?oog<0oookJ_oonfX0:_oonfX0
04[ooo]Z0_oo/@0<oookJP;oDOl0B?oonfX2oolV01gooo]Z1_oo]@0BoookJQ[oogT02?oonfX4o`00
0005ofL0oooonf[ooo]ZoookJ_oo05d00ooonfX01Oo30?oooo]ZoookJ_nI0?ooKP3o00WoobP000?o
oo]Zo`18oooo:0000ooo:003onGo0003ool0X?oUo`3oiOl000CoiOl00_l0gol00ooo:03o^@3ooook
JP06oolX0004o`3o4oooN@3ooo]ZohKo00?ooo]Z00?oolT0oomi0?ooN@002?ooN@000ol20?oooo]Z
oomi0002oomi0003ofWo0?ooN@3oogT000KoogT000?o/_l0oookJ_ooN@000_oonfX01OlSo`3ooed0
oomi0?ooN@3o0?_o013oogT000CoolT0oomi0?ooN@3oogT00ooonfX00oooN@3oo`23ool0P`02oomi
0005o`3oV?ooN@3oogT0oomi0?oPo`002?oonfX01?oj0?oooo]Zoooo0?ooo`03oookJP04ocT0oooo
nf[ooo]ZoookJP;oo`3:1?oonfX2oi80o`;oWol01OoonfX01Ol7o`3ooo]ZoookJ_l02ooo0?n700?o
oo]Z00?oomH0oookJ_oonfX01ooonfX2o`3oG@04o`3oIol02?oooo]ZoookJP;o0?oC0_l0BOl>oook
JP03oomc0?oonf[ooo]Z07;ooo]Z0_oo/@0<oookJP?oDOl0AooonfX2oolV01gooo]Z1_oo]@0Joook
JP;ookD01?oonfX2oolV00?ooo]Z00Cook40oookJ_oonf[o09go2ooonfX4o`000003ofL0oooonf[o
oo]Z00;ooo]Z00Goo`1MoookJ_oonf[ooo]Zol<0o`02oookJP05ofh0oooonf[ooo]ZoookJ_l0o`/0
0_oonfX01Ol0SOoooo]ZoookJ_ooV@3o04So00Gooo]Z00Wooi00oomO0?oo0:3oo`2;ok`0oombo`3o
1P3oool09_oonfX00_l0gol02_oo0;_o^@3ooookJ_oonf[ooo80ohKo0?oonf[o/`3oool0Z_l0oa<2
oookJP03ohKo0?oonf[ooo]Z00;ooo]Z00Oo007ooookJ_l_0?oool00oookJ_l0ojKoC`3o00;ooo]Z
00?oogl0o`80oooonfX00_oonfX02ol=0?oo7Ol0ofWo0?oo0<oo0?nho`3ocOoonf[oo`26oookJ_n0
0?oo/_l000Cooo]Z00?o8ol0oomM0?l0;?l00_oonfX02?l0nooooo]Zool0Z_oooP3oK_l0oo80oooo
nf[oo`0k0ooonfX2ool0/@03oonk0?oonf[oo`0c00Wooo]Z00Goo`23oookJ_oonf[ooo]Zo`3oV002
oookJP03on3o0?oonf[ooo]Z00Kooo]Z00?onP3ooookJ_oonfX00_ooo`03oookJP05ocT0oooonf[o
oo]ZoookJ_oo0<X01OoonfX2oi80o`;oWol01OoonfX01?l7o`3ooo]Zo`0;ool0ohL4oookJP03oooF
0?oonf[ooo]Z00Kooo]Z0_l0oed00ooonf[o0?mWo`08o`02oookJP03o`3odol0BOoo04Wo00oooo]Z
00?oog<0oookJ_oonfX0:ooonfX004Sooo]Z0_oo/@0<oookJP;oDOl0AooonfX3oolV01Wooo]Z1_oo
]@0KoookJQSoogT01ooonfX4o`000005ofL0oooonf[ooo]ZoookJ_oo05d00_oonfX01Oo30?oooo]Z
oookJ_oo:03oKP3o00WoobP000?ooo]Zo`18oooo:0001?oo:0000oooT03ooel0ool0X006onGo0004
o`3Ooooo0;_oobP0okT0o`SoobP00_oonfX01on6o`3ooo]ZoookJ_oonf[oolT0o`01oooob@002?oo
N@000ol20?ooogT0oomi0002oomi0003ofWo0?ooN@3oogT000KoogT01OoonfX2oomM0003oomi0?oo
nf[o0?_o00coogT000Gook/0oomi0?ooN@3oogT0ooo90002oookJP03oomi0?oonf[ooo]Z00;oogT0
00Goo`23oomi0?ooN@3oogT0o`3oV003oomi0003on3o0?oonf[ooo]Z00Kooo]Z00ConP3ooookJ_oo
o`3oo`2g0ooonfX01Oli0?oooo]ZoookJ_oonf[oo`3:00Gooo]Z00?oTP3ooookJ_nOo`001_oonfX0
0ol7o`3ooo]ZoookJP02o`3oQ`;ooo]Z0_ooeP09oookJP04o`3oGOl0ofOo0?mWo`08o`;ooo]Z00?o
0?oCoookJ_l0BOl03_oonfX2oomc07?ooo]Z0_oo/@0<oookJP;oDOl0AooonfX3oolV01Wooo]Z1_oo
]@0RoookJP;ookD01?oonfX01ooo9P3ooo]ZoookJ_oonf[ook40oookJ_l0WOl02ooonfX4o`000003
ofL0oooonf[ooo]Z00;ooo]Z00Coo`1MoookJ_oonf[o``3o0_oonfX01Om^0?oooo]ZoookJ_oonf[o
0?l;00;ooo]Z00Go08gooookJ_oonf[ooiT0o`18o`05oookJP0=oon@0?ooG`3oo`2Pool0Ronl0?oo
L_l0o`H0oooo02Kooo]Zo`3Ooooonf[oo`2kokT0o`02oookJP06ooob0?n6o`3ooo]Zok<0oooo0:[o
0?lC0_oonfX00on6o`3ooo]ZoookJP02oookJP05o`01oooonf[o;`3oooo00?oonfX00_m?0?l01?oo
nf[oogl0oomo0?l20?l2oookJP0<o`d0oolMo`3o7Ol0ofWo0?oonf[o0?nho`3ocOoonf[oo`26oook
J_n00?oo/_l01?oonfX2oomM0006o`0/oooonf[ooo]Zo`3koooonf[oo`2Z0_m^o`000oob0?oooo]Z
ool0>`02oookJP04o`1?oooo0;7ook/0oonk00;oo`0c2OoonfX01Ooo08?ooo]ZoookJ_oonf[o0?nH
00;ooo]Z00?oh?l0oookJ_oonfX01_oonfX01?oj0?oooo]Zool0]oooo`04oookJP03ocT0oooonf[o
oo]Z00;oo`3:1OoonfX00onB0?oooo]Zoioo0005oookJP;o1ol000?ooo]Zo`0;ool0ohL00ooonfX2
oooF00Sooo]Z00Ko0?mMoookJ_l0ofOo0?mWo`08oooonfX2o`3od`03o`19oooonf[ooo]Z00gooo]Z
0_ooL`0^oookJP00A_oonfX2oona00cooo]Z0_mAo`17oookJP;oobH06OoonfX3oone01kooo]Z6Ooo
N@09oookJPCo000000CoI`3ooookJ_oonf[oo`1M0ooonfX01Oo30?oooo]ZoolX0?nI0?ooKP3o00Wo
obP000?o04SooolX0?oo:0000ooo:0001?ooT03ooel0ool0X?oo:006onGo0003ool0^ooo:03o^@3o
00SoobP000?ooo]ZohKo0?n6o`001?oonfX01?l00OooolT0ooo90?oob@06oomi0004o`80ooooN@3o
ogT0o`d0o`;oJOl02?ooN@04oookJP03ob?o0?ooG@3o02co00;ooo]Z2OooN@001Ooonf[o04oooomi
0?ooN@3ook/000CoogT01OoonfX5oomi00;o0?nH0_ooN@02on3o00Oooo]Z0_oj0?l00ooonf[oool0
oookJP02oookJP;o>@3o0ooonfX00ooo0<[ooo]ZoookJP03oookJP03oi80oooonf[oWol000Gooo]Z
0_l7o`000ooonf[o00_oo`3oQ`03oookJP03oooF0?oonf[ooo]Z00Sooo]Z00Go0?mMo`3oIol02?oo
00SooookJP02o`3od`;o04Wo3_oonfX00oooL`3ooo]ZoookJP09oookJP03oiD0oooonf[ooo]Z06Go
oo]Z0_oo/@0<oookJP;oDOl0AooonfX2oolV01Wooo]Z0ooo]@0ZoookJP;ookD00_oonfX01ooo9P3o
oo]ZoookJ_oonf[oDOl0oona0?l0WOl02ooonfX4o`000005ofL0oooonf[ooo]ZoookJ_oo05d00ooo
nfX01?o30?oooo]ZoiT0oom^0?l2oookJP04on/0ool0o`_ooo]Zo`2=o`;ooo]Z00?ooiT0o`18oooo
nfX01?oonfX03OooT03ooel0ool0X?oo08_o_03oog;o0?l60?ooo`0VoookJ_l0goooo`3Qool0^oni
0?l00_oonfX01ooolP3ooo]ZoookJ_nc0?ooo`2Zo`3o4ooonfX00_n6o`04oookJP06o`01oooonf[o
;`3oooo00?l0ojKoC`3o0_oonfX00oooO`3oo`2<o`80o`02oookJP07o`d0oolMo`3oJOl0ofWo0?oo
nf[o0?nho`3oc@02ool0QP03oookJ_n00?oo/_l000?ooo]Z00?o8ol0oomM0?l0;?l00ooonfX01_l0
nooooo]Zool0Z_m^o`3ooo]Zoo80o`;oo`0k0_oonfX01Ol0Coooo`2aoonk0?oonf[oo`0c00Wooo]Z
0_oo08<2oookJP;o0?nH00?ooo]Zon3o0?oPo`001ooonfX2ooX0o`03oookJ_ooo`3oool000?ooo]Z
0_li0?l2oookJP03ool0b_oonf[ooo]Z00Cooo]Z00?oTP3ooookJ_nOo`001OoonfX01Ol7o`3ooo]Z
o`0;ool02ooo0?n700?ooo]Z00?oomH0oookJ_oonfX01ooonfX01?l0oegooo]Zo`3oIol02?l2oook
JP03o`3odol0BOoo04Wo00oooo]Z00?oog<0oookJ_oonfX02?oonfX2oiD0obCooo]Z0014oookJP;o
ok403?oonfX2oe7o04Kooo]Z0ooo9P0HoookJP?ookD05?oonfX;ok00oa3oogT000?ookD0oomi0?oo
:0000_oo:007oomi00Sooo]Z0ol000001OmW0?oooo]ZoookJ_oonf[oo`1M00;ooo]Z00Go``3ooook
J_oo:03oobP0ofh0o`09oolX0003oookJ_l0B?oooo]Z00CoobP000Gooi00ool0X?nl0?ooobP0og;o
0004onGo0003ool0^ooo:03o^@3o00WoobP000?oQ_l0oookJ_oonfX00ooonfX01_l00Ooooo]Zobl0
oooob@3oC`3oooo900OoogT000?o7Ol0ofWo0?nJ0?l02?ooN@04oookJP03ob?o0?ooG@3o02co00co
ogT000CoolT0oomi0?oob@3ook/01?ooN@04oookJPKoogT000Ko0?nHoomi0?ooN@3oogT0on3o0?oo
N@07oookJP04ooX0oooonf[oool0oooo00?ooo]Z00Co>@3ooookJ_oonf[ooo]Z0_oo0<X4oookJP;o
TP3o0_nOo`05oookJP05o`Oo0?oonf[ooo]Zo`0;ool0ohL00ooonfX00oooeP3ooo]ZoookJP07oook
JP04o`3oGOl0ofOo0?mWo`08o`;ooo]Z00?o0?oCoookJ_l0BOl03_oonfX2onGo00_ooo]Z00?oU@3o
oookJ_oonfX0I?oonfX2oona00cooo]Z0_mAo`16oookJP?oobH06?oonfX3oone01Cooo]Z5On`0?l6
oookJP;ookD000?ooo]ZoolV0?oo9P000_oonfX00ooo/@3o09gooookJP0:oookJP?o000000?oI`3o
oookJ_oonfX00_oonfX01?oo05gooo]ZoookJ_o30?l2oookJP07ofh0oooonf[ooo]ZoookJ_l0o`_o
oo]Zo`2=o`02oookJP03oonI0?oonf[o04So00Cooo]Z00goH?l0oon@0?oo0:3oo`2;ok`0oombo`3o
1P3oool09_oonf[o0=ooool0hOoo0;_o^@3o00;ooo]Z00Sooo80oookJ_nc0?oo/`3ooookJ_l0oa?o
oo]ZohKo00Gooo]Z00Ko007ooookJ_l_0?oool00o`3oY_m?0?l2oookJP03oomo0?oo08cooo]Z00;o
oo]Z00Co3@3ooago0?mYo`3oob400_l0okP00ol0olgoo`26oookJP02oh00o`07ok;o0?oonf[ooo]Z
oookJ_lSo`3ooed0o`0/o`03oookJP04o`3koooonf[oK_l0ofko00;olP3o00Woo`0koookJ_oonf[o
oo]Zo`1?oooo0;7ook/0oookJ_oo03<02OoonfX01Ooo08?ooo]ZoookJ_oonf[o0?nH00;ooo]Z00?o
h?l0oookJ_oonfX01_oonfX01?oj0?oooo]Zool0]oooo`04oookJP05ocT0oooonf[ooo]ZoookJ_oo
0<X01OoonfX2oi80o`;oWol01OoonfX00ol7o`3ooo]Zo`0;o`02o`3oQ`;ooo]Z0_ooeP08oookJP;o
0?mM0_l0ofL01Ol02?oooo]Zo`3odol0om?o04Wo00oooo]Z0_ooL`0:oookJP03oiD0oooonf[ooo]Z
02Cooo]Z0012oookJP;ook403?oonfX2oe7o04Kooo]Z0_oo9P0HoookJP?ookD04ooonfX4ok00o`ko
oo]Z3OooN@05oolX00SoogT01ooonfX3o`000004oolX0?oonf[ooo]Zool0G@;ooo]Z00GoogT0oook
J_oonf[oobP0ofh0o`0:oolX0004o`18oooonf[ooo]Zool000;oobP000Oooi00ool0X?nl0?ooobP0
og;o0?oo02KoobP000?oiOl000?oobP0okT0oooo:0002?oo:0000on6o`3ooo]ZoookJP03oookJP05
o`01oooonf[o;`3ooookJ_m?0?l00ooob@05oomi0004oago0?mYo`3oVP3oool0c`SoogT00ooonfX2
oomM00googT000Goo`2aoomi0?oo^`3ook/0ooo90003oomi0003ooo90?oonf[ooo]Z00OoogT000Ko
0?nHoomi0?ooN@3oogT0on3o0?ooN@06oookJP;onP3o00?ooo]Zoooo0?oonfX00ooonfX01Oli0?oo
oo]ZoookJ_oonf[oo`3:00Gooo]Z00?oTP3ooookJ_nOo`001OoonfX2o`Oo0004oookJ_l02ooo0?n7
o`3oQ`;ooo]Z0_ooeP09oookJP04o`3oGOl0ofOooo]Zo`08o`;ooo]Z00?o0?oCo`19ool0BOl03?oo
nfX5onGo00[ooo]Z00?oU@3ooookJ_oonfX0HooonfX2oona00cooo]Z0_mAo`16oookJP;oobH06?oo
nfX3oone01?ooo]Z1?n`0?lEoookJPCo/03o1?oonfX01?oo]@3ooo]ZoookJ_oo9P02oookJP03oona
0?l0WOoooo]Z00Wooo]Z0ol000001OmW0?oooo]ZoookJ_oonf[oo`1M00;ooo]Z00Go``3ooookJ_oo
nf[oV@3oofh0o`02oookJP08o`3o2ooonf[ooo]Zo`2=oooonf[ooiT0oookJ_l0B?l4oookJP0=of3o
0?ooT03oo`2Pool0Ronl0?ooL_l0o`H0oooo02Kooo]Zo`3Ooooo0>7oo`2kokT0o`02oookJP08ooob
0?oonf[o/`3oool0Z_oonf[o0?lCoookJ_n6o`05oookJP06o`01oooonf[o;`3oooo00?l0ojKoC`3o
0_oonfX00oooO`3o0P3ooookJP02oookJP;o7Ol000?oJOl0ool0col0okP00_l0old01?oo08Kooo]Z
oh00oonbo`04oookJP;ooed000?o02cooookJ_oonfX00_l0nol01_oo0:[oK_l0ooon0?ob0?oooo]Z
ool0>`;ooo]Z00Co04ooool0/Ooo^`3ook/00_oo03<9oookJP05ool0Pooonf[ooo]ZoookJ_l0oiP0
0_oonfX00ooPo`3ooo]ZoookJP05oookJP;onP3o00?ooo]Zool0]oooo`001?oonfX00oli0?oooo]Z
oookJP02ool0bPGooo]Z00?oTP3ooookJ_nOo`001OoonfX2o`Oo0003oookJ_l02ooo0?n700?ooo]Z
00?oomH0oookJ_oonfX01ooonfX01?l0oegooo]Zo`3oIol02?l2oookJP03o`3odol0BOoo04Wo00oo
oo]Z00?oog<0oookJ_oonfX02OoonfX00onE0?oooo]ZoookJP0UoookJP00@?oonfX2oona00cooo]Z
0_mAo`16oookJP;oobH05ooonfX3oone01?ooo]Z0on`0?lFoookJPWoogT01Ooo:009oomi00Kooo]Z
0ol000001?oo:03ooo]ZoookJ_oo:002oookJP04oomi0?oonf[oobP0ofh0o`CoobP000?oo`00oolX
0?oo:0000ooo:0000ol0B?oooo]ZoookJP02ool0000=oolX0?ooT03oo`2Pok`0oooo:03oL_l0ool0
0?oo02KoobP0o`3OoooUo`3oobP0okT0o`09oolX0003ohKo0?oonf[ooo]Z00;ooo]Z0_oob@001?l0
O?oo;`3ooookJ_m?0?l2oomi0003ooo90?ooO`3oolT000?oogT000Oo7Ol0ofWo0?nJ0?oo0?nhoomi
0?l0olgooo]Z00GoogT00ooonfX00oooG@3o02cooomi000<oomi0003ool0/Ooob@3ook/000CoolT0
00?oogT0ooo90?oonfX01oooN@02o`3oV0;oogT00_oPo`000oooN@3ooo]ZoookJP04oookJP04ooX0
oooonf[ooo]Zoooo00?ooo]Z0_li0?l3oookJP03ool0b_oonf[ooo]Z00?ooo]Z00?oTP3ooookJ_nO
o`001OoonfX01Ol7o`3ooo]ZoookJ_l02ooo0?n700?ooo]Z00?oomH0oookJ_oonfX01ooonfX00ol0
oego0?mWo`3oI`02o`08o`04oookJ_l0om?o0?oCo`19o`cooo]Z1_oUo`0:oookJP03oiD0oooonf[o
oo]Z06;ooo]Z0_oo/@0<oookJP;oDOl0A_oonfX2oolV01Oooo]Z0ooo]@0CoookJP?o/03o7OoonfX2
ok00o`;ooo]Z00SookD0oookJ_oonf[ooo]ZoolV0?oonf[ook40o`2Mo`[ooo]Z0ol000001?mW0?oo
oo]ZoookJ_oo05d3oookJP04ol<0oooonf[ooo]Zofh0o`;ooo]Z00So0?l;oookJ_oonf[o08gooook
J_ooV@3ooo]Zo`18o`Gooo]Z01Kooi00ool0X?oo08_o_03ooookJ_mbo`3oo`0VoookJ_l0goooo`3Q
ool0^oni0?ooFol0oookJ_oolP3ooo]Zok<0oooo0:[ooo]Zo`3o4ooonf[oQ_l01?oonfX2o`01o`05
o`1lool_0?oool00o`3oY_m?0?l00_oonfX00oooO`3o0P3ooookJP02oookJP0;oago0?mSo`3oJOl0
oookJ_l0okSo0?o=oookJ_oo08Kooo]Zoh00oonbo`001?oonfX00oooG@3o02coo`0/o`02oookJP06
o`3koooonf[oo`2Zofko0?oonf[olP3o0_oo03/2oookJP05o`1?oooo0;7ook/0oookJ_oo03<02Ooo
nfX2ool0P`;ooo]Z0_l0oiP00ooonf[oh?l0on3o0007oookJP03ooX0oooonf[ooo]Z00;oool00ooo
nfX2ocT0o`;ooo]Z00?oo`3:oookJ_oonfX01?oonfX00onB0?oooo]Zoioo0005oookJP05o`Oo0?oo
nf[o00_oo`0;ool0ohL00ooonfX00oooeP3ooo]ZoookJP06oookJP;o0?mM0_l0ofL01Ol02?oooo]Z
oookJ_l0om?o04Wo00oooo]Z0_ooL`0;oookJP03oiD0oooonf[ooo]Z02Kooo]Z000noookJP;ook40
3?oonfX2oe7o04Gooo]Z0ooo9P0=oookJP;oolT01ooonfX3oone01;ooo]Z1?n`0?l=oookJP[o0:co
1Ooo:006oomi00;o/03o0ooo:006ool000CoogT01OoonfX2o`0000;oobP000Co0000oookJ_oo:03o
oo]Z0_ooN@02oolX0004ofh0oooo:03oobP0oolX00?oo`001?oo:002oookJP0?ool00?oo:03oobP0
oon@0?oo0:3o_03ooolX0?mbo`3oo`00ool09_oo:03o0=oooomi0?oo:03o^@3o00[oobP00ooonfX4
ooo90003obl0oooonf[oC`3o00?oogT000Coogl0ooo90?ooN@3oogT00_lMo`000omYo`3oVP3oo`3o
^002o`3oc@03oomi0?oo08KoogT000?oogT00_oonfX01?lSo`3ooed0o`0/oooonfX<oomi0003ool0
/Ooob@3ook/000GoolT02OooN@001Ol0oiSooo]Zoomi0?ooN@3oh?l000;oogT01OoonfX2ooX0o`03
oookJ_oo0;Ooool000?ooo]Z00Co>@3ooookJ_oonf[ooo]Z0_oo0<X4oookJP;oTP3o00?ooo]Zoioo
0?oonfX01?oonfX00ol7o`3ooo]ZoookJP02o`3oQ`;ooo]Z0_ooeP08oookJP;o0?mM00?o0?mWoook
J_l02?l00_oonfX00ol0om?o04Woo`19o`0;oookJPOoiOl02OoonfX2oiD0of?ooo]Z0_oo/@0<oook
JP;oDOl0AOoonfX3oolV01Kooo]Z0ooo]@0BoookJPCo/03o3_oonfX?o`2/o`Gooo]Z0_n`0?l01Ooo
nf[ookD0oone0?oonf[oobH000;ooo]Z00?ook40o`2MoooonfX02?oonfX2o`000005ofL0ool0003o
0000oookJ_oo05d00_oonfX03?o30?oooo]ZoookJ_nI0?ooKP3ooookJ_o[0?oo0?l;oookJ_l0SOoo
oo]ZoonI00;ooo]Z00?o04SooookJ_oonfX00_oonfX01oooT03oo`2Pool0Ronl0?oooo]Zog;o0?oo
02H00_oonfX03Ol0goooo`2kokT0oomKo`3ooo]Zooob0?oonf[o/`3oool0Z_oonf[o0?lCoookJ_n6
o`001?oonfX01ol00Ooooo]Zo`1lool_0?oool00o`3oY_m?0?l00_oonfX00oooO`3o0P3ooookJP02
oookJP0;oago0?mYo`3oJOl0oookJ_l0okSo0?o=oookJ_oo08Kooo]Zoh00oonbo`000ooonfX00olS
o`3ooed0o`0/o`03oookJP07o`3koooonf[oK_l0ofko0?oonf[olP3oool0>`03oookJP03o`1?oooo
0;7ook/000;oo`0c2OoonfX01Ooo08?ooo]ZoookJ_oonf[o0?nH00;ooo]Z00?oh?l0oookJ_oonfX0
1OoonfX2ooX0o`03oookJ_oo0;Ooool000Cooo]Z00?o>@3ooookJ_oonfX00_oo0<X5oookJP;oTP3o
0_nOo`05oookJP03o`Oo0?oonf[o00_o00;o0?n70_oonfX2oooF00Sooo]Z00?o0?mMoookJ_l0ofL0
0_l02?l01?oonf[o0?oCo`3odol0BOl?oookJP03oomc0?oonf[ooo]Z00Wooo]Z0_nE0?lYoookJP00
??oonfX2oona00cooo]Z0_mAo`15oookJP;oobH03ooonfX3ooo900Cooo]Z0ooo]@0BoookJP?o/03o
3OoonfX4o`2/o`;ooo]Z2Ooo07H00ooob@3oobP0oolX0005oolX00;oogT00_oo:0000on`0?ooobP0
oolX0006ool000;oogT01ooonfX01Ol0003oobP0oolX0?oo:03ooo]Z00;oobP00_ooN@02oolX0004
ofh0oooo:03oobP0oolX00Coo`001?oo:0000ooo003oobP0oolX0004oolX0006ool00?mbo`3oo`00
ool09_oo:03o0=oo0_ooN@000oni0?ooobP0oolX0008oolX00;ooo]Z1Ooob@000ol_0?ooogT0odl0
o`03oomi000;oomo0?ooN@3oogT0oomi0?lMo`3o3@3oofWo0?oo8@3o0?nho`3ocOooN@000_oo08H0
0oooN@3oP03ooomi0002oomi0007oookJ_ooG@3ooed0o`0/oooonf[oogT0o`3ko`0;oomi0003ooo9
0?oo^`3oolT000?oolT02_ooN@000ol0oiSooo]ZoookJP02on3o00;oogT01OoonfX00ooj0?oooo]Z
oookJP02oooo00?ooo]Z00Go>@3ooookJ_oonf[ooo]Zool0bP05oookJP04oi80oooonf[oWol0oioo
00Cooo]Z0_l7o`000ooonf[o00_oo`3oQ`03oookJP03oooF0?oonf[ooo]Z00Oooo]Z00Ko0?mMo`3o
Iol0ofOooo]Zo`08oooonfX2o`3od`03o`19oooonf[ooo]Z00Sooo]Z2OoUo`09oookJP03oiD0oooo
nf[ooo]Z067ooo]Z0_oo/@0=oookJP03oe7o0?oonf[ooo]Z04?ooo]Z0_oo9P0GoookJP;ookD04_oo
nfX3ok00o`gooo]Z1Ol0[?l2oookJPgoo`1f0ol0[?l4oookJP;o/03o00Cooo]Zoone0?oonf[oobH0
0_oonfX00ooo/@3o09gooookJP07oookJP;o000000CoI`3oo`000?oonf[oo`1M0_oonfX01Oo30?oo
oo]ZoookJ_oonf[oKP3o00;ooo]Z00Go0?l;oookJ_l0SOoooo]ZoonI0002oookJP03o`18oooonf[o
oo]Z00;ooo]Z00Oooi00ool0X?oo08_o_03ooookJ_mbo`3oo`0V00;ooo]Z00go0=ooool0^oni0?oo
Fol0oookJ_oolP3ooo]Zok<0oooo0:[ooo]Zo`3o4ooonf[oQ_l000Cooo]Z00Oo007ooookJ_l_0?oo
;`3oooo00?l0ojKoC`3o00;ooo]Z00?oogl0o`80oooonfX00_oonfX01?lMo`3oJOl0oiX0ool0okP2
o`3oc@;oo`2600?ooo]Zoh00oonbo`000ooonfX2oomM000;o`0/oooonf[ooo]ZoookJ_l0nooooo]Z
ofko0?oooP3ooo]Zoo80oooo03/00ooonfX2ool0/@03oonk0?oo03?ooo]Z00Sooo]Z0_oo08<2oook
JP;o0?nH00?ooo]Zon3o0?oPo`001ooonfX00ooj0?oooo]ZoookJP02oooo00?ooo]Z0_li0?l2oook
JP03ool0b_oonf[ooo]Z00Cooo]Z00?oTP3ooookJ_nOo`001OoonfX2o`Oo0003oookJ_l02ooo0?n7
00?ooo]Z00?oomH0oookJ_oonfX01_oonfX2o`3oG@;o0?mW00Go00SooookJ_oonf[o0?oCo`19o`0@
oookJP03oomc0?oonf[ooo]Z00Wooo]Z00?oU@3ooookJ_oonfX0:OoonfX003[ooo]Z0_oo/@0<oook
JP;oDOl0AOoonfX2oolV013ooo]Z1Ooob@000ooonf[ookD0oone000BoookJP?o/03o3?oonfX4o`2/
o`;ooo]Z1?oo07H<oookJP03ooo90?oo:03oobP000WoobP01_oo0002oolX00Oooo]Z00?o0000oolX
0?oo:0000ooo:002oomi00;oobP000?oKP3ooolX0?oo00001_oo0003oolX0003ool00?oo:03oobP0
00GoobP000GoL_l0ool00?oo02KoogT0o`3Oo`02oomi0003okT0oooo:03oobP000;oobP000?o/`3o
oolX0?oo:0001?oo:006ooo90003oomi0?m?0?ooC`3o00?oogT000?oogl0oomi0?ooN@000_lMo`00
1ol=0?ooJOl0ool0coooN@3o0?o=oomi0?oo08H01_ooN@000ooonf[ooed0oookJP03oomi0005o`3k
ooooN@3oK_l0oomi0?ob0?l01oooN@02oonk00CoolT02oooN@02oookJP04on3o0?oonf[ooo]Zoomi
00Gooo]Z00ConP3ooookJ_oonf[oool00ooonfX2ocT0o`;ooo]Z0_oo0<X4oookJP;oTP3o00?ooo]Z
oioo0?oonfX01?oonfX01Ol7o`3ooo]ZoookJ_l02ooo0?n700?ooo]Z00?oomH0oookJ_oonfX01_oo
nfX2o`3oG@07o`3oIooonf[o00Soo`08oooonf[o0?oCo`19o`0:oookJP[oiOl02?oonfX2oiD0of;o
oo]Z0_oo/@0=oookJP;oDOl0A?oonfX2oolV01Kooo]Z0ooo]@0AoookJP?o/03o3?oonfX4o`2/o`;o
oo]Z1Ooo07H>oookJPGoo`1f0ooonfX02?n`0?oooo]Zoone0?oonf[oobH0oookJ_oo/@3o09go2?oo
nfX2o`000004ofL0ool0003ooo]Zool0G@;ooo]Z00Co``3ooookJ_oonf[oKP3o0_oonfX00ol0o`_o
oo]ZoookJP02oookJP04oonI0?oonf[ooo]Zo`18o`?ooo]Z00Oooi00oookJ_oo0:3ooo]Zok`0oomb
o`3oo`0V00;ooo]Z00go0=ooool0^oni0?ooFol0oookJ_oolP3oo`3dok<0oooo0:[ooo]Zo`3o4ooo
nf[oQ_l000Cooo]Z00Go007ooookJ_l_0?oooo]Zooo00002odl0o`;ooo]Z00Coogl0o`80oooonf[o
oo]Z0_lMo`001omYo`3oVP3oo`3o^?l0olgooo]Zool0Q_oonfX00_n00?l4oookJP03oomM0?oonf[o
02co00?ooo]Z00Co0?_oofko0?m^o`3oooh00_ob0?l01Ooo03_ooo]ZoookJ_l0Coooo`2a00;ook/0
00?oo`0coookJ_oonfX01ooonfX02?oo08?ooo]ZoookJ_oonf[o0?nHobKo0?oonf[oh?l02?oonfX0
1?oj0?oooo]ZoookJ_ooo`04oookJP03ocT0oooonf[ooo]Z00;oo`3:1OoonfX2oi80o`;oWol01Ooo
nfX01Ol7o`3ooo]Zo`0;ool02ooo0?n700;ooo]Z0_ooeP08oookJP03o`3oGOoonf[o0?mW00;o00So
0_oonfX00ol0om?ooo]ZoookJP0>oookJP;oog<02_oonfX2oiD0obcooo]Z000hoookJP;ook403?oo
nfX2oe7o04Gooo]Z0_oo9P0@oookJPOoolT000?ookD0oookJ_oonfX00ooonfX2ooo900[ooo]Z0on`
0?l2oookJP;oiOl02?oonfX3o`2/o`Koo`1f4ooonfX00ooob@3oobP0oolX0009oolX00;oo`001?oo
:006oookJPKoobP000GoogT0oolX0?oo:03oobP0ofh0o`08ool000[oobP000KoL_l0ool09_oo02Ko
ogT0o`3OooooN@02okT0o`CoobP000?oo`00oolX0?oo:0000ooo:008ooo90004odl0ool0ojKoogT0
oomi00;oogl00_ooN@001OlMo`3o3@3oo`d0oomYo`3o0?nh00;o0?o=00?oogT0ool0Q_ooN@001Ooo
N@000ooonf[ooed0oomi0002oomi00;o0?_o00CoogT0ofko0?oob@3olP3o1oooN@001?oo^`3oo`0c
ooo90?oonfX3ooo900[oogT00_oonfX00ooPo`3ooo]ZoookJP05oookJP;onP3o00?ooo]Zool0]ooo
o`000ooonfX01Oli0?oooo]ZoookJ_oonf[oo`3:00Gooo]Z00CoTP3ooookJ_oonf[oWol01?oonfX2
o`Oo0004oookJ_l02ooo0?n7o`3oQ`;ooo]Z0_ooeP08oookJP05o`3oGOl0ofOo0?mWoookJ_l02?l0
0_oonfX00ol0om?o04WooookJP09oookJP[oiOl02?oonfX00onE0?oooo]ZoookJP1PoookJP;ook40
3OoonfX2oe7o04Cooo]Z0_oo9P0FoookJP;ookD04OoonfX3ok00o`cooo]Z0ol0[?l00ooonf[oo`1f
ool0MP03ool0MQSooo]Z00Coo`1foookJ_oonf[ooo]Z0_n`0?l01Ooonf[oobH0oookJ_oo/@3o09go
00Sooo]Z00So0000ofL0ool0003o0000oookJ_oo05gooo]Zol<0o`;ooo]Z00?oV@3oofh0oooonfX0
1OoonfX01?ooV@3ooo]ZoookJ_l0B?l3oookJP07oon@0?oonf[oo`2PoookJ_nl0?ooL_l0ool09P02
oookJP0=o`3Ooooo0;_o^@3ooe_o0?oonf[ooo80ool0m?nc0?oooo]Zool0Z_l0oa?ooo]ZohKo0004
oookJP06o`01oooonf[o;`3ooookJ_l0ojKoC`3o0_oonfX2oomo000>o`80oooonf[ooo]Zoago0?l=
0?ooJOl0oiX0ool0okSo0?o=oookJ_oo08Kooo]Zoh00oonbo`04oookJP03oomM0?oonf[o02co00;o
oo]Z0_l0nol01Om^o`3oooh0ooon0?ob0?ooo`0k00?ooo]Z00?o04ooool0/Ooo^`000_oo03<9oook
JP05ool0Pooonf[ooo]ZoookJ_l0oiP00_oonfX00ooPo`3ooo]ZoookJP05oookJP;onP3o00?ooo]Z
ool0]oooo`001?oonfX01?li0?oooo]ZoookJ_oo0<X6oookJP03oi80oooonf[oWol000Gooo]Z0_l7
o`001?oonf[o00_oo`3oQol0ohL2oookJP03oooF0?oonf[ooo]Z00Kooo]Z0_l0oed2o`3oI`03o`08
oooonf[ooo]Z00;o0?oC4?oonfX00oooL`3ooo]ZoookJP09oookJP03oiD0oooonf[ooo]Z02cooo]Z
000foookJP;ook403?oonfX2oe7o03[ooo]Z0_oUo`08oookJP?oobH04OoonfX9ooo900Cooo]Z0ooo
b@07oookJP?o/03o0oooN@001?oonf[oiOl0onGo0?oUo`04oookJPCo0:co0ooo07H@oookJP;oobP0
1?oonfX00ooo:03oo`00ool00003ool00003ooo90?oo:03oobP000koobP00ooonfX:oolX0003ofh0
oooo:03oo`0000Koo`002_oo:0000ombo`3oo`0Voomi0002oolX0003oomi0?ni0?ooogT000?oobP0
0ooo0003oolX00WoolT000GoC`3ooomi0?ooN@3oogT0oomo0003oomi0007oago0?l=0?ooJOl0ofWo
0?l0okSo0?o=oomi0002ool0QPKoogT000?ooo]ZoomM0?ooN@000_ooN@001_l0noooolT0ooo90?m^
o`3oolT0oo80o`GoogT000Coo`2aoomi0?oo^`3oo`0c1?oonfX3ooo900SoogT000?ooo]Zon3o0?oP
o`001ooonfX00ooj0?oooo]ZoookJP02oooo00?ooo]Z00Go>@3ooookJ_oonf[ooo]Zool0bP05oook
JP04oi80oooonf[oWol0oioo00Cooo]Z00Go1ol0oookJ_oonf[o00_oo`3oQ`03oookJP03oooF0?oo
nf[ooo]Z00Kooo]Z0_l0oed01Ol0ofOooo]Zo`08ool02?oooo]Z00;o0?oC3?oonfX:onGo00Kooo]Z
0_nE0?mQoookJP;ook403OoonfX2oe7o04?ooo]Z0ooo9P0FoookJP;ookD04?oonfX3ok00o`cooo]Z
0ol0[?l4ool0MQkooo]Z0_oo07H3oookJP06ok00oooonf[oobH0oookJ_oo/@3o09go1ooonfX01Ol0
003oI`3oo`000?l0003oo`1M00;ooo]Z00Co``3ooookJ_oonf[oKP3o1ooonfX00oooV@3ooo]Zo`18
o`03oookJP08oon@0?oonf[oo`2PoookJ_nl0?ooL_l0ool09_oonfX2o`3Oo`0<ool0^oni0?ooFol0
oookJ_oolP3oo`3dok<0oooonf[oo`2Zo`3o4ooonf[oQ_l01?oonfX01_l00Ooooo]Zobl0oooo`03o
0?nVodl0o`;ooo]Z00?oogl0ool0S?oonfX00_oonfX01_lMo`3oJOl0ofWo0?nJ0?oo0?nho`3oc@;o
o`2600?ooo]Zoh00oonbo`001?oonfX00oooG@3o02coo`0/o`02oookJP07o`3koooonf[oK_l0ooon
0?oonf[olP3oool0>`03oookJP04o`1?oooo0;7ook/0ool0<`Wooo]Z0_oo08<2oookJP;o0?nH00?o
oo]Zon3o0?oPo`001ooonfX00ooj0?oooo]ZoookJP02oooo00?ooo]Z0_li0?l2oookJP03ool0b_oo
nf[ooo]Z00Cooo]Z00?oTP3ooookJ_nOo`001?oonfX2o`Oo0004oookJ_l02ooo00_oo`3oQ`?ooo]Z
00?oomH0oookJ_oonfX01_oonfX00ol0oegooo]Zo`3oI`02o`08o`;ooo]Z00?o0?oCoookJ_oonfX0
3_oonfX2oomc00[ooo]Z0_nE0?l_oookJP00=?oonfX2oona00cooo]Z0_mAo`0koookJP?oiOl01_oo
nfX2oolV01?ooo]Z2_oob@03oookJPGoolT01?oonfX2ok00o`;ooo]Z1OooN@04onGo00?o0:co00?o
oo]Zool0M_oo07H04ooonfX3oolX00;ooo]Z00?oobP0ool00?oo00002?oo00000ooob@3oobP0ool0
000<oolX0003oookJ_oo:03oobP000[oobP02?oo0009oolX0003og;o0?oo02KoogT000?oobP000Co
^@3ooomi0?oo:03oobP01?oo0002oolX00[oolT000GoC`3ooomi0?ooN@3oogT0oomo0003oomi0004
oago0?l=0?ooJOl0oolQ00;o0?o=00?oogT0ool0Q_ooN@001_ooN@02oomM0003o`0/ooooN@3oogT0
00?oolT000?oK_l0oo80ooob0?l00_ooN@02oookJP05oomi0?oo0;7ook/0oonk0?oo03<01_oonfX0
0ooob@3ooo]ZoookJP06oomi0003oookJ_oPo`3ooo]Z00Kooo]Z0_oj0?l2oookJP04oooo0?oonf[o
oo]ZoookJP;o>@3o0_oonfX2ool0bPCooo]Z0_nB0?l00ooonf[oWol0oookJP03oookJP;o1ol000Co
oo]Zo`0;ool0ohOo0?n70ooonfX00oooeP3ooo]ZoookJP06oookJP05o`3oGOoonf[o0?mWoookJ_l0
2?l00_oonfX00ol0om?o04WooookJP0=oookJPSoiOl01OoonfX2oiD0of7ooo]Z0_oo/@0=oookJP;o
DOl0@ooonfX2oolV01Kooo]Z0ooo]@0@oookJP;o/03o3?oonfX3o`2/o`?oo`1f9?oonfX02?oo07Ko
oo]ZoookJ_oonf[o/03ooookJ_oo9P3ook402?oonfX01Ol0003oI`3oo`000?l0003oo`1M00;ooo]Z
00?o``3ooookJ_m^0?l01ooonfX00oooV@3ooo]Zo`18o`03oookJP0<oon@0?oo0:3oo`2PoookJ_nl
0?ooL_l0ool09_oonf[o0=oooookJ_oo0;_o^@3o0_oonfX02?oolP3oo`3dok<0oooonf[oo`2Zo`3o
4ooonf[oQ_l00ooonfX2o`01o`03o`1lool_0?oool0000;oC`3o0_oonfX00oooO`3o0P3ooookJP02
oookJP04oago0?mYo`3oVP3ooolQ00;o0?o=00Goo`26oookJ_n00?ooP03ook;o0003oookJP;ooed0
00So02cooookJ_oonf[ooo]Zo`3koooonf[oK_l0ooon00;olP3o00Goo`0koookJ_oonf[o04ooool0
/@02oonk0003ool0<ooonf[ooo]Z00Oooo]Z00Goo`23oookJ_oonf[ooo]Zo`3oV002oookJP03on3o
0?oonf[ooo]Z00Gooo]Z0_oj0?l2oookJP03oooo0?oonf[ooo]Z00;ooo]Z00?o>@3ooookJ_oonfX0
0_oo0<X5oookJP;oTP3o0_nOo`04oookJP04o`Oo0?oonf[ooo]Zo`0;o`;o0?n70_oonfX2oooF00Oo
oo]Z0_l0oed2o`3oI`05o`08oooonf[ooo]Zo`19ool0om<04?oonfX00oooL`3ooo]ZoookJP08oook
JP;oU@3o<OoonfX003;ooo]Z0_oo/@0<oookJP;oDOl0??oonfX5onGo00?ooo]Z0_oo9P0CoookJPco
olT00_oonfX6ooo90004oookJ_n`0?oo/03ook00o`?ooo]Z1_ooN@001?oUo`3o0:coo`2/ool0[?l2
oookJP;oo`1f4ooonfX6oolX013oo`002ooo:0000ooonf[oobP0oolX0009oolX00Soo`002_oo:000
0ooo02KoobP0oolX0002oolX0003okT0ooooN@3oogT000Goo`000_oo:00:ooo90005odl0oooonf[o
oo]Zoomi0?ooO`000oooN@001OlMo`3oogT0ofWo0?oo0<oo0?o=00;oogT000?oo`26oomi0?ooN@00
1OooN@001?ooG@3o02coo`0/oooonfX3ooo900;oK_l000ColP3oooo90?ooN@3oogT00_oonfX00ol0
Coooo`2aoonk0002ool0<`Wooo]Z1_ooN@000ooonf[oh?l0oookJP06oookJP05ooX0oooonf[ooo]Z
ool0]oooo`000ooonfX01Oli0?oooo]ZoookJ_oonf[oo`3:00Gooo]Z00CoTP3ooookJ_oonf[oWol0
1?oonfX01Ol7o`3ooo]ZoookJ_l02ooo0?n700?ooo]Z0_ooeP07oookJP;o0?mM0_l0ofL2o`08o`03
oookJ_oUo`3oiOl0013ooo]Z1ooUo`05oookJP03oiD0oooonf[ooo]Z05oooo]Z0_oo/@0=oookJP;o
DOl0@ooonfX2oolV01Kooo]Z0_oo]@0@oookJP?o/03o2ooonfX3o`2/o`03oookJ_oo07Koo`1f02So
oo]Z0_oo07H4oookJP03oolV0?oo/@3ooo]Z00Kooo]Z0ol000001ooo05gooo]ZoookJ_o30?oooo]Z
oiT0oom^0?l01_oonfX00oooV@3ooo]Zo`18o`03oookJP03oomO0?oo0:3ooo]Z00;o_03o00SoL_l0
ool09_oonf[o0=oooookJ_oo0;_o^@3ooookJP;ooo8000Ooo`3dok<0oooonf[oo`2Zo`3o4ooonf[o
Q_l000?ooo]Z00Oo007ooookJ_l0O?oo;`3oooo00?m?0?oo<ol000;ooo]Z00?oogl0o`80oooonfX0
0_oonfX02_lMo`3oJOl0oiX0ool0okSo0?o=oookJ_oo08Kooo]Zoh00oonbo`04oookJP03oomM0?l0
;?oo02co00;ooo]Z0_l0nol01Ooonf[oK_l0ooon0?ob0?ooo`0k00?ooo]Z00?o04ooool0/Ooo^`00
0_oo03<9oookJP05ool0Pooonf[ooo]ZoookJ_l0oiP00_oonfX00ooPo`3ooo]ZoookJP05oookJP05
ooX0oooonf[ooo]Zool0]oooo`000ooonfX2ocT0o`;ooo]Z00?oo`3:oookJ_oonfX01?oonfX00onB
0?oooo]Zoioo0004oookJP;o1ol00_oonfX2o`3oQ`?ooo]Z00?oomH0oookJ_oonfX01_oonfX00ol0
oegooo]Zo`3oI`02o`08o`;ooo]Z0_l0om<@oookJP03oomc0?oonf[ooo]Z00Sooo]Z00?oU@3ooook
J_oonfX0<OoonfX0037ooo]Z00?ook40oookJ_oonfX02_oonfX2oe7o03gooo]Z1_oUo`000ooonf[o
iOl0onGo000DoookJQKoolT01OoonfX8oomi00CoiOl000?oo`1foookJ_oonfX04OoonfX8oolX00ko
o`006?oo:009ool000WoobP000?oo`0VoolX0?oo:0000ooo:002oomi00Koo`000_oo:009ooo90005
odl0oooonf[ooo]Zool0S?ooO`000oooN@001OlMo`3oJOl0ofWo0?ooN@3o0?o=00;oogT000?oo`26
oomi0?ooN@001?ooN@000olSo`3ooed0o`0/o`05ooo90004ofko0?ob0?oolP3oooo900?oogT00_l0
Col00ooo0;7ook/0ool0<`09oookJP04ool0PoooN@3ooo]Zo`3oV0?oogT00_oPo`06oookJP;onP3o
0_oonfX2oooo00?ooo]Z00?o>@3ooookJ_oonfX00_oo0<X4oookJP;oTP3o0_oonfX01?nOo`3ooo]Z
oookJ_oonfX2o`Oo00;ooo]Z0_l0ohL3oookJP03oooF0?oonf[ooo]Z00Gooo]Z0_l0oed01?oonf[o
0?mWoookJ_l02?l5onGo00kooo]Z0_oUo`000ooonf[oiOl0onGo0003onGo00Cooo]Z0_nE0?mQoook
JP03oona0?oonf[ooo]Z00_ooo]Z0_mAo`13oookJP;oobH05_oonfX2oone00oooo]Z0on`0?l;oook
JP?o0:co00Cooo]Zool0M_oo07Koo`1f7OoonfX5oa[o00[ooo]Z00?oo`1foookJ_oonfX00_oonfX0
0ooo/@3ooo]ZoookJP05oookJPCo000000Gooo]Zol<0oooonf[ooo]Zofh0o`06oookJP03oonI0?oo
nf[o04So00Cooo]Z00?oo`2PoookJ_nl0?l00_mbo`004?oo02Kooo]Zo`3Ooooonf[oo`2kokT0oooo
nf[ooo80ohKo0?oo0?Co/`3ooookJ_oo0:[o0?lCoookJ_n6o`03oookJP06o`01oooonf[o;`3oobl0
oooonf[oC`3o0ooonfX01OooO`3o0P3ooookJ_oonf[oHol000;oJOl000SoVP3oo`3o^?l0olgooo]Z
ool0Q_oonf[oP03ook;o00Cooo]Z00?ooed0o`0/oooonfX00_oonfX01?l0nooooo]Zool0Z_m^o`02
oo80o`08ool0>ooonf[ooo]ZoookJ_l0Coooo`2aoonk0?oo03<9oookJP;oo`230_oonfX2o`3oV003
oookJ_oPo`3oh?l000Kooo]Z0_oj0?l2oookJP;oool00ooonfX00oli0?oooo]ZoookJP02ool0bPGo
oo]Z0_nB0?l00ooonf[oWol0oookJP03oookJP05o`Oo0?oonf[ooo]Zo`0;ool0ohL00ooonfX2oooF
00Oooo]Z0_l0oed2o`3oI`05o`08oooonf[ooo]Zo`19ool0om<04?oonfX2oomc00Wooo]Z0_nE0?ld
oookJP00;ooonfX2oona00cooo]Z00?oDOl0oookJ_oonfX0??oonfX8onGo01Gooo]Z2_oob@03oook
JP[oolT00ooonfX:oomi00CoiOl04ooonfX9oolX00coo`001Ooo:0000oooN@3oobP0oolX000DoolX
00Koo`002_oo:0000ooo02KoobP0oolX0003oolX0003oomi0?oo003oo`0000Goo`0000?oQ_l0oolX
0?oo:0001_oob@02odl0o`;ooo]Z00_oo`2<oomo0?l20?oooo]Zoomi0?lMo`3oJOl0oolQ0?ooN@3o
0?o=oomi0002ool0QPKoogT000?o8ol0oomM0?oob@001Ooob@000om^o`3olP3oooo90002ooo900;o
ogT000Go04ooool0/Ooo^`3ook/0ool0<`09oookJP08ool0Pooonf[ooo]Zo`3oV?lVo`3ooo]Zoomi
0?oPo`07oookJP05ooX0oooonf[ooo]ZoookJ_ooo`000ooonfX2ocT0o`;ooo]Z00?oo`3:oookJ_oo
nfX00ooonfX00onB0?oooo]ZoookJP02oioo00?ooo]Z00Go1ol0oookJ_oonf[o00_oo`3oQ`03oook
JP;oomH01ooonfX01?l0oegooo]Zo`3oIol0ofL2o`08o`GoiOl03_oonfX00ooUo`3ooo]ZoookJP02
oookJP?oiOl01?oonfX00onE0?oooo]ZoookJP0=oookJP;o0;OoD?oonfX2oona00cooo]Z0_mAo`13
oookJP;oobH05OoonfX3oone00kooo]Z0on`0?l;oookJP?o0:co00Cooo]Zool0M_oo07Koo`1f6?oo
nfX2oa[o00?ooh<00olJo`05obco00_ooo]Z00?oo`1foookJ_oonfX02OoonfX4o`000004oookJ_o3
0?oooo]Zofh0o`Kooo]Z00?ooiT0oookJ_l0B?l01?oonfX04Ooo0:3ooo]Zok`0oombo`3ooo]Zool0
9_oonf[o0=oooookJ_oo0;_o^@3ooookJ_oolP3oQ_l0oookJ_nc0?ooo`2Z00;o0?lC0_n6o`03oook
JP04o`01oooonf[o;`3oooo000;oC`3o0ooonfX02_ooO`3o0P3ooookJ_oonf[oHol0ofWo0?nJ0?oo
ob40o`3o^?l0old2ool0QP03oookJ_n00?oo/_l000?ooo]Z00?o8ol0oomM0?l0;?l00_oonfX2o`3k
o`04oookJ_oooP3oK_l0oo80o`;oo`0k0_oonfX01Ol0Coooo`2aoonk0?oo^`3oo`0c00Wooo]Z00Go
o`23oookJ_oonf[ooo]Zo`3oV002oookJP03on3o0?oonf[ooo]Z00Gooo]Z00GonP3ooookJ_oonf[o
oo]Zoooo0004oookJP04ocT0oooonf[ooo]Zool0bPKooo]Z00CoTP3ooookJ_nOo`3oWol00ooonfX2
o`Oo00;ooo]Z0_l0ohL3oookJP03oooF0?oonf[ooo]Z00Kooo]Z00?o0?mMoookJ_l0ofL00_l02?l2
oookJP;o0?oC4?oonfX00oooL`3ooo]ZoookJP08oookJP03oiD0oooonf[ooo]Z00kooo]Z0_l0]olT
oookJP00;OoonfX2oona00cooo]Z0_mAo`0noookJPWoiOl04ooonfX00ooo]@3oolT0ooo90002ooo9
00Wooo]Z2ooob@02oookJP_oogT01?oUo`0AoookJP_oobP02_oo0007oolX0003ool00?oo:03oobP0
01GoobP01?oo000:oolX0003ool09_oo:03oobP000?oobP00_ooN@07ool000;ooo]Z00?oobP0o`01
oooob@000ooob@001?m?0?ooolT0oookJ_oonfX2oomo000:o`80oooonf[o7Ol0oago0?mYo`3oo`3?
oomi0?l0olgoogT0ool0QPOoogT00_ooG@06ooo90003ofko0?ob0?ooolT000;oolT00_ooN@000ol0
Coooo`2aoonk0002ool0<`Sooo]Z0_oo08<2oookJP03o`3oV?lVo`3ooo]Z00;oh?l01_oonfX2ooX0
o`;ooo]Z0_ooo`03oookJP05ocT0oooonf[ooo]ZoookJ_oo0<X01OoonfX01?nB0?oooo]ZoookJ_nO
o`03oookJP;o1ol00_oonfX2o`3oQ`?ooo]Z00?oomH0oookJ_oonfX01OoonfX2o`3oG@04oookJ_l0
ofOoiOl0o`08o`KoiOl03OoonfX2onGo00Kooo]Z00CoiOl0oookJ_oonf[ooo]Z0_nE0?l?oookJP03
o`2goooonf[ooo]Z04kooo]Z0_oo/@0=oookJP03oe7o0?oonf[ooo]Z047ooo]Z0_oo9P0EoookJP;o
okD03ooonfX2ok00o`cooo]Z0_l0[?l01?oonf[oo`1fool0M_oo07HHoookJP03oa[o0?ooP`3ooh<0
00;ooh<01Ol/o`02o`18o`Ko0?o12_oonfX00ooo07Kooo]ZoookJP08oookJPCo000000Co``3ooook
J_oonf[oKP3o2?oonfX02_l0B?oooo]ZoookJ_oonf[ooi00ool0X?nl0?ooL_l0oookJ_oo02H2oook
JP0<o`3Ooooo0;_o^@3ooookJ_oolP3oQ_l0oookJ_oo0?Coo`2Zo`3o4ooonf[oQ_l01?oonfX01_l0
0Ooooo]Zobl0oooo`03oC`3oo`3oYP;ooo]Z0_ooO`002ol20?oooo]ZoookJ_lMo`3oJOl0oiX0oooo
0<oooo]Zo`3ocOoo08Kooo]Z00;oP03o1?oonfX2oomM000:o`0/oooonf[ooo]Zo`3koooonf[oo`2Z
ooon0?m^o`3olP3oool0>`?ooo]Z00?o04ooool0/Ooo^`000_oo03<9oookJP03ool0Pooonf[ooo]Z
00;o0?nH0_oonfX00ooPo`3ooo]ZoookJP04oookJP;onP3o0_oonfX2oooo00?ooo]Z0_li0?l2oook
JP03ool0b_oonf[ooo]Z00Cooo]Z00?oTP3ooookJ_nOo`001?oonfX01Ol7o`3ooo]ZoookJ_oonf[o
0?n700?ooo]Z0_ooeP07oookJP;o0?mM0_l0ofL00ol02?oooo]ZoookJP02o`3oda3ooo]Z0_ooL`09
oookJP;oU@3o4?oonfX00ol0]ooooo]ZoookJP0ToookJP00:ooonfX2oona00cooo]Z0_mAo`0ooook
JP[oiOl04OoonfX2oone00gooo]Z3Ooob@0=oomi00CoiOl03_oonfX@oolX00Goo`002Ooo:002ool0
01SoobP00ooo0008oolX0003ool09_oo:03oobP000CoobP000?oogT0ool00?oo00001Ooo0003oook
JP03o`01oooonf[ooo]Z00;oolT000GoC`3oooo90?oob@3oo`2<oomo0002o`80o`09oookJ_lMo`3o
JOl0ofWo0?oo0<oo0?nho`3ocOooN@3oo`2600KoogT000Co8ol0oomM0?l0;?ooogT01Ooob@02oo80
o`?oolT000?ooo]Zoomi0?oo0;400_oo^`000ooo03?ooo]ZoookJP07oookJP03ool0Pooonf[ooo]Z
00;o0?nH0_oonfX00ooPo`3ooo]ZoookJP05oookJP05ooX0oooonf[ooo]ZoookJ_ooo`001?oonfX0
0oli0?oooo]ZoookJP02ool0bPCooo]Z0_ooN@000ooonf[oWol0oioo0003oookJP05o`Oo0?oonf[o
oo]Zo`0;ool0ohL01?oonfX00oooeP3ooo]ZoookJP05oookJP04o`3oGOoUo`3o0?mWo`3oI`;o00So
1_oUo`0=oookJP03onGo0?oonf[ooo]Z00Wooo]Z00?oU@3ooookJ_oonfX03OoonfX2o`2godoooo]Z
0_oo/@0=oookJP;oDOl0@_oonfX2oolV01Gooo]Z0_oo]@0?oookJP;o/03o3?oonfX2o`2/o`03oook
J_oo07Koo`1f01Sooo]Z00Co6_l0oon30?ooP`3ooh<00_l/o`03oookJPCo04So00?o0?o1oookJ_oo
nfX04?oonfX2ool0MPSooo]Z1?l000000oo30?oooo]Zofh0o`08oookJP0:o`18oooonf[ooo]Zoook
J_ooG`3oo`2Pok`0oombo`3ooo]Zool09P;ooo]Z00co0=ooool0^oni0?oooo]Zooob0?n6o`3ooo]Z
ool0m?oo0:[o0?lCoookJ_n6o`03oookJP;o007o00Cooo]Zobl0oooonf[oC`3o0ooonfX00oooO`3o
o`2<o`80o`02oookJP;oJOl000SoVP3oo`3o^?oonf[o0?o=ool0Q_oonf[oP03ook;o00Cooo]Z00?o
oed0o`0/oooonfX00_oonfX01?l0nooooo]Zool0Z_oooP02oo80o`05ool0>ooonf[ooo]Zo`1?oooo
0;400_oo^`000ooo03?ooo]ZoookJP07oookJP;oo`230_oonfX00ol0oiSooo]ZoookJP02on3o00Ko
oo]Z00GonP3ooookJ_oonf[ooo]Zoooo0004oookJP03ocT0oooonf[ooo]Z00;oo`3:1OoonfX2oi80
o`;oWol00ooonfX2o`Oo00;ooo]Z0_l0ohL3oookJP03oooF0?oonf[ooo]Z00Kooo]Z00?o0?mMoook
J_l0ofL00_l02?l2oookJP03o`3odooonf[ooo]Z00oooo]Z00?oog<0oookJ_oonfX02?oonfX00onE
0?oooo]ZoookJP0>oookJP;o0;Oo9ooonfX002[ooo]Z00?ook40oookJ_oonfX02_oonfX2oe7o043o
oo]Z3?oUo`0>oookJP;ookD03_oonfX;ooo900;ooo]Z2oooN@04onGo00kooo]Z0_lJo`0PoolX00;o
o`001ooo:003ool000WoobP00_oo0003oolX0004ool00?oo:03oo`00ool000coobP00_ooN@06ool0
00?ooo]Z00Ko007ooookJ_l0O?oo;`3ooolX0?m?0?l2ooo900;oogl000Wo0P3ooookJ_oonf[o7Ol0
ofWo0?oo8@3oo`3?o`3o^?l0old00_oo08H6oomi00;ooed000Co02cooookJ_oonf[o0?_o0_oob@00
0om^o`3olP3oooo90003ooo90006o`1?oooo0;7oo`2aoonk0?oonf[oo`0c2?oonfX2ool0P`;ooo]Z
00Go0?nHobKo0?oonf[ooo]Zon3o0007oookJP05ooX0oooonf[ooo]ZoookJ_ooo`000ooonfX2oomi
00;ooo]Z00Coo`3:oookJ_oonf[ooo]Z1OooN@001?nOo`3ooo]ZoookJ_oonfX2o`Oo00;ooo]Z0_l0
ohL3oookJP;oomH01_oonfX2o`3oG@04onGo0?l0ofOoiOl0o`08o`OoiOl03OoonfX00ooUo`3ooo]Z
oookJP08oookJP;oU@3o3_oonfX2o`2goe3ooo]Z00?ook40oookJ_oonfX02ooonfX2oe7o04;ooo]Z
0_oo9P0FoookJP03oone0?oonf[ooo]Z00gooo]Z0_n`0?l;oookJP?o0:co00?ooo]Zool0M_oo07H0
5_oonfX2oa[o00?ooh<00_l/o`02oookJPCo04So00?o0?o1oookJ_oonfX05_oonfX00ooo07Kooo]Z
oookJP05oookJPCo000000?o``3ooookJ_m^0?l01ooonfX00ol0B?oooo]ZoookJP02oookJP05oon@
0?oo0:3ooo]Zog;o0?oo02H00_oonfX03?l0goooo`2kokT0oooonf[ooo80ohKo0?oonf[oo`3dool0
Z_l0oa?ooo]ZohKo00?ooo]Z00Ko007ooookJ_l0O?oo;`3ooc?o0?m?0?l2oookJP;oogl000ko0P3o
oookJ_oonf[ooo]ZofWo0?nJ0?ooob40o`3o^?oonf[o0?o=ool0Q_oonf[oP03ook;o00Cooo]Z00Co
oed0o`0/oooonf[ooo]Z0_l0nol01Ooonf[oooh0ofko0?ob0?ooo`0k00?ooo]Z0_oo0;400ooo^`3o
oo]Zool0<`09oookJP03ool0Pooonf[ooo]Z00;o0?nH0_oonfX00ooPo`3ooo]ZoookJP05oookJP05
ooX0oooonf[ooo]ZoookJ_ooo`000ooonfX2ocT0o`;ooo]Z00?oo`3:oookJ_oonfX01?oonfX00onB
0?oooo]Zoioo0003oookJP;o1ol00ooonfX00ol0ohOooo]ZoookJP02oookJP03oooF0?oonf[ooo]Z
00Gooo]Z0_l0oed2o`3oI`03o`08oooonf[ooo]Z00;o0?oC4OoonfX00oooL`3ooo]ZoookJP07oook
JP;oU@3o3ooonfX2o`2gobWooo]Z000eoookJP;oDOl0@OoonfX:onGo00oooo]Z0_oo]@0?oookJPOo
olT01_oonfX7oomi00CoiOl03ooonfX4oa[o0003oon30?oo:03oobP001ooobP00ooo0005oolX00Go
o`002?oo:003ool000;oobP01Ooo000:oolX00;oogT01_oo0003oookJP09o`01oooonf[o;`3oobl0
oooo:03oC`3ooolX0?oob@3oogl000;o0P3o0_oonfX01?lMo`3oJOl0oolQ0?oo0<l2o`3oc@04ool0
Q_n00?ooP03ook;o00?oogT000?o8ol0oomM0?l0;?l00ooonfX01Ol0nooooo]Zooon0?m^o`3olP3o
00GoolT000?oo`2aoookJ_oo^`000_oo03<8oookJP07ool0Pooonf[ooo]ZoookJ_l0oiSo9_l0oook
JP02on3o00Kooo]Z0_oj0?l2oookJP;oool000?ooo]Zoomi0?ooN@000_ooN@001?oonf[oo`3:ool0
b_oonfX7oomi0005oioo0?oonf[ooo]ZoookJ_l7o`000_oonfX00ol02ooo0?n7oookJP03oookJP03
oooF0?oonf[ooo]Z00Gooo]Z00Co0?mMoookJ_oonf[o0?mW0_l02?l7onGo00cooo]Z0_oUo`09oook
JP;oU@3o3ooonfX00ol0]ooooo]ZoookJP1LoookJP;oDOl0@_oonfX2oolV01Kooo]Z0_oo]@0>oook
JP;o/03o2ooonfX2o`2/o`;ooo]Z0_oo07HDoookJPCo6_l00_ooP`02obco00;ooo]Z0ol0B?l00ol0
ol7ooo]ZoookJP07oookJPCoo`2c1?l0G?l5ool0/`Kooo]Z00?oo`1foookJ_oonfX01OoonfX4o`00
0003ol<0oom^0?oooo]Z00_ooo]Z00Gooi00ool0X?oonf[oL_l0ool09P02oookJP06o`3Ooooo0;_o
^@3ooookJ_oolP3oQ_l00_oo0?@01?oo0:[o0?lCoookJ_n6o`03oookJP06o`01oooonf[o;`3oobl0
oolco`3oC`3o0_oonfX00oooO`3oo`2<o`80o`02oookJP05o`d0oomYo`3oVP3oool0cooonfX00_l0
old01?oonf[oP03ooh00oonbo`03oookJP;ooed00ooonfX01?l0nooooo]Zool0Z_m^o`02oo80o`07
ool0>ooonf[ooo]ZoookJ_oo0;7ooo]Zoonk0002ool0<`Wooo]Z00Goo`23oookJ_oonf[o0?nHobKo
0002oookJP03on3o0?oonf[ooo]Z00Cooo]Z0_oj0?l2oookJP;oool00ooonfX00oli0?oooo]Zoook
JP02ool0bPGooo]Z0_nB0?l2oioo00?ooo]Z00Co1ol0oookJ_oonf[ooo]Z0_l0ohL3oookJP;oomH0
1ooonfX00ol0oegooo]Zo`3oI`02o`08o`03oookJ_l0om?o0?oC017ooo]Z0_ooL`08oookJP;oU@3o
4?oonfX00ol0]ooooo]ZoookJP0YoookJP00=?oonfX00omAo`3ooo]ZoookJP10oookJPOoiOl04_oo
nfX00ooo]@3ooo]ZoookJP0=oookJP04ok00oooob@3oolT0ooo900Wooo]Z00Go0:cooomi0?ooN@3o
ogT0ool0MP03onGo01;ooo]Z0_lJo`001Ooonf[ooh<0oon30?ooP`3o;?l000;o0?o10_l0B?l2oomi
00;ooo]Z0ooo:005ool0/`03o`1Loooo:03oobP000koobP01?oo0003oolX00Koo`001ooo:00<ool0
00WoobP000?oogT0ool00?oo00001Ooo0002oookJP04o`01oooonf[o;`3oooo000;oC`3o00CoobP0
oookJ_ooO`3o0P3o0_oonfX02_mSo`3o7Ol0ofWo0?oo8@3o0?nho`3ocOoonf[oo`26oh00oonbo`03
oookJP04oomi0?ooG@3ooed0o`0/o`;ooo]Z0_l0nol01?oonf[oK_l0oo80ooob0?l4ooo900;oo`2a
0_oo^`000ooo03?ooo]ZoookJP07oookJP03ool0Pooonf[ooo]Z00;o0?nH0_oonfX00ooPo`3ooo]Z
oookJP05oookJP05ooX0oooonf[ooo]ZoookJ_ooo`001_ooN@000ooonf[oo`3:oomi0008oomi00?o
oo]Z0_l7o`02oookJP;o0?n71?oonfX00oooeP3ooo]ZoookJP04oookJP;o0?mM00Cooo]Zo`3oIol0
ofOo00So2?oUo`0<oookJP03onGo0?oonf[ooo]Z00Sooo]Z00?oU@3ooookJ_oonfX03OoonfX2o`2g
oegooo]Z0_mAo`12oookJP;oobH05_oonfX2oone00kooo]Z0_n`0?l;oookJP;o0:co0_oonfX2ool0
MQCooo]Z0_lJo`001?oonf[ooh<0oon30?ooP`02obco0004o`3o`Ol0B?oo04Soo`18o`Oooo]Z1?oo
0;<6o`1Loa3ooo]Z00?oo`1foookJ_oonfX01?oonfX3o`000003ol<0oooonf[ooo]Z00_ooo]Z00Go
oi00oookJ_oo08_ooo]Zog;o0002oookJP09o`3Ooooo0;_o^@3ooookJ_oolP3oQ_l0ool0m?oonf[o
o`2Z00;ooo]Z00[oQ_l0oookJ_oonf[ooo]Zo`01oooonf[o;`3oooo00?lco`3oC`3o0_oonfX00ooo
O`3ooo]Zo`80o`02oookJP0:o`d0oomYo`3oVP3oool0cooonf[o0?o=ool0Q_oonf[oP03ook;o00Co
oo]Z00?ooed0o`0/oooonfX00_oonfX01Ol0nooooo]Zooon0?m^o`3olP3o00;oo`0k0_oonfX2ool0
/@;ook/000?oo`0coookJ_oonfX01ooonfX2ool0P`;ooo]Z00Go0?nHoookJ_oonf[ooo]Zon3o0006
oookJP05ooX0oooonf[ooo]ZoookJ_ooo`000ooonfX2ocT0o`;ooo]Z00?oo`3:oookJ_oonfX01?oo
nfX00onB0?ooWol0oioo0003oookJP;o1ol00_oonfX2o`3oQ`Cooo]Z00?oomH0oookJ_oonfX01Ooo
nfX2o`3oG@;o0?mW00Go00SooookJ_oonf[o0?oCo`19o`0AoookJP03oomc0?oonf[ooo]Z00Oooo]Z
00?oU@3ooookJ_oonfX03_oonfX2o`2gobcooo]Z000boookJP;oDOl0@_oonfX5onGo01?ooo]Z0_oo
]@0>oookJP;o/03o2_oonfX3o`2/o`04oookJ_oo07Koo`1fool0MQCooo]Z0_lJo`03oon30004obco
0?l0ol7o0?o1o`3o`@;o04So1OooN@02oolX00;oo`2c00?oobP0o`1Lool0G?l00_l0G?l2oolX00Go
o`000oooN@07oolX00Goo`0000?oobP0ool00?oo00000_oo00000ooo:03oo`00ool00002ool000Co
obP03?oo0009oolX00Soo`000_oonfX01ol00Ooo;`3oobl0oooo`03oC`3oo`3oY_oo:0000_ooO`00
1ol20?oooo]ZoookJ_mSo`3o7Ol0ofWo0?oo8@000_l0old2ool0QP03oh00oonbo`3ooo]Z00?ooo]Z
00?ooed0oomi0?l0;?l00_oonfX02?l0nooooo]Zooon0?m^o`3olP3ooookJ_oo03_ooo]Z0_oob@00
0ooo0;7ooo]Zoonk0002ool0<`Sooo]Z0_oo08<2oookJP03o`3oV?lVo`3ooo]Z00;oh?l01_oonfX2
ooX0o`;ooo]Z00?oogT0oooo0?ooN@004?ooN@03oookJP05o`Oo0?oonf[ooo]Zo`0;ool0ohL01?oo
nfX2oooF00Kooo]Z00Co0?mMoookJ_oonf[o0?mW0_l02?l00ooonf[oiOl0onGo0005onGo00_ooo]Z
00?oog<0onGo0?oonfX02?oonfX2oiD0o`kooo]Z0_l0]omMoookJP;oDOl0@_oonfX2oolV01Oooo]Z
00?ookD0oookJ_oonfX03?oonfX2ok00o`[ooo]Z0ol0[?l01?oonf[oo`1fool0M_oo07HDoookJP;o
6_l00oooP`02obco00;o0?o10_l0B?l8oookJP;oo`2c1?l0G?lGoookJP03ool0M_oonf[ooo]Z00?o
oo]Z0_l000000oo30?oo0000oookJP0;oookJP03oon@0?oonf[oo`2;00;oL_l00_oonfX02Ol0gooo
o`2kokT0oooonf[ooo80ohKo0?oo0?Cooo]Zool0ZP02oookJP0:ohKo0?oonf[ooo]ZoookJ_l00Ooo
oo]Zobl0oooo`03o0?nVodl0o`;ooo]Z00?oogl0oookJ_l20?l00_oonfX01?l=0?ooJOl0oiX0oooo
0<l2o`3oc@04ool0Q_oonf[oP03ook;o00Cooo]Z00Cooed0o`0/oooonf[ooo]Z0_l0nol01Ooo0:[o
K_l0ofko0?ob0?ooo`0k00?ooo]Z00?oo`2aoookJ_oo^`000_oo03<9oookJP03ool0Pooonf[ooo]Z
00;o0?nH0_oonfX2on3o00Gooo]Z0_oj0?l2oookJP03ool0]oooo`3ooo]Z00;ooo]Z00?o>@3ooook
J_oonfX00_oo0<X5oookJP;oTP3o00?oWol0oookJ_oonfX00_oonfX01_l7o`3ooo]ZoookJ_oonf[o
0?n7o`0;o`?ooo]Z0_ooeP06oookJP;o0?mM00Gooo]Zo`3oIol02?oo00SooookJP02o`3oda7ooo]Z
0_ooL`08oookJP;oU@3o3ooonfX2o`2gobkooo]Z000`oookJP;oDOl0@_oonfX00ooo9P3oiOl0onGo
000EoookJP;ookD03_oonfX2ok00o`[ooo]Z0_l0[?l2oookJP;oo`1f5OoonfX01?lJo`3ooh<0oon3
0?ooP`02obco00;o0?o10ol0B?l7oomi00;oo`2c0ol0G?l2oolX0004ool00?oo:03oobP0oolX00Co
o`001OooN@06oolX00Woo`000ooo:004ool000;oobP03Ooo0009oolX00Ooo`000_oonfX01Ol00Ooo
;`3oo`1loooo:03oC`3o00;oobP000?oogl0ool0S?l20?l00_oonfX2oago0005ofWo0?oo8@3o0?o=
oookJ_oo08H00_n00?l01?nbo`3ooo]ZoookJ_oonfX2oomM0006oookJ_l0;?oooo]Zo`3kooooN@3o
ooh00_m^o`000oob0?ooo`0kool0>`02oookJP;oo`2a0_oo^`000ooo03?ooo]ZoookJP07oookJP05
ool0Pooonf[ooo]ZoookJ_l0oiP00_oonfX00ooPo`3ooo]ZoookJP05oookJP04ooX0oooonf[oogT0
oomi00;oool04OooN@02oookJP;o1ol000Cooo]Zo`0;ool0ohOo0?n71?oonfX00oooeP3ooo]Zoook
JP04oookJP;o0?mM00Gooo]Zo`3oIol0ofOo00SooookJP02onGo0003o`19oooUo`3oiOl000?oiOl0
2ooonfX00oooL`3ooo]ZoookJP08oookJP03oiD0oooonf[ooo]Z00gooo]Z00?o0;OooookJ_oonfX0
FooonfX2oe7o04;ooo]Z0_oo9P0GoookJP;ookD03OoonfX2ok00o`[ooo]Z0_l0[?l2oookJP;oo`1f
5OoonfX2oa[o00;ooh<00_l/o`02o`3o`@?o04So1ooonfX2ool0/`?o05co0_ooG008oookJP_o__l0
1_oonfX00ooo07Kooo]ZoookJP03oookJP;o000000?o``3oo`000?oonfX02_oonfX04?ooT03oo`2;
ool0Rombo`3ooo]Zool09_oonf[o0=ooool0^oni0?oooo]Zooob0?n6o`3oo`3doookJ_oo0:X2oook
JP0=ohKo0?oonf[ooo]ZoookJ_l00Ooo07coobl0oooonf[o0?nVodl0oooonf[oo`2<oomo0002o`80
o`09oookJ_l=0?oo7Ol0ofWo0?nJ0?ooo`3?o`3ocOoo08Kooo]Z00;oP03o00Co/_l0oookJ_oonf[o
oo]Z0_ooG@001Ol0;?oooo]ZoookJ_l0nooooo]Z00;oK_l00_ob0?l00ooo03_ooo]ZoookJP02ool0
/@;ook/000?oo`0coookJ_oonfX02?oonfX01?oo08?ooo]ZoookJ_l0oiP3oookJP03on3o0?oonf[o
oo]Z00Cooo]Z00ConP3ooookJ_oonf[ooo]Z0_ooo`03oookJP04ocT0oooonf[ooo]Zool0bPKooo]Z
00?oTP3ooioo0?nOo`000ooonfX2o`Oo00;ooo]Z0_l0ohL4oookJP03oooF0?oonf[ooo]Z00Gooo]Z
00Go0?mMoookJ_l0ofOo0?mWo`08o`02oookJP03o`3odol0BOoooo]Z013ooo]Z00?oog<0oookJ_oo
nfX01ooonfX00onE0?oooo]ZoookJP0>oookJP03o`2goooonf[ooo]Z02kooo]Z000XoookJPGo001o
00?ooo]Zoe7o0?mAo`000_oonfX5o`00Oc_ooo]Z0_oo9P000ol007oooo]ZoookJP02oookJPGo001o
3?oonfX2oone00kooo]Z0_n`0?l9oookJP?o0:co00Cooo]Zool0M_oo07Koo`1f1ooonfX9o`00O`?o
oo]Z00?o001ooa[o0?lJo`000_ooP`02obco0003oookJ_l0ol7o04So00;o04So00?ooo]Zoomi0?oo
N@001_ooN@03o`1Lo`WoobP01Ooo00000oooN@3oobP0oolX0008oolX00Ooo`000_oo:006ool00003
oolX0?oo003oo`0000_oo`002Ooo:007ool000;oobP000Go007oobl0oooo`03o0?nVodl0o`02oolX
0003oomo0?l20?oooo]Z00;ooo]Z00Go7Ol0ofWo0?mYo`3oob40o`3oc@02ool0QP03oh00oooonf[o
/_l000?ooo]Z00Gooed0o`00Ool007oo02coo`00O`02oomi000=ooon0?m^o`3oogT0oo80oooo03_o
oo]Zo`00Ool0Coooo`2ao`00Oooo^`3ooo]Zool0<`08oookJP;oo`230_oonfX2o`3oV0;ooo]Z00?o
h?l0oookJ_oonfX01OoonfX01Ooj0?ooogT0oomi0?ooN@3oool000OoogT000?oo`3:oomi0?ooN@00
2?ooN@02oookJP05o`Oo0?oonf[ooo]Zo`0;ool0ohL00ooonfX00ol007ooomH0oooF0004oookJP;o
001o00Co0?mMo`00Ool007oo0?mW0_oob@000ooonf[oiOl0o`19o`03oookJP?oiOl02_oonfX2oomc
00Wooo]Z0_nE0?l>oookJP;o0;Oo1?oonfX5o`00O`Gooo]Z1Ol007m4oookJPGo001o00?ooo]Zoe7o
0?oonfX00_oonfX5o`00Oc[ooo]Z0_oo9P000ol007oooo]ZoookJP02oookJPGo001o3OoonfX2oone
00gooo]Z0_n`0?l9oookJP?o0:co00Cooo]Zool0M_oo07Koo`1f1ooonfX9o`00O`?ooo]Z00Co001o
oa[o0?lJo`3o6_l00_ooP`000ol/o`3ooo]Zo`3o`@03o`18o`Kooo]Z1?oo0;<2o`1Lo`;ooe`000?o
obh0oookJ_oonfX01OoonfX3okko00Gooo]Z1?mao`02oookJP?o__l01?oonfX00ooo07Kooo]Zoook
JP02oookJP;o000000?o``3oo`000?oonfX02OoonfX01_ooT03oo`2;oookJ_mbo`3ooo]Zool09P;o
oo]Z00Koo`2kokT0oooonf[ooo80ohKo0?oonfX2ool0ZP03oookJ_n6o`3oQ_l000?ooo]Z00[o007o
obl0ool_0?oooo]Zo`3oY_m?0?oooo]Zool0S?ooO`3o0P3o0_oonfX02_lMo`3oJOl0ofWo0?nJ0?oo
oo]Zo`3ocOoo08Kooo]Zoh00oonbo`04oookJP03oomM0?l007oo02co00;o001o00Go0?_oool0Z_m^
o`3o001ooo80o`02ool0>`07oookJ_l007ooo`2ao`00Oooo^`3o001oool0<`09oookJP;oo`2300?o
oo]Zo`3oV?l0oiP00ooonfX00ooPo`3ooo]ZoookJP04oookJP05ooX0oooonf[ooo]Zool0]oooo`00
0ooonfX2ocT0o`;ooo]Z00?oo`3:oookJ_oonfX01?oonfX00onB0?ooWol0oookJP03oookJP05o`Oo
0?oonf[ooo]ZoookJ_l0ohL00ooonfX00ol007ooomH0oooF0004oookJP;o001o0_l0oed01Ol007oo
0?mWo`08ool02?oooo]Z00;o0?oC4OoonfX2oomc00Sooo]Z0_nE0?l?oookJP;o0;Oo1?oonfX5o`00
O`Gooo]Z1Ol007lNoookJP009ooonfX6o`00O`04oe7o0?oonf[ooo]ZoookJPOo001o>?oonfX2oolV
00?o001o0ooonfX7o`00O`Wooo]Z0_oo]@0>oookJP;o/03o2OoonfX2o`2/o`;ooo]Z0_oo07H:oook
JPWo001o0_oonfX2oa[o00;ooh<000?o;?l0o`00Ool007l00ol0B?l3oookJPOoogT00_l0G?l2oomi
00OoobP000?o__l0ool00?oo00001Ooo000;oolX00Coo`0000?oobP0ool00?oo:0001ooo00000ooo
:03oo`00ool0000<ool000WoobP01ooo00002_oo:03o007oobl0oooo`03o0?nVodl0oooo:03oo`2<
oomo0?l20?l2oookJP;o7Ol000GoJOl0oolQ0?l0olgo0?o=ool0QP02oh00o`03oookJ_nbo`3ooo]Z
00;ooo]Z00?ooed0oookJ_l007l00oooN@000ooooP3oK_l0ofko0002oo80o`07ool0>ooonf[o001o
o`1?oooo0;7o001ooonk0002ool0<`Sooo]Z00Goo`23oookJ_oonf[ooo]Zo`3oV002oookJP;oh?l0
1_oonfX2ooX0o`04oookJ_ooN@3oool0oooo00OoogT00ooonfX9oomi00;o1ol000Cooo]Zo`0;ool0
ohOo0?n71?oonfX00oooeP3o001oo`00O`03oookJP04o`00Ool0oego0?mMo`00O`;o0?mW0_oob@02
onGo00Kooo]Z00?oiOl0oookJ_oonfX01ooonfX2oomc00[ooo]Z00?oU@3ooookJ_oonfX03OoonfX0
0ol0]ooooo]ZoookJP03oookJPOo001o0ooonfX7o`00Od;ooo]Z1Ol007l2oe7o00?ooo]Z1ol007lg
oookJP;oobH00ol007l3oookJPOo001o2_oonfX2oone00gooo]Z0_n`0?l9oookJP;o0:co0_oonfX2
ool0MP[ooo]Z2Ol007l2oookJP;o6_l000?o;?l0oon30?ooP`000_l007l00ol0ol7o04Soo`18o`06
oookJP?oo`2c0_oonfX2o`1Lo`03oomL0?oo;P3ooo]Z00Kooo]Z0onno`000ooonf[oLOl0og7o0005
og7o00Wooo]Z0_nno`02oookJP03ool0M_oonf[ooo]Z00;ooo]Z00?o0000ol<0ool000000_l00008
oookJP06oon@0?oo08_ooo]ZoookJ_mbo`3oo`0V0_oonfX01ooo0;_o^@3ooookJ_oolP3oQ_l0oook
J_oo0:X00_oonfX00on6o`3ooo]ZoookJP02oookJP0:o`01ool_0?oool00oookJ_l0ojKoC`3ooook
J_oo08coogl0o`80o`;ooo]Z00Co7Ol0ofWo0?nJ0?ooob400_l0old01?oonf[oP03ooh00oonbo`04
oookJP04oomM0?oonf[o02coo`00O`;o0?_o0_m^o`02oo80o`07ool0>ooonf[ooo]Zo`00Oooo0;7o
001ooonk0002ool0<`03o`00Oooonf[ooo]Z00Kooo]Z00Coo`23oookJ_oonf[o0?nH0ooonfX2on3o
00Gooo]Z0_oj0?l2oookJP;oool00ooonfX00oli0?oooo]ZoookJP02ool0bPGooo]Z0_nB0?l01?nO
o`3ooo]ZoookJ_oonfX2o`Oo00;ooo]Z0_l0ohL4oookJP03oooF0?l007oo001o00?ooo]Z0_l007l0
1_l0oego001oo`3oIol0ofOo00SooookJP;o0?oC00?o04WooookJ_oonfX03_oonfX2oomc00Wooo]Z
00?oU@3ooookJ_oonfX03_oonfX00ol0]ooooo]ZoookJP03oookJPOo001o0ooonfX7o`00Oagooo]Z
000WoookJP?o001o00?ooo]Zoe7o0?mAo`000_l007l2oookJP?o001o00Cooo]Zo`00Ool007oo001o
=_oonfX2oolV00;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX2oone00ko
oo]Z0_n`0?l9oookJP;o0:co0_oonfX2ool0MPcooo]Z1?l007l5oookJP07oa[o0?ooP`3ooh<0oon3
0?l007oooo]Zo`00O`02o`18o`Gooo]Z1OooN@03o`1Lo`GoogT00_oo:004okko00Soo`002ooo:004
ool00003oolX0?oo003oo`0000Ooo`000ooo:00>ool000SoobP01Ooo00001?oo:03o007oobl0oooo
`002odl0o`04oolX0?oo08coogl0o`80o`;ooo]Z00Wo7Ol0oiX0oomYo`3oob40o`3ocOoonf[oo`26
oh00oooonfX00_nbo`02oookJP03ob?o0?ooG@3ooo]Z00CoogT000Koooh0ofko0?ooN@3olP3ooomi
0?oo03/2oookJP;oo`2a0_oo^`000ooo03?o001oo`00O`06oookJP;oo`230_oonfX2o`3oV0;ooo]Z
00?oh?l0oookJ_oonfX01OoonfX01Ooj0?oooo]ZoookJ_oo0;Ooool000SoogT01?oonfX8oomi0005
o`Oo0?oonf[ooo]Zo`0;ool0ohL01?oonfX2oooF00?o001o0ooonfX01?l0oegoolT0ooo90?l0ofL3
ooo90003onGo0?l0BOoooo]Z00oooo]Z00?oog<0oookJ_oonfX02?oonfX2oiD0o`kooo]Z0_l0]ol6
oookJP?o001o0_oonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007m2oookJP?o001o0_mA
o`03o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007leoookJP;oobH00_oonfX3o`00O`?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP;ookD03OoonfX2ok00o`Wooo]Z0_l0[?l2oookJP;o
o`1f3?oonfX4o`00O`Gooo]Z0_lJo`03oon30003oookJ_l007oo0?o100;o04So1_oonfX2ool0/`;o
oo]Z0ol0G?l00ooo;P3ooo]ZoookJP04oookJPCo__l01?mao`0BoookJP03okko0?oonf[ooo]Z00Co
oo]Z00Co0000ol<0ool0003o00002OoonfX01OooT03oo`2;oookJ_mbo`3oo`0V00;ooo]Z00Ooo`2k
okT0oooonf[ooo80ohKo0?oonf[oo`2Z00;ooo]Z00?oQ_l0oookJ_oonfX00_oonfX01?l00Ooo;`3o
ooo00?l0ojH2odl0o`03oookJ_oo08coogl000;ooo]Z0_lMo`001omYo`3oVP3oo`3o^?l0olgoo`26
oookJ_n00?l00_nbo`03oookJP;ooed00_l0;?l02?l007oo0?_oool0Z_m^o`3ooo]Zoo80oooonf[o
o`0k0_oonfX2ool0/@;ook/000Coo`0co`00Ool007oo001o1_oonfX2ool0P`03oookJ_l0oiSo0?nH
00;ooo]Z0_oPo`06oookJP05ooX0oooonf[ooo]ZoookJ_ooo`000ooonfX2ocT0o`;ooo]Z00?oo`3:
oookJ_oonfX01?oonfX00onB0?ooWol0oookJP03oookJP05o`Oo0?oonf[ooo]ZoookJ_l0ohL01?oo
nfX2oooF00?o001o0ooonfX2o`3oG@06o`00Ool0ofOo00Soo`08ool007oo0?oC0_l0BOl@oookJP03
oomc0?oonf[ooo]Z00Oooo]Z0_nE0?l?oookJP;o0;Oo1_oonfX3o`00O`;ooo]Z0ol007l2oookJP?o
001o00Cooo]Zo`00Ool007oo001o7OoonfX001[ooo]Z2_l007l2oookJP?o001o00?ooo]Zoe7o0?oo
nfX00ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o:?oonfX:o`00O`03oookJ_oo9P3oobH0
00So001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Cooo]Z0_oo]@0>oookJP;o/03o2OoonfX2
o`2/o`;ooo]Z0_oo07H2oookJP[o001o0ooonfX4o`00O`;ooo]Z00Co6_l0oon30?ooP`3o;?l00_l0
07l00ooonf[o04Soo`18o`03o`00O`;ooo]Z1OooN@02o`1Lo`CoogT02?oo:0000omao`3oo`00ool0
0005ool000koobP03Ooo0003oolX0003oookJ_oo003oo`0000coo`001?oo:0001?oo003oobP0oolX
0?oo:003ool000;o007o00?o;`3oooo00?m?0?l00_oo:002oomo0008oolX0?oonf[o7Ol0oago0?nJ
0?ooJOl0oolQ0?l0old2ool0QP03oh00oooonf[o/_l000?ooo]Z00?o8ol0oomM0?ooN@001?ooN@00
1OoooP3oK_l0oo80ooob0?ooogT000?ooo]Z00?oo`2ao`00Oooo^`000_oo03<01?oonf[o001oo`00
Ool007l4oookJP03ool0Pooonf[ooo]Z00;o0?nH0_oonfX2on3o00Kooo]Z0_oj0?l01?oonf[oo`2g
oooo0?ooo`02oookJPKoogT01?oonfX8oomi0003o`Oo0?oonf[o00_o00;o0?n70_oonfX00ol007oo
omH0oooF0006o`00O`?oolT00_l0ofL3ooo90003onGo0?l007oooo]Z00kooo]Z0_ooL`09oookJP;o
U@3o3_oonfX2o`2go`Oooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
OcCooo]Z2_l007l2oookJP?o001o00?oDOl0oookJ_oonfX00ol007l01?oonf[o001oo`00Ool007l3
oookJP?o001o9ooonfX:o`00O`03oookJ_oo9P3oobH000So001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`Gooo]Z0_oo]@0=oookJP;o/03o2OoonfX2o`2/o`?ooo]Z00?oo`1foookJ_oonfX02_l0
07l3oookJPCo001o0_oonfX01?lJo`3ooh<0oon30?ooP`02o`00O`04oookJ_l0ol7o04Soo`18o`;o
001o1?oonfX2ool0/`05oookJ_l0G?oo05coo`1LooooG0001_oonfX3okko0004oookJ_mao`3oLOl0
og7o00;o00Ko2?oonfX2o`3oeA7ooo]Z00Co0000ol<0ool0003o00002?oonfX01OooT03oo`2;oook
J_mbo`3oo`0V00;ooo]Z00Coo`2koookJ_oonf[ooo800_oonfX01?oo0:[ooo]ZoookJ_n6o`03oook
JP;o007o00Ko;`3oooo00?m?0?ooC`3ooookJ_oo08`2oomo0006oookJ_lMo`3o7Ol0o`d0oomYo`3o
ob400_l0old01?oo08Kooo]Zoh00oonbo`04oookJP03oomM0?oonf[o02co00;ooo]Z00Oo0?_oool0
Z_m^o`3o001ooo80oooonf[oo`0k00;ooo]Z00?oo`2ao`00Oooo^`000_oo03<2oookJP?o001o0ooo
nfX2ool0P`03oookJ_l0oiSo0?nH00?ooo]Z00?oh?l0oookJ_oonfX01?oonfX2ooX0o`;ooo]Z0_oo
o`03oookJP03ocT0oooonf[ooo]Z00;oo`3:1OoonfX2oi80o`03oioo0?oonf[ooo]Z00;ooo]Z00?o
1ol0oookJ_oonfX00_l0ohL2oookJP03o`00OoooeP3oomH000Ko001o00?ooo]Zo`3oGOl007l00_l0
ofL01Ol02?oooo]Zo`3odol0om?o04Wo013ooo]Z0_ooL`09oookJP03oiD0oooonf[ooo]Z00gooo]Z
0_l0]ol7oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007lLoookJP00
6_oonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00ObSo
oo]Z2Ol007l2oolV0003oookJ_l007oo001o00Oo001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`?ooo]Z00?ookD0oookJ_oonfX03?oonfX2ok00o`Wooo]Z0_l0[?l3oookJP03ool0M_oonf[ooo]Z
00;ooo]Z2_l007l4oookJP?o001o00Ko6_l0oon30?ooP`3o;?l0oookJ_l007l3o`18o`;ooo]Z0ol0
07l01?oonf[oogT0oomi0?ooN@03o`1Lo`04oomi0?oo:03oobP0oolX00?ooo]Z00?o__l0oolX0?oo
:0000ooo:008ool000ooobP03_oo0002oolX0003oookJ_oo:03oo`0000?oobP02_oo0008oolX0003
ool00?l00OooobP000;oobP000CoC`3ooolX0?oo:03oogl00ooo:0001olMo`3oobP0oolX0?mYo`3o
o`3?o`3ocOoo08H00_n00?l2ok;o00;ooo]Z0_lSo`000oooG@3oogT0oomi0002oomi0004ooon0?m^
o`3oK_l0oo80o`;oogT000Co001ooookJ_ooN@3oo`2a0_oo^`001?oo03?ooo]ZoookJ_oonfX3o`00
O`?ooo]Z00Koo`23oookJ_oonf[o0?nHobKo0?oonfX2on3o00Kooo]Z0_oj0?l2oookJP;oool00ooo
nfX6oomi00Cooo]Z00CoogT0oookJ_nOo`3ooo]Z0oooN@02o`Oo0003oookJ_l02ooo0?n700Cooo]Z
00?oomH0o`00Ool007l00ol007l5ooo90003o`3oIooob@3oolT000;oolT000?o04Woo`00Ool007l0
3OoonfX2oomc00[ooo]Z00?oU@3ooookJ_oonfX03OoonfX00ol0]ooooo]ZoookJP07oookJP?o001o
0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007ldoookJP[o001o0_oonfX3o`00O`?o
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o9ooonfX:o`00O`03oolV0?oonf[o001o
00So001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Cooo]Z00?ookD0oookJ_oonfX02ooonfX2
ok00o`[ooo]Z00Co0:cooookJ_oonf[ooo]Z0_oo07H3oookJP[o001o1?oonfX3o`00O`05oa[o0?oo
P`3ooh<0obco0?oonfX00_l007l3o`18o`04oookJ_l007oo001oo`00O`;ooo]Z0_oo0;<3o`1Lo`03
oomL0?oo;P3ooo]Z00Cooo]Z0onno`02oookJP;oLOl00ol01_l5oookJPGo0?oE1?oonfX6o`0Co`Wo
oo]Z1?l00007oookJP05oon@0?oonf[ooo]Zog;o0?oo02H00_oonfX01?oo0;_ooo]Zooob0?oolP05
oookJP05ohKo0?oonf[ooo]ZoookJ_l00Ol00_l_0?l01?oo`03oC`3ooc?o0?oonfX2oomo00;ooo]Z
00So7Ol0o`d0oonJ0?ooJOl0ool0col0olgoo`26oookJP;oP03o00Ko/_l0oookJ_oonf[ooo]Zob?o
0?ooG@02o`0/o`03oookJ_l0noooo`2Z00;oK_l00_ob0?l2ool0>`03o`00Ool0Coooo`2a00;ook/0
00?oo`0co`00OooonfX00_oonfX3o`00O`;ooo]Z00Goo`23oookJ_oonf[o0?nHobKo0002oookJP;o
h?l01_oonfX01Ooj0?oooo]ZoookJ_oonf[oool000Cooo]Z00Co>@3ooookJ_oonf[oo`3:1_oonfX0
0onB0?ooWol0oookJP03oookJP;o1ol00_oonfX00ol0ohOooo]ZoookJP02oookJP03oooF0?l007oo
001o00Go001o0_l0oed01_l007oo0?mWo`08ool02?oooo]Zo`3od`;o04Wo00?o001ooookJ_oonfX0
3?oonfX2oomc00Wooo]Z0_nE0?l?oookJP03o`2goooonf[ooo]Z00Oooo]Z0ol007l3oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00Oacooo]Z000VoookJPCo001o0_oonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007l_oookJP;oobH00ooonfX2o`00O`?ooo]Z0ol007l2oookJP?o
001o0ooonfX3o`00O`03oookJ_oo]@3ookD000gooo]Z0_n`0?l9oookJP;o0:co0ooonfX2ool0MQ?o
oo]Z0_ooN@02oon300;o;?l000Gooo]Zo`18ool0B?oo0?o1o`00O`03oookJP;o001o00?oo`2coomi
0?l0G?l00_l0G?l2oomL00Kooo]Z0_nno`07oolX00Goo`0000?o0?oEoolX0?oo:0001_oo:0000ooo
003oobP0oolX0003oolX01Coo`000ooo:00<ool000OoobP000Go007ooolX0?oo:03oobP0odl0o`02
oolX0006oomo0?oo:03oobP0oolX0?lMo`3oobP00_mYo`001_oo:03o0?o=ool0Q_n00?oooo]Zok;o
00?ooo]Z00?o8ol0oomM0?ooG@001?ooN@001?oooP3oK_l0oo80ooob0?l5oomi0005ool0/Ooo^`3o
001oool0<ol007l00ooonfX3o`00O`04oookJ_oo08?oo`23oookJP;o0?nH0_oonfX00ooPo`3ooo]Z
oookJP05oookJP05ooX0oooonf[ooo]Zool0]oooo`000ooonfX01?li0?ooogT0oookJ_oonfX3oomi
00?ooo]Z00CoTP3ooomi0?nOo`3oWol00_oonfX2oomi0005o`Oo0?oonf[oogT0oomi0?l0ohL00ooo
nfX2oooF00;o001o0_oonfX5ooo900;o0?mW1?oob@001?oonf[o001oo`00Ool007l<oookJP03oomc
0?oonf[ooo]Z00Sooo]Z0_nE0?l>oookJP;o0;Oo2_oonfX4o`00O`;ooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o@?oonfX4o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o;ooonfX2oolV00;ooo]Z0_l007l3oookJP?o001o0_oonfX3o`00O`?ooo]Z0ol007l2oook
JP;ookD03?oonfX2ok00o`[ooo]Z0_l0[?l2oookJP;oo`1f5?oonfX00olJo`3ooh<0oon30002obco
0005oookJ_l0B?oo04Soo`18ool0ol400ooonfX3o`00O`;oo`2c0_l0G?l2oomL00Kooo]Z0_nno`03
oookJP;oLOl000?o00Koo`3oF?l0oeP01?oonfX3o`3oe@Gooo]Z2?l0ojH2oookJP03o`0Coooonf[o
oo]Z00Kooo]Z1?l00006oookJP05oon@0?oonf[ooo]Zog;o0?oo02H00_oonfX00ooo0;_ooo]Zooob
0006oookJP09ohKo0?oonf[ooo]ZoookJ_l00Ooo;`3ooookJ_oo`03oC`3o00;ooo]Z00Koogl0o`80
oooonf[ooo]Zoago0?l=0?l2ofWo0007o`3o^?l0olgoo`26oookJ_n00?oooo]Zok;o0003oookJP;o
oed000[o02cooookJ_oonf[o0?_oool0Z_m^o`3ooo]Zoo80oooonf[oo`0k0_l007l01Ol0Coooo`2a
oonk0?oonf[oo`0c00;o001o0ooonfX3o`00O`;oo`2300?ooo]Zo`3oV?l0oiP00_oonfX2on3o00Ko
oo]Z0_oj0?l2oookJP03ool0]oooo`3ooo]Z00;ooo]Z0_li0?l2oookJP03ool0b_oonf[ooo]Z00?o
oo]Z0_nB0?l00onOo`3ooo]ZoookJP02oookJP05o`Oo0?oonf[ooo]Zo`0;ool0ohL00ooonfX2oooF
00;o001o0ooonfX01?l007oo0?mMo`3oGOoonfX2o`3oI`05o`08ool007oo0?oCo`3odol0BOl00ol0
07l=oookJP03oomc0?oonf[ooo]Z00Sooo]Z00?oU@3ooookJ_oonfX03OoonfX2o`2go`[ooo]Z1?l0
07l2oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00Oacooo]Z000VoookJPSo001o0_oo
nfX3o`00O`?ooo]Z0ol007l]oookJP;oobH01_oonfX2o`00O`;ooo]Z0ol007l2oookJP?o001o0ooo
nfX2o`00O`;ookD03OoonfX2ok00o`Wooo]Z0_l0[?l3oookJP;oo`1f5?oonfX00oooN@3ooh<0oon3
0002obco0004o`00Ool0B?oo04Soo`3o`@?o001o0ooonfX01?oo0;?o05coo`1Lool0G?l2oomL00?o
oo]Z0_ooN@001Ooonf[o__l0okko0?nno`3ooo]Z00SoobP00_oo0003o`3oe@?oogT00_oo:0000ol0
ojKoo`00ool00002ool000CoobP00_oo0002oolX013oo`000_oo:0000ooob@3oo`00ool0000<ool0
00CoobP00_l00Ol2oolX0003o`3oY_m?0?ooobP000GoobP000Co7Ol0ofWo0?mYo`3oobP00_l0old0
1?oo08KoP03ooookJ_nbo`03oookJP03ob?o0?ooG@3o02co00;ooo]Z0_ooN@000ooooP3oK_l0oo80
o`05oomi0003ool0/Ooo^`3ook/000;oo`0c0_l007l3oookJP?o001o00Koo`23oookJ_oonf[o0?nH
obKo0?oonfX2on3o00Kooo]Z0_oj0?l2oookJP;oool00ooonfX00oli0?oooo]Zoomi0002oomi0003
oookJ_ooN@3ooo]Z00;ooo]Z00?oTP3ooookJ_nOo`001?oonfX2o`Oo00;oogT00_l0ohL3oookJP04
oooF0?oonf[ooo]ZoookJP;o001o00?ooo]Zooo90?oob@000_oob@000ol0ofOoolT0ooo90003ooo9
00;ooo]Z0ol007l:oookJP;oog<02_oonfX00onE0?oooo]ZoookJP0=oookJP03o`2goooonf[ooo]Z
00[ooo]Z2?l007l2oookJP?o001o0ooonfX3o`00Od3ooo]Z2?l007l2oookJP?o001o0ooonfX3o`00
Obgooo]Z0_oo9P05oookJP;o001o0_oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o0_oo]@0<oook
JP;o/03o2_oonfX2o`2/o`?ooo]Z00?oo`1foookJ_oonfX04_oonfX00olJo`3ooh<0oon30002obco
0003o`00Ool0B?oo04So00;o0?o10_l007l3oookJP03o`00Oooo0;?o05co00;o05co0_ooG005oook
JP?o__l00ooonfX2og7o0003o`06ool0oeSo0?mH00?ooo]Z0ol0omD4oookJP;o0:Co0_l0ojH00ol0
Y?oooo]ZoookJP0@oookJPCo00001OoonfX01?ooT03ooo]ZoookJ_mbo`03oookJP03ool0^ooonf[o
oo8000Kooo]Z00WoQ_l0oookJ_oonf[ooo]Zo`01ool_0?oool00o`3oY_m?0?l00_oonfX01OooO`3o
0P3ooookJ_oonf[o7Ol000;oJOl000Soo`3?o`3ocOl0olgoo`26oookJ_n00?oooo]Zok;o00?ooo]Z
00?ooed0oookJ_l0;?l00_oonfX2ool0ZP03ofko0?oonf[olP3o00;oo`0k0_oonfX00ooo0;7ook/0
oonk0002ool0<`?o001o0ooonfX2o`00O`05ool0Pooonf[ooo]Zo`3oV?lVo`000_oonfX00ooPo`3o
oo]ZoookJP05oookJP04ooX0oooonf[ooo]ZoookJP;oool00ooonfX00oli0?oooo]ZoookJP02ool0
bPCooo]Z0_nB0?l00onOo`3ooo]ZoookJP02oookJP;o1ol00_oonfX2o`3oQ`?ooo]Z00CoomH0oook
J_oonf[ooo]Z0_l007l2oookJP04o`3oGOl007oo001oo`3oI`;o00So00Go001oo`3odol0BOoo04Wo
oookJP03o`00O`_ooo]Z0_ooL`09oookJP;oU@3o3ooonfX00ol0]ooooo]ZoookJP0:oookJPSo001o
0_oonfX3o`00O`?ooo]Z0ol007lLoookJP009_oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007l3oookJP?o001o:ooonfX2oolV00Sooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJP?o
001o0ooonfX2oone0003o`00Oooonf[ooo]Z00_ooo]Z00?o/03ooookJ_oonfX01ooonfX2o`2/o`?o
oo]Z0_oo07H=oookJP;oogT01OoonfX00olJo`3oogT0oon30003oomi00;o04So00?o0?o1o`00Oooo
N@000ol007l2oookJP;o05co00Co06;ooomL0?ooG03oobh00ooonfX3oomi0004okko0?oonf[ooo]Z
oookJPWoobP00_l0omD4oomi0004o`2Toooo:03o0?nVo`3oYPCoo`001Ooo:0001?oo003oobP0oolX
0?oo:00@ool00004oolX0?oob@3oolT0ooo900koo`000_oo:0001_l00OooobP0oolX0?oo:03o0?nV
odl0o`GoobP00_lMo`001omYo`3oobP0oolX0?l0olgoobP0ool0Q_n00?l00_nbo`02oookJP05ob?o
0?ooG@3ooed0o`0/oooonfX00_l0nol01?oooP3oK_l0oo80ooob0?l5oomi0005ool0/Ooo^`3oogT0
ool0<ooonfX00ol007l3oookJP04o`00Oooo08?oo`23oookJP;o0?nH0_oonfX00ooPo`3ooo]Zoook
JP04oookJP;onP3o0_oonfX00ooo0;Ooool0oookJP02oookJP;o>@3o1OooN@03oookJP;oTP3o0_nO
o`03oookJP03oomi0?l7o`3oogT000;oogT000Co0?n7oomi0?oonf[ooo]Z0_ooeP04oookJP;o001o
0_l0oed00ooob@3o0?mWo`3oI`06ooo900;ooo]Z0ol007l9oookJP03oomc0?oonf[ooo]Z00Sooo]Z
0_nE0?l>oookJP;o0;Oo3OoonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l3oookJP?o
001o@?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l3oookJP?o001o:ooonfX2oolV
00Oooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJP?o001o0ooonfX00ol007oookD0oone000=
oookJP03ok00oooonf[ooo]Z00Sooo]Z0_l0[?l3oookJP;oo`1f4ooonfX2oa[o0003oon30?oonf[o
;?l000;ooo]Z00Co04Soo`3o`Ol0ol7ooo]Z0ol007l3oookJP;o05co00?o06;ooomL0?ooG0001Ooo
nfX2okko00Cooo]Z0_mao`000ol01_oo0?mHo`3oF003oookJP;o0?oE1?oonfX2o`2To`?o0?nV1?oo
nfX4oong00gooo]Z1?l00005oookJP03oon@0?oonf[oL_l000?ooo]Z00?oo`2koookJ_oolP002_oo
nfX02Ol00Ooo;`3oooo00?l0ojKoC`3ooookJ_oo08coogl0o`80o`02oookJP09oago0?mYo`3oob40
ool0col0olgooo]Zool0Q_oonf[oP03o00;o/_l00_oonfX2oomM00;o02co00?ooo]Zo`3koooo0:X0
0_m^o`02oo80o`0:ool0>ooonf[ooo]Zo`1?oooo0;7ook/0o`00Oooo03?o001ooookJP?o001o0ooo
nfX2ool0P`03o`00Ool0oiSo0?nH00;ooo]Z0_oPo`06oookJP;onP3o0_oonfX00ooo0;Ooool0oook
JP02oookJP;o>@3o0_oonfX00ooo0<[ooo]ZoookJP03oookJP03oi80oonOo`3oWol000Cooo]Z00Go
1ol0oookJ_oonf[o00_oo`3oQ`03oookJP;oomH01?oonfX2o`00O`;o0?mM00Go001oo`3oIol0ofOo
00SooookJP02o`3od`04o`19oooonf[ooo]ZoookJP?o001o2_oonfX00oooL`3ooo]ZoookJP08oook
JP03oiD0oooonf[ooo]Z00gooo]Z0_l0]ol=oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`?ooo]Z0ol007lLoookJP009_oonfX3o`00O`Oooo]Z0ol007l3oookJP?o001o:OoonfX2oolV
00_ooo]Z0_l007l01?oonf[o001oo`00Ool007l2oookJP?o001o00?ooo]Zoone0?oo]@000ol007l;
oookJP;o/03o2OoonfX01?l0[?oooo]ZoookJ_oonfX2ool0MPkooo]Z0oooN@03oookJP;o6_l00_oo
P`02oomi00;o04So00?o0?o1o`00Ool007l00_ooN@03o`00O`;o05co00Co06;oooo90?ooG03oobh0
1?oonfX5oomi0003oookJ_mao`3oobP000OoobP00_l0omD2oolX00;oogT01?l0ojH00oooN@3oo`00
ool00002ool000_oobP02?oo00000ooo:03oo`00ool00003ool000KoolT02ooo0003oolX0006o`01
oooo:03oobP0oolX0?l0ojKoC`3o1Ooo:0000olMo`3oJOl0ofWo0002oolX0005o`3ocOoo08Koo`26
oh00oonbo`000ooonfX00olSo`3ooed0o`0/o`02oookJP05o`3koooonf[oooh0ofko0?ob0?l01Ooo
N@001ooo0;7ook/0oonk0?ooN@3oo`0co`00OooonfX00ol007l2oookJP;oo`230_l007l00ol0oiSo
oo]ZoookJP02on3o00Kooo]Z00ConP3ooookJ_oonf[ooo]Z0_ooo`001?oonf[oogT0oomi0?li0?l6
oomi00;ooo]Z0_nB0?l2oioo00;ooo]Z0_ooN@02ooo900;oogT00_l0ohL01?ooN@3ooo]ZoookJ_oo
eP07oookJP04o`3oGOl007oooo]Zo`3oI`OoolT00ooonfX3o`00O`Oooo]Z0_ooL`0:oookJP03oiD0
oooonf[ooo]Z00cooo]Z0_l0]ol?oookJP?o001o1ooonfX3o`00O`?ooo]Z0ol007m0oookJP?o001o
1ooonfX3o`00O`?ooo]Z0ol007lYoookJP;oobH02_oonfX2o`00O`04oookJ_l007oo001oo`00O`;o
oo]Z0ol007l2oookJP;ookD00_l007l;oookJP;o/03o2OoonfX2o`2/o`?ooo]Z0_oo07HCoookJP;o
6_l00_ooP`02obco0004oookJ_l0B?oo04Soo`3o`@;o001o00Gooo]Zo`00Ool007oo001ooookJP02
o`1Lo`03o`1RooooG03ooe`000Gooo]Z0_nno`03oookJP?oLOl00ol0oeP3oookJP;o0?oE1?oonfX0
1?l04ooo0?nVo`3oY_l0ojH2oookJPGookL01OoonfX6o`3o;PKooo]Z1?l00004oookJP03oon@0?oo
nf[oL_l000?ooo]Z00?oo`2koookJ_oolP002_oonfX02?l00Ooo;`3oooo00?l0ojKoC`3ooookJ_oo
08coogl00ooonfX01OlMo`3oJOl0oolQ0?oo0<oo0?o=00;oo`2600?ooo]Zoh00oonbo`000_oonfX0
1OlSo`3ooed0o`0/ool0;?oooo]Z00;o0?_o00Koo`2Zofko0?oonf[olP3oool0>ooonfX2o`00O`05
ool0/Ooo^`3ook/0oookJ_oo03<00_l007l01?oonf[o001oo`00Ool007l2oookJP06ool0Pol007oo
001oo`3oV?lVo`3ooo]Z0_oPo`07oookJP04ooX0oooonf[ooo]ZoookJP;oool00_oonfX2ocT0o`;o
oo]Z0_oo0<X4oookJP;oTP3o00?oWol0oookJ_oonfX00_oonfX2o`Oo00;ooo]Z0_l0ohL3oookJP03
oooF0?oonf[ooo]Z00Gooo]Z00Co0?mMo`00Oooonf[o0?mW0_l02?l2o`3od`;o04Wo00Co001ooook
J_oonf[ooo]Z0ol007l8oookJP;oog<02OoonfX2oiD0o`kooo]Z0_l0]ol?oookJP?o001o1ooonfX3
o`00O`?ooo]Z0ol007lLoookJP009_oonfX3o`00O`Oooo]Z0ol007l3oookJP?o001o9ooonfX2oolV
00kooo]Z1Ol007l2oookJP;o001o0_oo]@02oookJP?o001o2OoonfX2ok00o`Wooo]Z0_l0[?l3oook
JP03ool0M_oonf[ooo]Z00gooo]Z1OooN@02oa[o00;ooh<00oooN@001Ol0B?ooogT0oomi0?ooN@3o
001o00CoogT000Coo`2co`1Lool0H_oooo]Z0_oob@001Ooo;P3o001ooookJ_oonf[o__l000KoogT0
00?oLOl0oolX0?oo:0001?oo:003o`3oe@03oolX0?ooN@3oogT000;o0?nV0_oo:002oomi00Goo`00
1Ooo:0000ooo003oobP0oolX0005oolX00Soo`000_oo:0000ooo003oolT0ooo90007ooo900Soo`00
0ooo:002o`01o`?oobP00_m?0?l5oolX0003oago0?mYo`3oobP000;oobP000Go0?o=ool0Q_n00?oo
P03ook;o0002oookJP;o8ol000?ooed0o`0/oooonfX00_l0nol01?oooP3oK_l0oo80ooob0?l4oomi
00;oo`2a00Cook/0oomi0?ooN@3oo`0c0_l007l02?oonf[o001oo`00Ool007oooo]Zool0Pooonf[o
001o0_l0oiP2oookJP03on3o0?oonf[ooo]Z00Cooo]Z0_oob@02oookJP03ool0]oooo`3oogT000;o
ogT00_li0?l6oomi00;ooo]Z00CoTP3ooookJ_nOo`3ooo]Z0_ooN@04ooo900;oogT000Co0?n7oomi
0?ooN@3ooo]Z0_oob@06oookJP;o0?mM00?ooo]Zo`3oIol0ofL01ooob@001?l007oooo]ZoookJ_oo
nfX3o`00O`Gooo]Z0_ooL`0:oookJP;oU@3o3_oonfX00ol0]ooooo]ZoookJP0?oookJP?o001o1ooo
nfX3o`00O`?ooo]Z0ol007m0oookJP?o001o1ooonfX3o`00O`?ooo]Z0ol007lWoookJP;oobH03Ooo
nfX5o`00O`;ooo]Z0ol007l2oone0004oookJ_l007oo001oo`00O`Wooo]Z0_n`0?l:oookJP04o`2/
oooonf[ooo]ZoookJP;oo`1f5?oonfX00olJo`3ooh<0oon30002obco0003o`00Ool0B?oo04So00;o
oo]Z0ol007l02_oonf[o001oo`00Oooo0;?o05coo`1Roooonf[ooe`0ool^0?l007l3oookJP;o__l0
0ooonfX2og7o0003o`06ool0oeSo0?mH00Cooo]Z0_l0omD3oookJP04o`0Cool0ojKo0?nVo`3oYPCo
oo]Z00?ookL0oookJ_oonfX01?oonfX4o`3o;Pcooo]Z1?l00003oookJP03oon@0?oonf[oL_l000?o
oo]Z00?oo`2koookJ_oolP002OoonfX2o`01o`07obl0ool0ojKoC`3oodl0oooonf[oo`2<oomo0002
oookJP08o`d0oolMo`3oJOl0oolQ0?l0okSo0?o=ool0Q_oonfX2oh00o`06ok;o0?oonf[ooo]Zob?o
0?ooG@3o02co0_oonfX01?l0noooo`2Zofko0?m^o`02oo80o`03ool0>ooonf[ooo]Z00;oo`2a00Co
ok/0oookJ_oonf[oo`0c0ol007l01?oonf[o001oo`00Ool007l2ool0P`06oookJ_l0oiSo0?nHobKo
0?oonf[oh?l01ooonfX2ooX0o`;ooo]Z0_ooo`03oookJP03ocT0oooonf[ooo]Z00;oo`3:1?oonfX2
oi80o`03oioo0?oonf[ooo]Z00?ooo]Z00Go1ol0oookJ_oonf[o00_oo`3oQ`03oookJP;oomH01_oo
nfX2o`3oG@08oookJ_l0ofOo0?mWo`08ool007oo0?oCoookJ_l0BOl3o`00O`?ooo]Z0ol007l6oook
JP;oog<02_oonfX00onE0?oooo]ZoookJP0=oookJP03o`2goooonf[ooo]Z00oooo]Z0ol007l7oook
JP?o001o0ooonfX3o`00Oacooo]Z000WoookJP?o001o0_oonfX3o`00O`;ooo]Z0ol007l01?oonf[o
001oo`00Ool007lWoookJP03oolV0?oonf[ooo]Z00kooo]Z1Ol007l2oookJP;ookD00_l007l01?oo
nf[o001oo`00Ool007l8oookJP;o/03o2OoonfX2o`2/o`?ooo]Z0_oo07H?oookJPKoogT00_ooP`03
oomi00;o04So2OooN@000ol0G?oo001ooomL0004ooo90003oookJ_nno`3o__l000OoogT01Ooo:002
o`3oe@?ooo]Z00Co0:Coo`3oY_l0ojKoogT00ooo:0000ooonf[oo`00ool00002ool000KoobP000?o
o`00oolX0?oo:0001_oo:006ool00004oolX0?oo003oo`00oolX00WoolT00_oo:006ool000?oobP0
00Co007ooolX0?oo:03oobP00_m?0?l6oolX0004oago0?mYo`3oobP0oolX00;o0?o=0_n00?l01Ooo
nf[o/_l0oookJ_oonf[o8ol000;oobP00_oonfX01Ol0nooooo]Zooon0?m^o`3olP3o00GoogT000Co
o`2aoonk0?oo^`3oogT00_oo03<3o`00O`;ooo]Z00So001oool0Pooo08?ooo]Zo`00Ool0oiSo001o
oookJP;oh?l01?oonfX5ooo90003oookJ_ooo`3oool000?oogT000?o>@3ooomi0?ooN@001OooN@00
0ooonf[oTP3ooi80o`02oioo0003oookJ_oob@3oolT000CoolT01OooN@03ooo900Gooo]Z0_l0oed2
ooo90004o`3oIooob@3oolT0o`3od`GoolT00ol007l01?oonf[o001oo`00Ool007l5oookJP03oomc
0?oonf[ooo]Z00Sooo]Z0_nE0?l>oookJP;o0;Oo4ooonfX3o`00O`;ooo]Z0ol007l2oookJP?o001o
00Cooo]Zo`00Ool007oo001o@_oonfX3o`00O`;ooo]Z0ol007l2oookJP?o001o00Cooo]Zo`00Ool0
07oo001o9ooonfX00ooo9P3ooo]ZoookJP0=oookJPGo001o0ooonfX2oone0003o`00Oooonf[o001o
00;o001o2?oonfX2ok00o`[ooo]Z0_l0[?l2oookJP;oo`1f5?oonfX00olJo`3ooh<0oon30002obco
0003oookJ_l0ol7o04So00;o001o0_oonfX3o`00O`05oookJ_oo0;?o05coo`1Lool007l00_ooG002
o`00O`;ooo]Z0_nno`03oookJP;oLOl000?ooo]Zo`3oF?l0oeP01?oonfX2o`3oe@?ooo]Z00?o0:Co
o`3oY_l0ojH01OoonfX2oong00Gooo]Z0_l0obh@oookJPCo00000_oonfX00oooT03ooo]Zog;o0002
oookJP;oo`2k00?ooo]Zooob0?oonfX02?oonfX01ol00Ooo;`3oobl0ool0ojKoC`3ooookJ_oo08`0
0_ooO`02oookJP04o`d0oolMo`3oJOl0o`3o^0;o0?o=00Cooo]Zoh00oon00?oo/_l00_oonfX01OlS
o`3ooed0oomM0?l0;?oooo]Z00;o0?_o00Goo`2Zofko0?oo<03olP3oool0>`03oookJP04ool0/Ooo
^`3ook/0o`00O`;oo`0c00Cooo]Zo`00Ool007oo001o0_oonfX01ol007ooo`23o`00Oooonf[o0?nH
obKo0?l007l00_oPo`07oookJP05ooX0oooonf[ooo]ZoookJ_ooo`000ooonfX2ocT0o`;ooo]Z00?o
o`3:oookJ_oonfX00_oonfX2oi80o`;oWol01?oonfX2o`Oo00;ooo]Z0_l0ohL3oookJP03oooF0?oo
nf[ooo]Z00Cooo]Z0_l0oed2oookJP03o`3oIol02?oo00So00;o0?oC0_l0BOl2oookJP?o001o00Co
oo]Zo`00Ool007oo001o1_oonfX00oooL`3ooo]ZoookJP08oookJP;oU@3o3_oonfX2o`2goa?ooo]Z
0ol007l2oookJP?o001o0_oonfX3o`00O`04oookJ_l007oo001oo`00Oagooo]Z000WoookJPOo001o
0ooonfX7o`00ObGooo]Z0_oo9P0BoookJPCo001o0_oo]@000ooonf[o001oo`00O`05o`00O`Kooo]Z
0_n`0?l:oookJP04o`2/oooonf[ooo]ZoookJP;oo`1f4?oonfX5oomi00;ooh<00oooN@02o`18o`co
ogT000?ooe`0ooo90?oob@000ooob@000onno`3oogT0oomi0006oomi00CoobP00_l0omD2oomi0006
oookJ_l04ooo0?nVo`3oY_ooN@3ooo]Z1Ooo:003ool000KoobP000?oo`00oolX0?oo:0002?oo:006
ool00003oolX0?oo003oolT000SoolT01?oo:004ool000?oobP000?o007ooolX0?oo:0002Ooo:000
0olMo`3oJOl0oolX0002o`3oc@03oolX0?n00?ooobP000;o/_l000?ooo]ZoolX0?oo:0000ooo:002
o`3ko`05ool0Z_oooP3oK_l0oo80oooo03/00oooN@02ool0/@04oonk0?ooN@3oogT0ool0<`Co001o
0_oonfX2ool0P`;o001o00Go9_l0o`3oV?l007oo001oon3o0003oookJPOoolT00_ooo`000ooonf[o
ogT0oomi0002ocT0o`OoogT00_nB0?l00ooonf[oWol0ooo90007ooo900GoogT00ooob@05oookJP03
o`3oGOoonf[oolT000;o0?mW00?oolT0o`3odol0om<01Ooob@000ooonf[o001oo`00O`05o`00O`?o
oo]Z0_ooL`0:oookJP03oiD0oooonf[ooo]Z00gooo]Z00?o0;OooookJ_oonfX04ooonfX7o`00O`03
oookJ_oo0;[oo`2j00Oo001o@_oonfX7o`00O`?ooo]Z1ol007lUoookJP;oobH04OoonfX4o`00O`03
oookJ_oo]@3ookD000Oo001o1_oonfX2ok00o`[ooo]Z0_l0[?l3oookJP03ool0M_oonf[ooo]Z01;o
oo]Z00Oo6_l0oon30?ooP`3ooo]Zobco0?oonf[o0?o100;o04So1ol007l01?oo0;?o05coo`1Lool0
07l2oomL00Co001o0_nno`03oookJP;oLOl000?ooo]Zo`06ool0oeP01?oonfX2o`3oe@?ooo]Z00?o
0:Coo`3oY_l0ojH01?oonfX3oong00Cooo]Z0_l0obh2ooon00;ooo]Z0_oo=`0=oookJPCo000000Co
oo]Zoon@0?ooT03oL_l00_oonfX00ooo0;_ooo]ZoookJP09oookJP;o007o00Go;`3oo`3oY_m?0?oo
C`3ooookJP02oomo00;ooo]Z00Wo3@3ooago0?lMo`3oJOl0o`3o^?l0olgoo`26oookJ_n00?l00_nb
o`001_oonf[o8ol0oomM0?ooG@3o02cooookJP;o0?_o0_oo0:X01?m^o`3ooo]Zoo80oooo03/2oook
JP;oo`2a00Cook/0oookJ_l007ooo`0c1Ol007l2oookJP;oo`230_l007l01?l0oiSo9_l0o`00OooP
o`07oookJP;onP3o0_oonfX2oooo00;ooo]Z0_li0?l2oookJP;oo`3:1?oonfX00onB0?oooo]Zoioo
0005oookJP03o`Oo0?oonf[ooo]Z00;o0?n70ooonfX2oooF00Kooo]Z00?o0?mMoookJ_oonfX00_l0
ofL00ol02?oooo]Zo`3od`02o`19o`04o`00Oooonf[ooo]ZoookJPOo001o1?oonfX2oomc00[ooo]Z
00?oU@3ooookJ_oonfX03?oonfX2o`2goaGooo]Z1ol007l3ool0^POo001o7OoonfX002Wooo]Z1?l0
07l5oookJPGo001o9?oonfX2oolV01Gooo]Z00?o001ooone0?oo]@001?oonfX5o`00O`Kooo]Z00?o
/03ooookJ_oonfX02?oonfX2o`2/o`?ooo]Z00?oo`1foookJ_oonfX03ooonfX4oomi00;ooh<00ooo
N@02o`18o`ooogT01Ooob@07oomi0003o`3oF?oo:03oobP000;oogT000?o0?oEoomi0?ooN@000_oo
N@000ol04ooo0?nVoookJP02oookJPOoobP000?oo`00oolX0?oo:0001?oo:0000ooo003oobP0oolX
000:oolX00?oo`000ooo:002ool000SoolT000?oo`00oolX0?oo:0000_oo:004ool00003oolX0?l0
0OooobP000goobP000Co0?o=oolX0?oo:03oP03o0_nbo`07oolX0004o`3koooonf[oooh0ofko00;o
lP3o00Goo`0koookJ_oonf[oogT0ool0/@02oonk0003oomi0?oo03?oo`0c00Co001o0_oonfX01?oo
08?ooo]ZoookJ_lVo`02o`3oV0;o001o00?oh?l0oookJ_oob@002?oob@000oooo`3ooo]ZoookJP02
oookJP03ocT0ooooN@3oogT000KoogT000?oTP3ooookJ_oob@002Ooob@06oomi00;oolT01?oonfX2
o`3oG@06oookJ_l0ofOo0?mWo`08oooob@3o0?oC1_oob@03oookJPGo001o0ooonfX00oooL`3ooo]Z
oookJP08oookJP;oU@3o3_oonfX2o`2goaSooo]Z1?l007l2ool0^P?ooo]Z1Ol007m5oookJPCo001o
1OoonfX5o`00ObCooo]Z0_oo9P0DoookJP;o001o0_oo]@03oookJPGo001o1_oonfX00on`0?oooo]Z
oookJP08oookJP;o0:co0ooonfX2ool0MQ?ooo]Z0_lJo`001OooP`3ooo]Zobco0?l/o`3o0?o100;o
04So0ooonfX4o`00O`;oo`2c00Co05cooookJ_ooG03ooe`01Ol007l01?nno`3ooo]ZoookJ_oonfX2
og7o00;o00Ko0_l0oeP4oookJP05o`3oeOoonf[ooo]ZoookJ_l04ol00_l0ojH4oookJP;ookL01?oo
nfX3o`3o;P;oooh00_n6o`02oolg00Oooo]Z1ol0Yol00ooonf[o0000o`000002o`000003oookJ_oo
T03oL_l000;ooo]Z00?oo`2koookJ_oonfX02OoonfX01_l00Ooooo]Zobl0ool0ojKoC`3ooookJP;o
ogl000?o0P3ooookJ_oonfX00_lMo`02ofWo0003oookJ_l0olgooo]Z00;oP03o00Ko/_l0oookJ_oo
nf[o8ol0oomM0?l0;?l2oookJP03o`3koooonf[oo`2Z00;oK_l00_ob0?l3oookJP04ool0/Ooo^`3o
ok/0oookJP;oo`0c1Ol007l2oookJP03ool0Pooonf[ooo]Z00;o0?nH0_l007l00ooPo`3ooo]Zoook
JP04oookJP;onP3o0_oonfX2oooo00?ooo]Z00?o>@3ooookJ_oonfX00_oo0<X4oookJP;oTP3o0_nO
o`04oookJP;o1ol00_oonfX00ol0ohOooo]ZoookJP02oookJP03oooF0?oonf[ooo]Z00Cooo]Z0_l0
oed00ooonf[o0?mWo`3oI`02o`08o`;o0?oC00Co04Woo`00Ool007oo001o1?oonfX5o`00O`Cooo]Z
00?oog<0oookJ_oonfX02?oonfX2oiD0o`kooo]Z00?o0;OooookJ_oonfX05ooonfX3o`00O`;oo`2j
1?oonfX5o`00Oakooo]Z001JoookJP03oolV0?oonf[ooo]Z01Gooo]Z00?ookD0oookJ_oonfX03Ooo
nfX2ok00o`Wooo]Z0_l0[?l3oookJP;oo`1f4OoonfX3oomi00;ooh<00oooN@02o`18o`CoogT00ooo
nfX:oomi00CoolT01OooN@03o`3oF0;oogT000?ooo]Zo`3oeOl0omD01_ooN@03oookJPkoobP000?o
o`00oolX0?oo:0002?oo:002ool000?oogT000Coo`00oolX0?oo003oo`000ooUo`06ooo90003ool0
0?oo:03oobP000;oobP01?oo00000oooN@3oobP0oolX000=oolX0003o`3ocOoo:03oobP000[oobP0
00Wo0?_ooookJ_oooP3oK_l0oo80oooonf[oo`0koookJ_l0Col00_oo0;401Ooo^`3oogT0ool0<ooo
03?oogT000Gooo]Z0_oo08<01?oonf[o9_l0obKo0?l0oiP2oookJP;oh?l02Ooob@02oooo00?ooo]Z
0_li0?l7oomi00;oTP3o2ooob@06oomi00;oolT01?oonfX01?l0oegooo]ZoookJ_l0ofL2o`08o`03
o`3odooob@3oolT000GoolT02_oonfX2oomc00[ooo]Z00?oU@3ooookJ_oonfX03OoonfX00ol0]ooo
oo]ZoookJP0KoookJP03ool0^_oonf[ooo]Z00;oold0NooonfX2oolV01Oooo]Z00?ookD0oookJ_oo
nfX03?oonfX2ok00o`[ooo]Z00Co0:cooookJ_oonf[ooo]Z0_oo07HCoookJP;o6_l00_ooP`02obco
0003oookJ_l0B?oo04So00Oooo]Z0_oo0;<2o`1Lo`;ooe`01OoonfX2okko00;ooo]Z0_mao`02o`06
o`;o0?mH1?oonfX2o`3oe@?ooo]Z00?o0:Coo`3oY_oonfX00ooonfX2oong00?ooo]Z0_l0D_l01Ol0
obkoooh0ooon0?oooP3oQ_l000?oocL000Cooo]ZodWo0?m9o`3oBOl00_oonfX3o`2Wo`Kooo]Z0_l0
Yol4o`000003oon@0?oonf[oL_l000cooo]Z0_l00Ol02Ooonf[ool00odl0oom?0?oooo]Zoomo0?oo
08co0P3ooookJP02oago00;oJOl000?o0?nho`3ocOl0old00_n00?l01?nbo`3ooo]ZoookJ_oonfX2
oomM0007o`0/oooonf[o0?_oo`3koooonf[oo`2Zofko0002oo80o`03ool0>ooonf[ooo]Z00;oo`2a
00Cook/0oookJ_oo03?oo`0c1ooonfX2ool0P`03oookJ_lVo`3o0?nH00;ooo]Z0_oPo`06oookJP06
ooX0oooonf[ooo]ZoookJ_ooo`3oo`2g0_oonfX2ocT0o`;ooo]Z00?oo`3:oookJ_oonfX00_oonfX2
oi80o`03oookJ_nOo`3ooo]Z00?ooo]Z0_l7o`02oookJP;o0?n70ooonfX2oooF00Kooo]Z00Co0?mM
oookJ_oonf[o0?mW0_l02?l01?oonf[o0?oCo`19ool0BOl?oookJP;oog<02_oonfX00onE0?oooo]Z
oookJP0<oookJP;o0;Oo7?oonfX01?oo0;[ooo]ZoookJ_oonfX2ooo=02Cooo]Z001HoookJP;oobH0
5_oonfX2oone00kooo]Z0_n`0?l:oookJP04o`2/oooonf[ooo]ZoookJP;oo`1f4_oonfX2oomi00;o
oh<01?ooN@001?l0B?ooogT0oomi0?ooN@04oookJP03ool0/oooN@3oogT000[oogT00_oob@04oomi
00;o0?mH00CoogT0oookJ_oonf[ooo]Z0_l0omD9oomi0003oookJ_oo:03oobP000coobP000?oo`00
oolX0?oo:0002Ooo:004ool000;oobP000?oo`00onGo0?oUo`000_oUo`02oomi00GoolT000?oo`00
oolX0?oo:0000ooo0002oomi01goobP000?ooo]Zooon0?m^o`000_ob0?l2ool0>`;o04oo00Goo`2a
oookJ_oo^`3ooo]Zool0<`02oomi00Gooo]Z00Coo`23oookJ_oonf[o9_l00_l0oiP2oookJP03on3o
0?oob@3oolT000SoolT000Coool0oookJ_oonf[ooo]Z0_li0?l2oookJP03ool0b_ooN@3oogT000?o
ogT000?oTP3ooookJ_nOo`002_oob@06oomi00;oolT00ooonfX2o`3oG@04oookJ_l0ofOo0?mWo`08
o`;o0?oC1ooob@09oookJP;oog<02_oonfX2oiD0o`kooo]Z0_l0]olLoookJP;oo`2j0_oonfX00ooo
c@3ooo]ZoookJP1joookJP03oolV0?oonf[ooo]Z01Gooo]Z0_oo]@0=oookJP;o/03o2_oonfX2o`2/
o`;ooo]Z0_oo07HDoookJP03oa[o0?ooP`3ooh<000;o;?l000?ooo]Zo`18ool0B?l01ooonfX2ool0
/`;o05co0_ooG005oookJP;o__l00ooonfX00omao`3o00Koo`06o`02o`3oF0Cooo]Z0_l0omD2oook
JP;o0:Co0_l0ojH3oookJP;ookL00_oonfX3o`1Bo`;ooo]Z00?oooh0oookJ_n6o`000_oo=`03oook
JP03odWo0?ooXP3ooo]Z00;ooo]Z00?o0:OooookJ_oonfX02OoonfX3o`0000;ooi0000?oL_l0oook
J_oonfX02_oonfX01Ol00Ooooo]ZoookJ_oo`03oC`3o00;ooo]Z00Googl0oookJ_oonf[ooo]Zoago
0002ofWo0005ool0col0okSo0?o=ool0Q_n00?l00_nbo`03oookJP07oomM0?oonf[o02cooookJ_l0
nooooo]Zool0ZP02ofko000:oo80oooo03_oo`0koookJ_l0Coooo`2aoookJ_oo^`3ooo]Zool0<`So
oo]Z00?oo`23oookJ_oonfX00_l0oiP2oookJP03on3o0?oonf[ooo]Z00Cooo]Z0_oj0?l2oookJP;o
ool00_oonfX2ocT0o`;ooo]Z0_oo0<X4oookJP04oi80oooonf[oWol0oioo00Cooo]Z00?o1ol0oook
J_oonfX00_l0ohL3oookJP;oomH01_oonfX2o`3oG@05oookJ_l0ofOo0?mWo`08oooonfX00_l0om<0
0ol0BOoooo]ZoookJP0=oookJP;oog<02_oonfX2oiD0o`gooo]Z0_l0]olLoookJP;oo`2j0ooonfX0
0oooc@3ooo]ZoookJP0ToookJP00E_oonfX2oolV01Kooo]Z0_oo]@0>oookJP;o/03o2_oonfX2o`2/
o`;ooo]Z0_oo07HCoookJP;oogT000Gooh<0oomi0?ooN@3oogT0o`3o`@02o`18o`CoogT00_oonfX2
ool0/`[oogT01?oob@03oomi00;o0?mH00CoolT0oookJ_oonf[ooo]Z0_l0omD00ooonf[oogT0oomi
0008oomi00OoobP000?oooh0oolX0?oo:0001?oo:0000ooo003oobP0oolX0008oolX00Koo`000_oo
:004onGo00?oogT000GoobP0ooo90?oob@3oolT0ool00002oolX00;oo`0000?oogT0oolX0?oo:000
7Ooo:0002_oo0:[oooh0ofko0?ob0?oooo]Zool0>ooonf[o04oooookJ_oo0;42oonk00;oo`0c00?o
oo]Zoomi0?oonfX00ooonfX2ool0P`04oookJ_lVo`3o0?nHo`3oV0;ooo]Z0_oPo`000ooonf[oolT0
ooo90005ooo900?oogT00_oonfX2ocT0o`;ooo]Z0_oo0<X2oookJP;oogT00_nB0?l2oioo00;ooo]Z
2?oob@06oomi00;oolT00_oonfX2o`3oG@03oookJ_l0ofOo0?mW00;o00So00Co0?oCooo90?oob@3o
oo]Z1Ooob@09oookJP03oomc0?oonf[ooo]Z00Sooo]Z0_nE0?l>oookJP;o0;Oo7?oonfX2ool0^P;o
oo]Z0_ooc@1koookJP;oobH05_oonfX2oone00gooo]Z0_n`0?l:oookJP;o0:co0ooonfX00ooo07Ko
oo]ZoookJP0BoookJP03oa[o0?ooP`3ooh<000;o;?l000?ooo]Zo`18ool0B?l01ooonfX2ool0/`;o
05co0_ooG006oookJP04okko0?oonf[ooo]ZoookJP;oLOl000?o00Koo`3oF?l0oeP01?oonfX2o`3o
e@;ooo]Z0_l0Y?l2o`3oYP?ooo]Z0_oo]`02oookJP;o05;o0_l0obh01?oonf[oooh0ooon0?n6o`02
oolg00?ooo]Z0_m9o`03oookJP;o0:Oo3?oonfX3o`000003oon@0?mbo`3ooo]Z00_ooo]Z00Ko007o
oookJ_oo`03o0?nVodl0oooonfX2ool0S0;ooo]Z00CoHol0oago0?mYo`3oob400_oonfX01?l0olgo
P03ooh00oonbo`03oookJP04ob?o0?ooG@3o02coo`0/o`;o0?_o0_oo0:X01Om^o`3olP3ooo80oooo
03_ooo]Z00;o04oo00?oo`2aoonk0?oo^`000_oo03<7oookJP;oo`2300?ooo]ZobKo0?l0oiP00_oo
nfX2on3o00Kooo]Z00?onP3ooookJ_oonfX00_ooo`02oookJP;o>@3o0_oonfX2ool0bPCooo]Z0_nB
0?l00ooonf[oWol0oookJP03oookJP;o1ol000Cooo]Zo`3oQol0ohOo00_o0ooonfX00oooeP3ooo]Z
oookJP04oookJP;o0?mM00?ooo]Zo`3oIol0ofL00_l02?l01?oonf[o0?oCo`19ool0BOl?oookJP03
oomc0?oonf[ooo]Z00Sooo]Z0_nE0?l>oookJP03o`2goooonf[ooo]Z01[ooo]Z0_oo0;X3oookJP;o
old09ooonfX005Gooo]Z00?oobH0oookJ_oonfX05?oonfX2oone00kooo]Z0_n`0?l:oookJP;o0:co
0ooonfX00ooo07Kooo]ZoookJP0BoookJP03oomi0?ooP`3ooh<000?oogT00_l0B?l3oomi00Cooo]Z
00?oo`2coookJ_ooN@001_ooN@000ooonf[oolT0ooo90003ooo90003og7o0?ooN@3oogT000;o0?mH
1?oonfX2o`3oe@;ooo]Z2_ooN@06oolX00;oooh00_oo:0001Ooo=`3oobP0oolX0?oo:03oBOl000So
obP00_oo00000ooo:03oo`00ool00005ool000?oiOl01OooN@02oolX0004ooo90?oo003oo`00ool0
00;oogT08?oo:0001?oooP3oK_l0oo80ooob0?l2ool0>`;o04oo00?oo`2aoonk0?oo^`000_oo03<6
oookJP;oo`2300Cooo]ZobKo0?l0oiSo0?nH0_oonfX2on3o00Cooo]Z0_oob@06oomi0003ooo90?oo
nf[o>@3o00;ooo]Z0_oo0<X4oookJP04oomi0?nB0?ooogT0oioo00Gooo]Z1_oob@06oomi00;oolT0
0_oonfX01?l0oegooo]Zo`3oIol0ofL2o`08o`;o0?oC00?oolT0oookJ_oonfX00_oonfX3ooo900So
oo]Z0_ooL`0:oookJP03oiD0oooonf[ooo]Z00gooo]Z00?o0;OooookJ_oonfX06ooonfX01Ooo0;[o
oo]ZoookJ_oonf[oold007_ooo]Z0_oo9P0FoookJP;ookD03OoonfX2ok00o`[ooo]Z0_l0[?l3oook
JP;oo`1f4ooonfX2oa[o0004oon30?oonf[o;?l0oookJP;o04So2?oonfX00ooo0;?o06;oo`1Lo`02
oomL00Kooo]Z0_nno`02oookJP;oLOl000?o00Koo`3oF?l0oeP01?oonfX2o`3oe@?ooo]Z00?o0:Co
o`0Cool0ojH00ooonfX2oong00?ooo]Z00Co05;ooookJ_l0obkooo]Z0_oooP000ooonf[oocL0oolg
0002oookJP?oBOl00ooonfX2o`2Wo`kooo]Z0_l000000oooT03oL_l0og;o000:oookJP;o007o00Co
oo]Zooo00?l0ojKoC`3o0_oo08`3oookJP;o7Ol000?oJOl0oookJ_oonfX00_l0old00on00?oooo]Z
ok;o0002oookJP;o8ol000Oooed0o`0/ool0nooo0?_ooookJ_oo0:[oK_l000;olP3o0_oo03/01ooo
nf[o04ooool0/Ooo0;7ook/0oookJ_oo03<01ooonfX2ool0P`04oookJ_lVo`3o0?nHo`3oV0;ooo]Z
00?oh?l0oookJ_oonfX01?oonfX2ooX0o`;ooo]Z00Goool0oookJ_oonf[ooo]ZocT0o`02oookJP;o
o`3:1OoonfX01?nB0?oooo]Zoioo0?nOo`04oookJP05o`Oo0?oonf[ooo]Zo`3oQol02ol00ooonfX2
oooF00Kooo]Z00Co0?mMoookJ_oonf[o0?mW0_l02?l01?oonf[o0?oCo`3odol0BOl?oookJP;oog<0
2_oonfX00onE0?oooo]ZoookJP0<oookJP;o0;Oo7?oonfX00ooo0;[ooo]ZoookJP02oookJP03ooo=
0?oonf[ooo]Z02Oooo]Z001CoookJP;oobH05OoonfX2oone00oooo]Z00?o/03ooookJ_oonfX02Ooo
nfX01?l0[?oooo]ZoookJ_oonfX2ool0MQ?ooo]Z00?o6_l0oon30?ooP`000oooN@02o`18o`;oogT0
1OoonfX2ool0/`03o`1RooooN@3oogT000?oogT00ooonfX5ooo90004og7o0?oob@3o00Koo`3oF0Go
oo]Z00Co0?oEoookJ_oonf[ooo]Z2_ooN@05oolX00;oooh000Coo`00ohKo0?oo:03oocL00ooo:000
0om9o`3oobP0oolX0004oolX0003ool00?oob@3oolT000?oobP02?oo00000ooUo`3oogT0oomi0003
oomi00CoobP000Coo`00oomi0?ooN@3oogT02_oo:002ool000WoobP000?o/_l0oolX0?oo:0001ooo
:0003OoooP3oK_l0oo80ooob0?oooo]Zool0>ooonf[o04oooookJ_oo0;7ook/0oookJ_oo03<01ooo
nfX01Ooo08?ooo]ZoookJ_lVo`3o0?nH00;ooo]Z0_oPo`05oookJPSoogT000?oolT0ocT0ooli0?l0
0_oonfX00ooo0<[ooo]ZoookJP03oookJP;oTP3o0_nOo`04oookJP03o`Oo0?oob@3oolT000CoolT0
0oooN@02ooo90004oomi0?oob@3oolT0oookJP;o0?mM0_l0ofL2o`08o`04oookJ_l0om?o04Woooo9
00Kooo]Z00?oolT0oookJ_oonfX01OoonfX2oomc00[ooo]Z0_nE0?l>oookJP;o0;Oo7?oonfX2ool0
^P;ooo]Z0_ooc@1joookJP;oobH05_oonfX2oone00kooo]Z00?o/03ooookJ_oonfX02OoonfX00ol0
[?oooo]ZoookJP02oookJP03ool0M_oonf[ooo]Z017ooo]Z0_lJo`02oon300;o;?l000?ooo]Zo`18
ool0ol401ooonfX2ool0/`;o05co00?ooe`0oookJ_oonfX01?oonfX2okko00?ooo]Z00CoLOl0o`06
ool0oeSo0?mH1?oonfX2o`3oe@Cooo]Z00?o0:Coo`3oY_l0ojH00ooonfX01?oo]`3ooo]ZoookJ_oo
nfX2o`1Bo`07oookJ_l0obkoooh0ooon0?oonf[oQ_l0oolg0003oookJP04odWo0?ooXP3ooj80o`3o
D@?o0:Oo4?oonfX2o`000003oon@0?mbo`3ooo]Z00Wooo]Z00?o007ooookJ_oonfX00_l0ojH00om?
0?ooo`2<oookJP03oookJP04oago0?mYo`3oJOl0oookJP;o0?o=00Coo`26oh00oonbo`3o/_l00_oo
nfX02?lSo`3ooed0oomM0?oonf[o0?_ooookJ_oo0:[oK_l00_ob0?l00ooonf[oo`0koookJP02o`1?
o`03ool0/Ooo^`3ook/000;oo`0c1ooonfX00ooo08?ooo]ZoookJP02o`3oV0;ooo]Z0_oPo`06oook
JP03ooX0oooonf[ooo]Z00;oool00_oonfX2ocT0o`;ooo]Z00?oo`3:oookJ_oonfX00ooonfX2oi80
o`03oookJ_nOo`3ooo]Z00?ooo]Z0_l7o`001?oonf[o0?n7o`3oQol02ol3oookJP03oooF0?oonf[o
oo]Z00Cooo]Z0_l0oed01?oonf[o0?mWo`3oIol02?l2oookJP03o`3odol0BOoo04Wo00kooo]Z0_oo
L`0:oookJP;oU@3o3OoonfX2o`2goacooo]Z0_oo0;X3oookJP;oold0:_oonfX002Sooo]Z:Ol00002
oolV01Ko000000?ookD0o`000?l000003Ol00002ok00o`[o00000_l0[?l2o`0000;oo`1f5?l00000
0olJo`3ooh<0o`000002oomi0003o`3o`Ol0B?oo000000Ko00000_oo0;<01?l0003o05cooomi0?oo
N@06o`0000CoolT00_mao`000ol01_oo0?mHo`3oF004o`0000;o0?oE0ol00007oomi00;ookL000?o
0000oolX0?oo:0000ooo:0001?oooP3oobP0ohKo0?n6o`02oolg00;oobP00_m9o`07oolX0004ooo9
0?oo003oolT0ooo900CoobP01_oo0006oomi00;oobP01OooN@000ooo003oobP0oolX0008oolX00;o
o`002Ooo:003ool000KoobP00_m^o`001?ob0?oo0000ool0>ooo03/2o`1?o`03ool0/Ooo^`3ook/0
00;oo`0c1_l00002ool0P`04o`000?lVo`3o0?nHo`3oV0;o000000Coh?l0o`000?l0003o00002ooo
N@001?oob@3o>@3oo`000?l00002ool0bPGo000000?oTP3ooioo0?nOo`001?l00002o`Oo0003o`00
0?l0ohOoogT000?oolT00oooN@05ooo90004o`000?l0oego0000o`3oI`;o00So00Co0000o`3odol0
om?o04Wo3ol000000oooL`3o0000o`000008o`0000;oU@3o3ol000000ol0]ooo0000o`00000Jo`00
00;oo`2j0_l00002ooo=00Wo0000B?oonfXZo`000003oolV0?l0003o000001Co00000_oo]@0>o`00
00;o/03o2_l00002o`2/o`?o00000_oo07HCo`000003oa[o0?ooP`3ooh<000;o;?l000?o0000o`18
ool0B?l01ol00002ool0/`;o05co0_ooG006o`000004okko0?l0003o0000o`0000;oLOl00_l0oeP5
o`000003o`3oeOl0003o000000;o000000?o01?oo`3oY_l0ojH00ol00002oong00;o00000_l0D_l0
1_l0003o0?l^o`3o;_oooP3o0000ohKo00;oocL000Koom`0o`000?m9o`3oBOl0oonR0?l0oe42o`2W
o`;o00000_oL0?l5o`0000;o0?og2_l000000oooT03o0000o`000008o`000005o`01ool0003ool00
o`3oY_l000000_oo08`3o`000004oago0?mYo`3oJOl0o`0000;o0?o=00Coo`26oh00oon00?oo/_l0
0_l00003oomM0003o`0/ool0nooo0?_o00;oo`2Z00?oK_l0oo80ool000000_oo03/2o`1?o`;oo`2a
00?ook/0o`000?oo03<01ol00002ool0P`03o`000?lVo`3o0?nH00;o00000_oPo`06o`0000;onP3o
00?o0000ool0]oooo`000_l00002ocT0o`;o00000_oo0<X5o`000004oi80ool0003oWol0oioo00?o
00000_l7o`001?l0003o0?n7o`3oQol02ol3o`0000;oomH01_l000001?l0oego0000o`3oIol0ofL2
o`08o`04o`000?l0om?o0?oCo`19o`oo000000?oog<0o`000?l000002?l00002oiD0o`ko000000?o
0;Ooo`000?l000006_l00002ool0^P?o00000_ooc@09o`0002?ooo]Z000XoookJRSo000000?oobH0
o`000?l000005?l00002oone00ko00000_n`0?l:o`0000;o0:co0ol000000ooo07Ko0000o`00000B
o`000004oa[o0?ooP`3ooh<0obco00;oogT00_l0B?l7o`000004ool0/ol0003o05coo`1Lo`;ooe`0
1Ol000001?nno`3oolT0ooo90?l00002og7o0003oomi0?l0oeSo0?mH00Go000000Go0?oEo`000?l0
003o0000o`0Co`05oomi0005o`000?oo]`3ookL0o`000?l0D_l00_oo:002o`3o;P04o`000?oooP3o
Q_l0ohKo00;oocL00_oo:002odWo0003oonR0?oo:03oobP000OoobP000?oo`00oolX0?oo:0000_oo
:006ool000OoogT00_oo:003oomi00Goo`002?oo:003ool000GoobP02?oo0003oolX00;oK_l00_ob
0?l2ool0>`03o`000?l0Cooo000000;ook/00_oo03<6o`0000;oo`230_l00002o`3oV0;o00000_oP
o`02o`0000coogT000?oolT0o`000?l000000_oo0<X5o`0000;oTP3o00?oWol0o`000?l000000ol0
00001Ol7o`3o0000o`3oQol0ohOo00_o00;o000000CoolT0oomi0?ooN@3oogT00_l00003ooo900;o
0?mM0_l0ofL01Ol02?oo0000o`000?l0om?o04Wo00oo00000_ooL`09o`0000;oU@3o3ol00002o`2g
oaco000000Goo`2jo`000?l0003o0000ooo=000;o`0004Sooo]Z:?l00002oolV01Ko000000?ookD0
o`000?l000003?l00002ok00o`[o00000_l0[?l3o`0000;oo`1f4ol00002oa[o0004oon30?l/o`3o
;?l0o`0000;o04So2?l000000ooo0;?o05coo`1Lo`02oomL00Ko00000_nno`02o`0000;oLOl00_l0
oeP5o`0000;o0?oE0ol000000ol04ooo0?nVo`3oYP03o`0000;ookL00_l00002o`1Bo`?o0?l^00?o
0000ooon0?n6o`000_oo=`001?oog03o0000o`000?m9o`02oonR0004o`3oDOl0Yooo0000o`0000;o
g03o1_l000000ol0ooOo0000o`00000Co`0000;o007o00Gool00o`3oY_l0ojKo0000ool0S003o`00
000:o`d0oolMo`3oHol0oolQ0?l0003o0?o=ool0Q_l0003oP03ook;o00;o000000Wo8ol0oomM0?l0
;?oo02coo`000?l0nooo0000ool0Z_m^o`000_ob0?l2ool0>`04o`000?l0Cooo0000ool0/@;ook/0
0_oo03<6o`0000;oo`2300Co0000obKo0?l0oiSo0?nH0_l000000ooPo`3o0000o`000005o`000003
ooX0ool0003oo`2g00;oool000?o0000ocT0ooli0?l00_l00002ool0bPGo00000_nB0?l00ol0003o
Wol0o`000003o`000005o`Oo0?l0003o0?n7o`3oQol02ol00ol00002oooF00Ko00000_l0oed01?l0
003o0?mWo`08ool02?l2o`000003o`3odol0BOoo000000ko00000_ooL`09o`0000;oU@3o3_l00002
o`2goaco000000?oo`2jo`000?l000000_l000000oooc@3o0000o`000009o`0002?ooo]Z000Xoook
JRKo00000_oo9P0Eo`0000;ookD03ol000000on`0?oo0000o`000009o`000004o`2/ool0003o0000
o`0000;oo`1f4ol000001_ooN@3o6_l0oon30?l0003o;?l0o`0000;o04So1ol00002ool0/`04o`00
0?l0G?ooobh0oomL00Ko000000So__l0o`000?l0003o0000og7o0?l0003o00Kooomi00Go00000_l0
omD2o`000004o`0Cool0ojKoogT0oomi00?o00000_oo]`02o`000005o`1Bool0003o0?l^o`3o;_oo
:0000_oooP000on6o`3oocL0oolg0002oolX00;oBOl00_ooXP09oolX00?oo`000ooo:005ool000So
ogT00_oo:0000oooN@3oo`00ool00006ool000KoobP00ooo0003oolX00_oo`000_oo:0000om^o`3o
lP3ooo80o`02ool0>`03o`000?l0Cooo04oo00;ook/00_oo03<7o`000003ool0Pol0003o000000;o
0?nH00Co0000ooo90?oob@3oolT01?l0000;oomi0004ooo90?l0003oo`3:ool0bPKo000000?oTP3o
oioo0?nOo`001?l00002o`Oo0005o`000?l0ohOo00_oo`0;ool000000_ooeP03oomi00Co000000Co
olT0o`3oGOooN@3oogT00_l02?l01?l0003o0?oCo`3odol0BOl>o`0000;oog<02_l000000onE0?oo
0000o`00000=o`0000;o0;Oo7?l00002ool0^P;o00000_ooc@0<o`0004Sooo]Z9_l00002oolV01Ko
00000_oo]@0>o`000003ok00ool0003o000000Wo000000?o0:coo`000?l000000_l000000ooo07Ko
0000o`00000Bo`000004oa[o0?ooP`3ooh<0obco00;o000000?o04Soo`3o`Ol000001_l00002ool0
/`03o`1Loooo;P3ooe`000Ko00000_nno`03o`000003og7o0?l01_oo0?mH00Go00000_l0omD3o`00
0003o`0Cool0ojKo0?nV00Co000000GookL0o`000?l0003o0000o`1Bo`02o`3o;P;o00000_oooP02
oolg0003o`000?oog03o000000;oBOl000Cooj80o`3oDOl0Yooo0:Oo0_l000000ooL0?oo0000o`00
0004o`0000;o0?og0ol000000ooo;03o0000o`000005o`0000;o0?nf1ol00002o`01o`03o`000?l0
ojKo0?nV00Ko000000Co3@3oof?o0?l0003o00000_l0old00ooo08KoP03ooh00o`02o`0000;o8ol0
0_l0;?l2o`000003o`3koooo0:[oK_l000;olP3o00Ko0000ool0>ol0003o0000o`1?oooo0;42oonk
00;oo`0c1ol000000ooo08?o0000o`000002o`3oV0;o00000_oPo`06o`0000;onP3o0_oo0;L01?oo
o`3o0000o`000?li0?l2o`0000;oo`3:1_l000001?nB0?oo0000oioo0?nOo`03o`0000;o1ol000Co
0000o`3oQol02ooo00_o0_l00002oooF00Oo000000Go0?mMo`000?l0ofOo0?mWo`08o`02o`0000;o
0?oC00?o04Woo`000?l000003?l00002oomc00[o000000?oU@3oo`000?l000003?l00002o`2goaco
00000_oo0;X3o`0000;oold03?l0000SoookJP00:?oonfXUo`000003oolV0?l0003o000001Co0000
00?ookD0o`000?l000003Ol00002ok00o`[o00000_l0[?l2o`0000;oo`1f5?l000000oooN@3ooh<0
oon30002obco0003o`000?l0B?oo000000Oo000000Coo`2co`000?l0G?oo05co0_ooG005o`0000;o
__l00_l00002og7o00;o00Ko0oooN@03o`000007o`3oeOl0003o0000o`000?l04ooo0?nVo`2To`03
oomi00;ookL00ol000001?l0D_oo0000o`3o;_oo:002ooon0003oolX0?oo=`3oocL000;oobP00_m9
o`02oonR00OoobP01ooo0002oolX00Goo`001_ooN@000ooo003oobP0oolX000;ool000GoobP00ooo
0002oolX00coo`000_oo0:X01?m^o`3olP3ooolX0?oo:002o`000003o`1?oooo0;7ook/000;oo`0c
1ol00002ool0P`;o000000?o0?nHooo90?oob@000ooob@04o`0000_oogT000?oolT0ool0b_oo0<X0
1_l00002oi80o`03oioo0?l0003o000000;o00000_l7o`001Ol0003o0?n7o`3oQol02ooo000000;o
omH00ol000000oooN@3o0000o`000002o`0000CoogT000Go00Soo`000?l0003o0?oCo`19o`0?o`00
0003oomc0?l0003o000000So00000_nE0?l?o`000003o`2gool0003o000001[o00000_oo0;X3o`00
0003ooo=0?l0003o000000co0000B?oonfXUo`000003oolV0?l0003o000001Co00000_oo]@0>o`00
00;o/03o2_l00002o`2/o`?o00000_oo07HCo`000003oa[o0?ooP`3ooh<000;o;?l000?o0000o`18
ool0B?l01ol00002ool0/`;o05co0_ooG006o`000004okko0?l0003o0000o`0000;oLOl000?o00Ko
o`3oF?l000001?l000000ol0omGo0000o`000002o`000003o`0Cool0ojKo000000?o00000_oo]`02
o`0000;o05;o00?o0?l^o`000?l000000_oooP02oolg0003o`000?oog03oom`000;oBOl00_ooXP02
o`2Wo`;o00000_oL0?l6o`000003o`3omol0003o000000;o000000?oob`0o`000?l000000_l00000
1Ol0=ooo0000o`000?l0003o0?nf00Ko00000_l00Ol00ooo`03o0?nVo`3oYP06o`0000;o3@3o0_l0
0002o`3oc@04oh00oooo08KoP03ook;o00;o000000?o8ol0o`0/ool0;?l00_l00002o`3ko`04ool0
Z_m^o`3olP3oo`0000;oo`0k0_l000000ooo0;7ook/0oonk0002ool0<`Oo00000_oo08<00ol0003o
9_l0o`3oV002o`0000;oh?l01ol000000ooj0?ooo`2gool0]`02oooo0004o`000?li0?oo>@3oo`00
00;oo`3:1_l00002oi80o`;oWol00ol00002o`Oo0004o`000?l0ohOo0?n7o`0;o`;o00000_ooeP07
o`0000;o0?mM0_l0ofL2o`08o`;o000000?o0?oCo`19ool000003_l000000oooL`3o0000o`000008
o`0000;oU@3o3_l000000ol0]ooo0000o`00000Jo`0000;oo`2j1?l000000oooc@3o0000o`00000<
o`0002?ooo]Z001;oookJP;oobH05OoonfX2oone00kooo]Z0_n`0?l:oookJP;o0:co0ooonfX00ooo
07Kooo]ZoookJP0BoookJP03oa[o0?ooN@3ooh<000;oogT000?ooo]Zo`18ool0B?l02?oonfX00ooo
0;?o05coo`1Lo`02oomL00Kooo]Z00So__l0oookJ_oonf[ooo]Zog7o0?oonf[o00Koo`3oF0GoogT0
0_l0omD2oookJP03o`0Cool0ojKo0?nV00KoogT00ooonfX02?l0D_oo0?l^o`3o;_oo:03oooh0oolX
0?n6o`3oocL00_oo:002odWo00;ooj801_oo:00:ool00003oolX0?oo003oo`0000Koo`001ooo:00<
ool000?oobP04Ooo0005oolX00;ooo]Z00Go04oooolX0?oo:03oobP0ool0<`07oookJP;oo`2300?o
oo]Zooo90?oob@001_oob@000ooonf[oogT0oomi0002oomi00;onP3o2?ooN@000ooonf[oo`3:oook
JP05oookJP;oTP3o00?oWol0oookJ_oonfX00ooonfX01Ol7o`3ooo]Zo`3oQol0ohOo00_o00;ooo]Z
00?oomH0oookJ_oonfX01OoonfX6oomi00;ooo]Z0_l0om<?oookJP;oog<02OoonfX2oiD0o`oooo]Z
0_l0]olLoookJP04ool0^_oonf[ooo]ZoookJP;oold0N_oonfX2oolV01Kooo]Z00?ookD0oookJ_oo
nfX03?oonfX2ok00o`[ooo]Z0_l0[?l4oookJP03ool0M_oonf[ooo]Z01;ooo]Z00Co6_l0oon30?l/
o`3o;?l00_oonfX00ol0B?oo0?o1oookJP06oookJP03ool0/ol0G?oo05co00;ooe`01_oonfX2okko
00?ooo]Z00CoLOl0o`06ool0oeSo0?mH1?oonfX2o`3oe@?ooo]Z00?o01?oo`3oY_l0ojH00ooonfX2
oong00?ooo]Z00?o05;ooookJ_l0obh00_oonfX00ooooP3oQ_l0oolg0002oookJP03oooL0?m9o`3o
BOl000;ooj800_l0Yol01?l0@Ooooo]ZoookJ_oL0?l6oookJP;o0?og1?oonfX00ooo;03ooo]Zoook
JP02oookJP05o`0goooonf[ooo]ZoookJ_l0okH01?l000001?oonf[ool00ooo00?oo`002o`3oYPGo
oo]Z0ol=0?l5oookJP03oh00oooonf[o/_l000?ooo]Z00Co8ol0o`0/oooonf[ooo]Z0_l0nol01?oo
nf[oK_l0oo80ooob0?l2ool0>`;ooo]Z00?o04oooonk0?oo^`000_oo03<7oookJP;oo`2300Gooo]Z
obKo0?l0oiSo0?nHoookJP02on3o00Oooo]Z0_oj0?l00ooo0;Ooool0oooo0002oookJP04ocT0oooo
nf[ooo]Zool0bPKooo]Z0_nB0?l2oioo00Cooo]Z00Go1ol0oookJ_l0ohOo0?n7o`0;o`03oookJP03
oooF0?oonf[ooo]Z00Gooo]Z0_l0oed01?oonf[o0?mWo`08ool02?l2oookJP;o0?oC3ooonfX2oomc
00Wooo]Z0_nE0?l>oookJP;o0;Oo7?oonfX00ooo0;[ooo]ZoookJP02oookJP;oold0<_oonfX004[o
oo]Z00?oobH0oookJ_oonfX05?oonfX00ooo]@3ooo]ZoookJP0=oookJP03ok00oooonf[ooo]Z00Wo
oo]Z00Co0:cooookJ_oonf[ooo]Z0_oo07HCoookJP;o6_l00_ooP`04oomi00Sooo]Z0_oo0;<00ol0
G?oooe`0oomL0006oookJP;o__l00_oonfX2og7o00;o00Ko00?o0?mHoomi0?ooN@001OooN@02oook
JP03o`0Cool0ojKo0:Co00OoogT000Gooo]Zo`1Bool0D_oo0?l^oolX0002ooon0003ohKo0?oo=`3o
ocL000;oobP000?oBOl0oolX0?ooXP001_oo:00;ool00003oolX0?oo003oo`0000Coo`002_oo:00=
ool00003oolX0?oo003oo`0000coo`003Ooo:0000ooo03?ooo]ZoookJP06oookJP03ool0Pooob@3o
olT000SoolT01?ooN@02ooX0o`;oogT000?oool0oomi0?ooN@001?ooN@02ool0bPKooo]Z00?oTP3o
oioo0?nOo`001?oonfX2o`Oo0005oookJ_l0ohOo00_oo`0;oooonfX00_ooeP05oookJPSoogT00_oo
nfX00ol0om?o04WooookJP0=oookJP;oog<02_oonfX00onE0?oooo]ZoookJP0=oookJP;o0;Oo7?oo
nfX2ool0^P;ooo]Z0_ooc@1koookJP03oolV0?oonf[ooo]Z01Cooo]Z0_oo]@0>oookJP03ok00oooo
nf[ooo]Z00Wooo]Z00?o0:cooookJ_oonfX00_oonfX2ool0MQ?ooo]Z00Co6_l0oon30?ooP`3o;?l0
0_oonfX2o`18o`Oooo]Z0_oo0;<00ol0G?oo06;ooomL0006oookJP;o__l00ooonfX2og7o0003o`06
ool0oeSooo]Z00?ooo]Z0_l0omD3oookJP03o`0Cool0Y?oo0?nV00Cooo]Z00CookL0oookJ_oonf[o
oo]Z0_l0D_l00ooonf[o0?l^oookJP02ooon00;oocL00_oonfX2odWo00;ooj8000Good`0o`2Woooo
nf[o047ooookJP02om`0o`Gooo]Z0_l0ooL2oookJP;o0>Go0_oo;004oookJP03o`0goooonf[ooo]Z
00;o0?nf00?ooo]Zo`000?l000000_l0000:oookJP03o`d0oooonf[ooo]Z00Cooo]Z0_n00?l2ok;o
00?ooo]Z00Oo02cooookJ_oonf[ooo]Zo`3koooonf[oK_l000;olP3o00?oo`0koookJ_oonfX00_l0
Col2oonk00;oo`0c2?oonfX00ooo08?ooo]ZoookJP02o`3oV003oookJ_oPo`3oh?l000Oooo]Z0_oj
0?l00ooo0;Ooool0oooo0002oookJP;o>@3o00?ooo]Zool0b_oo0<X01_oonfX00onB0?oooo]Zoioo
0004oookJP;o1ol000Cooo]Zo`3oQol02ooo00_o0_oonfX2oooF00Oooo]Z00Go0?mMoookJ_l0ofOo
0?mWo`08o`03oookJP03o`3odol0BOoooo]Z00gooo]Z0_ooL`0:oookJP03oiD0oooonf[ooo]Z00co
oo]Z0_l0]olLoookJP;oo`2j0ooonfX2ooo=03Cooo]Z0018oookJP;oobH05OoonfX2oone00kooo]Z
0_n`0?l:oookJP;o0:co0ooonfX00ooo07Kooo]ZoookJP0BoookJP03oa[o0?ooP`3ooh<000KoogT0
1ooonfX01?oo0;?o05coo`1LooooG007oookJP05okko0?oonf[ooo]ZoookJ_mao`000_l01_l00ooo
nf[o0?mHoomi0008oomi0003o`0Cool0ojKooo]Z00SoogT000So05;oo`3o;_l0obkoobP0ooon0?oo
:03oQ_l0oolg00?oobP000?oBOl0oolX0?ooXP001ooo:00Bool000coobP05ooo000?oolX00Sooo]Z
00?oo`23ooo90?oob@002Ooob@000ooonf[oogT0oomi0002ooX0o`;oogT00_ooo`06oomi0003ool0
b_oonf[ooo]Z00Cooo]Z0_nB0?l00onOo`3ooo]ZoookJP02oookJP;o1ol000Gooo]Zo`3oQol0ohOo
00_ooookJP02oooF00Cooo]Z2_ooN@000ooonf[o0?oCo`3od`0?oookJP03oomc0?oonf[ooo]Z00So
oo]Z0_nE0?l?oookJP03o`2goooonf[ooo]Z01[ooo]Z0_oo0;X3oookJP03ooo=0?oonf[ooo]Z07Wo
oo]Z0_oo9P0EoookJP;ookD03_oonfX2ok00o`[ooo]Z0_l0[?l3oookJP;oo`1f5?oonfX2oon300;o
;?l00_oonfX00ol0B?oo0?o1oookJP06oookJP03ool0/ol0G?oo05co00;ooe`01_oonfX00onno`3o
oo]ZoookJP02oookJP04og7o0?l01_oooo]Zo`3oF0Cooo]Z00?o0?oEoookJ_oonfX00_oonfX00ol0
4ooo0:Coo`3oYP03oookJP;ookL00ooonfX02?l0D_oooo]Zo`3o;_l0obkooo]Zooon0?n6o`3oocL0
0_oonfX01ooog03oBOl0oookJ_ooXP3ood`0o`3oDOl0Yol00_l0@Ol2om`0o`?ooo]Z0_ooR@000ooo
nf[o0?ogoookJP02oookJP03o`3Uoooonf[oob`000Gooo]Z00Co03Ooooo90?oonf[o0?nf0ooonfX4
o`0000Wooo]Z00?o3@3ooookJ_oonfX01?oonfX00on00?oooo]Zok;o0004oookJP03o`0/oooonf[o
oo]Z00;ooo]Z00CoK_l0oo80ooob0?ooo`0k0_oonfX01_l0Coooo`2aool0/Ooo^`3ooo]Zool0<`So
oo]Z0_oo08<3o`3oV003oookJ_oPo`3oh?l000Oooo]Z0_oj0?l2ool0]`06oooo0?oonf[ooo]Zoook
J_li0?oooo]Z0_oo0<X6oookJP;oTP3o0_nOo`03oookJP;o1ol000Cooo]Zo`3oQol0ohOo00_o0_oo
nfX2oooF00Oooo]Z0_l0oed2o`3oI`;o00So0_oonfX2o`3od`oooo]Z00?oog<0oookJ_oonfX02?oo
nfX2oiD0o`kooo]Z00?o0;OooookJ_oonfX06_oonfX2ool0^PCooo]Z00?oold0oookJ_oonfX0=?oo
nfX004Oooo]Z00?oobH0oookJ_oonfX05?oonfX00ooo]@3ooo]ZoookJP0<oookJP;o/03o2ooonfX0
1?l0[?oooo]ZoookJ_oonfX2ool0MQ?ooo]Z0_lJo`000oooP`3oogT0oomi0007oomi00Cooo]Z00?o
o`2co`1Lool0G?l00_ooG006oookJP;o__l00_oonfX2og7o0004o`06oooonf[o0?mHo`3oF0_oogT0
00?ooo]Zoomi0?ooN@001OooN@02o`1Bo`05o`3o;_ooN@3oooh0ooon0?n6o`000_oo=`02oolX00;o
BOl000?ood`0oonR0?l0oe400_l0Yol4oolX00;oo`0000?oobP0ool00?oo00001?oo00000ooo:03o
o`00ool00008ool000goobP04Ooo000BoolX00Kooo]Z0_oob@000ooo08?oolT0ooo90009ooo900;o
oo]Z0_oj0?l3oomi0003oooo0?ooN@3oogT000;o>@3o0oooN@06oookJP;oTP3o00?oWol0oookJ_oo
nfX00_oonfX2o`Oo0005oookJ_l0ohOo0?n7o`0;oooonfX00_ooeP04oookJP_oogT00_l0om<?oook
JP;oog<02OoonfX2oiD0o`oooo]Z0_l0]olLoookJP04ool0^_oonf[ooo]ZoookJP;oold0NooonfX0
0ooo9P3ooo]ZoookJP0DoookJP03oone0?oonf[ooo]Z00cooo]Z0_n`0?l;oookJP03o`2/oooonf[o
oo]Z00;ooo]Z00?oo`1foookJ_oonfX04_oonfX01?lJo`3ooh<0obco0?l/o`02oookJP;o04So1ooo
nfX00ooo0;?o05coo`1Lo`02oomL00Kooo]Z0_nno`03oookJP;oLOl000?o00Koo`3oF?l0oeP00ooo
nfX2o`3oe@?ooo]Z00Co01?oo`2Tool0ojKo0?nV0_oonfX2oong00?ooo]Z0_l0D_l2o`3o;P07oook
J_oooP3oooh0ohKo0?oo=`3ooo]ZoooL0002odWo0003oom<0?ooXP3o0?mA00;o0:Oo00?o047oom`0
oooL0?l01?oonfX01?ooR@3ooo]Zo`3omol0ooL3oookJP03o`3Uoooonf[oob`000;o02go0_oonfX2
o`0go`03ooo90?oonf[o0?nf00Cooo]Z1?l0000JoookJP04ool0Z_m^o`3olP3oool0>`;ooo]Z00?o
04ooool0/Ooo0;400_oo^`02ool0<`Sooo]Z00Coo`23o`3oV?l0oiSo9_l00_oonfX00ooPo`3ooo]Z
oookJP05oookJP;onP3o0_oo0;L2oooo00;ooo]Z0_li0?l00ooonf[oo`3:oookJP05oookJP;oTP3o
0_nOo`03oookJP;o1ol000Cooo]Zo`3oQol0ohOo00_o0_oonfX2oooF00Sooo]Z00?o0?mMo`3oIol0
ofL00_l02?l2oookJP;o0?oC3ooonfX2oomc00Wooo]Z0_nE0?l>oookJP;o0;Oo7?oonfX00ooo0;[o
oo]ZoookJP02oookJP;oold0=ooonfX004Gooo]Z0_oo9P0EoookJP;ookD03_oonfX00on`0?oooo]Z
oookJP09oookJP;o0:co0_oonfX2ool0MQCooo]Z00?o6_l0oon30?ooP`002oooN@001?oonf[oo`2c
ool0/ol0G?l2oomL00Oooo]Z00Go__l0oookJ_oonf[ooo]Zog7o0002o`06o`;o0?mH0_oonfX9oomi
00;ooo]Z1oooN@002?l0D_oo0?l^o`3o;_oonf[oooh0oolX0?n6o`3oocL00ooo:0001_m9o`3oobP0
oom<0?ooXP3o0?mAo`2Wo`GoobP00ooo00000ooo:03oo`00ool00004ool00003oolX0?oo003oo`00
00Soo`002Ooo:00Aool000;oogT04ooo:003oookJPCoolT00_oo08<;ooo90004oookJ_oj0?oonP3o
oookJP;oogT00_ooo`001oooN@3o>@3oocT0ooooN@3ooo]Zool0b_ooN@001_oonfX00onB0?ooogT0
oomi0003oookJP;o1ol000Gooo]Zo`3oQol0ohOo00_ooookJP02oooF00Kooo]Z2_ooN@000ol0om?o
04WooookJP0=oookJP;oog<02OoonfX2oiD0o`oooo]Z0_l0]olLoookJP;oo`2j0_oonfX2ooo=07_o
oo]Z0_oo9P0EoookJP;ookD03_oonfX00on`0?oooo]ZoookJP09oookJP;o0:co0ooonfX2ool0MQ?o
oo]Z00Co6_l0oon30?ooP`3o;?l00_oonfX2o`18o`Oooo]Z0_oo0;<01?l0G?oo06;ooomL0?oo;P06
oookJP03okko0?oonf[ooo]Z00;ooo]Z00CoLOl0o`06ool0oeSo0?mH1?oonfX00ol0omGooo]Zoook
JP02oookJP;o0:Co00Go0?nVoookJ_oonf[ooo]Zoong0004oookJP03o`1Boooonf[o0?l^00;ooo]Z
00coooh0ohKo0?oonf[oocL0oookJ_oog03oBOl0oookJ_ooC03ooj80o`3oDOl0Yol2oookJP03om`0
oooonf[ooo]Z00;oodH00_ooR@000ooonf[o0?ogoookJP03oookJP04o`3Uoooonf[o02goo`0]o`?o
oo]Z00Oo03Ooooo90?oo@`3ooo]Zo`3o]_oonf[o`03o00?ooo]Z00Co0000ojGo0?l0003o00005ooo
nfX2ool0ZP?olP3o0_oonfX00ol0Coooo`2aool0/@02oonk00;oo`0c2?oonfX2ool0P`04o`3oV?lV
o`3ooo]ZoookJP;oh?l01_oonfX2ooX0o`04oookJ_oo0;Ooool0oooo00;ooo]Z0_li0?l00ooonf[o
o`3:ool0bP06oookJP03oi80oonOo`3oWol000Cooo]Z00Go1ol0oookJ_l0ohOo0?n7o`0;o`02oook
JP;oomH02?oonfX2o`3oG@03o`3oIol02?oo00So00;ooo]Z0_l0om<00ol0BOoooo]ZoookJP0<oook
JP;oog<02OoonfX2oiD0o`kooo]Z0_l0]olLoookJP;oo`2j0ooonfX2ooo=03Wooo]Z0013oookJP;o
obH05OoonfX2oone00kooo]Z0_n`0?l:oookJP;o0:co0ooonfX00ooo07Kooo]ZoookJP0BoookJP04
oa[o0?ooP`3ooh<0obco00[oogT00_oonfX01Ooo0;?o05coo`1LooooG03oobh000Kooo]Z0_nno`02
oookJP;oLOl000?o00KooookJ_l0oeP00ooonfX7oomi00;o0?nV2?ooN@02o`1Bo`05o`3o;_oonf[o
ooh0ooon0?n6o`000_oo=`001Ooog03oobP0oolX0?m9o`3ood`000;ooj8000?o0?mAoolX0?oo:000
1Ooo:003ool000;oobP01?oo0003oolX00[oo`001_oo:00@ool00003oomi0?oo003oo`0000;oo`00
4_oo:002oookJPCoolT00_oo08<<ooo900;onP3o00?ooo]Zool0]ooo0;L00_ooo`000oooN@3o>@3o
ocT0o`02oomi00;oo`3:1?oonfX2oomi00;oTP3o00?oogT0oookJ_oonfX00_oonfX01_l7o`3ooo]Z
o`3oQol0ohOo00_ooookJP;oomH02OoonfX8oomi0003o`19oooonf[ooo]Z00gooo]Z00?oog<0oook
J_oonfX02?oonfX00onE0?oooo]ZoookJP0>oookJP03o`2goooonf[ooo]Z01[ooo]Z0_oo0;X2oook
JP;oold0NooonfX2oolV01Gooo]Z0_oo]@0>oookJP;o/03o2ooonfX01?l0[?oooo]ZoookJ_oonfX2
ool0MQCooo]Z0_ooP`02obco00;ooo]Z00?o04Soo`3o`OoonfX01_oonfX00ooo0;?o05coo`1Lo`02
oomL00Kooo]Z0_nno`03oookJP;oLOl000?o00Koo`3oF?oonfX00ooonfX2o`3oe@?ooo]Z00Co01?o
o`2Tool0ojKo0?nV0_oonfX2oong00?ooo]Z0_l0D_l2o`3o;P04oookJ_oooP3oooh0ohKo00;oocL0
0_oog0001Om9o`3ooo]ZoonR0?ooXP3o0?mA00?ooo]Z00Kog03ooookJ_oonf[oodH0oookJ_ooR@02
oookJP04o`3omooonf[ooo]ZoookJP;o0>Go00?ooo]Zo`0]oooonfX01?oonfX01_l0=ooood<0oook
J_l0okKooo]Zol00o`Cooo]Z00CoYOl0o`000?l0003o00005?oonfX2ool0ZP07ooon0?ob0?oolP3o
oookJ_oo03_ooo]Zo`1?o`02ool0/@;ook/000?oo`0coookJ_oonfX01ooonfX2ool0P`03o`3oV?lV
o`3ooo]Z00;ooo]Z00?oh?l0oookJ_oonfX01?oonfX2ooX0o`04oookJ_oo0;Ooool0oooo00;ooo]Z
0_li0?l00ooonf[oo`3:ool0bP06oookJP;oTP3o00?oWol0oookJ_oonfX00_oonfX2o`Oo0005oook
J_l0ohOo00_oo`0;oooonfX00_ooeP08oookJP;o0?mM0_l0ofL00ol02?oooo]ZoookJP02o`3od`03
o`19oooonf[ooo]Z00cooo]Z0_ooL`09oookJP;oU@3o3ooonfX00ol0]ooooo]ZoookJP0JoookJP;o
o`2j0ooonfX2ooo=03_ooo]Z0012oookJP03oolV0?oonf[ooo]Z01Cooo]Z00?ookD0oookJ_oonfX0
3?oonfX2ok00o`_ooo]Z00Co0:cooookJ_oonf[ooo]Z0_oo07H?oookJP03oomi0?oonf[ooo]Z00;o
oo]Z00Co6_l0oon30?oonf[o;?l02?ooN@03oookJP05ool0/ol0G?oo05cooomL0?oo;P001_oonfX2
okko00?ooo]Z00?oLOl0o`06oooonfX00_l0oeP3oookJPKoogT00_l0ojH9oomi000:o`1Bool0obko
0?l^oookJ_oooP3oobP0ohKo0?oo=`3oobP0oooL00;ooo]Z00GoBOl0oonR0?ooXP3o0?mAo`2Wo`07
oolX00Goo`000_oo:002ool000GoobP01Ooo0002oolX00;oo`001_oo:005ool000CoobP03_oo000?
oolX00?ooo]Z0ooob@000ooo08?oolT0ooo90003ooo900;oh?l000?ooo]Zooo90?oob@000ooob@00
1?oj0?oooo]Zool0]ooo0;L2oooo0003oookJ_li0?oo>@3o00;oogT00_oo0<X3oookJP?oogT00_nB
0?l2oomi00?ooo]Z0_l7o`000ooonf[o0?n7o`0;o`02oookJP03oooF0?oonf[ooo]Z00Oooo]Z0_l0
oed00ol0ofOoogT0oomi0004oomi00oooo]Z0_ooL`09oookJP;oU@3o3ooonfX2o`2goacooo]Z00?o
o`2joookJ_oonfX00_ooc@1loookJP03oolV0?oonf[ooo]Z01Cooo]Z00?ookD0oookJ_oonfX03?oo
nfX2ok00o`_ooo]Z0_l0[?l3oookJP03ool0M_oonf[ooo]Z01;ooo]Z00Co6_l0oon30?oonf[o;?l0
0_oonfX2o`18o`Oooo]Z00Koo`2co`1Lool0G?oo06;ooomL0?oo;P06oookJP03okko0?oonf[ooo]Z
00;ooo]Z00CoLOl0o`06ool0oeSo0?mH1?oonfX01_l0omGooo]ZoookJ_oonf[o01?oo`2To`;o0?nV
0ooonfX00ooo]`3ooo]ZoookJP02oookJP04o`1Bool0obko0?l^oookJP;oooh000OoQ_l0oookJ_oo
=`3ooo]ZoooL0?oonf[oBOl000;ooj8000Co0?mAo`2Woooonf[ooo]Z0_oL0?l2oookJP03oom60?oo
nf[oohT000;ooo]Z00So0?ogoookJ_l0okOo0?ngo`3Uoooonf[oob`0o`0]o`Cooo]Z0_l0=ol3oook
JP03o`3o]_o00?oooo]Z00?ooo]Z0_nUo`03o`0001;ooo]Z00Coo`2Zooon0?oooP3oooh01?oonfX2
o`1?o`04ool0/Ooo^`3ook/0ool0<`Wooo]Z0_oo08<00ol0oiSo9_l0oookJP02oookJP;oh?l01_oo
nfX00ooj0?oooo]Zool0]`02oooo00;ooo]Z0_li0?l00ooonf[oo`3:ool0bP06oookJP;oTP3o00?o
Wol0oookJ_oonfX00_oonfX2o`Oo0004oookJ_l0ohOo0?n7o`0;o`;ooo]Z00?oomH0oookJ_oonfX0
1_oonfX2o`3oG@;o0?mW0_l02?l01?oonf[o0?oCo`3odol0BOl>oookJP;oog<02OoonfX2oiD0o`oo
oo]Z0_l0]olLoookJP04ool0^_oonf[ooo]ZoookJP;oold0?OoonfX0043ooo]Z0_oo9P0EoookJP;o
okD03_oonfX00on`0?oooo]ZoookJP09oookJP;o0:co0ooonfX00ooo07Kooo]ZoookJP0?oookJP04
oomi0?oonf[ooo]Zoa[o00;oogT00_l/o`06oomi00Cooo]Z0_oo0;<01?l0G?oo06;ooomL0?oo;P06
oookJP04okko0?oonf[ooo]ZoookJP;oLOl000?o00Koo`3oF?l0oeP01?oonfX6oomi0003o`3oY_oo
N@3oogT000KoogT000Gooo]Zo`1Bool0D_oo0?l^oookJP02ooon0003ohKo0?oo=`3oocL000;oom`0
00Cooo]ZodWo0?m9o`3ooj800_l0oe42oolX0003oookJ_oo:03oobP000CoobP01_oo00000ooo:03o
o`00oolX0006oolX00;oo`001Ooo:0000ooo003oobP0oolX000AoolX00[oo`003_oo:002oookJPGo
obP01?oob@02on3o00?ooo]Z1?oob@000ooj0?ooo`2gool0]`02oooo0005oookJ_li0?oo>@3ooook
J_ooN@000_oo0<X00ooonf[oogT0oomi0002oomi00?oTP3o0oooN@02oookJP;o1ol000?ooo]Zo`3o
Qol0ohL00_oonfX2oooF00Sooo]Z0_l0oed2o`3oI`03o`08ooooN@3oogT000?oogT03_oonfX2oomc
00Wooo]Z0_nE0?l?oookJP;o0;Oo7?oonfX2ool0^P;ooo]Z00?oold0oookJ_oonfX0N_oonfX2oolV
01Gooo]Z0_oo]@0>oookJP03ok00oooonf[ooo]Z00Wooo]Z0_l0[?l3oookJP;oo`1f4ooonfX00olJ
o`3ooh<0oon30002obco0003oookJ_l0B?oo04So00Oooo]Z0_oo0;<01?l0G?oo06;oo`1RooooG007
oookJP04okko0?oonf[ooo]ZoookJP;oLOl00_l0oeP4oookJP;o0?oE0ooonfX00ol04ooo0:Coo`3o
YP04oookJP04oong0?oonf[ooo]ZoookJP;o05;o00Co0?l^oookJ_oonf[oooh00_n6o`02oolg00;o
om`00_m9o`001?ooXP3ood`0o`3oDOl0@Ol2oookJP03om`0oooonf[ooo]Z00;oodH00_ooR@02oook
JP03o`3omooonf[o0?ng00;o0>Go00?ooo]Zool/0?l0;Ol00_l0oOl01?oonf[o03Ooo`0goooo@`02
oookJP;o0?nf00?o`03ooookJ_oonfX00_oonfX00onUo`3o0?lTo`000003o`0000oooo]Z1?oooP04
oookJP?o04oo00Cooo]Zool0/Ooo^`3oo`0c2OoonfX2ool0P`;o0?nH0ooonfX2on3o00Kooo]Z0_oj
0?l00ooo0;Ooool0oooo0002oookJP;o>@3o00?ooo]Zool0b_oo0<X01OoonfX3oi80o`03oioo0?oo
nf[ooo]Z00?ooo]Z00Go1ol0oookJ_l0ohOo0?n7o`0;o`02oookJP;oomH01ooonfX2o`3oG@;o0?mW
0_l02?l01?oonf[o0?oCo`3odol0BOl?oookJP03oomc0?oonf[ooo]Z00Oooo]Z0_nE0?l?oookJP;o
0;Oo7?oonfX2ool0^P?ooo]Z00?oold0oookJ_oonfX0?OoonfX003oooo]Z00?oobH0oookJ_oonfX0
5?oonfX00ooo]@3ooo]ZoookJP0<oookJP;o/03o2_oonfX2o`2/o`?ooo]Z0_oo07HAoookJP?oogT0
00Go6_l0oomi0?oonf[o;?l0oookJP04oomi00Kooo]Z00?oo`2co`1Lool0G?l00_ooG006oookJP;o
__l00ooonfX01?mao`3o00KooookJ_l0oeP5oookJP?oogT000Cooo]Zoomi0?l0ojKo0?nV1_ooN@02
oookJP;o05;o00[oogT0o`3o;_oonf[oooh0oeOo0?n6o`3oocL0oookJ_oog03ooo]Z0_m9o`001Ooo
XP3ooo]Zo`3oDOl0YoooobP000;ooo]Z1_oo:009ool000koobP00_ooN@0CoolX00[oo`001Ooo:002
ool000_oobP000?o0?nHooo90?oob@000_oob@000ooPo`3oolT0oookJP03oookJP?oolT000Gooo]Z
ool0]oooo`3oool0oookJP02ocT0o`;ooo]Z0_oo0<X5oomi00;oTP3o1OooN@001?oonf[o1ol0o`Oo
0?oonfX2o`3oQ`;ooo]Z0_ooeP08oookJP;o0?mM0_l0ofL2o`08o`03oookJ_l0om?oogT000;oogT0
3_oonfX00oooL`3ooo]ZoookJP07oookJP;oU@3o4?oonfX00ol0]ooooo]ZoookJP0JoookJP;oo`2j
0_oonfX2ooo=07cooo]Z00?oobH0oookJ_oonfX05?oonfX00ooo]@3ooo]ZoookJP0<oookJP;o/03o
2ooonfX01?l0[?oooo]ZoookJ_oonfX2ool0MQCooo]Z00Co6_l0oon30?oonf[o;?l00_oonfX00ol0
B?oo0?o1oookJP06oookJP04ool0/ol0G?oo05coo`1Ro`;ooe`01_oonfX2okko00;ooo]Z0_mao`00
0ol01_oo0?mHoookJP04oookJP06o`3oeOoonf[ooo]ZoookJ_l04ooo0:Co0_l0ojH3oookJP;ookL0
0ooonfX01?l0D_oo0?l^o`3o;_oonfX2ooon0007ohKo0?oonf[oocL0oookJ_oog03ooo]ZodWo0002
oonR0003oookJ_l0oe7o047o00;ooo]Z00Cog03ooookJ_oonf[oodH00_ooR@02oookJP;o0?og0_l0
okL01ol0iOoooo]ZoookJ_oo;03o02goo`3moooonfX00_oo0:401ol0=ooood<0oookJ_l0ok?o0?nf
oookJ_o00?l01OoonfX00onUo`3ooo]Zo`000003o`0000Sooo]Z1ooooP05oookJP?o04oo0_oonfX3
ool0<`Wooo]Z0_oo08<2o`3oV0?ooo]Z0_oPo`06oookJP;onP3o00?ooo]Zoooo0?ooo`000_oonfX2
ocT0o`03oookJ_oo0<[oo`3:00Gooo]Z0_nB0?l00ooonf[oWol0oioo0004oookJP;o1ol000?ooo]Z
o`3oQol02ol00_oonfX2oooF00Oooo]Z0_l0oed2o`3oI`;o00So00Cooo]Zo`3odol0om?o04Wo3ooo
nfX2oomc00Wooo]Z00?oU@3ooookJ_oonfX03_oonfX00ol0]ooooo]ZoookJP0JoookJP;oo`2j0ooo
nfX2ooo=043ooo]Z000moookJP;oobH05OoonfX2oone00kooo]Z00?o/03ooookJ_oonfX02OoonfX0
1?l0[?oooo]ZoookJ_oonfX2ool0MQ;ooo]Z1OooN@02obco0003o`18ooooN@3oogT000Oooo]Z00Ko
o`2co`1Lool0G?oo06;ooomL0?oo;P06oookJP03okko0?oonf[ooo]Z00;ooo]Z00CoLOl0o`06ool0
oeSo0?mH1?oonfX00ol0omGoogT0oookJP02oookJP03oomi0?l0ojKoogT000CoogT01?oonfX01?l0
D_oooo]Zo`3o;_ooN@02ooon0003ohKo0?oo=`3oocL000;oom`000Cooo]ZodWo0?ooXP3ood`00_l0
oe401Ol0Yooooo]ZoookJ_oonf[og03o00GoobP02Ooo0007oolX00?oo`000_oo:0000oo00?ooo`00
ool00003oomi0003oolX0?oo003oobP000ooobP02_oo0004oolX00;oo`003Ooo:002ooo900;oh?l0
00?oolT0oookJ_oonfX00_oonfX2ooX0o`04ooo90?oo0;Ooool0oooo00;ooo]Z00?o>@3ooookJ_oo
nfX00_oo0<X3oookJP;oogT00_nB0?l6oomi00;o1ol000?ooo]Zo`3oQol0ohL00_oonfX2oooF00So
oo]Z0_l0oed2o`3oI`;o00So00Kooo]Zo`3odol0om?o04WooookJ_ooN@0=oookJP;oog<02?oonfX2
oiD0oa3ooo]Z0_l0]olKoookJP;oo`2j0_oonfX2ooo=07cooo]Z0_oo9P0EoookJP;ookD03_oonfX0
0on`0?oooo]ZoookJP09oookJP;o0:co0ooonfX00ooo07Kooo]ZoookJP0BoookJP03oa[o0?ooP`3o
oh<000;o;?l000?ooo]Zo`18ool0B?l01ooonfX00ooo0;?o05coo`1Lo`02o`1Ro`03oomL0?oo;P3o
oo]Z00Gooo]Z00Ko__l0oookJ_oonf[ooo]Zog7o0?l01_l2o`3oF0Cooo]Z0_l0omD3oookJP03o`0C
ool0ojKo0?nV00Cooo]Z00?ookL0oookJ_oonfX00_oonfX00ol0D_oo0?l^oookJP02ooon00;oQ_l0
0_oo=`02oooL00;oBOl000Cooj80oom<0?l0oe7o0?mA0ooonfX01OoL0?oooo]ZoookJ_ooAP3oohT0
00?ooo]Z00Ko0?ogoookJ_l0okOok`3oo`3UoooonfX2oa;o000<o`0]ool0oOoo0?n^ool0XOoonf[o
03Oooom30?oonf[o0?nco`3o]_oonf[o`03o1OoonfX00ol0obCoYOl0oookJP04o`00017ooo]Z0ol0
Col2oookJP?oo`0c2OoonfX3ool0P`03o`3oV?oonf[ooo]Z00;ooo]Z0_oPo`06oookJP;onP3o00?o
oo]Zoooo0?ooo`000_oonfX2ocT0o`03oookJ_oo0<[oo`3:00Gooo]Z0_nB0?l00ooonf[oWol0oioo
0004oookJP;o1ol000?ooo]Zo`3oQol0ohL00_oonfX2oooF00Oooo]Z0_l0oed2o`3oI`;o00So00?o
oo]Zo`3odol0om<00_l0BOl>oookJP;oog<02OoonfX2oiD0o`oooo]Z0_l0]olKoookJP;oo`2j0ooo
nfX2ooo=04;ooo]Z000loookJP03oolV0?oonf[ooo]Z01Cooo]Z00?ookD0oookJ_oonfX03?oonfX2
ok00o`[ooo]Z0_l0[?l3oookJP03ool0M_oonf[ooo]Z017ooo]Z1_ooN@001?oonf[o04Soo`3o`Ol0
ol46oookJP;oo`2c00Co05cooookJ_l0H_oooe`01_oonfX2okko00?ooo]Z0_mao`000ooonf[o0?mH
oookJP04oookJP05o`3oeOoonf[ooo]ZoookJ_l04ol00_l0ojH3oomi0003oookJ_oo]`3ooo]Z00;o
oo]Z0_l0D_l02_oonf[o0?l^oomi0?oooP3oogT0ohKo0?oo=`3ooo]ZoooL0?oonfX2odWo0003oonR
0?ooC03o0?mA00;o0:Oo0_oonfX2om`0o`GoobP02Ooo0006oolX00Koo`0000?o`03oool00?oo0000
1?ooN@02ool000_oobP00ooo0003oolX00Woo`000ooo:002ool000goobP00ooPo`02ooo900?ooo]Z
0_oj0?l01?oonf[oo`2goooo0?ooo`02oookJP;o>@3o00?ooo]Zool0b_oo0<X01OoonfX2oi80o`Go
ogT00ol7o`000ooonf[o0?n7o`3oQ`02oookJP;oomH01ooonfX3oomi00;o0?mW0_l02?l01?oonf[o
0?oCo`3odol0BOl?oookJP;oog<02OoonfX00onE0?oooo]ZoookJP0>oookJP;o0;Oo7?oonfX00ooo
0;[ooo]ZoookJP02ooo=07gooo]Z00?oobH0oookJ_oonfX05?oonfX00ooo]@3ooo]ZoookJP0<oook
JP;o/03o2ooonfX01?l0[?oooo]ZoookJ_oonfX2ool0MQ?ooo]Z0_lJo`000oooP`3o;?l0obco0002
oookJP03o`18ool0ol7ooo]Z00Gooo]Z0_oo0;<01Ol0G?oooo]Zo`1Roooonf[ooe`000Kooo]Z0_nn
o`02oookJP;oLOl000?o00Koo`3oF?oonfX01?oonfX00ol0omGooo]ZoookJP02oookJP03o`2Tool0
ojKooo]Z00?ooo]Z0_oo]`03oookJP;o05;o00_o0?l^oookJ_oooP3oEol0ohKo0?oonf[oocL0oook
J_oog03ooo]ZodWo0002oonR0003oookJ_l0oe7o0:Oo00;ooo]Z0_oL0?l01?oonf[oodH0oom60?oo
R@03oookJP03o`3omooonf[o0?ng00;o0>Go00Oooo]Zoa;o0?l0;Ooooo]Zo`3moooonf[oo`2Q00;o
03Oo00Kood<0oookJ_l0ok?o0?nfoookJ_o00?l5oookJP;oYOl00_oonfX4o`0001?ooo]Z0ooo03<8
oookJPCoo`230_l0oiP3oookJP?oh?l01_oonfX2ooX0o`03oookJ_ooo`3oool000;ooo]Z0_li0?l2
oookJP03ool0b_oonf[ooo]Z00?ooo]Z0_nB0?l00ooonf[oWol0oioo0003oookJP?o1ol000?ooo]Z
o`3oQol0ohL00_oonfX2oooF00Oooo]Z0_l0oed2o`3oI`03oookJ_l02?oooo]Z00;o0?oC0_l0BOl>
oookJP;oog<02OoonfX2oiD0o`oooo]Z0_l0]olLoookJP04ool0^_oonf[ooo]ZoookJP;oold0A?oo
nfX003[ooo]Z0_oo9P0EoookJP;ookD03_oonfX00on`0?oooo]ZoookJP08oookJP;o0:co0ooonfX2
ool0MQ?ooo]Z2?ooN@000ol0ol7ooo]ZoookJP05oookJP04ool0/ooonf[o05coo`1Ro`;ooe`01_oo
nfX00onno`3ooo]ZoookJP02oookJP04og7o0?oonf[ooo]Zo`3oF0Cooo]Z0_l0omD3oookJP04o`0C
ool0ojKoogT0oomi00;ooo]Z0_oo]`03oookJP06o`1Boooonf[o0?l^o`3o;_ooN@3oooh00_ooN@00
0ooo=`3oom`0oooL0002odWo0005oookJ_ooXP3ood`0o`3oDOl0Yol00ooonfX00ooL0?oooo]ZoolX
0004oolX00Soo`001_oo:00;ool00004oomi0?oo003oo`00oomi00;oo`003?oo:003ool000;oobP0
2_oo00001?oo:03oo`00ool00?oo000:oolX00?oh?l00ooonfX00ooob@3ooo]ZoookJP02ooX0o`04
oookJ_oo0;Ooool0oooo00;ooo]Z0_li0?l00ooonf[oo`3:ool0bP05oookJP;oTP3o00?oWol0oomi
0?ooN@000_ooN@02o`Oo00;ooo]Z0_l0ohL01?l02ooooo]ZoooF0?ooeP05oookJPGoogT00_l0ofL2
o`08o`04oookJ_l0om?o0?oCo`19o`oooo]Z0_ooL`09oookJP;oU@3o3ooonfX2o`2goacooo]Z0_oo
0;X2oookJP03ooo=0?oonf[ooo]Z07_ooo]Z0_oo9P0EoookJP;ookD03_oonfX00on`0?oooo]Zoook
JP09oookJP;o0:co0_oonfX2ool0MQCooo]Z00Co6_l0oon30?ooP`3o;?l00_oonfX2o`18o`Oooo]Z
00?oo`2coookJ_l0G?l00_l0H_l2oomL00Kooo]Z00So__l0oookJ_oonf[ooo]Zog7o0?l01_oooo]Z
o`3oF0Cooo]Z0_l0omD3oookJP03o`0Cool0ojKo0?nV00Cooo]Z00?ookL0oookJ_oonfX00_oonfX0
1ol0D_oo0?l^o`3o;_oonf[oooh0oeOo0?n6o`000_oo=`02oooL00;oBOl000Gooj80oom<0?l0oe7o
0?mAo`11o`02oookJP05om`0oooonf[ooo]Zoom60?ooR@000ooonfX2o`3om`;o0?ng017o0>Gooook
J_oonf[o4_l0o`0]oooonf[o0?gooookJ_oo0:7o03Ooooo90?oo@`3ooo]Zo`3o/ol0eOoo0?nfol00
o`05oookJP03ojGo0?l0obCooo]Z00;ooo]Z1?l00002oookJP03o`02oooonf[ooo]Z00Gooo]Z2Ooo
03<:oookJP03ool0Pooonf[o0?nH00;o0?nH0_oonfX3on3o00Oooo]Z0_oj0?l00ooonf[oool0oooo
0002oookJP;o>@3o0_oonfX2ool0bPCooo]Z0_nB0?l00ooonf[oWol0oioo0003oookJP;o1ol00_oo
nfX2o`3oQ`;ooo]Z0_ooeP07oookJP;o0?mM0_l0ofL00ooonf[o00Soo`08o`02o`3od`;o04Wo3_oo
nfX2oomc00Wooo]Z0_nE0?l?oookJP;o0;Oo7?oonfX2ool0^P?ooo]Z00?oold0oookJ_oonfX0A?oo
nfX003Wooo]Z00?oobH0oookJ_oonfX05?oonfX00ooo]@3ooo]ZoookJP0=oookJP03ok00oooonf[o
oo]Z00Sooo]Z00?o0:cooookJ_oonfX00_oonfX00ooo07Kooo]ZoookJP0BoookJP[oogT01OoonfX2
ool0/`;o05co00?o06;ooomL0?oonfX01OoonfX2okko00?ooo]Z0_mao`000ooonf[o0?mHo`3oF004
oookJP03o`3oeOoonf[ooo]Z00;ooo]Z0_l0ojH4oookJP03oong0?oonf[ooo]Z00;ooo]Z00Co05;o
oookJ_l0obkooo]Z0_oooP04oomi0006oookJ_m9o`3ooo]ZoookJ_ooXP3o0?mA0_l0Yol2oookJP;o
g03o00?ooo]ZoolX0?oo:0000_oo:0000ooonf[oobP0ool00005ool000KoobP03?oo0002oomi00?o
o`000_ooN@0;oolX0003ool00?oo:03oo`0000?oobP03_oo0006oolX00Coh?l000?oobP0oookJ_oo
nfX00ooonfX3ooX0o`04oookJ_ooo`3oool0oooo00;ooo]Z0_li0?l00ooonf[oo`3:ool0bP05oook
JP;oTP3o0_nOo`02oookJP04oomi0?l7o`3o1ol0oomi00;ooo]Z00Go0?n7o`0;oooonf[ooo]ZoooF
0004oookJPKoogT00_l0ofL2o`08o`04oookJ_l0om?o0?oCo`19o`oooo]Z0_ooL`08oookJP?oiOl0
3ooonfX2o`2goacooo]Z0_oo0;X2oookJP;oold0OOoonfX00ooo9P3ooo]ZoookJP0DoookJP03oone
0?oonf[ooo]Z00gooo]Z00?o/03ooookJ_oonfX02OoonfX01Ol0[?oooo]ZoookJ_oonf[oo`1f01Co
oo]Z0_lJo`000oooP`3o;?l0obco0002oookJP03o`18ool0ol7ooo]Z00Gooo]Z0_oo0;<2o`1Lo`03
o`1Roooonf[ooe`000Kooo]Z0_nno`02oookJP;oLOl000?o00Koo`3oF?l0oeP01?oonfX00ol0omGo
oo]ZoookJP02oookJP;o0?nV1?oonfX2oong00?ooo]Z0_l0D_l01?l0obkooo]ZoookJ_oooP02ohKo
000;oolg0?oonf[oom`0oookJ_m9o`3ooo]ZoonR0?oonf[o0?mAo`2Wool0@Ol00_oonfX01OoL0?oo
oo]Zoom60?ooAP3oohT000?ooo]Z00Ko0?ogo`08oonco`3ok`3oo`3Uool0on42oa;o0008o`0]ool0
oOoo0?gooookJ_oo0:7o03Ooooo90?oo@`02o`3o/`03o`3Eool0okKo`03o00Kooo]Z00?oYOl0oook
J_oonfX00_oonfX4o`0000;ooo]Z00Co00;ooookJ_oonf[ooo]Z0_l0oiPDoookJP05ool0Pol0oiSo
0?nHobKo0?oonfX00ooPo`07oookJP?onP3o0oooo`02oookJP;o>@3o0_oonfX2ool0bPCooo]Z0_nB
0?l00ooonf[oWol0oioo0003oookJP;o1ol00_oonfX2o`3oQ`;ooo]Z0_ooeP08oookJP04o`3oGOl0
ofOo0?mWoookJP;o00So00Cooo]Zo`3odol0BOoo04Wo3_oonfX2oomc00Wooo]Z0_nE0?l?oookJP;o
0;Oo7?oonfX2ool0^P?ooo]Z0_ooc@17oookJP00=ooonfX2oolV01Gooo]Z0_oo]@0>oookJP;o/03o
2OoonfX2o`2/o`?ooo]Z0_oo07HDoookJPWoogT01_oonfX00ooo0;?ooo]Zo`1Lo`02o`1Ro`03oomL
0?oonf[ooo]Z00Cooo]Z00?o__l0oookJ_oonfX00_oonfX01?mao`3ooo]ZoookJ_l0oeP5oookJP06
o`3oeOoonf[ooo]ZoookJ_l04ooo0?nV1OoonfX01?oo]`3ooo]ZoookJ_oonfX2o`1Bo`;o0?l^00?o
oo]Zooon0?ooN@001OooN@001_m9o`3ooo]ZoonR0?ooXP3o0?mAo`2Wo`?ooo]Z00?og03ooookJ_oo
nfX00ooo:0000ooonf[oobP0o`3om`05ool000WoobP02ooo00000oooN@3oo`00ool00003ool000co
obP000Coo`00oolX0?oo:03oogT00ooo:00>ool000CoobP000?oh?l0oolX0?oo:0000_oo:004oook
JP;onP3o00Gooo]Zoooo0?ooo`3oool0ool0]`02oookJP;o>@3o00?ooo]Zool0b_oo0<X01OoonfX2
oi80o`;oWol00ooonfX2o`Oo00;oogT000?ooo]Zo`3oQol0ohL00_oonfX2oooF0003oookJ_ooN@3o
ogT000KoogT00_l0ofL2o`08o`04oookJ_l0om?o0?oCo`19o`oooo]Z0_ooL`06oookJPGoiOl03ooo
nfX2o`2goacooo]Z0_oo0;X2oookJP;oold0OOoonfX2oolV01Gooo]Z0_oo]@0>oookJP;o/03o2_oo
nfX2o`2/o`;ooo]Z0_oo07HDoookJP04oa[o0?ooP`3ooh<0obco00;ooo]Z0_l0B?l00ol0ol7ooo]Z
oookJP04oookJP03ool0/ooonf[o05co00;o06;o00?oobh0oomL0?oonfX01?oonfX2okko00?ooo]Z
00CoLOl0o`06oooonf[o0?mH1OoonfX00ol0omGooo]ZoookJP02oookJP03o`3oY_oonf[ooo]Z00?o
oo]Z00?ookL0oookJ_oonfX00_oonfX00ol0D_oooo]Zo`3o;P02oookJP08ooon0?n6o`3ooo]Zoolg
0?oonf[oom`0oookJ_m9o`02oonR00;o0?mA00Wo0:OooookJ_oonf[ooo]Zom`0oooonf[oodH0oook
J_ooR@000ooonfX02ol0ooOo00Sook?o0?oonf[o0>Goo`3ohOlBo`3oob`0o`0]ool0oOoo0?n^00;o
o`2Q00Go03Ooooo90?oo@`3o0?nco`3Eo`02o`3o]P05ol00oooonf[ooo]ZoookJ_ooN`000_oonfX0
1_nUo`3ooo]ZoookJ_oonf[o097ooookJP;o000000Ooom<0o`000?oonf[ooo]Zo`02oooonf[oold0
00?ooo]Z00?oh?l0o`3oV?oonfX03_oonfX3o`3oV0?ooo]Z0_oPo`07oookJP?onP3o0oooo`000ooo
0;Oooo]ZoookJP02ocT0o`04oookJ_oo0<[oo`3:ool0bPCooo]Z0_nB0?l00ooonf[oWol0oioo0003
oookJP;o1ol00_oonfX2o`3oQ`;ooo]Z0_ooeP08oookJP04o`3oGOl0ofOo0?mWoookJP;o00So00Co
oo]Zo`3odol0om?o04Wo3_oonfX2oomc00Wooo]Z0_nE0?l?oookJP;o0;Oo7?oonfX2ool0^P?ooo]Z
0_ooc@19oookJP00=_oonfX00ooo9P3ooo]ZoookJP0CoookJP;ookD03ooonfX00on`0?oooo]Zoook
JP08oookJP03o`2/oooonf[ooo]Z00;ooo]Z00?oo`1foookJ_oonfX04_oonfX00olJo`3oogT0oomi
0005oomi0003o`3o`Ooonf[ooo]Z00Gooo]Z00Coo`2coookJ_l0G?oo06;o0_ooG005oookJP;o__l0
0ooonfX2og7o0003oookJ_l0oeSo0?mH00Cooo]Z0_l0omD3oookJP;o0?nV1?oonfX2oong00?ooo]Z
00?o05;ooookJ_l0obh00_oonfX00ooooP3oogT0oomi0006oomi0004oonR0?l0oe7ooo]Zo`2Wo`;o
oo]Z0_oL0?l01?oonf[oodH0oolX0?ooR@03oolX0003o`3omooo003oo`0000;oo`002Ooo:00=ool0
0003oomi0?oo003oo`0000?oo`001_oo:0000ooo003oobP0oolX0003oolX00;oo`001_ooN@000ooo
003oogT0ool0000:ool00004oolX0?oPo`3oh?l0on3o00CoobP00_oonfX3ooX0o`?oool00_oo0;L2
oookJP;o>@3o00?ooo]Zool0b_oo0<X01?oonfX3oi80o`;oWol00ooonfX2o`Oo00;ooo]Z00?oogT0
o`3oQol0ohL00_oonfX2oooF0003oookJ_ooN@3oogT000OoogT000Co0?mWo`08ool02?oooo]Z0_l0
om<00ol0BOoooo]ZoookJP0=oookJP;oog<01OoonfX7onGo00oooo]Z00?o0;OooookJ_oonfX06ooo
nfX00ooo0;[ooo]ZoookJP02ooo=07kooo]Z00?oobH0oookJ_oonfX05?oonfX00ooo]@3ooo]Zoook
JP0=oookJP03ok00oooonf[ooo]Z00Wooo]Z00Go0:cooookJ_oonf[ooo]Zool0MP0DoookJP;o6_l0
00?ooh<0obco0?l/o`000_oonfX00ol0B?oo0?o1oookJP06oookJP05ool0/ooonf[o05coo`1Roooo
nfX00_ooG005oookJP04okko0?oonf[ooo]ZoookJP;oLOl000?o00Koo`3oF?l0oeP01?oonfX2o`3o
e@?ooo]Z0_l0ojH4oookJP;ookL00ooonfX2o`1Bo`;o0?l^0_oonfX01?oooP3oQ_l0oolg0?oo=`02
oooL0007oookJ_m9o`3ooj80oookJ_l0oe7o047oo`2Wo`02oookJP;og03o0_ooAP02oon900?ooo]Z
01Go0?ogo`08oonco`3ooo]Zo`3Uool0on7o4_l0ool/0?l0;Ooo0?goo`3o[_oo0:7ooo]Zo`0goooo
b@3ood<0o`3o/ol0eOoo0?nfoookJ_o00?l01?oonfX01?ooN`3ooo]Zo`3o9?nUo`03oookJP05o`2A
oooonf[oOP3oo`000?ood`000_l000001Ooonf[o00;ooookJ_ooc@3oo`2j00;ooo]Z0_oPo`03o`3o
V0Wooo]Z0ol0oiP4oookJP;oh?l01ooonfX2ooX0o`?oool00_oo0;L2oookJP;o>@3o00?ooo]Zool0
b_oo0<X01?oonfX3oi80o`?oWol00ooonfX2o`Oo00;ooo]Z0_l0ohL2oookJP;oomH02?oonfX2o`3o
G@05o`3oIooonf[o00Soo`08oooonfX00_l0om<00ol0BOoooo]ZoookJP0<oookJP;oog<02_oonfX0
0onE0?oooo]ZoookJP0>oookJP03o`2goooonf[ooo]Z01_ooo]Z00Coo`2joookJ_oonf[ooo]Z0_oo
c@1;oookJP00=?oonfX2oolV01Gooo]Z00?ookD0oookJ_oonfX03OoonfX2ok00o`Wooo]Z0_l0[?l3
oookJP;oo`1f5?oonfX00olJo`3oogT0oomi0003oomi0003o`18ool0ol7ooo]Z00Kooo]Z0_oo0;<0
1?oonf[o05cooookJ_ooG006oookJP03okko0?oonf[ooo]Z00;ooo]Z00CoLOl0oookJ_oonf[o0?mH
1OoonfX01_l0omGooo]ZoookJ_oonf[o01?oo`3oYPGooo]Z00?ookL0oookJ_oonfX00_oonfX01?l0
D_oo0?l^o`3o;_oonfX2ooon00[oogT00_l0Yol2oookJP07om`0oooonf[ooo]Zoom60?oonf[oohT0
oomi0003oolX00?oo`0000?oobP0ool00?oo:0000_oo:0001?l0oOooobP0ool00?oo:00Eool000Go
obP00ooo0004oolX00;oo`002OooN@000ooo003oogT0ool00004oomi00Coh?l00_oo:0001?oonf[o
obP0oolX0?oo:003ooX0o`03oookJ_ooo`3oool000;oo`2g0_oonfX3ocT0o`03oookJ_oo0<[oo`3:
00Cooo]Z0_nB0?l2oioo00Cooo]Z0_l7o`02oookJP?o0?n70_oonfX2oooF00?ooo]Z1oooN@02o`3o
I`04o`08oooonf[o0?oCo`3od`;o04Wo3_oonfX2oomc00?ooo]Z2_oUo`0>oookJP;o0;Oo7?oonfX2
ool0^P03oookJ_ooc@3oold007kooo]Z0_oo9P0FoookJP03oone0?oonf[ooo]Z00cooo]Z0_n`0?l:
oookJP;o0:co0_oonfX2ool0MQCooo]Z00Co6_l0oon30?ooP`3o;?l00_oonfX2o`18o`03o`3o`Ooo
nf[ooo]Z00Cooo]Z0_oo0;<00ooonf[o05coo`1Ro`02oomL00Gooo]Z0_nno`03oookJP04og7o0?l0
1_oooo]Zo`3oF0Gooo]Z00?o0?oEoookJ_oonfX00_oonfX00ol0ojKo01?ooookJP03oookJP03oong
0?oonf[ooo]Z00;ooo]Z00?o05;ooookJ_l0obh00_oonfX2ooon0004ohKo0?oo=`3ooo]ZoooL00;o
oo]Z00CoBOl0oonR0?oonf[o0?mA0_l0Yol2oookJP05om`0oooonf[oodH0oookJ_ooR@000ooonfX2
o`3om`06o`3o]onco`3oo`3>o`3Uool0on7o4_l00_l0;Ol03?l0oOoo0?n^ool0XOooX03o03Ooooo9
0?oo@`3ooo]Zo`3o/ol0okKooo]Zol00o`Cooo]Z00Coog/0oookJ_l0obCoYOl00ooonfX01Ol0TOoo
oo]ZoookJ_oo2P3oom<000;o00000_oonfX01?l00_oooo]ZoookJ_ooc@04oookJPCoh?l02?l0oiP0
0ooonf[oh?l0on3o0004on3o00Kooo]Z0ooj0?l2oooo00;oo`2g0_oonfX3ocT0o`03oookJ_oo0<[o
o`3:00Cooo]Z0_nB0?l3oioo00Cooo]Z0_l7o`001?oonf[o0?n7o`3oQol0ohL2oookJP;oomH02Ooo
nfX00ol0oego0?mWo`3oI`02o`08o`04oookJ_l0om?o0?oCo`19o`kooo]Z0_ooL`0:oookJP;oU@3o
3ooonfX2o`2goacooo]Z0_oo0;X2oookJP;oold0COoonfX003?ooo]Z00?oobH0oookJ_oonfX04ooo
nfX2oone00oooo]Z00?o/03ooookJ_oonfX02?oonfX00ol0[?oooo]ZoookJP02oookJP03ool0M_oo
nf[ooo]Z01;ooo]Z0_lJo`03oomi0004oookJ_l0B?oo04Soo`3o`@Cooo]Z00GoogT0oookJ_oonf[o
o`2coookJP02o`1Lo`;ooe`01OoonfX2okko00?ooo]Z0_mao`02oookJP03o`3oF?oonf[ooo]Z00;o
oo]Z0_l0omD3oookJP03o`0Cool0ojKooo]Z00Cooo]Z00CookL0oookJ_oonf[ooo]Z0_l0D_l01Ol0
obkooo]ZoookJ_oooP3oEol000_oogT000Co047ooookJ_oonf[og03o0_oonfX01?ooAP3ooo]Zoon9
0?ooN@05oolX00;oogT000Goo`00oolX0?oo:03oobP0o`3mo`02oolX00Coo`0000?oogT0ool00?oo
00003ooo0005oolX0004ool00?oo:03oo`00ool000GoobP01_oo0009oomi00?oo`000oooN@000ooo
:03oogT0oomi0002oomi0003ooX0oooo0;OoobP000;oool01Ooo:0000oli0?oooo]Zool0bP02ool0
bPCooo]Z0_nB0?l2oioo00Cooo]Z0_l7o`001?oonf[o0?n7o`3oQol0ohL2oookJP?oomH01_oonfX4
oomi00;o0?mW00Co00SooookJ_l0om?o0?oC0_l0BOl>oookJP;oog<00ooonfX;onGo00gooo]Z0_l0
]olKoookJP?oA?l00_oonfX00oooc@3ooo]ZoookJP1moookJP03oolV0?oonf[ooo]Z01Cooo]Z0_oo
]@0>oookJP03ok00oooonf[ooo]Z00Wooo]Z00Go0:cooookJ_oonf[ooo]Zool0MP0DoookJP;o6_l0
00?ooh<0obco0?l/o`000_oonfX00ol0B?oo0?o1oookJP06oookJP07ool0/ooonf[o05coo`1Lool0
H_oooe`0ool^0004oookJP;o__l00ooonfX2og7o0003o`06oooonf[o0?mH00Cooo]Z0_l0omD4oook
JP03o`3oY_oonf[ooo]Z00?ooo]Z00CookL0oookJ_oonf[ooo]Z0_l0D_l01_oonf[o0?l^oookJ_oo
nf[oooh0ohKo00;oocL000Wooo]ZoooL0?oonf[ooo]ZodWo0?ooC03ooo]Zo`3oDOl0Yol00_oonfX2
om`0o`04oookJ_ooAP3ooo]Zoon900?ooo]Z00Go0?ogoookJ_nco`3o/ol0oookJP02o`3oh@04ool/
0?lBo`3ooo]Zo`3mo`;oo`2Q00_ooj00o`0goooo@`3ood<0oookJ_l0ok?o0?nfoookJ_o00?oooo]Z
ool0X`02oookJP04oomk0?oonf[ooo]ZojGo00Cooo]Z00Go097ooookJ_mn0?ooo`X0oooC0002o`00
0006oookJ_l0ogco00;oo`0Joooonf[oold01?oonfX01?oj0?oooo]ZoookJ_oonfX9on3o00Sooo]Z
1?oj0?l01?oo0;Ooool0oooo0?oo0;L2oookJP?o>@3o00Cooo]Zool0b_oo0<[oo`3:1?oonfX2oi80
o`;oWol01OoonfX2o`Oo00?o0?n700?o00_ooookJ_oonfX00_ooeP09oookJP04o`3oGOl0ofOo0?mW
o`08o`;ooo]Z0_l0om<00ol0BOoooo]ZoookJP0<oookJP;oog<02_oonfX2oiD0o`oooo]Z0_l0]olL
oookJP;oo`2j0ooonfX00oooc@3ooo]ZoookJP1=oookJP00<OoonfX2oolV01Gooo]Z00?ookD0oook
J_oonfX03OoonfX2ok00o`[ooo]Z00Co0:cooookJ_oonf[ooo]Z0_oo07HDoookJP04oa[o0?ooP`3o
ogT0obco00;ooo]Z00?o04Soo`3o`OoonfX00ooonfX00oooN@3ooo]Zoomi0002ool0/`04oookJ_l0
G?oooo]ZoomL00Kooo]Z00?o__l0oookJ_oonfX00_oonfX00omao`3o00KooookJP02o`3oF0Cooo]Z
00?o0?oEoookJ_oonfX00_oonfX2o`3oYPGooo]Z00GookL0oookJ_oonf[oogT0o`1Bo`02o`3o;P;o
oo]Z00?oooh0oeOo0?ooN@003?ooN@002?oonf[og03ooookJ_oonf[oodH0oookJ_oo:03oogT01_oo
:002oomi00?oobP000?o0?gooolX0?oo:0001?oo00000ooo:03oo`00ool0000@ool000CoobP01_oo
0004oolX00Soo`002Ooo:007oomi00;oobP00oooo`05oolX0004oookJ_oo0<[oo`3:ool0bPGooo]Z
0_nB0?l2oioo00?ooo]Z0ol7o`001?oonf[o0?n7o`3oQol02ol2oookJP;oomH02OoonfX3oomi0003
o`3oIol02?ooogT000;o0?oC0_l0BOl>oookJP;oog<01OoonfX:onGo00cooo]Z0_l0]olIoookJPGo
A?l00_oonfX2ooo=07kooo]Z0_oo9P0FoookJP03oone0?oonf[ooo]Z00cooo]Z0_n`0?l;oookJP03
o`2/oooonf[ooo]Z00;oo`1f5?oonfX01?lJo`3ooh<0oon30?l/o`02oookJP;o04So00?o0?o1oook
J_oonfX01?oonfX2ool0/`03oookJ_l0G?oo06;o00;ooe`01OoonfX00onno`3ooo]ZoookJP02oook
JP03og7o0?l01_oooo]Z00;o0?mH1?oonfX00ol0omGooo]ZoookJP02oookJP03o`2Tool0ojKooo]Z
00Cooo]Z00KookL0oookJ_oonf[ooo]Zo`1BoooonfX2o`3o;P06oookJ_oooP3oooh0ohKo0?oo=`3o
oo]Z0_oog0000ooonf[oBOl0odWo0002oookJP05o`3oDOl0Yooooo]ZoookJ_oL0?l00_oonfX00ooo
AP3ooo]Zoon90003oookJP0@o`3omooonf[o/ol0onl0ool0iOoo0?oQoookJ_oo;03o4_l0oookJ_l0
oOooo`2QoookJ_ooX03o03Oooom300;ooo]Z00Ko0?ncool0:ooonf[o`03ooookJ_oo0:<2oookJP04
oomk0?oonf[ooo]ZojGo00?ooo]Z00Oo0?mjool0c_oonf[ooo]Zool:0?l0003oom<000;o000000Co
oo]Zo`3oO?l00_oo01[o0_oonfX00oooc@3ooo]ZoookJP02oookJPConP3o3OoonfX3ooX0o`;oo`2g
0oooo`000ooonf[o>@3oocT0o`02ocT0o`;ooo]Z0_oo0<X5oookJP;oTP3o0_nOo`04oookJP?o1ol0
0_l0ohL2o`0;o`;ooo]Z0_ooeP09oookJP;o0?mM00?o0?mWo`08oooonfX00ol0om<00ol0BOoooo]Z
oookJP0<oookJP;oog<02_oonfX2oiD0o`oooo]Z0_l0]olLoookJP;oo`2j0ooonfX2ooo=053ooo]Z
000_oookJP;oobH05OoonfX2oone00oooo]Z00?o/03ooookJ_oonfX02?oonfX2o`2/o`;ooo]Z0_oo
07HEoookJP04oa[o0?ooP`3o;?l0obco00;ooo]Z00?o04Soo`3o`OoonfX01?oonfX2oomi0004ool0
/oooN@3oogT0o`1Lo`;ooe`01OoonfX2okko00?ooo]Z0_mao`02oookJP03o`3oF?oonf[ooo]Z00;o
oo]Z0_l0omD3oookJP03o`0Cool0ojKooo]Z00Cooo]Z0_oo]`02oookJP03o`1BooooN@3o0?l^00;o
oo]Z0_oooP000on6o`3oogT0oomi000:oomi00;ooo]Z00Kog03ooookJ_oonf[oodH0oookJ_ooR@09
oolX0004oomi0?oo:03oobP0o`3mo`;oobP01_oo00000ooo:03oo`00ool0000?ool000?oobP000?o
om<0ool00?oo00001?oo0005oolX00Ooo`004Ooo:0000oooo`3oobP0oolX0005oolX00;oo`3:1_oo
nfX2oi80o`;oWol00ooonfX2o`Oo0004oookJ_l0ohOo0?n7o`3oQ`?ooo]Z0_ooeP08oookJP?o0?mM
00Cooo]Zo`3oIol0ofOoogT00_l0om<2o`19o`kooo]Z0_ooL`08oookJPOoiOl03?oonfX2o`2goaSo
oo]Z1om4o`000ooonf[oold0ooo=001noookJP;oobH05_oonfX2oone00kooo]Z00?o/03ooookJ_oo
nfX02OoonfX2o`2/o`;ooo]Z00?oo`1foookJ_oonfX04ooonfX01?lJo`3ooh<0obco0?l/o`02oook
JP03o`18ool0ol7o0?o100Kooo]Z00Coo`2coookJ_oonf[o05co0_ooG0000ooo;P3ooo]ZoookJP02
oookJP;o__l00ooonfX2og7o0003o`06oooonf[o0?mH00Cooo]Z0_l0omD4oookJP;o0?nV1?oonfX2
oong00?ooo]Z00?o05;ooookJ_l0obh00_oonfX01_oooP3oQ_l0oolg0?oo=`3ooo]ZoooL00;ooo]Z
00KoBOl0oonR0?oonf[ooo]Zo`3oDOl0Yol2oookJP06om`0oooonf[ooo]Zoom60?oonf[oohT00ooo
nfX04Ol0ooOo/ol0ok?o0?o_0?oo0>Goo`3ohOoo;03o02gooa;o0?oonf[o0?goool0XOoonf[ooj00
o`0goooo@`3ooo]Z00;o0?nc00Goo`0[oookJ_o00?oooo]Zool0X`02oookJP05oomk0?oonf[ooo]Z
o`3o9?nUo`000_oonfX02?l0og[oo`3>oookJ_oonf[oOP3oool:0?l0003oom<00_l000001ooonf[o
0?mlo`02ool06_oo0?l0oookJ_ooc@002?oonfX=ooX0o`;oo`2g0oooo`02oookJP;o>@3o0ooonfX3
ool0bPGooo]Z0_nB0?l2oioo00Cooo]Z0_l7o`03o`3oQ`04o`0;oooonf[ooo]ZoookJP;oomH02?oo
nfX3o`3oG@;o0?mW00?ooo]Zo`3odol0om<00_l0BOl>oookJP;oog<02ooonfX00onE0?oooo]Zoook
JP0=oookJP;o0;Oo7?oonfX2ool0^P?ooo]Z0_ooc@1BoookJP00;_oonfX00ooo9P3ooo]ZoookJP0D
oookJP03oone0?oonf[ooo]Z00kooo]Z00?o/03ooookJ_oonfX02?oonfX01Ol0[?oooo]ZoookJ_oo
nf[oo`1f01Gooo]Z00Co6_l0oon30?ooP`3o;?l00_oonfX2o`18o`Kooo]Z0_ooN@001Ooo0;?oogT0
o`1Lool0G?oooe`000Kooo]Z00?o__l0oookJ_oonfX00_oonfX00omao`3o00KooookJP02o`3oF0Co
oo]Z00?o0?oEoookJ_oonfX00_oonfX2o`3oYPGooo]Z00GookL0oookJ_oonf[ooo]Zo`1Bo`03oomi
0004oookJ_oooP3oEol0ohKo00?oogT000?ooo]Zoomi0?ooN@001?ooN@000ol0Yooooo]ZoookJP02
om`0o`03oookJ_ooAP3oodH000;oohT03?oo:0001?l0oOooobP0oolX0?oo:007ool00003oolX0?oo
003oo`0000koo`000_oo:0000ooo003oom<0ool00005ool000KoobP01_oo000QoolX00;oWol00ooo
nfX2o`Oo0004oookJ_l0ohOo0?n7o`0;o`;ooo]Z0oooeP08oookJP;o0?mM0_oonfX2o`3oI`04oomi
0?l0om?o0?oCo`19o`oooo]Z0_ooL`0:oookJPKoiOl02ooonfX2o`2goaKooo]Z2_m4o`02ooo=07oo
oo]Z00?oobH0oookJ_oonfX05OoonfX00ooo]@3ooo]ZoookJP0=oookJP03ok00oooonf[ooo]Z00Wo
oo]Z00Go0:cooookJ_oonf[ooo]Zool0MP0DoookJP04oa[o0?ooP`3ooh<0obco00;ooo]Z0_l0B?l0
0ol0ol7ooo]ZoookJP05oookJP06ool0/ooonf[o05coo`1LooooG03oobh01OoonfX00onno`3ooo]Z
oookJP02oookJP05og7o0?l01_oooo]ZoookJ_l0oeP01?oonfX00ol0omGooo]ZoookJP02oookJP03
o`2Tool0ojKooo]Z00Cooo]Z00CookL0oookJ_oonf[ooo]Z0_l0D_l2o`3o;P05oookJ_oooP3oooh0
ohKo0?oo=`000_oonfX01_oog03ooo]ZoookJ_m9o`3ood`0oookJP;o0?mA00Go0:OooookJ_oL0?oo
g03ooookJP02oom600;oohT00ooonfX06?l0ooOo/ol0o`3o]oo_0?oo0>Goo`3ohOoo;03o02gooa;o
0?oonf[o0?goool0XOoonf[ooj00o`0goooo@`3ooo]Zo`3o/ol0eOooo`0[oookJ_o00?oooo]Zool0
X`?ooo]Z00Coog/0oookJ_l0obCoYOl00_oonfX00ol0og[oo`3>oookJP02oookJP03ool:0?oonf[o
om<000?o000000So0?mloookJ_l00_oo01[ooookJ_l0o`3oold0ool0^Pgooo]Z00?oo`2goooo0?oo
o`001_ooo`02oookJP?o>@3o0_oonfX3ool0bPGooo]Z0onB0?l2oioo00Cooo]Z0_l7o`02o`3oQ`04
o`0;oooonf[ooo]ZoookJP?oomH02?oonfX2o`3oG@04oookJ_l0ofOo0?mWoookJP;o0?oC0_l0BOl>
oookJP;oog<02ooonfX2oiD0o`kooo]Z0_l0]olLoookJP;oo`2j0ooonfX2ooo=05Cooo]Z000/oook
JP;oobH05OoonfX2oone00oooo]Z0_n`0?l9oookJP;o0:co0_oonfX2ool0MQGooo]Z00?o6_l0oon3
0?l/o`000ooonfX00ol0B?oo0?o1oookJP05oookJP06oomi0?oo0;?oo`2coomi0?l0G?oooe`00_oo
N@04oookJP;o__l00ooonfX2og7o0003o`06oooonf[o0?mH00Cooo]Z0_l0omD3oookJP03o`0Cool0
ojKooo]Z00Gooo]Z00GookL0oookJ_oonf[ooo]Zo`1Bo`05oomi0003oeOo0?oo=`3oogT000;oom`0
00?ooo]Zoomi0?ooN@000oooN@001Ol0@Ooo0:OooookJ_oonf[og03o00;ooo]Z00CoodH0oookJ_oo
R@3ooo]Z2ooo:0000oooN@3o0?gooolX0002oolX00Woo`0000?oobP0ool00?oo00002ooo0003oolX
0003ool00?ood`3oo`0000?oo`000_oo:008oomi00Koo`007_oo:002oioo00;ooo]Z0ol7o`001?oo
nf[o0?n7o`3oQol02ol2oookJP;oomH02OoonfX2o`3oG@05oookJ_l0ofOo0?mWo`3oIooonfX00_l0
om<00ol0BOoooo]ZoookJP0=oookJP;oog<02ooonfX00onE0?ooiOl0onGo0003onGo00[ooo]Z0_l0
]olFoookJP[oA?l00_ooc@1ooookJP;oobH05_oonfX2oone00kooo]Z0_n`0?l:oookJP;o0:co0_oo
nfX2ool0MQCooo]Z00Co6_l0oon30?oonf[o;?l00_oonfX00ol0B?oo0?o1o`3o`@06oookJP;oo`2c
00Gooo]Zo`1LooooG03ooe`0ool^0004oookJP;o__l00ooonfX2og7o0004o`06oooonf[o0?mHo`3o
F0?ooo]Z0_l0omD4oookJP03o`2Tool0ojKooo]Z00Cooo]Z00OookL0oookJ_oonf[ooo]Zo`1Boooo
nf[o0?l^00;ooo]Z00Goooh0oeOo0?oo=`3oocL0oookJP02oooL0003oookJ_m9o`3oBOl000;ooo]Z
00Go0?mAo`11ool0Yooooo]Zom`0o`02oookJP03oom60?oonf[oohT000?ooo]Z0_l0ooL00onco`3o
0?ngonl0o`02o`3oh@0Bool/0?lBo`3o4_l0oookJ_l0oOoooo]Zool0XOooX03o03Oooom30?oonf[o
0?nco`3Eoooo02_ooo]Zol00oooonf[oo`2S0_oonfX01Ol:o`3oog/0oookJ_l0obCoYOl000?ooo]Z
00Oo0?mjool0c_oonf[ooo]Zool:0?oonf[oom<000Co000000So0?mloookJ_l00_oo01[ooookJ_l0
o`3ooo]Zooo=01Kooo]Z0_li0?l00ooonf[oo`3:ool0bP02ool0bPCooo]Z1?nB0?l3oioo00?ooo]Z
0ol7o`02o`3oQ`03o`0;oooonf[ooo]Z00?oomH02OoonfX2o`3oG@?o0?mW00Cooo]Zo`3odol0om?o
04Wo3ooonfX2oomc00_ooo]Z0_nE0?l>oookJP;o0;Oo7?oonfX2ool0^P?ooo]Z0_ooc@1FoookJP00
:ooonfX00ooo9P3ooo]ZoookJP0DoookJP03oone0?oonf[ooo]Z00kooo]Z00?o/03ooookJ_oonfX0
2?oonfX01Ol0[?oooo]ZoookJ_oonf[oo`1f01Gooo]Z00Co6_l0oon30?ooP`3o;?l00_oonfX2o`18
o`Oooo]Z00?oogT0ool0/oooN@000_l0G?l01?ooG03oogT0oomi0?ooN@03oookJP03okko0?oonf[o
oo]Z00;ooo]Z00?oLOl0o`06oooonfX00_l0oeP4oookJP03o`3oeOoob@3ooo]Z00;ooo]Z00?o01?o
o`3oY_oonfX01OoonfX00ooob@3ooo]ZoookJP02o`1Bo`KoogT000?oocL0oookJ_ooN@000_oonfX4
oomi0003o`3oDOl0Yooo0:Oo00;ooo]Z00Cog03ooookJ_oonf[oodH00_ooR@000ooonf[oogT0oolX
0007oolX0004oa;o0?l0;OooogT0o`3mo`?oobP02?oo0004oolX00Ooo`000ooo:0001?oo003oobP0
oolX0?oo:002ool00003oooC0?oo003oo`0000;oo`000_oo:008oomi00Koo`002_oo:005ool000ko
obP00_oonfX3o`Oo00;ooo]Z0_l0ohL3oookJP;oomH02?oonfX3o`3oG@03oookJ_l0ofOo0?mW00;o
oo]Z0_l0om<@oookJP;oog<02_oonfX3oiD0o`;ooo]Z0ooUo`08oookJP?o0;Oo6?oonfX9odCo0003
ooo=0?oonf[ooo]Z07kooo]Z00?oobH0oookJ_oonfX05OoonfX00ooo]@3ooo]ZoookJP0=oookJP03
ok00oooonf[ooo]Z00Wooo]Z00Go0:cooookJ_oonf[ooo]Zool0MP0DoookJP;o6_l000Cooh<0obco
0?l/o`3ooo]Z0_l0B?l00ol0ol7ooo]ZoookJP05oookJP06ool0/ooonf[o05coo`1LooooG03oobh0
1OoonfX00onno`3ooo]ZoookJP02oookJP05og7o0?l01_oo00KooookJ_l0oeP01?oonfX00ol0omGo
oo]ZoookJP03oookJP03o`2Tool0ojKooo]Z00Cooo]Z00SookL0oookJ_oonf[ooo]Zo`1Boooonf[o
0?l^oookJP;oooh000GoQ_l0oolg0?oonf[ooo]ZoooL0002oookJP03odWo0?ooXP3ooo]Z00;o0?mA
0_l0Yol01ooonf[og03ooookJ_oonf[oodH0oookJ_ooR@000ooonfX02Ol0ooOooo]Zok?o0?l0okOo
k`3oo`3ohOl05oooob`0oa;o0002oookJP0>o`3moooonf[oo`2QoonP0?l0=ooood<0oookJ_l0ok?o
0=Goool0:ooonf[o`03ooookJ_oo0:<2oookJP05o`[o0?ooN`3ooo]ZoookJ_nUo`000ooonfX01Ol0
og[oo`3>oookJ_oonf[oo`X000;ooo]Z00?oom<0o`000?l000000_l000002Ol0ogcooo]Zo`02ool0
6_oooo]Zo`3o0?oonf[oold0ool0^P0CoookJPGoo`3:1_oonfX2oi80o`04oookJ_nOo`3oWol0oioo
00?ooo]Z0ol7o`001?oonf[o0?n7o`3oQol02ol2oookJP;oomH02OoonfX3o`3oG@;o0?mW0_oonfX2
o`3od`03o`19oooonf[ooo]Z00gooo]Z0_ooL`0:oookJP?oU@3o3_oonfX2o`2goagooo]Z00?oo`2j
oookJ_oonfX00_oonfX00oooc@3ooo]ZoookJP1FoookJP00:_oonfX00ooo9P3ooo]ZoookJP0Coook
JP;ookD03ooonfX2ok00o`Wooo]Z0_l0[?l2oookJP;oo`1f5OoonfX00olJo`3ooh<0obco0003oook
JP03o`18ool0ol7ooo]Z00Kooo]Z0_oo0;<2o`1Lo`03oomL0?ooN@3oogT000CoogT000?ooo]Zokko
0?oonfX00_oonfX2og7o0003o`06oooonf[o0?mH00Cooo]Z0_l0omD3ooo90003oookJ_l0ojKo0?nV
00Gooo]Z0_oo]`001?oob@3ooo]Zo`1BoooonfX=oomi0004oonR0?l0oe7o0?mAo`2Wo`;ooo]Z0_oL
0?l2oookJP03oom60?ooR@3ooo]Z00;ooo]Z1ooo:0001OooN@3o4_l0o`0]ooooN@3o0?go00?oobP0
1ooo0007oolX00Goo`001ooo:0000ooo2P3oo`00oooC0002ool000;oobP000?oo`00oolX0?oo:000
2?ooN@06ool000SoobP02?oo000;oolX0004oookJ_l7o`3o1ol0o`Oo00?ooo]Z0_l0ohL2oookJP?o
omH01ooonfX3o`3oG@;ooo]Z0_l0ofL01?oonf[o0?oCo`3odol0om<@oookJP;oog<02OoonfX3oiD0
o`Kooo]Z00?oiOl0oookJ_oonfX01OoonfX2o`2goacooo]Z1_m4o`02ooo=083ooo]Z00?oobH0oook
J_oonfX05?oonfX2oone00kooo]Z0_n`0?l:oookJP;o0:co0_oonfX2ool0MQCooo]Z00Co6_l0oon3
0?ooP`3o;?l00_oonfX00ol0B?oo0?o1o`3o`@06oookJP;oo`2c0_l0G?l00oooG03oobh0ool^0005
oookJP04okko0?oonf[ooo]ZoookJP;oLOl000Co00KooookJ_oonf[o0?mH0ooonfX2o`3oe@Cooo]Z
00?o0:Coo`3oY_l0ojH01?oonfX2oong00?ooo]Z00So05;oo`3o;_l0obkooo]Zooon0?mGo`3oQ_l0
oolg00;ooo]Z00Woom`0oookJ_oonf[oBOl0oonR0?oonf[o0?mAoookJ_l0Yol00_oonfX01_oL0?oo
oo]ZoookJ_ooAP3ooo]Zoon900?ooo]Z00Oo0?ogoookJ_nco`3o0?ngo`3Uool0on7oob`000;o4_l0
0_oonfX03_l0oOoooo]Zool0XOooX03o03Oooom30?oonf[o0?nco`3Eoooo02_ooo]Zol00oooonf[o
o`2S0_oonfX01Ol:o`3oog/0oon<0?oonf[oYOl000;ooo]Z00[oo`0koookJ_l0og[oo`3>oookJ_l0
S?ooo`X0oookJ_ood`3ooo]Z1?l000001_l0ogcooo]Zo`02ool06_oooi`0o`3o00;ooo]Z00?oold0
oookJ_l0om<00ooonfX00ol7o`3ooo]ZoookJP0AoookJPGoTP3o0onOo`03oookJP?o1ol00_oonfX2
o`3oQ`03o`0;oooonf[ooo]Z00;oomH02?oonfX3o`3oG@03oookJ_l0ofOo0?mW00;ooo]Z0_l0om<0
0ol0BOoooo]ZoookJP0=oookJP;oog<02_oonfX2oiD0o`oooo]Z0_l0]olMoookJP;oo`2j0ooonfX2
ooo=05Wooo]Z000ooookJP03oone0?oonf[ooo]Z00kooo]Z00?o/03ooookJ_oonfX02?oonfX01Ol0
[?oooo]ZoookJ_oonf[oo`1f01Gooo]Z00Co6_l0oon30?ooP`3o;?l00_oonfX2o`18o`Kooo]Z00Go
ogT0oookJ_oo0;?oogT0o`1Lo`08oomi00;o__l000CoogT0oookJ_oonf[oLOl00_ooN@000ooonf[o
0?mHoookJP03oookJP03o`3oeOoonf[oolT000?oolT000?o0?nVoookJ_oonfX01?oonfX00ooo]`3o
oo]Zooo90002o`1Bo`03oookJ_ooN@3oogT000SoogT000OoBOl0oomi0?ooN@3ooj80o`3oDOl0@Ooo
0:Oo00;ooo]Z00Kog03ooookJ_oonf[ooo]Zoom60?ooR@03oookJPKoobP00_ooN@001?lBo`3o02go
oomi0?l0oOl4oolX00Koo`002Ooo:002ool000KoobP00_ooN@001Ooo2P3oobP0oolX0?ood`3oo`00
00OoobP01_ooN@02oolX00?oo`002?oo:005ool0017oogT00ooonfX3o`3oQ`;ooo]Z0_ooeP08oook
JP;o0?mM0_oonfX3o`3oI`04oookJ_l0om?o0?oCo`19oa3ooo]Z0_ooL`09oookJP;oU@3o3ooonfX2
o`2goakooo]Z1?m4o`02ooo=0003odCo0?oonf[ooo]Z09Gooo]Z00?ookD0oookJ_oonfX03OoonfX0
0on`0?oooo]ZoookJP09oookJP05o`2/oooonf[ooo]ZoookJ_oo07H05?oonfX2oa[o0003oon30?l/
o`3o;?l000;ooo]Z00?o04Soo`3o`OoonfX01_oonfX00ooo0;?ooo]Zo`1Lo`02oomL0003ool^0?oo
nf[ooo]Z00?ooo]Z0_nno`03oookJP04og7o0?l01_oo00KooookJP;o0?mH0ooonfX00ol0omGooo]Z
oookJP03oookJP03o`2Tool0ojKooo]Z00Cooo]Z00CookL0oookJ_oonf[ooo]Z0_l0D_l01ol0obko
oo]ZoookJ_oooP3oEol0ohKo0?oo=`000_oonfX01Ooog03ooo]ZodWo0?m9o`3ooj8000;o0?mA0_l0
Yol2oookJP06om`0oooonf[ooo]Zoom60?oonf[oohT00ooonfX03Ol0ooOo00Sook?o0?l0okOo0>Go
o`3ohOoo;03o4_l0o`0]oooonf[o0?n^o`3moooonfX00_ooX0004Ol0=ooood<0o`3bool0ok?o0=Go
ool0:ooonf[o`03ooookJ_oo0:?oo`25oookJ_l:o`3oog/0oookJ_ooS03oYOl000?ooo]Z00Koo`0k
o`3oN_l0on;oo`3>o`2<oooo2P02oookJP03oooC0?oonf[o000000;o000000Oo0?mloookJ_oonf[o
00;oo`0JooooW03o0?l000;ooo]Z00Coold0oiD0oooonf[o0?oC0ooonfX2o`Oo013ooo]Z1?nOo`04
oookJPCo1ol00_oonfX3o`3oQ`03o`0;oooonf[ooo]Z00;oomH02?oonfX2o`3oG@04oookJ_l0ofOo
0?mWo`3oI`;ooo]Z0_l0om<00ol0BOoooo]ZoookJP0=oookJP;oog<02_oonfX2oiD0o`oooo]Z0_l0
]olMoookJP;oo`2j0ooonfX2ooo=05_ooo]Z000moookJP;ookD03ooonfX2ok00o`[ooo]Z00?o0:co
oookJ_oonfX00_oo07HEoookJP03oa[o0?ooP`3o;?l000?ooo]Z00?o04SooookJ_oonfX01_oonfX2
ool0/`;o05co2?ooN@000onno`3ooo]Zoomi0002oomi0003og7o0?ooN@3ooo]Z00;o0?mH0ooonfX2
o`3oe@03oookJ_oob@3oolT000;oolT000?o0?nVooo90?oonfX00ooonfX2oong0003oookJ_oob@3o
05;o00?oolT02OooN@000om9o`3oogT0oomi0002oomi00;o0:Oo0_oonfX01_oL0?oooo]ZoookJ_oo
nf[oodH0oon900?ooo]Z1ooo:0001OooN@3o4_l0oomi0?ooN@3o0?go00CoobP01Ooo0004oolX00;o
o`003Ooo:003oomi0003oolX0?ood`3oobP000SoobP01_ooN@0;oolX00Ooo`003oooN@03oolX00;o
0?n70_oonfX3oooF00Oooo]Z0ol0oed01?oonf[o0?mWo`3oIol0ofL2oookJP;o0?oC00?o04Wooook
J_oonfX03_oonfX2oomc00Sooo]Z0onE0?l?oookJP;o0;Oo7_oonfX2odCo0003oookJ_m4o`3oA?l0
00?oA?l0U_oonfX2oone00kooo]Z0_n`0?l;oookJP03o`2/oooonf[ooo]Z00;oo`1f5?oonfX01?lJ
o`3ooh<0oon30?l/o`02oookJP;o04So1ooonfX2ool0/`;o05co00?ooe`0ool^0?oo;P001OoonfX0
0onno`3ooo]ZoookJP02oookJP05og7o0?l01_oooo]ZoookJ_l0oeP00ooonfX2o`3oe@Gooo]Z0_l0
ojH5oookJP05oong0?oonf[ooo]ZoookJ_l0D_l00_l0obh2oookJP04ooon0?mGo`3oQ_l0oolg00;o
oo]Z00Soom`0oookJ_m9o`3ood`0oonR0?l0oe7ooo]Zo`2Wo`?ooo]Z00Cog03ooookJ_oonf[oodH0
0_ooR@03oookJP0:o`3omol02?oo/ol0o`3o]ol0iOoo0?oQool/0?lBo`3o02gooookJP;o0?go01Go
o`2QoonP0?l0=ooo00Sooom30?l0l_oo0?nco`3Eoooo02_ooo]Zol00oooonf[oo`2Sool0QOoonf[o
2_l0oomk0?oonf[ooh`0ojGo0?l0ob@00_oonfX01ooo03_o0?mjo`2Aoooo0<ko08coogh0oooo2P00
0_oonfX00oood`3ooo]Zo`000002o`00000>o`3oO?oonf[o00;ooookJ_l06_oooi`0oookJ_l0o`3o
oo]Zooo=0?oo0;[oU@3ooookJ_l0om<2oookJP03oooF0?oonf[o1ol000;o1ol00ooonfX:oioo00Co
oo]Z1?l7o`000ooonf[o0?n7o`3oQ`03o`3oQ`03o`0;oooonf[oomH000?oomH01ooonfX3o`3oG@?o
0?mW0ooonfX2o`3oda3ooo]Z0_ooL`09oookJP?oU@3o3ooonfX2o`2goagooo]Z0_oo0;X3oookJP;o
old0GOoonfX003cooo]Z00?ookD0oookJ_oonfX03_oonfX00on`0?oooo]ZoookJP08oookJP;o0:co
0_oonfX00ooo07Kooo]ZoookJP0CoookJP04oa[o0?ooP`3ooh<0obco00;ooo]Z0_l0B?l7oookJP;o
o`2c00?oogT0o`1LooooN@001oooN@02okko0003oookJ_ooN@3oogT000;oLOl000?oogT0oookJ_l0
oeP01?oonfX00ol0omGooo]ZoookJP03ooo900;o0?nV0ooob@02oookJP05oong0?oonf[ooo]Zooo9
0?l0D_l00ooob@06oomi0004oookJ_oog03oogT0odWo00KoogT000?ooo]Zom`0oooL0?l00_oonfX2
oom60007oon90?oonf[ooo]ZoookJ_ooN@3oobP0o`3o]`04oolX0005oomi0?lBo`3oogT0oookJ_l0
oOl01?oo:004ool000KoobP000?oo`00oolX0?oo:0002ooo:006oomi00WoobP01_ooN@0:oolX0003
ool00?l7o`3o1ol000Go1ol03OooN@05oolX00;oogT00_ooeP08oookJP;o0?mM00Cooo]Zo`3oIol0
ofOo0?mW0_oonfX3o`3od`03o`19oooonf[ooo]Z00kooo]Z0_ooL`08oookJP;oU@3o4?oonfX2o`2g
oakooo]Z2Om4o`2FoookJP03oone0?oonf[ooo]Z00gooo]Z00?o/03ooookJ_oonfX02OoonfX2o`2/
o`;ooo]Z00?oo`1foookJ_oonfX04_oonfX2oa[o0003oon30?l/o`3o;?l000;ooo]Z00?o04Soo`3o
`OoonfX01_oonfX01_oo0;?ooo]Zo`1Lool0H_oooe`0ool^00Gooo]Z0_nno`03oookJP;oLOl000Co
00KooookJ_oonf[o0?mH0ooonfX00ol0omGooo]ZoookJP03oookJP03o`2Tool0ojKooo]Z00Cooo]Z
0_oo]`03oookJP04o`1Bool0obkooo]ZoookJP;oooh00_n6o`001?oo=`3ooo]ZoookJ_oog002odWo
00;ooj8000?o0?mAo`2Wool0Yol00_oonfX2om`0o`04oookJ_ooAP3oodH0oon900?ooo]Z0_l0ooL0
8?l02?oo/ol0o`3o]ol0iOoo0?oQool/0?lBo`3o02gooookJ_l0oOoooo]Zool0XOooX03o03Ooo`08
oooo@`3o0?;oo`3o/ol0eOooo`0[oookJ_o00?oooo]Zool0Xooo08Gooo]Zo`[o0?ooN`3oaOl0oon<
0?nUo`3o0?lT0_oonfX01ooo03_o0?mjo`2Aoooo0<kooo]Zo`2<oooo2P000_oonfX00oood`3o0?nI
oookJP03o`000008o`3oO?oonf[o00;ooookJ_l06_oooi`0oomV0?l0o`02oookJP05ooo=0?oonf[o
U@3ooomc0?l0om<00_oonfX2oooF00;ooo]Z4Ol7o`05o`3oQ`;o00_o1OooeP09oookJP;o0?mM00?o
oo]Zo`3oIol0ofL00ooonfX3o`3oda3ooo]Z0_ooL`09oookJP;oU@3o4?oonfX2o`2goagooo]Z0_oo
0;X3oookJP;oold0GooonfX003_ooo]Z00?ookD0oookJ_oonfX03OoonfX2ok00o`[ooo]Z00?o0:co
oookJ_oonfX00_oo07HEoookJP03oa[o0?ooP`3o;?l000?ooo]Z00?o04SooookJ_oonfX01_oonfX0
1?oo0;?oogT0o`1Lool0G?l6oomi00;ooo]Z00?o__l0oookJ_oonfX00_ooN@000omao`3oogT0oomi
0002o`3oF0?ooo]Z0_l0omD2oookJP?oolT000?o0?nVooo90?oob@001?oob@001Ooo]`3ooo]Zoook
J_oonf[o05;o00?oolT02?ooN@02odWo00SoogT00ooonfX00oooAP3ooo]Zoon90003oookJP03o`3o
mooo:03o/ol000CoobP000OoogT0oa;o0?oonf[ooo]ZoolX0?oonf[oo`2Q00;oobP000Cood<0ool0
0?oo003oogT05Ooo:007oomi00SoobP01_ooN@0:oolX00Woo`002_ooN@05oolX00;oogT02_oonfX2
o`3oG@?o0?mW0_oonfX01?l0BOoo0?oCo`3odol0BOlAoookJP;oog<02?oonfX2oiD0oa3ooo]Z0_l0
]olKoookJPgoA?l0UOoonfX2oone00kooo]Z0_n`0?l;oookJP03o`2/oooonf[ooo]Z00;oo`1f5?oo
nfX01?lJo`3ooo]Zoon30?l/o`02oookJP;o04So2?oonfX00ooo0;?o05coo`1Lo`02oomL0003ool^
0?oonf[ooo]Z00?ooo]Z00?o__l0oookJ_oonfX00_oonfX01?mao`3ooo]Zo`06oooonfX2o`3oF0?o
oo]Z00?o0?oEoookJ_oonfX00ooonfX2o`3oYPGooo]Z00CookL0oookJ_oonf[ooo]Z0_l0D_l02?l0
obkooo]ZoookJ_oooP3oEol0ohKo0?oonf[oocL00_oonfX02?oog03oBOl0oom<0?ooXP3o0?mAoook
J_l0Yooo047o0_oonfX01_oL0?oooo]ZoookJ_ooAP3ooo]Zoon900?ooo]Z02;o0?ogoookJ_nco`3o
/ol0oookJ_l0iOoo0?oQool/0?lBo`3o02gooookJ_l0oOoooo]Zool0XOooX03o03Ooo`08oooo@`3o
0?;oo`3o/ol0eOooo`0[oookJ_o00?oooo]Zool0Xooo08Gooo]Zo`[o0?ooN`3oaOl0oon<0?nUo`3o
0?lT0_oonfX03Ooo03_ooo]Zo`3oN_oo0<kooo]Zo`2<oooo2P3ooo]Zool0o?oonf[oom<0o`3oVOoo
nfX00ol000004?l0ogcooo]Zo`02oooO0?oo01[ooonL0?ooIP3o0?l0oookJ_oo<@3ooo]Zooo=0?nE
0?ooog<0oookJ_l0om<3oookJP;oomH02ooonfX6o`3oQ`;o00_o1OooeP0;oookJP?o0?mM0ol0ofL2
oookJP?o0?oC4OoonfX2oomc00Wooo]Z0_nE0?l@oookJP;o0;Oo7OoonfX2ool0^P;ooo]Z0oooc@1Q
oookJP00>OoonfX2oone00oooo]Z00?o/03ooookJ_oonfX02?oonfX2o`2/o`;ooo]Z00?oo`1foook
J_oonfX04ooonfX01?lJo`3ooh<0oon30?l/o`02oookJP;o04So1ooonfX2ool0/`;o05co1OooN@04
oookJP04okko0?oonf[ooo]ZoookJP;oLOl00_ooN@001_l0oeSoogT0oomi0?ooN@3ooo]Zo`3oe@Co
oo]Z0_oob@000ol0ojKoolT0ooo90003ooo90004oong0?oonf[ooo]ZoookJP;o05;o0ooob@04oomi
0005oolg0?ooN@3oogT0oomi0?m9o`002?ooN@001ooL0?oooo]ZoookJ_oonf[oodH0oookJ_ooR@00
0ooonfX00ol0ooOoobP0ok?o0003oolX0003ool/0?ooN@3o4_l000;ooo]Z00Ko0?gooolX0?oo:03o
obP0oomi0?oo@`02ool00003oomi0?oo:03oobP0017oobP000?oo`3>oolX0?oo:0002?ooN@08oolX
00GoogT02ooo:008ool000SoogT01Ooo:002oomi00Gooo]Z1_ooN@03o`3oI`KoolT04_oonfX2oomc
00Sooo]Z0_nE0?l@oookJP;o0;Oo6_oonfX<odCo00;ooo]Z00?oA?l0oookJ_oonfX0TooonfX00ooo
]@3ooo]ZoookJP0=oookJP03ok00oooonf[ooo]Z00Wooo]Z0_l0[?l2oookJP03ool0M_oonf[ooo]Z
01;ooo]Z0_lJo`02oon30005obco0?oonf[ooo]Zo`18ool0ol401ooonfX01_oo0;?o05coo`1Lool0
H_oooe`0ool^00Kooo]Z00Co__l0oookJ_oonf[ooo]Z0_mao`02o`06o`03oookJ_l0oeSooo]Z00;o
oo]Z0_l0omD4oookJP03o`0Cool0ojKooo]Z00Cooo]Z0_oo]`03oookJP03o`1Boooonf[o0?l^00;o
oo]Z00Goooh0oeOo0?n6o`3ooo]Zoolg0002oookJP05oooL0?m9o`3ood`0oonR0?l0oe400_l0Yol3
oookJP06om`0oooonf[ooo]Zoom60?oonf[oohT00ooonfX08_l0ooOooo]Zok?o0?l0okOooo]Zo`3U
ool0on7oob`0oa;o0?l0;Ooooo]Zo`3moooonf[oo`2QoonP0?l0=ooo00Sooom30?l0l_oo0?nco`3E
oooo02_ooo]Zol00oooonf[oo`2Sool0QOoonf[o2_l0oomk0?o5o`3ooh`0oookJ_nUo`02oookJP0>
ool0>ooonf[o0?mjool0c_l0on;ooo]Zo`2<oooo2P3ooo]Zool0o?ood`3o0?nIoookJ_ooB002o`00
000Bo`3oO?l0003ooo]Zo`02oooO0?oooo]ZoonL0?ooIP3o0?l0oookJ_oo<@3ooo]Zooo=0?oonf[o
U@3ooomc0?oonf[o0?oC1?oonfX4oooF00_ooo]Z1?ooeP0=oookJP?o0?mM0ol0ofL2oookJP?o0?oC
4_oonfX2oomc00Sooo]Z0onE0?l@oookJP;o0;Oo7OoonfX2ool0^P;ooo]Z0_ooc@1ToookJP00>?oo
nfX00ooo]@3ooo]ZoookJP0=oookJP;o/03o2_oonfX00ol0[?oooo]ZoookJP02ool0MQGooo]Z00Co
6_l0oon30?l/o`3o;?l00_oonfX00ol0B?oooo]ZoookJP06oookJP03ool0/ooonf[o05co00OoogT0
0_oonfX2okko00?ooo]Z00GoLOl0oomi0?ooN@3oogT0o`3oF004oomi0003o`3oeOoonf[ooo]Z00;o
oo]Z00?oolT0o`3oY_l0ojH00ooob@000ooonf[ookL0oong0003oookJP03o`1Boooob@3oolT000;o
olT00oooN@02oolg00?oogT000?oBOl0oomi0?ooN@001OooN@000ooonf[og03ooookJP02oookJP03
oom60?oonf[oohT000?ooo]Z00?o0?ogoookJ_nco`000_oo:0001ol0on7oob`0o`0]oolBo`3ooo]Z
o`3o[_l0oOl01?oo:0001?oo@`3oo`00oomi0?l0ok<CoolX0003ool0c_oo:03oobP000[oogT00_oo
:0000ol0003oobP0oolX0002oolX00CoogT03?oo:008ool000KoogT01Ooo:00<oomi00?o0?mW1ooo
b@0AoookJP?oog<02?oonfX2oiD0o`oooo]Z0ol0]olLoookJP_oA?l0UooonfX2oone00kooo]Z0_n`
0?l;oookJP03o`2/oooonf[ooo]Z00;oo`1f5?oonfX00olJo`3ooo]Zoon30002obco00;ooo]Z00?o
04SooookJ_oonfX01_oonfX01_oo0;?o05cooookJ_l0H_oooe`0ool^00Gooo]Z0_nno`03oookJP03
og7o0?oonf[o00Ko00;ooo]Z00Go0?mHoookJ_oonf[ooo]Zo`3oe@05oookJP03o`2Tool0ojKooo]Z
00Cooo]Z00?ookL0oookJ_oonfX00_oonfX00ol0D_oo0?l^o`3o;P02oookJP03ooon0?mGo`3oQ_l0
00;oocL000Wooo]ZoooL0?m9o`3oBOl0oom<0?ooXP3o0?mAo`2Wool0@Ol00_oonfX2om`0o`;ooo]Z
00?oodH0oookJ_ooR@000ooonfX03Ol0ooOooo]Zok?o0?l0okOooo]Zo`3Uool0on7oob`0oa;o0?l0
;Ooooo]Zo`3moooonfX00_ooX0004ol0=ooo00Soo`3bool0l_oo0?nco`3Eoooo02_ooo]Zol00oooo
nf[oo`2Sool0QOoonf[o2_l0oomk0?o5o`3ooh`0oookJ_nUo`000_oonfX03?oo03_ooo]Zo`3oN_oo
0<ko0?oRoookJ_l0S?ooo`X0oookJ_oo0?coom<0o`3oV@;ooo]Z00coodP0o`000?l0003o0?mlo`00
0?oonf[o00;ooml0oooeo`3ooi`0oomV0?l0o`02oookJP07oola0?ooc@3oo`2joiD0oooonf[oog<0
oookJP02o`3od`;o00So1?oonfX;oooF00gooo]Z1?l0oed3o`3oI`;ooo]Z0ol0om<BoookJP?oog<0
2?oonfX2oiD0oa3ooo]Z0ol0]olMoookJP;oo`2j0_oonfX2ooo=06Kooo]Z000foookJP;ookD03ooo
nfX00on`0?oooo]ZoookJP08oookJP;o0:co0_oonfX00ooo07Kooo]ZoookJP0CoookJP04oa[o0?oo
P`3ooh<0obco00;ooo]Z0_l0B?l7oookJP;oo`2c0_l0G?l9oomi0003okko0?oonf[ooo]Z00;ooo]Z
00?oLOl0oomi0?ooN@000_l0oeP3oomi00;o0?oE1?oonfX00ooob@3o0?nVooo90002ooo900;ooo]Z
00?ookL0oookJ_oonfX00_oonfX01Ol0D_ooolT0ooo90?oob@3oooh000?oogT000KoocL0oomi0?oo
N@3oogT0oookJ_m9o`06oomi00;ooo]Z00Oog03ooookJ_oonf[ooo]Zoom60?oonf[oohT000?ooo]Z
00[o0?ogok?o0?nco`3oobP0o`0Gool0on7oob`0o`0]oolBo`3ooo]Z0_l0oOl7oolX0004o`3o/ooo
02_oobP0oomi013oobP000Co0?mjoolX0?oonf[oobP02?ooN@03oolX00;oogT01?oo:004oomi00Oo
obP000?oog<0oolX0?oo:0000_oo:008ool000WoobP00_ooN@000ooonf[oogT0oomi0005oomi00Co
0?mW0_ooN@06ooo9013ooo]Z0oooL`09oookJP;oU@3o3ooonfX2o`2goaoooo]Z00?oo`2jodCo0?m4
o`001om4o`2GoookJP03oone0?oonf[ooo]Z00gooo]Z00?o/03ooookJ_oonfX02OoonfX2o`2/o`;o
oo]Z00?oo`1foookJ_oonfX04_oonfX2oa[o00;ooh<000?o;?l0oookJ_oonfX00_l0B?l7oookJP04
ool0/ol0G?oo05coo`1Ro`;ooe`01_oonfX00onno`3ooo]ZoookJP02oookJP04og7o0?oonf[o00Ko
oookJP;o0?mH0ooonfX00ol0omGooo]ZoookJP03oookJP;o0?nV1OoonfX01?oo]`3ooo]ZoookJ_oo
nfX2o`1Bo`03o`3o;_oonf[ooo]Z00;oooh00_n6o`001_oo=`3ooo]ZoookJ_oog03oBOl0oom<00;o
oj8000?ooo]Zo`2Wool0@Ol00_oonfX01ooL0?oooo]ZoookJ_oonf[oodH0oookJ_ooR@000ooonfX0
2_l0ooOooo]Zok?o0?l0okOooo]Zo`3Uool0on7oob`0oa;o0?oonfX2o`3mo`0FoookJ_ooX03ooo]Z
o`0gool02?oo0?;ooookJ_l0ok?o0=Goool0:ooonf[o`03ooookJ_oo0:?oo`25oookJ_l:o`3oog/0
olGo0?ooS03ooo]ZojGo00?ooo]Z00Ooo`0koookJ_l0og[oo`3>oookJ_l0S?ooo`X000;ooo]Z00So
o`3loooC0?l0oiWooo]Zoom80?oonf[o0000o`3oO0;o000000Oooo]Zo`02oooO0?oomOl0oonL0?mK
0?oo0?l000;ooo]Z00Cooc40oookJ_ooc@3oo`2j0_nE0?l00oooL`3ooo]ZoookJP02o`3od`;o00So
5OoonfX4o`3oG@Go0?mW1Ol0om<BoookJP?oog<02OoonfX2oiD0oa3ooo]Z0_l0]olNoookJP;oo`2j
0_oonfX2ooo=06Sooo]Z000eoookJP03oone0?oonf[ooo]Z00gooo]Z0_n`0?l:oookJP03o`2/oooo
nf[ooo]Z00;oo`1f5OoonfX01?lJo`3ooh<0oookJ_l/o`02oookJP03o`18oooonf[ooo]Z00Kooo]Z
00Coo`2coookJ_l0G?oooo]Z2?ooN@000ooonf[o__l0oookJP02oookJP;oLOl00_ooN@001_l0oeSo
ogT0oomi0?ooN@3ooo]Zo`3oe@Gooo]Z00Co0:Coo`3oY_oob@3oolT00_oonfX2oong00Cooo]Z00Ko
05;ooookJ_oob@3oolT0ooon0?oob@02oomi0004oolg0?ooN@3oogT0oooL00;oBOl01oooN@000ooo
nf[og03ooookJP02oookJP03oom60?oonf[oohT000?ooo]Z00Oo0?ogok?o0?l0okOooo]Zo`0Gool0
on7oob`000;o4_l000Cooo]Zo`3moooonf[oogT01ooo:0000ooo02_o0?nfoomi000?oolX0006oook
J_l0og[oobP0oookJ_oo:03oo`X01oooN@03oolX00?oogT01Ooo:003oomi00SoobP000Coog<0oomi
0?ooN@3oobP02?oo000AoolX00;o0?mW1?ooN@07ooo900Oooo]Z2Ooob@000oooL`3ooo]ZoookJP08
oookJP;oU@3o3ooonfX2o`2goakooo]Z0ooo0;X00ooonf[oA?l0odCo0006odCo09Kooo]Z0_oo]@0>
oookJP;o/03o2ooonfX00ol0[?oooo]ZoookJP02ool0MQCooo]Z00Go6_l0oookJ_ooP`3ooo]Zobco
0002oookJP03o`18oooonf[ooo]Z00Kooo]Z00Koo`2co`1Loooonf[o06;ooomL0?oo;P06oookJP04
okko0?oonf[ooo]ZoookJP;oLOl00_l01_l00ooonf[o0?mHoookJP03oookJP03o`3oeOoonf[ooo]Z
00;ooo]Z00?o01?oo`3oY_oonfX01?oonfX2oong00?ooo]Z00?o05;ooookJ_l0obh00_oonfX01Ooo
oP3oEol0ohKo0?oonf[oocL000;ooo]Z0_m9o`001_ooC03ooj80o`3oDOoonf[o0:Ooo`11o`;ooo]Z
00Oog03ooookJ_oonf[ooo]Zoom60?oonf[oohT000?ooo]Z00Oo0?ogoookJ_nco`3o0?ngoookJ_l0
iOoo0?oQ00;o4_l002Sooo]Zo`3mool0ojkooo]ZoonP0?oonf[o03Ooo`08ool0l_oooo]Zo`3o/ol0
eOooo`0[oookJ_o00?oooo]Zool0Xooo08Gooo]Zo`[o0?ooN`3oaOl0oon<0?oonf[oYOl0oookJ_no
o`3ooo]Zool0>ooonf[o0?mjool0c_l0on;o08coogh0oooo2P3ooo]Zool0o?ood`3o0?nI0_oonfX0
1?ooB03ooo]Zo`000?l0og`2o`000007o`02oooO0?oomOl0oookJ_ooW03oF`3oo`3o0002oookJP04
oola0?oonf[ooo]Zooo=00;ooo]Z00CoU@3ooomc0?ooL`3ooo]Z0ol0BOl4o`08o`Ko0?mM0ooonfX7
o`3oG@Go0?mW1Ol0om<3o`19oa7ooo]Z0oooL`0:oookJP;oU@3o4?oonfX2o`2goakooo]Z0_oo0;X0
1?oonf[oold0ooo=0?ooc@1ZoookJP00<ooonfX2oone00oooo]Z00?o/03ooookJ_oonfX02OoonfX0
1?l0[?oooo]ZoookJ_oo07HFoookJP;ooh<00_l/o`000ooonf[o04Soo`18o`07oookJP;oolT000?o
oo]Zo`1LoooonfX01_ooN@02oookJP;o__l00ooonfX00omao`3ooo]Zoomi0002o`3oF0;oogT000?o
oo]Zo`3oeOl0omD01OoonfX2o`3oYPCooo]Z00?ookL0oookJ_oonfX00ooonfX01ol0D_oooo]Zooo9
0?oob@3oooh0ooo90?ooN@000_oo=`001_ooN@3oom`0oooL0?m9o`3ooo]Zoom<00?oogT000?o0:Oo
oomi0?ooN@000_ooN@03oookJP03oom60?ooR@3oohT000?ooo]Z00So0?ogok?o0?l0okOooo]Zo`0G
ool0on7oob`0oa;o00;ooo]Z00?o0?gooookJ_oo0:402Ooo:0000ooonf[oogT0oolX000:oolX00;o
o`0000CoobP0oookJ_l0og[oobP00_oonfX00ooo2P3oogT0oomi0005oomi00?oobP01?ooN@05oolX
00ooogT02?oo000?oolX00KoogT01ooob@000ooonf[oolT0ooo9000=ooo900[ooo]Z0onE0?l?oook
JP;o0;Oo7_oonfX2ool0^P;ooo]Z0_m4o`000ooonf[oA?l0odCo0004odCo09Kooo]Z00?ookD0oook
J_oonfX03OoonfX00on`0?oooo]ZoookJP09oookJP;o0:co0_oonfX00ooo07Kooo]ZoookJP0Coook
JP03oa[o0?ooP`3ooh<000;o;?l000?ooo]Zo`18ool0B?l01ooonfX2ool0/`05o`1Loooonf[o06;o
oomL0?oo;P001OoonfX2okko00?ooo]Z00CoLOl0oookJ_l01_oooo]Z0_l0oeP3oookJP;o0?oE1?oo
nfX2o`3oYPGooo]Z00?ookL0oookJ_oonfX00_oonfX00ol0D_oooo]Zo`3o;P02oookJP03ooon0?oo
nf[oQ_l000;oocL000Wooo]ZoooL0?m9o`3ooo]Zoom<0?ooXP3o0?mAoookJ_l0Yol00ooonfX01OoL
0?oooo]ZoookJ_oonf[oodH000;oohT00ooonfX01Ol0ooOooo]Zok?o0?l0okOooo]Z00;o0?oQ02_o
4_l0o`0]oooonf[o0?goo`3o[_oonf[ooj00oh<0ool0=oooolT0o`3boooonf[o0?nco`3Eoooo02_o
oo]Zol00oooonf[oo`2Sool0QOoonf[o2_l0oomk0?o5o`3ooh`0oookJ_l0obCoYOl0okoo0?oonf[o
o`0koookJ_l0og[oo`3>o`3oh_oonf[o08coool:0?oonf[oo`3loooC0?oonf[o0?nI00;ooo]Z00?o
odP0oookJ_l0og`00ol000001ol00_oog`3oooGo0?oonf[ooi`0oookJ_l0o`000ooonfX02Ooo<@3o
oo]Zooo=0?oonf[o0;OooookJ_nE0?oooo]Zoomc0004oookJP03o`19ool0om?o0?oC00Ko00So2_l0
ofL5o`3od`Co04Wo4_oonfX3oomc00[ooo]Z0onE0?l@oookJP;o0;Oo7_oonfX2ool0^P03oookJ_oo
c@3oold006gooo]Z000boookJP03oone0?oonf[ooo]Z00gooo]Z0_n`0?l:oookJP;o0:co0_oonfX0
0ooo07Kooo]ZoookJP0CoookJP04oa[o0?ooP`3ooo]Zobco00;ooo]Z00?o04Soo`3o`OoonfX01_oo
nfX01Ooob@3ooo]Zo`1Lool0G?oo06;o00GoogT00ooonfX00onno`3ooo]ZoookJP02oookJP04og7o
0?oonf[oogT0o`3oF0;oogT00_oonfX00ol0omGooo]ZoookJP03oookJP03o`0Cool0ojKooo]Z00Co
oo]Z00?ookL0oookJ_oonfX00_oonfX2o`1Bo`07oookJ_oob@3oolT0ooon0?mGo`3oogT0oolg0002
oookJP05oooL0?oonf[oBOl0onGo0?ooC0000_ooN@000ol0YoooogT0oomi0005oomi00;oodH000Go
ohT0oookJ_oonf[ooo]Zo`3om`02ok?o0006o`08ool05ooo01Ooo`3ohOoo;03o4_l00_oonfX01?l0
oOoooo]Zool0XOooX00EoolX00;oo`0000CoobP0oookJ_l0og[oo`3>0_oonfX00ooo2P3oOP3ooomi
0005oomi00?oobP01?ooN@000ol00_ooobP0oolX0003oolX00ooogT02Ooo000;oolX0003o`3odooo
N@3oogT000GoogT01_oob@03oookJPkoolT02OoonfX2oiD0oa3ooo]Z0_l0]olNoookJP;oo`2j0_oo
nfX00oooc@3oA?l0oookJP03oookJPCoA?l0UOoonfX2oone00kooo]Z0_n`0?l;oookJP05o`2/oooo
nf[ooo]ZoookJ_oo07H05?oonfX2oa[o0003oon30?oonf[o;?l000;ooo]Z00?o04Soo`3o`OoonfX0
1_oonfX01?oo0;?o05coo`1Lool0H_l2oomL00Kooo]Z00?o__l0oookJ_oonfX00_oonfX01Omao`3o
oo]Zo`06oooonf[o0?mH00Cooo]Z00?o0?oEoookJ_oonfX00_oonfX00ol04ooo0?nVoookJP05oook
JP04oong0?oonf[ooo]ZoookJP;o05;o00?ooo]Zo`3o;_oonfX00_oooP000ooonf[oQ_l0oolg0002
oookJP08oooL0?m9o`3ooo]Zoom<0?ooXP3o0?mAoookJ_l0Yol2oookJP;og03o0_oonfX2oom60004
oon90?oonf[ooo]ZoookJP;o0?og0_nco`00<_oonf[o01Ooo`3ohOoonf[o4_l0o`0]oooonf[o0?go
o`3o[_oonf[ooj00oh<0ool0=oooolT0o`3boooonf[o0?nco`3Eoooo02_ooo]Zol00oooonf[oo`2S
oookJ_oo08Gooo]Zo`[o0?o5o`3ooh`0oookJ_l0obCoYOl0okoo0?oonf[oo`0koookJ_l0og[oo`3>
o`3oh_oonf[o08coool:0?oonf[oo`3loookJ_ood`3ooo]Zo`3oVOoonf[oodP00_oonfX02ol0ogco
0000o`000?l00_oo0000oml0oooeo`3ooo]ZoonL0?oonf[o0?l000?ooo]Z00Wooc40oookJ_oonf[o
old0oookJ_l0]ooooo]ZoiD0oooonfX00_ooL`05oookJPKo0?oC0_l02?l8o`3od`Co04Wo5?oonfX3
oomc00_ooo]Z0_nE0?l@oookJP?o0;Oo7_oonfX2ool0^P03oookJ_ooc@3oold006oooo]Z000`oook
JP;ookD03ooonfX00on`0?oooo]ZoookJP09oookJP03o`2/oooonf[ooo]Z00;oo`1f5OoonfX01?lJ
o`3ooh<0obco0?l/o`02oookJP05o`18oooonf[ooo]ZoookJ_oob@001?oonfX01Ooob@3ooo]Zo`1L
oooonf[o06;o00CoogT01?oonfX01?nno`3ooo]ZoookJ_oonfX2og7o0003oookJ_ooN@3o0?mH00Co
oo]Z00?o0?oEoookJ_oonfX00ooonfX00ol0Y?oo0?nVoookJP03oookJP;ookL01?oonfX01?l0D_oo
oo]Zo`3o;_oob@02ooon0004ohKo0?oo=`3oocL0oookJP;oom`000Sooo]ZodWo0?oonf[ooj80oomi
0?oonf[o0:OooookJPKoogT000?oodH0oomi0?ooR@000ooonfX02Ol0ooOo/ol0o`3o]ol02?oo01Oo
o`3oS?l0on7oob`0oa;o0002oookJP04o`3moooonf[oo`2QoonP00WoobP000?oogT0oookJ_oo:000
2?oo:0001onUo`3oo`00oookJ_oonf[oo`0ko`3oN_oo0<h00_oonfX00ol0S?ooo`X0oookJP05oomi
00?oobP01OooN@000ol00_ooobP0oolX0003oolX00;oogT00_oonfX4oomi00;oolT01OooN@09ool0
00WoobP000?ooo]Zoomi0?ooN@001_ooN@05ooo900Kooo]Z2ooob@08oookJP?oU@3o3ooonfX3o`2g
oakooo]Z0_oo0;X2oookJP;oold01_oonfX3odCo09Gooo]Z00?ookD0oookJ_oonfX03OoonfX00on`
0?oooo]ZoookJP09oookJP;o0:co0_oonfX2ool0MQCooo]Z00?o6_l0oookJ_ooP`000_l/o`02oook
JP03o`18oooonf[ooo]Z00Kooo]Z00Koo`2co`1Loooonf[o06;ooomL0?oo;P06oookJP04okko0?oo
nf[ooo]ZoookJP;oLOl000Cooo]Zo`06oooonf[o0?mH1?oonfX00ol0omGooo]ZoookJP02oookJP03
o`0Cool0ojKooo]Z00Cooo]Z0_oo]`03oookJP08o`1Boooonf[o0?l^o`3o;_oonf[oooh0oeOo0?n6
o`02oolg0005oookJ_oog03oom`0odWo0?oonfX00_ooXP02oookJP04o`2Woooonf[ooo]Zom`0o`?o
oo]Z00?oodH0oookJ_ooR@000ooonfX03ol0ooOooo]Zok?o0?l0okOooo]Zo`0Gool0on7ooo]Zoa;o
0?l0;Ooooo]Zo`3mool0ojkooo]ZoonP0002o`0go`0Dooo90?l0l_oooo]Zo`3o/ol0eOooo`0[oook
J_o00?oooo]Zool0Xooonf[oo`25oookJ_l:o`3oaOl0oon<0?oonf[o0?lTojGo0?noo`02oookJP04
ool0>ooonf[o0?mjo`3ohP;ooo]Z00Oo08coool:0?oonf[oo`3loooC0?oonf[o0?nI00;ooo]Z00Co
odP0oookJ_oonf[o0?ml0_l000002?l00_oooo]Zoml0oooeo`3ooo]ZoonL0?oonf[o0?l00ooonfX0
2Ooo<@3ooo]ZoookJ_oo0;[oold0oookJ_l0]ooooo]ZoiD0o`02oookJP;oog<02?oonfX6o`19oa[o
oo]Z0oooL`0;oookJP?oU@3o4?oonfX2o`2goaoooo]Z0_oo0;X00ooonf[oold0ooo=001aoookJP00
;ooonfX00ooo]@3ooo]ZoookJP0=oookJP;o/03o2_oonfX2o`2/o`;ooo]Z00?oo`1foookJ_oonfX0
4ooonfX01?lJo`3ooh<0oon30?l/o`03oookJP03o`18oooonf[ooo]Z00;ooo]Z00?oolT0oookJ_oo
nfX00_oob@001?oonf[o05coo`1Rool0H_l2oomi00Gooo]Z0_nno`03oookJP03og7o0?oonf[o00Ko
00;o0?mH0ooonfX2o`3oe@Gooo]Z00?o0:Coo`3oY_oonfX00ooonfX00ooo]`3ooo]ZoookJP03oook
JP08o`1Boooonf[o0?l^oookJ_oooP3oEol0ohKo0?oo=`02oookJP0:oooL0?oonf[oBOl0odWo0?oo
nf[ooj80o`3oDOoUo`3o0:OooookJPKoogT000CoodH0oomi0?ooN@3oogT00_oonfX02Ol0ooOo/ol0
o`3o]ooo0<ko01Ooo`3Uool0on7oob`0oa;o0002oookJP04o`3moooonf[oo`2QoonP00SoobP000?o
oo]Zol00oooonfX02?oo:0003Ol0obCoYOl0oolX0?oo:03ooo]Zool0>ol0og[oo`3>o`3oh_oonf[o
08coool:0?oonfX01?ooN@02oookJP;oobP00_ooN@02ooo90003oomi0?l00_oo000000?oobP02ooo
N@000ooob@3oogT0oomi0003oomi00Koo`000ooonfX7oolX00?ooo]Z2?ooN@001?oonf[oolT0ooo9
0?oob@07oookJPWoolT01ooonfX3oiD0oa3ooo]Z0_l0]olOoookJP;oo`2j0_oonfX2ooo=00Wooo]Z
00?oA?l0oookJ_oonfX0T_oonfX2oone00kooo]Z0_n`0?l;oookJP05o`2/oooonf[ooo]ZoookJ_oo
07H05?oonfX2oa[o00;ooh<000?o;?l0oookJ_oonfX00_l0B?l7oookJP;oo`2c00Co05cooookJ_l0
H_oooe`01_oonfX2okko00?ooo]Z00CoLOl0oookJ_l01_oo00Ko0_l0oeP3oookJP;o0?oE1?oonfX0
0ol04ooo0?nVoookJP04oookJP03oong0?oonf[ooo]Z00;ooo]Z00?o05;ooookJ_l0obh00_oonfX0
1?oooP3ooo]ZohKo0?oo=`02oookJP09oooL0?m9o`3oBOl0oookJ_ooXP3o0?mAoookJ_l0@Ooo0:Oo
00;ooo]Z00Oog03ooookJ_oonf[ooo]Zoom60?oonf[oohT000?ooo]Z01Oo0?ogoookJ_nco`3o0?ng
oookJ_l0iOoo0?oQoookJ_lBo`3o02gooookJ_l0oOoo0?n^oookJ_ooX03o03Ooo`08oooo@`3o0?;o
oookJ_l0ok?o0=Goool0:`02oookJP0<ol00oooo0:?ooo]Zool0QOoonf[o2_l0olGo0?ooS03ooo]Z
o`3o9?nUo`3o_ol00_oonfX01?oo03_ooo]Zo`3oN_l0on82oookJP07o`2<oooo2P3ooo]Zool0o?oo
d`3ooo]Zo`3oV@03oookJP03oom80?oonf[o0?ml00;o000000Wo00;oo`000?oonf[og`3oooGo0?oo
nf[ooi`0oookJ_l0o`001?oonfX01?oo<@3ooo]ZoookJ_ooc@02oookJP03o`2goooonf[oU@3o00?o
oo]Z0_ooL`0SoookJP?oog<02ooonfX3oiD0oa7ooo]Z0_l0]olOoookJP;oo`2j00?ooo]Zooo=0?oo
c@00LooonfX002kooo]Z00?ookD0oookJ_oonfX03OoonfX00on`0?oooo]ZoookJP09oookJP03o`2/
oooonf[ooo]Z00;oo`1f5OoonfX01?lJo`3ooh<0oookJ_l/o`02oookJP;o04So1?oonfX4ooo900;o
oo]Z00Co05coo`1RooooG03oogT01_oonfX00onno`3ooo]ZoookJP02oookJP04og7o0?oonf[o00Ko
o`3oF0Cooo]Z00?o0?oEoookJ_oonfX00ooonfX00ol0Y?oo0?nVo`3oYP04oookJP03oong0?oonf[o
oo]Z00;ooo]Z0_l0D_l01ooonf[o0?l^oookJ_oooP3oEol0ohKo0?oo=`000_oonfX00ooog03ooo]Z
odWo0002oookJP03oonR0?l0oe7oiOl000;oiOl01_ooN@000oooAP3oogT0oomi0002oookJP;o0?og
00Wo/ol0o`3o]ooo0<ko01Ooo`3Uool0on7oob`0oa;o0?oonfX00_l0oOl01?oonf[oo`2QoonP0?oo
N@06oolX0004o`3o]_oonf[o`03ooookJP?oobP000Oooo]ZoolX0?oo:03oobP0oon<0?l0obCoYOl0
00?oobP000Coo`0ko`3oN_oo0<ko0?oR0_oonfX00ol0S?ooo`X0oookJP03oomi0004o`3oVOoonf[o
obP0oolX00?oogT01Ooob@000ooO0?ooobP0oolX000<oomi0003ooo90?ooN@3oogT000;oogT00_oo
0006oomi00;ooo]Z0ooo:006oookJPKoogT00ooonfX00ooob@3ooo]ZoookJP04oookJPCoog<01ooo
b@04oookJPCoU@3o4OoonfX2o`2goakooo]Z0ooo0;X01?oonf[oold0ooo=0?ooc@2OoookJP03oone
0?oonf[ooo]Z00gooo]Z00?o/03ooookJ_oonfX02OoonfX2o`2/o`;ooo]Z0_oo07HDoookJP05oa[o
0?oonf[ooh<0oookJ_l/o`000_oonfX00ol0B?oo0?o1oookJP06oookJP04ool0/ooonf[o05coo`1R
o`;ooe`01_oonfX00onno`3ooo]ZoookJP02oookJP05og7o0?oonf[o00KooookJ_l0oeP01?oonfX0
0ol0omGooo]ZoookJP03oookJP;o0?nV1OoonfX01?oo]`3ooo]ZoookJ_oonfX2o`1Bo`03oookJ_l0
obkooo]Z00;oooh000?ooo]ZohKo0?oo=`000_oonfX01ooog03oBOl0oookJ_oonf[ooj80o`3oDOoo
nfX00_l0Yol2oookJP07om`0oooonf[ooo]ZoookJ_ooAP3ooo]Zoon90003oookJP0:o`3omonco`3o
/ol0o`3o]ooonf[o0>Goo`3ohOoonf[o4_l0o`0]o`;o0?go00_ooo]Zool0XOooX03o03Ooo`08oooo
@`3o0?;ooookJ_l0ok?o0=Goool0:`02oookJP0Bol00oooo0:?ooo]Zool0QOoonf[o2_l0olGo0?oo
nf[ooh`0o`3o9?nUo`3ooo]Zokoo0?oonf[oo`0koookJ_l0og[o0?oR0_oonfX02?l0S?ooo`X0oook
J_oonf[oo`3loooC0?oonf[o0?nI0_oonfX01?ooB03ooo]ZoookJ_l0og`2o`000004o`02ool0003o
g`3oooGo00;ooo]Z00?ooi`0oookJ_l0o`001?oonfX01ooo<@3ooo]ZoookJ_oonf[oold0oookJ_l0
]ol00_oonfX2oiD0o`?ooo]Z0oooL`0KoookJPGoog<02_oonfX4oiD0oa7ooo]Z0ol0]olNoookJP?o
o`2j0oooc@1eoookJP00;?oonfX2oone00kooo]Z0_n`0?l:oookJP;o0:co0_oonfX00ooo07Kooo]Z
oookJP0CoookJP03oa[o0?ooP`3ooh<000;o;?l00_oonfX00ol0B?oooo]ZoookJP03oookJPGoolT0
0_l0G?l00ol0H_oooe`0oookJP06oookJP04okko0?oonf[ooo]ZoookJP;oLOl00_l01_l00ol0oeSo
oo]ZoookJP02oookJP03o`3oeOoonf[ooo]Z00?ooo]Z00?o0:Coo`3oY_oonfX01?oonfX00ooo]`3o
oo]ZoookJP02oookJP07o`1Boooonf[o0?l^o`3o;_oonf[oooh0oeOo0002oolg0005oookJ_oog03o
om`0oookJ_m9o`000_oonfX00oooXP3o0?mAonGo0004onGo00?oogT00_ooAP003?ooR@3ooo]Zoook
J_oonf[o0?ogoookJ_nco`3o0?ngool0c_l05ooo0>Goo`3oh@;o4_l000Oooo]Zo`3mool0ojkooo]Z
ool0XOooX03oP`3o00GoobP000Ooo`0[o`3o]_oonf[o`03ooookJ_oo0:?oobP000;ooo]Z0ooo:000
0oooS03oobP0ojGo0003oolX0008ool0>ol0og[oobP0ool0c_ooN@3ooo]Zo`2<oooo2P02oookJP;o
ogT000Go0?nIoookJ_oonf[oobP0oookJP03oomi00GoolT000?og`3oooGo0?ooN@000oooN@000ol0
o`3oogT0oomi000Eoomi0003oolX0?oonf[ooo]Z00Oooo]Z0oooN@06oookJPKoog<01?oonfX5ooo9
00;ooo]Z1?nE0?l=oookJPSoolT07_oonfX2ool0^P;ooo]Z0_ooc@2PoookJP;ookD03_oonfX2ok00
o`_ooo]Z00Go0:cooookJ_oonf[ooo]Zool0MP0DoookJP;o6_l00_ooP`02obco00;ooo]Z00?o04So
oookJ_oonfX01_oonfX01_oo0;?o05coo`1Lool0H_oooe`0ool^00Kooo]Z00Co__l0oookJ_oonf[o
oo]Z0_mao`02o`06o`03oookJ_l0oeSooo]Z00?ooo]Z00?o0?oEoookJ_oonfX00_oonfX00ol04ooo
0?nVoookJP05oookJP06oong0?oonf[ooo]ZoookJ_l0D_oooo]Z0_l0obh01?oonf[oooh0oeOo0?n6
o`02oolg0004oookJ_oog03oom`0odWo00;ooo]Z00Cooj80o`3oDOoonf[o0:Oo0_oonfX2om`0o`?o
oo]Z00?oodH0oookJ_ooR@000ooonfX01ol0ooOo/ol0o`08ool0okOooo]Zo`3Uool0on400_lBo`00
3_l0;Ooo0?goo`3o[_oonf[oo`2QoonP0?l0=ooo00Sooom30?l0l_oooo]Zo`3o/ol0eOooo`0[0_oo
nfX04_o00?ooo`2SoookJ_oo08Gooo]Zo`[o0?o5o`3ooo]Zoon<0?oonf[oYOl0oookJ_noo`3ooo]Z
ool0>ooonf[o0?mjool0cP;ooo]Z00So08coool:0?oonf[ooo]Zool0o?ood`3ooo]Zo`3oV@;ooo]Z
00GoodP0oookJ_oonf[ooo]Zo`3oO002o`000009o`02ool0003og`3oooGo0?oonf[ooi`0o`2Ioooo
nf[o0?l000Cooo]Z00?ooc40oookJ_oonfX00_oonfX01?ooc@3ooo]Zo`2gool0]ol2oookJP;oU@3o
1?oonfX3oomc01?ooo]Z1OooL`0;oookJPCoU@3o4ooonfX2o`2goaoooo]Z0_oo0;X00ooonf[oold0
ooo=001hoookJP00:ooonfX00ooo]@3ooo]ZoookJP0=oookJP03ok00oooonf[ooo]Z00Wooo]Z00?o
0:cooookJ_oonfX00_oo07HEoookJP04oa[o0?ooP`3ooo]Zobco00;ooo]Z00?o0?o1o`18oooonfX0
1?oonfX5ooo90004o`1Lool0H_oo06;ooomL00Kooo]Z0_nno`001_ooN@3ooo]ZoookJ_mao`3ooo]Z
o`06o`;oogT00ooonfX2o`3oe@Cooo]Z00?o01?oo`2Tool0ojH01?oonfX2oong00Cooo]Z00?o05;o
oookJ_l0obh00_oonfX00ooooP3ooo]Zoolg0002oookJP05oooL0?oonf[ooo]ZodWo0?oonfX00_oo
XP08onGo0004oomi0?ooAP3ooo]Zoon900?ooo]Z00GoogT0oookJ_nco`3o0?ngoomi0002o`3Uo`0;
o`3ohOlBo`3o02gooookJ_l0oOoo0?n^oookJ_oo0:7ooj00oh<0ooooN@000ooo:0002Ooonf[oo`0[
o`3o]_oonf[o`03ooookJ_oo0:?oobP0oookJP02o`[o0005oolX0?oonf[ooh`0oolX0?nUo`000ooo
:0001?oo03_oobP0o`3oN_oo0<h2oomi0004o`2<oomn0?ooo`X0oookJP;oogT000Kooo]Zo`3oVOoo
nf[ooo]Zoom80?oonfX2oomi00GoolT000?og`3oooGo0?oo:0001?ooN@000ol0o`3oogT0oomi000F
oomi01;oog<02_oonfX3ooo90004oookJ_nE0?ooU@3ooiD0o`Wooo]Z3_oob@0NoookJP;oo`2j0_oo
nfX2ooo=0:7ooo]Z00?ookD0oookJ_oonfX03OoonfX00on`0?oooo]ZoookJP09oookJP;o0:co0_oo
nfX2ool0MQCooo]Z00Go6_l0oookJ_ooP`3ooo]Zobco0002oookJP;o04So1ooonfX2ool0/`04o`1L
oooonf[o06;ooomL00Kooo]Z0_nno`03oookJP04og7o0?oonf[o00KooookJP;o0?mH0ooonfX2o`3o
e@Cooo]Z00?o01?oo`3oY_oonfX01?oonfX2oong00?ooo]Z00?o05;ooookJ_l0obh00_oonfX01?oo
oP3oEol0ohKo0?oo=`02oookJP04oooL0?oonf[oBOl0oookJP;ooj800_oonfX01?l0Yooooo]Zoook
J_oL0?l4oookJP03oom60?oonf[oohT000?ooo]Z01Oo0?ogok?o0?oo0<ko0?ngoookJ_l0iOoo0?oQ
oa;o0?oo;03o02goo`3mool0ojkooo]Zool0XOooX03o03Ooo`08oooo@`3o0?;ooookJ_l0ok?o0=Go
ool0:`02oookJP0Bol00oooonf[oo`2Sool0QOoonf[o2_l0olGo0?oonf[ooh`0oookJ_nUo`3ooo]Z
okoo0?oonf[oo`0koookJ_l0TOoo0?mj0_oonfX00ol0S?ooOP3oool:0002oookJP03ool0o?ood`3o
0?nI00?ooo]Z017oodP0oookJ_oonf[o0?mloookJ_l0003o00;oo`000?oO0?oo02goooGo0?oonf[o
oi`0o`2Ioooonf[oofH0o`3o0003oookJP03oola0?oonf[ooo]Z00;ooo]Z00Coold0ool0^_oonf[o
oo]Z0_l0]ol2oookJP?oU@3o1?oonfXCoomc00gooo]Z0onE0?lDoookJP?o0;Oo7ooonfX2ool0^P03
oookJ_ooc@3oold007[ooo]Z000ZoookJP03oone0?oonf[ooo]Z00cooo]Z0_n`0?l:oookJP;o0:co
0_oonfX00ooo07Kooo]ZoookJP0DoookJP;ooh<000Cooo]Zobco0?oonf[ooo]Z0_l0B?l5oookJPGo
olT000Co05coooo90?oob@3ooe`01_oonfX02Onno`3ooo]ZoookJ_ooN@3ooo]Zog7o0?oonf[o00Ko
oomi0004oookJP03o`3oeOoonf[ooo]Z00?ooo]Z00?o0:Coo`3oY_l0ojH01?oonfX00ooo]`3ooo]Z
oookJP03oookJP04o`1Boooonf[o0?l^oookJP;oooh000GoQ_l0oolg0?oonf[ooo]ZoooL0002oook
JP04odWo0?oonf[ooj80oom<00OoiOl00_ooN@000oooAP3ooo]Zoon90003oookJP06o`3omoooN@3o
/ol0o`3o]ooonf[oogT00_l0on402_lBo`3o02gooookJ_l0oOoo0?n^oookJ_oo0:7ooj00oookJ_l0
2?l2oolX0003o`3o/ooonf[oo`0[00;ooo]Z00co`03ooookJ_oo0:?oo`25oookJ_l:o`3oog/0oolX
0?oonf[ooh`0oookJ_nUo`04oolX0003ool0>ol0og[oogT000;oogT000?o08cooomi0?oo2P000_oo
nfX00oooN@3ooo]Zo`3oV@02oookJP03oom80?oonf[ooo]Z00;oogT01Ooob@000ooO0?oomOl0oomi
0004oomi0003o`3o0?ooN@3oogT000KoogT00_oonfX00oooc@3oiOl0onGo0002oookJP04o`2goooo
nf[oogT0oomi00?oU@3o1?oonfX5ooo901Gooo]Z00CoU@3oooo90?nE0?ooU@3o3?oonfX=ooo901co
oo]Z0ooo0;X2oookJP;oold0X_oonfX00ooo]@3ooo]ZoookJP0<oookJP;o/03o2ooonfX01Ol0[?oo
oo]ZoookJ_oonf[oo`1f01Gooo]Z00Go6_l0oon30?ooP`3ooo]Zobco0002oookJP03o`18oooonf[o
oo]Z00Kooo]Z00Coo`2coookJ_l0G?oooo]Z0_ooG006oookJP03okko0?oonf[ooo]Z00;ooo]Z00Go
LOl0oookJ_l01_oooo]Zo`3oF004oookJP03o`3oeOoonf[ooo]Z00?ooo]Z0_l0ojH5oookJP03oong
0?oonf[ooo]Z00;ooo]Z00Co05;ooookJ_l0obkooo]Z0_oooP000omGo`3oQ_l0oolg0002oookJP09
oooL0?oonf[oBOl0oookJ_ooXP3ood`0oookJ_l0@Ooo0:Oo00;ooo]Z00?og03ooookJ_oonfX00_oo
nfX00oooAP3ooo]Zoon90003oookJP05o`3omonco`3o0?ngo`3o]ooonfX00_l0on404?lBo`3oob`0
o`0]ool0oOoo0?n^oookJ_oo0:7ooj00o`0gool02?oood<0o`3boooonf[o0?nco`3Eoooo02/2oook
JP0=ol00oooonf[oo`2Sool0QOoonf[o2_l0olGo0?oonf[ooh`0oookJ_nUo`3ooo]Zokoo0002oook
JP08ool0>ol0TOoo0?mjo`3oh_oonf[o08coogh0oooo2P02oookJP03ool0o?ood`3o0?nI00?ooo]Z
00CoodP0oookJ_oonf[o0?ml0_oonfX03?l0003o00;oo`000?oO0?oo02goooGo0?oonf[ooi`0o`2I
ooooIP3oY03oo`3o00Cooo]Z00?ooc40oookJ_oonfX00_oonfX00oooc@3oo`2joookJP02oookJP03
o`2goooonf[ooo]Z00;ooo]Z0onE0?lNoookJP?oU@3o5?oonfX3o`2goaoooo]Z0ooo0;X00ooonf[o
old0ooo=001loookJP00>?oonfX00on`0?oooo]ZoookJP09oookJP03o`2/oooonf[ooo]Z00;oU?l0
5OoonfX00olJo`3ooh<0oookJP02obco00;ooo]Z00?o04SooookJ_oonfX01?oonfX4ooo900;o05co
1?oob@05oookJP03okko0?oonf[ooo]Z00?oogT00_l01_l00oooN@3ooo]ZoookJP02oookJP03o`3o
eOoonf[ooo]Z00?ooo]Z00?o0:Coo`3oY_oonfX01?oonfX00ooo]`3ooo]ZoookJP02oookJP;o05;o
00Oooo]Zo`3o;_oonf[oooh0oeOo0?n6o`3oocL000;ooo]Z00Ooom`0oomi0?m9o`3oBOl0oookJ_oo
XP3o0?mA00KoiOl000CoogT0oookJ_oonf[oodH00_ooR@02oookJP;o0?og0_nco`000oo_0?ooogT0
oomi0002oomi000?oa;o0?l0;Ooooo]Zo`3mool0ojkooo]Zool0XOooX03ooo]Zo`08oooo:03oiOl0
o`3o/ooonf[oo`0[00;ooo]Z00co`03ooookJ_oo0:?oo`25oookJ_l:o`3oog/0olGo0?oonf[ooh`0
oookJ_nUo`04oolX0003ool0>ol0og[oo`3>00?oogT000So08coool:0?ooN@3oogT0ool0o?ood`3o
oo]Zo`3oV@;ooo]Z00?oodP0oookJ_oonfX00_ooN@05ooo90003oml0oooeo`3oogT000CoogT000?o
0?l0oomi0?ooN@001_ooN@02oookJPCoiOl00_oonfX00ol0]oooogT0oomi0002oomi0005oookJ_nE
0?ooU@3ooiD0oooonfX03Ooob@0:oookJP?oU@3o4?oonfX;ooo901cooo]Z0_oo0;X3oookJP;oold0
/_oonfX00on`0?oooo]ZoookJP09oookJP;o0:co0_oonfX2ool0MQCooo]Z0_lJo`001?ooP`3ooo]Z
obco0?l/o`02oookJP03o`18oooonf[ooo]Z00Gooo]Z0_oo0;<2o`1Lo`03o`1RooooG03ooo]Z00Ko
oo]Z00Co__l0oookJ_oonf[ooo]Z0_mao`02o`06o`03oookJ_l0oeSooo]Z00?ooo]Z00?o0?oEoook
J_oonfX00_oonfX00ol04ooo0?nVoookJP05oookJP04oong0?oonf[ooo]ZoookJP;o05;o00Sooo]Z
o`3o;_oonf[oooh0oeOo0?oonf[oQ_l0oolg00;ooo]Z00Ooom`0odWo0?m9o`3ooo]ZoonR0?l0oe7o
oo]Z00;o0:Oo0_oonfX00ooL0?oooo]ZoookJP02oookJP03oom60?ooR@3oohT000;ooo]Z01So0?og
ok?o0?nco`3o0?ngonl0ool05ooo0?oQoookJ_lBo`3oob`0o`0]ool0oOoo0?n^oookJ_oo0:7ooj00
o`0gool02?oood<0o`3boooonf[o0?nco`3Eoooo02/2oookJP0=ol00oooonf[oo`2Sool0QOoonf[o
2_l0oomk0?o5o`3ooh`0oookJ_nUo`3o0?lTokoo0002oookJP04ool0>ol0TOoo0?mjool0cP;ooo]Z
00So08coool:0?oonf[ooo]Zool0o?oonf[oom<0o`3oV@?ooo]Z00CoodP0oookJ_oonf[o0?ml0_oo
nfX02ol0003o00;oo`000?oO0?oo02goooGo0?oonf[ooi`0o`2IooooIP3o0?l000Gooo]Z00?ooc40
oookJ_oonfX00ooonfX00oooc@3oo`2joookJP02oookJP03o`2goooonf[ooo]Z00Cooo]Z0onE0?lH
oookJP?oU@3o5?oonfX3o`2gob3ooo]Z0_oo0;X2oookJP;oold0O_oonfX003Kooo]Z0_n`0?l;oook
JP04o`2/oooonf[ooo]ZoiCo01Kooo]Z00Co6_l0oon30?oonf[o;?l00_oonfX00ol0ol7o04Sooook
JP06oookJP?oolT000?o05coooo90?oob@000_oob@05oookJP;o__l00_oonfX6oomi00?ooo]Z0_l0
omD4oookJP03o`0Cool0Y?oo0?nV00Cooo]Z0_oo]`04oookJP09o`1Boooonf[o0?l^o`3o;_oonf[o
ooh0oeOo0?n6o`3oocL000;ooo]Z00?oom`0oookJ_m9o`000_oonfX00oooXP3o0?mAonGo0004onGo
0003oomi0?oonf[ooo]Z00;oodH000WoohT0oookJ_oonf[ooo]Zo`3omooonf[o/ol0o`3o]oo_0?l0
1?ooN@003olBo`3oogT0oookJ_l0oOoo0?n^oookJ_oo0:7ooj00oookJ_oo@`3oogT0o`3bool0ok?o
iOl0ool0:`03oookJP0;ol00oooo0:?oo`25oookJ_l:o`3oog/0olGo0?oonf[ooh`0oookJ_nUo`00
1?oo:0000ooo03_o0?mjool0cP07oomi0004ool0o?ood`3ooo]Zo`3oV@;ooo]Z00?oodP0oookJ_oo
nfX00oooN@04ooo90003oml0ool0;OoomOl000GoogT000?o0?l0oomi0?ooN@001_ooN@000ooonf[o
iOl0onGo0004onGo00;ooo]Z1_ooN@02oookJP03oiD0oooob@3oolT000ooolT01_nE0?lDoookJPSo
olT07?oonfX2ool0^P;ooo]Z0oooc@2boookJP;o/03o2ooonfX01Ol0[?oooo]ZoookJ_oonf[oo`1f
01Gooo]Z00Go6_l0oookJ_ooP`3ooo]Zobco0002oookJP;o04So1ooonfX01_oo0;?ooo]Zo`1Loooo
nf[o06;ooomL00Kooo]Z0_nno`03oookJP04og7o0?oonf[o00KooookJP;o0?mH0ooonfX2o`3oe@Co
oo]Z00?o01?oo`3oY_oonfX01?oonfX2oong00?ooo]Z00Oo05;ooookJ_l0obko0?l^oookJ_oooP3o
Eol000;oQ_l000GoocL0oookJ_oonf[oom`0odWo0002oookJP04oonR0?l0oe7ooo]Zo`2Wo`;ooo]Z
0_oL0?l3oookJP;oodH001GoohT0oookJ_oonf[ooo]Zo`3omonco`3o00Soo`3o]oo_0?oo01Ooo`3o
hOoonf[o4_l0ool/0?l0;Ooo0?goo`3o[_oonf[oo`2QoonP0?l0=ol00_oo@`000ol0l_oooo]Zo`3o
/`02ool0:`;ooo]Z01?o`03ooookJ_oo0:?oo`25oookJ_l:o`3oog/0olGo0?ooS03ooo]ZojGo0?l0
obCooo]Zokoo0?oonf[oo`0koookJ_l0og[oo`3>00;ooo]Z00So08coogh0oooo2P3ooo]Zool0o?oo
nf[oom<0o`3oV@?ooo]Z00GoodP0oookJ_oonf[ooo]Zo`3oO002oookJP05o`02ool0003og`3ooeKo
0?oeo`000_oonfX01?ooW03o09WooomV0?l0o`06oookJP03oola0?oonf[ooo]Z00?ooo]Z00?oold0
ool0^_oonfX00_oonfX2o`2go`Oooo]Z1_nE0?l8oookJP[oU@3o5?oonfX3o`2gob7ooo]Z0_oo0;X0
1?oonf[oold0ooo=0?ooc@20oookJP00=OoonfX00on`0?oooo]ZoookJP09oookJP;o0:co0_oonfX0
0onDo`3ooo]ZoookJP0CoookJP05oa[o0?ooP`3ooh<0oookJ_l/o`000_oonfX00ol0ol7o04Sooook
JP06oookJP?oolT000Co05coooo90?oob@3ooe`01_oonfX01?nno`3ooo]ZoookJ_oonfX7oomi00;o
oo]Z00?o0?oEoookJ_oonfX00ooonfX00ol04ooo0:Coo`3oYP04oookJP03oong0?oonf[ooo]Z00?o
oo]Z00?o05;ooookJ_l0obh00_oonfX01OoooP3ooo]ZohKo0?oo=`3ooo]Z00;oom`000Kooo]ZodWo
0?ooN@3oogT0oonR0?ooN@04onGo0007om`0oooonf[ooo]ZoookJ_ooAP3ooo]Zoon90003oookJP05
o`3omooonf[o/ol0o`3o]ooo0<h01?ooN@003olBo`3oogT0oomi0?l0oOoo0?n^oookJ_oo0:7ooj00
oookJ_oo@`3oolT0o`3bool0ok?oiOl0ool0:`02onGo000=oookJ_o00?ooo`2Sool0QOoonf[o2_l0
oomk0?o5o`3ooo]Zoon<0?oonf[o0?lTojGo0003oolX0004ool0>ol0og[oogT0ool0cPOoogT000?o
om<0oookJ_l0oiT00ooonfX00oooB03ooo]ZoookJP02oomi0003oookJ_oob@3oolT000;oolT000?o
g`3oo`0]oooeo`001OooN@000ol0o`3oogT0oomi0002oookJPGoogT01ooUo`09oomi0003oookJ_oo
b@3oolT000goolT06OoonfX3o`2go`OoolT06_oonfX3ool0^P04oookJ_ooc@3oold0ooo=0;Cooo]Z
00?o/03ooookJ_oonfX02OoonfX2o`2/o`;ooo]Z0_oo07HDoookJP;o6_l00_ooP`001Ooonf[o;?l0
oookJ_oonf[o04So00Sooo]Z00Coo`2coookJ_l0G?oooo]Z0_ooG006oookJP03okko0?oonf[ooo]Z
00;ooo]Z00GoLOl0o`06ool01_oooo]Zo`3oF004oookJP03o`3oeOoonf[ooo]Z00?ooo]Z00?o0:Co
o`3oY_oonfX01?oonfX00ooo]`3ooo]ZoookJP02oookJP03o`1Boooonf[o0?l^00;ooo]Z00?oooh0
oeOo0?n6o`000_oo=`001?oonf[oom`0oooL0?m9o`02oookJP04oonR0?l0oe7ooo]Zo`2Wo`;ooo]Z
00?og03ooookJ_oonfX00_oonfX00oooAP3ooo]Zoon90003oookJP0Ho`3omonco`3ooo]Zo`3o]ooo
nf[o0>Goo`3ohOoonf[o4_l0ool/0?l0;Ooo0?goo`3o[_oonf[oo`2QoonP0?l0=ooood<0ooo90?l0
l_oooo]Zo`3o/ooo02_o0?nf0_oonfX06?o00?oooo]Zool0Xooo08Gooo]Zo`[o0?ooN`3oaOl0oook
J_ooS03ooo]ZojGo0?oonf[o_ol0oookJ_oo03_ooo]Zo`3oN_oonf[oo`3>oookJ_l0S?ooOP3oool:
00;ooo]Z00?oo`3loooC0?l0oiT01?oonfX01?ooB03ooo]ZoookJ_l0og`3oookJP0;o`02ool0003o
g`3oo`0Joooeo`3ooo]ZoonL0?l0VOoooo]ZoomV0?l0o`001_oonfX00ooo<@3ooo]ZoookJP04oook
JP03ooo=0?oonf[ooo]Z00?ooo]Z0ol0]ol:oookJPSoU@3o6ooonfX3o`2gob7ooo]Z0ooo0;X3ooo=
08?ooo]Z000coookJP;o/03o2ooonfX00ol0[?oooo]ZoookJP02oiCo01Gooo]Z00?o6_l0oon30?oo
nfX00_l/o`02oookJP;o04So1ooonfX3ooo90003o`1Loooob@3ooe`000Oooo]Z00Go__l0oookJ_oo
nf[ooo]Zog7o0008oomi0003o`3oeOoonf[ooo]Z00?ooo]Z00?o0:Coo`3oY_l0ojH01?oonfX00ooo
]`3oogT0oookJP02oookJP;oogT000?ooo]Zo`3o;_oonfX00_oooP001_oonf[oQ_l0oolg0?oonf[o
om`0oookJP;oBOl000CoogT0oonR0?ooXP3oogT00ooUo`000ooonf[og03ooookJP02oookJP03oom6
0?oonf[oohT000?ooo]Z00Co0?ogoookJ_nco`3o0?ng1OooN@001?lBo`3oogT0oomi0?l0oOl2oomi
0009ool0XOooX03ooo]Zoom30?oob@3o0?;oo`3o/ooUo`3oo`0[00?oiOl000Wo`03oool0Xooo08Go
oo]Zo`[o0?ooN`3oaOl0oookJ_ooS0000_oonfX02?nUo`3oobP0oolX0?oo:03oo`0koomi0?l0og[o
o`3>1oooN@000oood`3oogT0o`3oV@03oookJP06oom80?oonf[ooo]ZoookJ_ooN@3ooo]Z1Ooob@00
0ooO0?oo02goooGo0005oomi0003o`3o0?ooN@3oogT000;ooo]Z1?ooN@09onGo00[oogT02ooob@0I
oookJP?o0;Oo0ooonfX5ooo901[ooo]Z0_oo0;X2oookJP;oold0]OoonfX2ok00o`_ooo]Z00Go0:co
oookJ_oonf[ooo]Zool0MP0EoookJP04oa[o0?oonf[ooh<0oookJP;o;?l00_oonfX00ol0B?oooo]Z
oookJP05oookJP;oo`2c00Cooo]Zo`1Lool0H_oooe`01ooonfX01?nno`3ooo]ZoookJ_oonfX2og7o
0004o`06oooonf[ooo]Zo`3oF0Cooo]Z00?o0?oEoookJ_oonfX00ooonfX2o`3oYPGooo]Z00CookL0
oookJ_oonf[ooo]Z0_l0D_l00ooonf[o0?l^oookJP02ooon0003oeOo0?n6o`3oocL000;ooo]Z00Co
om`0oookJ_m9o`3ooo]Z0_ooXP02oookJP04o`2Woooonf[ooo]Zom`0o`Cooo]Z00?oodH0oookJ_oo
R@000ooonfX02Ol0ooOo/ol0o`3o]ol0okOooo]Zo`3Uool0on7ooo]Zoa;o0002o`0]o`0=o`3moooo
nf[oo`2Qool0XOooX03o03Oooom30?oob@3o0?;ooookJ_l0ok?oo`0[o`3o]P02oookJP0Dol00oooo
nf[oo`2Sool0QOoonf[o2_l0oomk0?o5o`3ooo]Zoon<0?oonf[oYOl0oookJ_noo`3ooo]Zool0>ooo
nf[o0?mjoookJ_oo0<h2oookJP07o`2<oooonf[oo`X0oookJ_oo0?coom<0o`3oV@04oookJP05oom8
0?oonf[ooo]ZoookJ_l0og`00ooonfX02ol00_oo0000oml0ool06_oomOl0oookJ_ooW03o09Wooook
J_ooIP3o0?l000Kooo]Z00?ooc40oookJ_oonfX01OoonfX00oooc@3oo`2joookJP05oookJP;o0;Oo
9ooonfX4o`2gob7ooo]Z0ooo0;X00ooonf[oold0ooo=0026oookJP00<_oonfX00on`0?oooo]Zoook
JP09oookJP;oolT00_oonfX00onDo`3ooo]ZoookJP0DoookJP;ooh<000Kooo]Zobco0?oonf[ooo]Z
o`3o`Ol0B?l8oookJP;oolT00_l0G?l2oomL00Kooo]Z0_nno`03oookJP03og7o0?ooN@3oogT000Go
ogT00_l0omD01oooN@3ooo]ZoookJ_oonf[o01?oo`2Tool0ojH01OoonfX00ooo]`3ooo]Zoomi0002
oookJP07oomi0?oonf[o0?l^o`3o;_oonf[oooh0oeOo0002ohKo0005oolg0?oonf[oom`0oookJ_m9
o`000_ooN@001OooXP3ood`0oomi0?ooN@3oiOl000;ooo]Z00Oog03ooookJ_oonf[ooo]Zoom60?oo
nf[oohT000?ooo]Z00Co0?ogoookJ_nco`3o0?ng1OooN@001?lBo`3oogT0oomi0?l0oOl4oomi0007
oookJ_oo@`3oolT0o`3bool0ok?oiOl0ool0:`03onGo0003ol00oooo0:?oo`2500;ooo]Z00Co2_l0
olGo0?oonf[ooh`00_oonfX02OnUo`3oobP0oolX0?oonf[oogT0ool0>ol0og[oo`3>o`3ohP07oomi
0003oooC0?oonf[o0?nI00?ooo]Z00KoodP0oookJ_oonf[ooo]Zo`3oO?oonfX5ooo90003oml0oooe
o`3oogT000GoogT000?o0?l0oomi0?oonfX00ooonfX2oomi00_oiOl02OooN@08ooo901Sooo]Z1?l0
]ol7oookJP;oolT06_oonfX2ool0^P04oookJ_ooc@3oold0ooo=0;Kooo]Z00?o/03ooookJ_oonfX0
2OoonfX2o`2/o`;ooo]Z0_oo07HEoookJP05oa[o0?ooP`3ooh<0oookJ_l/o`000_oonfX2o`18o`Oo
oo]Z00Coo`2coookJ_l0G?oo05co0_ooG006oookJP;o__l00ooonfX01?mao`3ooo]Zo`06oooonfX2
o`3oF0?ooo]Z0_l0omD4oookJP03o`0Cool0ojKooo]Z00Gooo]Z00KookL0oookJ_oonf[ooo]Zo`1B
oooonfX2o`3o;P03oookJ_oooP3oEol000;oQ_l000coocL0oookJ_oonf[oom`0oookJ_m9o`3ooo]Z
oonR0?ooC03ooo]Zo`11ool0Yol2oookJP03om`0oooonf[ooo]Z00;ooo]Z00?oodH0oon90?ooR@00
0ooonfX06?l0ooOo/ol0o`3o]oo_0?oooo]Zo`3Uool0on7ooo]Zoa;o0?l0;Ooooo]Zo`3moooonf[o
o`2QoookJ_ooX03o03Oooom30?oob@3o0?;ooookJ_l0ok?oo`0[o`3o]P;ooo]Z00ko`03ooookJ_oo
0:?oo`25oookJ_l:o`3oog/0olGo0?oonf[ooh`0oookJ_nUo`3ooo]Zokoo00;ooo]Z00Coo`0ko`3o
N_l0TOooo`3>0_oonfX02?l0S?ooOP3oool:0?oonf[oo`3loookJ_ood`3o0?nI0ooonfX00oooB03o
oo]ZoookJP02oookJP08o`3oO?oonf[ooo]ZoookJ_l00_oo0000oml0oooeo`02oookJP05oonL0?l0
VOoooo]ZoomV0?l0o`001_oonfX00ooo<@3ooo]ZoookJP06oookJP03ooo=0?oo0;[ooo]Z00Kooo]Z
0ol0]olPoookJPCo0;Oo8ooonfX2ool0^P04oookJ_ooc@3oold0ooo=08Sooo]Z000aoookJP03ok00
oooonf[ooo]Z00Wooo]Z00?oolT0oookJ_oonfX00_nDo`0EoookJP03oa[o0?ooP`3ooo]Z00;o;?l0
0_oonfX00ol0ol7o04SooookJP07oookJP;oolT000Co05coo`1RooooG03oobh01_oonfX00onno`3o
oo]ZoookJP02oookJP03og7o0?ooN@3oogT000GoogT000?o0?oEoomi0?oonfX00ooonfX00ol04ooo
0:Coo`3oYP05oookJP03oong0?oonf[oogT000?oogT0013ooo]Zo`3o;_oonf[ooo]Zooon0?oonf[o
Q_l0oookJ_oo=`3ooo]ZoooL0?oonf[oBOl0oookJ_ooN@3ooj801OooN@001?oonf[og03ooookJ_oo
nfX2oom60003oookJ_ooR@3ooo]Z00;ooo]Z00Co0?ogoookJ_nco`3o0?ng1?ooN@02oa;o00;oogT0
00co0?gooomi0?ooN@3oogT0oonP0?oonf[ood<0ooo90?l0l_oo0?nconGo0?oo02/3onGo0009ol00
oooo0:?ooo]Zool0QOoonf[o2_l0olGo0?oonf[ooh`000;ooo]Z00WoYOl0oookJ_oo:03ooo]Zoomi
0?oo03_o0?mjoomi0?oo0<h01oooN@000oood`3ooo]Zo`3oV@03oookJP05oom80?oonf[ooo]Zoook
J_l0og`00_oonfX4ooo90003oml0ool0;OoomOl000KoogT000?o0?l0oomi0?oonfX00ooonfX3oomi
00_oiOl02?ooN@05ooo901Kooo]Z1Ol0]ol;oookJP03ooo90?oonf[ooo]Z01Kooo]Z0ooo0;X00ooo
nf[oold0ooo=002hoookJP03ok00oooonf[ooo]Z00Wooo]Z00Go0:cooookJ_oonf[ooo]Zool0MP0E
oookJP;o6_l000Cooh<0oookJ_l/o`3o;?l00_oonfX00ol0B?oooo]ZoookJP06oookJP06ool0/ooo
nf[o05coo`1RooooG03oobh01_oonfX00onno`3ooo]ZoookJP02oookJP05og7o0?l01_oo00Kooook
J_l0oeP01?oonfX00ol0omGooo]ZoookJP03oookJP03o`2Tool0ojKooo]Z00Cooo]Z0_oo]`03oook
JP03o`1Boooonf[o0?l^00;ooo]Z00Goooh0oeOo0?n6o`3ooo]Zoolg0002oookJP07oooL0?m9o`3o
BOl0oookJ_ooXP3o0?mAoookJP02o`2Wo`;ooo]Z00Cog03ooookJ_oonf[ooo]Z0_ooAP000oooR@3o
oo]ZoookJP02oookJP0Ho`3omonco`3o0?ngonl0oooonf[o0>Goo`3ohOoonf[o4_l0o`0]oooonf[o
0?gooookJ_oo0:7ooo]ZoonP0?l0=ooood<0ooo90?l0l_oooo]Zo`3o/ooo02_o0?nf0_oonfX03_o0
0?oooo]Zool0Xooo08Gooo]Zo`[o0?ooN`3oaOl0oookJ_ooS03ooo]ZojGo0?oonf[o_ol00_oonfX0
1?oo03_o0?mjo`2Aoooo0<h3oookJP07o`2<oooo2P3ooo]ZoookJ_oo0?coom<0o`3oV@03oookJP03
oom80?oonf[ooo]Z00;ooo]Z00Wo0?mloookJ_oonf[ooo]Zo`02ool0003og`3oo`0]oooeo`000_oo
nfX01OooW03o09WooookJ_ooIP3o0?l000Kooo]Z00?ooc40oookJ_oonfX01ooonfX00oooc@3oo`2j
oookJP08oookJPCo0;Oo5ooonfX5o`2gobCooo]Z0ooo0;X00ooonf[oold0ooo=002;oookJP00;ooo
nfX2ok00o`[ooo]Z0_oob@02oookJP03oiCo0?oonf[ooo]Z01Cooo]Z00Co6_l0oon30?oonf[o;?l0
0ooonfX00ol0ol7o04SooookJP06oookJP06ool0/ooob@3o05coo`1Lool0H_oooe`01ooonfX00onn
o`3ooo]ZoookJP02oookJP03og7o0?ooN@3oogT000GoogT000?o0?oEoookJ_oonfX00ooonfX00ol0
4ooo0?nVo`3oYP05oookJP03oong0?oonf[oogT000CoogT000go0?l^oookJ_oooP3oooh0oookJ_n6
o`3ooo]Zoolg0?oonf[oom`0oookJ_m9o`3ooo]Z00;ooj801oooN@02oookJP04oom60?oonf[ooo]Z
oon900?ooo]Z00Co0?ogoookJ_nco`3o0?ng0oooN@000ol0on7o4_l0oomi0002oomi000<o`3moooo
N@3oogT0oh<0ooooX03ooo]Zoom30?oonf[o0?;oo`3o/ooUo`3oo`0[0ooUo`002Oo00?ooo`2Soook
J_oo08Gooo]Zo`[o0?ooN`3oaOl0oon<0002oookJP03ojGo0?oonf[oobP000;ooo]Z00Coo`0ko`3o
N_ooN@3oo`3>1oooN@000oood`3ooo]Zo`3oV@04oookJP05oom80?oonf[ooo]ZoookJ_l0og`00_oo
nfX4ooo90003oml0ool0;OoomOl000?oogT01Ooob@05oookJP?oogT00_oonfX9onGo00OoogT00_oo
b@03oomi01Ko0;Oo9_oonfX3ool0^P04oookJ_ooc@3oold0ooo=0;Sooo]Z0_n`0?l:oookJP;o0:co
0ooonfX00ooo07Kooo]ZoookJP0CoookJP05oa[o0?oonf[ooh<0oookJ_l/o`000ooonfX00ol0B?oo
oo]ZoookJP05oookJP;oo`2c00Cooo]Zo`1Lool0H_oooe`01ooonfX00onno`3ooo]ZoookJP02oook
JP05og7o0?l01_oooo]ZoookJ_l0oeP01?oonfX00ol0omGooo]ZoookJP03oookJP03o`2Tool0ojKo
oo]Z00Cooo]Z00?ookL0oookJ_oonfX00_oonfX01?l0D_oooo]Zo`3o;_oonfX2ooon0004oeOo0?n6
o`3ooo]Zoolg00;ooo]Z00?oom`0odWo0?oonfX00_ooXP000ol0oe7ooo]Zo`2Wo`03oookJP07om`0
oooonf[ooo]ZoookJ_ooAP3ooo]Zoon90004oookJP0Ho`3omonco`3o0?ngool0c_oonf[o0>Goo`3o
hOoo;03o4_l0o`0]oooonf[o0?gooookJ_oo0:7ooo]ZoonP0?l0=ooood<0ooo90?l0l_oooo]Zo`3o
/ooo02_o0?nf0_oonfX03_o00?oooo]Zool0Xooo08Gooo]Zo`[o0?ooN`3oaOl0oookJ_ooS03ooo]Z
ojGo0?oonf[o_ol00_oonfX01?oo03_o0?mjo`2Aoooo0<h3oookJP07o`2<oooo2P3ooo]ZoookJ_oo
0?coom<0o`3oV@04oookJP05oom80?oonf[ooo]ZoookJ_l0og`01?oonfX01Ol00_oo0000oml0ool0
;OoomOl000;ooo]Z00Gooi`0o`2Ioooonf[oofH0o`3o0007oookJP03oola0?oonf[ooo]Z00Oooo]Z
0_ooc@0<oookJQOo0;Oo9_oonfX3ool0^P04oookJ_ooc@3oold0ooo=08gooo]Z000^oookJP03ok00
oooonf[ooo]Z00Sooo]Z00?oU?l0ooo90?oonfX00_oonfX00onDo`3ooo]ZoookJP0DoookJP04oa[o
0?ooP`3ooo]Zobco00;ooo]Z00?o0?o1o`18ool0B?l01ooonfX01?oo0;?ooo]Zo`1Lool0H_l2oomL
00Kooo]Z0_nno`03oookJP;oLOl01_ooN@02o`3oe@Cooo]Z00?o01?oo`2Tool0ojH01OoonfX2oong
0003oookJ_ooN@3oogT000GoogT000Koooh0oeOo0?oonf[oQ_l0oookJ_oo=`02oooL00;oBOl000?o
oo]ZoonR0?ooC0001_ooN@03oookJP04oom60?oonf[ooo]Zoon900?ooo]Z00Ko0?ogoookJ_nco`3o
0?ngoookJ_ooN@02o`3oh@0@oa;o0?ooN@3oogT0oomi0?l0oOooogT0ool0XOn30?oooj00oomi0?oo
@`3ooo]Zo`3bool0ok?oiOl0ool0:`?oiOl000Wo`03oool0Xooonf[oo`25oookJ_l:o`3oog/0olGo
0?ooS0000_oonfX02OnUo`3ooo]ZoookJ_noo`3ooo]Zool0>ol0og[oogT0ool0cP07oomi0004ool0
o?ood`3ooo]Zo`3oV@?ooo]Z00GoodP0oookJ_oonf[ooo]Zo`3oO003oookJP?oolT000CoE_l0oml0
oooeo`3o00000oooN@08ooo900?ooo]Z0_ooN@05oookJPOoiOl00_ooN@11oookJPCoo`2j00Cooo]Z
ooo=0?ooc@3oold0^_oonfX00on`0?oooo]ZoookJP09oookJP04o`2/oooonf[ooo]ZoookJP;oo`1f
5OoonfX01OlJo`3ooh<0oon30?oonf[o;?l000;ooo]Z0_l0B?l7oookJP04ool0/ooonf[o05coo`1L
o`;ooe`01_oonfX2okko00?ooo]Z0_mao`001?l01_oooo]ZoookJ_l0oeP3oookJP;o0?oE1?oonfX0
0ol04ooo0?nVo`3oYP05oookJP03oong0?oonf[ooo]Z00;ooo]Z00_o05;ooookJ_l0obkooo]Zooon
0?oonf[oEol0ohKo0?oonf[oocL0oookJP02oooL0007odWo0?oonf[ooj80oom<0?l0oe7ooo]Zo`2W
o`03oookJP07om`0oooonf[ooo]ZoookJ_ooAP3ooo]Zoon90004oookJP03o`3omonco`3o0?ng00;o
oo]Z0_l0on404Ooo;03o4_l0o`0]oooonf[o0?gooookJ_oo0:7ooo]ZoonP0?l0=ooood<0ooo90?l0
l_oooo]Zo`3o/ooo02_o0?nf00;ooo]Z00co`03ooookJ_oo0:?oo`25oookJ_l:o`3oog/0olGo0?oo
nf[ooh`0oookJ_nUo`02oookJP06okoo0?oonf[oo`0ko`3oN_oonf[oo`3>0ooonfX00ol0S?ooo`X0
oookJP02oookJP03oooC0?oonf[o0?nI00?ooo]Z00GoodP0oookJ_oonf[ooo]Zo`3oO005oookJP05
o`02ool0003og`3oo`0]oooeo`000_oonfX01OooW03o09WooookJ_ooIP3o0?l000Oooo]Z00?ooc40
oookJ_oonfX02OoonfX2ooo=04?ooo]Z1?oo0;X01?oonf[oold0ooo=0?ooc@2@oookJP00;?oonfX2
ok00o`_ooo]Z00?oolT0oookJ_oonfX00_nDo`0EoookJP03oa[o0?ooP`3ooh<000;o;?l00_oonfX0
0ol0ol7o04SooookJP07oookJP06ool0/ooonf[o05coo`1RooooG03oobh01_oonfX00onno`3ooo]Z
oookJP02oookJP03og7o0?l01_oooo]Z00CoogT000?ooo]Zo`3oeOoonfX01?oonfX00ol04ooo0:Co
o`3oYP05oookJP03oong0?oonf[ooo]Z00OoogT000Coooh0oomi0?oonf[oQ_l00_oo=`000oooN@3o
oo]ZodWo0002oookJP03oonR0?ooC03oogT000CoogT000Gog03ooookJ_oonf[ooo]Zoom60002oook
JP0=oon90?oonf[ooo]ZoookJ_l0ooOooo]Zok?o0?o_0?oo01Oooomi0?l0on7oogT0oa;o0003oomi
0007o`3moooonf[oo`2Qoh<0ooooX03oogT0oom30002o`3bo`03o`3o/ol0eOooo`0[00?oiOl000Go
`03oool0Xooonf[oo`25oookJP02ooo90005olGo0?oonf[ooh`0oookJ_nUo`000_oonfX02?noo`3o
oo]Zool0>oooN@3o0?mjo`3oh_oo0<kooo]Z1OooN@001?oo0?coom<0oookJ_l0oiT3oookJP03oom8
0?oonf[ooo]Z00;ooo]Z00?o0?mloookJ_oonfX00ooob@001Ooonf[og`3oo`0]oooeo`3o000000;o
ogT000?o09Woooo90?oob@001_oob@03oookJP;oogT02OoonfX4onGo03oooo]Z0ooo0;X2oookJP?o
old0^ooonfX2ok00o`_ooo]Z00Go0:cooookJ_oonf[ooo]Zool0MP0EoookJP;o6_l000Cooh<0oook
J_l/o`3o;?l00_oonfX00ol0B?oooo]ZoookJP06oookJP06ool0/ooonf[o05coo`1RooooG03oobh0
1_oonfX00onno`3ooo]ZoookJP02oookJP04og7o0?l01_oooo]ZoookJP;o0?mH0ooonfX00ol0omGo
oo]ZoookJP03oookJP03o`2Tool0ojKooo]Z00Gooo]Z00?ookL0oookJ_oonfX00_oonfX01Ol0D_oo
0?l^o`3o;_oonf[oooh000;oEol000goQ_l0oolg0?oo=`3ooo]ZoooL0?oonf[oBOl0oookJ_ooXP3o
od`0o`3oDOoonf[o0:Oo00?ooo]Z00Oog03ooookJ_oonf[ooo]Zoom60?oonf[oohT000Cooo]Z00Wo
0?ogok?o0?o_0?oooo]Zo`0Gool0on7ooo]Zool/0?lBo`000_oonfX01ol0oOoooo]Zool0XOoonf[o
oj00o`0goooo@`000_l0l_l01?oonf[o0?ncool0:ol0okH2oookJP0Eol00oooonf[oo`2Sool0QOoo
nf[o2_l0oomk0?o5o`3ooo]Zoon<0?oonf[o0?lTojGo0?oonf[o_ol0oookJ_oo03_ooo]Zo`3oN_l0
on;oo`3>00;ooo]Z00?o08cooookJ_oo2P000_oonfX00oood`3ooo]Zo`3oV@03oookJP03oom80?oo
nf[ooo]Z00;ooo]Z00?o0?mloookJ_oonfX00_oonfX03Ol00_oooo]Zo`000?oO0?oomOl0o`000?oo
nf[ooi`0oe/0ool0VOooofH0oj@0ool0o`002?oonfX00ooo<@3ooo]ZoookJP09oookJP03ool0^_oo
c@3oo`2j03kooo]Z0ooo0;X2oookJP?oold0TooonfX002_ooo]Z00?o/03ooookJ_oonfX02OoonfX2
ooo900?oU?l05_oonfX01?lJo`3ooh<0oookJ_l/o`03oookJP03o`3o`Ol0B?oooo]Z00Kooo]Z0_oo
0;<2o`1Lo`03o`1RooooG03ooo]Z00Gooo]Z0_nno`04oookJP03og7o0?l01_oooo]Z00?oogT00_oo
nfX00ol0omGooo]ZoookJP03oookJP03o`0Cool0ojKo0?nV00Gooo]Z00?ookL0oookJ_oonfX01ooo
N@002OoooP3oEol0oookJ_n6o`3oocL0oookJ_oog03oogT0odWo0002oookJP03oonR0?ooN@3oogT0
00?oogT000?ooo]Zom`0oooonfX00_oonfX01?ooAP3ooo]Zoon90?ooR@02oookJP;o0?og0_nco`00
1_o_0?oo01Ooo`3oS?l0on7oogT0oa;o00?oogT000?o0?gooookJ_oo0:400_ooX0000oooN@3ood<0
o`3bo`02oomi0003o`3Eoooo02_oiOl000;oiOl000co`03oool0Xooonf[oo`25oookJ_l:o`3oolT0
olGo0?oob@3ooh`0oookJ_nUo`02oookJP07okoo0?oonf[oo`0koomi0?l0og[oogT0ool0cP02oook
JP?oogT000Kooo]Zool0o?oonf[oom<0oookJ_l0oiT3oookJP05oom80?oonf[ooo]ZoookJ_l0og`0
0ooonfX2oomi00;ooo]Z00?og`3oooGo0?ooN@000_ooN@000ol0VOooF`3oooo90006ooo900Gooo]Z
00?oogT0oookJ_oonfX02_oonfX00ooUo`3oold0ool0^P0ioookJPCoo`2j00?ooo]Zooo=0?ooc@00
0_ooc@2moookJP03ok00oooonf[ooo]Z00Wooo]Z0_l0[?l2oookJP;oo`1f5OoonfX01OlJo`3ooo]Z
oon30?oonf[o;?l000?ooo]Z00?o04SooookJ_oonfX01OoonfX2ool0/`04oookJ_l0G?oo06;ooomL
00Kooo]Z0_nno`04oookJP05og7o0?l01_oooo]ZoookJ_l0oeP01?oonfX00ol0omGooo]ZoookJP03
oookJP03o`2Tool0ojKooo]Z00Gooo]Z00CookL0oookJ_oonf[ooo]Z0_l0D_l02?l0obkooo]Zoook
J_oooP3oEol0oookJ_n6o`3oocL00_oonfX02Ooog03ooo]ZodWo0?oonf[ooj80oom<0?l0oe7o047o
o`2Wo`03oookJP05om`0oooonf[ooo]ZoookJ_ooAP000_ooR@03oookJP0:o`3omonco`3o/ol0onl0
oooonf[o01Ooo`3ohOoonf[oob`0oa;o00;ooo]Z00?o0?gooookJ_oo0:400_ooX0000ol0=ooood<0
o`3bo`02oookJP03o`3o/ooo02_o0?nf00;ooo]Z00[o`03ooookJ_oo0:?oo`25oookJ_l:o`3oog/0
olGo0?oonf[ooh`00_oonfX02OnUo`3ooo]Zokoo0?oonf[oo`0koookJ_l0og[o097oool0cP02oook
JP03o`2<oooonf[oo`X000;ooo]Z00Coo`3loooC0?oonf[o0?nI0ooonfX01OooB03ooo]ZoookJ_oo
nf[o0?ml00Gooo]Z00go00;ooookJ_oO0?oo02goooGo0?l0003ooo]ZoonL0?l0VOoooo]ZoomV0?nT
0?oo0?l000Sooo]Z00?ooc40oookJ_oonfX02ooonfX00oooc@3oo`2jool0^P0ioookJP?oo`2j00?o
oo]Zooo=0?ooc@000_ooc@2FoookJP00:_oonfX00on`0?oooo]ZoookJP09oookJP03ooo90?nDo`3o
U?l000?oU?l05?oonfX2oa[o0003oon30?oonf[o;?l000?ooo]Z0_l0B?l7oookJP04ool0/ooonf[o
05coo`1Ro`;ooe`01_oonfX00onno`3ooo]ZoookJP02oookJP;oLOl000Co00KooookJ_ooN@3oogT0
0ooonfX00ol0omGooo]ZoookJP02oookJP;o01?o00?o0?nVoookJ_oonfX01?oonfX01?oo]`3ooo]Z
oookJ_oonfX5oomi00;oooh000KoEol0ohKo0?n6o`3oocL0oookJ_oog002odWo0003oomi0?ooXP3o
oj8000CoogT00_oonfX00ooL0?oooo]ZoookJP02oom60003oookJ_ooR@3ooo]Z00;ooo]Z00[o0?og
oookJ_nco`3o0?ngool0c_l05ooo0?n<o`3ohOoo;03o4_l00_ooN@002Ooonf[o0?gooookJ_oo0:7o
oj00o`0gooooN@3ood<0o`3bo`03oomi000@ool0:ooUo`3oiOl0oookJ_o00?ooo`2SoookJ_oo08Go
oo]Zo`[o0?oob@3oaOl0ooo90?ooS03oolT0ojGo00;ooo]Z00Oo_ol0oookJ_oonf[oo`0ko`3oN_oo
N@3oo`3>00;ooo]Z0oooN@001_oonf[oo`3loookJ_ood`3ooo]Zo`3oV@?ooo]Z00?oodP0oookJ_oo
nfX00_oonfX01?l0ogcooo]ZoookJ_oonfX5oomi0006ooGo0?ooN@3oogT0oonL0?l0VOooogT01ooo
b@05oookJP03oola0?oonf[ooo]Z00cooo]Z00?oold0ool0^_oonfX0=?oonfX3ool0^P;ooo]Z0ooo
c@30oookJP03ok00oooonf[ooo]Z00Wooo]Z00Go0:cooookJ_oonf[ooo]Zool0MP0EoookJP;o6_l0
0_ooP`001?oonf[o;?l0oookJ_oonfX2o`18o`Oooo]Z00Coo`2coookJ_l0G?oo05co0_ooG006oook
JP03okko0?oonf[ooo]Z00;ooo]Z0_mao`001?l01_oooo]ZoookJ_l0oeP4oookJP03o`3oeOoonf[o
oo]Z00;ooo]Z00?o01?oo`2Tool0ojH01OoonfX2oong00?ooo]Z00Co05;ooookJ_l0obkooo]Z0_oo
oP001?mGo`3oQ_l0ohKo0?oo=`02oookJP03oooL0?m9o`3oBOl000;ooj8000Cooo]Zo`3oDOl0Yooo
0:Oo0ooonfX00ooL0?oooo]ZoookJP02oom60003oon90?oonf[ooo]Z00;ooo]Z00[o0?ogok?o0?l0
okOoo`3>oookJ_l05ooo0?oQoookJ_oo;03o4_l00_oonfX02?l0oOoooo]Zool0XOooX03oP`3oo`0g
oooo@`3o0?;o0_oonfX00ol0ok?oo`0[o`3o]P02oookJP0:ol00oooonf[oo`2Sool0QOoonf[o2_l0
oomk0?o5o`3ooo]Zoon<00;ooo]Z00?oYOl0oookJ_noo`000_oonfX01?oo03_o0?mjo`2Aoooo0<h2
oookJP03o`2<oooonf[oo`X000;ooo]Z00Coo`3loooC0?oonf[o0?nI0ooonfX00oooB03ooo]Zoook
JP02oookJP03o`3oO?oonf[ooo]Z00;ooo]Z00ko00;ooookJ_oonf[og`3oo`0]oooeo`3o0000oook
J_ooW03o09WooookJ_ooIP3ooo]Zo`3o00Sooo]Z00?ooc40oookJ_oonfX03?oonfX00oooc@3ooo]Z
ool0^P0eoookJP?oo`2j00Cooo]Zooo=0?ooc@3oold0V_oonfX002kooo]Z00?oolT0oookJ_oonfX0
0ooonfX2ooo900KoU?l04ooonfX00olJo`3ooh<0oon30002obco00;ooo]Z00?o0?o1o`18oooonfX0
1_oonfX2ool0/`;o05co00?o06;ooomL0?oo;P001_oonfX00onno`3ooo]ZoookJP02oookJP05og7o
0?l01_oo00Koo`3oF?ooN@001?oonfX00ol0omGooo]ZoookJP02oookJP03o`0Cool0Y?oo0?nV00Ko
oo]Z00CookL0oookJ_oonf[ooo]Z1OooN@002OoooP3oEol0oookJ_n6o`3ooo]Zoolg0?oonf[oom`0
odWo0002oomi0003oonR0?ooN@3oogT000;oogT00_oonfX2om`0o`;ooo]Z00CoodH0oookJ_oonf[o
ohT00ooonfX01_l0ooOooo]Zok?o0?l0okOoo`3>o`0Go`;o0?oQ00?oob`0oa;o0?ooN@000_oonfX0
2?l0oOooo`2Qool0XOooX03o03Ooo`08oooo@`3o0?;o0oooN@003_oo02_oogT0oomi0?oonf[o`03o
ool0Xooonf[oo`25oookJ_l:o`3oog/0olGo0?oob@3ooh`00ooob@002?oonf[o_ol0oookJ_oonf[o
o`0ko`3oN_ooN@3oo`3>0ooonfX2oomi0006oookJ_oo0?cooo]ZoooC0?oonf[o0?nI1?oonfX00ooo
B03ooo]ZoookJP02oookJP03o`3oO?oonf[ooo]Z00KoogT000KomOl0oomi0?ooN@3ooi`0o`2Ioooo
N@06ooo900Kooo]Z00?ooc40oookJ_oonfX03OoonfX3ooo=0003ool0^_oonf[ooo]Z02gooo]Z0ooo
0;X2oookJP?oold0cOoonfX2o`2/o`;ooo]Z0_oo07HEoookJP04oa[o0?oonf[ooh<0oookJP;o;?l0
0_oonfX00ol0B?oooo]ZoookJP06oookJP06ool0/ooonf[o05coo`1RooooG03oobh01_oonfX00onn
o`3ooo]ZoookJP02oookJP04og7o0?l01_oo00KooookJP;o0?mH1?oonfX00ol0omGooo]ZoookJP02
oookJP;o0:Co00?o0?nVoookJ_oonfX00ooonfX00ooo]`3ooo]ZoookJP02oookJP0;o`1Boooonf[o
0?l^oookJ_oooP3ooo]ZoeOo0?n6o`3ooo]Zoolg0?oonfX00_oog0001om9o`3ooo]ZoonR0?ooC03o
oo]Zo`3oDOl0Yol00ooonfX2om`0o`;ooo]Z00?oodH0oookJ_ooR@001?oonfX02_l0ooOo/ol0o`3o
]ooo0<kooo]Zo`3Uool0on7ooo]Zool/0?lBo`02oookJP08o`3moooo0:7oo`2QoonP0?n30?oo03Oo
oom30?l0l_l2oookJP03o`3o/ooo02_o0?nf00;ooo]Z00Co`03ooookJ_oo0:?oo`250_oonfX01?l:
o`3oaOl0oookJ_ooS002oookJP03ojGo0?oonf[o_ol000;ooo]Z00Coo`0ko`3oN_l0TOooo`3>0ooo
nfX02?l0S?ooo`X0oookJ_oonf[oo`3loooC0?oonf[o0?nI1?oonfX00oooB03ooo]ZoookJP02oook
JP03o`3oO?oonf[ooo]Z00;ooo]Z00Go00;ooookJ_mFo`3og`3oooGo0003o`000006oonL0?l0VOoo
oo]ZoomV0?oonf[o0?l02OoonfX00ooo<@3ooo]ZoookJP0<oookJP?oold00_oo0;X_oookJP?oo`2j
00Cooo]Zooo=0?ooc@3oold0WOoonfX002kooo]Z00?oolT0oookJ_oonfX00_oonfX00ooob@3ooo]Z
oiCo0007oiCo017ooo]Z00Co6_l0oon30?oonf[o;?l00ooonfX00ol0ol7o04SooookJP06oookJP03
ool0/ooonf[o05co00;o06;o00?ooe`0oookJ_oonfX01?oonfX2okko00Cooo]Z00CoLOl0o`06oooo
nf[o0?mH1?oonfX2o`3oe@Cooo]Z00?o01?oo`2Tool0ojH01_oonfX01?oo]`3ooo]ZoookJ_oonfX4
oomi0005oookJ_oooP3oEol0oookJ_n6o`000_oo=`000ooonf[oom`0odWo0002oomi0005oonR0?oo
N@3oogT0oomi0?l0Yol00_oonfX01OoL0?oooo]ZoookJ_oonf[oodH000;ooo]Z00koohT0oookJ_oo
nf[ooo]Zo`3omooonf[o/ol0o`3o]ooo0<ko01Ooo`3ohOoonf[oob`0oa;o00;ooo]Z0_l0oOl01ooo
0:7ooo]ZoonP0?l0=ooo00Sooom30?l0l_l00oooN@003_oo02_oogT0oomi0?ooN@3o`03oool0Xooo
nf[oo`25oookJ_l:o`3oog/0olGo0?oob@3ooh`01Ooob@02oookJP04ool0>ol0og[oogT0ool0cP?o
oo]Z00So08cooomi0?oonf[ooo]Zool0o?oonf[oom<0o`3oV@Cooo]Z00?oodP0oookJ_oonfX00_oo
nfX01?l0ogcooo]ZoookJ_oonfX5oomi0003ooGo0?ooN@3oogT000;oogT000?o09Wooomi0?oob@00
1Ooob@06oookJP03oola0?oonf[ooo]Z013ooo]Z0oooc@000ooo0;[ooo]ZoookJP09oookJPCoU?l0
6OoonfX4ool0^P03oookJ_ooc@3oold000;oold0cooonfX01Ol0[?oooo]ZoookJ_oonf[oo`1f01Ko
oo]Z00Go6_l0oookJ_ooP`3ooo]Zobco0002oookJP03o`3o`Ol0B?oooo]Z00Kooo]Z0_oo0;<01?oo
nf[o05coo`1RooooG006oookJP;o__l01?oonfX01Omao`3o00KooookJ_oonf[o0?mH00Cooo]Z0_l0
omD4oookJP03o`2Tool0ojKo0?nV00Gooo]Z00?ookL0oookJ_oonfX00_oonfX01Ol0D_oo0?l^o`3o
;_oonf[oooh000;oEol000goQ_l0oolg0?oo=`3ooo]ZoooL0?oonf[oBOl0oookJ_ooXP3ood`0oook
J_l0oe7o0:Oo00?ooo]Z00Oog03ooookJ_oonf[ooo]Zoom60?oonf[oohT000Cooo]Z00_o0?ogok?o
0?l0okOoo`3>oookJ_l0iOoo0?oQoookJ_oo;03o4_l0oookJP02o`3mo`07ool0XOoonf[ooj00oh<0
ool0=ooood<0o`3bo`02oookJP03o`3o/ooo02_o0?nf00;ooo]Z00Co`03ooookJ_oo0:?oo`250_oo
nfX01?l:o`3oaOl0oookJ_ooS002oookJP03ojGo0?oonf[o_ol000;ooo]Z00Coo`0ko`3oN_l0TOoo
o`3>0ooonfX00ol0S?ooo`X0oookJP02oookJP03ool0o?ood`3o0?nI00Cooo]Z00?oodP0oookJ_oo
nfX00_oonfX00ol0ogcooo]ZoookJP02oookJP06o`02oooonf[ooo]Zoml0ool0;OoomOl00_l00000
1_ooW03oF`3oo`2Ioooonf[oofH0o`3o00[ooo]Z00?ooc40oookJ_oonfX03ooonfX3ooo=00;oo`2j
:?oonfX4ool0^PCoold0X?oonfX002gooo]Z0ooob@02oookJP03ooo90?oonf[oU?l000WoU?l03_oo
nfX2oa[o0003oon30?l/o`3o;?l000?ooo]Z0_l0B?l7oookJP04ool0/ooonf[o05coo`1Ro`;ooe`0
1_oonfX00onno`3ooo]ZoookJP03oookJP04og7o0?l01_oooo]Zo`3oF0Cooo]Z00?o0?oEoookJ_oo
nfX00ooonfX00ol04ooo0?nVo`3oYP06oookJP04oong0?oonf[ooo]ZoookJP?oogT00_oonfX01_oo
oP3oEol0oookJ_n6o`3oocL0oookJP;oom`000CoBOl0oomi0?ooXP3ooj801?ooN@02oookJP05om`0
oooonf[ooo]ZoookJ_ooAP000_oonfX03_ooR@3ooo]ZoookJ_oonf[o0?ogoookJ_nco`3o0?ngool0
c_l05ooo0?oQoookJ_oo;03o4_l00_oonfX02Ol0oOoo0?n^ool0XOoonf[ooj00o`0gool02?oood<0
o`3bo`03oomi000>ool0:oooN@3oogT0oomi0?o00?ooo`2SoookJ_oo08Gooo]Zo`[o0?ooN`3oaOl0
ooo90?ooS007ooo90004ool0>ol0og[ooo]Zool0cP?ooo]Z00So08cooomi0?oonf[ooo]Zool0o?oo
nf[oom<0o`3oV@Cooo]Z00?oodP0oookJ_oonfX00ooonfX01?l0ogcooo]ZoookJ_oonfX5oomi0005
ooGo0?ooN@3oogT0oomi0?l0VOl00_ooN@06ooo900Oooo]Z00?ooc40oookJ_oonfX04_oonfX3ooo=
00;oo`2j1?oonfX<oiCo013ooo]Z1?oo0;X5ooo=0=;ooo]Z00?o0:cooookJ_oonfX00_oo07HEoook
JP;o6_l00_ooP`02obco00;ooo]Z0_l0B?l7oookJP06ool0/ooonf[o05coo`1Lool0H_oooe`01_oo
nfX00onno`3ooo]ZoookJP03oookJP05og7o0?l01_oooo]ZoookJ_l0oeP01?oonfX00ol0omGooo]Z
oookJP03oookJP03o`2Tool0ojKooo]Z00Gooo]Z00?ookL0oookJ_oonfX00_oonfX02Ol0D_oo0?l^
oookJ_oonf[oooh0oeOo0?oonf[oQ_l0oolg0002oookJP03oooL0?oonf[oBOl000;ooj8000Cood`0
o`3oDOl0oe7o0:Oo0ooonfX01ooL0?oooo]ZoookJ_oonf[oodH0oookJ_ooR@001?oonfX05?l0ooOo
/ol0o`3o]ooo0<kooo]Zo`3Uool0on7ooo]Zool/0?lBo`3ooo]Zo`3mool0ojkoo`2QoookJ_ooX03o
P`3oo`0goooo@`3o0?;o0_oonfX00ol0ok?oo`0[oookJP02oookJP04ol00oooonf[oo`2Sool0Q@;o
oo]Z00Co2_l0oomk0?o5o`3ooh`00_oonfX00onUo`3ooo]Zokoo0002oookJP05ool0>ol0og[ooo]Z
ool0c_l0on800_oonfX00ol0S?ooo`X0oookJP02oookJP03ool0o?ood`3o0?nI00Cooo]Z00?oodP0
oookJ_oonfX00ooonfX01Ol0ogcooo]ZoookJ_oonf[o00;o00;ooo]Z00?oE_l0oml0oooeo`000ol0
00001_ooW03o09WooookJ_oonf[oofH0o`3o00_ooo]Z00?ooc40oookJ_oonfX04OoonfX4ooo=0003
ool0^_oonf[ooo]Z01kooo]Z1?oo0;X5ooo=0:Cooo]Z000/oookJPKoolT000?ooo]ZoiCo0?nDo`00
1onDo`0?oookJP04oa[o0?oonf[ooh<0obco00?ooo]Z00?o0?o1o`18oooonfX01_oonfX2ool0/`;o
05co00?o06;ooomL0?oo;P001_oonfX00onno`3ooo]ZoookJP02oookJP;oLOl000?o00KooookJ_l0
oeP01?oonfX00ol0omGooo]ZoookJP02oookJP;o01?o00?o0?nVoookJ_oonfX01?oonfX2oong00?o
oo]Z0_ooN@003_l0obkooo]Zooon0?oooP3oEol0oookJ_n6o`3oocL0oookJ_oog03ooo]ZodWo0?oo
N@3ooj801oooN@001_oL0?oooo]ZoookJ_oonf[oodH0oookJP;oohT00ooonfX02?l0ooOooo]Zok?o
0?l0okOoo`3>o`0Gool0on7ooo]Z0_lBo`02oookJP09o`3mool0ojkoo`2QoookJ_ooX03o03Ooo`08
oooo@`3o0?;o00?oogT000koo`0[oomi0?ooN@3ooo]Zol00oooo0:?ooo]Zool0QOoonf[o2_l0oomk
0?o5o`3oolT0oon<00KoolT000KoogT0ool0>ol0og[ooo]Zo`3oh_oo0<h2oookJP09o`2<oooonf[o
o`X0oookJ_oo0?cooo]ZoooC0?oonf[o0?nI00?ooo]Z00?oodP0oookJ_oonfX00ooonfX01?l0ogco
oo]ZoookJ_oonfX9oomi0003oonL0?l0VOooogT000;oogT01?oob@08oookJP03oola0?oonf[ooo]Z
01Gooo]Z1?ooc@02ool0^Q7oU?l01_oonfX5ool0^PCoold0eOoonfX2o`2/o`;ooo]Z00?oo`1foook
J_oonfX05?oonfX01OlJo`3ooo]Zoon30?oonf[o;?l000?ooo]Z00?o04SooookJ_oonfX01_oonfX0
1?oo0;?ooo]Zo`1Lool0H_l2oomL00Kooo]Z00?o__l0oookJ_oonfX00_oonfX2og7o0004o`06oooo
nf[o0?mHo`3oF0Cooo]Z00?o0?oEoookJ_oonfX00_oonfX00ol04ooo0:Coo`3oYP05oookJP;ookL0
1?oonfX02Ol0D_oo0?l^oookJ_oonf[oooh0oeOo0?oonf[oQ_l0oolg0002oookJP09oooL0?oonf[o
BOl0oonR0?oonf[ood`0o`3oDOoonf[o0:Oo00?ooo]Z00Gog03ooookJ_oonf[ooo]Zoom60002oon9
00?ooo]Z0_l0ooL01onco`3o0?ngool0c_oonf[o0>Goo`3ohOoonfX00_lBo`002_oonf[o0?goo`3o
[_oo0:7ooo]ZoonP0?n30?oo03Oooom30?l0l_l2oookJP03o`3o/ooo02_ooo]Z00;ooo]Z00Co`03o
oookJ_oo0:?oo`250_oonfX01?l:o`3oog/0olGo0?ooS002oookJP0:ojGo0?oonf[ooo]Zokoo0?oo
nf[oo`0ko`3oN_oonf[o097oool0cP;ooo]Z00?o08cooookJ_oo2P000_oonfX01?oo0?coom<0oook
J_l0oiT4oookJP03oom80?oonf[ooo]Z00;ooo]Z00?o0?mloookJ_oonfX00_oonfX01_l00_oooo]Z
oookJ_oO0?oo01[oooGo00?o000000Kooi`0o`2Ioooonf[oY03ooomV0?l0o`0;oookJP03oola0?oo
nf[ooo]Z01Gooo]Z0oooc@03ool0^QKooo]Z1Ooo0;X4ooo=0:Wooo]Z000[oookJPOoolT01onDo`0A
oookJP04oa[o0?ooP`3ooh<0obco00?ooo]Z0_l0B?l7oookJP03ool0/ooonf[o05co00;o06;o00?o
oe`0oookJ_oonfX01?oonfX2okko00Cooo]Z00?oLOl0o`06oooonfX00_l0oeP4oookJP03o`3oeOoo
nf[ooo]Z00;ooo]Z00?o01?oo`2Tool0ojH01_oonfX05Ooo]`3ooo]ZoookJ_oonf[o05;ooomi0?oo
nf[o0?l^oookJ_oooP3ooo]ZoeOo0?oonf[oQ_l0oolg0?oonf[oom`0oookJ_m9o`3oogT0oonR0006
oomi0003oookJ_oL0?oooo]Z00;ooo]Z00?oodH0oookJ_ooR@001?oonfX02_l0ooOooo]Zok?o0?l0
okOoo`3>o`0Gool0on7ooo]Zoa;o0?l0;Ol2oookJP09o`3mool0ojkoo`2QoookJ_ooX03o03Ooo`08
oooo@`3o0?;o00?oogT000koo`0[oomi0?ooN@3ooo]Zol00oooo0:?oogT0ool0QOoonf[o2_l0oomk
0?o5o`3ooo]Zoon<00KoolT000KoogT0ool0>oooN@3o0?mjo`3oh_oo0<h2oookJP03o`2<oomn0?oo
o`X000;ooo]Z00Coo`3loookJ_ood`3o0?nI0ooonfX00oooB03ooo]ZoookJP03oookJP03o`3oO?oo
nf[ooo]Z00;ooo]Z2OooN@000oooW03o09Wooomi0002oomi00CoolT02?oonfX00ooo<@3ooo]Zoook
JP0IoookJP;oold05?nDo`03ool0^P03oookJ_ooc@3oold000;oold0f?oonfX01Ol0[?oooo]Zoook
J_oonf[oo`1f01Kooo]Z00Go6_l0oookJ_ooP`3ooo]Zobco0002oookJP;o04So2?oonfX01Ooo0;?o
oo]Zo`1Lool0H_oooe`000Kooo]Z0_nno`04oookJP05og7o0?l01_oooo]ZoookJ_l0oeP01OoonfX0
0ol0omGooo]ZoookJP02oookJP03o`0Cool0Y?oo0?nV00Gooo]Z00?ookL0oookJ_oonfX00_oonfX2
o`1Bo`09o`3o;_oonf[ooo]Zooon0?mGo`3ooo]ZohKo0?oo=`3ooo]Z00;oom`000?ooo]ZodWo0?oo
XP000_ooC0000ol0oe7o047oo`2Wo`03oookJP03om`0oooonf[ooo]Z00;oodH000?oohT0oookJ_oo
nfX00_oonfX05Ol0ooOooo]Zok?o0?l0okOoo`3>oookJ_l0iOoo0?oQoookJ_lBo`3o02gooookJ_l0
oOoo0?n^ool0XOoonf[ooj00oh<0ool0=ooood<0o`3bo`02oookJP03o`3o/ooo02_ooo]Z00;ooo]Z
00Co`03ooookJ_oo0:?oo`250_oonfX04?l:o`3oog/0olGo0?oonf[ooh`0oookJ_l0obCoYOl0oook
J_noo`3ooo]Zool0>ooonf[o0?mjo`2Aoooo0<h2oookJP03o`2<oomn0?ooo`X000;ooo]Z00Coo`3l
oookJ_ood`3o0?nI1?oonfX00oooB03ooo]ZoookJP02oookJP03o`3oO?oonf[ooo]Z00;ooo]Z00Ko
00;ooookJ_oonf[ooo]Zoml0oooeo`03o`000007oonL0?mK0?oo09WooookJ_ooIP3ooo]Zo`3o000;
oookJP03oola0?oonf[ooo]Z01Sooo]Z1Oooc@0Dool0^P03oookJ_ooc@3oold000;oold0[OoonfX0
02[ooo]Z2?oob@04oiCo01;ooo]Z0_lJo`000oooP`3o;?l0obco0003oookJP03o`18oooonf[ooo]Z
00Kooo]Z00Koo`2co`1Lool0G?oo06;ooookJ_ooG006oookJP03okko0?oonf[ooo]Z00?ooo]Z00Co
LOl0o`06oooonf[o0?mH1OoonfX00ol0omGooo]ZoookJP02oookJP03o`0Coooob@3oolT000Kooo]Z
00KookL0oookJ_oonf[ooo]Zo`1BoooonfX2o`3o;P05oookJ_oooP3oEol0oeOo0?n6o`000_oo=`00
1_oonf[oom`0oookJ_m9o`3ooo]ZoonR00GoogT00_oonfX01ooL0?oooo]ZoookJ_oonf[oodH0oook
J_ooR@001?oonfX01Ol0ooOooo]Zok?o0?l0okOoo`3>00;o0?oQ00?ooo]Zoa;o0?l0;Ol00_oonfX0
1ol0oOoo0?n^ool0XOoonf[ooj00o`0gool02?l00_l0l_l3oomi000>ool0:oooN@3ooo]ZoookJ_o0
0?ooo`2Soomi0?oo08GoogT0o`[o0?ooN`3oaOl0oookJ_ooS005ooo90007oookJ_ooN@3oo`0koomi
0?l0og[oogT0ool0cP02oookJP03o`2<oomn0?ooo`X000;ooo]Z00Coo`3loookJ_ood`3o0?nI1?oo
nfX00oooB03ooo]ZoookJP02oookJP03o`3oO?oonf[ooo]Z00?ooo]Z2_ooN@001?l0VOooogT0oomi
0?ooN@03ooo90003oomi0?oonf[ooo]Z00Oooo]Z00?ooc40oookJ_oonfX06_oonfX@oiCo00Soold0
f_oonfX2o`2/o`;ooo]Z0_oo07HEoookJP;o6_l00_ooP`02obco00;ooo]Z00?o04SooookJ_oonfX0
1_oonfX2ool0/`;o05co00?ooo]ZoomL0?oonfX01OoonfX00onno`3ooo]ZoookJP03oookJP05og7o
0?l01_oooo]ZoookJ_l0oeP01OoonfX00ol0omGooo]ZoookJP02oookJP03o`2Tool0ojKo0?nV00Go
oo]Z00?ookL0oookJ_oonfX00_oonfX01?l0D_oo0?l^o`3o;_oonfX2ooon0007oeOo0?n6o`3oocL0
oolg0?oonf[oom`0oookJP02odWo0004oonR0?ooC03ooo]Zo`3oD@;o0:Oo0ooonfX01_oL0?oooo]Z
oookJ_ooAP3ooo]Zoon900Cooo]Z00Ko0?ogoookJ_nco`3o0?ngool0c_oonfX2o`3oh@0=oookJ_lB
o`3o02gooookJ_l0oOoo0?n^ool0XOoonf[ooj00oh<0ool0=ooood<0o`3bo`02oookJP03o`3o/ooo
02_ooo]Z00;ooo]Z00Co`03ooookJ_oo0:?oo`250_oonfX04?l:o`3oog/0olGo0?oonf[ooh`0oook
J_l0obCoYOl0oookJ_noo`3ooo]Zool0>ooonf[o0?mjo`2Aoooo0<h2oookJP03o`2<oomn0?ooo`X0
00;ooo]Z00Coo`3loookJ_ood`3o0?nI1OoonfX00oooB03ooo]ZoookJP02oookJP03o`3oO?oonf[o
oo]Z00;ooo]Z00Ko00;ooookJ_oonf[og`3oo`0Joooeo`03o`000007oonL0?mK0?oo09WooookJ_oo
IP3ooo]Zo`3o000;oookJP03oola0?oonf[ooo]Z01gooo]Z5Oooc@2aoookJP00:_oonfX9ooo901Co
oo]Z00Co6_l0oookJ_ooP`3o;?l01?oonfX00ol0B?oooo]ZoookJP05oookJP;oo`2c00?o05cooook
J_l0H_l00_ooG006oookJP03okko0?oonf[ooo]Z00?ooo]Z00CoLOl0o`06oooonf[o0?mH1?oonfX2
o`3oe@?ooo]Z0_l04ol00ooob@3ooo]ZoookJP04oookJP;ookL00ooonfX00ol0D_oooo]Zo`3o;P02
oookJP05ooon0?mGo`3ooo]ZohKo0?oo=`000_oonfX01Ooog03ooo]ZodWo0?oonf[ooj8000CoogT0
0ooonfX01ooL0?oooo]ZoookJ_oonf[oodH0oookJ_ooR@001?oonfX02_l0ooOooo]Zok?o0?l0okOo
oo]Zo`3ohOl0iOoooo]Zoa;o0?l0;Ol2oookJP09o`3mool0ojkoo`2QoookJ_ooX03o03Oooom30?l0
l_oooo]Z00?oogT000koo`0[oookJ_oonf[ooo]Zol00oooo0:?oogT0ool0QOooN@3o2_l0oomi0?o5
o`3ooo]Zoon<00GoolT00_ooN@000ooo03_oogT0o`3oNP03oomi00;ooo]Z00So08coool:0?oonf[o
oo]Zool0o?oonf[oom<0o`3oV@Cooo]Z00?oodP0oookJ_oonfX00_oonfX00ol0ogcooo]ZoookJP03
oookJP03o`02ooooN@3oogT000_oogT000CoofH0ooo90?oob@3oolT02_oonfX00ooo<@3ooo]Zoook
JP0JoookJPooU?l0h_oonfX01Ol0[?oooo]ZoookJ_oonf[oo`1f01Kooo]Z00Go6_l0oookJ_ooP`3o
oo]Zobco0003oookJP03o`18oooonf[ooo]Z00Kooo]Z00Koo`2coookJ_l0G?oo06;oool^0?ooG006
oookJP03okko0?oonf[ooo]Z00?ooo]Z00?oLOl0o`06oooonfX00_l0oeP4oookJP;o0?oE0ooonfX0
0ol04ooo0:Coo`3oYP06oookJP03oong0?oonf[ooo]Z00;ooo]Z00Wo05;oo`3o;_oonf[ooo]Zooon
0?mGo`3ooo]ZohKo0?oo=`000_oonfX01_oog03ooo]ZodWo0?oonf[ooj80oom<00;o0?mA00Co0:Oo
oookJ_oonf[ooo]Z0_oL0?l2oookJP03oom60?oonf[oohT000Cooo]Z00Co0?ogoookJ_nco`3o0?ng
0_oonfX02ol0on7ooo]ZoookJ_lBo`3o02gooookJ_l0oOoo0?n^ool0XOoonf[ooj0000;o03Oo00Ko
od<0o`3boooonf[ooo]Zo`3o/ooo02/3oookJP04ol00oooonf[oo`2Sool0Q@;ooo]Z013o2_l0oomk
0?o5o`3ooo]Zoon<0?oonf[o0?lTojGo0?oonf[o_ol0oookJ_oo03_ooo]Zo`3oN_l0TOooo`3>0ooo
nfX02Ol0S?ooo`X0oookJ_oonf[oo`3loookJ_ood`3ooo]Zo`3oV@04oookJP03oom80?oonf[ooo]Z
00;ooo]Z00?o0?mloookJ_oonfX00_oonfX01ol00_oooo]ZoookJ_oonf[og`3ooookJ_oeo`000ol0
00001oooW03o09WooookJ_oonf[oofH0oookJ_l0o`002ooonfX00ooo<@3ooo]ZoookJP3SoookJP00
:_oonfX:ooo901;ooo]Z00Co6_l0oon30?ooP`3o;?l00ooonfX2o`18o`Oooo]Z00?oo`2coookJ_l0
G?l00_l0H_l00oooG03ooo]ZoookJP04oookJP;o__l01?oonfX2ooo90003o`06ool0oeSo0?mH00Co
oo]Z00?o0?oEoookJ_oonfX00_oonfX00ol04ooo0:Coooo90006oookJP03oong0?oonf[ooo]Z00;o
oo]Z00?o05;ooookJ_l0obh00_oonfX01OoooP3oEol0oookJ_n6o`3oocL000;ooo]Z00Goom`0oook
J_m9o`3ooo]ZoonR0003oomi0005o`2Woooonf[ooo]ZoookJ_oL0?l00ooonfX00oooAP3ooo]Zoon9
0004oookJP0:o`3omooonf[o/ol0ool0c_l05ooo0?oQo`3Uoooonf[o4_l0o`0]o`;ooo]Z00?o0?go
o`3o[_oo0:400_ooX0000ol0=ooood<0o`3bo`02oookJP;oogT000koo`0[oookJ_oonf[ooo]Zol00
oooo0:?ooo]Zool0QOooN@3o2_l0oomi0?o5o`3oogT0oon<00CoolT00oooN@000ooo03_oogT0o`3o
NP05oomi0003o`2<oooo2P3ooo]Z00;ooo]Z00?oo`3loooC0?l0oiT01?oonfX00oooB03ooo]Zoook
JP03oookJP03o`3oO?oonf[ooo]Z00;ooo]Z00?o00;ooookJ_ooN@002?ooN@001Ol0VOooogT0oomi
0?ooN@3oofH000;oolT000?oogT0oookJ_oonfX02?oonfX00ooo<@3ooo]ZoookJP0JoookJPcoU?l0
i?oonfX00ol0[?oooo]ZoookJP02ool0MQKooo]Z00Go6_l0oookJ_ooP`3ooo]Zobco0002oookJP;o
04So2?oonfX01?oo0;?ooo]Zo`1Lool0H_l2oomL00Gooo]Z0_nno`04oookJP;oLOl000?o00Kooook
J_l0oeP01OoonfX00ol0omGooo]ZoookJP02oookJP03o`0Cool0Y?oo0?nV00Kooo]Z00CookL0oook
J_oonf[ooo]Z0_l0D_l02?l0obkooo]ZoookJ_oooP3oEol0oookJ_n6o`3oocL00_oonfX02Ooog03o
oo]ZodWo0?oonf[ooj80oom<0?l0oe7ooo]Zo`2Wo`03oookJP07om`0oooonf[ooo]ZoookJ_ooAP3o
oo]Zoon90004oookJP07o`3omooonf[o/ol0onl0oooonf[o01Ooo`3oh@02oookJP06oa;o0?l0;Ooo
oo]Zo`3mool0ojkoo`2Q0_ooX0001?l0=ooo00Sooom30?l0l_l2oookJP03o`3o/ooo02_ooo]Z00;o
oo]Z00Co`03oool0Xooo0:?oo`250_oonfX04?l:o`3oog/0olGo0?oonf[ooh`0oookJ_l0obCoYOl0
oookJ_noo`3ooo]Zool0>ooonf[o0?mjo`2Aoooo0<h3oookJP03o`2<oooo2P3ooo]Z00;ooo]Z00Co
o`3loooC0?oonf[o0?nI1?oonfX00oooB03ooo]ZoookJP03oookJP03o`3oO?oonf[ooo]Z00;ooo]Z
00Oo00;ooookJ_oonf[oE_l0oml0oooeo`3ooo]Z00;o000000?ooi`0oe/0ool0VOl00_oonfX00ooo
IP3ooo]Zo`3o000;oookJP03oola0?oonf[ooo]Z0>?ooo]Z000ZoookJPSoolT04_oonfX2oa[o0003
oon30?l/o`3o;?l000?ooo]Z00?o04SooookJ_oonfX01OoonfX2ool0/`;o05co00?o06;ooookJ_oo
G0001_oonfX00onno`3ooo]ZoookJP03oookJP04ooo90?l01_oooo]Zo`3oF0Gooo]Z00?o0?oEooo9
0?oonfX00_oonfX00ol04ooo0:Coooo90006oookJP03oong0?oonf[ooo]Z00;ooo]Z00Co05;ooook
J_l0obkooo]Z0_oooP001OmGo`3oQ_l0ohKo0?oo=`3ooo]Z00;oogT000Cooo]ZodWo0?ooXP3ooj80
0oooN@001Ol0Yooooo]ZoookJ_oonf[og03o00?ooo]Z00?oodH0oomi0?ooN@000ooonfX2o`3om`;o
/ol0017oo`3>o`0Gool0on7o0>GooookJ_lBo`3o02gooomi0?oonf[o0?goo`3o[_oo0:7ooj00oh<0
ool0=ooood<0o`3bo`02oookJP;oogT000Soo`0[oookJ_oonf[ooo]Zol00oooo0:?ooo]Zool0Q@;o
ogT000Go2_l0olGo0?ooN@3ooh`0oomi0003ooo90004okoo0?ooN@3oogT0ool0>`OoogT000?o08co
ool:0?oonfX00_oonfX00ooo0?cooo]ZoooC0005oookJP03oom80?oonf[ooo]Z00;ooo]Z00?o0?ml
oookJ_oonfX00ooonfX00ol00_ooogT0oomi0007oomi0006oonL0?ooN@3oogT0oomi0?ooIP3oogT0
0_oob@0<oookJP03oola0?oonf[oolT000;oolT05ooonfX9oiCo0>Kooo]Z00Co0:cooookJ_oonf[o
o`1f5_oonfX2oa[o00;ooh<00_l/o`02oookJP03o`18oooonf[ooo]Z00Kooo]Z0_oo0;<2o`1Lo`03
oookJ_ooG03ooo]Z00Gooo]Z00?o__l0oookJ_oonfX00ooonfX01Omao`3o00KooookJ_oonf[o0?mH
00Gooo]Z00?o0?oEoookJ_oonfX00_oonfX00ol04ooo0:Coo`3oYP05oookJP;ookL00ooonfX00ol0
D_oooo]Zo`3o;P02oookJP06ooon0?mGo`3ooo]ZohKo0?oo=`3ooo]Z0_oog0002?oonf[oBOl0oook
J_ooXP3ood`0o`3oDOoonf[o0:Oo0ooonfX01OoL0?oooo]ZoookJ_oonf[oodH000;oohT00ooonfX2
o`3om`;o/ol000Gok`3ooookJ_l05ooo0?oQoookJP02oa;o000;o`0]oooonf[o0?goo`3o[_oo0:7o
oj00oookJ_l0=ooo00Sooom30?l0l_l00_oonfX00ol0ok?oo`0[oookJP02oookJP04ol00oooo0:?o
oo]Zool0Q@;ooo]Z013o2_l0oomk0?o5o`3ooo]Zoon<0?oonf[o0?lTojGo0?oonf[o_ol0oookJ_oo
03_ooo]Zo`3oN_l0TOooo`3>0ooonfX00ol0S?ooo`X0oookJP02oookJP04ool0o?oonf[oom<0o`3o
V@Gooo]Z00?oodP0oookJ_oonfX00_oonfX00ol0ogcooo]ZoookJP03oookJP07o`02oooonf[ooo]Z
oml0ool06_oomOl0oookJP02o`000008oonL0?mK0?oo09WooookJ_ooIP3oY03ooookJ_l0o`0<oook
JP03oola0?oonf[ooo]Z0>;ooo]Z000ZoookJPGoolT05?oonfX01?lJo`3ooo]Zoon30?l/o`04oook
JP03o`18oooonf[ooo]Z00Gooo]Z00Goo`2coookJ_l0G?oooo]Zo`1Ro`02oomL00Kooo]Z00?o__l0
oookJ_oonfX00ooonfX01?oob@3o00KooookJ_l0oeP5oookJP03o`3oeOoonf[oolT000;ooo]Z00?o
01?oo`2Toooob@001_oonfX01?oo]`3ooo]ZoookJ_oonfX2o`1Bo`07oookJ_l0obkooo]Zooon0?oo
nf[oogT0ohKo0002oolg0007oookJ_ooN@3ooo]ZoookJ_m9o`3ooj80oookJP02oomi0003oookJ_l0
Yooooo]Z00;ooo]Z00Kog03ooomi0?oonf[ooo]Zoom60?ooN@04oookJP0Eo`3omooonf[o/ol0o`3o
]ooo0<ko01Ooo`3ohOl0iOooogT0oa;o0?l0;Ooooo]Zoomi0?l0oOoo0?n^oomi0?ooX03oP`3oo`0g
oooo@`3o0?;o00?oogT000?o0=Goool0:ooonfX00_oonfX01?o00?ooo`2SoookJ_oo08D2oomi0005
o`[o0?o5o`3oogT0oon<0?ooN@000ooob@001?noo`3oogT0oomi0?oo03/7oomi0003o`2<oomn0?oo
o`X000;ooo]Z00Coo`3loookJ_ood`3o0?nI1?oonfX00oooB03ooo]ZoookJP03oookJP03o`3oO?oo
nf[ooo]Z00;ooo]Z00?o00;ooookJ_ooN@001oooN@000oooW03oogT0oomi0004oomi00;oolT02_oo
nfX7ooo901Oooo]Z0_nDo`02oookJP;oU?l0jooonfX00ooo07Kooo]ZoookJP0DoookJP05oa[o0?oo
nf[ooh<0oookJ_l/o`000ooonfX00ol0B?oooo]ZoookJP06oookJP06ool0/ooonf[o05coo`1Roooo
nf[ooe`01_oonfX00onno`3ooo]ZoookJP03oookJP03og7o0?l01_oooo]Z00;o0?mH1OoonfX00ol0
omGooo]ZoookJP02oookJP03o`0Cool0Y?oo0?nV00Gooo]Z00?ookL0oookJ_oonfX00_oonfX00ol0
D_oooo]Zo`3o;P02oookJP03ooon0?mGo`3oQ_l000;oocL000_ooo]ZoooL0?oonf[ooo]ZodWo0?oo
nf[ooj80oom<0?l0oe7ooo]Zo`2Wo`03oookJP06om`0oooonf[ooo]ZoookJ_ooAP3oohT01?oonfX0
5ol0ooOooo]Zok?o0?l0okOoo`3>oookJ_l05ooo0?oQoookJ_lBo`3oob`0o`0]oooonf[o0?goo`3o
[_oo0:7ooj00oookJ_l0=ooo00Sooom30?l0l_oooo]Z00;o0?nc00Koo`0[oookJ_oonf[ooo]Zol00
oooo0:<2oookJP0Bool0QOoonf[o2_l0oookJ_o5o`3ooo]Zoon<0?oonf[o0?lTojGo0?oonf[o_ol0
oookJ_oo03_ooo]Zo`3oN_oonf[oo`3>0ooonfX00ol0S?ooOP3oool:0002oookJP05ool0o?oonf[o
om<0oookJ_l0oiT01?oonfX00oooB03ooo]ZoookJP02oookJP03o`3oO?oonf[ooo]Z00?ooo]Z00Ko
00;ooookJ_oonf[oE_l0oml0oooeo`02oookJP;o000000Oooi`0o`2Ioooonf[ooo]ZoomV0?nT0?oo
0?l000gooo]Z00?ooc40oookJ_oonfX0h_oonfX002[ooo]Z0_oob@0FoookJP04oa[o0?oonf[ooh<0
obco00?ooo]Z0_l0B?l7oookJP03ool0/ooonf[o05co00;o06;o00?ooe`0ool^0?oonfX01OoonfX0
0onno`3ooo]ZoookJP02oookJP;oolT000?o00KooookJ_l0oeP01OoonfX00ol0omGooo]Zooo90002
ooo90003o`0Coooob@3oolT000Gooo]Z0_oo]`03oookJP06o`1Boooonf[o0?l^o`3o;_oonf[oooh0
0_mGo`001On6o`3oocL0oookJ_oonf[oogT000;ooo]Z00OoBOl0oonR0?ooC03oogT0oookJ_ooN@3o
0:Oo00?ooo]Z00?og03ooomi0?ooN@000_ooAP000oooN@3ooo]ZoookJP02oookJP09o`3omooonf[o
/ol0o`3o]ooo0<ko01Ooo`3ohOl0iOooob`000;oogT000?ooo]Zoomi0?ooN@000_ooN@001OooX03o
P`3oo`0goooo@`3o0?;o00;oogT000?o0?ncoomi0?oo02/00ooonfX01?o00?ooo`2SoookJ_oo08D2
oomi0004o`[o0?ooN@3oaOl0oon<00;oogT000KoolT0oookJ_oonf[o_ol0oomi0?oo03/7oomi0003
o`2<oomn0?ooo`X000;ooo]Z00Coo`3loookJ_ood`3o0?nI1?oonfX00oooB03ooo]ZoookJP03oook
JP03o`3oO?oonf[ooo]Z00?ooo]Z00?o00;ooookJ_ooN@001oooN@000oooW03oogT0oomi0004oomi
0003ooo90?oonf[ooo]Z00Oooo]Z2Ooob@3ooookJPSooo]Z00?oo`1foookJ_oonfX05?oonfX01OlJ
o`3ooo]Zoon30?oonf[o;?l000;ooo]Z0_l0B?l8oookJP06ool0/ooonf[o05coo`1Roooo;P3ooe`0
1_oonfX00onno`3ooo]ZoookJP03oookJP04og7o0?l01_oooo]Zo`3oF0Kooo]Z00Ko0?oEoookJ_oo
nf[ooo]Zo`0Cool0Y?l2o`3oYPGooo]Z00?ookL0oookJ_oonfX00_oonfX00ol0D_oo0?l^o`3o;P02
oookJP04ooon0?mGo`3oQ_l0oolg00;ooo]Z00[oom`0oookJ_oonf[oBOl0oookJ_ooXP3ood`0o`3o
DOl0@Ooo0:Oo0ooonfX00ooL0?oooo]ZoookJP02oom60003oon90?oonf[ooo]Z00;ooo]Z00[o0?og
oookJ_nco`3o0?ngool0c_oonf[o0>Goo`3ohOoonf[o4_l00_l0;Ol03ooonf[o0?gooookJ_oonf[o
oj00oookJ_l0=ooo00Sooom30?l0l_oooo]Zo`3o/ol0eOooo`0[o`3o]P02oookJP0>ol00oooo0:?o
oo]ZoookJ_oo08Gooo]Zo`[o0?oonf[oog/0olGo0?ooS03ooo]Zo`3o9?nUo`02oookJP07okoo0?oo
03_ooo]Zo`3oN_oonf[o0?oRool0cP02oookJP03o`2<oomn0?ooo`X000?ooo]Z00Coo`3loooC0?oo
nf[o0?nI1?oonfX00oooB03ooo]ZoookJP03oookJP03o`3oO?oonf[ooo]Z00?ooo]Z00Ko00;ooook
J_oonf[og`3oo`0]oooeo`02oookJP04o`000?ooW03o0000o`2Io`;ooo]Z00?oofH0oookJ_l0o`00
3OoonfX00ooo<@3ooo]ZoookJP3RoookJP00:_oonfX00ooo07Kooo]ZoookJP0CoookJP;o6_l00_oo
P`001Ol/o`3ooo]ZoookJ_oonf[o04So00Oooo]Z0_oo0;<01Ooonf[o05coo`1Roooonf[ooe`000Ko
oo]Z0_nno`04oookJP03ooo90?l01_oo00Ko00;o0?mH1?oonfX2o`3oe@03oookJ_oob@3oolT000?o
olT01_oonfX00ooo]`3ooo]ZoookJP02oookJP03o`1Boooonf[o0?l^00;ooo]Z00Soooh0oeOo0?n6
o`3oQ_l0oolg0?ooN@3ooo]Zoomi00;ooo]Z00GoBOl0oonR0?ooC03o0?mAoookJP02o`2Wo`?ooo]Z
00Cog03ooomi0?ooN@3oodH00_ooN@04oookJP09o`3omooonf[o/ol0o`3o]ooonf[o01Ooo`3ohOoo
nf[oob`000CoogT000So0?n^oomi0?ooN@3ooj00oomi0?l0=ooood<0o`3bo`;oogT000Co0?ncoomi
0?oo02_oogT00_oonfX02_o00?ooo`2SoookJ_oo08Gooo]Zoomi0?l:o`3oogT0olGo0?ooS002oomi
0006ooo90?oonf[ooo]Zokoo0?ooN@3oo`0k1oooN@000ol0S?ooOP3oool:0003oookJP03ool0o?oo
nf[oom<000Gooo]Z00?oodP0oookJ_oonfX00ooonfX00ol0ogcooo]ZoookJP02oookJP03o`02oooo
nf[ooo]Z00KoogT000?ooo]ZoonL0?ooN@001_ooN@000ol0o`3ooo]ZoookJP07oookJPWoolT0oooo
nfX7oookJP03ool0M_oonf[ooo]Z01?ooo]Z0_lJo`02oon300;o;?l00_oonfX00ol0B?oooo]Zoook
JP06oookJP;oo`2c00Gooo]Zo`1Lool0H_ooobh0oomL0005oookJP;o__l01?oonfX2og7o0003o`06
oooonf[o0?mH00Gooo]Z0_l0omD3oookJP03o`0Cool0Y?oo0?nV00Kooo]Z00CookL0oookJ_oonf[o
oo]Z0_l0D_l02?l0obkooo]ZoookJ_oonf[oooh0oeOo0?n6o`3oocL00_oonfX02?oog03ooo]Zoook
J_m9o`3ooo]ZoonR0?l0oe7ooo]Z0_l0Yol3oookJP06om`0oooonf[ooo]Zoom60?oonf[oohT01?oo
nfX02ol0ooOooo]Zok?o0?l0okOoo`3>oookJ_l0iOoo0?oQoookJ_lBo`3o02go00;ooo]Z00ko0?go
oookJ_oonf[ooj00oookJ_l0=ooo00Sooom30?l0l_oooo]Zo`3o/ooonf[oo`0[o`3o]P;ooo]Z00ko
`03oool0Xooonf[ooo]Zool0QOoonf[o2_l0oookJ_ooN`3oaOl0oon<0?oonf[o0?lTojGo00;ooo]Z
00Oo_ol0ool0>ooonf[ooo]Zo`3oN_l0on;oo`3>00;ooo]Z00?o08coogh0oooo2P000ooonfX01?oo
0?cooo]ZoooC0?l0oiT5oookJP03oom80?oonf[ooo]Z00;ooo]Z00?o0?mloookJ_oonfX00ooonfX0
1ol00_oooo]ZoookJ_oO0?oo01[oo`0]oooeo`000_oonfX01?l0003ooi`0oe/0ool0VOl2oookJP03
oomV0?oonf[o0?l000kooo]Z00?ooc40oookJ_oonfX0hOoonfX003oooo]Z00Co6_l0oookJ_ooP`3o
;?l01?oonfX00ol0B?oooo]ZoookJP05oookJP07ool0/ooonf[o05coo`1Lool0H_oooo]ZoomL0006
oookJP03okko0?oob@3ooo]Z00?ooo]Z00CoolT0o`06oooonf[o0?mH1OoonfX01?l0omGooo]Zoook
J_oonfX6ooo900Cooo]Z00?ookL0oookJ_oonfX00_oonfX01?l0D_oooo]Zo`3o;_oonfX2ooon0004
oeOo0?n6o`3oogT0oolg00?oogT000Sooo]ZodWo0?m9o`3ooj80oom<0?l0oe7ooo]Zo`2Wo`?ooo]Z
0_oL0?l00ooonf[oogT0oom60004oomi00;ooo]Z00Wo0?ogoookJ_nco`3oo`3>oookJ_l05ooo0?oQ
oookJ_oo;0001oooN@001OooX03oogT0o`0goooo@`3o0?;o00;oogT000?o0?ncoomi0?oo02/00ooo
N@004_o00?ooo`2SoookJ_oo08Gooo]Zoomi0?l:o`3oogT0olGo0?ooN@3ooh`0oookJ_l0obCoYOl0
oookJ_noo`3ooo]Zool0>`OoogT000?o08coogh0oooo2P000ooonfX00ooo0?cooo]ZoooC0005oook
JP03oom80?oonf[ooo]Z00?ooo]Z00?o0?mloookJ_oonfX00ooonfX00ol00_oooo]Zoomi0007oomi
0003oonL0?ooN@3oogT000GoogT000?o0?l0oookJ_oonfX02?oonfX8ooo90?oooo]Z7?oonfX01OlJ
o`3ooo]Zoon30?oonf[o;?l000?ooo]Z00?o04SooookJ_oonfX01_oonfX01Ooo0;?ooo]Zo`1Lool0
G?oooo]Z00;ooe`01OoonfX00onno`3ooo]ZoookJP03oookJP03og7o0?l01_oooo]Z00;o0?mH1Ooo
nfX00ol0omGooo]ZoookJP02oookJP03o`0Cool0Y?oo0?nV00Gooo]Z0_oo]`03oookJP03o`1Boooo
nf[o0?l^00;ooo]Z0_oooP000omGo`3oQ_l0oolg0002oookJP09oooL0?oonf[oBOl0odWo0?oonf[o
oj80o`3oDOoonf[o0:Oo00?ooo]Z0_oL0?l2oookJP03oom60?oonf[oohT000Cooo]Z00_o0?ogoook
J_nco`3o0?ngool0c_l05ooo0>Goo`3ohOoonf[o4_l0o`0]o`02oookJP0>o`3moooonf[ooo]ZoonP
0?oonf[o03Ooo`08oooo@`3o0?;ooookJ_l0ok?ooo]Zool0:ol0okH2oookJP0>ol00oooo0:?ooo]Z
oookJ_oo08Gooo]Zo`[o0?oonf[oog/0olGo0?oonf[ooh`0o`3o9?nUo`02oookJP07okoo0?oo03_o
oo]ZoookJ_l0og[o097oool0cP02oookJP03o`2<oomn0?ooo`X000Cooo]Z00?oo`3loooC0?l0oiT0
1OoonfX00oooB03ooo]ZoookJP02oookJP03o`3oO?oonf[ooo]Z00Cooo]Z00Ko00;ooookJ_oonf[o
g`3oo`0]oooeo`03oookJP09o`000?ooW03o09Woo`000?oonf[oY03ooomV0?oonf[o0?l000kooo]Z
00?ooc40oookJ_oonfX0hOoonfX003kooo]Z00Co6_l0oookJ_ooP`3o;?l00ooonfX2o`18o`Oooo]Z
00?oo`2coookJ_l0G?l00_l0H_l2oomL00Kooo]Z00?o__l0oookJ_oob@000ooonfX01?oob@3o00Ko
oookJ_l0oeP5oookJP04o`3oeOoonf[ooo]ZoookJPSoolT000?ooo]Zoong0?oo]`000ooonfX2o`1B
o`09oookJ_l0obkooo]Zooon0?oonf[oEol0ohKo0?oonf[oocL000CoogT000OoBOl0oookJ_ooXP3o
od`0o`3oDOoonf[o0:Oo00?ooo]Z00Gog03ooookJ_oonf[oogT0oom60006oomi000:o`3omooonf[o
/ol0ool0c_oonf[o01Ooo`3ohOoonf[oob`0oa;o00SoogT000?o03Oooom30?l0l_l00_ooN@000ol0
ok?oogT0ool0:`02oomi00;o`03o00?oo`2SoookJ_oo08D00_oonfX03Ol:o`3oogT0olGo0?ooN@3o
oh`0oookJ_l0obCoYOl0oookJ_noo`3ooo]Zoomi0?oo03/01OooN@02oookJP03o`2<oooo2P3ooo]Z
00;ooo]Z00Coo`3loookJ_ood`3o0?nI0_oonfX3o`00O`03oom80?l007oo001o00?o001o00?o0?ml
oookJ_oonfX00_l007l00ol00_oo001oo`00O`0?oomi0003o`3o0?oonf[ooo]Z00[ooo]Z1ooob@3o
oookJQ_ooo]Z00Go6_l0oookJ_ooP`3ooo]Zobco0002oookJP;o04So2?oonfX01_oo0;?ooo]Zo`1L
ool0H_ooobh0oomL00Kooo]Z00?o__l0oookJ_oonfX00ooonfX01?mao`3o00KooookJ_l0oeP6oook
JP03o`3oeOoonf[ooo]Z00;ooo]Z00?o01?oo`2Tool0ojH01OoonfX00ooo]`3ooo]ZoookJP02oook
JP03o`1Boooonf[o0?l^00;ooo]Z00Goooh0oeOo0?oonf[oQ_l0oolg0002oookJP03oooL0?oonf[o
BOl000;ooo]Z00Cooj80o`3oDOoonf[o0:Oo0ooonfX01ooL0?oooo]ZoookJ_oonf[oodH0oookJ_oo
R@001?oonfX02ol0ooOooo]Zok?o0?l0okOoo`3>o`0Gool0iOoo0?oQoookJ_lBo`3o02go00;ooo]Z
00ko0?gooookJ_oonf[ooj00oookJ_l0=ooo00Sooom30?l0l_oooo]Zo`3o/ooonf[oo`0[o`3o]P;o
oo]Z00ko`03oool0Xooonf[ooo]Zool0QOoonf[o2_l0oookJ_ooN`3oaOl0oookJ_ooS03ooo]ZojGo
00;ooo]Z00Oo_ol0oookJ_oo03_ooo]Zo`3oN_l0TOooo`3>00?ooo]Z00?o08cooookJ_oo2P000ooo
nfX01Ooo0?coom<0oookJ_l0oiWooo]Z00?o001o00?oodP0o`00Ool007l00ol007l00ol0ogcooo]Z
oookJP03o`00O`07o`02ool007oooo]Zoml0oooonf[o02goooGo0003oookJP08oonL0?l0003o09Wo
o`000?oonf[oofH0oookJ_l0o`0?oookJP03oola0?oonf[ooo]Z0>7ooo]Z000moookJP04oa[o0?oo
P`3ooh<0obco00?ooo]Z00?o04SooookJ_oonfX01_oonfX01_oo0;?ooo]Zo`1Lool0H_oooo]ZoomL
00Kooo]Z0_nno`000ooonf[oolT0ooo90003ooo90003o`06oooonf[o0?mH00Gooo]Z00Co0?oEoook
J_oonf[ooo]Z2_oob@04oookJP06o`1Boooonf[o0?l^o`3o;_oonf[oooh00_mGo`000on6o`3oocL0
oolg0004oomi0007odWo0?ooN@3ooj80oom<0?l0oe7oogT0o`2Wo`03oookJP05om`0oooonf[ooo]Z
oookJ_ooAP002?ooN@002?nco`3oo`3>oookJ_l05ooo0?oQoookJ_oo;03o4_l02OooN@001ooo@`3o
0?;ooookJ_ooN@3o0?ncoomi0?oo02/00_ooN@001Oo00?ooogT0ool0Xooonf[oo`2500;ooo]Z00[o
2_l0oomi0?o5o`3oogT0oon<0?oonf[o0?lTojGo0?oonf[o_ol00_oonfX00ooo03_oogT0oomi0003
oomi00;ooo]Z00?o08coool:0?oonfX00_oonfX01?oo0?cooo]ZoooC0?l0oiT3oookJP;o001o00?o
odP0o`00Ool007l00ol007l00ol0ogcooo]ZoookJP03o`00O`05o`02ool007oo001ooomi0?oO0?l0
1OooN@000oooW03oogT0oomi0005oomi0003o`3o0?oonf[ooo]Z00[ooo]Z1ooob@3ooookJQ[ooo]Z
00?o6_l0oon30?ooP`000_l/o`02oookJP03o`18oooonf[ooo]Z00Oooo]Z00Koo`2coookJ_l0G?oo
06;oool^0?ooG005oookJP;o__l01OoonfX01?mao`3o00KooookJ_l0oeP6oookJP04o`3oeOoonf[o
oo]ZoookJP;o01?o00?o0:Coo`3oY_oonfX01?oonfX01?oo]`3ooo]ZoookJ_oonfX2o`1Bo`;o0?l^
0_oonfX00ooooP3oEol0ohKo0002oolg00;ooo]Z00?oom`0oookJ_m9o`000_oonfX01?ooXP3o0?mA
oookJ_l0Yol3oookJP07om`0oooonf[ooo]ZoookJ_ooAP3ooo]Zoon90004oookJP0;o`3omooonf[o
/ol0o`3o]ooo0<ko01Ooo`3Uool0on7oob`0oa;o0?l0;Ol00_oonfX03_l0oOoooo]ZoookJ_ooX03o
oo]Zo`0gool02?oood<0o`3boooonf[o0?ncoookJ_oo02_o0?nf0_oonfX03_o00?ooo`2SoookJ_oo
nf[oo`25oookJ_l:o`3ooo]Zoomk0?o5o`3ooo]Zoon<0?oonf[oYOl00_oonfX01onoo`3ooo]Zool0
>ooonf[o0?mjo`2Aoooo0<h00ooonfX00ol0S?ooOP3oool:0003oookJP04ool0o?ood`3ooo]Zo`3o
V@;ooo]Z0_l007l00oooB03o001oo`00O`03o`00O`03o`3oO?oonf[ooo]Z00Co001o00Ko00;oo`00
Ool007oog`3oo`0]oooeo`04oookJP08oonL0?l0VOoo0000o`000?oonf[oofH0oookJ_l0o`0?oook
JP03oola0?oonf[ooo]Z0>7ooo]Z000koookJP;o6_l000?ooh<0obco0?oonfX00ooonfX00ol0B?oo
oo]ZoookJP05oookJP;oo`2c00Gooo]Zo`1Lool0H_oooo]ZoomL0006oookJP03okko0?oonf[ooo]Z
00GoolT000?o00Koo`3oF?l0oeP01?oonfX2o`3oe@?ooo]Z2Ooob@000ooo]`3ooo]ZoookJP02oook
JP03o`1Boooonf[o0?l^00;ooo]Z00Goooh0oeOo0?n6o`3oQ_l0oolg0005oomi0004odWo0?ooXP3o
oj80oom<00;oogT000Go0:Oooomi0?ooN@3ooo]Zom`0o`03oookJP03oom60?ooN@3oogT000GoogT0
00Wo00Sook?o0?oo0<kooo]Zo`0Gool0on7ooo]Zool/0?lBo`002?ooN@001_l0=ooood<0o`3boooo
nf[oogT0o`3o/`;oo`0[0_ooN@001Oo00?oooo]Zool0Xooonf[oo`2500;ooo]Z00[o2_l0oomi0?oo
N@3oaOl0oon<0?oonf[o0?lTojGo0?oonf[o_ol00_oonfX00ooo03_oogT0oomi0003oomi00;ooo]Z
00?o08coool:0?oonfX00ooonfX00ooo0?coom<0o`3oV@04oookJP04o`00OoooB03o001oo`00O`?o
oo]Z00Co0?mloookJ_oonf[ooo]Z0_l007l01Ol00_oooo]Zo`00Oooob@3og`3o00GoogT000?ooo]Z
oonL0?ooN@001OooN@000ooonf[o0?l0oookJP0<oookJPKoolT0oooonfXHoookJP;o6_l000?ooh<0
oookJ_l/o`000ooonfX00ol0B?oooo]ZoookJP06oookJP;oo`2c00Gooo]Zo`1Loooonf[oobh0oomL
0005oookJP03okko0?oonf[ooo]Z00?ooo]Z0_mao`000ol01_oo0?mHo`3oF005oookJP;o0?oE0ooo
nfX01?l04ooo0:Coo`2Tool0ojH5oookJP07oong0?oonf[ooo]ZoookJ_l0D_oooo]Zo`3o;P03oook
JP04ooon0?mGo`3oQ_l0oolg00;ooo]Z0_oog0000ooonf[oBOl0oookJP02oonR00;ooo]Z00Go0:Oo
oookJ_oonf[ooo]Zom`0o`03oookJP03oom60?oonf[oohT000Cooo]Z00_o0?ogoookJ_nco`3o0?ng
ool0c_l05ooo0>Goo`3ohOoo;03o4_l0o`0]o`02oookJP0>o`3moooonf[ooo]ZoonP0?oonf[o03Oo
o`08oooo@`3o0?;ooookJ_l0ok?ooo]Zool0:ol0okH2oookJP0>ol00oooo0:?ooo]ZoookJ_oo08Go
oo]Zo`[o0?oonf[oog/0olGo0?oonf[ooh`0oookJ_nUo`02oookJP07okoo0?oonf[oo`0koookJ_l0
og[o097oool0cP03oookJP03o`2<oomn0?ooo`X000Cooo]Z00?oo`3loooC0?l0oiT00ooonfX2o`00
O`03oom80?l007oooo]Z00;ooo]Z00Co0?mloookJ_oonf[ooo]Z0ol007l01ol00_oo001oo`00OooO
0?oooo]Zo`0]oooeo`001?oonfX02?ooW03o09Woo`000?l0003oY03ooomV0?oonf[o0?l04?oonfX0
0ooo<@3ooo]ZoookJP3PoookJP00>_oonfX01?lJo`3ooo]Zoon30?l/o`03oookJP;o04So1ooonfX0
1Ooo0;?ooo]Zo`1Lool0G?oo06;o00;ooe`01_oonfX00onno`3ooo]ZoookJP06ooo90003o`3oF?oo
nf[ooo]Z00?ooo]Z00?o0?oEoookJ_oonfX00ooonfX7ooo90003oookJ_oo]`3ooo]Z00?ooo]Z00?o
05;ooookJ_l0obh00_oonfX01OoooP3oEol0ohKo0?oonf[oocL000GoogT000CoBOl0oonR0?ooC03o
0?mA0_ooN@000ol0YoooogT0oomi0002oomi00;ooo]Z0_ooAP06oomi0005oookJ_l02?oo/ol0ool0
c_oonfX00_l0on400ooonf[oob`0oa;o0007oomi00;oolT000Oood<0oookJ_l0l_ooogT0o`3o/ooo
02_o0?nf00;oogT000Go`03ooookJ_oo0:?ooo]Zool0Q@02oookJP0:o`[o0?ooN@3oogT0olGo0?oo
S03ooo]Zo`3o9?nUo`3ooo]Zokoo00;ooo]Z00?oo`0koomi0?ooN@000_ooN@03oookJP03o`2<oooo
2P3ooo]Z00?ooo]Z00Coo`3loooC0?oonf[o0?nI1OoonfX01?ooB03o001oo`00Ool007l2oookJP03
o`3oO?oonf[ooo]Z00?o001o00Go00;ooookJ_oonf[oogT0oml0o`04oomi0003oookJ_ooW03oogT0
00CoogT000CoofH0oomi0?oonf[o0?l03OoonfX6ooo90?oooo]Z5ooonfX01OlJo`3ooo]Zoon30?oo
nf[o;?l000;ooo]Z0_l0B?l8oookJP05ool0/ooonf[o05coo`1LoooonfX00_ooG005oookJP03okko
0?oonf[ooo]Z00?ooo]Z00CoLOl0o`06oooonf[o0?mH1_oonfX00ol0omGooo]ZoookJP02oookJP04
o`0Cool0Y?oo0?nVo`3oYPGooo]Z00OookL0oookJ_oonf[ooo]Zo`1Boooonf[o0?l^00?ooo]Z00Co
ooh0oeOo0?n6o`3oocL00_oonfX02_oog03ooo]ZoookJ_m9o`3ooo]ZoonR0?ooC03ooo]Zo`11ool0
Yol3oookJP03om`0oooonf[ooo]Z00;oodH000?ooo]Zoon90?oonfX00ooonfX01_l0ooOooo]Zok?o
0?l0okOoo`3>o`0Go`;o0?oQ00?oob`0oa;o0?l0;Ol00_oonfX01?l0oOoooo]ZoookJ_ooX002o`0g
o`;ood<000Ko0?;ooookJ_l0ok?ooo]Zool0:ol0okH2oookJP0>ol00oooo0:?ooo]ZoookJ_oo08Go
oo]Zo`[o0?oonf[oog/0olGo0?oonf[ooh`0oookJ_nUo`02oookJP03okoo0?oonf[oo`0k00;ooo]Z
00?o0?mjool0c_oonfX00ooonfX00ol0S?ooo`X0oookJP03oookJP04ool0o?ood`3ooo]Zo`3oV@Co
oo]Z00CoodP0o`00Ool007oo001o0_oonfX00ol0ogcooo]ZoookJP03o`00O`08oookJ_l00_oooo]Z
o`00OooO0?oo01[oo`0]oooeo`03oookJP03oonL0?mK0?oo09Wo00;o000000CoofH0oookJ_oonf[o
0?l04?oonfX00ooo<@3ooo]ZoookJP3PoookJP00>OoonfX01?lJo`3ooh<0oon30?l/o`03oookJP03
o`18ool0ol7ooo]Z00Kooo]Z00Ooo`2coookJ_l0G?oo06;ooookJ_ooG03oobh000Kooo]Z00?o__l0
oookJ_oonfX01_oob@000ol0oeSoolT0oookJP03oookJP03o`3oeOoonf[ooo]Z00;ooo]Z00?o01?o
ooo90?oob@001?oob@000ooonf[ookL0oong0004oookJP04o`1Boooonf[o0?l^oookJP;oooh000Go
Eol0ohKo0?oonf[oocL0oookJP03oomi00;oBOl000?ooj80oom<0?l0oe400_ooN@000ol0YoooogT0
oomi0004oomi0003oom60?oonf[oogT000CoogT000Co0?ogoookJ_l02?oo/ol00_oonfX01_l0on7o
0>GooookJ_oo;03o4_l0o`0]o`KoogT000WoolT0oomi0?oo@`3ooo]Zo`3boooonf[o0?ncool0:ol0
okH00_ooN@001Oo00?oooo]Zool0Xooonf[oo`2500;ooo]Z00[o2_l0oookJ_ooN@3oaOl0oon<0?oo
nf[o0?lTojGo0?oonf[o_ol00_oonfX00ooo03_oogT0oomi0004oomi0004oookJ_l0S?ooOP3oool:
00?ooo]Z00Coo`3loooC0?oonf[o0?nI1OoonfX00oooB03ooo]Zo`00O`03o`00O`04o`3oO?oonf[o
oo]ZoookJP;o001o00Go00;ooookJ_oonf[ooo]Zoml0o`04oomi00;ooo]Z00?ooi`0oomi0?ooN@00
0_ooN@001OooIP3oogT0o`000?oonf[o0?l000kooo]Z1Ooob@3ooookJQKooo]Z00Go6_l0oon30?oo
P`3ooo]Zobco0002oookJP03o`18ool0ol7ooo]Z00Oooo]Z00Koo`2coookJ_l0G?oo06;oool^0?oo
G006oookJP03okko0?oonf[ooo]Z00?ooo]Z00CoLOl0o`06oooonf[o0?mH1_oonfX00ol0omGooo]Z
oookJP02oookJP03o`0Cool0Y?oo0?nV00Gooo]Z0_oo]`03oookJP03o`1Boooonf[o0?l^00;ooo]Z
0_oooP000omGo`3oQ_l0oolg0002oookJP0:oooL0?oonf[oBOl0odWo0?oonf[ooj80oom<0?oonf[o
047oo`2Wo`?ooo]Z00Cog03ooookJ_oonf[oodH00_oonfX00oooR@3ooo]ZoookJP02oookJP0;o`3o
mooonf[o/ol0o`3o]ooonf[o01Ooo`3ohOoonf[oob`0oa;o0?l0;Ol00_oonfX03_l0oOoooo]Zoook
J_ooX03o03Oooh<0oooo@`3oolT0o`3boooonf[o0?ncoookJ_oo02_o0?nf0_oonfX01Oo00?oooo]Z
ool0Xooonf[oo`2500;ooo]Z00Oo2_l0oomk0?o5o`3ooo]Zoon<0?oonf[oYOl000;ooo]Z00?o_ol0
oookJ_oo03/00_oonfX00ol0og[oo`3>o`3ohP03oookJP03o`2<oooonf[oo`X000?ooo]Z00Coo`3l
oooC0?oonf[o0?nI1?oonfX00oooB03ooo]Zo`00O`03o`00O`04o`3oO?oonf[ooo]ZoookJP?o001o
00Oo00;ooookJ_oonf[og`3oo`00Ool0;OoomOl000Cooo]Z00?ooi`0o`2Iool000000_l000001?oo
IP3o0000oookJ_l0o`0@oookJP03oola0?oonf[ooo]Z0>3ooo]Z000goookJP;o6_l000?ooh<0obco
0?l/o`000ooonfX00ol0B?oooo]ZoookJP06oookJP06ool0/ooonf[o05coo`1Roooonf[ooe`01_oo
nfX2okko00;ooo]Z1_oob@001?l0oeSoolT0ooo90?oob@02oookJP03o`3oeOoonf[ooo]Z00;ooo]Z
00?o01?oooo90?oob@000ooob@02oookJP03oong0?oonf[ooo]Z00;ooo]Z0_l0D_l01Ooonf[o0?l^
oookJ_oooP3ooo]Z00;oQ_l00_oo=`002_oonf[oogT0oomi0?ooN@3oBOl0oomi0?ooXP3ood`0o`3o
DOooN@02o`2Wo`GoogT000?ooo]Zoom60?oonfX01?ooN@003Ooonf[o0?ogoookJ_l02?oo/ol0oook
J_l05ooo0?oQo`3Uoooonf[oob`0oa;o0?l0;Ol01OooN@03ooo9000>oom30?oonf[o0?;ooookJ_l0
ok?oo`0[o`3o]_ooN@3ooo]Zol00oooonf[oo`2SoookJ_oo08D2oookJP0:o`[o0?ooN`3oogT0olGo
0?ooS03ooo]Zo`3o9?nUo`3ooo]Zokoo00;ooo]Z00Coo`0koookJ_ooN@3ooo]Z1OooN@000ol0S?oo
o`X0oookJP02oomi0004ool0o?oonf[oom<0o`3oV@Kooo]Z00KoodP0oookJ_oonf[ooo]Zo`00Ool0
og`2o`00O`;ooo]Z0_l007l02?l00_oooo]ZoookJ_oonf[og`3ooomi0?oeo`3oogT00_oonfX00ooo
W03ooo]Zoomi0003oomi0004oomV0?nT0?oooo]Zo`3o013ooo]Z1?oob@3ooookJQCooo]Z0_lJo`00
1?ooP`3ooo]Zobco0?l/o`02oookJP03o`18oooonf[ooo]Z00Oooo]Z00Koo`2coookJ_l0G?oo06;o
ool^0?ooG005oookJP;o__l01OoonfX01?mao`3o00KooookJ_l0oeP6oookJP04o`3oeOoonf[ooo]Z
oookJP;o01?o00?o0:Coo`3oY_oonfX01?oonfX01?oo]`3ooo]ZoookJ_oonfX2o`1Bo`07oookJ_l0
obkooo]ZoookJ_oooP3ooo]ZohKo0002oolg00;ooo]Z00?oom`0oookJ_m9o`000_oonfX00oooXP3o
0?mAoookJP02o`2Wo`;ooo]Z0_oL0?l2oookJP04oom60?oonf[ooo]Zoon900Cooo]Z00_o0?ogoook
J_nco`3ok`3ooookJ_l05ooo0?oQoookJ_oo;03o4_l0o`0]o`02oookJP0>o`3moooonf[ooo]ZoonP
0?l0=oooP`3ooom30?oob@3o0?;ooookJ_l0ok?ooo]Zool0:ol0okH2oookJP05ol00oooonf[oo`2S
oookJ_oo08D00_oonfX01ol:o`3oog/0olGo0?oonf[ooh`0oookJ_nUo`000_oonfX00onoo`3ooo]Z
ool0>`02oookJP03o`3oN_l0TOooo`3>00?ooo]Z00?o08cooookJ_oo2P000ooonfX01?oo0?cooo]Z
oooC0?l0oiT5oookJP06oom80?oonf[ooo]ZoookJ_l007oo0?ml0_l007l2oookJP;o001o00So00;o
oookJ_oonf[ooo]Zoml0ool06_oo02goooGo00?ooo]Z00?ooi`0oookJ_l0VOl00ol000000oooIP3o
oo]Zo`3o000BoookJP03oola0?oonf[ooo]Z0=oooo]Z000foookJP04oa[o0?oonf[ooh<0obco00?o
oo]Z0_l0B?l7oookJP;oo`2c0_l0G?l00ol0H_oooe`0oomL0006oookJP03okko0?oonf[ooo]Z00;o
oo]Z1?oob@02o`3oF0;oolT00_oonfX2o`3oe@Cooo]Z0_l0Y?l3ooo900?ooo]Z00?ookL0oookJ_oo
nfX00_oonfX02_l0D_oooo]Zo`3o;_l0obkooo]Zooon0?ooN@3oQ_l0oookJ_oo=`02oookJP?oogT0
00OoBOl0oookJ_ooXP3ood`0o`3oDOooN@3o0:Oo00CoogT00ooonfX00oooAP3ooo]ZoookJP05oomi
000;oookJ_l02?oo/ol0oookJ_l05ooo0?oQo`3Uoooonf[oob`0oa;o0?l0;Ol01?ooN@000oooX03o
olT0ooo90003ooo90005o`3boooonf[o0?ncool0:ol0okH00_oonfX00oo00?oooo]Zool0X`02oook
JP0:ool0QOoonf[o2_l0oomk0?oob@3oaOl0oon<0?oonf[o0?lTojGo00;ooo]Z00Oo_ol0oookJ_oo
03_ooo]Zoomi0?oonf[o097o00GoogT000?oo`X0oookJ_oonfX00_ooN@000ooo0?coom<0o`3oV@06
oookJP03oom80?oonf[ooo]Z00?ooo]Z00?o0?mlo`00Ool007l00_oonfX00ol007oo00;oo`00O`02
oookJP03oml0ooooN@3omOl000;oogT00_oonfX00oooW03ooo]Zoomi0002oomi0005o`000?ooIP3o
oo]ZoookJ_l0o`004?oonfX4ooo90?oooo]Z4ooonfX01OlJo`3ooo]Zoon30?oonf[o;?l000?ooo]Z
00?o04SooookJ_oonfX01_oonfX2ool0/`;o05co00?ooo]ZoomL0?ooG0001OoonfX00onno`3ooo]Z
oookJP04oookJP04og7o0?l01_oo0?mHo`3oF0Gooo]Z0_l0omD3oookJP04o`0Cool0Y?oo0:Coo`3o
YPGooo]Z00KookL0oookJ_oonf[ooo]Zo`1BoooonfX2o`3o;P;ooo]Z00Coooh0oeOo0?n6o`3oocL0
0ooonfX00ooog03ooo]ZodWo0002oookJP04oonR0?l0oe7ooo]Zo`2Wo`?ooo]Z00Gog03ooookJ_oo
nf[ooo]Zoom60002oookJP03oon90?oonf[ooo]Z00;ooo]Z00_o0?ogoookJ_nco`3ok`3ooookJ_l0
5ooo0?oQoookJ_oo;03o4_l0o`0]o`02oookJP0>o`3moooonf[ooo]ZoonP0?l0=oooP`3ooom30?oo
b@3o0?;ooookJ_l0ok?ooo]Zool0:ol0okH2oookJP05ol00oooonf[oo`2SoookJ_oo08D00_oonfX0
1ol:o`3oog/0olGo0?oonf[ooh`0oookJ_nUo`000ooonfX01onoo`3oo`0koookJ_oonf[o0?mjo`2A
oooo0<h00ooonfX00omn0?oo08coool:0003oookJP04ool0o?oonf[oom<0o`3oV@Gooo]Z00?oodP0
oookJ_oonfX00ooonfX00ol0ogco001oo`00O`02oookJP;o001o00Oo00;ooookJ_oonf[og`3oo`00
Ool0;OoomOl000Cooo]Z00?ooi`0o`2Iool000000_l000001?ooIP3ooo]ZoookJ_l0o`0BoookJP03
oola0?oonf[ooo]Z0=oooo]Z000eoookJP04oa[o0?ooP`3ooh<0obco00?ooo]Z00?o04Soo`3o`Ooo
nfX01_oonfX01ooo0;?ooo]Zo`1Lool0H_oooo]ZoomL0?oo;P001_oonfX00onno`3ooo]ZoookJP02
oookJPCoolT000?o0?mHooo90?oonfX00ooonfX00ol0omGooo]ZoookJP03oookJP04o`2Toooonf[o
olT0ooo900Cooo]Z00?ookL0oookJ_oonfX00_oonfX00ol0D_oooo]Zo`3o;P02oookJP05ooon0?oo
N@3oQ_l0oookJ_oo=`000ooonfX2oomi0007odWo0?oonf[ooj80oookJ_l0oe7oogT0o`2Wo`03oomi
0005om`0oooonf[ooo]ZoookJ_ooAP000_oonfX2oomi0004oookJ_ooN@3oogT0oomi00;o/ol000Co
oo]Zo`0Gool0on7o0>Go0_ooN@000olBo`3o02gooookJP02oomi0003ooo90?ooX03oolT000CoolT0
00Go0?;oooo90?l0ok?oo`0[o`3o]P02oookJP03ol00oooonf[oo`2S00;ooo]Z00[oo`25oookJ_l:
o`3oog/0oookJ_o5o`3ooh`0oookJ_l0obCoYOl00_oonfX00onoo`3ooo]Zool0>`02oookJP03o`3o
N_l0TOooogT000CoogT000?oo`X0oomi0?ooN@000_ooN@001?oo0?coom<0oomi0?l0oiT2oomi00?o
oo]Z00?oodP0oookJ_oonfX00ooonfX00ol0ogcooo]Zo`00O`02o`00O`04oookJ_l007oo00;oo`00
O`;ooo]Z00Cog`3ooomi0?oeo`3oogT00ooonfX01?ooW03oogT0oomi0?ooN@02o`000004oomV0?oo
nf[ooo]Zo`3o017ooo]Z0ooob@3ooookJQ;ooo]Z00Go6_l0oon30?ooP`3ooo]Zobco0002oookJP;o
04So2?oonfX01_oo0;?ooo]Zo`1Lool0H_ooobh0oomL00Kooo]Z00?o__l0oookJ_oonfX00ooonfX2
og7o0003o`06ool0oeSooo]Z00Gooo]Z00?o0?oEoookJ_oonfX00_oonfX01?l04ooo0:CooookJ_l0
ojH5oookJP07oong0?oonf[ooo]ZoookJ_l0D_oooo]Zo`3o;P03oookJP04ooon0?mGo`3oQ_l0oolg
00?ooo]Z00?oom`0oookJ_m9o`000_oonfX01?ooXP3o0?mAoookJ_l0Yol3oookJP05om`0oooonf[o
oo]ZoookJ_ooAP000_oonfX01?ooR@3ooo]ZoookJ_oonfX2o`3om`;o/ol000Sok`3ooookJ_l05ooo
0?oQoookJ_oo;03o4_l0o`0]o`;ooo]Z00ko0?gooookJ_oonf[ooj00o`0goon30?oood<0ooo90?l0
l_oooo]Zo`3o/ooonf[oo`0[o`3o]P;ooo]Z00Go`03ooookJ_oo0:?ooo]Zool0Q@02oookJP07o`[o
0?ooN`3ooo]ZolGo0?ooS03ooo]ZojGo0003oookJP07okoo0?oo03_ooo]ZoookJ_l0og[o097oool0
cP03oookJP03ogh0ool0S?ooo`X000?ooo]Z00Coo`3loookJ_ood`3o0?nI1OoonfX00oooB03ooo]Z
oookJP03oookJP03o`3oO?oonf[o001o00;o001o00Cooo]Zo`00Ool00_oo001o0_oonfX01?oO0?oo
01[oo`0]oooeo`03oookJP03oonL0?oonf[o09Wo00?o000000CoofH0oookJ_oonf[o0?l04_oonfX0
0ooo<@3ooo]ZoookJP3OoookJP00<ooonfX2oa[o0003oon30?l/o`3o;?l000?ooo]Z00?o04Sooook
J_oonfX01_oonfX01_oo0;?ooo]Zo`1Lool0H_oooo]ZoomL00Kooo]Z0_oUo`04oookJPCoolT000?o
0?mHoookJ_oonfX00ooonfX00ol0omGooo]ZoookJP03oookJP03o`2Tool0ojKoolT000Gooo]Z00?o
okL0oookJ_oonfX00_oonfX00ol0D_oooo]Zo`3o;P02oookJP05ooon0?ooN@3oQ_l0oookJ_oo=`00
0ooonfX01OooN@3oBOl0odWo0?oonf[ooj8000;o0?mA00CoogT0o`2WooooN@3oogT00_oL0?l3oook
JP05oom60?oonf[oohT0oomi0?oonfX01?ooN@002onco`3oogT0oomi0?l05ooo0?oQo`3Uoooo;03o
ogT0oa;o0?l0;Ooooo]Z00;oogT000?oo`2QoonP0?oob@001?oob@001Ol0l_oooo]Zo`3o/ooo02_o
0?nf00;ooo]Z00?o`03ooookJ_oo0:<00_oonfX01ooo08Gooo]Zo`[o0?ooN`3ooo]ZolGo0?ooS000
0_oob@001_oonf[oYOl0oookJ_noo`3ooo]Zool0>`;ooo]Z00?o0?mjo`2Aoooo0<h01?ooN@000ooo
2P3oogT0oomi0002oomi0003ool0o?ood`3oogT000GoogT000Cooo]Zoom80?oonf[ooo]Z0ol007l0
0ol0ogcooo]ZoookJP03o`00O`0:oookJ_l00_oo001oo`00Oooonf[og`3ooomi0?oeo`3oogT0o`00
O`;ooo]Z00?ooi`0oookJ_ooN@000_ooN@000ol0003oofH0oj@0o`02oookJP03o`3o0?oonf[ooo]Z
00oooo]Z0ooob@3ooookJQ3ooo]Z0_lJo`001?ooP`3ooo]Zobco0?l/o`02oookJP03o`18oooonf[o
oo]Z00Oooo]Z00Koo`2coookJ_l0G?oo06;oool^0?ooG005oookJP;o__l01OoonfX01?mao`3o00Ko
oookJ_l0oeP6oookJP03o`3oeOoonf[ooo]Z00;ooo]Z00Co01?oo`2Tool0ojKo0?nV1?oonfX2oong
00?ooo]Z00?o05;ooookJ_l0obh00ooonfX01?oooP3oEol0ohKo0?oo=`03oookJP03oooL0?m9o`3o
BOl000;ooo]Z00Cooj80o`3oDOoonf[o0:Oo0ooonfX01_oL0?oooo]ZoookJ_oonf[oodH0oookJP;o
ohT00ooonfX03?l0ooOooo]Zok?o0?l0okOoo`3>oookJ_l05ooo0?oQoookJ_oo;03o4_l0o`0]o`;o
oo]Z00ko0?gooookJ_oo0:7ooj00o`0goon30?oood<0ooo90?l0l_oooo]Zo`3o/ol0eOooo`0[o`3o
]P;ooo]Z00Go`03ooookJ_oo0:?ooo]Zool0Q@02oookJP03o`[o0?ooN`3ooo]Z00;ooh`000?ooo]Z
o`3o9?nUo`000_oonfX02?noo`3oo`0koookJ_oonf[o0?mjo`2Aoooo0<ko0?oR0_oonfX00omn0?oo
08coool:0003oookJP04ool0o?oonf[oom<0o`3oV@Gooo]Z00?oodP0oookJ_oonfX00ol007l00ol0
ogcooo]ZoookJP03o`00O`0:oookJ_l00_oo001oo`00Oooonf[og`3ooookJ_l0;OoomOl0o`00O`?o
oo]Z00?ooi`0oe/0ool0VOl00_l000001OooIP3oY03ooookJ_oonf[o0?l001?ooo]Z00?ooc40oook
J_oonfX0g_oonfX003;ooo]Z00Co6_l0oookJ_ooP`3o;?l00ooonfX2o`18o`Sooo]Z00Coo`2coook
J_l0G?oo06;o0_ooG006oookJP03onGo0?oonf[ooo]Z00?ooo]Z0ooob@02o`3oF0Gooo]Z00?o0?oE
oookJ_oonfX00_oonfX00ol04ooo0:Coo`3oYP06oookJP03oong0?oonf[ooo]Z00;ooo]Z00Co05;o
oookJ_l0obkooo]Z0_oooP001?ooN@3oQ_l0oookJ_oo=`02oookJP04oooL0?ooN@3oBOl0oookJP;o
oj8000Co0?mAoookJ_ooN@3o0:Oo0_oonfX00ooL0?oooo]ZoookJP02oookJP03oom60?oonf[oohT0
00?ooo]Z0oooN@000onco`3oogT0oomi0002oomi000:o`3Uoooo;03oogT0oa;o0?l0;Ooo0?gooomi
0?oonf[oo`2QoonP00GoolT000Go0?;ooookJ_l0ok?oo`0[o`3o]P02oookJP03ol00oooonf[oo`2S
00;ooo]Z00Ooo`25oookJ_l:o`3oog/0oookJ_o5o`3ooh`000?oolT000?oYOl0oookJ_noo`000_oo
nfX01Ooo03_ooo]Zo`3oN_l0TOooo`3>00GoogT000Ooo`X0oomi0?ooN@3oogT0ool0o?ooN@3oom<0
00SoogT00_oonfX3o`00O`03o`3oO?oonf[ooo]Z00?o001o00Sooo]Zo`02ool007oo001ooookJ_oO
0?ooogT0ooGo00;o001o0_oonfX01?ooW03ooo]Zoomi0?ooN@02o`000004oomV0?l0003ooo]Zo`3o
01?ooo]Z0_oob@3ooookJPoooo]Z00Go6_l0oookJ_ooP`3ooo]Zobco0003oookJP03o`18oooonf[o
oo]Z00Oooo]Z00Coo`2coookJ_l0G?oooo]Z0_ooG005oookJP03okko0?oonf[ooo]Z00Cooo]Z00Co
LOl0o`06oooonf[o0?mH1_oonfX01?l0omGooo]ZoookJ_oonfX2o`0Co`03o`2Tool0ojKooo]Z00Co
oo]Z00?ookL0oookJ_oonfX00_oonfX00ol0D_oooo]Zo`3o;P02oookJP;oooh000?oEol0ohKo0?oo
=`000_oonfX2oooL0003odWo0?oonf[ooo]Z00;ooj8000?o0?mAoookJ_l0Yol00ooonfX01ooL0?oo
oo]ZoookJ_oonf[oodH0oookJ_ooR@001?oonfX03Ol0ooOooo]Zok?o0?l0okOoo`3>oookJ_l0iOoo
0?oQoookJ_oo;03o4_l0o`0]oooonfX00_l0oOl03Ooonf[oo`2QoonP0?l0=oooP`3ooom30?oob@3o
0?;ooookJ_l0ok?o0=Goool0:ol0okH00_oonfX01Oo00?oooo]Zool0Xooonf[oo`2500;ooo]Z00Co
2_l0oomk0?oonf[ooh`00ooonfX02onUo`3ooo]ZoookJ_noo`3ooo]Zool0>ooonf[o0?mjo`2Aoooo
0<ko0?oR00?ooo]Z00?o08coool:0?oonfX00_oonfX01?oo0?cooo]ZoooC0?l0oiT6oookJP03oom8
0?oonf[ooo]Z00?o001o00?o0?mloookJ_oonfX00ol007l02?oonf[o00;oo`00Ool007oooo]Zoml0
ool0;OoomOl00_l007l2oookJP04oonL0?oonf[o09WooookJP;o000000CoofH0o`000?oonf[o0?l0
5?oonfX00ooo<@3ooo]ZoookJP3NoookJP00<OoonfX01?lJo`3ooo]Zoon30?l/o`03oookJP03o`18
ool0ol7ooo]Z00Kooo]Z0_oo0;<2o`1Lo`03oookJ_ooG03oobh000Kooo]Z00?oiOl0oookJ_oonfX0
0ooonfX2ooo90003oookJ_l0oeSooo]Z00Gooo]Z00?o0?oEoookJ_oonfX00_oonfX2o`2To`03o`3o
Y_oonf[ooo]Z00?ooo]Z0_oo]`04oookJP08o`1BooooN@3o0?l^oookJ_oooP3ooo]Zoomi0?n6o`02
oolg00;ooo]Z00[oom`0oookJ_m9o`3ooo]ZoonR0?ooC03o0?mAo`11ooooN@3o0:Oo0_oonfX01?oL
0?oooo]ZoookJ_oonfX2oomi0003oookJ_ooR@3ooo]Z00;ooo]Z0oooN@000onco`3oogT0oomi0005
oomi0003oa;o0?ooN@3o0?go00?oogT000?ooj00ooo90?oob@000ooob@001Ol0l_oooo]Zo`3o/ooo
02_o0?nf00;ooo]Z00?o`03ooookJ_oo0:<00_oonfX01ooo08Gooo]Zo`[o0?ooN`3ooo]ZolGo0?oo
S0000ooob@000onUo`3oolT0ooo90002oookJP06ool0>ooonf[o0?mjo`2Aoooo0<kooo]Z1?ooN@00
1ooo2P3oogT0oomi0?oonf[oogT0ool0o?ood`002_ooN@001Ooonf[o001oo`00Ool0ogco001o00;o
oo]Z0ol007l01Ol00_oooo]Zo`00Ool007oog`3o00;oogT000?omOl0o`00OooonfX00_oonfX01?oo
W03ooo]Zoomi0?oonfX2o`000004oomV0?l0003ooo]Zo`3o01Cooo]Z00?oolT0oookJ_oonfX0oooo
nfX<oookJP05oa[o0?oonf[ooh<0oookJ_l/o`000_oonfX2o`18o`Sooo]Z0_oo0;<2o`1Lo`03oook
J_ooG03ooo]Z00Gooo]Z00?o__l0oookJ_oonfX01?oonfX01?mao`3o00KooookJ_l0oeP6oookJP05
o`3oeOoonf[ooo]ZoookJ_l04ol00_l0Y?l00ol0ojKooo]ZoookJP03oookJP03oong0?oonf[ooo]Z
00;ooo]Z00?o05;ooookJ_l0obh00_oonfX00ooooP3ooo]ZoeOo0002oolg00;ooo]Z00?oom`0oook
J_m9o`000_oonfX01OooXP3ood`0o`3oDOl0@Ooo0:Oo00?ooo]Z00?og03ooookJ_oonfX00_ooAP00
0ooonf[oohT0oookJP03oookJP04o`3omooonf[o/ol0o`3o]`;ooo]Z00Go0>Goo`3ohOoonf[oob`0
oa;o0002oookJP0?o`3mool0ojkooo]Zool0XOooX03o03Oooh<0oooo@`3ooo]Zo`3boooonf[o0?nc
o`3Eoooo02_o0?nf00;ooo]Z00Go`03ooookJ_oo0:?ooo]Zool0Q@02oookJP04o`[o0?ooN`3ooo]Z
oon<00?ooo]Z00_oYOl0oookJ_oonf[o_ol0oookJ_oo03_ooo]Zo`3oN_l0TOooo`3>o`3ohP03oook
JP03o`2<oooo2P3ooo]Z00?ooo]Z00?oo`3loooC0?l0oiT01_oonfX01?ooB03ooo]ZoookJ_oonfX2
o`00O`04o`3oO?l007oooo]ZoookJP?o001o00Wo00;ooookJ_l007oo001ooml0oooonf[o02goooGo
0?l007l00ooonfX01?ooW03ooo]Zo`2IoooonfX2o`000004oomV0?l0003ooo]Zo`3o01Gooo]Z00?o
oc40oookJ_oonfX0gOoonfX0033ooo]Z00Co6_l0oon30?ooP`3o;?l00_oonfX2o`18o`Sooo]Z00Oo
o`2coookJ_l0G?oo06;ooookJ_ooG03oobh000Kooo]Z00?oiOl0oookJ_oonfX00_oonfX01Omao`3o
olT0o`06oooonf[o0?mH00Gooo]Z0_l0omD4oookJP03o`2Toooonf[o0?nV00Gooo]Z00?ookL0oook
J_oonfX00_oonfX2o`1Bo`04oookJ_l0obkooo]Zooon00;oogT000?oQ_l0oolg0?oonfX00_oonfX0
2_oog03ooo]ZodWo0?oonf[ooj80oom<0?l0oe7o047ooookJ_l0Yol2oookJP05om`0oooonf[ooo]Z
oookJ_ooN@000_oonfX01?ooR@3ooo]ZoookJ_oonfX3oomi0003ok?o0?ooN@3oogT000?oogT000Go
ob`0oookJ_lBo`3oogT0o`3mo`03oomi0003oonP0?ooN@3oolT000;oolT000Kooo]Zo`3boooonf[o
0?ncool0:ol0okH2oookJP03ol00oooonf[oo`2S00;ooo]Z00Ooo`25oookJ_l:o`3oog/0oookJ_o5
o`3ooh`000?oolT000?oYOl0ooo90?oob@000_oob@001_oo03_ooo]Zo`3oN_l0TOooo`3>oookJPCo
ogT000?oo`X0oomi0?oonfX00_oonfX00ooo0?coom<0oomi000;oomi0003oookJ_l007oo0?ml00Go
001o00So00;ooookJ_oonf[o001ooml0oomFo`3oogT0ooGo00;o001o0_oonfX01oooW03ooo]Zoe/0
ool0VOoooo]Zo`000?ooIP000_l000000ooonf[o0?l0oookJP0CoookJP03oola0?oonf[ooo]Z0?oo
oo]Z2ooonfX00olJo`3ooh<0oon30002obco00;ooo]Z00?o04SooookJ_oonfX01ooonfX01_oo0;?o
oo]Zo`1Lool0H_ooobh0oomL00Kooo]Z00?o__l0oookJ_oonfX00ooonfX2og7o0003o`06ool0oeSo
0?mH00Gooo]Z0_l0omD3oookJP04o`0Cool0Y?oooo]Zo`3oYPGooo]Z00CookL0oookJ_oonf[ooo]Z
0_l0D_l01Ooonf[o0?l^oookJ_oonf[oooh000;oEol000OoocL0oookJ_oonf[ooo]ZoooL0?oonf[o
BOl000;ooo]Z00Gooj80oom<0?l0oe7o047oo`2Wo`03oookJP04om`0oooonf[ooo]Zoom600;ooo]Z
00?oohT0oookJ_oonfX00_oonfX01?l0ooOooo]Zok?o0?l0okL2oookJP05o`3Uool0on7ooo]Zool/
0?lBo`000_oonfX03ol0oOoo0?n^oookJ_oo0:7ooj00o`0goon30?oood<0oookJ_l0l_oooo]Zo`3o
/ol0eOooo`0[o`3o]P02oookJP05ol00oooonf[oo`2SoookJ_oo08D00_oonfX01?l:o`3oog/0oook
J_ooS003oookJP0;ojGo0?oonf[ooo]Zokoo0?oonf[oo`0koookJ_l0og[o097oool0c_l0on800ooo
nfX00ol0S?ooo`X0oookJP03oookJP04ool0o?ood`3ooo]Zo`3oV@Gooo]Z00?oodP0oookJ_oonfX0
0ooonfX00ol007oo0?mlo`00O`04o`00O`03oookJ_l00_oooo]Z00;o001o00?og`3oo`0]oooeo`00
0_l007l2oookJP07oonL0?oonf[oF`3oo`2Ioooonf[o0000oomV0002o`000003oookJ_l0o`3ooo]Z
01Cooo]Z00?ooc40oookJ_oonfX0gOoonfX002kooo]Z0_lJo`000oooP`3o;?l0oookJP02oookJP03
o`18ool0ol7ooo]Z00Oooo]Z00Coo`2coookJ_l0G?oo06;o0_ooG006oookJP;oiOl01?oonfX01Oma
o`3o00Koo`06oooonf[o0?mH00Gooo]Z00?o0?oEoookJ_oonfX00ooonfX00ol0Y?oo0?nVo`3oYP05
oookJP03oong0?oonf[ooo]Z00;ooo]Z00[o05;ooookJ_l0obko0?l^oomi0?oooP3oogT0oookJ_n6
o`3oocL00ooonfX02?oog03ooo]ZodWo0?oonf[ooj80oookJ_l0oe7o047o0_l0Yol00ooonf[og03o
om`0o`03oookJP04oomi0?oonf[ooo]Zoon900Cooo]Z0_ooN@000onco`3oogT0oomi0003oomi0005
ool/0?oonf[o4_l0oomi0?l0oOl00oooN@002oooX03oogT0oomi0?ooN@3oolT0oookJ_l0l_oooo]Z
o`3o/ooo02_o0?nf00;ooo]Z00?o`03ooookJ_oo0:<00_oonfX01ooo08Gooo]Zo`[o0?ooN`3ooo]Z
olGo0?ooS0000ooob@002_nUo`3oolT0ooo90?oob@3ooo]Zool0>ooonf[o0?mjo`2Aoooo0<h2oook
JP?oogT000?oo`X0oomi0?oonfX00_oonfX00ooo0?coom<0oomi000:oomi00?ooo]Z00?o0?mlo`00
Ool007l00ol007l00ooonf[o00;ooookJP02oookJP05oml0ool06_oo02goooGo0?l007l00ooonfX0
0oooW03ooo]Zo`2Io`02oookJP05o`000?ooIP3o0000o`000?l0o`005OoonfX00ooo<@3ooo]Zoook
JP3ooookJPWooo]Z0_lJo`000oooP`3ooo]Zobco0003oookJP03o`18oooonf[ooo]Z00Oooo]Z00Co
o`2coookJ_l0G?oo06;o0_ooG005oookJP;o__l01OoonfX01?mao`3o00KooookJ_l0oeP6oookJP03
o`3oeOoonf[ooo]Z00;ooo]Z00Co01?oo`2Tool0ojKo0?nV1?oonfX2oong00?ooo]Z00Co05;ooook
J_l0obko0?l^0_oonfX01?oooP3oEol0oookJ_oo=`03oookJP03oooL0?oonf[oBOl000;ooo]Z00?o
oj80oookJ_l0oe400_l0Yol2oookJP;og03o0_oonfX01?ooAP3ooo]ZoookJ_ooR@04oookJP04o`3o
mooonf[o/ol0o`3o]`;ooo]Z00Go0>Goo`3ohOoonf[oob`0oa;o0002oookJP0?o`3mool0ojkooo]Z
ool0XOooX03o03OooookJ_oo@`3ooo]Zo`3boooonf[o0?nco`3Eoooo02_o0?nf00;ooo]Z00Go`03o
oookJ_oo0:?ooo]Zool0Q@02oookJP04o`[o0?ooN`3ooo]Zoon<00?ooo]Z00_oYOl0oookJ_oonf[o
_ol0oookJ_oo03_ooo]Zo`3oN_l0TOooo`3>o`3ohP03oookJP03o`2<oooo2P3ooo]Z00?ooo]Z00Co
o`3loooC0?oonf[o0?nI1OoonfX00oooB03ooo]ZoookJP04oookJP03o`3oO?l007oo001o00?o001o
00?ooo]Zo`02oooonfX00_oonfX01OmFo`3og`3oo`0]oooeo`3o001o00?ooo]Z00?ooi`0oookJ_l0
VOl00_oonfX01Ol0003oofH0o`000?l0003o0?l001Kooo]Z00?ooc40oookJ_oonfX0gOoonfX002go
oo]Z00Co6_l0oookJ_ooP`3o;?l00ooonfX00ol0B?oo0?o1oookJP07oookJP06ool0/ooonf[o05co
oookJ_ooG03oobh01_oonfX00ooUo`3ooo]ZoookJP03oookJP03og7o0?l01_oooo]Z00;o0?mH1Ooo
nfX00ol0omGooo]ZoookJP03oookJP03o`2Tool0ojKooo]Z00Gooo]Z00?ookL0oookJ_oonfX00_oo
nfX00ol0D_oooo]Zo`3o;P02oomi0005ooon0?ooN@3oQ_l0ohKo0?oo=`000_oonfX2oooL00;oBOl0
00Kooo]ZoonR0?oonf[o0?mAo`11ool0Yol2oookJP03oomi0?oonf[ooo]Z00;ooo]Z00CoogT0oook
J_ooR@3oohT01?oonfX2oomi0003ok?o0?ooN@3oogT000?oogT000Goob`0oomi0?ooN@3oogT0o`3m
o`03oomi000;oonP0?ooN@3oogT0ooo90?oo@`3ooo]Zo`3boooonf[o0?ncool0:ol0okH00_oonfX0
0oo00?oooo]Zool0X`02oookJP07ool0QOoonf[o2_l0oomk0?oonf[oaOl0oon<0003ooo9000:ojGo
0?oob@3oolT0ooo90?oonf[oo`0koookJ_l0og[ooo]Zool0cP;ooo]Z1?ooN@001ooo2P3ooo]Zoook
J_oonf[oo`3loomi0?ood`002_ooN@03oookJP03o`3oO?oonf[ooo]Z00Cooo]Z00So00;ooookJ_oo
nf[ooo]Zoml0oooonf[o02goooGo00Cooo]Z00Cooi`0oookJ_oonf[o09Wo0_oonfX01Ol0003oofH0
o`000?l0003o0?l001Kooo]Z00?ooc40oookJ_oonfX0oooonfX7oookJP03oa[o0?oonf[ooh<000;o
;?l00_oonfX2o`18o`Wooo]Z00Goo`2coookJ_l0G?oooo]ZoomL0006oookJP03okko0?oonf[ooo]Z
00Cooo]Z00CoLOl0o`06oooonf[o0?mH1_oonfX00ol0omGooo]ZoookJP02oookJP03o`0Cool0Y?oo
0?nV00Gooo]Z00?ookL0oookJ_oonfX00_oonfX00ol0D_oooo]Zo`3o;P03oookJP04ooon0?mGo`3o
Q_l0oolg00?ooo]Z00?oom`0odWo0?m9o`000_oonfX01?ooXP3ooo]Zo`3oDOl0Yol3oookJP05om`0
oooonf[ooo]ZoookJ_ooAP000_oonfX00oooR@3ooo]ZoookJP02oookJP04o`3omooonf[o/ol0o`3o
]`;ooo]Z00?o0>Goo`3ohOoonfX00_lBo`02oookJP0?o`3mool0ojkooo]Zool0XOooX03o03Oooook
J_oo@`3ooo]Zo`3boooonf[o0?nco`3Eoooo02_o0?nf00;ooo]Z00Go`03ooookJ_oo0:?ooo]Zool0
Q@02oookJP04o`[o0?ooN`3ooo]Zoon<00?ooo]Z00_oYOl0oookJ_oonf[o_ol0oookJ_oo03_ooo]Z
o`3oN_oonf[oo`3>o`3ohP03oookJP03o`2<oooonf[oo`X000?ooo]Z00Coo`3loookJ_ood`3o0?nI
1_oonfX00oooB03ooo]ZoookJP03oookJP03o`3oO?oonf[ooo]Z00Gooo]Z00Oo00;ooookJ_oonf[o
E_l0oml0ool0;OoomOl000Cooo]Z00Cooi`0oookJ_oonf[o09Wo0_oonfX01Ol0003oofH0o`000?l0
003o0?l001Oooo]Z00?ooc40oookJ_oonfX0g?oonfX002cooo]Z00Co6_l0oon30?ooP`3o;?l00_oo
nfX2o`18o`03o`3o`Ooonf[ooo]Z00Gooo]Z0_oo0;<3ooo90003oomL0?oo;P3ooo]Z00Gooo]Z00?o
iOl0oookJ_oonfX00ooonfX01?mao`3o00KooookJ_l0oeP6oookJP03o`3oeOoonf[ooo]Z00;ooo]Z
00?o01?oo`2Tool0ojH01_oonfX00ooo]`3ooo]ZoookJP02oookJP04o`1Boooonf[o0?l^oomi00;o
ooh000CoogT0ohKo0?ooN@3oocL00_oonfX00ooog03ooo]ZodWo0002oookJP05oonR0?oonf[o0?mA
o`11ool0Yol00_oonfX00ooL0?ooogT0oookJP02oookJP03oomi0?oonf[oohT000Gooo]Z00?oogT0
ok?o0?nco`001OooN@001Ooo;03oogT0o`0]ooooN@3o0?go00?oogT000Gooj00oomi0?oob@3ooo]Z
oom30002o`3bo`09oookJ_l0ok?oo`0[o`3o]_ooN@3ooo]Zol00oooonf[oogT000;ooo]Z00Ooo`25
oookJ_l:o`3oog/0oookJ_o5o`3ooh`000?oolT000_oYOl0ooo90?oob@3ooo]Zoomi0?oo03_ooo]Z
o`3oN_oonf[o0?oRool0cP02oookJP?oogT000Ooo`X0oookJ_oonf[ooo]Zool0o?ooN@3oom<000?o
ogT000?ooo]Zoomi0?ooN@001?ooN@04oookJP03o`3oO?oonf[ooo]Z00Cooo]Z00So00;ooookJ_oo
nf[ooo]Zoml0ool06_oo02goooGo00Cooo]Z00?ooi`0oookJ_l0VOl00ooonfX01?ooIP3o0000o`00
0?l0o`0GoookJP03oola0?oonf[ooo]Z0?oooo]Z1_oonfX01?lJo`3ooh<0oon30?l/o`03oookJP03
o`18ool0ol7ooo]Z00Oooo]Z0_oo0;<2o`1Lo`03oookJ_ooG03ooo]Z00Gooo]Z00?o__l0oookJ_oo
nfX01?oonfX01?mao`3o00KooookJ_l0oeP6oookJP03o`3oeOoonf[ooo]Z00;ooo]Z00?o01?oo`2T
ool0ojH01OoonfX00ooo]`3ooo]ZoookJP02oookJP03o`1Boooonf[o0?l^00;ooo]Z0_oooP000omG
o`3oQ_l0oolg0002oookJP;oom`000SoBOl0oookJ_oonf[ooo]ZoonR0?oonf[o0?mAo`2Wo`?ooo]Z
00Gog03ooookJ_oonf[ooo]Zoom60002oookJP03oon90?oonf[ooo]Z00;ooo]Z00Co0?ogoookJ_nc
o`3o0?ng0_oonfX01Ol0iOoo0?oQoookJ_lBo`3o02go00;ooo]Z00So0?goo`3o[_oo0:7oo`2QoonP
0?l0=ooooo]Zoom300;o0?;o00Gooo]Zo`3o/ol0eOooo`0[o`3o]P02oookJP05ol00oooonf[oo`2S
oookJ_oo08D00_oonfX01?l:o`3oog/0oookJ_ooS003oookJP0;ojGo0?oonf[ooo]Zokoo0?oonf[o
o`0koookJ_l0og[ooo]Zo`2Aoooo0<h00ooonfX00ol0S?ooOP3oool:0003oookJP04ool0o?oonf[o
om<0o`3oV@Kooo]Z00?oodP0oookJ_oonfX01?oonfX00ol0ogcooo]ZoookJP04oookJP08o`02oooo
nf[ooo]ZoookJ_mFo`3og`3oo`0]oooeo`04oookJP03oonL0?oonf[o09Wo00?ooo]Z00CoofH0o`00
0?l0003o0?l06?oonfX00ooo<@3ooo]ZoookJP3LoookJP00:ooonfX00olJo`3ooh<0obco0003oook
JP03o`18ool0ol7ooo]Z00Oooo]Z00Koo`2coookJ_oob@3o06;ooookJ_ooG007oookJP03onGo0?oo
nf[ooo]Z00;ooo]Z0_mao`000ol01_oooo]Zo`3oF005oookJP;o0?oE1?oonfX2o`2To`03o`3oY_oo
nf[ooo]Z00?ooo]Z0_oo]`04oookJP05o`1Boooonf[o0?l^oookJ_oooP000_ooN@000on6o`3oogT0
oolg0002oomi0003oooL0?oonf[oBOl000;ooo]Z00Gooj80oookJ_l0oe7o047oo`2Wo`02oookJP08
om`0ooooN@3oogT0oomi0?oonf[oogT0oookJ_ooR@05oookJP03oomi0?nco`3oogT000GoogT000Go
ob`0oomi0?l0;OooogT0o`3mo`03oomi0006oonP0?ooN@3oolT0oookJ_oo@`3o0?;o0_oonfX01_l0
ok?oo`0[o`3o]_oonf[oogT0ol00o`;ooo]Z00?oogT0oookJ_oo08D00_oonfX01Ol:o`3ooo]ZolGo
0?ooS03ooo]Z00;oolT000?oYOl0ooo90?noo`000_oonfX01_ooN@3oo`0ko`3oN_oonf[o0?oRool0
cP;ooo]Z0oooN@000ooo2P3oogT0oookJP02oookJP03ool0o?ood`3oogT000;oogT00_oonfX5oomi
00Cooo]Z00?o0?mloookJ_oonfX01?oonfX02?l00_oooo]ZoookJ_oonf[og`3ooookJ_l0;OoomOl0
1OoonfX00oooW03ooo]Zo`2Io`03oookJP04oomV0?l0003o0000o`3o01Oooo]Z00?ooc40oookJ_oo
nfX0oooonfX5oookJP04oa[o0?ooP`3ooo]Zobco00?ooo]Z00?o04SooookJ_oonfX01ooonfX01_oo
0;?ooo]Zo`1Lool0H_ooobh0oomL00Kooo]Z00?o__l0oookJ_oonfX00ooonfX2og7o0003o`06ool0
oeSo0?mH00Gooo]Z0_l0omD3oookJP04o`0Cool0Y?oo0?nVo`3oYPGooo]Z00?ookL0oookJ_oonfX0
0_oonfX00ol0D_oooo]Zo`3o;P02oookJP05ooon0?oonf[oEol0ohKo0?oo=`000_oonfX00ooog03o
oo]ZodWo0003oookJP04oonR0?oonf[o0?mAo`2Wo`?ooo]Z00Kog03ooookJ_oonf[ooo]Zoom60?oo
nfX2oon900Cooo]Z00Co0?ogoookJ_nco`3o0?ng0_oonfX01Ol0iOoo0?oQoookJ_lBo`3o02go00;o
oo]Z00Wo0?goo`3o[_oo0:7ooo]ZoonP0?l0=ooooo]Zoom30?l0l_l00_oonfX01?l0ok?o0=Goool0
:ol0okH2oookJP05ol00oooonf[oo`2SoookJ_oo08D00_oonfX01?l:o`3oog/0oookJ_ooS003oook
JP04ojGo0?oonf[ooo]Zokoo00;ooo]Z00Goo`0ko`3oN_oonf[o097oool0cP03oookJP03o`2<oomn
0?ooo`X000Cooo]Z00?oo`3loooC0?l0oiT01_oonfX00oooB03ooo]ZoookJP04oookJP03o`3oO?oo
nf[ooo]Z00Gooo]Z00Oo00;ooookJ_oonf[oE_l0oml0ool0;OoomOl000Gooo]Z00?ooi`0oookJ_l0
VOl00ooonfX01?ooIP3o0000o`000?l0o`0HoookJP03oola0?oonf[ooo]Z0=cooo]Z000ZoookJP03
oa[o0?ooP`3o;?l000?ooo]Z00?o04Soo`3o`OoonfX01ooonfX01?oo0;?ooo]Zooo90?l0H_l2oomL
0003oookJ_oUo`3ooo]Z00?ooo]Z0_oUo`04oookJP03og7o0?l01_oo00Ko00;o0?mH1OoonfX00ol0
omGooo]ZoookJP03oookJP03o`2Toooonf[o0?nV00Gooo]Z00?ookL0oookJ_oonfX00_oonfX2o`1B
o`04oookJ_l0obkooo]Zooon00;oogT000?oQ_l0oolg0?oo=`000_ooN@000ooog03oogT0odWo0002
oookJP05oonR0?l0oe7o0?mAo`11ool0Yol00_oonfX00ooL0?ooogT0oomi0003oomi0003oookJ_oo
R@3ooo]Z00Cooo]Z00?o0?ogok?o0?l02?l01oooN@02oookJP0:o`3mooooN@3oogT0oomi0?ooX03o
oo]Zo`0gool02?oood<0o`3bo`;ooo]Z00Ko0?ncool0:ol0okKooo]Zoomi0?o00?l3oomi0009oook
J_oo08Gooo]ZoookJ_l:o`3oog/0olGo0?ooS03ooo]Z00;oolT000_oYOl0ooo90?oonf[o_ol0oook
J_ooN@3oo`0koomi0?l0og[oogT0ool0cP03oookJP;oogT000Ooo`X0oomi0?ooN@3oogT0oookJ_oo
0?coom<000?oogT00_oonfX5oomi0005ooo90?oonf[ooo]ZoookJ_l0og`01_oonfX00ol00_oooo]Z
oookJP02oookJP04oml0ool0;OoomOl0oookJP;oolT00_oonfX00oooW03ooo]Zo`2Io`04oookJP04
oomV0?l0003o0000o`3o01Oooo]Z00?ooc40oookJ_oonfX0oooonfX4oookJP04oa[o0?ooP`3o;?l0
obco00?ooo]Z00?o04SooookJ_oonfX01ooonfX01?oo0;?ooo]Zo`1Lool0H_l2oomL00Gooo]Z0_nn
o`05oookJP04og7o0?l01_oo00Koo`3oF0Kooo]Z00?o0?oEoookJ_oonfX00_oonfX00ol04ooo0:Co
o`3oYP06oookJP04oong0?oonf[ooo]ZoookJP;o05;o00Wooo]Zo`3o;_oonf[ooo]Zooon0?oonf[o
Eol0ohKo0?oo=`000_oonfX00ooog03ooo]ZodWo0002oookJP05oom<0?ooXP3o0?mAo`3oDOl0Yol0
0ooonfX01ooL0?oooo]ZoookJ_oonf[oodH0oookJ_ooR@001OoonfX01?l0ooOooo]Zok?o0?l0okL2
oookJP;o0?oQ00?ooo]Zoa;o0?l0;Ol00_oonfX02Ol0oOoo0?n^ool0XOoonf[ooj00o`0goooonf[o
od<0o`3bo`02oookJP04o`3o/ol0eOooo`0[o`3o]P;ooo]Z00Go`03ooookJ_oo0:?ooo]Zool0Q@02
oookJP04o`[o0?oonf[oog/0oon<00?ooo]Z00_oYOl0oookJ_oonf[ooo]Zokoo0?oonf[oo`0koook
J_l0og[o097oool0cP03oookJP03o`2<oomn0?ooo`X000Cooo]Z00Coo`3loooC0?oonf[o0?nI1_oo
nfX00oooB03ooo]ZoookJP03oookJP03o`3oO?oonf[ooo]Z00Gooo]Z00So00;ooookJ_oonf[ooo]Z
oml0ool06_oo02goooGo00Cooo]Z00?ooi`0oookJ_l0VOl01?oonfX01?ooIP3o0000o`000?l0o`0H
oookJP03oola0?oonf[ooo]Z0=cooo]Z000ZoookJP04oon30?l/o`3ooo]ZoookJP;o04So00?oolT0
oookJ_oonfX01_oonfX01_oo0;?ooo]Zooo90?l0H_oooe`0ool^00;ooo]Z00GoiOl0oookJ_oonf[o
oo]ZonGo0005oookJP04og7o0?l01_oooo]Zo`3oF0Kooo]Z00?o0?oEoookJ_oonfX00ooonfX00ol0
Y?oo0?nVo`3oYP05oookJP03oong0?oonf[ooo]Z00;ooo]Z00Ko05;ooookJ_l0obko0?l^oookJ_oo
oP02oomi0004ohKo0?oo=`3oogT0oomi00;oom`000?ooo]ZodWo0?oonfX00_ooXP001?l0oe7ooo]Z
o`11ool0Yol2oookJP03om`0oooonf[oogT000GoogT01OoonfX00ol0ooOo/ol0o`08o`08oomi0003
oookJ_l0oOooogT000;oogT000Kooj00oookJ_l0=ooo00Sooom30?l0l_l2oookJP06o`3o/ooo02_o
0?nfoookJ_ooN@3o`03o1?ooN@001ooo08Gooo]ZoookJ_l:o`3oog/0olGo0?ooS0000_oonfX01Ooo
b@3oogT0oomi0?oonf[o_ol000;ooo]Z00Koo`0koomi0?l0og[oogT0ool0c_ooN@02oookJP03oomi
0?mn0?ooo`X000GoogT000?oom<0oomi0?ooN@001?oonfX3oomi0006oookJ_oob@3oolT0ooo90?oo
nf[o0?ml1ooonfX02Ol00_oooo]ZoookJ_oonf[og`3oo`0Jool0;OoomOl0oookJP03ooo90004oook
J_ooW03ooo]Zo`2Io`?ooo]Z00GoofH0o`000?l0003o0?l0o`00000HoookJP03oola0?oonf[ooo]Z
0?oooo]Z0ooonfX00oooP`3o;?l0oookJP02oookJP;o04So2OoonfX01Ooo0;?o05coo`1Loooonf[o
oe`000Kooo]Z00?o__l0oookJ_oonfX01?oonfX01?mao`3o00KooookJ_l0oeP6oookJP03o`3oeOoo
nf[ooo]Z00;ooo]Z00?o01?oo`2Tool0ojH01OoonfX2oong00?ooo]Z00Co05;ooookJ_l0obko0?l^
0_oonfX01OoooP3oEol0oeOo0?n6o`3oocL000;ooo]Z00?oom`0oookJ_m9o`000_oonfX2oonR0003
o`3oDOl0@Ooo0:Oo00?ooo]Z00Oog03ooookJ_oonf[ooo]Zoom60?oonf[oohT000Gooo]Z00Co0?og
oookJ_nco`3o0?ng0_oonfX01Ol0on7ooo]ZoookJ_lBo`3o02go00;ooo]Z00Wo0?goo`3o[_oo0:7o
oo]ZoonP0?l0=ooooo]Zoom30?l0l_l00_oonfX01?l0ok?o0=Goool0:ol0okH2oookJP05ol00oooo
nf[oo`2SoookJ_oo08D00_oonfX01?l:o`3ooo]Zoomk0?ooS003oookJP0<ojGo0?oonf[ooo]Zoook
J_noo`3ooo]Zool0>ooonf[o0?mjo`2Aoooo0<ko0?oR0_oonfX00ol0S?ooOP3oool:0004oookJP04
ool0o?ood`3ooo]Zo`3oV@Kooo]Z00?oodP0oookJ_oonfX00ooonfX00ol0ogcooo]ZoookJP06oook
JP08o`02oooonf[ooo]Zoml0oooonf[o01[oo`0]oooeo`04oookJP03oonL0?oonf[o09Wo00?ooo]Z
00GoofH0oj@0ool0003o0?l0o`00000IoookJP03oola0?oonf[ooo]Z0=_ooo]Z000ZoookJP05obco
0?oonf[ooo]Zo`18oooob@002?oonfX2ool0/`;oolT000?ooo]ZoomL0?oo;P000_oonfX3onGo0003
oookJ_oUo`3ooo]Z00Cooo]Z00CoLOl0o`06oooonf[o0?mH1_oonfX00ol0omGooo]ZoookJP02oook
JP03o`0Cool0Y?oo0?nV00Kooo]Z00?ookL0oookJ_oonfX00_oonfX00ol0D_oooo]Zo`3o;P02oook
JP05ooon0?ooN@3oogT0ohKo0?oo=`000_ooN@002?oog03ooo]ZoookJ_m9o`3ooo]ZoonR0?ooC03o
0?mA0_l0@Ol01Ol0Yooooo]ZoookJ_oL0?oooo]Z00SoogT00ooonfX00ol0ooOo/ol0o`3o]`09oomi
000;o`3mooooN@3oogT0ool0XOooX03ooo]Zo`0gool02?oood<0o`3boooonfX00_l0ok<01Ooo02_o
0?nfoookJ_oonf[o`03o00CoogT000Ooo`25oomi0?oonf[o2_l0oomk0?o5o`3ooh`000;ooo]Z00?o
olT0ojGo0?ooN@000_ooN@02oookJP05ool0>oooN@3o0?mjoomi0?oo0<h00oooN@001?oonf[o08co
oomi0?oo2P05oomi0003oooC0?ooN@3ooo]Z00?ooo]Z0oooN@000ooonf[oolT0ooo90003ooo90003
o`3oO?oonf[ooo]Z00Cooo]Z00So00;ooookJ_oonf[ooo]Zoml0ool06_oo02goooGo00;ooo]Z1Ooo
b@000ol0VOooolT0ooo90002oookJP05oomV0?l0003o0000o`3o0?l000006?oonfX00ooo<@3ooo]Z
oookJP3ooookJP?ooo]Z00Go;?l0oookJ_oonf[ooo]Zo`18o`09oookJP;oo`2c00Co05coo`1Roooo
nf[ooe`01_oonfX00onno`3ooo]ZoookJP04oookJP04og7o0?l01_oooo]Zo`3oF0Kooo]Z00?o0?oE
oookJ_oonfX00_oonfX00ol04ooo0:Coo`3oYP05oookJP03oong0?oonf[ooo]Z00;ooo]Z00?o05;o
oookJ_l0obh00ooonfX00ooooP3oEol0oookJP02oolg00;ooo]Z00?oom`0oookJ_m9o`000_oonfX0
1OooXP3ooo]Zo`3oDOl0@Ooo0:Oo00?ooo]Z00Oog03ooookJ_oonf[ooo]Zoom60?oonf[oohT000Go
oo]Z00Co0?ogoookJ_nco`3o0?ng0_oonfX01Ol0on7ooo]ZoookJ_lBo`3o02go00;ooo]Z00Wo0?go
o`3o[_oo0:7ooo]ZoonP0?l0=ooooo]Zoom30?l0l_l00_oonfX01?l0ok?o0=Goool0:ol0okH2oook
JP05ol00oooonf[oo`2SoookJ_oo08D00_oonfX01?l:o`3ooo]Zoomk0?ooS003oookJP0<ojGo0?oo
nf[ooo]ZoookJ_noo`3ooo]Zool0>ooonf[o0?mjo`2Aoooo0<ko0?oR0ooonfX00ol0S?oooo]Zool:
0003oookJP04ool0o?oonf[oom<0o`3oV@Kooo]Z00?oodP0oookJ_oonfX01?oonfX00ol0ogcooo]Z
oookJP05oookJP08o`02oooonf[ooo]ZoookJ_oO0?oo01[oo`0]oooeo`04oookJP03oonL0?oonf[o
09Wo00Cooo]Z00GoofH0o`000?l0003o0?l0o`00000IoookJP03oola0?oonf[ooo]Z0=_ooo]Z000/
oookJP03o`18oooob@3ooo]Z00Oooo]Z00Coo`2coookJ_oob@3o06;o0_ooG003oookJPGoiOl01?oo
nfX2og7o0003o`06oooonf[o0?mH00Kooo]Z00?o0?oEoookJ_oonfX00_oonfX2o`2To`03o`3oY_oo
nf[ooo]Z00Cooo]Z00?ookL0oookJ_oonfX00_oonfX00ol0D_oooo]Zo`3o;P02oookJP09ooon0?oo
N@3oogT0ohKo0?oo=`3oogT0oookJ_oog03ooo]Z00;oBOl000Oooo]ZoonR0?ooC03o0?mAo`11oooo
nf[o0:Oo00;ooo]Z00?og03ooookJ_oonfX02OooN@001?oonf[o0?ogok?o0?l0okL2oomi0003o`3o
hOooN@3oogT000CoogT000oo0?gooomi0?ooN@3oo`2QoonP0?oonf[o03Ooo`08oooo@`3o0?;ooook
J_l0ok?ooo]Zool0:ol0okH00_oonfX00oo00?ooogT0oomi0002oomi000;ool0QOooN@3oogT0oomi
0?ooN`3oaOl0oookJ_ooS03ooo]Zooo90?nUo`001oooN@000ol0og[oogT0ool0cP04oomi0004o`2<
oomn0?ooolT0ooo900CoogT000?oom<0oomi0?ooN@001?oonfX2oomi00;ooo]Z1_oob@05oookJP03
o`02oooonf[ooo]Z00;ooo]Z00Gog`3oo`0Jool0;OoomOl0oookJP0<ooo900;o000000?o0?l0o`00
0?oonfX05ooonfX00ooo<@3ooo]ZoookJP3ooookJPKooo]Z00?o04SooookJ_oonfX01ooonfX01?oo
0;?ooo]Zo`1Lool0H_l2oomL00Kooo]Z00?o__l0oookJ_oonfX00ooonfX2og7o0003o`06oooonf[o
0?mH00Gooo]Z0_l0omD4oookJP03o`2Tool0ojKo0?nV00Gooo]Z00?ookL0oookJ_oonfX00_oonfX0
0ol0D_oooo]Zo`3o;P03oookJP04ooon0?mGo`3ooo]Zoolg00?ooo]Z00?oom`0oookJ_m9o`000_oo
nfX01OooXP3ooo]Zo`3oDOl0@Ooo0:Oo00?ooo]Z00Oog03ooookJ_oonf[ooo]Zoom60?oonf[oohT0
00Gooo]Z00Oo0?ogoookJ_nco`3ok`3ooookJ_l05ooo0?oQ00;ooo]Z00go4_l0o`0]oooonf[ooo]Z
o`3mool0ojkoo`2QoookJ_ooX03o03OooookJ_oo@`3o0?;o00;ooo]Z00Co0?nco`3Eoooo02_o0?nf
0_oonfX01Oo00?oooo]Zool0Xooonf[oo`2500;ooo]Z00Go2_l0oookJ_ooN`3oaOl0oon<0002oook
JP0<o`3o9?nUo`3ooo]ZoookJ_noo`3ooo]Zool0>ooonf[o0?mjo`2Aoooo0<ko0?oR0ooonfX00ol0
S?ooOP3oool:0004oookJP03ool0o?ood`3o0?nI00Oooo]Z00?oodP0oookJ_oonfX00ooonfX00ol0
ogcooo]ZoookJP05oookJP09o`02oooonf[ooo]ZoookJ_oO0?oo01[ooookJ_l0;OoomOl000Cooo]Z
00?ooi`0oookJ_l0VOl01?oonfX01OooIP3o0000o`000?l0o`3o000001Wooo]Z00?ooc40oookJ_oo
nfX0fooonfX002_ooo]Z00?o04Soooo90?oonfX01ooonfX01_oo0;?ooo]Zooo90?l0H_oooe`0ool^
00?ooo]Z1ooUo`02oookJP03og7o0?oonf[o00Ko00;o0?mH1OoonfX2o`3oe@Cooo]Z00?o0:Cooook
J_l0ojH01_oonfX00ooo]`3ooo]ZoookJP02oookJP04o`1Boooonf[o0?l^oookJP;oooh00_ooN@00
1on6o`3oocL0oookJ_oonf[oom`0oookJ_m9o`000_oonfX01?ooXP3ooo]Zo`3oDOl0@Ol2o`2Wo`03
oookJ_oL0?oog03o00;ooo]Z2?ooN@02oookJP07o`3omonco`3o0?ngoomi0?l05ooo0?oQo`3Uo`05
oomi000?o`3mooooN@3ooo]Zool0XOooX03ooo]Zo`0gool02?oood<0o`3boooonf[o0?ncoookJ_oo
02_o0?nf00;ooo]Z00?o`03ooomi0?ooN@000_ooN@002?oo08GoogT0oomi0?l:o`3oog/0olGo0?oo
nf[ooh`00_oonfX00onUo`3ooo]Zoomi0005oomi0003o`3oN_ooN@3oo`3>00CoogT000?o08coogh0
oooo2P000ooob@02oomi0003oooC0?ooN@3o0?nI00Gooo]Z00CoogT0oookJ_oonf[ooo]Z1ooob@04
oookJP08o`02oooonf[ooo]ZoookJ_oO0?oo01[oo`0]oooeo`02oookJPkoolT000?o0?l0o`000?oo
nfX06?oonfX00ooo<@3ooo]ZoookJP3ooookJP?ooo]Z0_l0B?l9oookJP05ool0/ooonf[o05coo`1R
ooooG0001_oonfX2okko00Gooo]Z00?oLOl0o`06ool01_l00_l0oeP5oookJP03o`3oeOoonf[ooo]Z
00?ooo]Z00?o0:Coo`3oY_oonfX01OoonfX00ooo]`3ooo]ZoookJP02oookJP03o`1Boooonf[o0?l^
00;ooo]Z0_oooP000omGo`3ooo]Zoolg0002oookJP;oom`000Oooo]ZodWo0?oonf[ooo]ZoonR0?oo
nf[o0?mA00;o0:Oo0_oonfX2om`0o`?ooo]Z00?oodH0oookJ_ooR@001OoonfX01ol0ooOooo]Zok?o
0?o_0?oooo]Zo`0Gool0on400_oonfX03OlBo`3o02gooookJ_oonf[o0?goo`3o[_oo0:7ooo]ZoonP
0?l0=ooooo]Zoom30?l0l_l00_oonfX01?l0ok?o0=Goool0:ol0okH2oookJP05ol00oooonf[oo`2S
oookJ_oo08D00_oonfX01Ol:o`3ooo]Zoomk0?o5o`3ooh`000?ooo]Z00CoYOl0oookJ_oonf[o_ol0
0_oonfX01Ooo03_o0?mjo`2Aoooonf[oo`3>00?ooo]Z00?o08coogh0oooo2P001?oonfX01?oo0?co
om<0oookJ_l0oiT6oookJP03oom80?oonf[ooo]Z00?ooo]Z00?o0?mloookJ_oonfX01OoonfX02Ol0
0_oooo]ZoookJ_oonf[og`3ooeKo0?l06_oo02goooGo0004oookJP03oonL0?oonf[o09Wo00Cooo]Z
00KoofH0oj@0ool0003o0000o`3o0?l0000IoookJP03oola0?oonf[ooo]Z0=_ooo]Z000ZoookJP03
o`18oooob@3ooo]Z00Oooo]Z00Koo`2coookJ_oob@3o06;ooomL0?oo;P04oookJPSoiOl000CoLOl0
o`06ool01_oo0?mH1_oonfX00ol0omGooo]ZoookJP03oookJP03o`2Tool0ojKo0?nV00Gooo]Z0_oo
b@04oookJP06o`1Boooonf[o0?l^oookJ_oooP3ooo]Z0_ooN@02oolg0005oookJ_oog03oom`0oook
J_m9o`000_oonfX01OooXP3ooo]Zo`3oDOl0@Ooo0:Oo00;ooo]Z00Cog03ooookJ_oonf[ooo]Z1ooo
N@03oookJP;o/ol000Go0?ngoookJ_l05ooo0?oQo`3Uo`05oomi000?o`3mooooN@3ooo]Zool0XOoo
X03ooo]Zo`0gool02?oood<0o`3boooonf[o0?ncoookJ_oo02_o0?nf00;ooo]Z00?o`03ooomi0?oo
N@000_ooN@002?oo08GoogT0oomi0?l:o`3oog/0olGo0?oonf[ooh`00_oonfX00onUo`3ooo]Zoomi
0007oomi0003ool0c_ooN@3oogT000;oogT000?o08coogh0oooo2P001Ooob@000oood`3oogT0o`3o
V@05oookJP04oomi0?oonf[ooo]ZoookJPWoolT00_oonfX00ol00_oooo]ZoookJP02oookJP04oml0
oooonf[o02goooGo00;ooo]Z3Ooob@000ol0o`3oolT0o`00000IoookJP03oola0?oonf[ooo]Z0?oo
oo]Z0_oonfX00ol0B?oo0?o1oookJP07oookJP;oo`2c0_l0G?l00ooonf[ooe`0oookJP05oookJP03
okko0?oonf[ooo]Z00Cooo]Z00CoLOl0o`06oooonf[o0?mH1_oonfX00ol0omGooo]ZoookJP03oook
JP03o`2Tool0ojKooo]Z00Cooo]Z0_oo]`04oookJP03o`1Boooonf[o0?l^00;ooo]Z00Goooh0oook
J_mGo`3ooo]Zoolg0002oookJP04oooL0?oonf[oBOl0odWo00;ooo]Z00Cooj80oookJ_l0oe7o0:Oo
0ooonfX00ooL0?oooo]ZoookJP02oookJP03oom60?oonf[oohT000Gooo]Z00_o0?ogok?o0?nco`3o
k`3ooookJ_l05ooo0?oQoookJ_oo;03o4_l0o`0]o`02oookJP09o`3moooonf[oo`2QoookJ_ooX03o
03OooookJ_oo@`3o0?;o00;ooo]Z00Co0?nco`3Eoooo02_o0?nf0_oonfX01Oo00?oooo]Zool0Xooo
nf[oo`2500;ooo]Z00Go2_l0oookJ_ooN`3oaOl0oon<0003oookJP04ojGo0?oonf[ooo]Zokoo00;o
oo]Z00Goo`0ko`3oN_l0TOoooo]Zool0cP03oookJP03o`2<oomn0?ooo`X000Cooo]Z00Coo`3loooC
0?oonf[o0?nI1_oonfX00oooB03ooo]ZoookJP03oookJP03o`3oO?oonf[ooo]Z00Kooo]Z00So00;o
oookJ_oonf[ooo]Zoml0ool06_oo02goooGo00Gooo]Z00?ooi`0oookJ_l0VOl01?oonfX01?ooIP3o
oo]Zo`000?l0o`02o`0001[ooo]Z00?ooc40oookJ_oonfX0f_oonfX002[ooo]Z00?oolT0oookJ_oo
nfX01OoonfX2ool0/`;oolT00_ooG005oookJPSoiOl000CoLOl0onGo0?oonf[o0?mH1_oonfX00ol0
omGooo]ZoookJP03oookJP03o`2Tool0ojKooo]Z00Gooo]Z00?oolT0oookJ_oonfX00_oonfX2o`1B
o`08oookJ_l0obkooo]Zooon0?mGo`3oogT0ohKo0?oo=`02oookJP04oooL0?oonf[ooo]ZodWo00;o
oo]Z00Gooj80oookJ_l0oe7o047oo`2Wo`02oookJP03om`0oooonf[ooo]Z00;ooo]Z1OooN@03oook
JP08o`3omonco`3ok`3oo`3o]ooonf[o01Ooo`3ohOl0iOl5oomi000?o`3moooonf[ooo]Zool0XOoo
X03ooo]Zo`0gool02?oood<0o`3boooonf[o0?ncoookJ_oo02_o0?nf00;ooo]Z00?o`03ooomi0?oo
N@000_ooN@002?oo08GoogT0oookJ_l:o`3oog/0olGo0?oonf[ooh`00_oonfX00onUo`3ooo]Zoook
JP0;oomi0005oookJ_l0S?ooOP3oool:0?oonfX01_oob@000ol0oiWooo]ZoookJP04oookJP04oom8
0?oonf[ooo]ZoookJPOoolT01?oonfX02?l00_oooo]ZoookJ_oonf[og`3oo`0Jool0;OoomOl00ooo
nfX=ooo90004o`3o0?oob@3o0000o`0001Sooo]Z00?ooc40oookJ_oonfX0oooonfX2oookJP03o`3o
`Ooonf[ooo]Z00Kooo]Z00Coo`2coookJ_l0G?oo06;o0_ooG006oookJP03okko0?oonf[ooo]Z00Co
oo]Z00CoLOl0o`06oooonf[o0?mH1_oonfX00ol0omGooo]ZoookJP02oookJP03o`0Cool0ojKo0?nV
00Gooo]Z00?ookL0oookJ_oonfX00_oonfX2o`1Bo`05oookJ_l0obkooo]ZoookJ_oooP000_mGo`00
1on6o`3oocL0oookJ_oonf[oom`0oookJ_m9o`000_oonfX01OooC03ooj80o`3oDOl0oe7o0:Oo00?o
oo]Z00?og03ooookJ_oonfX00_oonfX00oooAP3oohT0oon90004oookJP;o0?og00_o/ol0o`3o]ooo
nf[ooo]Zo`0Gool0on7ooo]Zool/0?lBo`3o02gooookJP02o`3mo`08oookJ_oo0:7ooo]ZoonP0?l0
=ooooo]Zoom30?l0l_l2oookJP04o`3o/ol0eOooo`0[o`3o]P;ooo]Z00Go`03ooookJ_oo0:?ooo]Z
ool0Q@02oookJP05o`[o0?oonf[oog/0olGo0?ooS0000ooonfX01?nUo`3ooo]ZoookJ_noo`02oook
JP05ool0>ooonf[o0?mjoookJ_oo0<h00ooonfX00ol0S?ooOP3oool:0004oookJP04ool0o?ood`3o
oo]Zo`3oV@Oooo]Z00?oodP0oookJ_oonfX00ooonfX00ol0ogcooo]ZoookJP05oookJP09o`02oooo
nf[ooo]ZoookJ_oO0?ooE_l0o`0Jool0;OoomOl000Gooo]Z00?ooi`0oookJ_l0VOl00ooonfX01Ooo
IP3oY03ooookJ_l0003o0?l000?o00006OoonfX00ooo<@3ooo]ZoookJP3JoookJP00<OoonfX01_oo
0;?ooo]Zooo90?l0H_oooe`0ool^00Gooo]Z1ooUo`02og7o0003o`06oooonf[o0?mH00Kooo]Z00?o
0?oEoookJ_oonfX00_oonfX00ol04ooo0:Coo`3oYP06oookJP03ooo90?oonf[ooo]Z00;ooo]Z00[o
05;ooookJ_l0obko0?l^oookJ_oooP3oEol0oookJ_n6o`3oocL00_oonfX01Ooog03ooo]ZoookJ_m9
o`3ooo]Z00;ooj8000Cooo]Zo`3oDOl0@Ooo0:Oo0_oonfX00ooL0?oooo]ZoookJP02oookJPCoogT0
1?oonfX02Ol0ooOo/ol0o`08ool0okOooo]Zo`0Gool0on7o0>Goool/0004oomi000?o`3moooonf[o
oo]Zool0XOooX03ooo]Zo`0gool02?oood<0o`3boooonf[o0?ncoookJ_oo02_o0?nf00?ooo]Z00Go
`03ooomi0?ooN@3oogT0ool0Q@02oookJP05o`[o0?oonf[oaOl0oookJ_ooS0000_oonfX00onUo`3o
oo]ZoookJP0;oomi0005oookJ_l0S?ooOP3ooookJ_oo2P002?oob@05oookJP04oom80?oonf[ooo]Z
oookJPOoolT01?oonfX02Ol00_oooo]ZoookJ_oonf[oE_l0oml0oooonf[o02goooGo0002oookJPko
olT000?o0?l0o`000?l000006_oonfX00ooo<@3ooo]ZoookJP3ooookJPSooo]Z0_oo0;<01Ooonf[o
05coo`1RooooG03oobh000Kooo]Z00?o__l0oookJ_oonfX00ooonfX2og7o0003o`06oooonf[o0?mH
00Gooo]Z0_l0omD4oookJP03o`0Cool0ojKooo]Z00Gooo]Z00?ookL0oookJ_oonfX00_oonfX01?l0
D_oooo]Zo`3o;_l0obh2oookJP05ooon0?mGo`3ooo]ZohKo0?oo=`000_oonfX00ooog03ooo]ZodWo
0002oookJP;ooj8000?o0?mAo`11ool0Yol00ooonfX00ooL0?oooo]ZoookJP02oookJP03oom60?oo
R@3ooo]Z00Cooo]Z00Co0?ogoookJ_nco`3o0?ng0_oonfX01Ol0iOoo0?oQoookJ_oo;03o4_l000;o
oo]Z00[o0?goo`3o[_oonf[oo`2QoookJ_ooX03o03OooookJ_oo@`3o0?;o0_oonfX01?l0ok?o0=Go
ool0:ol0okH3oookJP04ol00oooo0:?ooo]Zool0Q@;ooo]Z00Go2_l0oookJ_ooN`3oaOl0oon<0003
oookJP04ojGo0?oonf[ooo]Zokoo00;ooo]Z00Koo`0koookJ_l0og[ooo]Zool0c_l0on82oookJP04
o`2<oomn0?oooo]Zool:00?ooo]Z00Coo`3loookJ_ood`3o0?nI1ooonfX00oooB03ooo]ZoookJP03
oookJP03o`3oO?oonf[ooo]Z00Gooo]Z00?o00;ooookJ_oonfX00_oonfX01?oO0?oo01[oo`0]oooe
o`05oookJP03oonL0?oonf[o09Wo00Cooo]Z00GoofH0oj@0oooonf[o0000o`3o0002o`0001[ooo]Z
00?ooc40oookJ_oonfX0f_oonfX002gooo]Z00WoolT0oookJ_oonf[oo`2coookJ_oob@3o06;ooomL
0?oo;P001OoonfX7onGo0005og7o0?oonf[o00KooookJ_l0oeP01_oonfX00ol0omGooo]ZoookJP02
oookJP03o`0Cool0Y?oo0?nV00Kooo]Z00?oolT0oookJ_oonfX00_oonfX00ol0D_oooo]Zo`3o;P02
oookJP05ooon0?mGo`3ooo]ZohKo0?oo=`000_oonfX01ooog03ooo]ZodWo0?m9o`3ooo]ZoonR0?oo
C0000_l0oe401Ol0@Ooo0:OooookJ_oonf[og03o00Gooo]Z0oooN@04oookJP09o`3omonco`3o00So
o`3o]ooonf[o01Ooo`3ohOoonf[oob`000CoogT000oo0?gooookJ_oonf[oo`2QoonP0?n30?oo03Oo
o`08oooo@`3o0?;ooookJ_l0ok?ooo]Zool0:ol0okH00ooonfX01Oo00?ooogT0oomi0?ooN@3oo`25
00;ooo]Z00Go2_l0oookJ_o5o`3ooo]Zoon<0002oookJP04ojGo0?oonf[ooo]ZoookJPWoogT00ooo
nfX01?l0S?oooo]Zool:0?oonfX9ooo900?ooo]Z00?oodP0oookJ_oonfX00_oonfX6ooo900Cooo]Z
00?o00;ooookJ_oonfX00_oonfX01?oO0?oo01[oo`0]oooeo`03oookJPKoolT000?ooo]Zooo90?oo
b@001?oob@001?l0o`3o0000o`000?l0000JoookJP03oola0?oonf[ooo]Z0?oooo]Z1ooonfX01ooo
0;?ooo]Zo`1Lool0G?oo06;ooomL0?oo;P001OoonfX2okko00Gooo]Z00?oLOl0o`06ool01_l00_l0
oeP5oookJP03o`3oeOoonf[ooo]Z00?ooo]Z00?o01?oo`3oY_oonfX01OoonfX00ooo]`3ooo]Zoook
JP02oookJP03o`1Boooonf[o0?l^00?ooo]Z00Goooh0oeOo0?oonf[oQ_l0oolg0002oookJP03oooL
0?oonf[oBOl000;ooo]Z00Gooj80oookJ_l0oe7o047oo`2Wo`03oookJP03om`0oooonf[ooo]Z00;o
oo]Z00?oodH0oon90?oonfX01?oonfX01?l0ooOooo]Zok?o0?l0okL2oookJP05o`3Uool0on7ooo]Z
ool/0?lBo`000_oonfX02_l0oOoo0?n^oookJ_oo0:7ooo]ZoonP0?l0=ooooo]Zoom30?l0l_l2oook
JP04o`3o/ol0eOooo`0[o`3o]P?ooo]Z00Co`03oool0Xooonf[oo`250_oonfX01Ol:o`3ooo]Zoomk
0?o5o`3ooh`000?ooo]Z00CoYOl0oookJ_oonf[o_ol00_oonfX01_oo03_ooo]Zo`3oN_l0TOooo`3>
o`3ohP?ooo]Z00?o08cooookJ_oo2P000ooonfX01Ooo0?cooo]ZoooC0?oonf[o0?nI00Kooo]Z00?o
odP0oookJ_oonfX00ooonfX00ol0ogcooo]ZoookJP05oookJP03o`02oooonf[ooo]Z00;ooo]Z00Go
g`3ooeKo0?l06_oo02goooGo0005oookJP03oonL0?oonf[o09Wo00Cooo]Z00CoofH0oookJ_oonf[o
0?l00ol0000JoookJP03oola0?oonf[ooo]Z0=[ooo]Z000]oookJP;oolT000Koo`2coookJ_oob@3o
06;ooomL0?oo;P06oookJPGoiOl000Cooo]Zog7o0?oonf[o00Ko0_l0oeP5oookJP;o0?oE1?oonfX0
0ol04ooo0:Coo`3oYP06oookJP03ooo90?oonf[ooo]Z00;ooo]Z00?o05;ooookJ_l0obh00_oonfX0
1_oooP3oEol0oookJ_n6o`3oocL0oookJP;oom`000[ooo]ZodWo0?oonf[ooo]ZoonR0?ooC03o0?mA
oookJ_l0@Ooo0:Oo0_oonfX00ooL0?oooo]ZoookJP03oookJP;oogT01OoonfX02_l0ooOo/ol0o`3o
]ol0okOooo]Zo`0Gool0on7ooo]Zool/0?oonfX2oomi000@oookJ_l0oOoooo]ZoookJ_oo0:7ooj00
oh<0ool0=ooo00Sooom30?l0l_oooo]Zo`3o/ooonf[oo`0[o`3o]P?ooo]Z00Go`03ooookJ_ooN@3o
ogT0ool0Q@02oookJP05o`[o0?oonf[oaOl0oookJ_ooS0000_oonfX01?nUo`3ooo]ZoookJ_oonfX7
oomi0003ool0c_ooN@3ooo]Z00;ooo]Z00Go08cooookJ_oo2P3ooo]Zoomi0007ooo900Gooo]Z00?o
odP0oookJ_oonfX00_oonfX5ooo900Gooo]Z00Wo00;ooookJ_oonf[ooo]Zoml0ool06_oooo]Zo`0]
oooeo`000ooonfX5ooo900;ooo]Z1_oob@001?l0o`3o0000o`000?l0000JoookJP03oola0?oonf[o
oo]Z0?oooo]Z1_oonfX01_oo0;?ooo]Zo`1Lool0H_oooo]ZoomL00Kooo]Z00?o__l0oookJ_oonfX0
1?oonfX01?mao`3o00KooookJ_l0oeP6oookJP03o`3oeOoonf[ooo]Z00?ooo]Z00?o01?oo`3oY_oo
nfX01OoonfX00ooo]`3ooo]ZoookJP02oookJP03o`1Boooonf[o0?l^00?ooo]Z00Koooh0oeOo0?oo
nf[oQ_l0oolg0?oonfX2oooL0009oookJ_m9o`3ooo]ZoookJ_ooXP3ooo]Zo`3oDOl0@Ooo0:Oo00?o
oo]Z00?og03ooookJ_oonfX00_oonfX00oooAP3oohT0oookJP04oookJP04o`3omooonf[o/ol0o`3o
]`;ooo]Z00Go0>Goo`3ohOoonf[oob`0oa;o0002oookJP0:o`3mool0ojkooo]Zool0XOoonf[ooj00
o`0goooonf[ood<0o`3bo`;ooo]Z00Co0?nco`3Eoooo02_o0?nf0ooonfX01?o00?ooo`2SoookJ_oo
08D2oookJP05o`[o0?oonf[oog/0olGo0?ooS0000ooonfX01?nUo`3ooo]ZoookJ_noo`02oookJP06
ool0>ooonf[o0?mjo`2Aoooonf[oo`3>0ooonfX00ol0S?ooOP3oool:0003oookJP05ool0o?oonf[o
om<0oookJ_l0oiT01_oonfX00oooB03ooo]ZoookJP04oookJP03o`3oO?oonf[ooo]Z00Gooo]Z00Wo
00;ooookJ_oonf[ooo]Zoml0oomFo`3o01[oo`0]oooeo`001OoonfX01?ooW03ooo]Zo`2IoomK0?l3
oookJP05oomV0?nT0?oooo]ZoookJ_l0o`000ol0000JoookJP03oola0?oonf[ooo]Z0=[ooo]Z000/
oookJPGoolT000?o06;ooomL0?oonfX01_oonfX4onGo00;ooo]Z00CoLOl0o`06ool01_oo0?mH1_oo
nfX00ol0omGooo]ZoookJP03oookJP03o`2Tool0ojKo0?nV00Gooo]Z0_oob@04oookJP04o`1Boooo
nf[o0?l^oookJP;oooh000KoEol0oookJ_n6o`3oocL0oookJ_oog002oookJP07odWo0?oonf[ooo]Z
oonR0?ooC03o0?mAo`11o`02o`2Wo`;ooo]Z00?og03ooookJ_oonfX00_oonfX00oooAP3oogT0oon9
0005oookJP03o`3omonco`3o0?ng00;ooo]Z00Ko01Ooo`3ohOoonf[oob`0oookJ_ooN@02oookJP0?
o`3moooonf[ooo]Zool0XOooX03oP`3oo`0gool02?oood<0o`3boooonf[o0?ncoookJ_ooN@3o0?nf
00?ooo]Z00Go`03ooookJ_ooN@3ooo]Zool0Q@02oookJP05oomi0?oonf[oaOl0oookJ_ooS0000_oo
nfX01OnUo`3ooo]ZoookJ_oonf[o_ol000KoogT000?oo`3>oomi0?oonfX00_oonfX00ol0S?oooo]Z
ool:0002oookJPOoolT01OoonfX00oooB03ooo]ZoookJP02oookJPGoolT01OoonfX00ol00_oooo]Z
oookJP02oookJP04oml0oooonf[o02goooGo00?ooo]Z1Ooob@000ol0VOoooo]Zooo90005ooo90003
oookJ_l0o`3o000000;o00006ooonfX00ooo<@3ooo]ZoookJP3ooookJP?ooo]Z0_oo0;<00ooonf[o
05coo`1Ro`02oomL00Kooo]Z00?o__l0oookJ_oonfX01?oonfX01?mao`3o00KooookJ_l0oeP6oook
JP03o`3oeOoonf[ooo]Z00?ooo]Z0_l0ojH6oookJP03oong0?oonf[ooo]Z00;ooo]Z00?o05;ooook
J_l0obh00_oonfX2ooon0006oeOo0?oonf[oQ_l0oolg0?oonf[oom`00_oonfX01_m9o`3ooo]Zoook
J_ooXP3ooo]Zo`3oD@;o0:Oo0ooonfX01?oL0?oooo]ZoookJ_oonfX2oom60003oon90?oonf[ooo]Z
00?ooo]Z00_o0?ogoookJ_nco`3ok`3ooookJ_l05ooo0>Goo`3ohOoonf[oob`0oa;o0002oookJP0:
o`3mool0ojkooo]Zool0XOoonf[ooj00o`0goooonf[ood<0o`3bo`;ooo]Z00Co0?ncool0:ooo02_o
0?nf0ooonfX01?o00?ooo`2SoookJ_oo08D2oookJP05o`[o0?oonf[oog/0olGo0?ooS0000ooonfX0
1?nUo`3ooo]ZoookJ_noo`02oookJP06ool0>ooonf[o0?mjo`2Aoooonf[oo`3>0ooonfX00ol0S?oo
OP3oool:0003oookJP05ool0o?oonf[oom<0oookJ_l0oiT01_oonfX00oooB03ooo]ZoookJP04oook
JP03o`3oO?oonf[ooo]Z00Gooo]Z00?o00;ooookJ_oonfX00_oonfX01?oO0?oo01[oo`0]oooeo`06
oookJP03oonL0?oonf[o09Wo00Cooo]Z00GoofH0oookJ_oonf[ooo]Zo`3o0003o`0001_ooo]Z00?o
oc40oookJ_oonfX0fOoonfX002_ooo]Z1_oob@000oooG03ooo]ZoookJP05oookJP;oiOl00ooonfX2
og7o0003o`06oooonf[o0?mH00Kooo]Z00?o0?oEoookJ_oonfX00ooonfX00ol0Y?oo0?nVoookJP05
oookJP03ooo90?oonf[ooo]Z00?ooo]Z00So05;ooookJ_l0obkooo]Zooon0?oonf[oEol0oookJP;o
ocL000Gooo]ZoooL0?oonf[ooo]ZodWo0002oookJP05oonR0?ooC03o0?mAo`11ool0Yol00ooonfX0
0ooL0?oooo]ZoookJP02oookJP03oom60?oonf[oohT000Gooo]Z00?o0?ogok?o0?l0okL00_oonfX0
1_l05ooo0?oQoookJ_oo;03o4_l0oomi00;ooo]Z00oo0?gooookJ_oonf[oo`2QoonP0?n30?oo03Oo
o`08oooo@`3o0?;ooookJ_l0ok?ooo]Zoomi0?l0okH00ooonfX01Oo00?oooo]Zoomi0?oonf[oo`25
00;ooo]Z00GoogT0oookJ_o5o`3ooo]Zoon<0002oookJP05ojGo0?l0obCooo]ZoookJ_noo`001?oo
N@000ol0og[o097oool0cP04oookJP03o`2<oooonf[oo`X000?ooo]Z1_oob@05oookJP03oom80?oo
nf[ooo]Z00?ooo]Z0ooob@06oookJP03o`02oooonf[ooo]Z00;ooo]Z00Gog`3oo`0Joooonf[o02go
ooGo0003oookJPCoolT000?o09WooookJ_oonfX01Ooob@000ooonf[o0?l0o`000003o`0001_ooo]Z
00?ooc40oookJ_oonfX0oooonfX2oookJP07ool0/ooonf[ooo]Zo`1Lool0H_oooe`0ool^0006oook
JP03okko0?oonf[ooo]Z00?ooo]Z0_mao`000ol01_oooo]Zo`3oF005oookJP;o0?oE1OoonfX00ol0
ojKooo]ZoookJP05oookJP03oong0?oonf[ooo]Z00;ooo]Z00?o05;ooookJ_l0obh00_oonfX01?oo
oP3ooo]ZoeOo0?oonfX2oolg0008oookJ_oog03ooo]ZoookJ_m9o`3ooo]Zoom<0?ooXP02o`3oD@03
o`2Woooonf[ooo]Z00;ooo]Z00Oog03ooookJ_oonf[ooo]Zoom60?oonf[oohT000Gooo]Z00Wo0?og
oookJ_nco`3ok`3ooookJ_l05ooo0>Goo`3ohOoonfX00_lBo`02oookJP0:o`3mool0ojkooo]Zool0
XOoonf[ooj00o`0goooonf[ood<0o`3bo`;ooo]Z00Co0?ncool0:ooonf[o0?nf0ooonfX01?o00?oo
o`2SoookJ_oo08D2oookJP05o`[o0?oonf[oog/0olGo0?ooS0000ooonfX01?nUo`3ooo]ZoookJ_no
o`02oookJP06ool0>ooonf[o0?mjo`2Aoooonf[oo`3>0ooonfX00ol0S?ooOP3oool:0003oookJP03
ool0o?oonf[oom<000;ooo]Z00?o0?nIoookJ_oonfX01?oonfX00oooB03ooo]ZoookJP03oookJP03
o`3oO?oonf[ooo]Z00Gooo]Z00?o00;ooookJ_oonfX00_oonfX01OoO0?ooE_l0o`0Jool0;OoomOl0
00Gooo]Z00Cooi`0oookJ_l0VOooF`3o0ooonfX01OooIP3oY03ooookJ_oonf[o0?l000Co00006ooo
nfX00ooo<@3ooo]ZoookJP3IoookJP00:_oonfX8ooo900Gooo]Z00?o__l0onGo0?oonfX00ooonfX0
1Omao`3ooo]Zo`06oooonf[o0?mH00Kooo]Z00?o0?oEoookJ_oonfX00_oonfX01?l04ooo0:Coo`3o
Y_oob@05oookJP03ooo90?oonf[ooo]Z00?ooo]Z00Wo05;ooookJ_l0obkooo]Zooon0?oonf[oEol0
ohKo0?oo=`000_oonfX01Ooog03ooo]ZoookJ_m9o`3ooo]Z00;ooj8000Cooo]Zo`3oDOl0@Ooo0:Oo
0_oonfX2om`0o`Cooo]Z00?oodH0oookJ_ooR@001OoonfX00ol0ooOo/ol0o`3o]`02oookJP06o`0G
ool0on7ooo]Zool/0?lBo`3o02go0_oonfX03ol0oOoooo]ZoookJ_oo0:7ooj00oh<0ool0=ooo00So
oomi0?l0l_oooo]Zo`3o/ooonf[oogT0o`3o]P03oookJP05ol00oooonf[oo`2Soomi0?oo08D00_oo
nfX01OooN@3ooo]ZolGo0?oonf[ooh`000;ooo]Z00KoYOl0o`3o9?oonf[ooo]Zokoo0?oonfX3oomi
0003oookJ_l0og[oo`3>00Cooo]Z00?o08cooookJ_oo2P000ooonfX5ooo900Kooo]Z00?oodP0oook
J_oonfX00ooonfX3ooo900Oooo]Z00Wo00;ooookJ_oonf[ooo]ZoeKo0?oO0?oooo]Zo`0]oooeo`00
1?oonfX3ooo90004oe/0ool0VOoooo]ZoookJPGoolT000?ooo]Zo`3o0?l000000ol0000KoookJP03
oola0?oonf[ooo]Z0?oooo]Z0OoonfX01ooo0;?ooo]Zo`1Lool0G?oo06;ooomL0?oo;P001OoonfX2
okko00Gooo]Z00GoLOl0oookJ_l01_oooo]Zo`3oF005oookJP03o`3oeOoonf[ooo]Z00?ooo]Z00?o
01?oo`3oY_oonfX01OoonfX2oong00Cooo]Z00?o05;ooookJ_l0obh00_oonfX01OoooP3ooo]ZoeOo
0?n6o`3oocL000;ooo]Z00Goom`0oookJ_oonf[oBOl0oookJP02oonR0003o`3oDOl0@Ooo0:Oo00?o
oo]Z0_oL0?l3oookJP03oom60?oonf[oohT000Gooo]Z00_o0?ogoookJ_nco`3ok`3ooookJ_l05ooo
0>Goo`3ohOoo;03o4_l0o`0]o`02oookJP0:o`3mool0ojkooo]Zool0XOoonf[ooj00o`0goooonf[o
od<0o`3bo`;ooo]Z00Co0?ncool0:ooonf[o0?nf0ooonfX01?o00?oooo]Zool0Xooo08D2oookJP05
o`[o0?oonf[oog/0olGo0?ooS0000ooonfX01?nUo`3ooo]ZoookJ_noo`02oookJP06ool0>ooonf[o
oo]Zo`3oN_oonf[oo`3>0ooonfX00ol0S?ooOP3oool:0003oookJP03ool0o?oonf[oom<000;ooo]Z
00?o0?nIoookJ_oonfX01?oonfX00oooB03ooo]ZoookJP03oookJP03o`3oO?oonf[ooo]Z00Kooo]Z
00?o00;ooookJ_oonfX00_oonfX01?oO0?oo01[oo`0]oooeo`06oookJP03oonL0?oonf[o09Wo00Co
oo]Z00GoofH0oj@0oooonf[ooo]Zo`3o0004o`0001_ooo]Z00?ooc40oookJ_oonfX0fOoonfX002[o
oo]Z2Ooob@03oookJP03okko0?oonf[ooo]Z00?ooo]Z00GoLOl0oookJ_l01_oooo]Zo`3oF006oook
JP03o`3oeOoonf[ooo]Z00;ooo]Z00Go01?oo`2Tool0ojKooo]Zooo90004oookJP03ooo90?oonf[o
oo]Z00;ooo]Z0_l0D_l02?oonf[o0?l^oookJ_oooP3ooo]ZoeOo0?n6o`3oocL00_oonfX02ooog03o
oo]ZoookJ_m9o`3ooo]ZoonR0?ooC03ooo]Zo`3oDOl0@Ooo0:Oo00;ooo]Z00?og03ooookJ_oonfX0
0ooonfX00oooAP3ooo]Zoon90005oookJP03o`3omonco`3o0?ng00;ooo]Z00Ko01Ooo`3ohOoonf[o
ob`0oa;o0?l0;Ol2oookJP05o`3moooonf[ooo]Zool0XOooX0000_l0=ol2oom30006o`3booooN@3o
0?ncoookJ_ooN@3o0?nf0ooonfX01Oo00?oooo]Zool0XoooN@3oo`2500?oogT000Cooo]ZolGo0?oo
nf[ooh`00_oonfX01_nUo`3o0?lToookJ_oonf[o_ol0oookJP?oogT000Cooo]Zo`3oN_oo0<ko0?oR
0ooonfX00omn0?oo08coool:0004oookJPCoolT01ooonfX00oooB03ooo]ZoookJP03oookJP;oolT0
0_oonfX2onGo00?ooo]Z00?o00;ooookJ_oonfX00_oonfX01?oO0?oo01[oo`0]oooeo`05oookJP;o
olT000?ooo]Zo`2IoooonfX00_oonfX4ooo90003oookJ_l0o`3ooo]Z00Co00006ooonfX00ooo<@3o
oo]ZoookJP3ooookJP04ool0/ooonf[o05coo`1Ro`;ooe`01_oonfX00onno`3ooo]ZoookJP04oook
JP03og7o0?l01_oo00Ko00;o0?mH1OoonfX00ol0omGooo]ZoookJP03oookJP03o`0Cool0ojKooo]Z
00Gooo]Z00?ookL0oookJ_oonfX00_oonfX2o`1Bo`05oookJ_l0obkooo]ZoookJ_oooP000_mGo`00
1On6o`3oocL0oookJ_oonf[oom`000;ooo]Z00OoBOl0oookJ_ooXP3ooo]Zo`3oDOl0@Ooo0:Oo00?o
oo]Z00?og03ooookJ_oonfX00_oonfX00oooAP3ooo]Zoon90005oookJP0;o`3omonco`3o/ol0onl0
oooonf[o01Ooo`3Uool0on7oob`0oa;o0?l0;Ol00_oonfX02_l0oOoo0?n^oookJ_oo0:7ooo]ZoonP
0?l0=ooooo]Zoom30?l0l_l2oookJP04o`3o/ooo02_ooo]Zo`3o]P?ooo]Z00Co`03ooookJ_oo0:?o
o`250_oonfX01Ol:o`3ooo]Zoomk0?o5o`3ooh`000?ooo]Z00CoYOl0oookJ_oonf[o_ol00_oonfX0
1ooo03_ooo]ZoookJ_l0og[ooo]Zool0c_l0on800ooonfX00ol0S?ooo`X0oookJP03oookJP05ool0
o?oonf[oom<0oookJ_l0oiT01_oonfX00oooB03ooo]ZoookJP04oookJP03o`3oO?oonf[ooo]Z00Go
oo]Z00?o00;ooookJ_oonfX00_oonfX01?oO0?oooo]Zo`0Joooeo`06oookJP04oonL0?oonf[o09Wo
oe/0o`Cooo]Z00GoofH0oookJ_oonf[o0?l0oookJP04o`0001_ooo]Z00?ooc40oookJ_oonfX0fOoo
nfX002[ooo]Z1ooob@04oookJP03okko0?oonf[ooo]Z00?ooo]Z00GoLOl0oookJ_l01_oooo]Zo`3o
F005oookJP;o0?oE1?oonfX01?l04ooo0:Coo`3oY_oonfX3ooo900;ooo]Z00?oolT0oookJ_oonfX0
0_oonfX02_l0D_oooo]Zo`3o;_l0obkooo]Zooon0?oonf[oEol0ohKo0?oo=`02oookJP0;oooL0?oo
nf[oBOl0odWo0?oonf[ooj80oom<0?oonf[o0?mAo`11ool0Yol00_oonfX00ooL0?oooo]ZoookJP03
oookJP03oom60?oonf[oohT000Cooo]Z0_l0ooL02_nco`3o0?ngoookJ_oonf[o01Ooo`3ohOoonf[o
ob`0oa;o0?l0;Ol2oookJP0:o`3moooonf[ooo]Zool0XOooX03o03OooookJ_oo@`3oolT0o`3bo`Co
ogT000Wo0?nfoookJ_oonf[ooo]Zol00oooonf[oo`2Soomi0?oo08D01?ooN@000oooN`3oaOl0oon<
0002oookJP05ojGo0?l0obCooo]ZoookJ_noo`000_oonfX01_ooN@3ooo]ZoookJ_l0og[oo`3>o`3o
hPCooo]Z00?o08coool:0?oonfX00ooonfX4ooo900Oooo]Z00?oodP0oookJ_oonfX01?oonfX01?oo
b@3ooo]ZoookJ_oonfX3onGo0003oookJ_l00_oooo]Z00?ooo]Z00GoE_l0oml0oooonf[o02goooGo
0004oookJP;oolT000?ooo]Zoe/0ool0VOl00ooonfX3ooo900;ooo]Z00?o0?l0oookJ_l000000ol0
000KoookJP03oola0?oonf[ooo]Z0?oooo]Z0OoonfX01?l0G?oo06;ooomL0?oo;P06oookJP03okko
0?oonf[ooo]Z00Cooo]Z00CoLOl0o`06oooonf[o0?mH1_oonfX00ol0omGooo]ZoookJP03oookJP03
o`0Cool0ojKooo]Z00Gooo]Z00?ookL0oookJ_oonfX00_oonfX01?l0D_oooo]Zo`3o;_l0obh2oook
JP05ooon0?mGo`3ooo]ZohKo0?oo=`000_oonfX02_oog03ooo]ZodWo0?m9o`3ooo]ZoonR0?oonf[o
0?mAo`11ool0Yol3oookJP03om`0oooonf[ooo]Z00;ooo]Z00?oodH0oookJ_ooR@001?oonfX2o`3o
m`0:ok?o0?l0okOoo`3>oookJ_l05ooo0>Goo`3ohOoo;03o4_l0o`0]o`;ooo]Z00[o0?goo`3o[_oo
nf[oo`2QoookJ_ooX03ooo]Zo`08oooo@`3o0?;o0_oonfX01?l0ok?oo`0[oookJ_l0okH3oookJP04
ol00oooonf[oo`2Sool0Q@;ooo]Z00Go2_l0oookJ_ooN`3oaOl0oon<0003oookJP04ojGo0?oonf[o
oo]Zokoo00;ooo]Z00Ooo`0koookJ_oonf[o0?mjoookJ_oo0<ko0?oR00?ooo]Z00?o08coool:0?oo
nfX00ooonfX01Ooo0?cooo]ZoooC0?oonf[o0?nI00Kooo]Z00?oodP0oookJ_oonfX01?oonfX00ol0
ogcooo]ZoookJP05oookJP03o`02oooonf[ooo]Z00?ooo]Z00Cog`3oo`0Jool0;OoomOl01_oonfX0
0oooW03ooo]Zo`2Io`04oookJP06oomV0?nT0?oooo]ZoookJ_l0o`3ooo]Z1?l0000LoookJP03oola
0?oonf[ooo]Z0=Sooo]Z000ZoookJPGoolT01OoonfX00onno`3ooo]ZoookJP02oookJP;oLOl000Co
oo]Zo`06ool0oeSo0?mH1OoonfX00ol0omGooo]ZoookJP03oookJP04o`0Cool0ojKo0?nVoookJPKo
olT01?oonfX00ol0D_oooo]Zo`3o;P02oookJP05ooon0?oonf[oEol0ohKo0?oo=`000_oonfX00ooo
g03ooo]ZodWo0002oookJP04oonR0?ooC03ooo]Zo`3oD@;o0:Oo0_oonfX00ooL0?oooo]ZoookJP03
oookJP03oom60?oonf[oohT000Cooo]Z00Co0?ogoookJ_nco`3o0?ng0_oonfX2oomi0004oookJ_oo
;03o4_l0o`0]o`;ooo]Z00?o0?gooookJ_oonfX00_ooN@001Ol0=ooooo]Zoom30?oob@3o0?;o00Go
ogT00ooonfX01Oo00?oooo]Zool0Xooonf[oo`2500GoogT000?oaOl0oomi0?oonfX00_oonfX01?nU
o`3ooo]ZoookJ_noo`02oookJP06oomi0?oonf[ooo]Zo`3oN_oo0<ko0?oR1?oonfX00ol0S?ooo`X0
oookJP03oookJP05ool0o?oob@3oolT0oookJ_l0oiT01_oonfX00oooB03ooo]ZoookJP04oookJP04
ooo90?oonf[ooo]ZoookJPGoiOl000?o00;ooookJ_oonfX00_oonfX01?oO0?oo01[oo`0]oooeo`05
oookJP04ooo90?oonf[ooo]Zo`2Io`?ooo]Z0ooob@03oookJP03o`3o0?oonf[o000000?o00007?oo
nfX00ooo<@3ooo]ZoookJP3noookJP04o`1Lool0H_oooe`0ool^00Kooo]Z00?o__l0oookJ_oonfX0
0ooonfX2og7o0003o`06oooonf[o0?mH00Gooo]Z0_l0omD5oookJP;o0?nV1_oonfX00ooo]`3ooo]Z
oookJP02oookJP03o`1Boooonf[o0?l^00?ooo]Z00Goooh0oeOo0?oonf[oQ_l0oolg0002oookJP03
oooL0?oonf[oBOl000;ooo]Z00?ooj80oookJ_l0oe400_l0Yol3oookJP03om`0oooonf[ooo]Z00;o
oo]Z00?oodH0oookJ_ooR@001?oonfX01ol0ooOooo]Zok?o0?l0okOoo`3>oookJ_l05ol00_l0on40
0ooo;03o4_l0o`0]o`02oookJP04o`3mool0ojkooo]Zool0X@;ooj0000Cooo]Zo`08oooo@`3o0?;o
0_oonfX01?l0ok?oo`0[oookJ_l0okH3oookJP04ol00oooonf[oo`2Sool0Q@;ooo]Z00Go2_l0oook
J_ooN`3oaOl0oon<0003oookJP04ojGo0?oonf[ooo]Zokoo00;ooo]Z00Ooo`0koookJ_oonf[o0?mj
oookJ_oo0<ko0?oR00?ooo]Z00?o08coool:0?oonfX00ooonfX00ooo0?cooo]ZoooC0002oookJP03
o`3oVOoonf[ooo]Z00?ooo]Z00?oodP0oookJ_oonfX01?oonfX00ol0ogcooo]ZoookJP06oookJP03
o`02oooonf[ooo]Z00;ooo]Z00Cog`3ooookJ_l0;OoomOl01_oonfX01?ooW03ooo]Zo`2IoomK0?l4
oookJP06oomV0?oonf[ooo]ZoookJ_l0o`3ooo]Z1?l0000LoookJP03oola0?oonf[ooo]Z0=Sooo]Z
000ZoookJP?oolT01_oonfX00onno`3ooo]ZoookJP02oookJP05og7o0?oonf[o00Koo`06ool0oeP0
1_oonfX00ol0omGooo]ZoookJP03oookJP03o`0Cool0ojKooo]Z00;ooo]Z1_oob@03oookJP04o`1B
oooonf[o0?l^oookJP;oooh00_mGo`001on6o`3oocL0oookJ_oonf[oom`0oookJ_m9o`000_oonfX0
1OooXP3ood`0oookJ_l0oe7o0:Oo00?ooo]Z00?og03ooookJ_oonfX00ooonfX00oooAP3ooo]Zoon9
0004oookJP04o`3omooonf[o/ol0o`3o]`;ooo]Z00KoogT0oookJ_oonf[oob`0oa;o0?l0;Ol2oook
JP0:o`3moooonf[ooo]Zoomi0?oonf[o03OooookJ_oo@`3oolT0o`3bo`OoogT000Kooo]Zol00oooo
nf[oo`2SoookJ_oo08D5oomi0003olGo0?ooN@3oogT000;ooo]Z00CoYOl0oookJ_oonf[o_ol00_oo
nfX01_oo03_ooo]ZoookJ_l0og[oo`3>o`3ohPCooo]Z00?o08coool:0?oonfX00ooonfX01Ooo0?co
oo]Zooo90?oonf[o0?nI00Oooo]Z00?oodP0oookJ_oonfX01?oonfX01?l0ogcooo]ZoookJ_oonfX6
onGo00?ooo]Z00Gog`3oo`0Jool0;Ooooo]ZooGo0005oookJP04oonL0?oonf[oF`3oo`2Io`?ooo]Z
0_oob@03oookJP03o`3o0?oonf[ooo]Z00Co00007?oonfX00ooo<@3ooo]ZoookJP3noookJP03o`1R
ooooG03oobh000Kooo]Z00?o__l0oookJ_oonfX00ooonfX01Omao`3ooo]Zo`06oooonf[o0?mH00Go
oo]Z00?o0?oEoookJ_oonfX01?oonfX00ol0ojKo0:CooookJP05oookJP03oong0?oonf[ooo]Z00;o
oo]Z00?o05;ooookJ_l0obh00_oonfX2ooon0004oeOo0?oonf[oQ_l0oolg00;ooo]Z00?oom`0oook
J_m9o`000_oonfX01?ooXP3ooo]Zo`3oDOl0Yol4oookJP03om`0oooonf[ooo]Z00;ooo]Z00?oodH0
oookJ_ooR@001?oonfX01?l0ooOooo]Zok?o0?l0okL2oookJP06o`0Gool0on7ooo]Zool/0?lBo`3o
02go0_oonfX02ol0oOoo0?n^oookJ_oo0:7ooj00o`0goooonf[o00Sooom30?l0l_oooo]Z00;o0?nc
00?oo`0[oookJ_l0okH00ooonfX01?o00?oooo]Zool0Xooo08D2oookJP06o`[o0?oonf[oog/0olGo
0?oonf[ooh`00_oonfX01?nUo`3ooo]ZoookJ_noo`03oookJP06ool0>ooonf[o0?mjoookJ_oo0<ko
0?oR0ooonfX00ol0S?ooo`X0oookJP03oookJP03ool0o?oonf[oom<000;ooo]Z00?o0?nIoookJ_oo
nfX01?oonfX00oooB03ooo]ZoookJP04oookJP03o`3oO?oonf[ooo]Z00Gooo]Z00?o00;ooookJ_oo
nfX00_oonfX01OoO0?oooo]Zo`0Jool0;OoomOl000Kooo]Z00?ooi`0oookJ_l0VOl01OoonfX01?oo
IP3ooo]ZoookJ_l0o`02oookJPCo00007?oonfX00ooo<@3ooo]ZoookJP3HoookJP00:_oonfX00ooo
b@3ooo]ZoookJP05oookJP03okko0?oonf[ooo]Z00;ooo]Z00GoLOl0oookJ_l01_oooo]Zo`3oF006
oookJP03o`3oeOoonf[ooo]Z00;ooo]Z00?o01?oo`2Tool0ojH00ooonfX8ooo9000;oookJ_l0D_oo
oo]Zo`3o;_oonf[oooh0oookJ_mGo`3ooo]ZohKo0?oo=`000_oonfX00ooog03ooo]ZodWo0002oook
JP05oonR0?ooC03o0?mAo`3oDOl0Yol00ooonfX00ooL0?oooo]ZoookJP03oookJP03oom60?oonf[o
ohT000Cooo]Z00Co0?ogoookJ_nco`3o0?ng0_oonfX01_ooN@3ooo]ZoookJ_oo;03o4_l0o`0]o`;o
oo]Z00[o0?gooookJ_oonf[oogT0oookJ_l0=ooooo]Zoom30?oob@3o0?;o2OooN@001?oonf[oo`2S
oookJ_oo08D5oomi0003olGo0?ooN@3oogT000;ooo]Z00CoYOl0oookJ_oonf[o_ol00_oonfX01_oo
03_ooo]ZoookJ_l0og[oo`3>o`3ohPCooo]Z00?o08coool:0?oonfX00ooonfX01Ooo0?cooo]Zooo9
0?oonf[o0?nI00Oooo]Z00?oodP0oookJ_oonfX01?oonfX00ol0ogcooo]ZoookJP02oookJPOoiOl0
0_oonfX01?oO0?oooo]Zo`0]oooeo`05oookJP04oonL0?oonf[ooo]Zo`2Io`Cooo]Z00?oolT0oj@0
oooonfX00_oonfX00ol0o`3ooo]ZoookJP04o`0001cooo]Z00?ooc40oookJ_oonfX0o_oonfX00ooo
G03ooo]ZoookJP05oookJP03okko0?oonf[ooo]Z00?ooo]Z00?oLOl0o`06ool01_l00_l0oeP5oook
JP03o`3oeOoonf[ooo]Z00?ooo]Z00?o01?oo`3oY_l0Y?l01_oonfX00ooo]`3ooo]ZoookJP02oook
JP03o`1Boooonf[o0?l^00;ooo]Z00Koooh0oookJ_mGo`3ooo]ZohKo0?oo=`02oookJP06oooL0?oo
nf[oBOl0oookJ_ooC03ooj800_l0oe400ol0Yooooo]ZoookJP02oookJP03om`0oooonf[ooo]Z00;o
oo]Z00?oodH0oookJ_ooR@001?oonfX01?l0ooOooo]Zok?o0?l0okL2oookJP06o`0Gool0on7ooo]Z
ool/0?lBo`3o02go0_oonfX04?l0oOoo0?n^oookJ_oo0:7ooj00o`0goooonf[o00Sooom30?l0l_oo
oo]Zo`3o/ooonf[oo`0[oookJ_l0okH3oookJP04ol00oooonf[oo`2Sool0Q@;ooo]Z00Ko2_l0oook
J_ooN`3oaOl0oookJ_ooS002oookJP04ojGo0?oonf[ooo]Zokoo00?ooo]Z00Koo`0koookJ_l0og[o
oo]Zool0c_l0on83oookJP03o`2<oooo2P3ooo]Z00?ooo]Z00?oo`3loookJ_ood`000_oonfX00ol0
oiWooo]ZoookJP04oookJP03oom80?oonf[ooo]Z00Cooo]Z00?o0?mloookJ_oonfX01OoonfX00ol0
0_oooo]ZoookJP03oookJP04oml0ool06_oo02goooGo00Kooo]Z00Cooi`0oookJ_l0VOooF`3o1?oo
nfX01OooIP3ooo]ZoookJ_oonf[o0?l000;ooo]Z1?l0000MoookJP03oola0?oonf[ooo]Z0=Oooo]Z
000`oookJP;o__l01?oonfX01Omao`3ooo]Zo`06oooonf[o0?mH00Gooo]Z00?oolT0o`3oeOoonfX0
0ooonfX00ol04ooo0:Coo`3oYP03oookJPWoolT000So05;ooookJ_l0obkooo]Zooon0?oonf[oEol0
oookJP;oocL00_oonfX01?oog03ooo]ZodWo0?oonfX2oonR0004oookJ_l0oe7ooo]Zo`2Wo`?ooo]Z
00?og03ooookJ_oonfX00ooonfX00oooAP3ooo]Zoon90004oookJP05o`3omooonf[o/ol0onl0oooo
nfX00_ooN@02oookJP06ool/0?lBo`3o02gooomi0?oonf[o0?go0_oonfX02?ooN@3ooo]Zo`0goooo
nf[ood<0ooo90?l0l_oooo]Z1oooN@001Oo00?oooo]Zool0Xooonf[oo`2500GoogT000?oaOl0oomi
0?ooN@000_oonfX01?nUo`3ooo]ZoookJ_noo`02oookJP06ool0>ooonf[ooo]Zo`3oN_oo0<ko0?oR
1?oonfX00ol0S?oooo]Zool:0003oookJP05ool0o?oonf[ooo]ZoooC0?l0oiT01ooonfX00oooB03o
oo]ZoookJP04oookJP03o`3oO?oonf[ooo]Z00;ooo]Z2OoUo`001?oO0?oo01[oo`0]oooeo`06oook
JP04oonL0?oonf[oF`3oo`2Io`Cooo]Z0_oUo`02oookJP04o`3o0?oonf[ooo]ZoookJPCo00007?oo
nfX00ooo<@3ooo]ZonGo0002onGo0?oooo]Z0ooonfX2okko00Gooo]Z00CoLOl0o`06oooonf[o0?mH
1_oonfX00ol0omGooo]ZoookJP03oookJP03o`0Cool0ojKooo]Z00Gooo]Z0_oo]`04oookJP03o`1B
oooonf[o0?l^00;ooo]Z00Coooh0oookJ_mGo`3ooo]Z0_oo=`02oookJP04oooL0?oonf[oBOl0oook
JP;ooj8000?o0?mAoookJ_l0Yol01?oonfX00ooL0?oooo]ZoookJP02oookJP03oom60?oonf[oohT0
00Cooo]Z00Co0?ogoookJ_nco`3ok`3o0_oonfX01_l05ooo0?oQoookJ_oo;03o4_l0o`0]o`;ooo]Z
013o0?goo`3o[_oonf[oo`2QoonP0?l0=ooooo]Zo`08oooo@`3o0?;ooookJ_l0ok?ooo]Zool0:ooo
nf[o0?nf0ooonfX01?o00?oooo]Zool0Xooo08D2oookJP06o`[o0?oonf[oog/0olGo0?oonf[ooh`0
0_oonfX01?nUo`3ooo]ZoookJ_noo`03oookJP06ool0>ooonf[o0?mjoookJ_oo0<ko0?oR0ooonfX0
0ol0S?ooOP3oool:0003oookJP06ool0o?oonf[ooo]ZoooC0?oonf[o0?nI1_oonfX00oooB03ooo]Z
oookJP04oookJP03o`3oO?oonf[ooo]Z00Kooo]Z00?o00;ooookJ_oonfX00_oonfX01?oO0?oooo]Z
o`0Joooeo`07oookJP03oonL0?oonf[o09Wo00Gooo]Z00CoofH0oookJ_oonf[o0?l00ooonfX4o`00
01gooo]Z00?ooc40oookJ_oonfX0eooonfX002oooo]Z00?o__l0oookJ_oonfX00ooonfX01Omao`3o
oo]Zo`06oooonf[o0?mH00Gooo]Z0_oob@04oookJP03o`0Cool0Y?oo0?nV00?ooo]Z2?oob@02o`1B
o`08oookJ_l0obkooo]Zooon0?oonf[oEol0ohKo0?oo=`02oookJP;oom`000Wooo]ZodWo0?oonf[o
oj80oom<0?oonf[o0?mAo`11ool0Yol00ooonfX00ooL0?oooo]ZoookJP02oookJP;oodH000?ooo]Z
oon90?oonfX00ooonfX01Ol0ooOooo]Zok?o0?o_0?oooo]Z00;oogT00_oonfX2oa;o0004o`0]oooo
nf[oogT0o`3mo`;ooo]Z00SoogT0oookJ_l0=ooooo]Zoom30?oob@3o0?;ooookJPOoogT000Go`03o
oookJ_oo0:?ooo]Zool0Q@08oomi00;ooo]Z00CoYOl0oookJ_oonf[o_ol00_oonfX01_oo03_ooo]Z
oookJ_l0og[oo`3>o`3ohPCooo]Z00?o08cooookJ_oo2P001?oonfX01Ooo0?cooo]ZoooC0?oonf[o
0?nI00Kooo]Z00?oodP0oookJ_oonfX01?oonfX00ol0ogcooo]ZoookJP03oookJPOoiOl000Kooo]Z
oml0ool06_oo02gooookJ_oeo`05oookJP04oonL0?oonf[ooo]Zo`2Io`Cooo]Z00?oofH0onGo0?oU
o`000ooUo`03oookJPCo00006ooonfX6onGo0?oooo]Z0_oonfX00onno`3ooo]ZoookJP04oookJP04
og7o0?l01_oooo]Zo`3oF0Gooo]Z0_l0omD5oookJP03o`0Cool0ojKooo]Z00Gooo]Z00?ookL0oook
J_oonfX00_oonfX2o`1Bo`05oookJ_l0obkooo]ZoookJ_oooP000_mGo`001?n6o`3oocL0oookJ_oo
nfX2oooL0008oookJ_m9o`3ooo]ZoonR0?oonf[o0?mAo`11ool0Yol4oookJP04om`0oooonf[ooo]Z
oookJP;oodH000?ooo]Zoon90?oonfX00ooonfX01?l0ooOooo]Zok?o0?o_0?l2oookJP06o`0Gool0
on7ooo]Zool/0?lBo`3o02go0_oonfX04?l0oOoo0?n^oookJ_oo0:7ooj00o`0goooonf[o00Sooom3
0?l0l_oooo]Zo`3o/ooonf[oo`0[o`3Eool0okH3oookJP04ol00oooonf[oo`2Sool0Q@;ooo]Z00Ko
2_l0oookJ_ooN`3oaOl0oookJ_ooS002oookJP04ojGo0?oonf[ooo]Zokoo00?ooo]Z00Koo`0koook
J_l0og[ooo]Zool0c_l0on83oookJP03o`2<oomn0?ooo`X000Cooo]Z00Goo`3loookJ_ood`3ooo]Z
o`3oV@06oookJP03oom80?oonf[ooo]Z00Cooo]Z00?o0?mloookJ_oonfX01_oonfX00ol00_oooo]Z
oookJP02oookJP05oml0oooonf[o01[oo`0]oooeo`001_oonfX01?ooW03ooo]Zo`2IoomK0?l4oook
JP05oomV0?oonf[ooo]ZoookJ_l0o`000ooonfX4o`0001gooo]Z00?ooc40oookJ_oonfX0eooonfX0
02kooo]Z00?o__l0oookJ_oonfX00ooonfX00omao`3ooo]Zo`06o`02o`3oF0Gooo]Z00?oolT0oook
J_oonfX00ooonfX00ol04ooo0?nVo`3oYP04oookJPOoolT000[o05;ooookJ_l0obko0?l^oookJ_oo
oP3ooo]ZoeOo0?n6o`3oocL00_oonfX02ooog03ooo]ZoookJ_m9o`3ooo]ZoonR0?ooC03ooo]Zo`3o
DOl0@Ooo0:Oo00?ooo]Z00?og03ooookJ_oonfX00_oonfX01?ooAP3ooo]ZoookJ_ooR@04oookJP05
o`3omooonf[o/ol0onl0oooonfX00_ooN@004_oonf[oolT0oa;o0?oonf[o02gooookJ_ooN@3o0?go
oomi0?oo0:7oogT0oookJ_l0=ooooo]Zoom30?oob@3o0?;ooookJPKoogT000Oooo]Zol00oooonf[o
o`2SoookJ_oo08Gooo]Z00SoogT000Gooo]ZojGo0?oonf[ooo]Zokoo0002oookJP07ool0>ooonf[o
oo]Zo`3oN_oo0<kooo]Zo`3ohP03oookJP03ogh0ool0S?ooo`X000Cooo]Z00Goo`3loookJ_ood`3o
oo]Zo`3oV@07oookJP03oom80?oonf[ooo]Z00Cooo]Z00?o0?mloookJ_oonfX00ooonfX6onGo00;o
oo]Z00Cog`3ooookJ_l0;OoomOl01OoonfX01?ooW03ooo]ZoookJ_l0VOl5oookJP03oomV0?oUo`3o
iOl000GoiOl000?ooo]Zo`000?l000000_l0000IoookJPSoiOl0oooonfX1oookJP03okko0?oonf[o
oo]Z00?ooo]Z0_mao`000ol01_oooo]Zo`3oF005oookJP03o`3oeOoonf[ooo]Z00Cooo]Z0_l0ojH6
oookJP03oong0?oonf[ooo]Z00;ooo]Z00Co05;ooookJ_l0obko0?l^0_oonfX01OoooP3oEol0oook
J_n6o`3oocL000;ooo]Z00[oom`0oookJ_oonf[oBOl0oookJ_ooXP3ooo]Zo`3oDOl0@Ooo0:Oo1?oo
nfX01OoL0?oooo]ZoookJ_oonf[oodH000;ooo]Z00?oohT0oookJ_oonfX00_oonfX01?l0ooOooo]Z
ok?o0?o_0?l2oookJP06o`0Gool0on7ooo]Zool/0?lBo`3o02go0_oonfX04?l0oOoooo]Zool0XOoo
0:7ooj00o`0goooonf[o00Sooom30?l0l_oooo]Zo`3o/ooonf[oo`0[o`3Eool0okH3oookJP04ol00
oooonf[oo`2Sool0Q@;ooo]Z00Ko2_l0oookJ_ooN`3oaOl0oookJ_ooS002oookJP04ojGo0?oonf[o
oo]Zokoo00?ooo]Z00Koo`0koookJ_l0og[o097oool0c_l0on84oookJP03o`2<oooo2P3ooo]Z00?o
oo]Z00Goo`3loookJ_ood`3ooo]Zo`3oV@07oookJP03oom80?oonf[ooo]Z00Cooo]Z00?o0?mloook
J_oonfX01OoonfX00ol00_oooo]ZoookJP03oookJP04oml0ool06_oooo]ZooGo00Kooo]Z00Cooi`0
oookJ_oonf[o09Wo1OoonfX01OooIP3ooo]ZoookJ_oonf[o0?l000?ooo]Z1?l0000NoookJP03oola
0?oonf[ooo]Z0=Kooo]Z000]oookJP03okko0?oonf[ooo]Z00?ooo]Z00CoLOl0o`06ool01_oo0?mH
1_oonfX00ooob@3ooo]ZoookJP03oookJP03o`0Cool0ojKooo]Z00Cooo]Z1_oob@001?oonf[o05;o
oookJ_l0obh2oookJP05ooon0?oonf[oEol0ohKo0?oo=`000_oonfX02Ooog03ooo]ZoookJ_m9o`3o
oo]ZoonR0?ooC03ooo]Zo`3oD@02o`2Wo`?ooo]Z00?og03ooookJ_oonfX00_oonfX01?ooAP3ooo]Z
oookJ_ooR@04oookJP04o`3omoooN@3oogT0onl0o`?oogT000Sooo]Zooo90?lBo`3ooo]Zo`0]oooo
nf[oogT0o`3mo`?oogT000Sooo]Zo`0goooonf[ood<0ooo90?l0l_oooo]Zo`3o/`CoogT00_oonfX0
1_oob@3ooo]Zool0Xooonf[oo`25oookJP[oogT00_oonfX01?noo`3ooo]ZoookJ_oo03/2oookJP04
o`3oN_l0TOooo`3>o`3ohPCooo]Z00?o08coool:0?oonfX00ooonfX01Ooo0?cooo]ZoooC0?oonf[o
0?nI00Oooo]Z00?oodP0oookJ_oonfX01?oonfX00ol0ogcooo]ZoookJP03oookJPKoiOl00_oonfX0
1?oO0?oo01[oo`0]oooeo`06oookJP04oonL0?oonf[ooo]Zo`2Io`Cooo]Z00?oofH0oj@0oooUo`00
1ooUo`04o`0001Wooo]Z2?oUo`3ooookJP03okko0?oonf[ooo]Z00?ooo]Z00GoLOl0o`06ool01_oo
oo]Zo`3oF005oookJP03o`3oeOoonf[ooo]Z00Cooo]Z00?o0?nVo`2ToooonfX01OoonfX00ooo]`3o
oo]ZoookJP02oookJP03o`1Boooonf[o0?l^00;ooo]Z0_oooP001?mGo`3ooo]ZohKo0?oo=`02oook
JP08oooL0?oonf[oBOl0odWo0?oonf[ooj80oookJ_l0oe42o`2Wo`?ooo]Z0_oL0?l3oookJP04oom6
0?oonf[ooo]Zoon900Cooo]Z00Co0?ogok?o0?nco`3ok`3o0_oonfX01_l05ooo0?oQoookJ_oo;03o
4_l0o`0]o`;ooo]Z013o0?gooookJ_oo0:7ooo]ZoonP0?l0=ooooo]Zooo90?oo@`3o0?;ooookJ_l0
ok?ooo]Zool0:ol0eOoo0?nf0_oonfX2ol00o`03oookJ_oo0:?oo`2500;ooo]Z00Ko2_l0oookJ_oo
N`3oaOl0oookJ_ooS002oookJP04ojGo0?oonf[ooo]Zokoo00?ooo]Z00Koo`0koookJ_l0og[o097o
oookJ_oo0<h4oookJP03o`2<oooo2P3ooo]Z00?ooo]Z00?oo`3loookJ_ood`000_oonfX00ol0oiWo
oo]ZoookJP04oookJP03oom80?oonf[ooo]Z00Cooo]Z00?o0?mloookJ_oonfX01_oonfX00ol00_oo
oo]ZoookJP02oookJP05oml0oooonf[o01[oo`0]oooeo`001_oonfX01?ooW03ooo]ZoookJ_l0VOl4
oookJP05oomV0?oonf[ooo]ZoookJ_l0o`001?oonfX4o`0001kooo]Z00?ooc40oookJ_oonfX0e_oo
nfX002cooo]Z00?o__l0oookJ_oonfX00_oonfX2og7o0003o`06oooonf[o0?mH00Kooo]Z00?oolT0
oookJ_oonfX00ooonfX00ol04ooo0?nVoookJP04oookJPGoolT00_oonfX00ol0D_oooo]Zo`3o;P02
oookJP05ooon0?oonf[oEol0ohKo0?oo=`000_oonfX02_oog03ooo]ZoookJ_m9o`3ooo]ZoonR0?oo
C03ooo]Zo`3oDOl0Yol4oookJP03om`0oooonf[ooo]Z00;ooo]Z00CoodH0oookJ_oonf[oohT00ooo
nfX2ooo90003oomi0?l0okOoogT000?oogT000?ooo]Zooo90?lBo`000_l0;Ol00ooonf[o0?goo`3m
o`05oomi0006oookJ_oo@`3ooo]Zo`3boooonf[o0?nc1?ooN@02oookJP05ooo90?oonf[oo`2Soook
J_oo08D00_oonfX;oomi0004okoo0?oonf[ooo]Zool0>`;ooo]Z00Co0?mjo`2Aoooo0<ko0?oR1?oo
nfX00ol0S?ooo`X0oookJP03oookJP05ool0o?oonf[oom<0oookJ_l0oiT01ooonfX00oooB03ooo]Z
oookJP04oookJP03o`3oO?oonf[ooo]Z00Cooo]Z1OoUo`02oookJP05oml0oomFo`3o02gooookJ_oe
o`001OoonfX01?ooW03ooo]ZoookJ_l0VOl5oookJP03oomV0?nT0?ooiOl000OoiOl01?l0000Joook
JPOoiOl0o_oonfX00onno`3ooo]ZoookJP03oookJP03og7o0?l01_oooo]Z00;o0?mH1OoonfX00ol0
omGooo]ZoookJP04oookJP03o`3oY_l0Y?oooo]Z00Gooo]Z00?ookL0oookJ_oonfX00_oonfX00ol0
D_oooo]Zo`3o;P02oookJP06ooon0?oonf[oEol0oookJ_n6o`3oocL00_oonfX00ooog03ooo]ZodWo
0002oookJP04oonR0?oonf[o0?mAo`2Wo`Cooo]Z00?og03ooookJ_oonfX00_oonfX01?ooAP3ooo]Z
oookJ_ooR@03oookJP;o0?og00?o/ol0o`3o]ooo0<h00_oonfX01ol05ooo0?oQoookJ_oo;03o4_l0
o`0]oooonfX00_l0oOl03ooonf[oo`2QoookJ_ooX03o03OooookJ_oob@3ood<0o`3boooonf[o0?nc
oookJ_oo02_o0=Goo`3o]P02oookJP05ol00oooonf[ooo]Zool0Xooo08D00_oonfX01_l:o`3ooo]Z
oomk0?o5o`3ooo]Zoon<00;ooo]Z00CoYOl0oookJ_oonf[o_ol00ooonfX01_oo03_ooo]Zo`3oN_l0
TOoooo]Zool0cPCooo]Z00?o08coool:0?oonfX00ooonfX01_oo0?cooo]ZoookJ_ood`3ooo]Zo`3o
V@Kooo]Z00?oodP0oookJ_oonfX01?oonfX00ol0ogcooo]ZoookJP06oookJP03o`02oooonf[ooo]Z
00;ooo]Z00Gog`3ooeKo0?l06_oo02goooGo0006oookJP04oonL0?oonf[ooo]Zo`2Io`Gooo]Z00Go
ofH0oookJ_oonf[ooo]Zo`3o0004oookJPCo00007_oonfX00ooo<@3ooo]ZoookJP3FoookJP00:ooo
nfX00onno`3ooo]ZoookJP02oookJP05og7o0?oonf[o00KooookJ_l0oeP01OoonfX2ooo900Cooo]Z
00?o01?oooo90?l0ojH01_oonfX3ooo900?ooo]Z00Co05;ooookJ_l0obkooo]Z0_oooP001?oonf[o
Eol0ohKo0?oo=`02oookJP0:oooL0?oonf[ooo]ZodWo0?oonf[ooj80oom<0?oonf[o0?mAo`2Wo`Co
oo]Z00?og03ooookJ_oonfX00_oonfX01?ooAP3ooo]ZoookJ_ooR@03oookJP04ooo90?oonf[oogT0
o`3o]`GoogT000?oolT0oa;o0?l0;Ol00_oonfX00ol0oOooogT0oomi0006oomi0005oookJ_l0l_oo
oo]Zo`3o/ooonfX00_ooN@03oookJP05ooo90?oonf[oo`2SoookJ_oo08D00_oonfX00oooN@3ooo]Z
oomi0007oomi0005oookJ_noo`3ooo]ZoookJ_oo03/00_oonfX01?l0og[o097oool0c_l0on84oook
JP03o`2<oooo2P3ooo]Z00?ooo]Z00?oo`3loookJ_ood`000_oonfX00ol0oiWooo]ZoookJP04oook
JP03oom80?oonf[ooo]Z00Gooo]Z00?o0?mloookJ_oonfX01?oonfX4onGo00?ooo]Z00Cog`3ooook
J_l0;OoomOl01_oonfX01?ooW03ooo]Zoe/0ool0VOl5oookJP03oomV0?oUo`3oiOl000KoiOl000?o
oo]Zo`000?l000000ol0000IoookJPOoiOl0oOoonfX00onno`3ooo]ZoookJP03oookJP04og7o0?l0
1_oooo]Zo`3oF0Gooo]Z0_l0omD5oookJP03o`0Cool0ojKo0:Co00Kooo]Z00?ookL0oookJ_oonfX0
0_oonfX00ol0D_oooo]Zo`3o;P02oookJP06ooon0?oonf[oEol0oookJ_n6o`3oocL00_oonfX00ooo
g03ooo]ZodWo0002oookJP04oonR0?oonf[o0?mAo`2Wo`Cooo]Z00?og03ooookJ_oonfX00_oonfX0
1?ooAP3ooo]ZoookJ_ooR@03oookJP05o`3omooonf[o/ol0o`3o]ooo0<h00_oonfX02ol0iOoo0?oQ
oookJ_oo;03o4_l0o`0]oooonf[o0?goo`3o[_oonf[oo`2Q00;ooj0000_o03OooookJ_oob@3ood<0
o`3boooonf[o0?ncoookJ_oo02_o0=Goo`3o]P02oookJP05ol00oooonf[ooo]Zool0Xooo08D00_oo
nfX01_l:o`3ooo]Zoomk0?o5o`3ooo]Zoon<00;ooo]Z00CoYOl0oookJ_oonf[o_ol00ooonfX01_oo
03_ooo]Zo`3oN_l0TOoooo]Zool0cPCooo]Z00?o08coogh0oooo2P000ooonfX01_oo0?cooo]Zoook
J_ood`3ooo]Zo`3oV@Kooo]Z00?oodP0oookJ_oonfX01OoonfX00ol0ogcooo]ZoookJP05oookJP03
o`02oooonf[ooo]Z00?ooo]Z00Gog`3oo`0Joooonf[o02goooGo0006oookJP04oonL0?oonf[oF`3o
o`2Io`Cooo]Z00?oY03ooomV0?oonfX00_oonfX00ol0o`3ooo]ZoookJP02oookJPGo00007OoonfX0
0ooo<@3ooo]ZoookJP3FoookJP00:_oonfX00onno`3ooo]ZoookJP02oookJP05og7o0?oonf[o00Ko
oookJ_l0oeP01OoonfX00ooob@3ooo]ZoookJP03oookJP03o`0Coooob@3o0?nV00Kooo]Z0_oob@04
oookJP05o`1Boooonf[o0?l^oookJ_oooP000_oonfX00omGo`3oocL0oolg0002oookJP07oooL0?oo
nf[oBOl0odWo0?oonf[ooj80oom<0002o`3oD@03o`2Woooonf[ooo]Z00;ooo]Z00?og03ooookJ_oo
nfX00_oonfX01?ooAP3ooo]Zoon90?ooR@03oookJP05ooo90?oonf[oogT0o`3o]ooonfX01?ooN@00
0ooob@3o4_l0o`0]o`02oookJP03o`3moooonf[oogT000OoogT000Ko0?;ooookJ_l0ok?ooo]Zoomi
0?l0okH3oookJP05ooo90?oonf[oo`2SoookJ_oo08D00_oonfX00oooN@3ooo]Zoomk0007oomi0005
oookJ_noo`3ooo]ZoookJ_oo03/00_oonfX01?l0og[o097oool0c_l0on84oookJP03o`2<oooo2P3o
oo]Z00?ooo]Z00?oo`3loookJ_ood`000_oonfX00ol0oiWooo]ZoookJP05oookJP03oom80?oonf[o
oo]Z00Cooo]Z00?o0?mloookJ_oonfX01?oonfX4onGo00?ooo]Z00Cog`3oo`0Jool0;OoomOl01_oo
nfX01?ooW03ooo]ZoookJ_l0VOl5oookJP03oomV0?nT0?ooiOl000KoiOl00_oonfX4o`0001_ooo]Z
1_oUo`3loookJP03okko0?oonf[ooo]Z00;ooo]Z0_mao`000ol01_oooo]Zo`3oF005oookJP03o`3o
eOoonf[ooo]Z00Cooo]Z00?o01?oo`3oY_l0Y?l01_oonfX00ooo]`3ooo]ZoookJP02oookJP03o`1B
oooonf[o0?l^00;ooo]Z00Coooh0oookJ_mGo`3ooo]Z0_oo=`02oookJP09oooL0?oonf[oBOl0oook
J_ooC03ooj80oookJ_l0oe7o0:Oo00Cooo]Z00?og03ooookJ_oonfX00_oonfX01?ooAP3ooo]Zoon9
0?ooR@03oookJP05o`3omooonf[o/ol0o`3o]ooo0<h00_oonfX06?l0iOoo0?oQoookJ_oo;03o4_l0
o`0]oooonf[o0?goo`3o[_oonf[oo`2QoonP0?oonf[o03OooookJ_oob@3ood<0o`3boooonf[o0?nc
oookJ_oo02_o0=Goo`3o]P;ooo]Z00Go`03ooookJ_oonf[oo`2Sool0Q@02oookJP06o`[o0?oonf[o
og/0olGo0?oonf[ooh`00_oonfX01?nUo`3ooo]ZoookJ_noo`03oookJP06ool0>ooonf[o0?mjo`2A
oooonf[oo`3>1?oonfX00ol0S?ooOP3oool:0003oookJP06ool0o?oonf[ooo]ZoooC0?oonf[o0?nI
1ooonfX00oooB03ooo]ZoookJP04oookJP03o`3oO?oonf[ooo]Z00Kooo]Z00?o00;ooookJ_oonfX0
0_oonfX01OoO0?oooo]Zo`0Jool0;OoomOl000Kooo]Z00Cooi`0oookJ_oonf[o09Wo1OoonfX01Ooo
IP3ooo]ZoookJ_oonf[o0?l000Gooo]Z1?l0000NoookJP03oola0?oonf[ooo]Z0=Kooo]Z000^oook
JP05og7o0?l01_oo00KooookJ_l0oeP01OoonfX00ooob@3ooo]ZoookJP03oookJP03o`0Coooob@3o
0?nV00Gooo]Z00?ookL0ooo90?oonfX01?oonfX01Ol0D_oooo]Zo`3o;_oonf[oooh000;ooo]Z00?o
Q_l0oolg0?oonfX00_oonfX01?oog03ooo]ZodWo0?oonfX2oonR0004oookJ_l0oe7ooo]Zo`2Wo`Co
oo]Z00?og03ooookJ_oonfX00_oonfX00oooAP3ooo]Zoon90004oookJP04ooo90?oonf[oogT0o`3o
]`GoogT000?oolT0oa;o0?l0;Ol00_ooN@000ol0oOoooo]Zoomi0007oomi0005o`3boooonf[o0?nc
oookJ_ooN@000_oob@02oookJP05ooo90?oonf[oo`2SoookJ_oo08D00ooonfX00ol:o`3oog/0oomi
0005oomi00?ooo]Z00?o_ol0oookJ_oo03/00ooonfX00ol0og[oo`3>o`3ohP04oookJP03o`2<oooo
nf[oo`X000Cooo]Z00Goo`3loookJ_ood`3ooo]Zo`3oV@07oookJP03oom80?oonf[ooo]Z00Cooo]Z
00?o0?mloookJ_oonfX01OoonfX3onGo00?ooo]Z00Gog`3ooeKo0?oonf[o02goooGo0006oookJP04
oonL0?oonf[oF`3oo`2Io`Gooo]Z00?oofH0oookJ_oUo`001OoUo`03oookJPCo00006ooonfX6onGo
0?oooo]Z0OoonfX01Omao`3o00Koo`06oooonf[o0?mH00Gooo]Z00?o0?oEoookJ_oonfX01?oonfX0
0ol04ooo0?nVoookJP05oookJP;ookL01?oonfX00ol0D_oooo]Zo`3o;P02oookJP05ooon0?oonf[o
Eol0ohKo0?oo=`000ooonfX01?oog03ooo]ZodWo0?oonfX2oonR0003oookJ_l0oe7o0:Oo00Cooo]Z
00?og03ooookJ_oonfX00_oonfX00oooAP3ooo]Zoon90004oookJP04o`3omooonf[o/ol0o`3o]`?o
oo]Z01So0>Goo`3ohOoonf[oob`0oa;o0?l0;Ooooo]Zo`3mool0ojkooo]Zool0XOooX03ooo]Zo`0g
oooonf[oolT0oom30?l0l_oooo]Zo`3o/ooonf[oo`0[o`3Eool0okH2oookJP05ol00oooonf[ooo]Z
ool0Xooo08D00ooonfX01Ol:o`3oog/0olGo0?oonf[ooh`000;ooo]Z00GoYOl0oookJ_oonf[ooo]Z
okoo0002oookJP06ool0>ooonf[ooo]Zo`3oN_oonf[oo`3>1?oonfX00ol0S?ooOP3oool:0004oook
JP05ool0o?oonf[oom<0oookJ_l0oiT01ooonfX00oooB03ooo]ZoookJP04oookJP03o`3oO?oonf[o
oo]Z00Kooo]Z00?o00;ooookJ_oonfX00_oonfX01OoO0?ooE_l0o`0Jool0;OoomOl000Oooo]Z00Co
oi`0oookJ_mK0?oo09Wo1OoonfX01OooIP3ooo]ZoookJ_oonf[o0?l000Gooo]Z1?l0000OoookJP03
oola0?oonf[ooo]Z0=Gooo]Z000]oookJP03og7o0?l01_oooo]Z00;o0?mH1OoonfX00ooob@3ooo]Z
oookJP03oookJP03o`0Cool0ojKo0?nV00Gooo]Z00?ookL0oookJ_oonfX00ooonfX2o`1Bo`08oook
J_l0obkooo]Zooon0?oonf[oEol0ohKo0?oo=`03oookJP0:oooL0?oonf[oBOl0oookJ_ooXP3ood`0
oookJ_l0oe7ooo]Zo`2Wo`Cooo]Z00?og03ooookJ_oonfX00_oonfX00oooAP3ooo]Zoon90004oook
JP06ooo90?oonf[oogT0o`3o]oooN@3oolT00oooN@001ooob@3o4_l0o`0]ooooN@3ooo]Zo`3moooo
nfX01oooN@001_oonf[o0?;ooookJ_l0ok?ooo]Zool0:`GoolT000Cooo]Zool0Xooonf[oo`250ooo
nfX00ol:o`3oog/0olGo0004oomi0007ojGo0?oonf[ooo]ZoookJ_noo`3ooo]Zool0>`03oookJP04
o`3oN_oo0<kooo]Zo`3ohP?ooo]Z00?oOP3oo`2<oooo2P001?oonfX01Ooo0?cooo]ZoooC0?oonf[o
0?nI00Oooo]Z00?oodP0oookJ_oonfX01?oonfX00ol0ogcooo]ZoookJP06oookJP;oiOl01?oonfX0
1?oO0?oooo]Zo`0]oooeo`06oookJP04oonL0?oonf[ooo]Zo`2Io`Gooo]Z00?oofH0oj@0oooonfX0
1_oUo`03oookJPCo00007?oonfX5onGo0?oooo]Z00?oLOl0o`06oooonfX00_l0oeP5oookJP03o`3o
eOoonf[ooo]Z00Cooo]Z0_l0ojH6oookJP03oong0?oonf[ooo]Z00;ooo]Z0_l0D_l00ooonf[o0?l^
oookJP02ooon00;oEol000?oQ_l0oolg0?oonfX00_oonfX01Ooog03ooo]ZodWo0?oonf[ooj8000;o
oo]Z00?o0?mAo`2WoooonfX00ooonfX00ooL0?oooo]ZoookJP02oookJP03oom60?oonf[oohT000Co
oo]Z00Co0?ogoookJ_nco`3o0?ng0ooonfX05?l0iOoo0?oQoookJ_oo;03o4_l0o`0]oooonf[o0?go
o`3o[_oonf[oo`2QoonP0?oonf[o03OooookJ_oob@3ood<0o`3boooonf[o0?nc0_oonfX01Ooo02_o
0?nfoookJ_oonf[o`03o00;ooo]Z00?oo`2Sool0QOoonfX00_oonfX01Ol:o`3oog/0olGo0?oonf[o
oh`000;ooo]Z00GoYOl0oookJ_oonf[ooo]Zokoo0002oookJP07ool0>ooonf[ooo]Zo`3oN_oonf[o
o`3>o`3ohP04oookJP03o`2<oooo2P3ooo]Z00?ooo]Z00Goo`3loookJ_ood`3ooo]Zo`3oV@07oook
JP03oom80?oonf[ooo]Z00Cooo]Z00?o0?mloookJ_oonfX01ooonfX00ol00_oooo]ZoookJP02oook
JP05oml0ool06_oo02gooookJ_oeo`001_oonfX01?ooW03ooo]ZoookJ_l0VOl5oookJP05oomV0?oo
nf[ooo]ZoookJ_l0o`001_oonfX4o`0001oooo]Z00?ooc40oookJ_oonfX0eOoonfX002cooo]Z00Co
LOl0o`06oooonf[o0?mH1_oonfX00ooob@3ooo]ZoookJP03oookJP03o`0Cool0ojKooo]Z00Gooo]Z
00?ookL0oookJ_oonfX00ooonfX02_l0D_oooo]Zo`3o;_l0obkooo]Zooon0?oonf[oEol0ohKo0?oo
=`03oookJP0:oooL0?oonf[oBOl0oookJ_ooXP3ood`0oookJ_l0oe7ooo]Zo`2Wo`Cooo]Z00?og03o
oookJ_oonfX00_oonfX01OooAP3ooo]Zoon90?oonf[oogT000;ooo]Z00CoolT0oookJ_ooN@3o0?ng
0_ooN@02ooo90004oomi0?oob@3o4_l0o`0]o`;ooo]Z00?o0?gooookJ_oonfX01OooN@001ooo@`3o
0?;oo`3boooonf[o0?ncoookJ_oo02/01_oob@000ooo0:?ooo]Zoomi0003oookJP03o`[o0?oonf[o
ogT000CoogT000OoYOl0oookJ_oonf[ooo]Zokoo0?oonf[oo`0k00?ooo]Z00Co0?mjool0c_oonf[o
0?oR1?oonfX00ol0S?ooo`X0oookJP03oookJP03ool0o?oonf[oom<000;ooo]Z00?o0?nIoookJ_oo
nfX01?oonfX00oooB03ooo]ZoookJP05oookJP03o`3oO?oonf[ooo]Z00Gooo]Z0_oUo`04oookJP05
oml0oomFo`3o02gooookJ_oeo`001OoonfX01OooW03ooo]ZoookJ_mK0?oo09Wo00Gooo]Z00?oofH0
oookJ_oonfX01OoUo`04oookJPCo00007OoonfX4onGo0?kooo]Z00CoLOl0o`06oooonf[o0?mH1_oo
nfX00ol0omGooo]ZoookJP04oookJP03o`3oY_l0Y?oooo]Z00Gooo]Z00?ookL0oookJ_oonfX00_oo
nfX02ol0D_oooo]Zo`3o;_l0obkooo]Zooon0?oonf[oEol0oookJ_n6o`3oocL000?ooo]Z00Koom`0
odWo0?m9o`3ooo]ZoonR0?oonfX2o`3oD@03o`2Woooonf[ooo]Z00;ooo]Z00?og03ooookJ_oonfX0
0_oonfX00oooAP3ooo]Zoon90004oookJP04o`3omooonf[o/ol0o`3o]`?ooo]Z00?o0>Goo`3ohOoo
nfX00_lBo`002ol0;Ooooo]Zo`3mool0ojkooo]Zool0XOooX03ooo]Zo`0goooonf[oolT000;o0?;o
00Kooo]Zo`3o/ooonf[ooo]Zool0:ol0okH2oookJP05ol00oooonf[ooo]Zool0Xooo08D00ooonfX0
1Ol:o`3ooo]ZolGo0?oonf[ooh`000;ooo]Z00GoYOl0oookJ_oonf[ooo]Zokoo0002oookJP07ool0
>ooonf[ooo]Zo`3oN_l0TOooo`3>o`3ohP04oookJP03o`2<oomn0?ooo`X000?ooo]Z00Koo`3loook
J_oonf[oom<0oookJ_l0oiT6oookJP03oom80?oonf[ooo]Z00Gooo]Z00?o0?mloookJ_oonfX01_oo
nfX00ol00_oooo]ZoookJP02oookJP05oml0oomFo`3o01[oo`0]oooeo`001_oonfX01?ooW03ooo]Z
oookJ_l0VOl6oookJP05oomV0?oonf[ooo]ZoookJ_l0o`001_oonfX4o`0001oooo]Z00?ooc40oook
J_oonfX0eOoonfX002_ooo]Z00CoLOl0o`06oooonf[o0?mH1OoonfX2ooo900Cooo]Z0_l04ol00ol0
ojKooo]ZoookJP04oookJP03oong0?oonf[ooo]Z00?ooo]Z00?o05;ooookJ_l0obh00_oonfX01Ooo
oP3ooo]ZoeOo0?n6o`3oocL000?ooo]Z00[oom`0oookJ_m9o`3ooo]ZoonR0?ooC03ooo]Zo`3oDOoo
nf[o0:Oo1?oonfX01?oL0?oooo]ZoookJ_oonfX2oom6000:oookJ_ooR@3ooo]ZoookJ_ooN@3ooo]Z
ooo90?oonf[oogT0o`3o]`;oogT01?oob@001OlBo`3o02gooookJ_oonf[o0?go00;ooo]Z1?ooN@00
0ooob@3ood<0o`3bo`02oookJP04o`3o/ooonf[oo`0[o`3o]POoolT000Kooo]Zoomi0?oonf[ooo]Z
o`[o0?oonfX4oomi0003oookJ_nUo`3ooo]Z00;ooo]Z00?o_ol0oookJ_oo03/00ooonfX01?l0og[o
o`3>oookJ_l0on84oookJP03o`2<oooo2P3ooo]Z00?ooo]Z00?oo`3loookJ_ood`000_oonfX00ol0
oiWooo]ZoookJP05oookJP03oom80?oonf[ooo]Z00Cooo]Z00?o0?mloookJ_oonfX01_oonfX00ooU
o`3ooo]ZoookJP02oookJP05oml0oomFo`3ooo]Zo`0]oooeo`001_oonfX01?ooW03ooo]ZoookJ_l0
VOl5oookJP04oomV0?nT0?oooo]ZoookJPCoiOl01OoonfX4o`0001gooo]Z1?oUo`3moookJP04og7o
0?l01_oooo]Zo`3oF0Gooo]Z0_l0omD5oookJP03o`0Cool0ojKo0:Co00Kooo]Z00?ookL0oookJ_oo
nfX00_oonfX00ol0D_oooo]Zo`3o;P02oookJP06ooon0?oonf[oEol0oookJ_n6o`3oocL00ooonfX0
2Ooog03oBOl0oookJ_oonf[ooj80oookJ_l0oe7ooo]Zo`2Wo`04oookJP04om`0oooonf[ooo]Zoook
JP;oodH000?ooo]Zoon90?oonfX00ooonfX01?l0ooOooo]Zok?o0?l0okL3oookJP08o`3Uool0on7o
oo]Zoa;o0?oonf[o02gooookJ_l0oOl2oookJP07ool0XOooX03ooo]Zo`0goooonf[oolT0o`3bo`02
oookJP05o`3o/ooonf[ooo]Zool0:ol0okH00_oonfX01_o00?oooo]ZoookJ_oo0:?ooo]Zool0Q@;o
oo]Z00Go2_l0oookJ_ooN`3oaOl0oon<0002oookJP05ojGo0?oonf[ooo]ZoookJ_noo`000_oonfX0
1ooo03_ooo]ZoookJ_l0og[o097oool0c_l0on801?oonfX00ol0S?ooOP3oool:0003oookJP06ool0
o?oonf[ooo]ZoooC0?oonf[o0?nI1ooonfX00oooB03ooo]ZoookJP04oookJP03o`3oO?oonf[ooo]Z
00Kooo]Z00?o00;ooookJ_oonfX00_oonfX01_oO0?ooE_l0o`0Jool0;Ooooo]ZooGo00Kooo]Z00Co
oi`0oookJ_oonf[o09Wo1OoonfX01OooIP3ooo]ZoookJ_oonf[o0?l000Oooo]Z1?l0000OoookJP03
oola0?oonf[ooo]Z0=Gooo]Z000ZoookJP04og7o0?l01_oooo]Zo`3oF0Gooo]Z00?oolT0oookJ_oo
nfX00ooonfX00ol04oooolT0o`3oYP06oookJP03oong0?oonf[ooo]Z00?ooo]Z00?o05;ooookJ_l0
obh00_oonfX01OoooP3ooo]ZoeOo0?n6o`3oocL000;ooo]Z0_oog0002Ooonf[oBOl0oookJ_ooXP3o
od`0oookJ_l0oe7o047oo`2Wo`04oookJP05om`0oooonf[ooo]ZoookJ_ooAP000_oonfX00oooR@3o
oo]ZoookJP03oomi0003oookJ_ooN@3o0?ng00;oogT01?oob@001OlBo`3o02gooomi0?oonf[o0?go
00;oogT000Ooo`2Qoomi0?ooN@3oogT0ooo90?oo@`3o0?;o00;oolT000Co0?ncoookJ_oo02_o0?nf
2?oob@002?ooN@3ooo]ZoookJ_l:o`3ooo]Zoomi0?oonf[oogT00_oonfX01OnUo`3ooo]ZoookJ_oo
nf[o_ol000;ooo]Z00Ooo`0koookJ_oonf[o0?mjoookJ_oo0<ko0?oR00Cooo]Z00?o08coool:0?oo
nfX00ooonfX00ooo0?cooo]ZoooC0002oookJP03o`3oVOoonf[ooo]Z00Gooo]Z00?oodP0oookJ_oo
nfX01?oonfX00ol0ogcooo]ZoookJP07oookJP03o`02oooonf[ooo]Z00;ooo]Z00Cog`3ooookJ_l0
;OoomOl01_oonfX01OooW03ooo]ZoookJ_mK0?oo09Wo00Gooo]Z00CoofH0oookJ_oonf[ooo]Z0ooU
o`06oookJPCo00007_oonfX3onGo0?cooo]Z00CoLOl0o`06oooonf[o0?mH1OoonfX00ol0omGooo]Z
oookJP04oookJP03o`0Cool0ojKooo]Z00Kooo]Z00?ookL0oookJ_oonfX00_oonfX00ol0D_oooo]Z
o`3o;P02oookJP06ooon0?oonf[oEol0oookJ_n6o`3oocL00_oonfX2oooL0008odWo0?oonf[ooo]Z
oonR0?oonf[o0?mAo`11ool0Yol4oookJP05om`0oooonf[ooo]ZoookJ_ooAP000_oonfX00oooR@3o
oo]ZoookJP02oookJP04o`3omooonf[o/ol0o`3o]`?ooo]Z00So0>Goo`3ohOoonf[o4_l0oookJ_l0
;Ooooo]Zo`3mo`;ooo]Z00Ooo`2QoonP0?oonf[o03OooookJ_oob@3o0?;o00;ooo]Z00Go0?ncoook
J_oonf[oo`0[o`3o]P02oookJP06ol00oooonf[ooo]Zool0Xooonf[oo`250_oonfX01Ol:o`3ooo]Z
oomk0?o5o`3ooh`000;ooo]Z00Go0?lTojGo0?oonf[ooo]Zokoo0003oookJP06ool0>ooonf[o0?mj
o`2Aoooonf[oo`3>1?oonfX00ol0S?ooOP3oool:0003oookJP06ool0o?oonf[ooo]ZoooC0?oonf[o
0?nI1ooonfX00oooB03ooo]ZoookJP04oookJP03o`3oO?oonf[ooo]Z00Oooo]Z00?o00;ooookJ_oo
nfX00_oonfX01OoO0?oo01[oo`0]oooonf[omOl000Kooo]Z00Cooi`0oookJ_oonf[o09Wo1_oonfX0
1OooIP3ooo]ZoookJ_oonf[o0?l000Oooo]Z1?l0000PoookJP03oola0?oonf[ooo]Z0=Cooo]Z000Z
oookJP04o`06oooonf[o0?mHooo900Cooo]Z00?oolT0oookJ_oonfX00ooonfX00ol04oooolT0o`3o
YP06oookJP03oong0?oonf[ooo]Z00?ooo]Z00Co05;ooookJ_l0obkooo]Z0_oooP001?oonf[oEol0
ohKo0?oo=`02oookJP07oooL0?oonf[ooo]ZodWo0?oonf[ooj80oom<0002o`3oD@03o`11ool0Yooo
oo]Z00?ooo]Z00Gog03ooookJ_oonf[ooo]Zoom60002oookJP03oon90?oob@3oogT000GoogT000Co
0?ngoomi0?ooN@3oogT00ooob@001OlBo`3o02goooo90?oob@3o0?go00;oogT000?oo`2Qoomi0?oo
N@000_oob@000ooo@`3o0?;oooo90003ooo90003ool0:ol0okKooo]Z00OoolT000SoogT0oookJ_oo
nf[o2_l0oookJ_ooN@3ooo]Zoomi00;ooo]Z00GoYOl0oookJ_oonf[ooo]Zokoo0002oookJP07ool0
>ooonf[ooo]Zo`3oN_oonf[oo`3>o`3ohP04oookJP03o`2<oooo2P3ooo]Z00?ooo]Z00?oo`3loook
J_ood`000_oonfX00ol0oiWooo]ZoookJP05oookJP03oom80?oonf[ooo]Z00Cooo]Z00?o0?mloook
J_oonfX01ooonfX00ol00_oooo]ZoookJP02oookJP05oml0ool06_oooo]Zo`0]oooeo`001_oonfX0
1?ooW03ooo]ZoookJ_l0VOl5oookJP04oomV0?nT0?oooo]ZoookJPCoiOl01_oonfX4o`0001kooo]Z
0ooUo`3loookJP03o`06oooonf[o0?mH00Gooo]Z00?o0?oEoookJ_oonfX01?oonfX00ol04ooo0?nV
oookJP05oookJP;ookL01?oonfX00ol0D_oooo]Zo`3o;P02oookJP03ooon0?oonf[oEol000;oQ_l0
00goocL0oookJ_oonf[oom`0oookJ_m9o`3ooo]Zoom<0?ooXP3ooo]Zo`3oDOl0@Ooo0:Oo00Cooo]Z
00Gog03ooookJ_oonf[ooo]Zoom60002oookJP03oon90?oonf[ooo]Z00;ooo]Z00Co0?ogoookJ_nc
o`3o0?ng0ooonfX02?l0iOoo0?oQoookJ_lBo`3ooo]Zo`0]oooonf[o0?go0_oonfX01ooo0:7ooj00
oookJ_l0=ooooo]Zooo90?l0l_l00_oonfX01Ol0ok?ooo]ZoookJ_oo02_o0?nf00;ooo]Z00Ko`03o
oookJ_oonf[oo`2SoookJ_oo08D2oookJP05o`[o0?oonf[oog/0olGo0?ooS0000_oonfX01Ol0obCo
YOl0oookJ_oonf[o_ol000?ooo]Z00Koo`0koookJ_l0og[o097ooookJ_oo0<h4oookJP03o`2<oomn
0?ooo`X000?ooo]Z00Koo`3loookJ_oonf[oom<0oookJ_l0oiT7oookJP03oom80?oonf[ooo]Z00Co
oo]Z00?o0?mloookJ_oonfX01ooonfX00ol00_oooo]ZoookJP02oookJP06oml0oooonf[o01[oo`0]
oooonf[omOl01_oonfX01?ooW03ooo]Zoe/0ool0VOl5oookJP03oomV0?nT0?oooo]Z00;ooo]Z00?o
0?l0oookJ_oonfX01OoonfX4o`00023ooo]Z00?ooc40oookJ_oonfX0e?oonfX002_ooo]Z00?o0?mH
oookJ_oob@000ooonfX00ooob@3ooo]ZoookJP03oookJP03o`0Cool0ojKo0?nV00Gooo]Z0_oo]`05
oookJP06o`1Boooonf[o0?l^oookJ_oooP3ooo]Z0_mGo`02ooo900;ooo]Z00Coom`0oookJ_oonf[o
BOl00_ooXP000ooonf[o0?mAoookJP02o`2Wo`?ooo]Z0_oL0?l3oookJP04oom60?oonf[ooo]Zoon9
00;oolT02?ooN@001_l0iOooolT0ooo90?oob@3o4_l0o`0]o`;oolT000Ko0?goooo90?ooN@3oo`2Q
oomi0?l0=ol2ooo90003oom30?l0l_ooolT000;oolT000Gooo]Zool0:ol0okKooo]Zoomi0006ooo9
0006oomi0?oonf[ooo]Zo`[o0?oonf[oogT00_oonfX01?ooS03ooo]ZojGo0?l0ob@2oookJP04okoo
0?oonf[ooo]Zool0>`;ooo]Z00Co0?mjoookJ_oo0<ko0?oR1?oonfX00ol0S?ooo`X0oookJP03oook
JP06ool0o?oonf[ooo]ZoooC0?oonf[o0?nI1ooonfX00oooB03ooo]ZoookJP05oookJP03o`3oO?oo
nf[ooo]Z00Kooo]Z00?o00;ooookJ_oonfX00ooonfX01?oO0?oooo]Zo`0]oooeo`06oookJP05oonL
0?oonf[ooo]Zoe/0ool0VOl01?oonfX00oooIP3oY03ooookJP02oookJP?oiOl01ooonfX4o`0001oo
oo]Z0_oUo`3moookJP03o`3oF?oonf[ooo]Z00?ooo]Z00?o0?oEoookJ_oonfX01?oonfX2o`3oYPKo
oo]Z00?ookL0oookJ_oonfX00ooonfX00ol0D_oooo]Zo`3o;P02oookJP04ooon0?mGo`3oEol0ohKo
00;oocL00_oonfX01?oog03ooo]ZodWo0?oonfX2oonR0004oookJ_l0oe7o0:Ooo`2Wo`?ooo]Z0_oL
0?l3oookJP04oom60?oonf[ooo]Zoon900?ooo]Z0_l0ooL00ooonf[o/ol0o`3o]`03oookJP08o`3U
ool0on7ooo]Zoa;o0?oonf[o02gooookJ_l0oOl2oookJP07ool0XOooX03ooo]Zo`0goooonf[oolT0
o`3bo`02oookJP05o`3o/ooonf[ooo]Zool0:ol0okH00_oonfX01_o00?oooo]ZoookJ_oo0:?ooo]Z
ool0Q@;ooo]Z00Ko2_l0oookJ_ooN`3oaOl0oookJ_ooS002oookJP04ojGo0?oonf[ooo]Zokoo00?o
oo]Z00Koo`0koookJ_l0og[o097ooookJ_oo0<h4oookJP03o`2<oomn0?ooo`X000?ooo]Z00Koo`3l
oookJ_oonf[ooo]ZoooC0?l0oiT7oookJP03oom80?oonf[ooo]Z00Gooo]Z00?o0?mloookJ_oonfX0
1_oonfX00ol00_oooo]ZoookJP03oookJP05oml0ool06_oo02gooookJ_oeo`001_oonfX01?ooW03o
oo]ZoookJ_l0VOl5oookJP03oomV0?nT0?oooo]Z00;ooo]Z00?o0?l0oookJ_oonfX01_oonfX4o`00
023ooo]Z00?ooc40oookJ_oonfX0e?oonfX002[ooo]Z00?o0?mHoookJ_oob@001?oob@05oookJP03
o`0Cool0ojKooo]Z00Gooo]Z00?ookL0oookJ_oonfX00ooonfX2o`1Bo`08oookJ_l0obkooo]Zooon
0?oonf[oEol0ohKo0?oob@03oookJP0:oooL0?oonf[ooo]ZodWo0?ooXP3ood`0oookJ_l0oe7ooo]Z
o`2Wo`Cooo]Z00?og03ooookJ_oonfX00_oonfX01?ooAP3ooo]ZoookJ_ooR@02ooo900WoogT00ooo
b@002_lBo`3o02goooo90?oob@3o0?gooookJ_ooN@3oo`2QoonP0?l0=ol2ooo90003oom30?l0l_oo
olT000;oolT000Gooo]Zool0:ol0okKooo]Zooo90002oomi00?oolT000Oooo]Zoomi0?ooN@3oogT0
o`[o0?oonf[oogT000;ooo]Z00Cooh`0oookJ_nUo`3o0?lT0_oonfX01?noo`3ooo]ZoookJ_oo03/2
oookJP04o`3oN_oonf[oo`3>o`3ohPCooo]Z00?o08cooookJ_oo2P001?oonfX01Ooo0?cooo]ZoooC
0?oonf[o0?nI00Oooo]Z00?oodP0oookJ_oonfX01OoonfX00ol0ogcooo]ZoookJP06oookJP03o`02
oooonf[ooo]Z00?ooo]Z00Cog`3oo`0Jool0;OoomOl01_oonfX01OooW03ooo]ZoookJ_oonf[o09Wo
00Gooo]Z00?oofH0oj@0oooonfX00_oonfX2onGo00Sooo]Z1?l0000OoookJP;oiOl0o?oonfX00ol0
oeSooo]ZoookJP02oookJP;o0?oE1_oonfX00ol0ojKo0:CooookJP05oookJP03oong0?oonf[ooo]Z
00?ooo]Z00Co05;ooookJ_l0obkooo]Z0_oooP001?mGo`3ooo]ZohKo0?oo=`03oookJP05oooL0?oo
nf[oBOl0oookJ_ooXP000_oonfX00ol0oe7o0:OooookJP03oookJP03om`0oooonf[ooo]Z00;ooo]Z
00CoodH0oookJ_oonf[oohT00ooonfX01Ol0ooOooo]ZoookJ_nco`3o0?ng00;ooo]Z0_l0iOl01ol0
on7ooo]Zoa;o0?oonf[o02gooookJ_l0oOl00_oonfX01ooo0:7ooj00oookJ_l0=ooooo]Zooo90?l0
l_l00_oonfX01Ol0ok?ooo]ZoookJ_oo02_o0?nf00;ooo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_oo
08D2oookJP06o`[o0?oonf[oog/0olGo0?oonf[ooh`00_oonfX01?nUo`3ooo]ZoookJ_noo`03oook
JP06ool0>ooonf[o0?mjo`2Aoooonf[oo`3>1?oonfX01?l0S?ooOP3ooookJ_oo2P03oookJP05ool0
o?oonf[ooo]ZoooC0?l0oiT01ooonfX00oooB03ooo]ZoookJP05oookJP03o`3oO?oonf[ooo]Z00Oo
oo]Z00?o00;ooookJ_oonfX00_oonfX01OoO0?oooo]Zo`0Jool0;OoomOl000Kooo]Z00Cooi`0oook
J_oonf[o09Wo1_oonfX00oooIP3oY03ooookJP02oookJP03o`3o0?oonf[ooo]Z00Kooo]Z1?l0000Q
oookJP03oola0?oonf[ooo]Z0=?ooo]Z000[oookJPGoolT01OoonfX00ooob@3o0?nVoookJP05oook
JP03oong0?oonf[ooo]Z00?ooo]Z00[o05;ooookJ_l0obko0?l^oookJ_oooP3ooo]ZoeOo0?n6o`3o
olT00ooonfX02_oog03ooo]ZoookJ_m9o`3ooj80oom<0?oonf[o0?mAoookJ_l0Yol4oookJP03om`0
oooonf[ooo]Z00;ooo]Z00KoodH0oookJ_oonf[oohT0oookJ_oob@0;oomi0003ooo90?lBo`3o02go
00;oolT000Ko0?gooookJ_ooN@3oo`2QoonP0?l0=ol2ooo90008oom30?l0l_ooolT0ooo90?l0ok?o
oo]Zool0:ol0okH2oookJPCoogT00_oonfX6oomi00;ooo]Z00Cooh`0oookJ_nUo`3o0?lT0ooonfX0
0onoo`3ooo]Zool0>`02oookJP04o`3oN_oonf[oo`3>o`3ohPCooo]Z00?o08cooookJ_oo2P001?oo
nfX01Ooo0?cooo]ZoooC0?oonf[o0?nI00Oooo]Z00?oodP0oookJ_oonfX01OoonfX00ol0ogcooo]Z
oookJP07oookJP03o`02oooonf[ooo]Z00;ooo]Z00Gog`3oo`0Joooonf[o02goooGo0006oookJP05
oonL0?oonf[ooo]Zoe/0ool0VOl01?oonfX00oooIP3oY03ooookJP03oookJP03onGo0?oonf[ooo]Z
00Oooo]Z1?l0000PoookJP03onGo0?oonf[ooo]Z0?kooo]Z00?o0?oEoookJ_oonfX01OoonfX00ol0
ojKooo]ZoookJP05oookJP03oong0?oonf[ooo]Z00?ooo]Z00[o05;oo`3o;_l0obkooo]Zooon0?oo
nf[oEol0oookJ_n6o`3oocL00ooonfX01Ooog03ooo]ZodWo0?oonf[ooj8000;ooo]Z00?o0?mAo`2W
oooonfX00ooonfX00ooL0?oooo]ZoookJP02oookJP04oom60?oonf[ooo]Zoon900?ooo]Z00Go0?og
oookJ_oonf[o/ol0o`3o]`02oookJP09o`3Uool0on7o0?oQoookJ_lBo`3ooo]Zo`0]oooonf[o0?go
00;ooo]Z00Ooo`2QoonP0?oonf[o03OooookJ_oob@3o0?;o00;ooo]Z00Go0?ncoookJ_oonf[oo`0[
o`3o]P02oookJP06ol00oooonf[ooo]Zool0Xooonf[oo`250_oonfX01_l:o`3ooo]Zoomk0?o5o`3o
oo]Zoon<00;ooo]Z00GoYOl0oookJ_oonf[ooo]Zokoo0002oookJP06ool0>ooonf[o0?mjo`2Aoooo
nf[oo`3>1?oonfX01?l0S?ooOP3ooookJ_oo2P03oookJP05ool0o?oonf[ooo]ZoooC0?l0oiT01ooo
nfX00oooB03ooo]ZoookJP05oookJP03o`3oO?oonf[ooo]Z00Oooo]Z00?o00;ooookJ_oonfX00_oo
nfX01OoO0?oooo]Zo`0Jool0;OoomOl000Oooo]Z00Cooi`0oookJ_oonf[o09Wo1OoonfX00oooIP3o
Y03ooookJP02oookJP03o`3o0?oonf[ooo]Z00Oooo]Z1?l0000QoookJP03oola0?oonf[ooo]Z0=?o
oo]Z000ZoookJPKoolT00ooonfX00ol04oooolT0o`3oYP06oookJP03oong0?oonf[ooo]Z00?ooo]Z
00?o05;ooookJ_l0obh00_oonfX01OoooP3ooo]ZoeOo0?n6o`3oolT000?ooo]Z00[oom`0oookJ_oo
b@3oolT0oonR0?ooC03ooo]Zo`3oDOoonf[o0:Oo1?oonfX00ooL0?oooo]ZoookJP02oookJP05oom6
0?oonf[oohT0oon90?oonfX00_oob@09oomi00;oolT000Go4_l0o`0]oooob@3oolT0o`3mo`02oook
JP0<ool0XOooX03o03Oooomi0?oob@3ood<0o`3boooob@3ooo]Zo`3o/ooonf[oo`0[0ooonfX00ooo
b@3oogT0oomi000:oomi0005oookJ_ooS03ooo]ZojGo0?l0ob@00ooonfX00onoo`3ooo]Zool0>`02
oookJP04o`3oN_l0TOooo`3>o`3ohPCooo]Z00?o08cooookJ_oo2P001?oonfX00ooo0?cooo]ZoooC
0002oookJP03o`3oVOoonf[ooo]Z00Cooo]Z00?oodP0oookJ_oonfX01OoonfX00ol0ogcooo]Zoook
JP07oookJP03o`02oooonf[ooo]Z00?ooo]Z00Cog`3ooookJ_l0;OoomOl01OoonfX00ooob@3ooi`0
oookJP02oookJP03o`2Ioooonf[ooo]Z00?ooo]Z00?oofH0oj@0oooonfX00ooonfX00ol0o`3ooo]Z
oookJP07oookJPCo00008?oonfX00ooo<@3ooo]ZoookJP3moookJP03o`3oeOoonf[ooo]Z00Cooo]Z
00?o01?oo`3oY_oonfX01OoonfX2oong00Cooo]Z0_l0D_l02Ol0obkooo]ZoookJ_oooP3ooo]ZoeOo
0?oonf[oQ_l0oolg0002oookJP;oom`00_m9o`001_oonf[ooj80oookJ_oonf[o0?mAo`2Wo`Cooo]Z
00?og03ooookJ_oonfX00_oonfX01?ooAP3ooo]Zoon90?ooR@03oookJP05o`3omooonf[ooo]Zok?o
0?l0okL00_oonfX02Ol0iOoo0?oQoookJ_oonf[o4_l0oookJ_l0;Ooooo]Zo`3mo`02oookJP07ool0
XOooX03ooo]Zo`0goooonf[oolT0o`3bo`02oookJP04o`3o/ooonf[ooo]Zool0:`?ooo]Z00Ko`03o
oookJ_oonf[oo`2SoookJ_oo08D2oookJP06o`[o0?oonf[oog/0olGo0?oonf[ooh`00_oonfX01OnU
o`3ooo]ZoookJ_oonf[o_ol000;ooo]Z00Ooo`0koookJ_l0og[ooo]Zo`2Aoooo0<ko0?oR00?ooo]Z
00Co08coogh0oooonf[oo`X00ooonfX01_oo0?cooo]ZoookJ_ood`3ooo]Zo`3oV@Kooo]Z00?oodP0
oookJ_oonfX01OoonfX00ol0ogcooo]ZoookJP07oookJP03o`02oooonf[ooo]Z00?ooo]Z00Gog`3o
o`0Jool0;Ooooo]ZooGo0006oookJP04oonL0?oonf[ooo]Zo`2Io`Kooo]Z00?oofH0oookJ_oonfX0
0_oonfX00ol0o`3ooo]ZoookJP07oookJPCo00008OoonfX00ooo<@3ooo]ZoookJP3CoookJP00:_oo
nfX7ooo90004oookJ_l04oooolT0o`3oYPKooo]Z00?ookL0oookJ_oonfX00ooonfX00ol0D_oooo]Z
o`3o;P02oookJP05ooon0?oonf[oEol0ohKo0?oob@000ooonfX02_oog03ooo]Zooo90?oonf[ooj80
oom<0?oonf[o0?mAoookJ_l0Yol4oookJP03om`0oooonf[ooo]Z00;ooo]Z00?oodH0oookJ_ooR@00
0_oonfX2ooo900[oogT000KoolT0oa;o0?l0;OooolT0oookJ_l0oOl2oookJP0<ool0XOooX03o03Oo
oomi0?oob@3ood<0o`3boooob@3ooo]Zo`3o/ooonf[oo`0[1?oonfX=oomi0004oon<0?oonf[oYOl0
o`3o90?ooo]Z00?o_ol0oookJ_oo03/00_oonfX01?l0og[o097oool0c_l0on84oookJP03o`2<oomn
0?ooo`X000Cooo]Z00?oo`3loookJ_ood`000_oonfX00ol0oiWooo]ZoookJP05oookJP03oom80?oo
nf[ooo]Z00Gooo]Z00?o0?mloookJ_oonfX01_oonfX00ol00_oooo]ZoookJP03oookJP04oml0ool0
6_oo02goooGo00Kooo]Z00KoolT0oonL0?oob@3oolT0oe/0ool0VOl4oookJP03oomV0?nT0?oooo]Z
00?ooo]Z00?o0?l0oookJ_oonfX02?oonfX4o`00023ooo]Z00?ooc40oookJ_oonfX0o?oonfX00ol0
omGooo]ZoookJP04oookJP03o`2Tool0ojKooo]Z00Gooo]Z00?ookL0oookJ_oonfX00ooonfX00ol0
D_oooo]Zo`3o;P02oookJP06ooon0?oonf[oEol0oookJ_n6o`3oocL00_oonfX00ooog03ooo]ZodWo
0002oookJP05oonR0?oonf[ooo]Zo`3oDOl0Yol01?oonfX00ooL0?oooo]ZoookJP02oookJP03oom6
0?oonf[oohT000Cooo]Z00Go0?ogoookJ_oonf[o/ol0o`3o]`02oookJP09o`3Uool0on7ooo]Zoook
J_lBo`3ooo]Zo`0]oooonf[o0?go00;ooo]Z00Ooo`2QoonP0?oonf[o03OooookJ_oob@3o0?;o00;o
oo]Z00Co0?ncoookJ_l0eOooo`0[0ooonfX01_o00?oooo]ZoookJ_oo0:?ooo]Zool0Q@;ooo]Z00Ko
2_l0oookJ_ooN`3oaOl0oookJ_ooS002oookJP05ojGo0?oonf[ooo]ZoookJ_noo`000_oonfX01ooo
03_ooo]Zo`3oN_oonf[o097oool0c_l0on800ooonfX01?l0S?oooo]Zogh0oooo2P03oookJP06ool0
o?oonf[ooo]ZoooC0?oonf[o0?nI1ooonfX00oooB03ooo]ZoookJP05oookJP03o`3oO?oonf[ooo]Z
00Oooo]Z00?o00;ooookJ_oonfX00_oonfX01OoO0?oooo]Zo`0Jool0;OoomOl000Oooo]Z00Cooi`0
oookJ_mK0?oo09Wo1OoonfX00oooIP3oY03ooookJP02oookJP03o`3o0?oonf[ooo]Z00Sooo]Z1?l0
000QoookJP03oola0?oonf[ooo]Z0=?ooo]Z000ZoookJPWoolT000?o0?nVoookJ_oonfX00ooonfX2
oong00Gooo]Z00?o05;ooookJ_l0obh00_oonfX01OoooP3ooo]ZoeOo0?n6o`3oolT000;ooo]Z0_oo
g0002Ooonf[oolT0oookJ_ooXP3ood`0oookJ_l0oe7ooo]Zo`2Wo`04oookJP03om`0oooonf[ooo]Z
00;ooo]Z00?oodH0oookJ_ooR@000ooonfX2ooo900SoogT00_oob@002_lBo`3o02gooookJ_l0ojko
0?gooookJ_ooN@3oo`2QoonP0?l0=ol2oomi0007oom30?l0l_oooo]ZoookJ_l0ok?ooo]Zool0:`04
oookJP03ooo90?ooN@3oogT000[oogT000Cooh`0oomi0?ooN@3o0?lT0ooonfX00onoo`3ooo]Zool0
>`02oookJP04o`3oN_l0TOoooo]Zool0cPCooo]Z00?o08coogh0oooo2P001?oonfX00ooo0?cooo]Z
oooC0002oookJP03o`3oVOoonf[ooo]Z00Gooo]Z00?oodP0oookJ_oonfX01OoonfX00ol0ogcooo]Z
oookJP06oookJP03o`02oooonf[ooo]Z00?ooo]Z00Gog`3oo`0Joooonf[o02goooGo0006oookJP05
oonL0?oob@3oolT0ooo90?l0VOl01OoonfX00oooIP3oY03ooookJP03oookJP03o`3o0?oonf[ooo]Z
00Sooo]Z1?l0000QoookJP03oola0?oonf[ooo]Z0?[ooo]Z00?o0?oEoookJ_oonfX01?oonfX00ol0
Y?oo0?nVoookJP05oookJP03oong0?oonf[ooo]Z00?ooo]Z00?o05;ooookJ_l0obh00_oonfX00ooo
oP3ooo]ZoeOo0002ohKo0006oolg0?oonf[ooo]ZoooL0?oonf[oBOl00_oonfX01OooXP3ooo]Zoook
J_l0oe7o0:Oo00Cooo]Z00?og03ooookJ_oonfX00_oonfX00oooAP3ooo]Zoon90004oookJP05o`3o
mooonf[ooo]Zok?o0?l0okL00_oonfX02Ol0iOoo0?oQoookJ_oonf[o4_l0oookJ_l0;Ooooo]Zo`3m
o`02oookJP07ool0XOooX03ooo]Zo`0goooonf[oolT0o`3bo`02oookJP04o`3o/ooonf[o0=Goool0
:`?ooo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_oo08D2oookJP06o`[o0?oonf[oog/0olGo0?oonf[o
oh`00_oonfX01OnUo`3ooo]ZoookJ_oonf[o_ol000;ooo]Z00Ooo`0koookJ_l0og[ooo]Zo`2Aoooo
nf[oo`3>00?ooo]Z00Co08cooookJ_mn0?ooo`X00ooonfX01_oo0?cooo]ZoookJ_ood`3ooo]Zo`3o
V@Oooo]Z00?oodP0oookJ_oonfX01OoonfX00ol0ogcooo]ZoookJP07oookJP03o`02oooonf[ooo]Z
00;ooo]Z00Gog`3ooookJ_l06_oo02goooGo0007oookJP04oonL0?oonf[ooo]Zo`2Io`Kooo]Z00?o
ofH0oookJ_oonfX00_oonfX00ol0o`3ooo]ZoookJP08oookJPCo00008OoonfX00ooo<@3ooo]Zoook
JP3CoookJP00:_oonfX6ooo90003o`0Cool0ojKo0?nV00Gooo]Z00?ookL0oookJ_oonfX00ooonfX2
o`1Bo`03oookJ_l0obkooo]Z00;oooh00_mGo`001On6o`3oolT0oookJ_oonf[oom`000;ooo]Z00Co
olT0oookJ_ooXP3ood`00_l0oe400ooonf[o0:OooookJP03oookJP03om`0oooonf[ooo]Z00;ooo]Z
00?oodH0oookJ_ooR@000ooonfX2ooo900OoogT000So0?oQoomi0?oob@3o4_l0o`0]oooonf[o0?n^
o`3mo`;ooo]Z00?oo`2QoonP0?l0=ol00_ooN@001ooo@`3o0?;ooookJ_oonf[o0?ncoookJ_oo02/0
1?oonfX00ooob@3oogT0oomi000:oomi0004oon<0?ooN@3oYOl0o`3o90?ooo]Z00Wo_ol0oookJ_oo
nf[oo`0koookJ_l0og[o097ooookJ_oo0<h01?oonfX00ol0S?ooOP3oool:0004oookJP03ool0o?oo
nf[oom<000;ooo]Z00?o0?nIoookJ_oonfX01OoonfX00oooB03ooo]ZoookJP05oookJP03o`3oO?oo
nf[ooo]Z00Oooo]Z00?o00;ooookJ_oonfX00_oonfX01OoO0?oo01[ooookJ_l0;OoomOl000Kooo]Z
00?oolT0oonL0?oob@000_oob@001ol0VOooolT0ooo90?oob@3ooo]ZoomV0?nT0?l01?oonfX00ol0
o`3ooo]ZoookJP09oookJPCo00008OoonfX00ooo<@3ooo]ZoookJP3ioookJP03o`3oeOoonf[ooo]Z
00Cooo]Z0_l0ojH6oookJP03oong0?oonf[ooo]Z00?ooo]Z00Co05;ooookJ_l0obkooo]Z0_oooP02
oeOo0003ohKo0?oo=`3oocL000;ooo]Z00?oom`0oookJ_m9o`000_oonfX01OooXP3ooo]Zo`3oDOl0
oe7o0:Oo00Cooo]Z00?og03ooookJ_oonfX00_oonfX00oooAP3ooo]Zoon90004oookJP05o`3omooo
nf[ooo]Zok?o0?o_0?l00_oonfX02Ol0iOoo0?oQoookJ_oonf[o4_l0oookJ_l0;Ooooo]Zo`3mo`02
oookJP07ool0XOooX03ooo]Zo`0goooonf[oolT0o`3bo`02oookJP04o`3o/ooonf[o0=Goool0:`?o
oo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_oo08D2oookJP06o`[o0?oonf[oog/0olGo0?oonf[ooh`0
0_oonfX01OnUo`3ooo]ZoookJ_oonf[o_ol000;ooo]Z00Ooo`0koookJ_l0og[ooo]Zo`2Aoooonf[o
o`3>00?ooo]Z00Co08cooookJ_mn0?ooo`X00ooonfX01_oo0?cooo]ZoookJ_ood`3ooo]Zo`3oV@Oo
oo]Z00?oodP0oookJ_oonfX01OoonfX00ol0ogcooo]ZoookJP07oookJP03o`02oooonf[ooo]Z00;o
oo]Z00KoE_l0oml0ool06_oooo]Zo`0]oooeo`07oookJP04oonL0?oonf[oF`3oo`2Io`Gooo]Z00?o
ofH0oj@0oooonfX00_oonfX00ol0o`3ooo]ZoookJP09oookJPCo00008_oonfX00ooo<@3ooo]Zoook
JP3BoookJP00:_oonfX6ooo90003o`3oY_oonf[ooo]Z00Cooo]Z00?ookL0oookJ_oonfX00ooonfX0
2ol0D_oooo]Zo`3o;_l0obkooo]Zooon0?oonf[oEol0oookJ_n6o`3oolT000;ooo]Z00Coom`0oook
J_oonf[oolT00_ooXP001OooC03o0?mAoookJ_oonf[o0:Oo00?ooo]Z0_oL0?l3oookJP;oodH000?o
oo]Zoon90?oonfX00_oonfX2ooo900OoogT000So0?oQoomi0?oob@3o4_l0o`0]oooonf[o0?n^o`3m
o`;ooo]Z00Ooo`2QoonP0?l0=oooogT0ooo90?oo@`3o0?;o00;ooo]Z00?o0?ncoookJ_oo02/01?oo
nfX00oo00?oooo]Zoomi000:oomi0004oon<0?ooN@3oYOl0o`3o90?ooo]Z00Wo_ol0oookJ_oonf[o
o`0koookJ_l0og[o097ooookJ_oo0<h01?oonfX00ol0S?ooOP3oool:0004oookJP06ool0o?oonf[o
oo]ZoooC0?oonf[o0?nI1ooonfX00oooB03ooo]ZoookJP05oookJP03o`3oO?oonf[ooo]Z00Oooo]Z
00?o00;ooookJ_oonfX00ooonfX01OoO0?oo01[oo`0]oooonf[omOl000Kooo]Z00Gooi`0ooo90?oo
b@3oolT0o`2Io`05ooo90003oomV0?nT0?oooo]Z00?ooo]Z00?o0?l0oookJ_oonfX02OoonfX4o`00
027ooo]Z00?ooc40oookJ_oonfX0o_oonfX00ol04ooo0?nVoookJP06oookJP03oong0?oonf[ooo]Z
00?ooo]Z00[o05;oo`3o;_l0obkooo]Zooon0?oonf[oEol0oookJ_n6o`3oocL00ooonfX01?oog03o
oo]ZodWo0?oonfX2oonR0004oookJ_l0oe7ooo]Zo`2Wo`Cooo]Z00?og03ooookJ_oonfX00_oonfX0
0oooAP3ooo]Zoon90004oookJP05o`3omooonf[ooo]Zok?o0?o_0?l00_oonfX02Ol0iOoo0?oQoook
J_oonf[o4_l0oookJ_l0;Ooooo]Zo`3mo`02oookJP07ool0XOooX03ooo]Zo`0goooonf[oolT0o`3b
o`02oookJP04o`3o/ooonf[o0=Goool0:`?ooo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_oo08D2oook
JP06o`[o0?oonf[oog/0olGo0?oonf[ooh`00_oonfX01OnUo`3ooo]ZoookJ_oonf[o_ol000;ooo]Z
00Ooo`0koookJ_l0og[ooo]Zo`2Aoooonf[oo`3>00?ooo]Z00Co08cooookJ_mn0?ooo`X00ooonfX0
1_oo0?cooo]ZoookJ_ood`3ooo]Zo`3oV@Oooo]Z00?oodP0oookJ_oonfX01OoonfX00ol0ogcooo]Z
oookJP08oookJP03o`02oooonf[ooo]Z00;ooo]Z00Gog`3ooookJ_l06_oo02goooGo0007oookJP04
oonL0?oonf[ooo]Zo`2Io`Kooo]Z00?oofH0oookJ_oonfX00_oonfX00ol0o`3ooo]ZoookJP09oook
JPCo00008_oonfX00ooo<@3ooo]ZoookJP3BoookJP00:_oonfX5ooo90003o`3oY_oob@3oolT000Co
oo]Z00?ookL0oookJ_oonfX00ooonfX00ol0D_oooo]Zo`3o;P02oookJP04ooon0?oonf[oEol0oook
JP;oolT00_oonfX02?oog03ooo]ZoookJ_oob@3ooj80oookJ_ooC03o0?mA0_oonfX01Ol0Yooooo]Z
oookJ_oonf[og03o00Cooo]Z00CoodH0oookJ_oonf[oohT01?oonfX2ooo900GoogT000Wo0>Goo`3o
hOoo;03oolT0oa;o0?l0;Ooooo]Zo`3o[_l0oOl00_oonfX01ooo0:7ooj00o`0gooooN@3oolT0oom3
0?l0l_l00_oonfX00ol0ok?ooo]Zool0:`04oookJP03ol00oooonf[oogT000[oogT000Cooh`0oook
J_nUo`3o0?lT0ooonfX02Onoo`3ooo]ZoookJ_oo03_ooo]Zo`3oN_l0TOoooo]Zool0cP04oookJP03
o`2<oomn0?ooo`X000Gooo]Z00Goo`3loookJ_ood`3ooo]Zo`3oV@07oookJP03oom80?oonf[ooo]Z
00Kooo]Z00?o0?mloookJ_oonfX01_oonfX00ol00_oooo]ZoookJP03oookJP05oml0ool06_oooo]Z
o`0]oooeo`001_oonfX00oooW03oolT0ooo90002ooo90003o`2Ioooob@3oolT000;oolT000?oofH0
ooo90?oob@000ooonfX00ol0o`3ooo]ZoookJP0:oookJPCo00008_oonfX00ooo<@3ooo]ZoookJP3l
oookJP03o`2Tool0ojKooo]Z00Gooo]Z0_oo]`05oookJP0:o`1Bool0obkooo]ZoookJ_oooP3ooo]Z
oeOo0?oonf[oQ_l0oolg00?ooo]Z00[oom`0oookJ_m9o`3ooo]ZoonR0?ooC03ooo]Zo`3oDOoonf[o
0:Oo1?oonfX00ooL0?oooo]ZoookJP02oookJP03oom60?oonf[oohT000Cooo]Z00Go0?ogoookJ_oo
nf[o/ol0onl0o`02oookJP09o`3Uool0on7ooo]Zool/0?lBo`3ooo]Zo`0]oooonf[o0?go00;ooo]Z
00Ooo`2QoonP0?oonf[o03OooookJ_oob@3o0?;o00;ooo]Z00Co0?ncoookJ_l0eOooo`0[0ooonfX0
1_o00?oooo]ZoookJ_oo0:?ooo]Zool0Q@;ooo]Z00Ko2_l0oookJ_ooN`3oaOl0oookJ_ooS002oook
JP05ojGo0?oonf[ooo]ZoookJ_noo`000_oonfX01ooo03_ooo]Zo`3oN_oonf[o097ooookJ_oo0<h0
0ooonfX01?l0S?oooo]Zogh0oooo2P04oookJP05ool0o?oonf[oom<0oookJ_l0oiT01ooonfX00ooo
B03ooo]ZoookJP06oookJP03o`3oO?oonf[ooo]Z00Oooo]Z00?o00;ooookJ_oonfX00_oonfX01OoO
0?oooo]Zo`0Jool0;OoomOl000Oooo]Z00Gooi`0oookJ_oonf[oF`3oo`2Io`05oookJP03oomV0?oo
nf[ooo]Z00;ooo]Z00?o0?l0oookJ_oonfX02_oonfX4o`0002;ooo]Z00?ooc40oookJ_oonfX0d_oo
nfX002_ooo]Z0ooob@000ol0ojKoolT0ooo90002ooo900;ooo]Z00?ookL0oookJ_oonfX00ooonfX0
0ol0D_oooo]Zo`3o;P02oookJP05ooon0?oonf[oEol0ohKo0?oob@000ooonfX02ooog03ooo]Zoook
J_oob@3ooj80oookJ_ooC03o0?mAoookJ_l0@Ooo0:Oo00?ooo]Z00?og03ooookJ_oonfX00_oonfX0
1?ooAP3ooo]ZoookJ_ooR@04oookJP04ooo90?nco`3oogT0o`3o]`;oogT000So01Ooo`3Uool0on7o
ob`0oookJ_lBo`3o02gooookJP;o0?go0_oonfX01ooo0:7ooj00o`0gooooN@3oolT0oom30?l0l_l0
0_ooN@000ol0ok?ooo]Zool0:`04oookJP03ol00oooonf[oo`2S00[oogT000Cooh`0oookJ_nUo`3o
0?lT0ooonfX01?ooN@3ooo]ZoookJ_oo03/2oookJP03o`3oN_oonf[oo`3>00Gooo]Z00?o08cooook
J_oo2P001?oonfX01Ooo0?cooo]ZoooC0?oonf[o0?nI00Oooo]Z00?oodP0oookJ_oonfX01_oonfX0
0ol0ogcooo]ZoookJP06oookJP03o`02oooonf[ooo]Z00?ooo]Z00Gog`3oo`0Joooonf[o02goooGo
0007oookJP05oonL0?oob@3oolT0ooo90?l0VOl01Ooob@001?ooIP3oolT0ooo90?oob@02oookJP03
o`3o0?oonf[ooo]Z00[ooo]Z1?l0000RoookJP03oola0?oonf[ooo]Z0?_ooo]Z00?o0:Coo`3oY_oo
nfX01OoonfX00ooo]`3ooo]ZoookJP04oookJP0:o`1Bool0obkooo]ZoookJ_oooP3ooo]ZoeOo0?oo
nf[oQ_l0oolg00;ooo]Z0_oog0002Ooonf[oBOl0oookJ_ooXP3ood`0oookJ_l0oe7o047oo`2Wo`04
oookJP03om`0oooonf[ooo]Z00;ooo]Z00?oodH0oookJ_ooR@001?oonfX01Ol0ooOooo]Zok?o0?nc
o`3ok`3o00;ooo]Z00Oo0>Goo`3ohOoonf[oob`0oa;o0?oonf[o02go00;o0?go0_oonfX01ooo0:7o
oj00oookJ_l0=ooooo]Zooo90?l0l_l00_oonfX01?l0ok?ooo]Zo`3Eoooo02/3oookJP06ol00oooo
nf[ooo]Zool0Xooonf[oo`250_oonfX01_l:o`3ooo]Zoomk0?o5o`3ooo]Zoon<00;ooo]Z00GoYOl0
o`3o9?oonf[ooo]Zokoo0002oookJP07ool0>ooonf[ooo]Zo`3oN_l0TOoooo]Zool0cP04oookJP03
o`2<oomn0?ooo`X000Cooo]Z00Goo`3loookJ_ood`3ooo]Zo`3oV@07oookJP03oom80?oonf[ooo]Z
00Kooo]Z00?o0?mloookJ_oonfX01ooonfX00ol00_oooo]ZoookJP02oookJP05oeKo0?oO0?oo01[o
oookJ_oeo`002?oonfX01?ooW03ooo]ZoookJ_l0VOl6oookJP03oomV0?oonf[ooo]Z00;ooo]Z00?o
0?l0oookJ_oonfX02_oonfX4o`0002;ooo]Z00?ooc40oookJ_oonfX0d_oonfX002[ooo]Z0ooob@00
0ol0ojKoolT0ooo90004ooo90003oong0?oonf[ooo]Z00?ooo]Z00?o05;ooookJ_l0obh00_oonfX0
1OoooP3ooo]ZoeOo0?n6o`3oolT000?ooo]Z00Goom`0oookJ_oonf[oolT0oonR0002oom<0004o`3o
DOoonf[o047oo`2Wo`?ooo]Z00?og03ooookJ_oonfX00_oonfX01?ooAP3ooo]ZoookJ_ooR@02oook
JP0Aoomi0?l0ooOoolT0ok?o0?oonf[o0?ngoomi0?oonf[o01Ooo`3Uool0on7oob`0oookJ_lBo`3o
02gooookJ_l0oOl00ooonfX01ooo0:7ooj00o`0gooooN@3oolT0oom30?l0l_l00_ooN@000ol0ok?o
ogT0ool0:`04oookJP03ol00oooonf[oo`2S00GoogT000?o2_l0oomi0?ooN@000_ooN@001?ooS03o
oo]ZojGo0?l0ob@3oookJP04oomi0?oonf[ooo]Zool0>`;ooo]Z00Co0?mjoookJ_oo0<ko0?oR1?oo
nfX00ol0S?oooo]Zool:0004oookJP03ool0o?oonf[oom<000;ooo]Z00?o0?nIoookJ_oonfX01Ooo
nfX00oooB03ooo]ZoookJP05oookJP03o`3oO?oonf[ooo]Z00Oooo]Z00?o00;ooookJ_oonfX00_oo
nfX01_oO0?ooE_l0o`0Jool0;Ooooo]ZooGo00Kooo]Z00Gooi`0ooo90?oob@3oolT0o`2Io`05ooo9
0003oomV0?oob@3oolT000?oolT000?o0?l0oookJ_oonfX02ooonfX5o`00027ooo]Z00?ooc40oook
J_oonfX0n_oonfX00ol0Y?oo0?nVoookJP05oookJP03oong0?oonf[ooo]Z00?ooo]Z0_l0D_l01_l0
obkooo]ZoookJ_oooP3ooo]ZoeOo00;oQ_l000CoocL0oookJ_oonf[oom`00_oonfX02?m9o`3ooo]Z
oonR0?ooC03ooo]Zo`3oDOl0@Ooo0:Oo1?oonfX00ooL0?oooo]ZoookJP02oookJP03oom60?oonf[o
ohT000?ooo]Z0_l0ooL00ooonf[o/ol0o`3o]`03oookJP05o`3Uool0on7ooo]Zool/0?lBo`000_l0
;Ol02ol0oOoo0?n^oookJ_oonf[oo`2QoonP0?n30?oo03OooookJ_oob@3o0?;o00;ooo]Z00Co0?nc
oookJ_l0eOooo`0[0ooonfX01_o00?oooo]ZoookJ_oo0:?ooo]Zool0Q@;ooo]Z00Ko2_l0oookJ_oo
N`3oaOl0oookJ_ooS002oookJP05ojGo0?l0obCooo]ZoookJ_noo`000_oonfX02?oo03_ooo]Zoook
J_l0og[o097ooookJ_oo0<ko0?oR0ooonfX00ol0S?ooOP3oool:0004oookJP03ool0o?oonf[oom<0
00;ooo]Z00?o0?nIoookJ_oonfX01OoonfX00oooB03ooo]ZoookJP05oookJP03o`3oO?oonf[ooo]Z
00Sooo]Z00?o00;ooookJ_oonfX00_oonfX01OoO0?oooo]Zo`0Jool0;OoomOl000Oooo]Z00Cooi`0
oookJ_oonf[o09Wo1_oonfX00oooIP3ooo]ZoookJP02oookJP03o`3o0?oonf[ooo]Z00_ooo]Z1Ol0
000QoookJP03oola0?oonf[ooo]Z0=;ooo]Z000ZoookJP;oolT000?o0?nVooo90?oob@000ooob@02
oong00Gooo]Z00?o05;ooookJ_l0obh00_oonfX01OoooP3oEol0oeOo0?n6o`3oolT000?ooo]Z00Wo
om`0oookJ_oob@3oolT0oonR0?ooC03ooo]Zo`3oDOoonfX00_l0Yol3oookJP03om`0oooonf[ooo]Z
00;ooo]Z00CoodH0oookJ_oonf[oohT00ooonfX01oooN@3ooo]Zok?o0?oonf[o0?ngoomi0?oonfX0
0_l0iOl01?l0on7oob`0oookJ_lBo`02oookJP0;o`3moooonf[ooo]ZoookJ_oo0:7ooj00o`0goooo
N@3oolT0oom30?l0l_l00_ooN@000ol0ok?ooo]Zool0:`04oookJP04ol00oooonf[oo`2SoookJPCo
ogT000Wo2_l0oookJ_ooN@3oogT0oookJ_ooS03ooo]ZojGo0?l0ob@00ooonfX01?ooN@3ooo]Zoook
J_oo03/2oookJP04o`3oN_oonf[oo`3>o`3ohPCooo]Z00?o08coooo90?oo2P001?oonfX00ooo0?co
oo]ZoooC0002oookJP03o`3oVOoonf[ooo]Z00Gooo]Z00?oodP0oookJ_oonfX01OoonfX00ol0ogco
oo]ZoookJP07oookJP03o`02oooonf[ooo]Z00?ooo]Z00Gog`3oo`0Joooonf[o02goooGo0007oook
JP05oonL0?oob@3oolT0ooo90?l0VOl00_oob@001?oonf[oolT0ooo90?ooIP05ooo90003o`3o0?oo
nf[ooo]Z00_ooo]Z1?l0000RoookJP03oola0?oonf[ooo]Z0?Wooo]Z00?o0:Coo`3oY_oonfX01Ooo
nfX00ooo]`3ooo]ZoookJP03oookJP03o`1Boooonf[o0?l^00;ooo]Z00Coooh0oeOo0?mGo`3oQ_l0
0_oo=`02oookJP06oooL0?oonf[oBOl0odWo0?oonf[ooj800_oonfX00ol0oe7o0:Ooo`2Wo`03oook
JP;og03o1?oonfX00oooAP3ooo]Zoon90003oookJP05o`3omooonf[ooo]Zok?o0?l0okL00_oonfX2
o`3Uo`08o`3ohOoonf[oob`0oa;o0?l0;Ooooo]Zo`3mool0ojh2oookJP07ool0XOooX03oP`3oo`0g
oooonf[oolT0o`3bo`02oookJP04o`3o/ooonf[o0=Goool0:`?ooo]Z00Ko`03ooookJ_oonf[oo`2S
oookJ_oo08D3oookJP05o`[o0?ooN`3oaOl0oookJ_ooS0000_oonfX01OnUo`3o0?lToookJ_oonf[o
_ol000;ooo]Z00Soo`0koookJ_oonf[o0?mjo`2Aoooonf[oo`3>o`3ohP?ooo]Z00?o08cooookJ_oo
2P001?oonfX00ooo0?cooo]ZoooC0002oookJP03o`3oVOoonf[ooo]Z00Gooo]Z00?oodP0oookJ_oo
nfX01OoonfX00ol0ogcooo]ZoookJP08oookJP03o`02oooonf[ooo]Z00;ooo]Z00Gog`3ooookJ_l0
6_oooo]ZooGo0008oookJP04oonL0?oonf[oF`3oo`2Io`Gooo]Z00?oofH0oj@0oooonfX00ooonfX0
0ol0o`3ooo]ZoookJP0;oookJPCo00008ooonfX00ooo<@3ooo]ZoookJP3AoookJP00:_oonfX00ooo
b@3o0?nVooo90002ooo900;ooo]Z00?ookL0oookJ_oonfX00ooonfX2o`1Bo`05oookJ_l0obkooo]Z
oookJ_oooP000_oob@000on6o`3oolT0oookJP02oookJP0:oooL0?oonf[oolT0oookJ_ooXP3ood`0
oookJ_l0oe7ooo]Zo`2Wo`Cooo]Z00?og03ooookJ_oonfX00_oonfX01?ooAP3ooo]ZoookJ_ooR@03
oookJP;oogT000?o/ol0o`08ool0okL00_oonfX01_l0iOoooo]Zo`3ohOoo;03ooo]Zoa;o00;ooo]Z
00_o0?gooookJ_oonf[ooo]Zool0XOooX03o03Oooomi0?oob@3ood<0o`3bo`02oomi0003o`3o/ooo
nf[oo`0[00Cooo]Z00Co`03ooookJ_oo0:?ooo]Z0oooN@001?oonf[o2_l0oookJ_ooN@02oookJP04
oon<0?oonf[oYOl0o`3o90?ooo]Z00CoogT0oookJ_oonf[oo`0k0_oonfX01?l0og[o097oool0c_l0
on84oookJP03o`2<oooob@3oo`X000Cooo]Z00?oo`3loookJ_ood`000_oonfX00ol0oiWooo]Zoook
JP05oookJP03oom80?oonf[ooo]Z00Gooo]Z00?o0?mloookJ_oonfX01ooonfX00ol00_oooo]Zoook
JP03oookJP05oml0ool06_oooo]Zo`0]oooeo`001ooonfX01OooW03ooo]Zooo90?oob@3o09Wo00;o
olT00_oonfX2ooo90003oomV0?oob@3oolT000;oolT000?o0?l0oookJ_oonfX03?oonfX4o`0002;o
oo]Z00?ooc40oookJ_oonfX0n?oonfX00ol0Y?oo0?nVoookJP04oookJP;ookL01OoonfX00ol0D_oo
oo]Zo`3o;P02oookJP05ooon0?mGo`3ooo]ZohKo0?oo=`000ooonfX00ooog03ooo]ZodWo0002oook
JP05oonR0?oonf[ooo]Zo`3oDOl0Yol01?oonfX00ooL0?oooo]ZoookJP03oookJP03oom60?oonf[o
ohT000?ooo]Z00Go0?ogoookJ_oonf[o/ol0o`3o]`02oookJP0:o`3Uool05ooo0?oQoookJ_oo;03o
4_l0o`0]oooonf[o0?goo`3o[P;ooo]Z00Ooo`2QoonP0?n30?oo03OooookJ_oob@3o0?;o00;ooo]Z
00Co0?ncoookJ_oo02_oo`0[0ooonfX01_o00?oooo]ZoookJ_oo0:?ooo]Zool0Q@?ooo]Z00Go2_l0
oomk0?o5o`3ooo]Zoon<0002oookJP05ojGo0?l0obCooo]ZoookJ_noo`000_oonfX02?oo03_ooo]Z
oookJ_l0og[ooo]Zo`2Aoooo0<ko0?oR0ooonfX00ol0S?oooo]Zool:0004oookJP03ool0o?oonf[o
om<000;ooo]Z00?o0?nIoookJ_oonfX01OoonfX00oooB03ooo]ZoookJP05oookJP03o`3oO?oonf[o
oo]Z00Sooo]Z00?o00;ooookJ_oonfX00ooonfX01?oO0?oo01[ooookJ_oeo`08oookJP04oonL0?oo
nf[ooo]Zo`2Io`Kooo]Z00?oofH0oookJ_oonfX00_oonfX00ol0o`3ooo]ZoookJP0<oookJPCo0000
8ooonfX00ooo<@3ooo]ZoookJP3AoookJP00:_oonfX00ol0ojKoolT0ooo90003oookJP03oong0?oo
nf[ooo]Z00?ooo]Z00Co05;ooookJ_l0obko0?l^0_oonfX00ooooP3oolT0ooo90002ooo900;ooo]Z
0_oog0002Ooonf[oolT0oookJ_ooXP3ood`0oookJ_l0oe7ooo]Zo`2Wo`04oookJP03om`0oooonf[o
oo]Z00;ooo]Z00CoodH0oookJ_ooR@3oohT00ooonfX2oomi0003ok?o0?l02?oo0?ng00;ooo]Z00Ko
0>GooookJ_l0on7oob`0oookJ_lBo`02oookJP0;o`3moooonf[ooo]ZoookJ_oo0:7ooj00o`0goooo
N@3oolT0oom30?l0l_l00_ooN@000ol0ok?ooo]Zool0:`04oookJP06ol00oooonf[ooo]Zool0Xooo
nf[oogT00_oonfX00ol:o`3ooo]Zoomi0002oookJP04oon<0?ooN@3oYOl0o`3o90?ooo]Z00CoogT0
oookJ_oonf[oo`0k0_oonfX01Ol0og[o097oool0c_l0on;oolT000?ooo]Z00?o08coooo90?oo2P00
1?oonfX00ooo0?cooo]ZoooC0002oookJP03o`3oVOoonf[ooo]Z00Gooo]Z00?oodP0oookJ_oonfX0
1OoonfX00ol0ogcooo]ZoookJP07oookJP03o`02oooonf[ooo]Z00?ooo]Z00Kog`3ooookJ_l06_oo
02gooookJ_oeo`06oookJP03oonL0?oonf[oolT000;oolT000Co09Woooo90?oonf[ooo]Z0_oob@00
0oooIP3oolT0ooo90002ooo90003oookJ_l0o`3ooo]Z00gooo]Z1?l0000SoookJP03oola0?oonf[o
oo]Z0?Oooo]Z00?o0?nVoookJ_oonfX00ooonfX00ooo]`3ooo]ZoookJP04oookJP03o`1Bool0obko
0?l^00;ooo]Z00Goooh0oeOo0?oonf[oQ_l0oolg0003oookJP03oooL0?oonf[oBOl000;ooo]Z00Go
oj80oookJ_oonf[o0?mAo`2Wo`04oookJP03om`0oooonf[ooo]Z00?ooo]Z00?oodH0oon90?ooR@00
0ooonfX01Ol0ooOooo]ZoookJ_nco`3o0?ng00;ooo]Z00[o0>Goo`0Gool0on7ooo]Zool/0?lBo`3o
02gooookJ_l0oOoo0?n^0_oonfX01ooo0:7ooj00oh<0ool0=ooooo]Zooo90?l0l_l00_oonfX01?l0
ok?ooo]Zool0:ol0okH3oookJP06ol00oooonf[ooo]Zool0Xooonf[oo`250ooonfX01Ol:o`3oog/0
olGo0?oonf[ooh`000;ooo]Z00GoYOl0o`3o9?oonf[ooo]Zokoo0002oookJP08ool0>ooonf[ooo]Z
o`3oN_oonf[o097oool0c_l0on83oookJP03o`2<oooonf[oo`X000Cooo]Z00?oo`3loookJ_ood`00
0_oonfX00ol0oiWooo]ZoookJP05oookJP03oom80?oonf[ooo]Z00Kooo]Z00?o0?mloookJ_oonfX0
1ooonfX00ol00_oooo]ZoookJP03oookJP05oml0oooonf[o01[oo`0]oooeo`001ooonfX01OooW03o
oo]ZoookJ_mK0?oo09Wo00Gooo]Z00?oofH0oj@0oooonfX00ooonfX00ol0o`3ooo]ZoookJP0<oook
JPCo00008ooonfX00ooo<@3ooo]ZoookJP3AoookJP00:_oonfX00ooob@3ooo]ZoookJP02oookJP03
oong0?oonf[ooo]Z00?ooo]Z00?o05;ooookJ_l0obh00_oonfX2ooon00KoolT000Ooom`0oookJ_oo
nf[oolT0oookJ_ooXP3ood`000;o0?mA00?ooo]Zo`2WoooonfX00ooonfX00ooL0?oooo]ZoookJP02
oookJP03oom60?oonf[oohT000Cooo]Z00Go0?ogoomi0?nco`3o00Soo`3o]`02oomi0006o`3Uoooo
nf[o0?oQool/0?oonf[o4_l00_oonfX02_l0oOoooo]ZoookJ_oonf[oo`2QoonP0?l0=oooogT0ooo9
0?oo@`02oomi0004oookJ_l0ok?ooo]Zool0:`Cooo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_ooN@02
oookJP0:o`[o0?oonf[oog/0olGo0?oonf[ooh`0oookJ_ooN@3oYOl0oomi00;ooo]Z00[oogT0oook
J_oonf[ooo]Zool0>ooonf[o0?mjo`2Aoooo0<ko0?oR0ooob@001?oonf[o08coooo90?oo2P04oook
JP06ool0o?oonf[ooo]ZoooC0?oonf[o0?nI1ooonfX00oooB03ooo]ZoookJP05oookJP03o`3oO?oo
nf[ooo]Z00Sooo]Z00?o00;oooo90?oob@000_oonfX01_oob@3oE_l0o`0Joooonf[o02goooGo00Oo
oo]Z00Kooi`0oookJ_oob@3oolT0o`2Ioooob@03oookJP;oolT000KoofH0ooo90?oob@3oolT0oook
J_l0o`0?oookJPCo00008ooonfX00ooo<@3ooo]ZoookJP3loookJP03oong0?oonf[ooo]Z00Cooo]Z
00Co05;oo`3o;_oonf[ooo]Z0_oooP001?mGo`3ooo]ZohKo0?oo=`02oookJP;oom`000Kooo]ZodWo
0?oonf[ooo]ZoonR0?oonfX2o`3oD@03o`2Woooonf[ooo]Z00;ooo]Z00?og03ooookJ_oonfX00ooo
nfX00oooAP3oohT0oookJP03oookJP05o`3omooonf[ooo]Zok?o0?l0okL00_oonfX02_l0iOoo01Oo
o`3ohOoonf[oob`0oa;o0?l0;Ooooo]Zo`3mool0ojh2oookJP07ool0XOooX03oP`3oo`0goooonf[o
olT0o`3bo`02oookJP04o`3o/ooonf[oo`0[o`3o]P?ooo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_oo
08D3oookJP05o`[o0?ooN`3ooo]ZolGo0?ooS0000ooonfX01?nUo`3ooo]ZoookJ_noo`03oookJP07
ool0>ooonf[o0?mjoookJ_l0TOooo`3>o`3ohP03oookJP03o`2<oooonf[oo`X000Cooo]Z00Koo`3l
oookJ_oonf[oom<0oookJ_l0oiT7oookJP03oom80?oonf[ooo]Z00Kooo]Z00?o0?mloookJ_oonfX0
2?oonfX00ol00_oooo]ZoookJP02oookJP05oml0oooonf[o01[ooookJ_oeo`002?oonfX01?ooW03o
oo]ZoookJ_l0VOl6oookJP03oomV0?oonf[ooo]Z00;ooo]Z00?o0?l0oookJ_oonfX03OoonfX4o`00
02Cooo]Z00?ooc40oookJ_oonfX0d?oonfX002kooo]Z00?ookL0oookJ_oonfX00ooonfX00ol0D_oo
oo]Zo`3o;P02oookJP03ooon0?oonf[oolT000OoolT000Kooo]Zooo90?oonf[ooj80oom<0?l0oe42
oookJP04o`2Woooonf[ooo]ZoookJP;og03o1?oonfX00oooAP3ooo]Zoon90004oookJP03o`3omooo
N@3o/ol000;o0?ng1?ooN@001?l0on7oob`0oookJ_lBo`02oookJP0;o`3moooonf[ooo]ZoookJ_oo
0:7ooj00o`0gooooN@3oolT0oom30?ooN@000_oonfX00ol0ok?ooo]Zool0:`04oookJP06ol00oooo
nf[ooo]Zool0Xooonf[oo`250_oonfX02Ol:o`3ooo]Zoomk0?o5o`3ooo]Zoon<0?oonf[oogT0ojGo
0004oomi00?ooo]Z00Koo`0koookJ_l0og[o097oool0c_l0on84ooo90003o`2<oooob@3oolT000Co
oo]Z00Coo`3loookJ_oonf[oom<00_oonfX00ol0oiWooo]ZoookJP05oookJP03oom80?oonf[ooo]Z
00Gooo]Z00?o0?mloookJ_oonfX01ooonfX00ol00_oooo]Zooo90002ooo90006oookJ_oob@3o01[o
oookJ_l0;OoomOl01ooonfX00oooW03ooo]ZoookJP02ooo90003o`2Ioooonf[ooo]Z00;ooo]Z00?o
olT0oomV0?oob@000_oob@02oookJP03o`3o0?oonf[ooo]Z00gooo]Z1?l0000SoookJP03oola0?oo
nf[ooo]Z0?_ooo]Z00?ookL0oookJ_oonfX01?oonfX02_l0D_oo0?l^oookJ_oonf[oooh0oookJ_mG
o`3ooo]ZohKo0?oo=`02oookJP05oooL0?oonf[ooo]ZodWo0?oonfX00_ooXP001?oonf[o0?mAoook
J_l0Yol4oookJP03om`0oooonf[ooo]Z00?ooo]Z00?oodH0oon90?oonfX00ooonfX01Ol0ooOooo]Z
oookJ_nco`3o0?ng00;ooo]Z00[o0>Goo`0Gool0on7ooo]Zool/0?lBo`3o02gooookJ_l0oOoo0?n^
0_oonfX03Ooo0:7ooj00oh<0ool0=ooooo]Zooo90?oo@`3o0?;ooookJ_l0ok?ooo]Zool0:ol0okH0
0ooonfX01_o00?oooo]ZoookJ_oo0:?ooo]Zool0Q@?ooo]Z00Go2_l0oomk0?oonf[oaOl0oon<0003
oookJP04ojGo0?oonf[ooo]Zokoo00?ooo]Z00Ooo`0koookJ_l0og[ooo]Zo`2Aoooo0<ko0?oR00?o
oo]Z00?o08cooookJ_oo2P001?oonfX01?oo0?cooo]ZoookJ_ood`02oookJP03o`3oVOoonf[ooo]Z
00Gooo]Z00?oodP0oookJ_oonfX01OoonfX00ol0ogcooo]ZoookJP08oookJP03o`02oooonf[ooo]Z
00?ooo]Z00Gog`3oo`0Joooonf[o02goooGo0007oookJP05oonL0?oonf[ooo]Zoe/0ool0VOl01Ooo
nfX00oooIP3oY03ooookJP03oookJP03o`3o0?oonf[ooo]Z00gooo]Z1?l0000ToookJP03oola0?oo
nf[ooo]Z0=3ooo]Z000]oookJP03oong0?oonf[ooo]Z00?ooo]Z00?o05;ooookJ_l0obh00_oonfX0
0ooooP3ooo]ZoeOo0009ooo90004oookJ_ooXP3ood`0o`3oD@;ooo]Z00Go0:OooookJ_oonf[ooo]Z
om`0o`05oookJP03oom60?oonf[oohT000Cooo]Z00Go0?ogoomi0?nco`3o0?ngonl0o`05oomi0003
ool/0?lBo`3o4_l000;ooo]Z00_o0?gooookJ_oonf[ooo]Zool0XOooX03o03OooookJ_oob@3ood<0
oomi0002oookJP03o`3o/ooonf[oo`0[00Cooo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_oo08D2oook
JP06o`[o0?oonf[oog/0olGo0?oonf[ooh`00_oonfX00onUo`3oogT0oomi0003oomi00;ooo]Z00Oo
o`0koookJ_l0og[o097oool0c_l0on;ooo]Z00?oolT000Co08coooo90?oob@3oolT01?oonfX00ooo
0?cooo]ZoooC0002oookJP03o`3oVOoonf[ooo]Z00Gooo]Z00?oodP0oookJ_oonfX01OoonfX00ol0
ogcooo]ZoookJP07oookJP03o`02oooonf[oolT000GoolT000?o01[ooookJ_oeo`002?oonfX01Ooo
W03ooo]ZoookJ_oob@3o09Wo00Cooo]Z0_oob@000oooIP3oolT0ooo90002oookJP03o`3o0?oonf[o
oo]Z00kooo]Z1?l0000SoookJP03oola0?oonf[ooo]Z0?[ooo]Z00?ookL0oookJ_oonfX01?oonfX0
1ol0D_oo0?l^oookJ_oonf[oooh0oookJ_mGo`000_n6o`001?oo=`3ooo]ZoookJ_oog002oookJP08
odWo0?oonf[ooj80oom<0?oonf[o0?mAoookJ_l0Yol4oookJP03om`0oooonf[ooo]Z00?ooo]Z00?o
odH0oon90?oonfX00ooonfX01Ol0ooOooo]ZoookJ_nco`3o0?ng00;ooo]Z00Co0>Goo`0Gool0on7o
oo]Z0_lBo`001?l0;Ooooo]Zo`3mool0ojh2oookJP0=ool0XOooX03oP`3oo`0goooonf[oolT0oom3
0?l0l_oooo]Zo`3o/ooonf[oo`0[o`3o]P03oookJP06ol00oooonf[ooo]Zool0Xooonf[oo`250ooo
nfX01Ol:o`3oog/0oookJ_o5o`3ooh`000?ooo]Z00CoYOl0oookJ_oonf[o_ol00ooonfX01ooo03_o
oo]Zo`3oN_oonf[o097oool0c_l0on800ooonfX01?l0S?oooo]Zogh0oooo2P04oookJP03ool0o?oo
nf[oom<000;ooo]Z00?o0?nIoookJ_oonfX01OoonfX00oooB03ooo]ZoookJP05oookJP03o`3oO?oo
nf[ooo]Z00Sooo]Z00?o00;ooookJ_oonfX00ooonfX01OoO0?oooo]Zo`0Jool0;OoomOl000Sooo]Z
00Cooi`0oookJ_mK0?oo09Wo1_oonfX00oooIP3ooo]ZoookJP02oookJP03o`3o0?oonf[ooo]Z00ko
oo]Z1?l0000ToookJP03oola0?oonf[ooo]Z0=3ooo]Z000/oookJP03oong0?oonf[ooo]Z00?ooo]Z
00?o05;ooookJ_l0obh00_oonfX00ooooP3oEol0oeOo000:ooo90003oonR0?ooC03o0?mA00;ooo]Z
00Go0:OooookJ_oonf[ooo]Zom`0o`05oookJP03oom60?oonf[oohT000Cooo]Z00Go0?ogoomi0?nc
o`3o0?ngonl0o`05oomi0003ool/0?lBo`3o02go00;ooo]Z00So0?gooookJ_oonf[ooo]Zool0XOoo
X03o03OooookJP;oolT000KoogT0oookJ_oonf[o0?ncoookJ_oo02/4oookJP06ol00oooonf[ooo]Z
ool0Xooonf[oo`250_oonfX01_l:o`3ooo]Zoomk0?o5o`3ooo]Zoon<00;ooo]Z00?oYOl0o`3o9?oo
N@001OooN@001ooo03_ooo]Zo`3oN_l0TOooo`3>o`3oh_oonfX00ooob@000ol0S?ooolT0ooo90002
ooo900?ooo]Z00?oo`3loookJ_ood`000_oonfX00ol0oiWooo]ZoookJP05oookJP03oom80?oonf[o
oo]Z00Gooo]Z00?o0?mloookJ_oonfX02?oonfX00ol00_oooo]Zooo90006ooo90003o`0]oooeo`3o
oo]Z00Kooo]Z00Gooi`0oookJ_oonf[oolT0o`2Io`05oookJP04ooo90?ooIP3oolT0ooo900?ooo]Z
00?o0?l0oookJ_oonfX03_oonfX4o`0002?ooo]Z00?ooc40oookJ_oonfX0nOoonfX00ooo]`3ooo]Z
oookJP04oookJP05o`1Bool0obkooo]ZoookJ_oooP000_mGo`000on6o`3oocL0oolg0002oookJP0;
oooL0?oonf[ooo]ZodWo0?oonf[ooj80oom<0?oonf[o0?mAoookJ_l0Yol01?oonfX00ooL0?oooo]Z
oookJP03oookJP03oom60?ooR@3ooo]Z00?ooo]Z00Go0?ogoookJ_oonf[o/ol0o`3o]`02oookJP0:
o`3Uool0ohco0?oQoookJ_lBo`3ooo]Zo`0]oooonf[o0?goo`3o[P;ooo]Z00Goo`2QoonP0?l0=ooo
03OooookJP02oom30006o`3boooonf[o0?ncoookJ_oo02_o0?nf0ooonfX01_o00?oooo]ZoookJ_oo
0:?ooo]Zool0Q@?ooo]Z00Go2_l0oomk0?oonf[oaOl0oon<0003oookJP04ojGo0?oonf[ooo]Zokoo
00?ooo]Z00Ooo`0koookJ_l0og[ooo]Zo`2Aoooo0<ko0?oR00?ooo]Z00Co08cooookJ_mn0?ooo`X0
1?oonfX00ooo0?cooo]ZoooC0002oookJP03o`3oVOoonf[ooo]Z00Gooo]Z00?oodP0oookJ_oonfX0
1_oonfX00ol0ogcooo]ZoookJP08oookJP03o`02oooonf[ooo]Z00;ooo]Z00Gog`3ooeKo0?l06_oo
02goooGo0008oookJP04oonL0?oonf[ooo]Zo`2Io`Kooo]Z00?oofH0oookJ_oonfX00ooonfX00ol0
o`3ooo]ZoookJP0>oookJPCo00009?oonfX00ooo<@3ooo]ZoookJP3@oookJP00:ooonfX00ooo]`3o
oo]ZoookJP02oookJP;o05;o00Oooo]Zo`3o;_oonf[ooo]Zooon0?mGo`3ooo]Z00coolT000Co0?mA
oookJ_oonf[o0:Oo0ooonfX00ooL0?oooo]ZoookJP02oookJP;oodH000?ooo]Zoon90?oonfX00ooo
nfX01Ol0ooOooo]Zok?o0?l0okOok`3o00CoogT000Co0?oQool/0?lBo`3o02go0_oonfX02ol0oOoo
oo]ZoookJ_oonf[oo`2QoonP0?l0=ooooo]Zooo90?oonf[oogT000;ooo]Z00?o0?ncoookJ_oo02/0
1?oonfX01_o00?oooo]ZoookJ_oo0:?ooo]Zool0Q@;ooo]Z00Ko2_l0oookJ_ooN`3oaOl0oookJ_oo
S002oookJP03ojGo0?l0obCoogT000GoogT000Koo`0koomi0?l0og[o097oool0c_l0on82oookJP?o
olT000?o08coooo90?oob@000ooob@001?oonf[oo`3loookJ_ood`02oookJP03o`3oVOoonf[ooo]Z
00Gooo]Z00?oodP0oookJ_oonfX01OoonfX00ol0ogcooo]ZoookJP08oookJP03o`02oooonf[ooo]Z
00OoolT000?omOl0oookJ_oonfX01OoonfX01_ooW03ooo]ZoookJ_oonf[oolT0o`2Io`Gooo]Z00?o
olT0oomV0?oob@000ooonfX00ol0o`3ooo]ZoookJP0?oookJPCo00009?oonfX00ooo<@3ooo]Zoook
JP3goookJP03oong0?oonf[ooo]Z00?ooo]Z0_l0D_l02?l0obkooo]ZoookJ_oooP3oEol0oookJ_n6
o`3oocL00ooonfX02ooog03ooo]ZodWo0?m9o`3ooo]ZoonR0?ooC03ooo]Zo`3oDOoonf[o0:Oo00Co
oo]Z00?og03ooookJ_oonfX00_oonfX2oom60003oon90?oonf[ooo]Z00;ooo]Z00Go0?ogoookJ_oo
nf[o/ol0o`3o]`02oookJP0:o`3Uool0ohco0?oQool/0?lBo`3ooo]Zo`0]oooonf[o0?goo`3o[P;o
oo]Z00goo`2QoonP0?l0=ooooo]Zo`08oooo@`3ooo]Zo`3boooonf[o0?ncoookJ_oo02_o0?nf00?o
oo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_oo08D3oookJP05o`[o0?ooN`3ooo]ZolGo0?ooS0000ooo
nfX01?nUo`3ooo]ZoookJ_noo`03oookJP07ool0>ooonf[ooo]Zo`3oN_l0TOooo`3>o`3ohP04oook
JP03o`2<oomn0?ooo`X000Cooo]Z00?oo`3loookJ_ood`000_oonfX00ol0oiWooo]ZoookJP05oook
JP03oom80?oonf[ooo]Z00Kooo]Z00?o0?mloookJ_oonfX02?oonfX00ol00_oooo]ZoookJP02oook
JP06oml0oomFo`3o01[ooookJ_l0;OoomOl01ooonfX01OooW03ooo]ZoookJ_mK0?oo09Wo00Kooo]Z
00?oofH0oookJ_oonfX00_oonfX00ol0o`3ooo]ZoookJP0?oookJPCo00009?oonfX00ooo<@3ooo]Z
oookJP3@oookJP00:_oonfX00ooo]`3ooo]ZoookJP02oookJP04o`1Boooonf[o0?l^o`3o;P;ooo]Z
00?oooh0oeOo0?oonfX03_oob@02o`2Wo`?ooo]Z00?og03ooookJ_oonfX00_oonfX01?ooAP3ooo]Z
oookJ_ooR@04oookJP05o`3omooonf[o/ol0o`3o]oo_0?l00oooN@001Ooonf[o0?oQool/0?lBo`3o
02go00;ooo]Z00_o0?gooookJ_oonf[ooo]Zool0XOooX03o03OooookJ_oob@3ooo]Zoomi0002oook
JP03o`3o/ooonf[oo`0[00Cooo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_oo08D2oookJP06o`[o0?oo
nf[oog/0olGo0?oonf[ooh`00_oonfX00onUo`3o0?lToomi0005oomi0007ool0>ooonf[o0?mjooo9
0?oo0<kooo]Zo`3ohP04ooo90003o`2<oooob@3oolT000;oolT00_oonfX00ooo0?cooo]ZoooC0002
oookJP03o`3oVOoonf[ooo]Z00Gooo]Z00?oodP0oookJ_oonfX01OoonfX00ol0ogcooo]ZoookJP08
oookJP03o`02oooonf[oolT000OoolT000?omOl0oookJ_oonfX01_oonfX01OooW03ooo]ZoookJ_oo
nf[o09Wo00Kooo]Z00?oofH0ooo90?oonfX00ooonfX00ol0o`3ooo]ZoookJP0?oookJPCo00009?oo
nfX00ooo<@3ooo]ZoookJP3foookJP03oong0?oonf[ooo]Z00?ooo]Z00?o05;oo`3o;_l0obh00_oo
nfX01OoooP3oEol0oookJ_n6o`3oocL000?ooo]Z00?oom`0oookJ_m9o`000_oonfX01_ooXP3ood`0
oookJ_l0oe7ooo]Zo`2Wo`Cooo]Z00?og03ooookJ_oonfX00_oonfX00oooAP3ooo]Zoon90004oook
JP05o`3omooonf[ooo]Zok?o0?l0okL00_oonfX02_l0iOoo0?n<o`3ohOoo;03o4_l0oookJ_l0;Ooo
oo]Zo`3mool0ojh2oookJP0=ool0XOooX03o03OooookJ_l02?oood<0oookJ_l0l_oooo]Zo`3o/ooo
nf[oo`0[o`3o]P03oookJP06ol00oooonf[ooo]Zool0Xooonf[oo`250ooonfX01Ol:o`3oog/0oook
J_o5o`3ooh`000?ooo]Z00CoYOl0oookJ_oonf[o_ol00ooonfX01ooo03_ooo]ZoookJ_l0og[o097o
ool0c_l0on801?oonfX00ol0S?ooOP3oool:0004oookJP03ool0o?oonf[oom<000;ooo]Z00?o0?nI
oookJ_oonfX01OoonfX00oooB03ooo]ZoookJP06oookJP03o`3oO?oonf[ooo]Z00Sooo]Z00?o00;o
oookJ_oonfX00ooonfX01OoO0?oo01[ooookJ_l0;OoomOl000Sooo]Z00Cooi`0oookJ_oonf[o09Wo
1_oonfX00oooIP3ooo]ZoookJP03oookJP03o`3o0?oonf[ooo]Z00oooo]Z1?l0000UoookJP03oola
0?oonf[ooo]Z0<oooo]Z000^oookJP03o`1Boooonf[o0?l^00?ooo]Z00Coooh0oeOo0?oonf[oQ_l0
3?oob@000ooonf[o0:Ooo`11o`03oookJP03om`0oooonf[ooo]Z00;ooo]Z00CoodH0oookJ_oonf[o
ohT01?oonfX01Ol0ooOooo]Zok?o0?l0okOok`3o00;oogT000Ko0>GooookJ_l0on7oob`0oa;o0?l0
;Ol2oookJP04o`3moooonf[ooo]ZoookJP;ooj0000Go03OooookJ_oob@3ooo]Zoomi0002oookJP03
o`3o/ooonf[oo`0[00Cooo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_oo08D2oookJP06o`[o0?oonf[o
og/0olGo0?oonf[ooh`00_oonfX00onUo`3o0?lToomi0005oomi0008ool0>ooonf[o0?mjoookJ_oo
0<kooo]Zo`3oh_oonfX3ooo90003o`2<oooob@3oolT000;oolT00_oonfX01_oo0?cooo]ZoookJ_oo
d`3ooo]Zo`3oV@Sooo]Z00?oodP0oookJ_oonfX01?oonfX00ol0ogcooo]ZoookJP08oookJP03o`02
oooonf[ooo]Z00OoolT000?o02goooGo0?oonfX01_oonfX01OooW03ooo]ZoookJ_oonf[o09Wo00Ko
oo]Z00?oofH0ooo90?oonfX00ooonfX00ol0o`3ooo]ZoookJP0@oookJPCo00009?oonfX00ooo<@3o
oo]ZoookJP3koookJP03o`1Bool0obkooo]Z00;ooo]Z00Goooh0oeOo0?oonf[oQ_l0oolg0002oook
JP;oom`000[ooo]ZodWo0?oonf[ooo]ZoonR0?ooC03ooo]Zo`3oDOl0@Ooo0:Oo1?oonfX00ooL0?oo
oo]ZoookJP02oookJP03oom60?oonf[oohT000Cooo]Z00Go0?ogoookJ_oonf[o/ol0o`3o]`02oook
JP05o`3Uool0ohco0?oQool/0?lBo`000_l0;Ol00ooonf[o0?goo`3o[P02oookJP;ooj0000_o03Oo
oookJ_l02?oood<0oookJ_l0l_oooo]Zo`3o/ooonf[oo`0[o`3o]P03oookJP06ol00oooonf[ooo]Z
ool0Xooonf[oo`250ooonfX01Ol:o`3oog/0oookJ_o5o`3ooh`000?ooo]Z00CoYOl0oookJ_oonf[o
_ol00ooonfX01ooo03_ooo]ZoookJ_l0og[ooo]Zool0c_l0on801?oonfX00ol0S?ooOP3oool:0004
oookJP06ool0o?oonf[ooo]ZoooC0?oonf[o0?nI2?oonfX00oooB03ooo]ZoookJP05oookJP03o`3o
O?oonf[ooo]Z00Sooo]Z00?o00;ooookJ_oonfX00ooonfX01_oO0?ooE_l0o`0Jool0;Ooooo]ZooGo
00Oooo]Z00Cooi`0oookJ_oonf[o09Wo1_oonfX00oooIP3oY03ooookJP03oookJP03o`3o0?oonf[o
oo]Z013ooo]Z1?l0000UoookJP03oola0?oonf[ooo]Z0<oooo]Z000]oookJP03o`1Boooonf[o0?l^
00;ooo]Z0_oooP000omGo`3ooo]ZohKo0003ooo90003oooL0?oonf[oolT000GoolT000?o0?mAoook
J_l0Yol01?oonfX00ooL0?oooo]ZoookJP02oookJP04oom60?oonf[oohT0oon900Cooo]Z00go0?og
oookJ_nco`3o0?ngonl0ooooN@3ooo]Zo`3Uoooonf[o0?oQool/0?lBo`3o02go00;ooo]Z00_o0?go
oookJ_oonf[ooo]ZoonP0?oonf[o03OooookJ_oob@3ooo]Zoomi0002oookJP03o`3o/ooonf[oo`0[
00Cooo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_oo08D2oookJP06o`[o0?oonf[oog/0olGo0?oonf[o
oh`00_oonfX00onUo`3o0?lToomi0005oomi0008ool0>ooonf[o0?mjoookJ_oob@3oo`3>o`3oh_oo
nfX7ooo900?ooo]Z00Coo`3loookJ_oonf[oom<00_oonfX00ol0oiWooo]ZoookJP05oookJP03oom8
0?oonf[ooo]Z00Cooo]Z00?o0?mloookJ_oonfX02OoonfX00ol00_oooo]Zooo90006ooo90003oook
J_oeo`3ooo]Z00Oooo]Z00Gooi`0oookJ_oonf[oF`3oo`2Io`06oookJP03oomV0?oonf[ooo]Z00?o
oo]Z00?o0?l0oookJ_oonfX04?oonfX4o`0002Gooo]Z00?ooc40oookJ_oonfX0n?oonfX2o`1Bo`03
o`3o;_oonf[ooo]Z00;oooh000CoEol0oookJ_n6o`3oocL00_oonfX01?oog03ooo]ZoookJ_m9o`02
oookJP06oonR0?ooC03o0?mAo`3oDOl0@Ooo0:Oo1?oonfX00ooL0?oooo]ZoookJP02oookJP03oom6
0?oonf[oohT000Cooo]Z00Go0?ogoookJ_oonf[o/ol0o`3o]`02oookJP06o`3Uool0ohco0?oQool/
0?lBo`3o02go0_oonfX04Ol0oOoo0?n^oookJ_oonf[ooj00oookJ_l0=ooooo]Zo`08oooo@`3ooo]Z
o`3boooonf[o0?ncoookJ_oo02_o0?nf00?ooo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_oo08D3oook
JP05o`[o0?ooN`3ooo]ZolGo0?ooS0000ooonfX01?nUo`3ooo]ZoookJ_noo`03oookJP07ool0>ooo
nf[ooo]Zo`3oN_oonf[o097oool0cP04oookJP03o`2<oomn0?ooo`X000Cooo]Z00Coo`3loookJ_oo
nf[oom<00_oonfX00ol0oiWooo]ZoookJP05oookJP03oom80?oonf[ooo]Z00Gooo]Z00?o0?mloook
J_oonfX02OoonfX00ol00_oooo]ZoookJP02oookJP06oml0oomFo`3o01[ooookJ_l0;OoomOl02?oo
nfX01?ooW03ooo]Zoe/0ool0VOl6oookJP03oomV0?oonf[ooo]Z00?ooo]Z00?o0?l0oookJ_oonfX0
4?oonfX4o`0002Gooo]Z00?ooc40oookJ_oonfX0cooonfX002cooo]Z00?o05;ooookJ_l0obh00_oo
nfX01OoooP3ooo]ZoeOo0?oonf[oQ_l000;oolT000?ooo]ZoooL0?oonfX01Ooob@001?ooC03ooo]Z
oookJ_l0Yol3oookJP;og03o1?oonfX00oooAP3ooo]Zoon90005oookJP05o`3omooonf[o/ol0o`3o
]oo_0?l00_oonfX01_l0iOoooo]Zo`3ohOoo;03o4_l0o`0]o`;ooo]Z00_o0?gooookJ_oonf[ooo]Z
oonP0?ooN@3o03OooookJ_oob@3ooo]Zoomi0002oookJP03o`3o/ooonf[oo`0[00Cooo]Z00Ko`03o
oookJ_oonf[oo`2SoookJ_oo08D2oookJP06o`[o0?oonf[oog/0olGo0?oonf[ooh`00_oonfX00onU
o`3o0?lToomi0004oomi0008oookJ_oo03_ooo]Zo`3oN_oonf[oolT0ool0c_l0on82oookJPKoolT0
0ooonfX01?oo0?cooo]ZoookJ_ood`02oookJP03o`3oVOoonf[ooo]Z00Gooo]Z00?oodP0oookJ_oo
nfX01OoonfX00ol0ogcooo]ZoookJP08oookJP03o`02oooonf[ooo]Z00KoolT000?ooo]Zooo90?oo
nfX01ooonfX01OooW03ooo]ZoookJ_oonf[o09Wo00Kooo]Z00?oofH0oj@0oooonfX00ooonfX00ol0
o`3ooo]ZoookJP0AoookJPCo00009OoonfX00ooo<@3ooo]ZoookJP3goookJP03o`1Boooonf[o0?l^
00;ooo]Z00Koooh0oookJ_mGo`3ooo]ZohKo0?oo=`02oookJP04oooL0?oonf[ooo]ZodWo00;ooo]Z
00Kooj80oom<0?l0oe7ooo]Zo`11ool0Yol3oookJP;og03o1?oonfX00oooAP3ooo]Zoon90004oook
JP05o`3omooonf[ooo]Zok?o0?l0okL00_oonfX01_l0iOoo0?n<o`3ohOoo;03o4_l0o`0]o`;ooo]Z
017o0?goo`3o[_oonf[ooo]ZoonP0?oonf[o03OooookJ_l02?oood<0oookJ_l0l_oooo]Zo`3o/ooo
nf[oo`0[o`3o]P03oookJP06ol00oooonf[ooo]Zool0Xooonf[oo`250ooonfX01Ol:o`3oog/0oook
J_o5o`3ooh`000?ooo]Z00CoYOl0oookJ_oonf[o_ol00ooonfX01ooo03_ooo]ZoookJ_l0og[ooo]Z
o`2Aoooo0<h01?oonfX00ol0S?ooOP3oool:0004oookJP04ool0o?oonf[ooo]ZoooC00;ooo]Z00?o
0?nIoookJ_oonfX01OoonfX00oooB03ooo]ZoookJP06oookJP03o`3oO?oonf[ooo]Z00Sooo]Z00?o
00;ooookJ_oonfX00ooonfX01OoO0?oo01[ooookJ_l0;OoomOl000Sooo]Z00Cooi`0oookJ_oonf[o
09Wo1_oonfX00oooIP3oY03ooookJP03oookJP03o`3o0?oonf[ooo]Z017ooo]Z1?l0000UoookJP03
oola0?oonf[ooo]Z0<oooo]Z000[oookJP03o`1Boooonf[o0?l^00;ooo]Z00Koooh0oookJ_mGo`3o
oo]Zoolg0?oob@02oookJP03oooL0?oonf[oolT000?oolT000Good`0o`3oDOoonf[ooo]Zo`2Wo`03
oookJP03om`0oooonf[ooo]Z00?ooo]Z00?oodH0oookJ_ooR@001OoonfX01Ol0ooOooo]Zok?o0?l0
okOok`3o00;ooo]Z00Ko0>Goo`3ohOl0on7oob`0oa;o0?l0;Ol2oookJP0;o`3moooonf[ooo]Zoook
J_ooX03ooo]Zoomi0?oonf[oolT0oookJ_ooN@000_oonfX00ol0ok?o0=Goool0:`04oookJP06ol00
oooonf[ooo]Zool0Xooonf[oo`250_oonfX01_l:o`3ooo]Zoomk0?o5o`3ooo]Zoon<00;ooo]Z00?o
YOl0o`3o9?oonfX01?ooN@002?oonf[oo`0koookJ_l0og[ooo]Zooo90?oo0<ko0?oR0_oonfX8ooo9
0005oookJ_oo0?cooo]ZoookJ_ood`000_oonfX00ol0oiWooo]ZoookJP05oookJP03oom80?oonf[o
oo]Z00Gooo]Z00?o0?mloookJ_oonfX02?oonfX01?l00_oooo]ZoookJ_oonfX6ooo90003o`0]oooo
b@3ooo]Z00Kooo]Z00Gooi`0oookJ_oonf[ooo]Zo`2Io`07oookJP03oomV0?oonf[ooo]Z00?ooo]Z
00?o0?l0oookJ_oonfX04OoonfX4o`0002Gooo]Z00?ooc40oookJ_oonfX0m_oonfX00ol0D_oooo]Z
o`3o;P02oookJP04ooon0?oonf[oEol0oookJP;oocL00_oonfX01Ooog03ooo]ZoookJ_m9o`3ooo]Z
00;ooj8000?ooo]Zo`3oDOoonfX00_l0Yol3oookJP03om`0oooonf[ooo]Z00?ooo]Z00?oodH0oook
J_ooR@001?oonfX01Ol0ooOooo]Zo`08oonco`3o0?ng00;ooo]Z00Ko0>Goo`3ohOl0on7oob`0oa;o
0?l0;Ol2oookJP0Ao`3mool0ojkooo]ZoookJ_ooX03ooo]Zo`0goooonf[o00Sooom30?oonf[o0?;o
oookJ_l0ok?ooo]Zool0:ol0okH00ooonfX01_o00?oooo]ZoookJ_oo0:?ooo]Zool0Q@?ooo]Z00Go
2_l0oomk0?oonf[oaOl0oon<0003oookJP04ojGo0?oonf[ooo]Zokoo00?ooo]Z00Ooo`0koookJ_oo
nf[o0?mjoookJ_l0TOooo`3>00Cooo]Z00?o08coogh0oooo2P001?oonfX01?oo0?cooo]ZoookJ_oo
d`02oookJP03o`3oVOoonf[ooo]Z00Gooo]Z00?oodP0oookJ_oonfX01_oonfX00ol0ogcooo]Zoook
JP08oookJP03o`02oooonf[ooo]Z00?ooo]Z00Kog`3ooookJ_l06_oo02gooookJ_oeo`07oookJP04
oonL0?oonf[ooo]Zo`2Io`Oooo]Z00?oofH0oookJ_oonfX00ooonfX00ol0o`3ooo]ZoookJP0Aoook
JPCo00009OoonfX00ooo<@3ooo]ZoookJP3?oookJP00:_oonfX00ol0D_oooo]Zo`3o;P02oookJP05
ooon0?oonf[oEol0ohKo0?oo=`000ooonfX00ooog03ooo]ZoookJP03ooo90005oom<0?l0oe7ooo]Z
oookJ_l0Yol00ooonfX00ooL0?oooo]ZoookJP03oookJP03oom60?oonf[oohT000Gooo]Z00Go0?og
oookJ_nco`3o0?ngonl0o`02oookJP06o`3Uool0on7ooo]Zool/0?lBo`3o02go0_oonfX01_l0oOoo
oo]ZoookJ_oonf[ooj00oookJP?oogT000Oooo]Zoomi0?oonf[ooo]Zo`3o/ol0eOooo`0[00Cooo]Z
00Ko`03ooookJ_oonf[oo`2SoookJ_oo08D2oookJP06o`[o0?oonf[oog/0oookJ_o5o`3ooh`00_oo
nfX00onUo`3o0?lToookJP03oomi00;oolT000Ooo`0koookJ_l0og[ooo]Zooo90?oo0<ko0?oR00?o
oo]Z2Ooob@000ooo0?cooo]ZoooC0002oookJP03o`3oVOoonf[ooo]Z00Gooo]Z00?oodP0oookJ_oo
nfX01OoonfX00ol0ogcooo]ZoookJP09oookJP03o`02oooonf[ooo]Z00WoolT01ooonfX01OooW03o
oo]ZoookJ_oonf[o09Wo00Kooo]Z00?oofH0oookJ_oonfX00ooonfX01?l0o`3o001oo`00Ool007l4
oookJPGo001o2?oonfX4o`0002Gooo]Z00?ooc40oookJ_oonfX0mOoonfX00ol0D_oooo]Zo`3o;P02
oookJP05ooon0?oonf[oEol0ohKo0?oo=`000ooonfX02ooog03ooo]ZoookJ_m9o`3ooo]ZoonR0?oo
C03ooo]Zo`3oDOoonf[o0:Oo00Cooo]Z00?og03ooookJ_oonfX00ooonfX00oooAP3oohT0oon90004
oookJP05o`3omooonf[o00Sook?o0?l0okL00_oonfX01_l0iOoo0?oQoookJ_oo;03o4_l0o`0]o`;o
oo]Z017o0?goo`3o[_oonf[ooo]ZoonP0?oonf[o03OooookJ_l02?oood<0oookJ_l0l_oooo]Zo`3o
/ooonf[oo`0[o`3o]P03oookJP06ol00oooonf[ooo]Zool0Xooonf[oo`250ooonfX01Ol:o`3oog/0
oookJ_o5o`3ooh`000?ooo]Z00CoYOl0oookJ_oonf[o_ol01?oonfX01_oo03_ooo]Zo`3oN_oonf[o
097oool0cPCooo]Z00?o08coogh0oooo2P001OoonfX00ooo0?cooo]ZoooC0002oookJP03o`3oVOoo
nf[ooo]Z00Gooo]Z00?oodP0oookJ_oonfX01_oonfX00ol0ogcooo]ZoookJP09oookJP03o`02oooo
nf[ooo]Z00;ooo]Z00Kog`3ooeKo0?l06_oooo]Zo`0]oooeo`08oookJP04oonL0?oonf[ooo]Zo`2I
o`Kooo]Z00?oofH0oj@0oooonfX00ooonfX01?l0o`3o001oo`00Ool007l4oookJPGo001o2?oonfX4
o`0002Gooo]Z00?ooc40oookJ_oonfX0cooonfX002_ooo]Z00So0?l^oookJ_oonf[oooh0oookJ_mG
o`3oQ_l0oolg00?ooo]Z00?oom`0oookJ_oonfX00_oob@000oooXP3ood`0o`3oD@02oookJP05o`2W
oooonf[ooo]ZoookJ_oL0?l01OoonfX00oooAP3ooo]Zoon90005oookJP05o`3omooonf[o/ol0o`3o
]oo_0?l00_oonfX01_l0iOoo0?oQoookJ_oo;03o4_l0o`0]o`;ooo]Z00Ko0?gooookJ_oonf[oolT0
oonP0?oonfX5oomi00;ooo]Z00?o0?nco`3Eoooo02/01?oonfX01_o00?oooo]ZoookJ_oo0:?ooo]Z
ool0Q@;ooo]Z00Ko2_l0oookJ_ooN`3ooo]ZolGo0?ooS002oookJP05ojGo0?l0obCooo]ZoookJ_oo
N@000_oonfX02?oob@3oo`0kooo90?l0og[ooo]Zooo90?oo0<ko0?oR0ooonfX8ooo90007oookJ_oo
0?cooo]ZoookJ_ood`3ooo]Zo`3oV@08oookJP03oom80?oonf[ooo]Z00Gooo]Z00?o0?mloookJ_oo
nfX02?oonfX01?l00_oooo]ZoookJ_oonfX:ooo900Gooo]Z00Gooi`0oookJ_oonf[ooo]Zo`2Io`06
oookJP03oomV0?nT0?oooo]Z00Cooo]Z00Co0?l0o`00Ool007oo001o0ooonfX7o`00O`Oooo]Z1?l0
000UoookJP03oola0?oonf[ooo]Z0?Kooo]Z00So0?l^oookJ_oonf[oooh0oookJ_mGo`3oQ_l0oolg
00?ooo]Z00_oom`0oookJ_oonf[oBOl0oookJ_ooXP3ood`0oookJ_l0oe7ooo]Zo`2Wo`04oookJP03
om`0oooonf[ooo]Z00?ooo]Z00?oodH0oon90?oonfX01?oonfX01Ol0ooOooo]Zo`08oonco`3o0?ng
00;ooo]Z00Ko0>Goo`3ohOoonf[oob`0oa;o0?l0;Ol2oookJP0Ao`3mool0ojkooo]ZoookJ_ooX03o
oo]Zo`0goooonf[o00Sooom30?oonf[o0?;ooookJ_l0ok?ooo]Zool0:ol0okH00ooonfX01_o00?oo
oo]ZoookJ_oo0:?ooo]Zool0Q@?ooo]Z00Go2_l0oomk0?oonf[oaOl0oon<0003oookJP04ojGo0?oo
nf[ooo]Zokoo00Cooo]Z00Koo`0koookJ_l0og[ooo]Zo`2Aoooo0<h4oookJP04o`2<oomn0?oooo]Z
ool:00Cooo]Z00Koo`3loookJ_oonf[oom<0oookJ_l0oiT8oookJP03oom80?oonf[ooo]Z00Gooo]Z
00?o0?mloookJ_oonfX02OoonfX00ol00_oooo]ZoookJP02oookJP06oml0oomFo`3o01[ooookJ_l0
;OoomOl02?oonfX01?ooW03ooo]ZoookJ_l0VOl6oookJP03oomV0?nT0?oooo]Z00Cooo]Z00Co0?l0
o`00Ool007oo001o0ooonfX7o`00O`Oooo]Z1?l0000UoookJP03oola0?oonf[ooo]Z0<oooo]Z000Z
oookJP08o`3o;_oonf[ooo]Zooon0?oonf[oEol0ohKo0?oo=`03oookJP08oooL0?oonf[oBOl0ooo9
0?oonf[ooj80oom<0?l0oe42oookJP05o`2Woooonf[ooo]ZoookJ_oL0?l01OoonfX00oooAP3ooo]Z
oon90005oookJP05o`3omooonf[o/ol0o`3o]oo_0?l00_oonfX02Ol0iOoo0?oQoookJ_oo;03o4_l0
o`0]oooonf[o0?n^o`3mo`03oookJP03oonP0?oonf[o03Oo00KoogT000?o0?nco`3Eoooo02/01?oo
nfX01_o00?oooo]ZoookJ_oo0:?ooo]Zool0Q@;ooo]Z00Ko2_l0oookJ_ooN`3ooo]ZolGo0?ooS002
oookJP05ojGo0?l0obCooo]ZoookJ_ooN@000_oonfX02?oob@3oo`0kooo90?oob@3o0?mjooo90?oo
0<ko0?oR0ooonfX8ooo90005oookJ_oo0?cooo]ZoookJ_ood`000_oonfX00ol0oiWooo]ZoookJP05
oookJP03oom80?oonf[ooo]Z00Gooo]Z00?o0?mloookJ_oonfX02?oonfX01?l00_oooo]ZoookJ_oo
nfX<ooo900?ooo]Z00GoolT0oonL0?oonf[ooo]Zooo90007oookJP03oomV0?oonf[ooo]Z00?ooo]Z
00?o0?l0oookJ_l007l00_l007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`0002Go
oo]Z00?ooc40oookJ_oonfX0mOoonfX02?l0obkooo]ZoookJ_oooP3ooo]ZoeOo0?n6o`3oocL00ooo
nfX02ooog03ooo]ZodWo0?m9o`3ooo]ZoonR0?ooC03ooo]Zo`3oDOoonf[o0:Oo00Cooo]Z00?og03o
oookJ_oonfX00_oonfX2oom60003oon90?oonf[ooo]Z00?ooo]Z00Go0?ogoookJ_l02?oo/ol0o`3o
]`02oookJP06o`3Uool0on7ooo]Zool/0?lBo`3o02go0_oonfX04Ol0oOoo0?n^oookJ_oonf[ooj00
oookJ_l0=ooooo]Zo`08oooo@`3ooo]Zo`3boooonf[o0?ncoookJ_oo02_o0?nf00?ooo]Z00Ko`03o
oookJ_oonf[oo`2SoookJ_oo08D3oookJP05o`[o0?ooN`3ooo]ZolGo0?ooS0000ooonfX01?nUo`3o
oo]ZoookJ_noo`04oookJP06ool0>ooonf[ooo]Zo`3oN_l0TOooo`3>1OoonfX00ol0S?oooo]Zool:
0004oookJP04ool0o?oonf[ooo]ZoooC00;ooo]Z00?o0?nIoookJ_oonfX01OoonfX00oooB03ooo]Z
oookJP06oookJP03o`3oO?oonf[ooo]Z00Sooo]Z00?o00;ooookJ_oonfX00ooonfX01OoO0?oo01[o
oookJ_l0;OoomOl000Wooo]Z00?ooi`0oookJ_l0VOl01ooonfX00oooIP3oY03ooookJP03oookJP03
o`3o0?oonf[o001o00;o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l0000Uoook
JP03oola0?oonf[ooo]Z0<oooo]Z000/oookJP05ooon0?oonf[oEol0ohKo0?oo=`000ooonfX00ooo
g03ooo]ZodWo0002oookJP04oonR0?ooC03o0?mAoookJP;o0:Oo0ooonfX00ooL0?oooo]ZoookJP03
oookJP03oom60?oonf[oohT000Gooo]Z013o0?ogoookJ_nco`3ooo]Zonl0oooonf[o01Ooo`3Uool0
on7ooo]Zool/0?lBo`3o02gooookJ_l0ojko0?go0_oonfX01?oo0:7ooj00ooo90?l0=ol8oomi0003
ool0:ooonf[ooo]Z00;ooo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_oo08D2oookJP06o`[o0?oonf[o
og/0oookJ_o5o`3ooh`00_oonfX00onUo`3o0?lToookJP02oookJP04okoo0?oonf[ooo]Zool0>`;o
olT000Go0?mjooo90?oo0<kooo]Zo`3ohP03oookJPKoolT00_oonfX01?oo0?cooo]ZoookJ_ood`02
oookJP03o`3oVOoonf[ooo]Z00Gooo]Z00?oodP0oookJ_oonfX01OoonfX00ol0ogcooo]ZoookJP08
oookJP03o`02oooonf[ooo]Z00;ooo]Z2_oob@05oookJP05oonL0?oob@3oolT0oookJ_oob@001_oo
nfX01?ooIP3oY03ooookJ_oonfX3o`00O`03o`3o0?l007oo001o00?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`Kooo]Z1?l0000VoookJP03oola0?oonf[ooo]Z0?Kooo]Z00Goooh0oookJ_mG
o`3oQ_l0oolg0003oookJP03oooL0?oonf[oBOl000;ooo]Z00Kooj80oom<0?oonf[o0?mAoookJ_l0
Yol4oookJP03om`0oooonf[ooo]Z00;ooo]Z00?oodH0oookJ_ooR@001OoonfX03Ol0ooOooo]Zo`08
oonco`3ok`3ooookJ_l05ooo0>Goo`3ohOoonf[oob`0oa;o0?l0;Ol00_oonfX04Ol0oOoooo]Zoook
J_oo0:7ooj00oookJ_l0=ooooo]Zo`08oooo@`3ooo]Zo`3boooonf[o0?ncoookJ_oo02_o0?nf00?o
oo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_oo08D3oookJP05o`[o0?ooN`3ooo]ZolGo0?ooS0000ooo
nfX01OnUo`3ooo]ZoookJ_oonf[o_ol000?ooo]Z00Ooo`0koookJ_oonf[o0?mjo`2Aoooo0<ko0?oR
00Cooo]Z00?o08coogh0oooo2P001?oonfX01?oo0?cooo]ZoookJ_ood`02oookJP03o`3oVOoonf[o
oo]Z00Gooo]Z00?oodP0oookJ_oonfX01_oonfX00ol0ogcooo]ZoookJP08oookJP03o`02oooonf[o
oo]Z00?ooo]Z00Kog`3ooookJ_l06_oooo]Zo`0]oooeo`08oookJP04oonL0?oonf[ooo]Zo`2Io`Ko
oo]Z00CoofH0oj@0oooonf[ooo]Z0ol007l00ol0o`3o001oo`00O`03o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l6oookJPCo00009_oonfX00ooo<@3ooo]ZoookJP3>oookJP00:ooonfX01Ooo
oP3ooo]ZoeOo0?n6o`3oocL000?ooo]Z00?oom`0oookJ_m9o`000_oonfX01_ooXP3ood`0o`3oDOoo
nf[o0:Ooo`11o`?ooo]Z00?og03ooookJ_oonfX00ooonfX00oooAP3oohT0oon90005oookJP0@o`3o
mooonf[o/ol0oookJ_o_0?oooo]Zo`0Gool0iOoo0?oQoookJ_oo;03o4_l0o`0]oooonf[o0?n^o`3m
o`;ooo]Z00Coo`2QoonP0?oob@3o03Oo2_ooN@03oookJP06ol00oooonf[ooo]Zool0Xooonf[oo`25
0_oonfX01_l:o`3ooo]Zoomk0?oonf[oaOl0oon<00;ooo]Z00?oYOl0o`3o9?oonfX00_oonfX01?no
o`3ooo]ZoookJ_oo03/2ooo90005o`3oN_oob@3oo`3>ooo90?l0on800ooonfX5ooo900?ooo]Z00Co
o`3loookJ_oonf[oom<00_oonfX00ol0oiWooo]ZoookJP05oookJP03oom80?oonf[ooo]Z00Gooo]Z
00?o0?mloookJ_oonfX02OoonfX00ol00_oooo]ZoookJP02oookJPWoolT01OoonfX00oooW03oolT0
ooo90003ooo900Kooo]Z00CoofH0oookJ_oonf[ooo]Z0_l007l00ol0o`3o001oo`00O`04o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJPKo00009?oonfX00ooo<@3ooo]ZoookJP3eoook
JP05ooon0?oonf[oEol0ohKo0?oo=`000ooonfX00ooog03ooo]ZodWo0002oookJP06oonR0?ooC03o
oo]Zo`3oDOl0@Ooo0:Oo1?oonfX00ooL0?oooo]ZoookJP02oookJP03oom60?oonf[oohT000Gooo]Z
00go0?ogoookJ_l02?oo/ol0onl0oooonf[o01Ooo`3Uool0on7ooo]Zool/0?lBo`3o02go00;ooo]Z
017o0?gooookJ_oonf[oo`2QoonP0?oonf[o03OooookJ_l02?oood<0oookJ_l0l_oooo]Zo`3o/ooo
nf[oo`0[o`3o]P03oookJP06ol00oooonf[ooo]Zool0Xooonf[oo`250ooonfX01Ol:o`3oog/0oook
J_o5o`3ooh`000?ooo]Z00GoYOl0oookJ_oonf[ooo]Zokoo0003oookJP07ool0>ooonf[ooo]Zo`3o
N_l0TOooo`3>o`3ohP04oookJP03o`2<oomn0?ooo`X000Cooo]Z00Coo`3loookJ_oonf[oom<00_oo
nfX00ol0oiWooo]ZoookJP05oookJP03oom80?oonf[ooo]Z00Kooo]Z00?o0?mloookJ_oonfX02?oo
nfX00ol00_oooo]ZoookJP03oookJP06oml0oomFo`3o01[ooookJ_l0;OoomOl02?oonfX01?ooW03o
oo]ZoookJ_l0VOl7oookJP04oomV0?oonf[ooo]ZoookJP;o001o00?o0?l0o`00Ool007l01?l007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX6o`0002Cooo]Z00?ooc40oookJ_oonfX0c_oo
nfX002[ooo]Z00Goooh0oookJ_mGo`3oQ_l0oolg0003oookJP03oooL0?oonf[oBOl000;ooo]Z00Go
oj80oom<0?l0oe7ooo]Zo`2Wo`04oookJP03om`0oooonf[ooo]Z00?ooo]Z00?oodH0oon90?oonfX0
1OoonfX02Ol0ooOooo]Zok?o0?oonf[ok`3ooookJ_l05ooo0>Goo`3oh@02ool/0005oa;o0?l0;Ooo
oo]Zo`3o[_l0oOl00_oonfX01Ooo0:7ooj00ooo90?l0=oooolT000SoogT01?oonfX01_o00?oooo]Z
oookJ_oo0:?ooo]Zool0Q@;ooo]Z00Ko2_l0oookJ_ooN`3ooo]ZolGo0?ooS002oookJP03ojGo0?l0
obCooo]Z00;ooo]Z00Co_ol0oookJ_oonf[oo`0k0_oob@001Ol0og[oolT0ool0c_oob@3o0?oR00;o
olT00_oonfX4ooo900?ooo]Z00Coo`3loookJ_oonf[oom<00_oonfX00ol0oiWooo]ZoookJP05oook
JP03oom80?oonf[ooo]Z00Kooo]Z00?o0?mloookJ_oonfX02?oonfX00ol00_oooo]ZoookJP02oook
JP;oolT000?og`3oooo90?oob@001?oob@06oookJP03oonL0?oob@3oolT000CoolT01?oonfX00ooo
IP3ooo]ZoookJP02oookJP03o`00Ool0o`3ooo]Z00;ooo]Z0ol007l2oookJP?o001o0ooonfX3o`00
O`Kooo]Z1?l0000VoookJP03oola0?oonf[ooo]Z0?Cooo]Z00Goooh0oookJ_mGo`3oQ_l0oolg0003
oookJP03oooL0?oonf[oBOl000;ooo]Z00Kooj80oom<0?l0oe7o0?mAo`11ool0Yol4oookJP03om`0
oooonf[ooo]Z00;ooo]Z00?oodH0oookJ_ooR@001OoonfX02Ol0ooOooo]Zo`08oonco`3ok`3ooook
J_l05ooo0>Goo`3oh@02ool/0005oa;o0?l0;Ooooo]ZoookJ_l0oOl00_oonfX03_oo0:7ooj00oook
J_l0=ooooo]Zo`08oooo@`3ooo]Zo`3boooonf[o0?ncoookJ_oo02_o0?nf0ooonfX01_o00?oooo]Z
oookJ_oo0:?ooo]Zool0Q@?ooo]Z00Go2_l0oomk0?oonf[oaOl0oon<0003oookJP05ojGo0?oonf[o
oo]ZoookJ_noo`000ooonfX01ooo03_ooo]ZoookJ_l0og[o097oool0c_l0on801?oonfX00ol0S?oo
OP3oool:0004oookJP04ool0o?oonf[ooo]ZoooC00;ooo]Z00?o0?nIoookJ_oonfX01OoonfX00ooo
B03ooo]ZoookJP06oookJP03o`3oO?oonf[ooo]Z00Wooo]Z00?o00;ooookJ_oonfX00ooonfX01OoO
0?oo01[ooookJ_l0;OoomOl000Wooo]Z00Cooi`0oookJ_l0VOooF`3o1_oonfX00oooIP3oY03ooook
JP02oookJP03o`00Ool0o`3ooo]Z00;ooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0
000VoookJP03oola0?oonf[ooo]Z0<kooo]Z000[oookJP03oeOo0?n6o`3oocL000?ooo]Z00?oom`0
oookJ_m9o`000_oonfX01OooXP3ood`0oookJ_oonf[o0:Oo00Cooo]Z00?og03ooookJ_oonfX00_oo
nfX2oom60003oon90?oonf[ooo]Z00Cooo]Z00ko0?ogoookJ_nco`3ooo]Zonl0oooonf[o01Ooo`3U
ool0on7oob`0oookJ_lBo`3o02gooookJP;o0?go0_oonfX01Ooo0:7ooj00ooo90?l0=oooolT000Oo
ogT000?oo`0[oookJ_oonfX00_oonfX01_o00?oooo]ZoookJ_oo0:?ooo]Zool0Q@?ooo]Z00Go2_l0
oomk0?oonf[oaOl0oon<0002oookJP03ojGo0?l0obCooo]Z00;ooo]Z00Co_ol0oookJ_oonf[oo`0k
0_oob@001_l0og[oolT0ool0c_oob@3o0?oRooo900?ooo]Z0ooob@05oookJP03ool0o?oonf[oom<0
00;ooo]Z00?o0?nIoookJ_oonfX01OoonfX00oooB03ooo]ZoookJP06oookJP03o`3oO?oonf[ooo]Z
00Sooo]Z00?o00;ooookJ_oonfX00ooonfX00ooob@3og`3oooo90005ooo900Kooo]Z00?ooi`0ooo9
0?oob@001_oob@03oookJP03oomV0?oonf[ooo]Z00?ooo]Z00Co0?l0o`00Oooonf[ooo]Z0ol007l2
oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0000VoookJP03oola0?oonf[ooo]Z0?Gooo]Z00?oEol0
ohKo0?oo=`000ooonfX00ooog03ooo]ZodWo0002oookJP06oonR0?ooC03o0?mAoookJ_l0@Ooo0:Oo
1?oonfX00ooL0?oooo]ZoookJP02oookJP03oom60?oonf[oohT000Gooo]Z00go0?ogoookJ_l02?oo
/ol0onl0oooonf[o01Ooo`3Uool0on7oob`0oookJ_lBo`3o02go00;ooo]Z017o0?gooookJ_oonf[o
o`2QoonP0?oonf[o03OooookJ_l02?oood<0oookJ_l0l_oooo]Zo`3o/ooonf[oo`0[o`3o]P03oook
JP06ol00oooonf[ooo]Zool0Xooonf[oo`250ooonfX01Ol:o`3oog/0oookJ_o5o`3ooh`000?ooo]Z
00GoYOl0oookJ_oonf[ooo]Zokoo0003oookJP07ool0>ooonf[ooo]Zo`3oN_l0TOooo`3>o`3ohP04
oookJP03o`2<oomn0?ooo`X000Gooo]Z00?oo`3loookJ_ood`000_oonfX00ol0oiWooo]ZoookJP06
oookJP03oom80?oonf[ooo]Z00Gooo]Z00?o0?mloookJ_oonfX02OoonfX00ol00_oooo]ZoookJP03
oookJP06oml0oooonf[o01[ooookJ_l0;OoomOl02?oonfX01?ooW03ooo]ZoookJ_l0VOl7oookJP03
oomV0?oonf[ooo]Z00?ooo]Z00Co0?l0o`00Oooonf[ooo]Z0ol007l2oookJP?o001o0ooonfX3o`00
O`Kooo]Z1?l0000VoookJP03oola0?oonf[ooo]Z0<kooo]Z000ZoookJP03oeOo0?n6o`3oocL000?o
oo]Z00Coom`0oookJ_m9o`3ooo]Z0_oob@001?ooC03ooo]ZoookJ_l0Yol4oookJP03om`0oooonf[o
oo]Z00;ooo]Z00?oodH0oookJ_ooR@001_oonfX03ol0ooOooo]Zok?o0?oonf[ok`3ooookJ_l05ooo
0>Goo`3ohOoo;03ooo]Zoa;o0?l0;Ooooo]Zo`3mo`03oookJP04ool0XOooX03oP`3oo`0go`;oolT0
1_ooN@000ooo02_ooo]ZoookJP02oookJP06ol00oooonf[ooo]Zool0Xooonf[oo`250ooonfX01Ol:
o`3oog/0oookJ_o5o`3ooh`000;ooo]Z00?oYOl0o`3o9?oonfX00_oonfX01onoo`3ooo]ZoookJ_oo
03_ooo]Zooo90?l0ogX00_oob@000ooo0<ko0?oRooo90003oookJP03o`2<oooob@3ooo]Z00Gooo]Z
00Koo`3loookJ_oonf[oom<0oookJ_l0oiT8oookJP03oom80?oonf[ooo]Z00Gooo]Z00?o0?mloook
J_oonfX02?oonfX01?l00_oooo]ZoookJ_oonfX2onGo0003ooo90?oO0?ooolT000GoolT01_oonfX0
0oooW03oolT0ooo90005ooo900Cooo]Z00?oofH0oookJ_oonfX00ooonfX01Ol0o`3o001oo`00Ool0
07oooo]Z00?o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJPCo00009_oonfX00ooo<@3ooo]Zoook
JP3doookJP03oeOo0?n6o`3oocL000?ooo]Z00Coom`0oookJ_m9o`3ooo]Z0_ooXP001OooC03o0?mA
oookJ_l0@Ooo0:Oo00Cooo]Z00?og03ooookJ_oonfX00_oonfX00oooAP3ooo]Zoon90005oookJP0=
o`3omooonf[o00Sook?o0?o_0?oooo]Zo`0Gool0iOoo0?oQool/0?oonf[o4_l0o`0]o`02oookJP0A
o`3moooonf[ooo]Zool0XOooX03oP`3oo`0goooonf[o00Sooom30?oonf[o0?;ooookJ_l0ok?ooo]Z
ool0:ol0okH00ooonfX01_o00?oooo]ZoookJ_oo0:?ooo]Zool0Q@?ooo]Z00Go2_l0oomk0?oonf[o
aOl0oon<0003oookJP05ojGo0?oonf[ooo]ZoookJ_noo`000ooonfX01ooo03_ooo]ZoookJ_l0og[o
097oool0c_l0on801?oonfX00ol0S?ooOP3oool:0005oookJP06ool0o?oonf[ooo]ZoooC0?oonf[o
0?nI2?oonfX00oooB03ooo]ZoookJP06oookJP03o`3oO?oonf[ooo]Z00Sooo]Z00?o00;ooookJ_oo
nfX00ooonfX01_oO0?ooE_l0o`0Joooonf[o02goooGo00Sooo]Z00Cooi`0oookJ_oonf[o09Wo1ooo
nfX00oooIP3oY03ooookJP03oookJP05o`3o0?l007oo001oo`00OooonfX00ol007l2oookJP?o001o
0ooonfX3o`00O`Kooo]Z1?l0000VoookJP03oola0?oonf[ooo]Z0<kooo]Z000ZoookJP03ohKo0?oo
=`3ooo]Z00;ooo]Z00Goom`0oookJ_m9o`3ooo]Zooo90002oom<00;ooo]Z00?o0:OooookJ_oonfX0
0_oonfX00ooL0?oooo]ZoookJP02oookJP03oom60?oonf[oohT000Kooo]Z00?o0?ogok?o0?nco`00
0_o_0?l01ooonf[o01Ooo`3Uool0on7oob`0oookJ_lBo`000_oonfX02?l0oOoooo]ZoookJ_oonf[o
o`2QoonP0?n30?oo03Oo0_oob@05oomi0003o`3Eoooo02_ooo]Z00?ooo]Z00Ko`03ooookJ_oonf[o
o`2SoookJ_oo08D3oookJP05o`[o0?ooN`3ooo]ZolGo0?ooS0000_oonfX00onUo`3o0?lToookJP02
oookJP07okoo0?oonf[ooo]Zool0>ooonf[oolT0o`3oNP02ooo90003ool0c_l0on;ooo]Z00?ooo]Z
00?o08coooo90?oonfX01OoonfX01_oo0?cooo]ZoookJ_ood`3ooo]Zo`3oV@Sooo]Z00?oodP0oook
J_oonfX01_oonfX00ol0ogcooo]ZoookJP08oookJP04o`02oooonf[ooo]ZoookJP;oiOl000?og`3o
ooo90?oUo`000ooob@08oookJP03oonL0?oob@3oolT000CoolT01?oonfX00oooIP3oY03ooookJP04
oookJP05o`3o0?oonf[o001oo`00OooonfX00ol007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0
000VoookJP03oola0?oonf[ooo]Z0?Cooo]Z00?oQ_l0oolg0?oonfX00_oonfX01Ooog03ooo]ZodWo
0?oonf[ooj8000;ood`000Co0?mAoookJ_l0@Ooo0:Oo1?oonfX00ooL0?oooo]ZoookJP02oookJP03
oom60?oonf[oohT000Gooo]Z00co0?ogoookJ_nco`3o/ol0onl0oooonf[o01Ooo`3Uool0on7oob`0
oookJ_lBo`03oookJP0Ao`3moooonf[ooo]Zool0XOooX03oP`3oo`0goooonf[o00Sooom30?oonf[o
0?;ooookJ_l0ok?ooo]Zool0:ol0okH00ooonfX01_o00?oooo]ZoookJ_oo0:?ooo]Zool0Q@?ooo]Z
00Go2_l0oookJ_ooN`3oaOl0oon<0003oookJP05ojGo0?oonf[ooo]ZoookJ_noo`000ooonfX01ooo
03_ooo]ZoookJ_l0og[o097oool0c_l0on801?oonfX00ol0S?ooOP3oool:0005oookJP06ool0o?oo
nf[ooo]ZoooC0?oonf[o0?nI2?oonfX00oooB03ooo]ZoookJP06oookJP03o`3oO?oonf[ooo]Z00So
oo]Z00?o00;ooookJ_oonfX00ooonfX01_oO0?ooE_l0o`0Joooonf[o02goooGo00Sooo]Z00Gooi`0
oookJ_oonf[o09Wooe/0o`06oookJP03oomV0?nT0?oooo]Z00Cooo]Z00Go0?l0oookJ_l007oo001o
oookJP03o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX4o`0002Kooo]Z00?ooc40oookJ_oonfX0
c_oonfX002[ooo]Z00_oocL0oookJ_oonf[ooo]ZoooL0?oonf[oBOl0oookJ_oob@3ood`0o`3oD@02
oookJP03o`2Woooonf[ooo]Z00;ooo]Z00?og03ooookJ_oonfX00_oonfX00oooAP3ooo]Zoon90005
oookJP;o0?og00?o/ol0o`3o]oo_0?l00_oonfX2o`3Uo`04o`3ohOoo;03ooo]Zoa;o00;ooo]Z00So
0?gooookJ_oonf[ooo]Zool0XOooX03oP`3oo`0go`;oolT01?ooN@000ol0ok?o0=Goool0:`04oook
JP06ol00oooonf[ooo]Zool0Xooonf[oo`250ooonfX01Ol:o`3oog/0oookJ_o5o`3ooh`000?ooo]Z
00GoYOl0oookJ_oonf[ooo]Zokoo0003oookJP03ool0>ooonf[o0?mj00;oolT000?oo`3>o`3oh_oo
nfX00ooonfX00ol0S?oooo]Zool:0005oookJP06ool0o?oonf[ooo]ZoooC0?oonf[o0?nI2?oonfX0
0oooB03ooo]ZoookJP06oookJP03o`3oO?oonf[ooo]Z00Sooo]Z00Co00;ooookJ_oonf[ooo]Z0ooU
o`000ooO0?ooiOl0ooo90002ooo900Sooo]Z00?ooi`0oookJ_oob@001?oob@05oookJP03oomV0?oo
nf[ooo]Z00?ooo]Z00Co0?l0oookJ_oonf[ooo]Z1Ol007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z
1?l0000VoookJP03oola0?oonf[ooo]Z0?Cooo]Z00ooocL0oookJ_oonf[ooo]ZoooL0?oonf[oBOl0
oookJ_ooXP3ood`0oookJ_l0oe7ooo]Zo`11ool0Yol01?oonfX00ooL0?oooo]ZoookJP02oookJP03
oom60?oonf[oohT000Cooo]Z0_l0ooL00ooonf[o/ol0o`3o]`02oookJP;o0>Go00Co0?oQool/0?oo
nf[o4_l00ooonfX04Ol0oOoooo]ZoookJ_oo0:7ooj00oh<0ool0=ooooo]Zo`08oooo@`3ooo]Zo`3b
oooonf[o0?ncoookJ_oo02_o0?nf00?ooo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_oo08D3oookJP05
o`[o0?oonf[oog/0olGo0?ooS0000ooonfX01Ol0obCoYOl0oookJ_oonf[o_ol000Cooo]Z00Koo`0k
oookJ_l0og[o097oool0c_l0on84oookJP04o`2<oomn0?oooo]Zool:00Cooo]Z00Koo`3loookJ_oo
nf[oom<0oookJ_l0oiT8oookJP03oom80?oonf[ooo]Z00Kooo]Z00?o0?mloookJ_oonfX02?oonfX0
0ol00_oooo]ZoookJP04oookJP05oml0ool06_oooo]ZoookJ_oeo`002OoonfX01?ooW03ooo]Zoook
J_l0VOl7oookJP03oomV0?nT0?oooo]Z00?ooo]Z00Co0?l0oookJ_oonf[ooo]Z1Ol007l2oookJP?o
001o0ooonfX3o`00O`Kooo]Z1?l0000WoookJP03oola0?oonf[ooo]Z0<gooo]Z000]oookJP07oooL
0?oonf[oBOl0oookJ_oob@3ood`0o`3oD@02oookJP03o`2Woooonf[ooo]Z00;ooo]Z00?og03ooook
J_oonfX00_oonfX00oooAP3ooo]Zoon90005oookJP05o`3omooonf[o/ol0o`3o]oo_0?l00_oonfX0
1_l0iOoooo]Zo`3ohOoo;03ooo]Zoa;o00;ooo]Z00So0?gooookJ_oonf[ooo]Zool0XOooX03oP`3o
o`0go`?oolT00_ooN@001?oonf[o0?nco`3Eoooo02/4oookJP06ol00oooonf[ooo]Zool0Xooonf[o
o`250ooonfX01Ol:o`3oog/0oookJ_o5o`3ooh`000?ooo]Z00GoYOl0oookJ_oonf[ooo]Zokoo0003
oookJP03ool0>ooonf[o0?mj00;oolT000?oo`3>o`3oh_oonfX00ooonfX00ol0S?ooOP3oool:0005
oookJP06ool0o?oonf[ooo]ZoooC0?oonf[o0?nI2?oonfX00oooB03ooo]ZoookJP06oookJP03o`3o
O?oonf[ooo]Z00Sooo]Z00?o00;ooookJ_oonfX00_oonfX2onGo0003oml0oooUo`3oiOl000;oolT0
2?oonfX00oooW03ooo]Zooo90004ooo900Gooo]Z00?oofH0oookJ_oonfX00ooonfX00ol0o`3ooo]Z
oookJP02oookJPGo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l0000VoookJP03
oola0?oonf[ooo]Z0?Oooo]Z00_oom`0oookJ_m9o`3ooo]ZoonR0?ooC03ooo]Zo`3oDOoonf[o047o
o`2Wo`04oookJP04om`0oooonf[ooo]ZoookJP;oodH000?ooo]Zoon90?oonfX00ooonfX01Ol0ooOo
oo]Zo`08oonco`3o0?ng00;ooo]Z00Ko0>Goo`3oS?l0on7oob`0oookJ_lBo`03oookJP0Ao`3moooo
nf[ooo]Zool0XOooX03oP`3oo`0goooonf[o00Sooom30?oonf[o0?;ooookJ_l0ok?ooo]Zool0:ol0
okH00ooonfX01_o00?oooo]ZoookJ_oo0:?ooo]Zool0Q@?ooo]Z00Go2_l0oookJ_ooN`3oaOl0oon<
0003oookJP05o`3o9?nUo`3ooo]ZoookJ_noo`001?oonfX01_oo03_ooo]Zo`3oN_l0TOooo`3>o`3o
hPCooo]Z00Co08coogh0oooonf[oo`X01?oonfX01_oo0?cooo]ZoookJ_ood`3ooo]Zo`3oV@Wooo]Z
00?oodP0oookJ_oonfX01OoonfX00ol0ogcooo]ZoookJP09oookJP03o`02oooonf[ooo]Z00?ooo]Z
00Kog`3ooookJ_l06_oooo]Zo`0]oooeo`08oookJP04oonL0?oonf[ooo]Zo`2Io`Oooo]Z00?oofH0
oj@0oooonfX00ooonfX00ol0o`3ooo]ZoookJP02oookJPGo001o0ooonfX3o`00O`04oookJ_l007oo
001oo`00O`Oooo]Z1?l0000WoookJP03oola0?oonf[ooo]Z0<gooo]Z000/oookJP08oooL0?oonf[o
BOl0oookJ_oob@3ood`0o`3oDOoonfX2o`2Wo`?ooo]Z0_oL0?l4oookJP03oom60?oonf[oohT000Go
oo]Z00Go0?ogoookJ_nco`3o0?ngonl0o`02oookJP06o`3Uool0on7o0?oQool/0?oonf[o4_l00_oo
nfX02?l0oOoooo]ZoookJ_oonf[oo`2QoonP0?n30?oo03Oo0ooob@02oomi0004oookJ_l0ok?o0=Go
ool0:`Cooo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_oo08D3oookJP05o`[o0?ooN`3ooo]ZolGo0?oo
S0000ooonfX01OnUo`3ooo]ZoookJ_oonf[o_ol000?ooo]Z00?oo`0koookJ_l0ogX00_oob@000ooo
0<ko0?oRoookJP03oookJP03o`2<oomn0?ooo`X000Gooo]Z00Coo`3loookJ_oonf[oom<00_oonfX0
0ol0oiWooo]ZoookJP05oookJP03oom80?oonf[ooo]Z00Kooo]Z00?o0?mloookJ_oonfX02OoonfX0
1?l00_oooo]ZoookJ_oonfX2onGo0005oml0oomFo`3oiOl0onGo0?oob@000_oUo`07oookJP03oonL
0?oonf[oolT000?oolT01_oonfX00oooIP3ooo]ZoookJP03oookJP03o`3o0?oonf[ooo]Z00?ooo]Z
1?l007l3oookJPOo001o1ooonfX4o`0002Oooo]Z00?ooc40oookJ_oonfX0mOoonfX02Ooog03ooo]Z
odWo0?oonf[ooj80oom<0?oonf[o0?mAoookJP02o`2Wo`?ooo]Z0_oL0?l3oookJP04oom60?oonf[o
oo]Zoon900Cooo]Z00Go0?ogoookJ_l02?oo/ol0o`3o]`02oookJP06o`3Uool0ohco0?oQool/0?oo
nf[o4_l00ooonfX04Ol0oOoooo]ZoookJ_oo0:7ooj00oh<0ool0=ooooo]Zo`08oooo@`3ooo]Zo`3b
oooonf[o0?ncoookJ_oo02_o0?nf00?ooo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_oo08D3oookJP05
o`[o0?oonf[oog/0olGo0?ooS0000ooonfX01Ol0obCoYOl0oookJ_oonf[o_ol000Cooo]Z00Koo`0k
oookJ_l0og[o097oool0c_l0on84oookJP04o`2<oomn0?oooo]Zool:00Cooo]Z00Coo`3loookJ_oo
nf[oom<00_oonfX00ol0oiWooo]ZoookJP06oookJP03oom80?oonf[ooo]Z00Kooo]Z00?o0?mloook
J_oonfX02?oonfX00ol00_oooo]ZoookJP03oookJP06oml0oomFo`3o01[ooookJ_l0;OoomOl02?oo
nfX01OooW03ooo]ZoookJ_oonf[o09Wo00Oooo]Z00?oofH0oj@0oooonfX00ooonfX00ol0o`3ooo]Z
oookJP03oookJPCo001o0ooonfX7o`00O`Oooo]Z1?l0000WoookJP03oola0?oonf[ooo]Z0<gooo]Z
000[oookJP0:oooL0?oonf[oBOl0oookJ_oob@3ood`0o`3oDOoonf[o0:Ooo`11o`?ooo]Z00?og03o
oookJ_oonfX00ooonfX00oooAP3oohT0oon90005oookJP05o`3omooonf[o/ol0o`3o]oo_0?l00_oo
nfX01_l0iOoo0?oQoookJ_oo;03ooo]Zoa;o00;ooo]Z00co0?gooookJ_oonf[ooo]Zool0XOooX03o
P`3oo`0goooonf[oolT0o`3booooN@02oookJP03o`3o/ol0eOooo`0[00Cooo]Z00Ko`03ooookJ_oo
nf[oo`2SoookJ_oo08D3oookJP06o`[o0?ooN`3ooo]ZolGo0?oonf[ooh`00_oonfX01OnUo`3o0?lT
oookJ_oonf[o_ol000?ooo]Z00Ooo`0koookJ_oonf[o0?mjooo90?oo0<ko0?oR00Gooo]Z00?o08co
ool:0?oonfX01?oonfX01?oo0?cooo]ZoookJ_ood`02oookJP03o`3oVOoonf[ooo]Z00Gooo]Z00?o
odP0oookJ_oonfX01ooonfX00ol0ogcooo]ZoookJP08oookJP03o`02oooonf[ooo]Z00;ooo]Z00?o
iOl0oml0oomFo`000_oUo`000ooob@3oiOl0oookJP07oookJP03oonL0?oonf[ooo]Z00?oolT01_oo
nfX00oooIP3ooo]ZoookJP03oookJP03o`3o0?oonf[ooo]Z00Gooo]Z0ol007l4oookJPGo001o2?oo
nfX4o`0002Oooo]Z00?ooc40oookJ_oonfX0m?oonfX01_oog03ooo]ZodWo0?oonf[ooj80oom<00;o
0?mA00?ooo]Zo`2WoooonfX00ooonfX00ooL0?oooo]ZoookJP02oookJP04oom60?oonf[oohT0oon9
00Cooo]Z00Go0?ogoookJ_l02?oo/ol0o`3o]`02oookJP06o`3Uool0ohco0?oQool/0?oonf[o4_l0
0ooonfX02_l0oOoooo]ZoookJ_oo0:7ooj00oh<0ool0=ooooo]Zo`08oooo@`02o`3bo`05oookJ_l0
ok?ooo]Zool0:ol0okH00ooonfX01_o00?oooo]ZoookJ_oo0:?ooo]Zool0Q@?ooo]Z00Ko2_l0oook
J_ooN`3oaOl0oookJ_ooS003oookJP04ojGo0?oonf[ooo]Zokoo00Cooo]Z00Koo`0koookJ_l0og[o
097oool0c_l0on85oookJP03o`2<oooonf[oo`X000Cooo]Z00Coo`3loookJ_oonf[oom<00_oonfX0
0ol0oiWooo]ZoookJP06oookJP03oom80?oonf[ooo]Z00Kooo]Z00?o0?mloookJ_oonfX02?oonfX0
0ol00_oooo]ZoookJP03oookJP03oml0oomFo`3o01[o00;ooo]Z00?omOl0oookJ_oonfX01ooonfX0
1?ooW03ooo]ZoookJ_l0VOl7oookJP03oomV0?nT0?oooo]Z00?ooo]Z00?o0?l0oookJ_oonfX01Ooo
nfX3o`00O`Cooo]Z1Ol007l8oookJPCo00009ooonfX00ooo<@3ooo]ZoookJP3=oookJP00:_oonfX0
2_oog03ooo]ZodWo0?oonf[oolT0oom<0?l0oe7ooo]Zo`2Wool0@Ol3oookJP03om`0oooonf[ooo]Z
00?ooo]Z00?oodH0oon90?oonfX01OoonfX01Ol0ooOooo]Zok?o0?l0okOok`3o00;ooo]Z00Ko0>Go
o`3ohOoonf[oob`0oookJ_lBo`02oookJP0;o`3moooonf[ooo]ZoookJ_oo0:7ooj00oh<0ool0=ooo
oo]Zooo90?l0l_l00ooonfX00ol0ok?o0=Goool0:`04oookJP06ol00oooonf[ooo]Zool0Xooonf[o
o`250ooonfX01_l:o`3oog/0oookJ_o5o`3ooo]Zoon<00;ooo]Z00GoYOl0o`3o9?oonf[ooo]Zokoo
0003oookJP07ool0>ooonf[ooo]Zo`3oN_oob@3oo`3>o`3ohP05oookJP03o`2<oooo2P3ooo]Z00Go
oo]Z00?oo`3loookJ_ood`000_oonfX00ol0oiWooo]ZoookJP06oookJP03oom80?oonf[ooo]Z00Ko
oo]Z00?o0?mloookJ_oonfX02?oonfX00ol00_oooo]ZoookJP03oookJP06onGo0?oO0?ooiOl0onGo
0?l0;OoomOl02OoonfX00oooW03ooo]Zooo90002ooo900Oooo]Z00?oofH0oookJ_oonfX00ooonfX0
0ol0o`3ooo]ZoookJP0IoookJPCo00009ooonfX00ooo<@3ooo]ZoookJP3coookJP0:oooL0?oonf[o
BOl0oookJ_ooXP3ood`0o`3oDOoonf[o047oo`2Wo`Cooo]Z00?og03ooookJ_oonfX00_oonfX00ooo
AP3ooo]Zoon90005oookJP05o`3omooonf[o00Sook?o0?l0okL00_oonfX01_l0iOoo0?n<o`3ohOoo
;03ooo]Zoa;o00?ooo]Z00_o0?gooookJ_oonf[oo`2QoonP0?n30?oo03OooookJ_l02?oood<0o`3b
o`02oookJP04o`3o/ooonf[oo`0[o`3o]P?ooo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_oo08D3oook
JP06o`[o0?oonf[oog/0olGo0?oonf[ooh`00ooonfX01?nUo`3ooo]ZoookJ_noo`04oookJP07ool0
>ooonf[o0?mjo`2Aoooo0<kooo]Zo`3ohP04oookJP03o`2<oomn0?ooo`X000Gooo]Z00?oo`3loook
J_ood`000_oonfX00ol0oiWooo]ZoookJP06oookJP03oom80?oonf[ooo]Z00Kooo]Z00?o0?mloook
J_oonfX02?oonfX00ol00_oooo]ZoookJP04oookJP06oml0ool06_oooo]ZoookJ_l0;OoomOl02?oo
nfX01OooW03ooo]ZoookJ_l0VOooF`3o00Oooo]Z00?oofH0oookJ_oonfX00ooonfX00ol0o`3ooo]Z
oookJP0IoookJPCo0000:?oonfX00ooo<@3ooo]ZoookJP3<oookJP00:ooonfX01om9o`3ooo]Zooo9
0?ooC03o0?mAoookJ_l0Yol01?oonfX00ooL0?oooo]ZoookJP03oookJP03oom60?ooR@3ooo]Z00Go
oo]Z00Go0?ogoookJ_nco`3o0?ngonl0o`02oookJP06o`3Uool0on7ooo]Zool/0?oonf[o4_l00_oo
nfX00ol0oOoooo]ZoookJP02ool0X@06oonP0?n30?oo03OooookJ_oob@3o0?;o0ooonfX00ol0ok?o
0=Goool0:`04oookJP06ol00oooonf[ooo]Zool0Xooonf[oo`250ooonfX01_l:o`3oog/0oookJ_o5
o`3ooo]Zoon<00;ooo]Z00GoYOl0o`3o9?oonf[ooo]Zokoo0003oookJP07ool0>ooonf[ooo]Zo`3o
N_oob@3oo`3>o`3ohP05oookJP03o`2<oooo2P3ooo]Z00Gooo]Z00?oo`3loookJ_ood`000_oonfX0
0ol0oiWooo]ZoookJP06oookJP03oom80?oonf[ooo]Z00Kooo]Z00?o0?mloookJ_oonfX02?oonfX0
0ol00_oooo]ZoookJP03oookJP06onGo0?oO0?ooiOl0onGo0?oob@3omOl02OoonfX00oooW03ooo]Z
oookJP02ooo900Oooo]Z00?oofH0oookJ_oonfX00ooonfX00ol0o`3ooo]ZoookJP0JoookJPCo0000
9ooonfX00ooo<@3ooo]ZoookJP3doookJP08odWo0?oonf[ooj80oom<0?l0oe7ooo]Zo`11ool0Yol4
oookJP03om`0oooonf[ooo]Z00;ooo]Z00?oodH0oookJ_ooR@001OoonfX01Ol0ooOooo]Zo`08oonc
o`3o0?ng00;ooo]Z00Ko0>Goo`3oS?l0on7oob`0oookJ_lBo`03oookJP0;o`3moooonf[oo`2Qool0
XOooX03oP`3oo`0goooonf[o00Sooom30?l0l_l00_oonfX01?l0ok?ooo]Zool0:ol0okH3oookJP06
ol00oooonf[ooo]Zool0Xooonf[oo`250ooonfX01_l:o`3ooo]Zoomk0?o5o`3ooo]Zoon<00?ooo]Z
00GoYOl0oookJ_oonf[ooo]Zokoo0003oookJP07ool0>ooonf[o0?mjo`2Aoooo0<kooo]Zo`3ohP04
oookJP03o`2<oomn0?ooo`X000Gooo]Z00?oo`3loookJ_ood`000_oonfX00ol0oiWooo]ZoookJP06
oookJP03oom80?oonf[ooo]Z00Kooo]Z00?o0?mloookJ_oonfX02?oonfX00ol00_oooo]ZoookJP04
oookJP06oml0oooonf[o01[ooookJ_l0;OoomOl02?oonfX01OooW03ooo]ZoookJ_oonf[o09Wo00Oo
oo]Z00?oofH0oj@0oooonfX00ooonfX00ol0o`3ooo]ZoookJP0JoookJPCo0000:?oonfX00ooo<@3o
oo]ZoookJP3<oookJP00:_oonfX01om9o`3ooo]Zooo90?ooC03o0?mAoookJ_l0Yol01?oonfX00ooL
0?oooo]ZoookJP03oookJP03oom60?ooR@3ooo]Z00Gooo]Z00_o0?ogoookJ_nco`3o0?ngonl0oooo
nf[o01Ooo`3Uool0on7ooo]Zool/0002oa;o00;ooo]Z00Ko0?gooookJ_oonf[oo`2QoookJ_ooX002
o`0go`03oookJ_oo@`3o0?;o00?ooo]Z00?o0?nco`3Eoooo02/01?oonfX01_o00?oooo]ZoookJ_oo
0:?ooo]Zool0Q@?ooo]Z00Ko2_l0oomk0?oonf[oaOl0oookJ_ooS002oookJP05ojGo0?l0obCooo]Z
oookJ_noo`000ooonfX01ooo03_ooo]ZoookJ_l0og[o097oool0c_l0on801OoonfX00ol0S?ooo`X0
oookJP05oookJP03ool0o?oonf[oom<000;ooo]Z00?o0?nIoookJ_oonfX01_oonfX00oooB03ooo]Z
oookJP07oookJP03o`3oO?oonf[ooo]Z00Sooo]Z00?o00;ooookJ_oonfX00ooonfX01OoO0?ooE_l0
onGo0?oUo`3omOl000Wooo]Z00Gooi`0oookJ_oonf[ooo]Zooo90007oookJP03oomV0?nT0?oooo]Z
00Cooo]Z00?o0?l0oookJ_oonfX06_oonfX4o`0002Oooo]Z00?ooc40oookJ_oonfX0looonfX02?m9
o`3ooo]ZoonR0?ooC03o0?mAoookJ_l0@Ooo0:Oo1?oonfX00ooL0?oooo]ZoookJP02oookJP03oom6
0?oonf[oohT000Gooo]Z00Go0?ogoookJ_l02?oo/ol0onl0o`02oookJP04o`3Uool0ohco0?oQool/
00;o4_l00ooonfX02ol0oOoooo]Zool0XOoonf[ooj00oh<0ool0=ooooo]Zo`08oooo@`3o0?;o00;o
oo]Z00Co0?ncoookJ_oo02_o0?nf0ooonfX01_o00?oooo]ZoookJ_oo0:?ooo]Zool0Q@?ooo]Z00Ko
2_l0oookJ_ooN`3oaOl0oookJ_ooS003oookJP05ojGo0?oonf[ooo]ZoookJ_noo`000ooonfX01ooo
03_ooo]Zo`3oN_oonf[oo`3>oookJ_l0on801?oonfX00ol0S?ooOP3oool:0005oookJP03ool0o?oo
nf[oom<000;ooo]Z00?o0?nIoookJ_oonfX01ooonfX00oooB03ooo]ZoookJP06oookJP03o`3oO?oo
nf[ooo]Z00Sooo]Z00?o00;ooookJ_oonfX00ooonfX00ooO0?ooE_l0o`0Jo`02oookJP03ooGo0?oo
nf[ooo]Z00Kooo]Z00Gooi`0oookJ_oonf[ooo]Zo`2Io`07oookJP03oomV0?nT0?oooo]Z00Cooo]Z
00?o0?l0oookJ_oonfX06_oonfX4o`0002Sooo]Z00?ooc40oookJ_oonfX0c?oonfX002_ooo]Z00Go
olT0oom<0?l0oe7ooo]Zo`2Wo`04oookJP03om`0oooonf[ooo]Z00?ooo]Z00?oodH0oon90?oonfX0
1OoonfX03Ol0ooOooo]Zok?o0?l0okOok`3ooookJ_l05ooo0>Goo`3ohOoonf[oob`0oa;o0?l0;Ol0
0_oonfX02ol0oOoooo]ZoookJ_oo0:7ooo]ZoonP0?l0=ooooo]Zo`08oooo@`3o0?;o00?ooo]Z00?o
0?nco`3Eoooo02/01?oonfX01_o00?oooo]ZoookJ_oo0:?ooo]Zool0Q@?ooo]Z00Ko2_l0oomk0?oo
nf[oaOl0oookJ_ooS002oookJP05ojGo0?l0obCooo]ZoookJ_noo`000ooonfX01ooo03_ooo]Zoook
J_l0og[o097ooookJ_oo0<h01OoonfX00ol0S?ooOP3oool:0005oookJP03ool0o?oonf[oom<000;o
oo]Z00?o0?nIoookJ_oonfX01_oonfX00oooB03ooo]ZoookJP07oookJP03o`3oO?oonf[ooo]Z00So
oo]Z00?o00;ooookJ_oonfX00_oonfX00ooob@3og`3ooeKo0002onGo0003ooo90?oeo`3ooo]Z00So
oo]Z00Cooi`0oookJ_oonf[oolT02?oonfX00oooIP3ooo]ZoookJP03oookJP03o`3o0?oonf[ooo]Z
01_ooo]Z1?l0000WoookJP03oola0?oonf[ooo]Z0?Cooo]Z00Cooj80oom<0?l0oe7ooo]Z0_l0Yol4
oookJP03om`0oooonf[ooo]Z00;ooo]Z00?oodH0oookJ_ooR@001OoonfX01Ol0ooOooo]Zo`08oonc
o`3ok`3o00;ooo]Z00Ko0>Goo`3oS?l0on7oob`0oa;o0?l0;Ol3oookJP07o`3moooonf[oo`2Qoook
J_ooX03oP`3oo`0go`02o`08o`08oom30?l0l_oooo]ZoookJ_l0ok?ooo]Zool0:ol0okH3oookJP06
ol00oooonf[ooo]Zool0Xooonf[oo`250ooonfX01_l:o`3ooo]Zoomk0?o5o`3ooo]Zoon<00?ooo]Z
00GoYOl0oookJ_oonf[ooo]Zokoo0003oookJP07ool0>ooonf[o0?mjoookJ_l0TOooo`3>o`3ohP04
oookJP03o`2<oomn0?ooo`X000Gooo]Z00?oo`3loookJ_ood`000_oonfX00ol0oiWooo]ZoookJP07
oookJP03oom80?oonf[ooo]Z00Kooo]Z00?o0?mloookJ_oonfX02?oonfX00ol00_oooo]ZoookJP03
oookJP03oml0oomFo`3o01[o00;ooo]Z00?o02goooGo0?oonfX01ooonfX01OooW03ooo]ZoookJ_l0
VOooF`3o00Oooo]Z00?oofH0oj@0oooonfX00ooonfX00ol0o`3ooo]ZoookJP0KoookJPCo0000:?oo
nfX00ooo<@3ooo]ZoookJP3<oookJP00:_oonfX01Ooob@3ood`0o`3oDOoonf[o0:Oo00Cooo]Z00?o
g03ooookJ_oonfX00ooonfX00oooAP3oohT0oookJP05oookJP04o`3omooonf[o/ol0o`3o]`;ooo]Z
00Oo01Ooo`3Uool0on7ooo]Zool/0?lBo`3o02go00;ooo]Z00_o0?gooookJ_oonf[oo`2QoookJ_oo
X03o03OooookJ_l02?oood<0o`3bo`03oookJP03o`3o/ol0eOooo`0[00Cooo]Z00Ko`03ooookJ_oo
nf[oo`2SoookJ_oo08D3oookJP06o`[o0?ooN`3ooo]ZolGo0?oonf[ooh`00_oonfX01OnUo`3o0?lT
oookJ_oonf[o_ol000?ooo]Z00Ooo`0koookJ_oonf[o0?mjo`2Aoooonf[oo`3>00Gooo]Z00?o08co
ogh0oooo2P001OoonfX01_oo0?cooo]ZoookJ_ood`3ooo]Zo`3oV@Sooo]Z00?oodP0oookJ_oonfX0
1ooonfX00ol0ogcooo]ZoookJP08oookJP03o`02oooonf[ooo]Z00?ooo]Z00KoolT0oml0oooob@3o
iOl0ooo90?oeo`09oookJP05oonL0?oonf[ooo]ZoookJ_l0VOl01ooonfX00oooIP3oY03ooookJP04
oookJP03o`3o0?oonf[ooo]Z01_ooo]Z1?l0000XoookJP03oola0?oonf[ooo]Z0?;ooo]Z00Gooj80
oom<0?l0oe7ooo]Zo`2Wo`05oookJP03om`0oooonf[ooo]Z00;ooo]Z00?oodH0oookJ_ooR@001Ooo
nfX01Ol0ooOooo]Zo`08oonco`3ok`3o00;ooo]Z00Ko0>Goo`3oS?l0on7oob`0oa;o0?l0;Ol3oook
JP0;o`3moooonf[oo`2QoookJ_ooX03oP`3oo`0gool02?oooo]Zoom30?l0l_l00_oonfX01?l0ok?o
oo]Zool0:ol0okH3oookJP06ol00oooonf[ooo]Zool0Xooonf[oo`250ooonfX01_l:o`3ooo]Zoomk
0?o5o`3ooo]Zoon<00?ooo]Z00GoYOl0oookJ_oonf[ooo]Zokoo0003oookJP07ool0>ooonf[o0?mj
oookJ_l0TOooo`3>o`3ohP04oookJP03o`2<oomn0?ooo`X000Gooo]Z00Koo`3loookJ_oonf[oom<0
oookJ_l0oiT9oookJP03oom80?oonf[ooo]Z00Kooo]Z00?o0?mloookJ_oonfX02?oonfX00ol00_oo
oo]ZoookJP04oookJP06oml0ool06_oooo]ZoookJ_l0;OoomOl02?oonfX01OooW03ooo]ZoookJ_oo
nf[o09Wo00Oooo]Z00?oofH0oj@0oooonfX01?oonfX00ol0o`3ooo]ZoookJP0KoookJPCo0000:?oo
nfX00ooo<@3ooo]ZoookJP3<oookJP00:_oonfX01?ooC03o0?mAoookJ_l0Yol4oookJP03om`0oooo
nf[ooo]Z00;ooo]Z0_ooAP000oooR@3ooo]ZoookJP04oookJP04o`3omooonf[o/ol0o`3o]`;ooo]Z
00Oo01Ooo`3Uool0on7ooo]Zool/0?lBo`3o02go00;ooo]Z00_o0?gooookJ_oonf[oo`2QoookJ_oo
X03o03OooookJ_l02?oood<0o`3bo`03oookJP03o`3o/ol0eOooo`0[00Cooo]Z00Ko`03ooookJ_oo
nf[oo`2SoookJ_oo08D3oookJP06o`[o0?ooN`3ooo]ZolGo0?oonf[ooh`00_oonfX01OnUo`3o0?lT
oookJ_oonf[o_ol000?ooo]Z00Ooo`0koookJ_oonf[o0?mjo`2Aoooonf[oo`3>00Gooo]Z00?o08co
ogh0oooo2P001OoonfX01_oo0?cooo]ZoookJ_ood`3ooo]Zo`3oV@Sooo]Z00?oodP0oookJ_oonfX0
1ooonfX00ol0ogcooo]ZoookJP08oookJP03o`02oooonf[ooo]Z00?ooo]Z00?oolT0oml0oooob@00
0_oob@000ooeo`3ooo]ZoookJP07oookJP05oonL0?oonf[ooo]ZoookJ_l0VOl02?oonfX00oooIP3o
oo]ZoookJP03oookJP03o`3o0?oonf[ooo]Z01cooo]Z1?l0000XoookJP03oola0?oonf[ooo]Z0?;o
oo]Z00Cood`0o`3oDOoonf[o0:Oo1OoonfX01?oL0?oooo]ZoookJ_oonfX2oom60003oookJ_ooR@3o
oo]Z00Cooo]Z00Go0?ogoookJ_l02?oo/ol0onl0o`02oookJP06o`3Uool0ohco0?oQool/0?lBo`3o
02go0ooonfX02ol0oOoooo]Zool0XOoonf[ooj00oh<0ool0=ooo00SooookJ_oo@`3o0?;o00;ooo]Z
00Co0?ncoookJ_oo02_o0?nf0ooonfX01_o00?oooo]ZoookJ_oo0:?ooo]Zool0Q@?ooo]Z00Ko2_l0
oookJ_ooN`3oaOl0oookJ_ooS003oookJP05ojGo0?oonf[ooo]ZoookJ_noo`000ooonfX01ooo03_o
oo]Zo`3oN_oonf[o097oool0c_l0on801?oonfX00ol0S?ooOP3oool:0005oookJP06ool0o?oonf[o
oo]ZoooC0?oonf[o0?nI2OoonfX00oooB03ooo]ZoookJP06oookJP03o`3oO?oonf[ooo]Z00Sooo]Z
00?o00;ooookJ_oonfX01?oonfX01_oO0?oooo]Zo`0Joooonf[o02goooGo00Sooo]Z00Kooi`0oook
J_oonf[ooo]Zo`2IoomK0?l7oookJP03oomV0?oonf[ooo]Z00?ooo]Z00?o0?l0oookJ_oonfX07?oo
nfX4o`0002Sooo]Z00?ooc40oookJ_oonfX0c?oonfX002[ooo]Z00?o0?mAoookJ_l0Yol01?oonfX0
0ooL0?oooo]ZoookJP02oookJP03oom60?oonf[oohT000Kooo]Z00Co0?ogoookJ_nco`3o0?ng0_oo
nfX01ol05ooo0>Goo`3ohOoonf[oob`0oa;o0?l0;Ol00_oonfX02ol0oOoooo]ZoookJ_oo0:7ooo]Z
oonP0?l0=ooooo]Zo`08oooo@`3o0?;o00?ooo]Z00Co0?nco`3Eoooo02_oU?l00ooonfX01_o00?oo
oo]ZoookJ_oo0:?ooo]Zool0Q@?ooo]Z00Ko2_l0oomk0?oonf[oaOl0oookJ_ooS002oookJP05ojGo
0?l0obCooo]ZoookJ_noo`000ooonfX01ooo03_ooo]ZoookJ_l0og[o097ooookJ_oo0<h01OoonfX0
0ol0S?ooOP3oool:0006oookJP05ool0o?oonf[oom<0oookJ_l0oiT02OoonfX00oooB03ooo]Zoook
JP06oookJP03o`3oO?oonf[ooo]Z00Sooo]Z00?o00;ooookJ_oonfX01?oonfX00ooO0?ooolT0ooo9
0002ooo90003ooGo0?oob@3ooo]Z00Oooo]Z00Cooi`0oookJ_oonf[o09Wo2?oonfX00oooIP3ooo]Z
oookJP04oookJP03o`3o0?oonf[ooo]Z01cooo]Z1?l0000XoookJP03oola0?oonf[ooo]Z0?;ooo]Z
00?o0?mAoookJ_l0Yol01OoonfX01OoL0?oooo]ZoookJ_oonf[oodH000;ooo]Z00?oohT0oookJ_oo
nfX00ooonfX01Ol0ooOooo]Zo`08oonco`3ok`3o00;ooo]Z00Ko0>Goo`3oS?l0on7oob`0oa;o0?l0
;Ol3oookJP0;o`3moooonf[oo`2QoookJ_ooX03oP`3oo`0gool02?oooo]Zoom30?l0l_l00_oonfX0
1?l0ok?ooo]Zool0:ol0okH3oookJP06ol00oooonf[ooo]Zool0Xooonf[oo`250ooonfX01_l:o`3o
oo]Zoomk0?o5o`3ooo]Zoon<00?ooo]Z00GoYOl0oookJ_oonf[ooo]Zokoo0003oookJP07ool0>ooo
nf[o0?mjoookJ_l0TOooo`3>o`3ohP04oookJP03o`2<oomn0?ooo`X000Kooo]Z00Goo`3loookJ_oo
d`3ooo]Zo`3oV@0:oookJP03oom80?oonf[ooo]Z00Gooo]Z00?o0?mloookJ_oonfX02?oonfX00ol0
0_oooo]ZoookJP04oookJP06oml0oomFo`3o01[ooookJ_l0;OoomOl02OoonfX01OooW03ooo]Zoook
J_l0VOooF`3o00Oooo]Z00?oofH0oj@0oooonfX01?oonfX00ol0o`3ooo]ZoookJP0LoookJPCo0000
:OoonfX00ooo<@3ooo]ZoookJP3;oookJP00:ooonfX00ol0Yooooo]ZoookJP02oookJP03om`0oooo
nf[ooo]Z00;ooo]Z00?oodH0oookJ_ooR@001_oonfX01?l0ooOooo]Zok?o0?l0okL2oookJP07o`0G
ool0iOoo0?oQoookJ_oo;03o4_l0o`0]o`02oookJP0;o`3moooonf[ooo]Zool0XOoonf[ooj00o`0g
oooonf[o00Sooom30?l0l_l00ooonfX01?l0ok?o0=Goool0:onDo`03oookJP06ol00oooonf[ooo]Z
ool0Xooonf[oo`250ooonfX01_l:o`3oog/0oookJ_o5o`3ooo]Zoon<00;ooo]Z00GoYOl0o`3o9?oo
nf[ooo]Zokoo0004oookJP06ool0>ooonf[o0?mjo`2Aoooonf[oo`3>1OoonfX00ol0S?ooOP3oool:
0006oookJP03ool0o?oonf[oom<000;ooo]Z00?o0?nIoookJ_oonfX01_oonfX00oooB03ooo]Zoook
JP06oookJP03o`3oO?oonf[ooo]Z00Wooo]Z00?o00;ooookJ_oonfX00ooonfX00ooO0?ooolT0ooo9
0002ooo90004ooGo0?oob@3oolT0ooo900Kooo]Z00Gooi`0oookJ_oonf[ooo]Zo`2Io`07oookJP03
oomV0?nT0?oooo]Z00Cooo]Z00?o0?l0oookJ_oonfX07OoonfX4o`0002Sooo]Z00?ooc40oookJ_oo
nfX0looonfX00ol0Yooooo]ZoookJP03oookJP05om`0oooonf[ooo]ZoookJ_ooAP000_oonfX00ooo
R@3ooo]ZoookJP03oookJP05o`3omooonf[o00Sook?o0?o_0?l00_oonfX01_l0iOoo0?n<o`3ohOoo
;03o4_l0o`0]o`?ooo]Z00_o0?gooookJ_oo0:7ooo]ZoonP0?n30?oo03Ooo`08oooonf[ood<0o`3b
o`02oookJP04o`3o/ooonf[oo`0[o`3o]P?ooo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_oo08D3oook
JP06o`[o0?oonf[oog/0olGo0?oonf[ooh`00ooonfX01OnUo`3ooo]ZoookJ_oonf[o_ol000?ooo]Z
00Ooo`0koookJ_l0og[ooo]Zo`2Aoooo0<ko0?oR00Cooo]Z00Co08coogh0oooonf[oo`X01OoonfX0
0ooo0?cooo]ZoooC0002oookJP03o`3oVOoonf[ooo]Z00Oooo]Z00?oodP0oookJ_oonfX01OoonfX0
0ol0ogcooo]ZoookJP09oookJP03o`02oooonf[ooo]Z00?ooo]Z00?og`3ooeKo0?l06_l00_oonfX0
0ol0;OoomOl0oookJP07oookJP05oonL0?oonf[ooo]ZoookJ_l0VOl02?oonfX00oooIP3ooo]Zoook
JP03oookJP03o`3o0?oonf[ooo]Z01gooo]Z1?l0000YoookJP03oola0?oonf[ooo]Z0<_ooo]Z000Z
oookJP03o`2Woooonf[ooo]Z00;ooo]Z00?og03ooookJ_oonfX00_oonfX00oooAP3ooo]Zoon90006
oookJP04o`3omooonf[o/ol0o`3o]`;ooo]Z00Oo01Ooo`3Uool0on7ooo]Zool/0?lBo`3o02go00;o
oo]Z00_o0?gooookJ_oonf[oo`2QoookJ_ooX03o03OooookJ_l02?oood<0o`3bo`03oookJP04o`3o
/ol0eOooo`0[oiCo00?ooo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_oo08D3oookJP06o`[o0?ooN`3o
oo]ZolGo0?oonf[ooh`00_oonfX01OnUo`3o0?lToookJ_oonf[o_ol000Cooo]Z00Koo`0koookJ_l0
og[o097ooookJ_oo0<h6oookJP03o`2<oooo2P3ooo]Z00Gooo]Z00?oo`3loookJ_ood`000_oonfX0
0ol0oiWooo]ZoookJP06oookJP03oom80?oonf[ooo]Z00Kooo]Z00?o0?mloookJ_oonfX02OoonfX0
0ol00_oooo]ZoookJP04oookJP05oml0oooob@3oolT0ooo90?oeo`000_oob@07oookJP05oonL0?oo
nf[ooo]ZoookJ_l0VOl02?oonfX00oooIP3ooo]ZoookJP03oookJP03o`3o0?oonf[ooo]Z01kooo]Z
1Ol0000XoookJP03oola0?oonf[ooo]Z0?7ooo]Z00?o0:OooookJ_oonfX00ooonfX01OoL0?oooo]Z
oookJ_oonf[oodH000;ooo]Z00?oohT0oookJ_oonfX00ooonfX01Ol0ooOooo]Zok?o0?nco`3oo`3>
00;ooo]Z00Ko0>GooookJ_l0on7oob`0oa;o0?l0;Ol3oookJP0;o`3moooonf[oo`2QoookJ_ooX03o
P`3oo`0gool02?oooo]Zoom30?l0l_l00_oonfX01?l0ok?ooo]Zool0:ol0okH3oookJP06ol00oooo
nf[ooo]Zool0Xooonf[oo`250ooonfX01_l:o`3ooo]Zoomk0?o5o`3ooo]Zoon<00?ooo]Z00GoYOl0
oookJ_oonf[ooo]Zokoo0003oookJP07ool0>ooonf[o0?mjoookJ_l0TOooo`3>o`3ohP05oookJP03
o`2<oooonf[oo`X000Gooo]Z00?oo`3loookJ_ood`000_oonfX00ol0oiWooo]ZoookJP07oookJP03
oom80?oonf[ooo]Z00Kooo]Z00?o0?mloookJ_oonfX02?oonfX00ol00_oooo]ZoookJP04oookJP06
oml0ool06_oooo]ZoookJ_l0;OoomOl02?oonfX01_ooW03ooo]ZoookJ_oonf[o09Wooe/0o`Oooo]Z
00?oofH0oj@0oooonfX00ooonfX00ol0o`3ooo]ZoookJP0NoookJPGo0000:?oonfX00ooo<@3ooo]Z
oookJP3;oookJP00;_oonfX00ooL0?oooo]ZoookJP02oookJP03oom60?oonf[oohT000Gooo]Z0_l0
ooL00ooonf[o/ol0o`3o]`02oookJP;o0>Go00Go0?oQoookJ_oo;03o4_l0o`0]o`02oookJP0;o`3m
oooonf[ooo]Zool0XOoonf[ooj00o`0goooonf[o00Sooom30?l0l_l00ooonfX01?l0ok?o0=Goool0
:onDo`03oookJP06ol00oooonf[ooo]Zool0Xooonf[oo`250ooonfX01_l:o`3oog/0oookJ_o5o`3o
oo]Zoon<00;ooo]Z00GoYOl0o`3o9?oonf[ooo]Zokoo0004oookJP06ool0>ooonf[ooo]Zo`3oN_oo
nf[oo`3>1_oonfX00ol0S?ooo`X0oookJP05oookJP03ool0o?oonf[oom<000;ooo]Z00?o0?nIoook
J_oonfX01_oonfX00oooB03ooo]ZoookJP06oookJP03o`3oO?oonf[ooo]Z00Wooo]Z00?o00;ooook
J_oonfX01?oonfX00ooO0?ooolT0ooo90002ooo90003ooGo0?oob@3ooo]Z00Oooo]Z00Gooi`0oook
J_oonf[oF`3oo`2Io`07oookJP03oomV0?nT0?oooo]Z00Cooo]Z00?o0?l0oookJ_oonfX07_oonfX4
o`0002Wooo]Z00?ooc40oookJ_oonfX0m_oonfX01_oL0?oooo]ZoookJ_oonf[oodH0oookJP;oohT0
1?oonfX2o`3om`04oookJ_nco`3o0?ngool0cP;ooo]Z00Ko0>GooookJ_l0on7oob`0oa;o0?l0;Ol3
oookJP0;o`3moooonf[oo`2QoookJ_ooX03oP`3oo`0gool02?oooo]Zoom30?l0l_l00_oonfX01?l0
ok?ooo]Zool0:ol0okH3oookJP06ol00oooonf[ooo]Zool0Xooonf[oo`250ooonfX01_l:o`3ooo]Z
oomk0?o5o`3ooo]Zoon<00?ooo]Z00GoYOl0oookJ_oonf[ooo]Zokoo0003oookJP07ool0>ooonf[o
oo]Zo`3oN_l0TOooo`3>o`3ohP05oookJP03o`2<oooonf[oo`X000Gooo]Z00?oo`3loookJ_ood`00
0_oonfX00ol0oiWooo]ZoookJP07oookJP03oom80?oonf[ooo]Z00Kooo]Z00?o0?mloookJ_oonfX0
2?oonfX00ol00_oooo]ZoookJP04oookJP06oml0oooonf[o01[ooookJ_l0;OoomOl02OoonfX01Ooo
W03ooo]ZoookJ_oonf[o09Wo00Oooo]Z00?oofH0oj@0oooonfX01?oonfX00ol0o`3ooo]ZoookJP0N
oookJPCo0000:OoonfX00ooo<@3ooo]ZoookJP3;oookJP00;OoonfX00ooL0?oooo]ZoookJP02oook
JP03oom60?oonf[oohT000Gooo]Z00Go0?ogoookJ_oonf[o/ol0o`3o]`02oookJP07o`3Uool0on7o
0?oQoookJ_oo;03o4_l0o`0]o`02oookJP0;o`3moooonf[ooo]Zool0XOoonf[ooj00o`0goooonf[o
00Sooom30?l0l_l00ooonfX01?l0ok?o0=Goool0:onDo`03oookJP06ol00oooonf[ooo]Zool0Xooo
nf[oo`250ooonfX01_l:o`3oog/0oookJ_o5o`3ooo]Zoon<00;ooo]Z00GoYOl0o`3o9?oonf[ooo]Z
okoo0004oookJP07ool0>ooonf[ooo]Zo`3oN_oonf[oo`3>o`3ohP05oookJP03o`2<oomn0?ooo`X0
00Gooo]Z00?oo`3loookJ_ood`000_oonfX00ol0oiWooo]ZoookJP06oookJP03oom80?oonf[ooo]Z
00Kooo]Z00?o0?mloookJ_oonfX02OoonfX00ol00_oooo]ZoookJP04oookJP03oml0oooob@3oolT0
00;oolT000?omOl0ooo90?oonfX01ooonfX01OooW03ooo]ZoookJ_oonf[o09Wo00Sooo]Z00?oofH0
oookJ_oonfX00ooonfX00ol0o`3ooo]ZoookJP0OoookJPCo0000:OoonfX00ooo<@3ooo]ZoookJP3e
oookJP07om`0oooonf[ooo]ZoookJ_ooAP3ooo]Zoon90005oookJP06o`3omooonf[ooo]Zok?o0?l0
okOoo`3>0_oonfX01_l0iOoo0?oQo`3ohOoo;03o4_l0o`0]o`?ooo]Z00_o0?gooookJ_oo0:7ooo]Z
oonP0?n30?oo03Ooo`08oooonf[ood<0o`3bo`02oookJP04o`3o/ooonf[oo`0[o`3o]P?ooo]Z00Ko
`03ooookJ_oonf[oo`2SoookJ_oo08D3oookJP06o`[o0?oonf[oog/0olGo0?oonf[ooh`00ooonfX0
1OnUo`3ooo]ZoookJ_oonf[o_ol000?ooo]Z00Soo`0koookJ_oonf[o0?mjo`2Aoooo0<kooo]Zo`3o
hPCooo]Z00?o08coogh0oooo2P001OoonfX00ooo0?cooo]ZoooC0002oookJP03o`3oVOoonf[ooo]Z
00Oooo]Z00?oodP0oookJ_oonfX01_oonfX00ol0ogcooo]ZoookJP08oookJP03o`02oooonf[ooo]Z
00Cooo]Z00Oog`3ooeKo0?l06_oooo]Zo`0]oooonf[omOl000Sooo]Z00Kooi`0oookJ_oonf[ooo]Z
o`2IoomK0?l7oookJP03oomV0?oonf[ooo]Z00?ooo]Z00?o0?l0oookJ_oonfX07ooonfX4o`0002Wo
oo]Z00?ooc40oookJ_oonfX0booonfX002cooo]Z0_oob@03oookJP03oom60?oonf[oohT000Gooo]Z
00Go0?ogoookJ_oonf[o/ol0o`3o]`02oookJP07o`3Uool0on7ooo]ZoookJ_oo;03o4_l0o`0]o`02
oookJP0;o`3moooonf[ooo]Zool0XOoonf[ooj00o`0goooonf[o00Sooom30?l0l_l00ooonfX01?l0
ok?o0=Goool0:onDo`03oookJP06ol00oooonf[ooo]Zool0Xooonf[oo`250ooonfX01_l:o`3oog/0
oookJ_o5o`3ooo]Zoon<00;ooo]Z00?oYOl0o`3o9?oonfX00_oonfX01Onoo`3ooo]ZoookJ_oonf[o
o`0k00;ooo]Z00Co0?mjoookJ_oo0<ko0?oR1OoonfX00ol0S?ooOP3oool:0005oookJP03ool0o?oo
nf[oom<000;ooo]Z00?o0?nIoookJ_oonfX01_oonfX00oooB03ooo]ZoookJP07oookJP03o`3oO?oo
nf[ooo]Z00Wooo]Z00?o00;ooookJ_oonfX00ooonfX00ooO0?ooE_l0ooo90003ooo90003ooGo0?oo
nf[ooo]Z00Kooo]Z00Gooi`0oookJ_oonf[ooo]Zo`2Io`08oookJP03oomV0?nT0?oooo]Z00Cooo]Z
00?o0?l0oookJ_oonfX07ooonfX4o`0002Wooo]Z00?ooc40oookJ_oonfX0looonfX2om`0o`?ooo]Z
00?oodH0oookJ_ooR@001OoonfX01_l0ooOooo]ZoookJ_nco`3o0?ngool0cP;ooo]Z00Ko0>Goo`3o
hOoonf[oob`0oa;o0?l0;Ol3oookJP0;o`3moooonf[oo`2QoookJ_ooX03oP`3oo`0gool02?oooo]Z
oom30?l0l_l00_oonfX01?l0ok?ooo]Zool0:ol0okH3oookJP06ol00oooonf[ooo]Zool0Xooonf[o
o`250ooonfX01_l:o`3ooo]Zoomk0?o5o`3ooo]Zoon<00?ooo]Z00?oYOl0o`3o9?oonfX00_oonfX0
1?noo`3ooo]ZoookJ_oo03/2oookJP05o`3oN_l0TOooo`3>oookJ_l0on801?oonfX00ol0S?ooOP3o
ool:0005oookJP03ool0o?oonf[oom<000;ooo]Z00?o0?nIoookJ_oonfX01ooonfX00oooB03ooo]Z
oookJP06oookJP03o`3oO?oonf[ooo]Z00Wooo]Z00?o00;ooookJ_oonfX00ooonfX01ooO0?ooE_l0
o`0Joooonf[o02gooookJ_oeo`002?oonfX01_ooW03ooo]ZoookJ_oonf[o09Wooe/0o`Oooo]Z00?o
ofH0oj@0oooonfX01?oonfX00ol0o`3ooo]ZoookJP0OoookJPCo0000:OoonfX00ooo<@3ooo]Zoook
JP3;oookJP00:ooonfX00ooob@3ooo]ZoookJP02oookJP03oom60?oonf[oohT000Gooo]Z00Go0?og
oookJ_oonf[o/ol0o`3o]`02oookJP07o`3Uool0on7ooo]ZoookJ_oo;03o4_l0o`0]o`02oookJP0;
o`3moooonf[ooo]Zool0XOoonf[ooj00o`0goooonf[o00Sooom30?l0l_l00ooonfX01?l0ok?o0=Go
ool0:onDo`03oookJP06ol00oooonf[ooo]Zool0Xooonf[oo`250ooonfX01_l:o`3oog/0oookJ_o5
o`3ooo]Zoon<00;ooo]Z00?oYOl0o`3o9?oonfX00_oonfX01Onoo`3ooo]ZoookJ_oonf[oo`0k00;o
oo]Z00Co0?mjoookJ_oo0<ko0?oR1OoonfX00ol0S?ooOP3oool:0005oookJP03ool0o?oonf[oom<0
00;ooo]Z00?o0?nIoookJ_oonfX01_oonfX00oooB03ooo]ZoookJP07oookJP03o`3oO?oonf[ooo]Z
00Wooo]Z00?o00;ooookJ_oonfX01?oonfX00ooO0?ooolT0ooo90002ooo90003ooGo0?oonf[ooo]Z
00Kooo]Z00Kooi`0oookJ_oonf[ooo]Zoe/0ool0VOl7oookJP03oomV0?nT0?oooo]Z00Cooo]Z00?o
0?l0oookJ_oonfX08?oonfX4o`0002Wooo]Z00?ooc40oookJ_oonfX0l_oonfX00ooL0?oooo]Zoook
JP02oookJP03oom60?oonf[oohT000Gooo]Z00Go0?ogoookJ_oonf[o/ol0o`3o]`03oookJP06o`3U
ool0on7ooo]Zool/0?lBo`3o02go0ooonfX02ol0oOoooo]Zool0XOoonf[ooj00oh<0ool0=ooo00So
oookJ_oo@`3o0?;o00;ooo]Z00Co0?ncoookJ_oo02_o0?nf0ooonfX01_o00?oooo]ZoookJ_oo0:?o
oo]Zool0Q@?ooo]Z00Ko2_l0oookJ_ooN`3oaOl0oookJ_ooS003oookJP03ojGo0?l0obCooo]Z00;o
oo]Z00Co_ol0oookJ_oonf[oo`0k0_oonfX01Ol0og[o097oool0c_oonf[o0?oR00Cooo]Z00?o08co
ogh0oooo2P001OoonfX00ooo0?cooo]ZoooC0002oookJP03o`3oVOoonf[ooo]Z00Oooo]Z00?oodP0
oookJ_oonfX01_oonfX00ol0ogcooo]ZoookJP09oookJP03o`02oooonf[ooo]Z00Cooo]Z00Kog`3o
o`0Joooonf[o02gooookJ_oeo`09oookJP05oonL0?oonf[ooo]ZoookJ_l0VOl02?oonfX00oooIP3o
oo]ZoookJP03oookJP03o`3o0?oonf[ooo]Z023ooo]Z1?l0000ZoookJP03oola0?oonf[ooo]Z0<[o
oo]Z000ZoookJP03ooo90?oonf[ooo]Z00;ooo]Z00?oodH0oookJ_ooR@001OoonfX01Ol0ooOooo]Z
oookJ_nco`3o0?ng00;ooo]Z00Oo0>Goo`3ohOoonf[ooo]Zool/0?lBo`3o02go00;ooo]Z00_o0?go
oookJ_oonf[oo`2QoookJ_ooX03o03OooookJ_l02?oood<0o`3bo`03oookJP04o`3o/ol0eOooo`0[
oiCo00?ooo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_oo08D3oookJP06o`[o0?ooN`3ooo]ZolGo0?oo
nf[ooh`00_oonfX00onUo`3o0?lToookJP02oookJP05okoo0?oonf[ooo]ZoookJ_oo03/00_oonfX0
1?l0og[ooo]Zool0c_l0on85oookJP03o`2<oomn0?ooo`X000Gooo]Z00Koo`3loookJ_oonf[oom<0
oookJ_l0oiT9oookJP03oom80?oonf[ooo]Z00Kooo]Z00?o0?mloookJ_oonfX02OoonfX00ol00_oo
oo]ZoookJP04oookJP03oml0oooonf[oolT000;oolT000?omOl0oookJ_oonfX01ooonfX01OooW03o
oo]ZoookJ_oonf[o09Wo00Sooo]Z00?oofH0oj@0oooonfX01?oonfX00ol0o`3ooo]ZoookJP0Poook
JPCo0000:OoonfX00ooo<@3oU?l0oiCo0002oiCo0>oooo]Z00?og03ooookJ_oonfX00_oonfX00ooo
AP3ooo]Zoon90005oookJP05o`3omooonf[ooo]Zok?o0?l0okL00ooonfX01_l0iOoo0?oQoookJ_oo
;03o4_l0o`0]o`;ooo]Z00co0?n^o`3moooonf[oo`2QoookJ_ooX03oP`3oo`0gool02?oooo]Zoom3
0?l0l_l2oookJP04o`3o/ooonf[oo`0[o`3o]P?ooo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_oo08D3
oookJP06o`[o0?oonf[oog/0olGo0?oonf[ooh`00ooonfX00onUo`3o0?lToookJP02oookJP04okoo
0?oonf[ooo]Zool0>`;ooo]Z00Go0?mjo`2Aoooo0<kooo]Zo`3ohP04oookJP03o`2<oomn0?ooo`X0
00Gooo]Z00Koo`3loookJ_oonf[oom<0oookJ_l0oiT:oookJP03oom80?oonf[ooo]Z00Gooo]Z00?o
0?mloookJ_oonfX02OoonfX00ol00_oooo]ZoookJP04oookJP06oml0oooonf[o01[ooookJ_l0;Ooo
mOl02OoonfX01_ooW03ooo]ZoookJ_oonf[o09Wooe/0o`Oooo]Z00?oofH0oj@0oooonfX01?oonfX0
0ol0o`3ooo]ZoookJP0PoookJPCo0000:_oonfX00ooo<@3ooo]ZoookJP3:oookJP00;_oonfX00ooo
AP3ooo]Zoon90005oookJP05o`3omooonf[ooo]Zok?o0?l0okL00_oonfX01ol0iOoo0?oQoookJ_oo
nf[oob`0oa;o0?l0;Ol00_oonfX02ol0oOoooo]ZoookJ_oo0:7ooo]ZoonP0?l0=ooooo]Zo`08oooo
@`3o0?;o00?ooo]Z00Co0?nco`3Eoooo02_oU?l00ooonfX01_o00?oooo]ZoookJ_oo0:?ooo]Zool0
Q@?ooo]Z00Ko2_l0oomk0?oonf[oaOl0oookJ_ooS002oookJP03ojGo0?l0obCooo]Z00;ooo]Z00Go
_ol0oookJ_oonf[ooo]Zool0>`02oookJP04o`3oN_oonf[ooo]Zool0cPGooo]Z00?o08coogh0oooo
2P001OoonfX01?oo0?cooo]ZoookJ_ood`02oookJP03o`3oVOoonf[ooo]Z00Kooo]Z00?oodP0oook
J_oonfX01_oonfX00ol0ogcooo]ZoookJP09oookJP03o`02oooonf[ooo]Z00Cooo]Z00?og`3ooeKo
0?oob@000_oob@000ooonf[omOl0oookJP07oookJP05oonL0?oonf[ooo]ZoookJ_l0VOl02?oonfX0
0oooIP3oY03ooookJP04oookJP03o`3o0?oonf[ooo]Z027ooo]Z1?l0000VoookJPSoU?l0looonfX0
0oooAP3ooo]Zoon90005oookJP05o`3omooonf[ooo]Zok?o0?l0okL00ooonfX01_l0iOoo0?oQoook
J_oo;03o4_l0o`0]o`;ooo]Z00co0?n^o`3moooonf[oo`2QoookJ_ooX03oP`3oo`0gool02?ooolT0
oom30?l0l_l2oookJP04o`3o/ooonf[oo`0[o`3o]P?ooo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_oo
08D3oookJP06o`[o0?oonf[oog/0olGo0?oonf[ooh`00ooonfX00onUo`3o0?lToookJP02oookJP04
okoo0?oonf[ooo]Zool0>`;ooo]Z00Go0?mjo`2Aoooonf[oo`3>o`3ohP04oookJP03o`2<oomn0?oo
o`X000Gooo]Z00Coo`3loookJ_oonf[oom<00_oonfX00ol0oiWooo]ZoookJP07oookJP03oom80?oo
nf[ooo]Z00Kooo]Z00?o0?mloookJ_oonfX02?oonfX00ol00_oooo]ZoookJP04oookJP07oml0oomF
o`3o01[ooookJ_l0;Ooooo]ZooGo0008oookJP06oonL0?oonf[ooo]ZoookJ_l0VOooF`3o2?oonfX0
0oooIP3ooo]ZoookJP03oookJP03o`3o0?oonf[ooo]Z027ooo]Z1?l0000ZoookJP03oola0?oonf[o
oo]Z0<[ooo]Z000]oookJP03oom60?oonf[oohT000Gooo]Z00Go0?ogoookJ_oonf[o/ol0ool0cP02
oookJP04o`3Uool0on7ooo]ZoookJP;o4_l000Co02gooookJ_oonf[o0?go0_oonfX02?oo0:7ooo]Z
oonP0?l0=ooooo]Zo`08oooo@`3o0?;o0ooonfX01?l0ok?o0=Goool0:onDo`03oookJP06ol00oooo
nf[ooo]Zool0Xooonf[oo`251?oonfX01Ol:o`3ooo]ZolGo0?oonf[ooh`000;ooo]Z00?oYOl0o`3o
9?oonfX00_oonfX01Onoo`3ooo]ZoookJ_oonf[oo`0k00;ooo]Z00Co0?mjoookJ_oonf[oo`3>1Ooo
nfX00ol0S?ooOP3oool:0005oookJP04ool0o?oonf[ooo]ZoooC00;ooo]Z00?o0?nIoookJ_oonfX0
1_oonfX00oooB03ooo]ZoookJP06oookJP03o`3oO?oonf[ooo]Z00Wooo]Z00?o00;ooookJ_oonfX0
1OoonfX01_oO0?oo01[oooo90?oob@3ooo]ZooGo00Sooo]Z00Kooi`0oookJ_oonf[ooo]Zoe/0ool0
VOl7oookJP03oomV0?nT0?oooo]Z00Gooo]Z00?o0?l0oookJ_oonfX08OoonfX4o`0002Kooo]Z2?nD
o`3boookJP03oom60?oonf[oohT000Gooo]Z00Go0?ogoookJ_oonf[o/ol0onl0o`02oookJP07o`0G
ool0iOoo0?oQoookJ_oo;03o4_l0o`0]o`02oookJP0<o`3o[_l0oOoooo]Zool0XOoonf[ooj00oh<0
ool0=ooo00Soooo90?oo@`3o0?;o0_oonfX01?l0ok?ooo]Zool0:ol0okH3oookJP06ol00oooonf[o
oo]Zool0Xooonf[oo`251?oonfX01Ol:o`3oog/0olGo0?oonf[ooh`000?ooo]Z00?oYOl0o`3o9?oo
nfX00_oonfX01?noo`3ooo]ZoookJ_oo03/2oookJP05o`3oN_l0TOoooo]Zool0c_l0on801?oonfX0
0ol0S?ooOP3oool:0005oookJP04ool0o?oonf[ooo]ZoooC00;ooo]Z00?o0?nIoookJ_oonfX01ooo
nfX00oooB03ooo]ZoookJP06oookJP03o`3oO?oonf[ooo]Z00Sooo]Z00?o00;ooookJ_oonfX01Ooo
nfX01_oO0?oo01[ooookJ_l0;Ooooo]ZooGo00Wooo]Z00Gooi`0oookJ_oonf[ooo]Zo`2Io`08oook
JP03oomV0?oonf[ooo]Z00Cooo]Z00?o0?l0oookJ_oonfX08OoonfX4o`0002[ooo]Z00?ooc40oook
J_oonfX0b_oonfX002cooo]Z00?oodH0oookJ_ooR@001OoonfX01Ol0ooOooo]ZoookJ_nco`3oo`3>
00;ooo]Z00Oo0>Goo`3ohOoonf[ooo]Zoa;o0?oonf[o02go00;ooo]Z00_o0?gooookJ_oonf[oo`2Q
oookJ_ooX03o03OooookJ_l02?oood<0o`3bo`03oookJP04o`3o/ol0eOooo`0[oiCo00?ooo]Z00Ko
`03ooookJ_oonf[oo`2SoookJ_oo08D4oookJP05o`[o0?oonf[oaOl0oookJ_ooS0000_oonfX00onU
o`3o0?lToookJP02oookJP05okoo0?oonf[ooo]ZoookJ_oo03/00_oonfX01?l0og[ooo]ZoookJ_oo
0<h5oookJP03o`2<oomn0?ooo`X000Gooo]Z00Coo`3loookJ_oonf[oom<00_oonfX00ol0oiWooo]Z
oookJP06oookJP03oom80?oonf[ooo]Z00Kooo]Z00?o0?mloookJ_oonfX02_oonfX00ol00_oooo]Z
oookJP04oookJP06oml0oooonf[o01[oooo90?oonf[omOl02OoonfX01OooW03ooo]ZoookJ_oonf[o
09Wo00Sooo]Z00?oofH0oj@0oooonfX01?oonfX00ol0o`3ooo]ZoookJP0RoookJPCo00009ooonfX7
oiCo0?7ooo]Z00?oodH0oookJ_ooR@001OoonfX01Ol0ooOooo]ZoookJ_nco`3ok`3o00;ooo]Z00Oo
01Ooo`3Uool0on7ooo]Zool/0?lBo`3o02go00;ooo]Z00co0?n^o`3moooonf[oo`2QoookJ_ooX03o
P`3oo`0gool02?ooolT0oom30?l0l_l2oookJP04o`3o/ooonf[oo`0[o`3o]P?ooo]Z00Ko`03ooook
J_oonf[oo`2SoookJ_oo08D4oookJP05o`[o0?ooN`3oaOl0oookJ_ooS0000ooonfX00onUo`3o0?lT
oookJP02oookJP04okoo0?oonf[ooo]Zool0>`;ooo]Z00Go0?mjo`2Aoooonf[oo`3>o`3ohP04oook
JP03o`2<oomn0?ooo`X000Gooo]Z00Coo`3loookJ_oonf[oom<00_oonfX00ol0oiWooo]ZoookJP07
oookJP03oom80?oonf[ooo]Z00Kooo]Z00?o0?mloookJ_oonfX02OoonfX00ol00_oooo]ZoookJP04
oookJP06oml0oooonf[o01[oo`0]oooonf[omOl02OoonfX01OooW03ooo]ZoookJ_oonf[o09Wo00Wo
oo]Z00?oofH0oookJ_oonfX00ooonfX00ol0o`3ooo]ZoookJP0RoookJPCo0000:_oonfX00ooo<@3o
oo]ZoookJP3:oookJP00:ooonfX00oooAP3ooo]Zoon90005oookJP05o`3omooonf[ooo]Zok?o0?oo
0<h00_oonfX01ol0iOoo0?oQoookJ_oo;03o4_l0oookJ_l0;Ol00_oonfX03?l0oOoooo]ZoookJ_oo
0:7ooo]ZoonP0?l0=ooooo]Zo`08oooo@`3o0?;ooiCo00;ooo]Z00Co0?nco`3Eoooo02_oU?l00ooo
nfX01_o00?oooo]ZoookJ_oo0:?ooo]Zool0Q@Cooo]Z00Go2_l0oomk0?o5o`3ooo]Zoon<0002oook
JP03onGo0?l0obCooo]Z00;ooo]Z00?o_ol0oookJ_oonfX00_oonfX00ooo03_ooo]Zo`3oNP02oook
JP03ool0c_oonf[ooo]Z00?ooo]Z00Co08coogh0oooonf[oo`X01OoonfX00ooo0?cooo]ZoooC0002
oookJP03o`3oVOoonf[ooo]Z00Kooo]Z00?oodP0oookJ_oonfX01_oonfX00ol0ogcooo]ZoookJP0:
oookJP03o`02oooonf[ooo]Z00Cooo]Z00Cog`3ooookJ_l06_ooolT00_oonfX00ooeo`3ooo]Zoook
JP06oookJP06oonL0?oonf[ooo]ZoookJ_mK0?oo09Wo1ooonfX00oooIP3oY03ooookJP04oookJP03
o`3o0?oonf[ooo]Z02?ooo]Z1?l0000WoookJPOoU?l0l?oonfX00oooAP3ooo]Zoon90005oookJP05
o`3omooonf[ooo]Zok?o0?o_0?l00_oonfX00ol05ooo0>Goo`3oh@02ool/000@oa;o0?l0;Ooooo]Z
oookJ_l0ojko0?gooookJ_oo0:7ooo]ZoonP0?n30?oo03Ooo`08oooob@3ood<0o`3bo`;ooo]Z00Co
0?ncoookJ_oo02_o0?nf0ooonfX01_o00?oooo]ZoookJ_oo0:?ooo]Zool0Q@Cooo]Z00Go2_l0oomk
0?o5o`3ooo]Zoon<0003oookJP03ojGo0?l0obCooo]Z00;ooo]Z00_o_ol0oookJ_oonf[ooo]Zool0
>ooonf[o0?mjo`2Aoooonf[oo`3>o`3ohP04oookJP04o`2<oomn0?oooo]Zool:00Gooo]Z00?oo`3l
oookJ_ood`000_oonfX00ol0oiWooo]ZoookJP07oookJP03oom80?oonf[ooo]Z00Kooo]Z00?o0?ml
oookJ_oonfX02OoonfX00ol00_oooo]ZoookJP04oookJP04oml0oooonf[o01[oo`0]o`;ooo]Z00?o
mOl0oookJ_oonfX01ooonfX01OooW03ooo]ZoookJ_oonf[o09Wo00Sooo]Z00?oofH0oookJ_oonfX0
1?oonfX00ol0o`3ooo]ZoookJP0RoookJPCo0000:ooonfX00ooo<@3ooo]ZoookJP39oookJP00:_oo
nfX00oooAP3ooo]Zoon90005oookJP05o`3omooonf[ooo]Zok?o0?oo0<h00_oonfX01ol0iOoo0?oQ
oookJ_oo;03o4_l0oookJ_l0;Ol00_oonfX04_l0oOoooo]ZoookJ_oo0:7ooo]ZoonP0?l0=ooooo]Z
o`08oooo@`3o0?;ooookJ_nDo`3ooo]Zo`3o/ol0eOooo`0[oiCo00?ooo]Z00Ko`03ooookJ_oo0:?o
o`2SoookJ_oo08D4oookJP05o`[o0?ooN`3oaOl0oookJ_ooS0000ooonfX01OoUo`3ooo]ZoookJ_oo
nf[o_ol000Cooo]Z00?oo`0koookJ_l0ogX00_oonfX00ooo0<kooo]ZoookJP03oookJP04o`2<oomn
0?oooo]Zool:00Gooo]Z00?oo`3loookJ_ood`000_oonfX00ol0oiWooo]ZoookJP06oookJP03oom8
0?oonf[ooo]Z00Kooo]Z00?o0?mloookJ_oonfX02_oonfX00ol00_oooo]ZoookJP04oookJP07oml0
oomFo`3o01[ooookJ_l0;Ooooo]ZooGo0008oookJP06oonL0?oonf[ooo]ZoookJ_mK0?oo09Wo2?oo
nfX00oooIP3ooo]ZoookJP04oookJP03o`3o0?oonf[ooo]Z02?ooo]Z1?l0000WoookJPKoU?l0l?oo
nfX00oooAP3ooo]Zoon90005oookJP05o`3omooonf[ooo]Zok?o0?o_0?l00_oonfX01ol05ooo0>Go
o`3ohOoo;03ooo]Zoa;o0?l0;Ol00_oonfX2o`3mo`0:oookJ_oo0:7ooo]ZoonP0?n30?oo03Ooo`08
oooob@3ood<0o`3bo`;ooo]Z00Co0?ncoookJ_oo02_o0?nf0ooonfX01_o00?oooo]ZoookJ_oo0:?o
oo]Zool0Q@Cooo]Z00Go2_l0oomk0?o5o`3ooo]Zoon<0004oookJP05ojGo0?oonf[ooo]ZoookJ_no
o`000ooonfX01ooo03_ooo]Zo`3oN_l0TOoooo]Zool0c_l0on801?oonfX01?l0S?ooOP3ooookJ_oo
2P05oookJP03ool0o?oonf[oom<000;ooo]Z00?o0?nIoookJ_oonfX01ooonfX00oooB03ooo]Zoook
JP06oookJP03o`3oO?oonf[ooo]Z00Wooo]Z00?o00;ooookJ_oonfX01?oonfX01ooO0?ooE_l0o`0J
oooonf[o02gooookJ_oeo`002OoonfX01OooW03ooo]ZoookJ_oonf[o09Wo00Sooo]Z00?oofH0oj@0
oooonfX01?oonfX00ol0o`3ooo]ZoookJP0SoookJPCo0000:ooonfX00ooo<@3ooo]ZoookJP39oook
JP00:ooonfX00oooR@3ooo]ZoookJP03oookJP05o`3omooonf[ooo]Zok?o0?oo0<h00_oonfX01Ol0
iOoo0?oQoookJ_oo;03o4_l000;oolT00_oonfX03?l0oOoooo]ZoookJ_oo0:7ooo]ZoonP0?l0=ooo
oo]Zo`08oooo@`3o0?;ooookJP;oU?l000Co0?nco`3Eoooo02_oU?l00ooonfX00oo00?oooo]Zool0
X`02oookJP03ool0QOoonf[ooo]Z00;ooo]Z00Go2_l0oomk0?oonf[oaOl0oon<0003oookJP05onGo
0?oonf[ooo]ZoookJ_noo`001?oonfX00ooo03_ooo]Zo`3oNP02oookJP03ool0c_oonf[ooo]Z00?o
oo]Z00Co08coogh0oooonf[oo`X01OoonfX00ooo0?cooo]ZoooC0002oookJP03o`3oVOoonf[ooo]Z
00Oooo]Z00?oodP0oookJ_oonfX01OoonfX00ol0ogcooo]ZoookJP0:oookJP03o`02oooonf[ooo]Z
00Gooo]Z00Kog`3oo`0Joooonf[o02gooookJ_oeo`08oookJP03oonL0?oonf[ooo]Z00;ooo]Z00?o
09WooookJ_oonfX01_oonfX00oooIP3oY03ooookJP04oookJP03o`3o0?oonf[ooo]Z02Cooo]Z1?l0
000XoookJPGoU?l0lOoonfX00oooR@3ooo]ZoookJP03oookJP05o`3omooonf[ooo]Zok?o0?o_0?l0
0_oonfX01ol05ooo0>Goo`3ohOoo;03ooo]Zoa;o0?l0;Ol00_oonfX03?l0oOoooo]ZoookJ_oo0:7o
oo]ZoonP0?n30?oo03Ooo`08oooob@3ood<0o`3bo`;ooo]Z00Co0?ncoookJ_oo02_o0?nf0ooonfX0
1_o00?oooo]ZoookJ_oo0:?ooo]Zool0Q@Cooo]Z00Go2_l0oomk0?oonf[oaOl0oon<0004oookJP05
ojGo0?oonf[ooo]ZoookJ_noo`000ooonfX01ooo03_ooo]Zo`3oN_l0TOoooo]Zool0c_l0on801Ooo
nfX00ol0S?oooo]Zool:0005oookJP03ool0o?oonf[oom<000;ooo]Z00?o0?nIoookJ_oonfX02?oo
nfX00oooB03ooo]ZoookJP05oookJP03o`3oO?oonf[ooo]Z00Wooo]Z00?o00;ooookJ_oonfX01Ooo
nfX01_oO0?oo01[ooookJ_l0;Ooooo]ZooGo00Wooo]Z00Gooi`0oookJ_oonf[ooo]Zo`2Io`09oook
JP03oomV0?oonf[ooo]Z00?ooo]Z00?o0?l0oookJ_oonfX09?oonfX4o`0002_ooo]Z00?ooc40oook
J_oonfX0bOoonfX002[ooo]Z00?oohT0oookJ_oonfX00ooonfX01Ol0ooOooo]ZoookJ_nco`3oo`3>
00;ooo]Z00Ko0>Goo`3ohOoonf[oob`0oa;o0?oob@03oookJP0;o`3moooonf[ooo]Zool0XOoonf[o
oj00o`0goooonf[o00Sooom30?l0l_l00_oonfX01OnDo`3o0?ncoiCo0?oo02_oU?l000?ooo]Z00?o
`03ooookJ_oo0:<00_oonfX00ooo08Gooo]ZoookJP02oookJP05o`[o0?ooN`3ooo]ZolGo0?ooS000
0ooonfX01OoUo`3ooo]ZoookJ_oonf[o_ol000Cooo]Z00?oo`0koookJ_l0ogX00_oonfX00ooo0<ko
oo]ZoookJP03oookJP04o`2<oomn0?oooo]Zool:00Gooo]Z00?oo`3loookJ_ood`000_oonfX00ol0
oiWooo]ZoookJP07oookJP03oom80?oonf[ooo]Z00Kooo]Z00?o0?mloookJ_oonfX02_oonfX00ol0
0_oooo]ZoookJP04oookJP06oml0oooonf[o01[oo`0]oooonf[omOl02OoonfX01_ooW03ooo]Zoook
J_oonf[oF`3oo`2Io`Oooo]Z00?oofH0oj@0oooonfX01OoonfX00ol0o`3ooo]ZoookJP0ToookJPCo
0000:?oonfX5oiCo0?3ooo]Z00?oohT0oookJ_oonfX00ooonfX01Ol0ooOooo]ZoookJ_nco`3ok`3o
00;ooo]Z00Ko01Ooo`3Uool0on7oob`0oookJ_lBo`03oookJP0<o`3moooonf[ooo]Zool0XOoonf[o
oj00oh<0ool0=ooo00Soooo90?oo@`3o0?;o0_oonfX01?l0ok?ooo]Zo`3Eoooo02/3oookJP06ol00
oooonf[ooo]Zool0Xooonf[oo`251?oonfX01Ol:o`3oog/0oookJ_o5o`3ooh`000Cooo]Z00GoYOl0
oookJ_oonf[ooo]Zokoo0003oookJP07ool0>ooonf[o0?mjo`2Aoooonf[oo`3>o`3ohP05oookJP03
o`2<oooonf[oo`X000Gooo]Z00Koo`3loookJ_oonf[oom<0oookJ_l0oiT:oookJP03oom80?oonf[o
oo]Z00Kooo]Z00?o0?mloookJ_oonfX02OoonfX00ol00_oooo]ZoookJP04oookJP06oml0oooonf[o
01[oo`0]oooonf[omOl02_oonfX01OooW03ooo]ZoookJ_oonf[o09Wo00Sooo]Z00?oofH0oookJ_oo
nfX01?oonfX00ol0o`3ooo]ZoookJP0ToookJPCo0000:ooonfX00ooo<@3ooo]ZoookJP39oookJP00
;ooonfX01Ol0ooOooo]Zok?o0?nco`3ok`3o00;ooo]Z00Ko0>Goo`3ohOoonf[oob`0oa;o0?oob@03
oookJP0;o`3moooonf[ooo]Zool0XOoonf[ooj00o`0goooonf[o00Sooom30?l0l_l00_oonfX01?nD
o`3o0?ncoiCo0?oo02/2oiCo00;ooo]Z00?o`03ooookJ_oo0:<00ooonfX02Ooo08Gooo]ZoookJ_oo
nf[o2_l0oomk0?oonf[oaOl0oon<0003oookJP05onGo0?oonf[ooo]ZoookJ_noo`001?oonfX00ooo
03_ooo]Zo`3oNP02oookJP03ool0c_oonf[ooo]Z00?ooo]Z00Co08coogh0oooonf[oo`X01OoonfX0
0ooo0?cooo]ZoooC0003oookJP03o`3oVOoonf[ooo]Z00Kooo]Z00?oodP0oookJ_oonfX01_oonfX0
0ol0ogcooo]ZoookJP0:oookJP03o`02oooonf[ooo]Z00Cooo]Z00Oog`3ooookJ_l06_oooo]Zo`0]
oooonf[omOl000Sooo]Z00?ooi`0oookJ_oonfX00_oonfX00ol0VOoooo]ZoookJP06oookJP03oomV
0?oonf[ooo]Z00Cooo]Z00?o0?l0oookJ_oonfX09OoonfX4o`0002Sooo]Z1OnDo`3eoookJP05o`3o
mooonf[o/ol0ok?o0?o_0?l00_oonfX01_l05ooo0>Goo`3ohOoo;03ooo]Zoa;o00?ooo]Z00co0?go
oookJ_oonf[oo`2QoookJ_ooX03oP`3oo`0gool02?ooolT0oom30?l0l_l2oookJP04o`3o/ooonf[o
0=Goool0:`?ooo]Z00Co`03ooookJ_oonf[oo`2S0_oonfX02Ooo08Gooo]ZoookJ_oonf[o2_l0oomk
0?oonf[oaOl0oon<0004oookJP05ojGo0?oonf[ooo]ZoookJ_noo`000ooonfX01ooo03_ooo]Zo`3o
N_l0TOoooo]Zool0c_l0on801OoonfX00ol0S?ooOP3oool:0005oookJP04ool0o?oonf[ooo]ZoooC
00;ooo]Z00?o0?nIoookJ_oonfX01ooonfX00oooB03ooo]ZoookJP06oookJP03o`3oO?oonf[ooo]Z
00Wooo]Z00?o00;ooookJ_oonfX01?oonfX01ooO0?oooo]Zo`0Joooonf[o02gooookJ_oeo`002Ooo
nfX01OooW03ooo]ZoookJ_oonf[o09Wo00Wooo]Z00?oofH0oookJ_oonfX00ooonfX00ol0o`3ooo]Z
oookJP0UoookJPCo0000:ooonfX00ooo<@3ooo]ZoookJP39oookJP00;_oonfX01Ol0ooOooo]Zok?o
0?l0okOok`3o00;ooo]Z00KoolT0o`3ohOoonf[oob`0oa;o0?oob@03oookJP0;o`3moooonf[ooo]Z
ool0XOoonf[ooj00o`0goooonf[o00Sooom30?l0l_l00_oonfX01?nDo`3o0?ncoiCo0?oo02/4oiCo
0003ol00oooonf[oo`2S00?ooo]Z00[oo`25oookJ_oonf[ooo]Zo`[o0?ooN`3ooo]ZolGo0?oonf[o
oh`00_oonfX01OoUo`3o0?lToookJ_oonf[o_ol000Cooo]Z00?oo`0koookJ_l0ogX00_oonfX00ooo
0<ko0?oRoookJP03oookJP04o`2<oomn0?oooo]Zool:00Gooo]Z00?oo`3loookJ_ood`000ooonfX0
0ol0oiWooo]ZoookJP06oookJP03oom80?oonf[ooo]Z00Kooo]Z00?o0?mloookJ_oonfX02_oonfX0
0ol00_oooo]ZoookJP05oookJP06oml0ool06_oooo]Zo`0]oooonf[omOl02?oonfX00oooW03ooo]Z
oookJP02oookJP03o`2Ioooonf[ooo]Z00Kooo]Z00?oofH0oookJ_oonfX01?oonfX00ol0o`3ooo]Z
oookJP0VoookJPCo0000:OoonfX4oiCo0?Cooo]Z00Go0?ogoookJ_nco`3o0?ngonl0o`02oookJP06
o`3Uool0on7o0?oQool/0?oonf[o4_l00ooonfX03?l0oOoooo]ZoookJ_oo0:7ooo]ZoonP0?n30?oo
03Ooo`08oooob@3ood<0o`3bo`;ooo]Z00Co0?ncoookJ_l0eOooo`0[0ooonfX01?o00?oooo]Zoook
J_oo0:<2oookJP0:ool0QOoonf[ooo]ZoookJ_l:o`3oog/0oookJ_o5o`3ooo]Zoon<00?ooo]Z00Go
YOl0o`3o9?oonf[ooo]Zokoo0003oookJP07ool0>ooonf[o0?mjo`2Aoooonf[oo`3>o`3ohP05oook
JP03o`2<oomn0?ooo`X000Gooo]Z00Coo`3loookJ_oonf[oom<00_oonfX00ol0oiWooo]ZoookJP07
oookJP03oom80?oonf[ooo]Z00Kooo]Z00?o0?mloookJ_oonfX02OoonfX00ol00_oooo]ZoookJP05
oookJP06oml0ool06_oooo]Zo`0]oooonf[omOl02OoonfX01OooW03ooo]ZoookJ_oonf[o09Wo00Wo
oo]Z00?oofH0oookJ_oonfX01?oonfX00ol0o`3ooo]ZoookJP0UoookJPCo0000:ooonfX00ooo<@3o
oo]ZoookJP39oookJP00;OoonfX01Ol0ooOooo]Zok?o0?l0okOok`3o00;ooo]Z00KoolT0o`3ohOoo
nf[oob`0oa;o0?oob@03oookJP0;o`3moooonf[ooo]Zool0XOoonf[ooj00o`0goooonf[o00Sooom3
0?l0l_l00ooonfX00ol0ok?oU?l0ool0:`04oiCo0003ol00oonDo`3oo`2S00?ooo]Z00[oo`25oook
J_oonf[ooo]Zo`[o0?ooN`3ooo]ZolGo0?oonf[ooh`00_oonfX01OoUo`3o0?lToookJ_oonf[o_ol0
00Cooo]Z00Ooo`0koookJ_l0og[o097ooookJ_oo0<ko0?oR00Cooo]Z00Co08coogh0oooonf[oo`X0
1OoonfX00ooo0?cooo]ZoooC0003oookJP03o`3oVOoonf[ooo]Z00Kooo]Z00?oodP0oookJ_oonfX0
1_oonfX00ol0ogcooo]ZoookJP0:oookJP03o`02oooonf[ooo]Z00Gooo]Z00Kog`3ooookJ_l06_oo
02gooookJ_oeo`09oookJP06oonL0?oonf[ooo]ZoookJ_mK0?oo09Wo1ooonfX00oooIP3oY03ooook
JP05oookJP03o`3o0?oonf[ooo]Z02Kooo]Z1?l0000YoookJPCoU?l0looonfX01Ol0ooOooo]Zok?o
0?l0okOok`3o00;ooo]Z00Ko0>Goo`3ohOoonf[oob`0oookJ_lBo`03oookJP0<o`3moooonf[ooo]Z
ool0XOoonf[ooj00oh<0ool0=ooo00Soooo90?oo@`3o0?;o0_oonfX01?l0ok?ooo]Zo`3Eoooo02/3
oookJP04ol00oooonf[ooo]Zool0X`;ooo]Z00[oo`25oookJ_oonf[ooo]Zo`[o0?ooN`3ooo]ZolGo
0?oonf[ooh`00ooonfX01OnUo`3o0?lToookJ_oonf[o_ol000?ooo]Z00Ooo`0koookJ_l0og[ooo]Z
o`2Aoooo0<ko0?oR00Gooo]Z00?o08coogh0oooo2P001OoonfX01?oo0?cooo]ZoookJ_ood`02oook
JP03o`3oVOoonf[ooo]Z00Oooo]Z00?oodP0oookJ_oonfX01_oonfX00ol0ogcooo]ZoookJP09oook
JP03o`02oooonf[ooo]Z00Gooo]Z00Kog`3ooookJ_l06_oo02gooookJ_oeo`0:oookJP05oonL0?oo
nf[ooo]Zoe/0ool0VOl02?oonfX00oooIP3ooo]ZoookJP04oookJP03o`3o0?oonf[ooo]Z02Kooo]Z
1?l0000[oookJP03oola0?oonf[ooo]Z0<Wooo]Z000/oookJP05o`3omooonf[o/ol0o`3o]oo_0?l0
0_oonfX01_oob@3o0?oQoookJ_oo;03o4_l0ooo900?ooo]Z00_o0?gooookJ_oonf[oo`2QoookJ_oo
X03o03OooookJ_l02?oood<0o`3bo`03oookJP03o`3o/onDo`3oo`0[00CoU?l000?o`03ooookJ_oo
0:<00ooonfX02_oo08Gooo]ZoookJ_oonf[o2_l0oomk0?oonf[oaOl0oookJ_ooS002oookJP05onGo
0?l0obCooo]ZoookJ_noo`001?oonfX01ooo03_ooo]Zo`3oN_l0TOoooo]Zooo90?l0on801?oonfX0
1?l0S?ooOP3ooookJ_oo2P05oookJP04ool0o?oonf[ooo]ZoooC00;ooo]Z00?o0?nIoookJ_oonfX0
1_oonfX00oooB03ooo]ZoookJP07oookJP03o`3oO?oonf[ooo]Z00Wooo]Z00?o00;ooookJ_oonfX0
1OoonfX01_oO0?oooo]Zo`0Jool0;Ooooo]ZooGo00Wooo]Z00?ooi`0oookJ_oonfX00_oonfX00ol0
VOoooo]ZoookJP06oookJP03oomV0?oonf[ooo]Z00Cooo]Z00?o0?l0oookJ_oonfX09ooonfX4o`00
02Wooo]Z1?nDo`3boookJP05o`3omooonf[o/ol0o`3o]oo_0?l00_oonfX01_l0iOoo0?oQoookJ_oo
;03ooo]Zoa;o00?ooo]Z00co0?gooookJ_oonf[oo`2QoookJ_ooX03oP`3oo`0gool02?ooolT0oom3
0?l0l_l2oookJP04o`3o/ooonf[o0=Goool0:`?ooo]Z00Co`03ooookJ_oonf[oo`2S0_oonfX02_oo
08Gooo]ZoookJ_oonf[o2_l0oomk0?oonf[oaOl0oookJ_ooS003oookJP05ojGo0?l0obCooo]Zoook
J_noo`000ooonfX01ooo03_ooo]Zo`3oN_oonf[o097oool0c_l0on801OoonfX00ol0S?ooOP3oool:
0005oookJP04ool0o?oonf[ooo]ZoooC00;ooo]Z00?o0?nIoookJ_oonfX01ooonfX00oooB03ooo]Z
oookJP06oookJP03o`3oO?oonf[ooo]Z00[ooo]Z00?o00;ooookJ_oonfX01?oonfX01_oO0?oooo]Z
o`0Jool0;Ooooo]ZooGo00[ooo]Z00Gooi`0oookJ_oonf[ooo]Zo`2Io`09oookJP03oomV0?oonf[o
oo]Z00Cooo]Z00?o0?l0oookJ_oonfX09_oonfX4o`0002cooo]Z00?ooc40oookJ_oonfX0b?oonfX0
02_ooo]Z00Go0?ogoookJ_nco`3o0?ngonl0o`02oookJP06ooo90?l0on7ooo]Zool/0?lBo`3oolT0
0ooonfX02ol0oOoooo]ZoookJ_oo0:7ooo]ZoonP0?l0=ooooo]Zo`08oooo@`3o0?;o00?ooo]Z00?o
0?ncoiCo0?oo02/01?nDo`000oo00?oooo]Zool0X`03oookJP0:ool0QOoonf[ooo]ZoookJ_l:o`3o
og/0oookJ_o5o`3ooo]Zoon<00;ooo]Z00GoiOl0o`3o9?oonf[ooo]Zokoo0004oookJP04ool0>ooo
nf[o0?mjo`2Ao`;ooo]Z00?oolT0oookJ_oonfX00_oonfX01?l0S?ooOP3ooookJ_oo2P05oookJP04
ool0o?oonf[ooo]ZoooC00;ooo]Z00?o0?nIoookJ_oonfX01_oonfX00oooB03ooo]ZoookJP07oook
JP03o`3oO?oonf[ooo]Z00[ooo]Z00?o00;ooookJ_oonfX01?oonfX01ooO0?ooE_l0o`0Joooonf[o
02gooookJ_oeo`002?oonfX00oooW03ooo]ZoookJP02oookJP03o`2Ioooonf[ooo]Z00Kooo]Z00?o
ofH0oookJ_oonfX01?oonfX00ol0o`3ooo]ZoookJP0XoookJPCo0000:_oonfX2oiCo0?;ooo]Z00Go
0?ogoookJ_nco`3o0?ngonl0o`02oookJP06o`3Uool0on7ooo]Zool/0?oonf[o4_l00ooonfX03?l0
oOoooo]ZoookJ_oo0:7ooo]ZoonP0?n30?oo03Ooo`08oooob@3ood<0o`3bo`;ooo]Z00Co0?ncoook
J_l0eOooo`0[0ooonfX01?o00?oooo]ZoookJ_oo0:<2oookJP0:ool0QOoonf[ooo]ZoookJ_l:o`3o
og/0oookJ_o5o`3ooo]Zoon<00?ooo]Z00GoYOl0o`3o9?oonf[ooo]Zokoo0003oookJP07ool0>ooo
nf[o0?mjoookJ_l0TOoooo]Zool0cP05oookJP03o`2<oomn0?ooo`X000Gooo]Z00Coo`3loookJ_oo
nf[oom<00_oonfX00ol0oiWooo]ZoookJP07oookJP03oom80?oonf[ooo]Z00Kooo]Z00?o0?mloook
J_oonfX02_oonfX00ol00_oooo]ZoookJP04oookJP07oml0oomFo`3o01[ooookJ_l0;Ooooo]ZooGo
0009oookJP06oonL0?oonf[ooo]ZoookJ_mK0?oo09Wo2?oonfX00oooIP3ooo]ZoookJP04oookJP03
o`3o0?oonf[ooo]Z02Oooo]Z1?l0000/oookJP03oola0?oonf[ooo]Z0<Sooo]Z000ZoookJP05o`3o
mooonf[o/ol0o`3o]oo_0?l00_oonfX01_oob@3o0?oQoookJ_oo;03o4_l0ooo900?ooo]Z00_o0?go
oookJ_oonf[oo`2QoookJ_ooX03o03OooookJ_l02?oood<0o`3bo`03oookJP03o`3o/onDo`3oo`0[
00CoU?l000?o`03ooookJ_oo0:<00ooonfX02_oo08Gooo]ZoookJ_oonf[o2_l0oomk0?oonf[oaOl0
oookJ_ooS002oookJP05onGo0?l0obCooo]ZoookJ_noo`001?oonfX01?oo03_ooo]Zo`3oN_l0TOl2
oookJP03ooo90?oonf[ooo]Z00;ooo]Z00Co08coogh0oooonf[oo`X01OoonfX01?oo0?cooo]Zoook
J_ood`02oookJP03o`3oVOoonf[ooo]Z00Oooo]Z00?oodP0oookJ_oonfX01_oonfX00ol0ogcooo]Z
oookJP0:oookJP03o`02oooonf[ooo]Z00Gooo]Z00Kog`3oo`0Joooonf[o02gooookJ_oeo`09oook
JP06oonL0?oonf[ooo]ZoookJ_mK0?oo09Wo1ooonfX00oooIP3oY03ooookJP05oookJP03o`3o0?oo
nf[ooo]Z02Sooo]Z1Ol0000YoookJP;oU?l0lOoonfX01Ol0ooOooo]Zok?o0?l0okOok`3o00;ooo]Z
00Ko0>Goo`3ohOoonf[oob`0oookJ_lBo`03oookJP0<o`3moooonf[ooo]Zool0XOoonf[ooj00oh<0
ool0=ooo00Soooo90?oo@`3o0?;o0_oonfX01?l0ok?ooo]Zo`3Eoooo02/3oookJP04ol00oooonf[o
oo]Zool0X`;ooo]Z00[oo`25oookJ_oonf[ooo]Zo`[o0?ooN`3ooo]ZolGo0?oonf[ooh`00ooonfX0
1OnUo`3o0?lToookJ_oonf[o_ol000?ooo]Z00Ooo`0koookJ_l0og[ooo]Zo`2Aoooonf[oo`3>00Go
oo]Z00?o08coogh0oooo2P001OoonfX01?oo0?cooo]ZoookJ_ood`02oookJP03o`3oVOoonf[ooo]Z
00Sooo]Z00?oodP0oookJ_oonfX01_oonfX00ol0ogcooo]ZoookJP09oookJP03o`02oooonf[ooo]Z
00Gooo]Z00Kog`3oo`0Joooonf[o02gooookJ_oeo`09oookJP06oonL0?oonf[ooo]ZoookJ_mK0?oo
09Wo2?oonfX00oooIP3oY03ooookJP05oookJP03o`3o0?oonf[ooo]Z02Oooo]Z1Ol0000[oookJP03
oola0?oonf[ooo]Z0<Sooo]Z000[oookJP03ok?o0?l0okOok`3o00;ooo]Z00KoolT0o`3ohOoonf[o
ob`0oa;o0?oob@03oookJP0;o`3moooonf[ooo]Zool0XOoonf[ooj00o`0goooonf[o00Sooom30?l0
l_l00ooonfX00ol0ok?o0=Goool0:`03oiCo0004oookJ_o00?oooo]Zool0X`?ooo]Z00[oo`25oook
J_oonf[ooo]Zo`[o0?ooN`3ooo]ZolGo0?oonf[ooh`00_oonfX01OoUo`3o0?lToookJ_oonf[o_ol0
00Cooo]Z00Coo`0koookJ_l0og[o097o0_oonfX00ooob@3ooo]ZoookJP02oookJP04o`2<oomn0?oo
oo]Zool:00Kooo]Z00?oo`3loookJ_ood`000_oonfX00ol0oiWooo]ZoookJP07oookJP03oom80?oo
nf[ooo]Z00Kooo]Z00?o0?mloookJ_oonfX02_oonfX00ol00_oooo]ZoookJP05oookJP06oml0oooo
nf[o01[oo`0]oooonf[omOl02OoonfX00oooW03ooo]ZoookJP02oookJP03o`2Ioooonf[ooo]Z00Ko
oo]Z00?oofH0oookJ_oonfX01?oonfX00ol0o`3ooo]ZoookJP0YoookJPCo0000:_oonfX2oiCo0?;o
oo]Z00?o/ol0o`3o]oo_0?l00_oonfX01_l0iOoo0?oQoookJ_oo;03ooo]Zoa;o00?ooo]Z00Wo0?go
oookJ_oonf[oo`2QoookJ_ooX03oP`3oo`0gool02?l00_oo@`001ol0l_oooo]ZoookJ_l0ok?ooo]Z
o`3Eoooo02/00ooonfX01?o00?oooo]ZoookJ_oo0:<2oookJP0:ool0QOoonf[ooo]ZoookJ_l:o`3o
og/0oookJ_o5o`3ooo]Zoon<00?ooo]Z00GoYOl0o`3o9?oonf[ooo]Zokoo0003oookJP07ool0>ooo
nf[o0?mjoookJ_l0TOoooo]Zool0cP05oookJP03o`2<oomn0?ooo`X000Kooo]Z00?oo`3loookJ_oo
d`000_oonfX00ol0oiWooo]ZoookJP08oookJP03oom80?oonf[ooo]Z00Kooo]Z00?o0?mloookJ_oo
nfX02OoonfX00ol00_oooo]ZoookJP05oookJP06oml0oooonf[o01[oo`0]oooonf[omOl02_oonfX0
1OooW03ooo]ZoookJ_oonf[o09Wo00Sooo]Z00?oofH0oj@0oooonfX01OoonfX00ol0o`3ooo]Zoook
JP0XoookJPCo0000;?oonfX00ooo<@3ooo]ZoookJP38oookJP00:_oonfX00onco`3o0?ngonl0o`02
oookJP06ooo90?l0on7ooo]Zool/0?lBo`3oolT00ooonfX02ol0oOoooo]ZoookJ_oo0:7ooo]ZoonP
0?l0=ooooo]Zo`08oooo@`3o0?;o00?ooo]Z00?o0?nco`3Eoooo02/00onDo`001?oonf[o`03ooook
J_oo0:<3oookJP0:ool0QOoonf[ooo]ZoookJ_l:o`3oog/0oookJ_o5o`3ooo]Zoon<00;ooo]Z00Go
iOl0o`3o9?oonf[ooo]Zokoo0004oookJP04ool0>ooonf[o0?mjo`2Ao`;ooo]Z00?oolT0oookJ_oo
nfX00_oonfX01?l0S?ooOP3ooookJ_oo2P06oookJP03ool0o?oonf[oom<000?ooo]Z00?o0?nIoook
J_oonfX01_oonfX00oooB03ooo]ZoookJP06oookJP03o`3oO?oonf[ooo]Z00[ooo]Z00?o00;ooook
J_oonfX01OoonfX01ooO0?oooo]Zo`0Joooonf[o02gooookJ_oeo`002?oonfX00oooW03ooo]Zoook
JP02oookJP03o`2Ioooonf[ooo]Z00Kooo]Z00?oofH0oookJ_oonfX01OoonfX00ol0o`3ooo]Zoook
JP0YoookJPCo0000:ooonfX00onDo`3ooo]ZoookJP3_oookJP03ok?o0?l0okOok`3o00;ooo]Z00Co
0>Goo`3ohOoonf[oob`00_lBo`03oookJP06o`3moooonf[ooo]Zool0XOoonf[ooj000_l0=ol01?l0
2?oood<0oookJ_l0l_l2oookJP04o`3o/ooonf[o0=Goool0:`?ooo]Z00Co`03ooookJ_oonf[oo`2S
0_oonfX02_oo08Gooo]ZoookJ_oonf[o2_l0oomk0?oonf[oaOl0oookJ_ooS003oookJP05ojGo0?l0
obCooo]ZoookJ_noo`000ooonfX01ooo03_ooo]Zo`3oN_oonf[o097ooookJ_oo0<h01OoonfX00ol0
S?ooOP3oool:0006oookJP04ool0o?oonf[ooo]ZoooC00;ooo]Z00?o0?nIoookJ_oonfX01ooonfX0
0oooB03ooo]ZoookJP06oookJP03o`3oO?oonf[ooo]Z00[ooo]Z00?o00;ooookJ_oonfX01?oonfX0
1ooO0?oooo]Zo`0Joooonf[o02gooookJ_oeo`002OoonfX01_ooW03ooo]ZoookJ_oonf[oF`3oo`2I
o`Sooo]Z00?oofH0oookJ_oonfX01?oonfX00ol0o`3ooo]ZoookJP0YoookJPCo0000;?oonfX00ooo
<@3ooo]ZoookJP38oookJP00:_oonfX02_l0okOok`3ooookJ_oonf[oolT0o`3ohOoonf[oob`0oa;o
0?oob@03oookJP0;o`3moooonf[ooo]Zool0XOoonf[ooj00o`0goooonf[o00Sooom30?l0l_l00ooo
nfX00ol0ok?o0=Goool0:`02oiCo00;ooo]Z00?o`03ooookJ_oo0:<00ooonfX02_oo08Gooo]Zoook
J_oonf[o2_l0oomk0?oonf[oaOl0oookJ_ooS002oookJP05onGo0?l0obCooo]ZoookJ_noo`001?oo
nfX01?oo03_ooo]Zo`3oN_l0TOl2oookJP03ooo90?oonf[ooo]Z00;ooo]Z00Go08coogh0oooonf[o
oo]Zool:0005oookJP03ool0o?oonf[oom<000?ooo]Z00?o0?nIoookJ_oonfX01_oonfX00oooB03o
oo]ZoookJP07oookJP03o`3oO?oonf[ooo]Z00Wooo]Z00?o00;ooookJ_oonfX01OoonfX01ooO0?oo
E_l0o`0Joooonf[o02gooookJ_oeo`002OoonfX01OooW03ooo]ZoookJ_oonf[o09Wo00Sooo]Z00?o
ofH0oj@0oooonfX01OoonfX00ol0o`3ooo]ZoookJP0ZoookJPCo0000:ooonfX00ooo<@3ooo]Zoook
JP3_oookJP0:o`3o]oo_0?oooo]ZoookJ_l0iOoo0?oQoookJ_oo;03o4_l0o`0]o`?ooo]Z00co0?go
oookJ_oonf[oo`2QoookJ_ooX03o03OooookJ_l02?oood<0oookJ_l0l_l2oookJP04o`3o/ooonf[o
0=Goool0:`?ooo]Z00Co`03ooookJ_oonf[oo`2S0_oonfX02_oo08Gooo]ZoookJ_oonf[o2_l0oomk
0?oonf[oaOl0oookJ_ooS003oookJP05ojGo0?l0obCooo]ZoookJ_noo`000ooonfX01ooo03_ooo]Z
o`3oN_oonf[o097ooookJ_oo0<h01OoonfX01?l0S?ooOP3ooookJ_oo2P05oookJP04ool0o?oonf[o
oo]ZoooC00;ooo]Z00?o0?nIoookJ_oonfX01ooonfX00oooB03ooo]ZoookJP06oookJP03o`3oO?oo
nf[ooo]Z00[ooo]Z00?o00;ooookJ_oonfX01?oonfX01ooO0?ooE_l0o`0Joooonf[o02gooookJ_oe
o`002OoonfX01_ooW03ooo]ZoookJ_oonf[oF`3oo`2Io`Sooo]Z00?oofH0oj@0oooonfX01OoonfX0
0ol0o`3ooo]ZoookJP0YoookJPCo0000;?oonfX00ooo<@3ooo]ZoookJP38oookJP00:_oonfX02Oo_
0?oooo]ZoookJ_oob@3o0?oQoookJ_oo;03o4_l0ooo90003oookJP0;o`3moooonf[ooo]Zool0XOoo
nf[ooj00o`0goooonf[o00Sooom30?l0l_l00_oonfX01Ooob@3o0?nco`3Eoooo02_oU?l000?ooo]Z
00?o`03ooookJ_oo0:<00ooonfX02_oo08Gooo]ZoookJ_oonf[o2_l0oomk0?oonf[oaOl0onGo0?oo
S002oookJP05onGo0?l0obCooo]ZoookJ_noo`001?oonfX01?oo03_ooo]Zo`3oN_l0TOl2oookJP03
ooo90?oonf[ooo]Z00?ooo]Z00Co08cooookJ_oonf[oo`X01OoonfX00ooo0?cooo]ZoooC0003oook
JP03o`3oVOoonf[ooo]Z00Kooo]Z00?oodP0oookJ_oonfX01ooonfX00ol0ogcooo]ZoookJP0:oook
JP03o`02oooonf[ooo]Z00Gooo]Z00Kog`3oo`0Joooonf[o02gooookJ_oeo`09oookJP03oonL0?oo
nf[ooo]Z00;ooo]Z00?o09WooookJ_oonfX01_oonfX00oooIP3ooo]ZoookJP04oookJP03o`3o0?oo
nf[ooo]Z02_ooo]Z1?l0000[oookJP03oola0?oonf[ooo]Z0>oooo]Z00Wok`3ooookJ_oonf[o0>Go
o`3ohOoonf[oob`0oa;o0?l0;Ol00ooonfX03?l0oOoooo]ZoookJ_oo0:7ooo]ZoonP0?l0=ooooo]Z
o`08oooo@`3ooo]Zo`3bo`;ooo]Z00Co0?ncoookJ_l0eOooo`0[0ooonfX01?o00?oooo]ZoookJ_oo
0:<2oookJP0:ool0QOoonf[ooo]ZoookJ_l:o`3oog/0oookJ_o5o`3ooo]Zoon<00?ooo]Z00GoYOl0
o`3o9?oonf[ooo]Zokoo0004oookJP06ool0>ol0og[ooo]Zo`2Aoooonf[oo`3>1_oonfX00ol0S?oo
oo]Zool:0005oookJP04ool0o?oonf[ooo]ZoooC00;ooo]Z00?o0?nIoookJ_oonfX01ooonfX00ooo
B03ooo]ZoookJP06oookJP03o`3oO?oonf[ooo]Z00[ooo]Z00?o00;ooookJ_oonfX01OoonfX01_oO
0?oo01[ooookJ_l0;Ooooo]ZooGo00Wooo]Z00?ooi`0oookJ_oonfX00_oonfX00ol0VOoooo]Zoook
JP06oookJP03oomV0?nT0?oooo]Z00Gooo]Z00?o0?l0oookJ_oonfX0:_oonfX4o`0002cooo]Z00?o
oc40oookJ_oonfX0b?oonfX002cooo]Z00KoolT0o`3ohOoonf[oob`0oa;o0?oob@03oookJP0;o`3m
oooonf[ooo]Zool0XOoonf[ooj00o`0goooonf[o00Sooom30?l0l_l00ooonfX01?oob@3o0=Goool0
:onDo`03oookJP03ol00oooonf[oo`2S00?ooo]Z00_oo`25oookJ_oonf[ooo]Zo`[o0?ooN`3ooo]Z
olGo0?oUo`3ooh`0onGo0002oookJP04onGo0?oonf[ooo]Zokoo00Cooo]Z00Coo`0koookJ_oob@3o
097o0_oonfX00ooob@3ooo]ZoookJP03oookJP04o`2<oooonf[ooo]Zool:00Gooo]Z00?oo`3loook
J_ood`000ooonfX00ol0oiWooo]ZoookJP06oookJP03oom80?oonf[ooo]Z00Oooo]Z00?o0?mloook
J_oonfX02_oonfX00ol00_oooo]ZoookJP05oookJP06oml0oooonf[o01[ooookJ_l0;OoomOl02Ooo
nfX00oooW03ooo]ZoookJP02oookJP03o`2Ioooonf[ooo]Z00Kooo]Z00?oofH0oookJ_oonfX01Ooo
nfX00ol0o`3ooo]ZoookJP0[oookJPCo0000;?oonfX00ooo<@3ooo]ZoookJP3`oookJP06o`3Uool0
on7ooo]Zool/0?lBo`3o02go0ooonfX03?l0oOoooo]ZoookJ_oo0:7ooo]ZoonP0?l0=ooooo]Zo`08
oooo@`3ooo]Zo`3bo`;ooo]Z00Co0?ncoookJ_l0eOooo`0[0ooonfX01?o00?oooo]ZoookJ_oo0:<2
oookJP0:ool0QOoonf[ooo]ZoookJ_l:o`3oog/0oookJ_o5o`3ooo]Zoon<00?ooo]Z00GoYOl0o`3o
9?oonf[ooo]Zokoo0004oookJP06ool0>ol0og[ooo]Zo`2Aoooonf[oo`3>1_oonfX00ol0S?oooo]Z
ool:0005oookJP04ool0o?oonf[ooo]ZoooC00;ooo]Z00?o0?nIoookJ_oonfX01ooonfX00oooB03o
oo]ZoookJP07oookJP03o`3oO?oonf[ooo]Z00Wooo]Z00?o00;ooookJ_oonfX01OoonfX01_oO0?oo
oo]Zo`0Joooonf[o02goooGo00[ooo]Z00Kooi`0oookJ_oonf[ooo]Zoe/0ool0VOl8oookJP03oomV
0?oonf[ooo]Z00Gooo]Z00?o0?l0oookJ_oonfX0:_oonfX4o`0002cooo]Z00?ooc40oookJ_oonfX0
b?oonfX002_ooo]Z00KoolT0o`3ohOoonf[oob`0oa;o0?oob@03oookJP04o`3moooonf[ooo]Zool0
X@;ooj0000Go03OooookJ_l02?oood<0o`3bo`03oookJP04ooo90?l0eOooo`0[o`3o]P?ooo]Z00?o
`03ooookJ_oo0:<00ooonfX02_oo08Gooo]ZoookJ_oonf[o2_l0oomk0?oonf[oaOl0oookJ_ooS004
onGo00;ooo]Z00?o_ol0oookJ_oonfX00_oonfX01ooo03_ooo]ZoookJ_oob@3o097ooookJ_oob@00
1OoonfX01?l0S?ooOP3ooookJ_oo2P05oookJP03ool0o?oonf[oom<000?ooo]Z00?o0?nIoookJ_oo
nfX01ooonfX00oooB03ooo]ZoookJP06oookJP03o`3oO?oonf[ooo]Z00[ooo]Z00?o00;ooookJ_oo
nfX01OoonfX01ooO0?oooo]Zo`0Joooonf[o02gooookJ_oeo`002?oonfX00oooW03ooo]ZoookJP02
oookJP03o`2Ioooonf[ooo]Z00Oooo]Z00?oofH0oookJ_oonfX01?oonfX00ol0o`3ooo]ZoookJP0/
oookJPCo0000;?oonfX00ooo<@3ooo]ZoookJP3_oookJP06o`3Uool0on7ooo]Zool/0?lBo`3o02go
0ooonfX01?l0oOoooo]ZoookJ_oo0:42oonP0006o`0goooonf[o00Sooom30?oonf[o0?;o0_oonfX0
1?l0ok?ooo]Zo`3Eoooo02/3oookJP04ol00oooonf[ooo]Zool0X`;ooo]Z00[oo`25oookJ_oonf[o
oo]Zo`[o0?ooN`3ooo]ZolGo0?oonf[ooh`00ooonfX01OnUo`3o0?lToookJ_oonf[o_ol000Cooo]Z
00Koo`0koookJ_l0og[o097ooookJ_oo0<h6oookJP03o`2<oomn0?ooo`X000Gooo]Z00Coo`3loook
J_oonf[oom<00_oonfX00ol0oiWooo]ZoookJP07oookJP03oom80?oonf[ooo]Z00Oooo]Z00?o0?ml
oookJ_oonfX02_oonfX00ol00_oooo]ZoookJP04oookJP07oml0oooonf[o01[ooookJ_l0;Ooooo]Z
ooGo0009oookJP06oonL0?oonf[ooo]ZoookJ_mK0?oo09Wo2?oonfX00oooIP3oY03ooookJP05oook
JP03o`3o0?oonf[ooo]Z02_ooo]Z1?l0000/oookJP03oola0?oonf[ooo]Z0<Sooo]Z000ZoookJP06
ooo90?l0on7ooo]Zool/0?lBo`3oolT00ooonfX02ol0oOoooo]ZoookJ_oo0:7ooj00oookJ_l0=ooo
oo]Zo`08oooo@`3o0?;o00?ooo]Z00CoolT0o`3Eoooo02_o0?nf0ooonfX00oo00?oooo]Zool0X`03
oookJP0:ool0QOoonf[ooo]ZoookJ_l:o`3oog/0oookJ_o5o`3ooo]Zoon<00GoiOl000?ooo]Zokoo
0?oonfX00ooonfX02?oo03_ooo]ZoookJ_oob@3o097ooookJ_oob@3o0?oR1?oonfX01?l0S?ooOP3o
oookJ_oo2P05oookJP03ool0o?oonf[oom<000?ooo]Z00?o0?nIoookJ_oonfX01ooonfX00oooB03o
oo]ZoookJP07oookJP03o`3oO?oonf[ooo]Z00Wooo]Z00?o00;ooookJ_oonfX01OoonfX01ooO0?oo
E_l0o`0Joooonf[o02gooookJ_oeo`002OoonfX00oooW03ooo]ZoookJP02oookJP03o`2Ioooonf[o
oo]Z00Kooo]Z00?oofH0oookJ_oonfX01?oonfX00ol0o`3ooo]ZoookJP0]oookJPCo0000;?oonfX0
0ooo<@3ooo]ZoookJP3^oookJP06o`3Uool0on7ooo]Zool/0?lBo`3o02go0ooonfX03?l0oOoooo]Z
oookJ_oo0:7ooj00oookJ_l0=ooooo]Zo`08oooo@`3ooo]Zo`3bo`;ooo]Z00Co0?ncoookJ_l0eOoo
o`0[0ooonfX01?o00?oooo]ZoookJ_oo0:<2oookJP0:ool0QOoonf[ooo]ZoookJ_l:o`3oog/0oook
J_o5o`3ooo]Zoon<00?ooo]Z00GoYOl0o`3o9?oonf[ooo]Zokoo0004oookJP07ool0>ooonf[o0?mj
o`2Aoooonf[oo`3>o`3ohP05oookJP03o`2<oomn0?ooo`X000Gooo]Z00Coo`3loookJ_oonf[oom<0
0_oonfX00ol0oiWooo]ZoookJP07oookJP03oom80?oonf[ooo]Z00Oooo]Z00?o0?mloookJ_oonfX0
2_oonfX00ol00_oooo]ZoookJP04oookJP07oml0oomFo`3o01[ooookJ_l0;Ooooo]ZooGo0009oook
JP03oonL0?oonf[ooo]Z00;ooo]Z00?o09WooookJ_oonfX01_oonfX00oooIP3oY03ooookJP05oook
JP03o`3o0?oonf[ooo]Z02cooo]Z1?l0000/oookJP03oola0?oonf[ooo]Z0<Sooo]Z000ZoookJP05
o`3ohOoonf[oob`0oa;o0?oob@000ooonfX02ol0oOoooo]ZoookJ_oo0:7ooj00oookJ_l0=ooooo]Z
o`08oooo@`3o0?;o00?ooo]Z00CoolT0o`3Eoooo02_o0?nf0ooonfX00oo00?oooo]Zool0X`03oook
JP0:ool0QOoonf[ooo]ZoookJ_l:o`3oog/0oookJ_o5o`3ooo]Zoon<00OoiOl01?oonfX02?oo03_o
oo]ZoookJ_oob@3o097ooookJ_oob@3o0?oR1?oonfX01?l0S?ooOP3ooookJ_oo2P05oookJP03ool0
o?oonf[oom<000?ooo]Z00?o0?nIoookJ_oonfX01ooonfX00oooB03ooo]ZoookJP07oookJP03o`3o
O?oonf[ooo]Z00Wooo]Z00?o00;ooookJ_oonfX01_oonfX01_oO0?oo01[ooookJ_l0;Ooooo]ZooGo
00Wooo]Z00?ooi`0oookJ_oonfX00_oonfX00ol0VOoooo]ZoookJP06oookJP03oomV0?oonf[ooo]Z
00Gooo]Z00?o0?l0oookJ_oonfX0;OoonfX4o`0002cooo]Z00?ooc40oookJ_oonfX0k_oonfX01Ol0
on7ooo]Zool/0?lBo`3o02go00?ooo]Z00co0?gooookJ_oonf[oo`2QoonP0?oonf[o03OooookJ_l0
2?oood<0oookJ_l0l_l2oookJP04o`3o/ol0eOoo0=Goool0:`?ooo]Z00Co`03ooookJ_oonf[oo`2S
0_oonfX02_oo08Gooo]ZoookJ_oonf[o2_l0oomk0?oonf[oaOl0oookJ_ooS003oookJP05ojGo0?l0
obCooo]ZoookJ_noo`001?oonfX01ooo03_ooo]Zo`3oN_l0TOoooo]Zool0c_l0on801OoonfX00ol0
S?ooOP3oool:0005oookJP04ool0o?oonf[ooo]ZoooC00;ooo]Z00?o0?nIoookJ_oonfX02?oonfX0
0oooB03ooo]ZoookJP06oookJP03o`3oO?oonf[ooo]Z00[ooo]Z00?o00;ooookJ_oonfX01OoonfX0
1_oO0?oo01[ooookJ_l0;Ooooo]ZooGo00[ooo]Z00Kooi`0oookJ_oonf[ooo]Zoe/0ool0VOl7oook
JP03oomV0?nT0?oooo]Z00Kooo]Z00?o0?l0oookJ_oonfX0;?oonfX4o`0002gooo]Z00?ooc40oook
J_oonfX0aooonfX002_ooo]Z00?oob`0oa;o0?oob@000ooonfX02ol0oOoooo]ZoookJ_oo0:7ooj00
oookJ_l0=ooooo]Zo`08oooo@`3o0?;o00?ooo]Z00CoolT0o`3Eoooo02_o0?nf0ooonfX00oo00?oo
oo]Zool0X`03oookJP0:ool0QOoonf[ooo]ZoookJ_l:o`3oog/0oookJ_o5o`3ooo]Zoon<00WoiOl0
0_oonfX02?oo03_ooo]ZoookJ_oob@3o097ooookJ_oob@3o0?oR1?oonfX01?l0S?ooOP3ooookJ_oo
2P05oookJP04ool0o?oonf[ooo]ZoooC00;ooo]Z00?o0?nIoookJ_oonfX01ooonfX00oooB03ooo]Z
oookJP07oookJP03o`3oO?oonf[ooo]Z00[ooo]Z00?o00;ooookJ_oonfX01OoonfX01_oO0?oooo]Z
o`0Joooonf[o02goooGo00Wooo]Z00?ooi`0oookJ_oonfX00_oonfX00ol0VOoooo]ZoookJP07oook
JP03oomV0?oonf[ooo]Z00Cooo]Z00?o0?l0oookJ_oonfX0;_oonfX4o`0002cooo]Z00?ooc40oook
J_oonfX0kooonfX00ooo;03o4_l0o`0]o`03oookJP0<o`3moooonf[ooo]Zool0XOooX03ooo]Zo`0g
oooonf[o00Sooom30?oonf[o0?;o0_oonfX01?l0ok?o0=GooookJ_oo02/3oookJP04ol00oooonf[o
oo]Zool0X`;ooo]Z00[oo`25oookJ_oonf[ooo]Zo`[o0?ooN`3ooo]ZolGo0?oonf[ooh`00ooonfX0
0onUo`3o0?lToookJP02oookJP0;okoo0?oonf[ooo]ZoookJ_oo03_ooo]Zo`3oN_l0TOoooo]Zool0
c_l0on801OoonfX00ol0S?ooOP3oool:0006oookJP06ool0o?oonf[ooo]ZoooC0?oonf[o0?nI2_oo
nfX00oooB03ooo]ZoookJP06oookJP03o`3oO?oonf[ooo]Z00[ooo]Z00?o00;ooookJ_oonfX01Ooo
nfX01_oO0?oooo]Zo`0Joooonf[o02goooGo00[ooo]Z00Kooi`0oookJ_oonf[ooo]Zoe/0ool0VOl8
oookJP03oomV0?nT0?oooo]Z00Gooo]Z00?o0?l0oookJ_oonfX0;OoonfX4o`0002gooo]Z00?ooc40
oookJ_oonfX0aooonfX002[ooo]Z00?oob`0oa;o0?oob@000ooonfX02ol0oOoooo]ZoookJ_oo0:7o
oj00oookJ_l0=ooooo]Zo`08oooo@`3o0?;o00?ooo]Z00CoolT0o`3Eoooo02_o0?nf0ooonfX00oo0
0?oooo]Zool0X`03oookJP0:ool0QOoonf[ooo]ZoookJ_l:o`3oog/0oookJ_o5o`3ooo]Zoon<00So
iOl00ooonfX02?oo03_oolT0oookJ_oob@3o097ooookJ_oob@3o0?oR1?oonfX01?l0S?ooOP3ooook
J_oo2P05oookJP04ool0o?oonf[ooo]ZoooC00;ooo]Z00?o0?nIoookJ_oonfX01ooonfX00oooB03o
oo]ZoookJP07oookJP03o`3oO?oonf[ooo]Z00[ooo]Z00?o00;ooookJ_oonfX01OoonfX01ooO0?oo
oo]Zo`0Joooonf[o02gooookJ_oeo`002OoonfX01_ooW03ooo]ZoookJ_oonf[oF`3oo`2Io`Sooo]Z
00?oofH0oookJ_oonfX01OoonfX00ol0o`3ooo]ZoookJP0^oookJPCo0000;OoonfX00ooo<@3ooo]Z
oookJP3]oookJP03ool/0?lBo`3o02go00?ooo]Z00co0?gooookJ_oonf[oo`2QoonP0?oonf[o03Oo
oookJ_l02?oood<0oookJ_l0l_l2oookJP04o`3o/ol0eOoooo]Zool0:`?ooo]Z00Co`03ooookJ_oo
nf[oo`2S0_oonfX02_oo08Gooo]ZoookJ_oonf[o2_l0oomk0?oonf[oaOl0oookJ_ooS003oookJP03
ojGo0?l0obCooo]Z00;ooo]Z00_o_ol0oookJ_oonf[ooo]Zool0>ooonf[o0?mjoookJ_l0TOooo`3>
o`3ohP05oookJP03o`2<oomn0?ooo`X000Kooo]Z00Coo`3loookJ_oonf[oom<00_oonfX00ol0oiWo
oo]ZoookJP07oookJP03oom80?oonf[ooo]Z00Kooo]Z00?o0?mloookJ_oonfX02ooonfX00ol00_oo
oo]ZoookJP04oookJP07oml0oooonf[o01[ooookJ_l0;Ooooo]ZooGo0009oookJP07oonL0?oonf[o
oo]ZoookJ_mK0?oooo]Zo`2Io`07oookJP03oomV0?nT0?oooo]Z00Gooo]Z00?o0?l0oookJ_oonfX0
;_oonfX4o`0002gooo]Z00?ooc40oookJ_oonfX0aooonfX002[ooo]Z00?o4_l0ooo90?oonfX00_oo
nfX02ol0oOoooo]ZoookJ_oo0:7ooj00oookJ_l0=ooooo]Zo`08oooo@`3o0?;o00?ooo]Z00CoolT0
o`3Eoooo02_o0?nf0ooonfX00oo00?oooo]Zool0X`03oookJP0;ool0QOoonf[ooo]ZoookJ_l:o`3o
og/0oookJ_o5o`3ooo]Zoon<0?oonfX01ooUo`03oookJP08ool0>ooonf[oolT0ooo90?l0TOoooo]Z
ooo90?l0on84oookJP04o`2<oomn0?oooo]Zool:00Gooo]Z00Coo`3loookJ_oonf[oom<00_oonfX0
0ol0oiWooo]ZoookJP07oookJP03oom80?oonf[ooo]Z00Oooo]Z00?o0?mloookJ_oonfX02_oonfX0
0ol00_oooo]ZoookJP05oookJP07oml0oomFo`3o01[ooookJ_l0;Ooooo]ZooGo0009oookJP03oonL
0?oonf[ooo]Z00;ooo]Z00?o09WooookJ_oonfX01_oonfX00ooUo`3ooo]ZoookJP05oookJP03o`3o
0?oonf[ooo]Z02oooo]Z1?l0000]oookJP03oola0?oonf[ooo]Z0>gooo]Z00?o4_l0o`0]oooonfX0
0_oonfX03?l0oOoooo]ZoookJ_oo0:7ooj00oookJ_l0=ooooo]Zo`08oooo@`3ooo]Zo`3bo`;ooo]Z
00Co0?nco`3Eoooonf[oo`0[1?oonfX00oo00?oooo]Zool0X`02oookJP0:ool0QOoonf[ooo]Zoook
J_l:o`3oog/0oookJ_o5o`3ooo]Zoon<00?ooo]Z00?oYOl0o`3o9?oonfX00_oonfX02onoo`3ooo]Z
oookJ_oonf[oo`0koookJ_l0og[ooo]Zo`2Aoooo0<ko0?oR00Gooo]Z00?o08coogh0oooo2P001_oo
nfX01?oo0?cooo]ZoookJ_ood`02oookJP03o`3oVOoonf[ooo]Z00Oooo]Z00?oodP0oookJ_oonfX0
1ooonfX00ol0ogcooo]ZoookJP0:oookJP03o`02oooonf[ooo]Z00Cooo]Z00Oog`3ooeKo0?l06_oo
oo]Zo`0]oooonf[omOl000Wooo]Z00?ooi`0oookJ_oonfX00_oonfX00omK0?oo09WooookJP06oook
JP03oomV0?nT0?oooo]Z00Kooo]Z00?o0?l0oookJ_oonfX0;_oonfX4o`0002gooo]Z00?ooc40oook
J_oonfX0aooonfX002[ooo]Z00GoolT0oookJ_oonf[ooo]Zo`3mo`02oookJP08ool0XOooX03ooo]Z
o`0goooonf[o00Sooom30?l0l_l3oookJP04ooo90?l0eOooo`0[o`3o]P?ooo]Z00?o`03ooookJ_oo
0:<00ooonfX02ooo08Gooo]ZoookJ_oonf[o2_l0oomk0?oonf[oaOl0oookJ_ooS03ooo]Z00KoiOl0
00Ko_ol0oookJ_oonf[ooo]Zool0>ooonfX4ooo90003oookJ_oob@3ooo]Z00?ooo]Z00Co08coogh0
oooonf[oo`X01OoonfX01?oo0?cooo]ZoookJ_ood`02oookJP03o`3oVOoonf[ooo]Z00Sooo]Z00?o
odP0oookJ_oonfX01ooonfX00ol0ogcooo]ZoookJP09oookJP03o`02oooonf[ooo]Z00Gooo]Z00?o
g`3ooeKo0?l06_l00_oonfX00ol0;OoomOl0oookJP08oookJP03oonL0?oonf[ooo]Z00;ooo]Z00?o
09WooookJ_oonfX01ooonfX00ooUo`3ooo]ZoookJP04oookJP03o`3o0?oonf[ooo]Z033ooo]Z1?l0
000]oookJP03oola0?oonf[ooo]Z0>gooo]Z00Go02gooookJ_oonf[ooo]Zo`3mo`02oookJP09ool0
XOooX03ooo]Zo`0goooonf[o00Sooom30?oonf[o0?;o00;ooo]Z00Co0?nco`3Eoooonf[oo`0[1?oo
nfX00oo00?oooo]Zool0X`02oookJP0:ool0QOoonf[ooo]ZoookJ_l:o`3oog/0oookJ_o5o`3ooo]Z
oon<00?ooo]Z00?oYOl0o`3o9?oonfX00_oonfX02onoo`3ooo]ZoookJ_oonf[oo`0koookJ_l0og[o
oo]Zo`2Aoooonf[oo`3>00Gooo]Z00?o08coogh0oooo2P001_oonfX01?oo0?cooo]ZoookJ_ood`02
oookJP03o`3oVOoonf[ooo]Z00Oooo]Z00?oodP0oookJ_oonfX01ooonfX00ol0ogcooo]ZoookJP0:
oookJP03o`02oooonf[ooo]Z00Cooo]Z00?og`3ooeKo0?l06_l00_oonfX00ol0;OoomOl0oookJP09
oookJP06oonL0?oonf[ooo]ZoookJ_mK0?oo09Wo2?oonfX00oooIP3oY03ooookJP05oookJP03o`3o
0?oonf[ooo]Z02oooo]Z1?l0000]oookJP03oola0?oonf[ooo]Z0<Oooo]Z000ZoookJP;oolT000co
oo]Zo`3moooonf[ooo]Zool0XOooX03ooo]Zo`0goooonf[o00Sooom30?l0l_l3oookJP04ooo90?l0
eOooo`0[o`3o]P?ooo]Z00?o`03ooookJ_oo0:<00ooonfX02_oo08Gooo]ZoookJ_oonf[o2_l0oomk
0?oonf[oaOl0oookJ_ooS002oookJPCoiOl000?ooo]Zokoo0?oonfX00_oonfX00ooo03_ooo]Zoook
JP05ooo900Gooo]Z00?o08cooookJ_oo2P001_oonfX00ooo0?cooo]ZoooC0002oookJP03o`3oVOoo
nf[ooo]Z00Sooo]Z00?oodP0oookJ_oonfX01ooonfX00ol0ogcooo]ZoookJP09oookJP03o`02oooo
nf[ooo]Z00Kooo]Z00Kog`3oo`0Joooonf[ooo]Zo`0]oooeo`0:oookJP06oonL0?oonf[ooo]Zoook
J_mK0?oo09Wo2?oonfX00ooUo`3ooo]ZoookJP05oookJP03o`3o0?oonf[ooo]Z033ooo]Z1?l0000]
oookJP03oola0?oonf[ooo]Z0?3ooo]Z00co0?gooookJ_oonf[oo`2QoonP0?oonf[o03OooookJ_l0
2?oood<0oookJ_l0l_l2oookJP04o`3o/ol0eOoooo]Zool0:`Cooo]Z00?o`03ooookJ_oo0:<00_oo
nfX02_oo08Gooo]ZoookJ_oonf[o2_l0oomk0?oonf[oaOl0oookJ_ooS003oookJP03ojGo0?l0obCo
oo]Z00;ooo]Z00_o_ol0oookJ_oonf[ooo]Zool0>ooonf[o0?mjoookJ_l0TOoooo]Zool0cP05oook
JP03o`2<oomn0?ooo`X000Kooo]Z00Coo`3loookJ_oonf[oom<00_oonfX00ol0oiWooo]ZoookJP07
oookJP03oom80?oonf[ooo]Z00Oooo]Z00?o0?mloookJ_oonfX02_oonfX00ol00_oooo]ZoookJP05
oookJP06oml0ool06_oooo]ZoookJ_l0;OoomOl02_oonfX01oooW03ooo]ZoookJ_oonf[oF`3ooook
J_l0VOl01ooonfX00oooIP3oY03ooookJP05oookJP03o`3o0?oonf[ooo]Z033ooo]Z1?l0000]oook
JP03oola0?oonf[ooo]Z0<Oooo]Z000ZoookJP;oolT000_o0?gooookJ_oonf[oo`2QoonP0?oonf[o
03OooookJ_l02?oood<0o`3bo`03oookJP04ooo90?l0eOooo`0[o`3o]P?ooo]Z00?o`03ooookJ_oo
0:<00ooonfX00ooo08Gooo]ZoookJP02o`[o0005oomk0?oonf[oaOl0oookJ_ooS0000_oonfX4onGo
0003oookJ_noo`3ooo]Z00;ooo]Z00?oo`0koookJ_oonfX01ooob@03oookJP04o`2<oooonf[ooo]Z
ool:00Gooo]Z00?oo`3loookJ_ood`000ooonfX00ol0oiWooo]ZoookJP07oookJP03oom80?oonf[o
oo]Z00Oooo]Z00?o0?mloookJ_oonfX02_oonfX00ol00_oooo]ZoookJP05oookJP06oml0oooonf[o
01[ooookJ_l0;OoomOl02_oonfX00oooW03ooo]ZoookJP02oookJP03o`2Ioooonf[ooo]Z00Kooo]Z
00?oiOl0oookJ_oonfX01OoonfX00ol0o`3ooo]ZoookJP0aoookJPCo0000;OoonfX00ooo<@3ooo]Z
oookJP3_oookJP0<o`3moooonf[ooo]Zool0XOooX03ooo]Zo`0goooonf[o00Sooom30?oonf[o0?;o
0_oonfX01?l0ok?o0=GooookJ_oo02/4oookJP03ol00oooonf[oo`2S00;ooo]Z00[oo`25oookJ_oo
nf[ooo]Zo`[o0?ooN`3ooo]ZolGo0?oonf[ooh`00ooonfX00onUo`3o0?lToookJP02oookJP0;okoo
0?oonf[ooo]ZoookJ_oo03_ooo]Zo`3oN_oonf[o097ooookJ_oo0<h01OoonfX01?l0S?ooOP3ooook
J_oo2P05oookJP04ool0o?oonf[ooo]ZoooC00;ooo]Z00?o0?nIoookJ_oonfX01ooonfX00oooB03o
oo]ZoookJP07oookJP03o`3oO?oonf[ooo]Z00_ooo]Z00?o00;ooookJ_oonfX01?oonfX01ooO0?oo
oo]Zo`0Joooonf[o02gooookJ_oeo`002OoonfX00oooW03ooo]ZoookJP02oookJP03oe/0ool0VOoo
oo]Z00Kooo]Z00?oofH0oj@0oooonfX01_oonfX00ol0o`3ooo]ZoookJP0`oookJPCo0000;OoonfX0
0ooo<@3ooo]ZoookJP37oookJP00:_oonfX03?oob@3o0?goooo90?oob@3oo`2QoonP0?oonf[o03Oo
oookJ_l02?oood<0o`3bo`?ooo]Z00CoolT0o`3Eoooo02_o0?nf0ooonfX00oo00?oooo]Zool0X`03
oookJP0:ool0QOoonf[ooo]Zo`[o0?oonf[oog/0oookJ_o5o`3ooo]Zoon<00;ooo]Z0ooUo`02oook
JP05okoo0?oonf[ooo]ZoookJ_oo03/00_oonfX9ooo90005oookJ_l0S?ooOP3ooookJ_oo2P001Ooo
nfX00ooo0?cooo]ZoooC0003oookJP03o`3oVOoonf[ooo]Z00Oooo]Z00?oodP0oookJ_oonfX01ooo
nfX00ol0ogcooo]ZoookJP0:oookJP03o`02oooonf[ooo]Z00Gooo]Z00Oog`3ooookJ_l06_oooo]Z
o`0]oooonf[omOl000Wooo]Z00?oiOl0oookJ_oonfX00_oonfX00ol0VOoooo]ZoookJP07oookJP03
onGo0?oonf[ooo]Z00Gooo]Z00?o0?l0oookJ_oonfX0<OoonfX4o`0002gooo]Z00?ooc40oookJ_oo
nfX0k_oonfX03?l0oOoooo]ZoookJ_oo0:7ooj00oookJ_l0=ooooo]Zo`08oooo@`3ooo]Zo`3bo`;o
oo]Z00Co0?nco`3Eoooonf[oo`0[1?oonfX00oo00?oooo]Zool0X`02oookJP0:ool0QOoonf[ooo]Z
oookJ_l:o`3oog/0oookJ_o5o`3ooo]Zoon<00?ooo]Z00?oYOl0o`3o9?oonfX00_oonfX02onoo`3o
oo]ZoookJ_oonf[oo`0koookJ_l0og[ooo]Zo`2Aoooonf[oo`3>00Gooo]Z00Co08coogh0oooonf[o
o`X01OoonfX01?oo0?cooo]ZoookJ_ood`02oookJP03o`3oVOoonf[ooo]Z00Sooo]Z00?oodP0oook
J_oonfX01_oonfX00ol0ogcooo]ZoookJP0;oookJP03o`02oooonf[ooo]Z00Cooo]Z00Oog`3ooook
J_l06_oooo]Zo`0]oooonf[omOl000Wooo]Z00?ooi`0oookJ_oonfX00_oonfX00omK0?oo09Wooook
JP07oookJP03oomV0?nT0?oooo]Z00Gooo]Z00?o0?l0oookJ_oonfX0<OoonfX4o`0002gooo]Z00?o
oc40oookJ_oonfX0aooonfX002[ooo]Z00_o0?goooo90?oonf[oo`2QoonP0?oonf[o03OooookJ_l0
2?oood<0o`3bo`03oookJP04ooo90?l0eOooo`0[o`3o]P?ooo]Z00?o`03ooookJ_oo0:<00ooonfX0
2_oo08Gooo]ZoookJ_l:o`3ooo]Zooo90?oonf[oaOl0oookJ_ooS003oookJP05onGo0?oonf[ooo]Z
oookJ_noo`001?oonfX00ooo03_ooo]Zooo90007ooo900;ooo]Z00Co08coogh0oooonf[oo`X01Ooo
nfX00ooo0?cooo]ZoooC0003oookJP03o`3oVOoonf[ooo]Z00Oooo]Z00?oodP0oookJ_oonfX02?oo
nfX00ol0ogcooo]ZoookJP09oookJP03o`02oooonf[ooo]Z00Gooo]Z00Oog`3ooeKo0?l06_oooo]Z
o`0]oooonf[omOl000[ooo]Z00KoiOl0oookJ_oonf[ooo]Zoe/0ool0VOl3oookJP;oiOl00ooonfX0
0ooUo`3ooo]ZoookJP05oookJP03o`3o0?oonf[ooo]Z03;ooo]Z1?l0000]oookJP03oola0?oonf[o
oo]Z0>gooo]Z00co0?gooookJ_oonf[oo`2QoonP0?oonf[o03OooookJ_l02?oood<0oookJ_l0l_l2
oookJP04o`3o/ol0eOoooo]Zool0:`Cooo]Z00?o`03ooookJ_oo0:<00_oonfX02_oo08Gooo]Zoook
J_oonf[o2_l0oomk0?oonf[oaOl0oookJ_ooS003oookJP03ojGo0?l0obCooo]Z00;ooo]Z00_o_ol0
oookJ_oonf[ooo]Zool0>ooonf[o0?mjoookJ_l0TOoooo]Zool0cP05oookJP04o`2<oomn0?oooo]Z
ool:00Gooo]Z00Coo`3loookJ_oonf[oom<00_oonfX00ol0oiWooo]ZoookJP08oookJP03oom80?oo
nf[ooo]Z00Oooo]Z00?o0?mloookJ_oonfX02_oonfX00ol00_oooo]ZoookJP04oookJP07oml0oomF
o`3o01[ooookJ_l0;Ooooo]ZooGo000:oookJP06oonL0?oonf[ooo]ZoookJ_mK0?oo09Wo2?oonfX0
0oooIP3oY03ooookJP05oookJP03o`3o0?oonf[ooo]Z03;ooo]Z1?l0000]oookJP03oola0?oonf[o
oo]Z0<Oooo]Z000/oookJP08ool0XOooX03ooo]Zo`0goooonf[o00Sooom30?l0l_l3oookJP04ooo9
0?l0eOooo`0[o`3o]P?ooo]Z00?o`03ooookJ_oo0:<00ooonfX02_oo08Gooo]ZoookJ_l:o`3ooo]Z
ooo90?oonf[oaOl0oookJ_ooS003oookJP05onGo0?oonf[ooo]ZoookJ_noo`001?oonfX00ooo03_o
oo]Zooo90007ooo900;ooo]Z00Co08coogh0oooonf[oo`X01OoonfX01?oo0?cooo]ZoookJ_ood`02
oookJP03o`3oVOoonf[ooo]Z00Sooo]Z00?oodP0oookJ_oonfX01ooonfX00ol0ogcooo]ZoookJP09
oookJP03o`02oooonf[ooo]Z00Kooo]Z00Kog`3oo`0Joooonf[ooo]Zo`0]oooeo`0:oookJP03onGo
0?oonf[ooo]Z00;ooo]Z00?o09WooookJ_oonfX00_oonfX3onGo0003oookJ_oUo`3ooo]Z00Kooo]Z
00?o0?l0oookJ_oonfX0<ooonfX4o`0002gooo]Z00?ooc40oookJ_oonfX0kooonfX02Ooo0:7ooj00
oookJ_l0=ooooo]Zo`08oooo@`3ooo]Zo`3bo`02oookJP04o`3o/ol0eOoooo]Zool0:`Cooo]Z00?o
`03ooookJ_oo0:<00_oonfX02_oo08Gooo]ZoookJ_oonf[o2_l0oookJ_ooN`3oaOl0oookJ_ooS003
oookJP03ojGo0?l0obCooo]Z00;ooo]Z00_o_ol0oookJ_oonf[ooo]Zool0>ooonf[o0?mjoookJ_l0
TOoooo]Zool0cP06oookJP03o`2<oooonf[oo`X000Kooo]Z00?oo`3loookJ_ood`000_oonfX00ol0
oiWooo]ZoookJP08oookJP03oom80?oonf[ooo]Z00Oooo]Z00?o0?mloookJ_oonfX02_oonfX00ol0
0_oooo]ZoookJP05oookJP06oml0ool06_oooo]ZoookJ_l0;OoomOl02_oonfX00oooW03ooo]Zoook
JP02oookJP03oe/0ool0VOoooo]Z00Kooo]Z00?oofH0oj@0oooonfX01_oonfX00ol0o`3ooo]Zoook
JP0boookJPCo0000;OoonfX00ooo<@3ooo]ZoookJP37oookJP00:ooonfX02?oo0:7ooj00oookJ_l0
=ooooo]Zo`08oooo@`3o0?;o0ooonfX01?oob@3o0=Goool0:ol0okH3oookJP03ol00oooonf[oo`2S
00?ooo]Z00[oo`25oookJ_oonf[o2_l0oookJ_oob@3ooo]ZolGo0?oonf[ooh`00ooonfX01OnUo`3o
oo]ZoookJ_oonf[o_ol000Cooo]Z00Coo`0koookJ_oob@3ooo]Z1Ooob@03oookJP04o`2<oomn0?oo
oo]Zool:00Gooo]Z00Coo`3loookJ_oonf[oom<00_oonfX00ol0oiWooo]ZoookJP08oookJP03oom8
0?oonf[ooo]Z00Oooo]Z00?o0?mloookJ_oonfX02_oonfX00ol00_oooo]ZoookJP05oookJP06oml0
oooonf[o01[ooookJ_l0;OoomOl02_oonfX00ooUo`3ooo]ZoookJP02oookJP03o`2Ioooonf[ooo]Z
00;ooo]Z1_oUo`07oookJP03o`3o0?oonf[ooo]Z03?ooo]Z1Ol0000]oookJP03oola0?oonf[ooo]Z
0>gooo]Z00Woo`2QoonP0?oonf[o03OooookJ_l02?oood<0oookJ_l0l_l00_oonfX01?l0ok?o0=Go
oookJ_oo02/4oookJP03ol00oooonf[oo`2S00;ooo]Z00[oo`25oookJ_oonf[ooo]Zo`[o0?oonf[o
og/0olGo0?oonf[ooh`01?oonfX01OnUo`3ooo]ZoookJ_oonf[o_ol000?ooo]Z00Ooo`0koookJ_l0
og[ooo]Zo`2Aoooonf[oo`3>00Kooo]Z00?o08cooookJ_oo2P001_oonfX00ooo0?cooo]ZoooC0003
oookJP03o`3oVOoonf[ooo]Z00Oooo]Z00?oodP0oookJ_oonfX01ooonfX00ol0ogcooo]ZoookJP0:
oookJP03o`02oooonf[ooo]Z00Gooo]Z00Oog`3ooookJ_l06_oooo]Zo`0]oooonf[omOl000Wooo]Z
00?ooi`0oookJ_oonfX00_oonfX00omK0?oo09WooookJP07oookJP03oomV0?nT0?oooo]Z00Gooo]Z
00?o0?l0oookJ_oonfX0<ooonfX5o`0002gooo]Z00?ooc40oookJ_oonfX0a_oonfX002[ooo]Z00So
o`2QoonP0?oonf[o03OooookJ_l02?oood<0o`3bo`?ooo]Z00CoolT0o`3Eoooo02_o0?nf0ooonfX0
1?o00?oooo]ZoookJ_oo0:<2oookJP0:ool0QOoonf[ooo]Zo`[o0?oonf[oolT0oookJ_o5o`3ooo]Z
oon<00?ooo]Z00KoYOl0oookJ_oonf[ooo]Zokoo0?oonfX2ooo90005oookJ_oo03_ooo]Zooo90?oo
nfX01Ooob@03oookJP04o`2<oomn0?oooo]Zool:00Gooo]Z00Coo`3loookJ_oonf[oom<00_oonfX0
0ol0oiWooo]ZoookJP08oookJP03oom80?oonf[ooo]Z00Oooo]Z00?o0?mloookJ_oonfX02_oonfX0
0ol00_oooo]ZoookJP05oookJP06oml0oooonf[o01[ooookJ_l0;OoomOl02_oonfX00ooUo`3ooo]Z
oookJP02oookJP03o`2Ioooonf[ooo]Z00?ooo]Z1ooUo`05oookJP03o`3o0?oonf[ooo]Z03Cooo]Z
1?l0000^oookJP03oola0?oonf[ooo]Z0>cooo]Z00Woo`2QoonP0?oonf[o03OooookJ_l02?oood<0
oookJ_l0l_l00_oonfX01?l0ok?o0=GooookJ_oo02/4oookJP03ol00oooonf[oo`2S00;ooo]Z00[o
o`25oookJ_oonf[ooo]Zo`[o0?oonf[oog/0olGo0?oonf[ooh`01?oonfX01OnUo`3ooo]ZoookJ_oo
nf[o_ol000?ooo]Z00Ooo`0koookJ_l0og[ooo]Zo`2Aoooonf[oo`3>00Kooo]Z00?o08coogh0oooo
2P001_oonfX00ooo0?cooo]ZoooC0003oookJP03o`3oVOoonf[ooo]Z00Oooo]Z00?oodP0oookJ_oo
nfX01ooonfX00ol0ogcooo]ZoookJP0:oookJP03o`02oooonf[ooo]Z00Gooo]Z00Oog`3ooookJ_l0
6_oooo]Zo`0]oooonf[omOl000[ooo]Z00Kooi`0oookJ_oonf[ooo]Zoe/0ool0VOl8oookJP03oomV
0?nT0?oooo]Z00Gooo]Z00?o0?l0oookJ_oonfX0=?oonfX4o`0002kooo]Z00?ooc40oookJ_oonfX0
a_oonfX002[ooo]Z00Oooj00oookJ_l0=ooooo]Zo`08oooo@`3o0?;o00?ooo]Z00CoolT0o`3Eoooo
02_o0?nf0ooonfX01?o00?oooo]ZoookJ_oo0:<2oookJP0:ool0QOoonf[ooo]Zo`[o0?oonf[oolT0
oookJ_o5o`3ooo]Zoon<00?ooo]Z00GoYOl0oookJ_oonf[ooo]Zokoo0002oookJP;oolT000Goo`0k
oookJ_oonf[oolT0o`2Ao`03ooo900Cooo]Z00Co08coogh0oooonf[oo`X01OoonfX01?oo0?cooo]Z
oookJ_ood`02oookJP03o`3oVOoonf[ooo]Z00Sooo]Z00?oodP0oookJ_oonfX01ooonfX00ol0ogco
oo]ZoookJP0:oookJP03o`02oooonf[ooo]Z00Gooo]Z00Kog`3ooeKo0?l06_oooo]Zo`0]oooeo`0;
oookJP03onGo0?oonf[ooo]Z00;ooo]Z00?o09WooookJ_oonfX00ooonfX8onGo00Cooo]Z00?o0?l0
oookJ_oonfX0=?oonfX4o`0002kooo]Z00?ooc40oookJ_oonfX0k?oonfX02?ooX03ooo]Zo`0goooo
nf[o00Sooom30?oonf[o0?;o0_oonfX01?l0ok?o0=GooookJ_oo02/4oookJP03ol00oooonf[oo`2S
00;ooo]Z00[oo`25oookJ_oonf[ooo]Zo`[o0?oonf[oog/0olGo0?oonf[ooh`01?oonfX01OnUo`3o
oo]ZoookJ_oonf[o_ol000?ooo]Z00Soo`0koookJ_oonf[o0?mjo`2Aoooonf[oo`3>o`3ohPGooo]Z
00?o08coogh0oooo2P001_oonfX00ooo0?cooo]ZoooC0003oookJP03o`3oVOoonf[ooo]Z00Oooo]Z
00?oodP0oookJ_oonfX01ooonfX00ol0ogcooo]ZoookJP0;oookJP03o`02oooonf[ooo]Z00Cooo]Z
00Oog`3ooeKo0?l06_oooo]Zo`0]oooonf[omOl000[ooo]Z00?ooi`0oookJ_oonfX00_oonfX00ol0
VOoooo]ZoookJP06oookJP03oomV0?nT0?oooo]Z00Kooo]Z00?o0?l0oookJ_oonfX0=?oonfX4o`00
02kooo]Z00?ooc40oookJ_oonfX0a_oonfX002_ooo]Z00Go03OooookJ_oob@3ood<0o`3bo`03oook
JP04ooo90?l0eOooo`0[o`3o]P?ooo]Z00Go`03ooookJ_oonf[oo`2SoookJP02ool0Q@;ooo]Z00Oo
2_l0oookJ_oob@3ooo]ZolGo0?oonf[ooh`000?ooo]Z00GoYOl0oookJ_oonf[ooo]Zokoo0002oook
JP;oolT000Goo`0kooo90?oob@3oolT0o`2Ao`03ooo900Gooo]Z00?o08cooookJ_oo2P001OoonfX0
1?oo0?cooo]ZoookJ_ood`02oookJP03o`3oVOoonf[ooo]Z00Sooo]Z00?oodP0oookJ_oonfX01ooo
nfX00ol0ogcooo]ZoookJP0:oookJP03o`02oooonf[ooo]Z00Kooo]Z00Kog`3oo`0Joooonf[o02go
oookJ_oeo`0:oookJP03onGo0?oonf[ooo]Z00;ooo]Z00?o09WooookJ_oonfX00ooonfX8onGo00Co
oo]Z00?o0?l0oookJ_oonfX0=OoonfX4o`0002kooo]Z00?ooc40oookJ_oonfX0kOoonfX01_l0=ooo
oo]Zo`08oooo@`3ooo]Zo`3bo`;ooo]Z00Co0?nco`3Eoooo02_oo`0[1?oonfX00oo00?oooo]Zool0
X`02oookJP0:ool0QOoonf[ooo]ZoookJ_l:o`3ooo]Zoomk0?o5o`3ooo]Zoon<00Cooo]Z00GoYOl0
oookJ_oonf[ooo]Zokoo0003oookJP08ool0>ooonf[ooo]Zo`3oN_l0TOoooo]Zool0c_l0on85oook
JP03o`2<oomn0?ooo`X000Kooo]Z00?oo`3loookJ_ood`000ooonfX00ol0oiWooo]ZoookJP07oook
JP03oom80?oonf[ooo]Z00Oooo]Z00?o0?mloookJ_oonfX02ooonfX00ol00_oooo]ZoookJP05oook
JP06oml0ool06_oooo]Zo`0]oooonf[omOl02_oonfX00oooW03ooo]ZoookJP02oookJP03oe/0ool0
VOoooo]Z00Oooo]Z00?oofH0oj@0oooonfX01OoonfX00ol0o`3ooo]ZoookJP0eoookJPCo0000;_oo
nfX00ooo<@3ooo]ZoookJP36oookJP00:_oonfX01Ol0=ooooo]Zo`08oooo@`3o0?;o00?ooo]Z00Co
olT0o`3Eoooo02_o0?nf0ooonfX01_o00?oooo]ZoookJ_oo0:?ooo]Zool0Q@?ooo]Z00Oo2_l0oook
J_oob@3ooo]ZolGo0?oonf[ooh`000?ooo]Z00GoYOl0oookJ_oonf[ooo]Zokoo0003oookJP03ooo9
0?oo03_oolT000KoolT01OoonfX00ol0S?oooo]Zool:0005oookJP04ool0o?oonf[ooo]ZoooC00;o
oo]Z00?o0?nIoookJ_oonfX02?oonfX00ooob@3ooo]ZoookJP07oookJP03o`3oO?oonf[ooo]Z00[o
oo]Z00?o00;ooookJ_oonfX01_oonfX01_oO0?oooo]Zo`0Jool0;Ooooo]ZooGo00Gooo]Z0_oUo`03
oookJP03onGo0?oonf[ooo]Z00;ooo]Z00?o09WooookJ_oonfX01?oonfX7onGo00Cooo]Z00?o0?l0
oookJ_oonfX0=_oonfX4o`0002kooo]Z00?ooc40oookJ_oonfX0k?oonfX01_l0=ooooo]Zo`08oooo
@`3ooo]Zo`3bo`;ooo]Z00Co0?nco`3Eoooo02_o0?nf1?oonfX00oo00?oooo]Zool0X`02oookJP08
ool0QOoonf[ooo]ZoookJ_l:o`3ooo]Zoomk0?o5o`02oookJP05oon<0?oonf[ooo]ZoookJ_nUo`00
0ooonfX01Onoo`3ooo]ZoookJ_oonf[oo`0k00;ooo]Z00Go0?mjo`2Aoooonf[oo`3>o`3ohP05oook
JP03o`2<oomn0?ooo`X000Kooo]Z00Coo`3loookJ_oonf[oom<00_oonfX00ol0oiWooo]ZoookJP07
oookJP03oom80?oonf[ooo]Z00Oooo]Z00?o0?mloookJ_oonfX02ooonfX00ol00_oooo]ZoookJP05
oookJP06oml0oooonf[o01[oo`0]oooonf[omOl02_oonfX00oooW03ooo]ZoookJP02oookJP03oe/0
ool0VOoooo]Z00Oooo]Z00?oofH0oj@0oooonfX01OoonfX00ol0o`3ooo]ZoookJP0foookJPCo0000
;_oonfX00ooo<@3ooo]ZoookJP36oookJP00:ooonfX01?l02?oood<0o`3boooob@02oookJP04ooo9
0?l0eOooo`0[o`3o]P?ooo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_oo08D3oookJP07o`[o0?oonf[o
olT0oookJ_o5o`3ooo]Zoon<0003oookJP03ojGo0?oonf[ooo]Z00;ooo]Z00Go_ol0oookJ_oonf[o
olT0ool0>`06ooo900Kooo]Z00?o08coogh0oooo2P001OoonfX01?oo0?cooo]ZoookJ_ood`02oook
JP03o`3oVOoonf[ooo]Z00Wooo]Z00?oolT0oookJ_oonfX01ooonfX00ol0ogcooo]ZoookJP0:oook
JP03o`02oooonf[ooo]Z00Gooo]Z00Kog`3ooookJ_l06_oooo]Zo`0]oooeo`06oookJP?oiOl000?o
oo]ZonGo0?oonfX00ooonfX00omK0?oo09WooookJP05oookJPKoiOl01OoonfX00ol0o`3ooo]Zoook
JP0foookJPCo0000;_oonfX00ooo<@3ooo]ZoookJP3]oookJP04o`08oooo@`3ooo]Zo`3bo`;ooo]Z
00Co0?nco`3Eoooo02_o0?nf1?oonfX00oo00?oooo]Zool0X`02oookJP08ool0QOoonf[ooo]Zoook
J_l:o`3ooo]Zoomk0?o5o`02oookJP05oon<0?oonf[ooo]ZoookJ_nUo`000ooonfX01Onoo`3ooo]Z
oookJ_oonf[oo`0k00;ooo]Z00Go0?mjoookJ_l0TOooo`3>o`3ohP05oookJP03o`2<oomn0?ooo`X0
00Kooo]Z00Coo`3loookJ_oonf[oom<00_oonfX00ol0oiWooo]ZoookJP08oookJP03oom80?oonf[o
oo]Z00Oooo]Z00?o0?mloookJ_oonfX02_oonfX00ol00_oooo]ZoookJP05oookJP07oml0oooonf[o
01[ooookJ_l0;Ooooo]ZooGo000:oookJP06oonL0?oonf[ooo]ZoookJ_mK0?oo09Wo2OoonfX00ooo
IP3ooo]ZoookJP05oookJP03o`3o0?oonf[ooo]Z03Kooo]Z1?l0000^oookJP03oola0?oonf[ooo]Z
0<Kooo]Z000ZoookJP03o`08oooo@`3o0?;o00CoolT000?o0=Goool0:ol0okH00ooonfX01_o00?oo
oo]ZoookJ_oo0:?ooo]Zool0Q@?ooo]Z00Oo2_l0oookJ_oob@3ooo]ZolGo0?oonf[ooh`000?ooo]Z
00?oYOl0oookJ_oonfX00_oonfX01Onoo`3ooo]ZoookJ_oonf[oo`0k00SoolT01?oonfX00ol0S?oo
OP3oool:0005oookJP04ool0o?oonf[ooo]ZoooC00;ooo]Z00?o0?nIoookJ_oonfX02OoonfX00ooo
b@3ooo]ZoookJP07oookJP03o`3oO?oonf[ooo]Z00[ooo]Z00?o00;ooookJ_oonfX01OoonfX01_oO
0?oooo]Zo`0Joooonf[o02goooGo00Kooo]Z1_oUo`04oookJP03o`2Ioooonf[ooo]Z00Cooo]Z1_oU
o`05oookJP03o`3o0?oonf[ooo]Z03Oooo]Z1?l0000^oookJP03oola0?oonf[ooo]Z0>cooo]Z00Co
00Sooom30?oonf[o0?;o0_oonfX01?l0ok?o0=Goool0:ol0okH4oookJP03ol00oooonf[oo`2S00;o
oo]Z00Soo`25oookJ_oonf[ooo]Zo`[o0?oonf[oog/0olGo00;ooo]Z00Gooh`0oookJ_oonf[ooo]Z
ojGo0003oookJP05okoo0?oonf[ooo]ZoookJ_oo03/00_oonfX01Ol0og[ooo]Zo`2Aoooo0<ko0?oR
00Gooo]Z00?o08coogh0oooo2P001_oonfX01?oo0?cooo]ZoookJ_ood`02oookJP03o`3oVOoonf[o
oo]Z00Sooo]Z00?oodP0oookJ_oonfX01ooonfX00ol0ogcooo]ZoookJP0:oookJP03o`02oooonf[o
oo]Z00Gooo]Z00Oog`3ooookJ_l06_oooo]Zo`0]oooonf[omOl000[ooo]Z00?ooi`0oookJ_oonfX0
0_oonfX00ol0VOoooo]ZoookJP07oookJP03oomV0?nT0?oooo]Z00Gooo]Z00?o0?l0oookJ_oonfX0
=ooonfX4o`0002kooo]Z00?ooc40oookJ_oonfX0a_oonfX002[ooo]Z00?ood<0o`3boooob@001?oo
b@000ooo02_o0?nfoookJP02oookJP06ol00oooonf[ooo]Zool0Xooonf[oo`250ooonfX01ol:o`3o
oo]Zooo90?oonf[oaOl0oookJ_ooS0000ooonfX00onUo`3ooo]ZoookJP02oookJP05okoo0?oonf[o
oo]ZoookJ_oo03/01ooob@05oookJP04o`2<oomn0?oooo]Zool:00Gooo]Z00?oo`3loookJ_ood`00
0_oonfX2ooo900[ooo]Z00?oolT0oookJ_oonfX01ooonfX00ol0ogcooo]ZoookJP0:oookJP03o`02
oooonf[ooo]Z00Gooo]Z00Kog`3ooeKo0?l06_oooo]Zo`0]oooeo`07oookJPKoiOl00ooonfX00ol0
VOoooo]ZoookJP05oookJPGoiOl01OoonfX00ol0o`3ooo]ZoookJP0hoookJPCo0000;_oonfX00ooo
<@3ooo]ZoookJP3/oookJP03oom30?oonf[o0?;o00;ooo]Z00Co0?nco`3Eoooo02_o0?nf1?oonfX0
0oo00?oooo]Zool0X`02oookJP08ool0QOoonf[ooo]ZoookJ_l:o`3ooo]Zoomk0?o5o`02oookJP05
oon<0?oonf[ooo]ZoookJ_nUo`000ooonfX01Onoo`3ooo]ZoookJ_oonf[oo`0k00;ooo]Z00Go0?mj
oookJ_l0TOoooo]Zool0cP05oookJP04o`2<oomn0?oooo]Zool:00Kooo]Z00?oo`3loookJ_ood`00
0_oonfX00ol0oiWooo]ZoookJP08oookJP03oom80?oonf[ooo]Z00Oooo]Z00?o0?mloookJ_oonfX0
2ooonfX00ol00_oooo]ZoookJP04oookJP07oml0oomFo`3o01[ooookJ_l0;Ooooo]ZooGo000:oook
JP03oonL0?oonf[ooo]Z00;ooo]Z00?oF`3oo`2IoooonfX01ooonfX00oooIP3oY03ooookJP05oook
JP03o`3o0?oonf[ooo]Z03Sooo]Z1?l0000^oookJP03oola0?oonf[ooo]Z0<Kooo]Z000ZoookJP03
o`3boooob@3oolT000?oolT000?oo`0[ooo90?oonfX00_oonfX01_o00?oooo]ZoookJ_oo0:?ooo]Z
ool0Q@?ooo]Z00Oo2_l0oookJ_oob@3ooo]ZolGo0?oonf[ooh`000?ooo]Z00?oYOl0oookJ_oonfX0
0_oonfX01Onoo`3ooo]ZoookJ_oonf[oo`0k00OoolT01OoonfX01?l0S?ooOP3ooookJ_oo2P05oook
JP04ool0o?oonf[ooo]ZoooC00;ooo]Z00?oolT0oookJ_oonfX02?oonfX00ooob@3ooo]ZoookJP07
oookJP03o`3oO?oonf[ooo]Z00[ooo]Z00?o00;ooookJ_oonfX01_oonfX01_oO0?oo01[ooookJ_l0
;Ooooo]ZooGo00Kooo]Z2?oUo`000ooonf[oF`3oo`2Io`07oookJPCoiOl01_oonfX00ol0o`3ooo]Z
oookJP0hoookJPCo0000;_oonfX00ooo<@3ooo]ZoookJP3/oookJP;o0?;o0_oonfX01?l0ok?o0=Go
ool0:ol0okH4oookJP03ol00oooonf[oo`2S00;ooo]Z00Soo`25oookJ_oonf[ooo]Zo`[o0?oonf[o
og/0olGo00;ooo]Z00Gooh`0oookJ_oonf[ooo]ZojGo0003oookJP05okoo0?oonf[ooo]ZoookJ_oo
03/00_oonfX01Ol0og[ooo]Zo`2Aoooonf[oo`3>00Gooo]Z00Co08coogh0oooonf[oo`X01_oonfX0
0ooo0?cooo]ZoooC0003oookJP03o`3oVOoonf[ooo]Z00Oooo]Z00?oodP0oookJ_oonfX01ooonfX0
0ol0ogcooo]ZoookJP0;oookJP03o`02oooonf[ooo]Z00Gooo]Z00Kog`3oo`0Joooonf[o02gooook
J_oeo`0;oookJP06oonL0?oonf[ooo]ZoookJ_mK0?oo09Wo2OoonfX00oooIP3ooo]ZoookJP05oook
JP03o`3o0?oonf[ooo]Z03Sooo]Z1?l0000^oookJP03oola0?oonf[ooo]Z0<Kooo]Z000ZoookJPGo
olT000Koo`0[ooo90?oob@3oolT0oookJ_o00?l2oookJP03ool0Xooonf[oo`2500?ooo]Z00Oo2_l0
oookJ_oob@3ooo]ZolGo0?oonf[ooh`000?ooo]Z00?oYOl0oookJ_oonfX00_oonfX01Onoo`3ooo]Z
oookJ_oonf[oo`0k00KoolT01_oonfX01?l0S?ooOP3ooookJ_oo2P05oookJP04ool0o?oonf[ooo]Z
oooC00;ooo]Z00?oolT0oookJ_oonfX02?oonfX00ooob@3ooo]ZoookJP07oookJP03o`3oO?oonf[o
oo]Z00_ooo]Z00?o00;ooookJ_oonfX01OoonfX01_oO0?oooo]Zo`0Jool0;Ooooo]ZooGo00Oooo]Z
2OoUo`000ol0VOoooo]ZoookJP05oookJPCoiOl01_oonfX00ol0o`3ooo]ZoookJP0ioookJPCo0000
;_oonfX00ooo<@3ooo]ZoookJP3_oookJP04o`3o/ol0eOooo`0[o`3o]PCooo]Z00?o`03ooookJ_oo
0:<00_oonfX02?oo08Gooo]ZoookJ_oonf[o2_l0oookJ_ooN`3oaOl00_oonfX01OooS03ooo]Zoook
J_oonf[oYOl000?ooo]Z00Go_ol0oookJ_oonf[ooo]Zool0>`02oookJP05o`3oN_oonf[o097ooook
J_oo0<h01OoonfX01?l0S?ooOP3ooookJ_oo2P06oookJP03ool0o?oonf[oom<000?ooo]Z00?o0?nI
oookJ_oonfX01ooonfX00oooB03ooo]ZoookJP07oookJP03o`3oO?oonf[ooo]Z00_ooo]Z00?o00;o
oookJ_oonfX01OoonfX01?oO0?oooo]Zo`0Jool0;Ol2oookJP03ooGo0?oonf[ooo]Z00Sooo]Z00Ko
oi`0oookJ_oonf[ooo]Zoe/0ool0VOl9oookJP03oomV0?nT0?oooo]Z00Gooo]Z00?o0?l0oookJ_oo
nfX0>OoonfX4o`0002kooo]Z00?ooc40oookJ_oonfX0a_oonfX002[ooo]Z1?oob@000ooo02_oolT0
ooo90002oookJP06ol00oooonf[ooo]Zool0Xooonf[oo`250ooonfX01ol:o`3ooo]Zooo90?oonf[o
aOl0oookJ_ooS0000ooonfX00onUo`3ooo]ZoookJP02oookJP05okoo0?oonf[ooo]ZoookJ_oo03/0
1Ooob@000ooo0<kooo]ZoookJP04oookJP04o`2<oomn0?oooo]Zool:00Gooo]Z00Coo`3loookJ_oo
nf[oom<00_oonfX00ooob@3ooo]ZoookJP08oookJP03ooo90?oonf[ooo]Z00Oooo]Z00?o0?mloook
J_oonfX02ooonfX00ol00_oooo]ZoookJP05oookJP06oml0oooonf[o01[ooookJ_l0;OoomOl02?oo
nfX7onGo0003oookJ_l0VOoooo]Z00Oooo]Z0ooUo`06oookJP03o`3o0?oonf[ooo]Z03[ooo]Z1?l0
000^oookJP03oola0?oonf[ooo]Z0>kooo]Z00Co0?nco`3Eoooo02_o0?nf1?oonfX00oo00?oooo]Z
ool0X`02oookJP08ool0QOoonf[ooo]ZoookJ_l:o`3ooo]Zoomk0?o5o`02oookJP05oon<0?oonf[o
oo]ZoookJ_nUo`000ooonfX01Onoo`3ooo]ZoookJ_oonf[oo`0k00;ooo]Z00Go0?mjoookJ_l0TOoo
oo]Zool0cP05oookJP04o`2<oomn0?oooo]Zool:00Kooo]Z00?oo`3loookJ_ood`000ooonfX00ol0
oiWooo]ZoookJP07oookJP03oom80?oonf[ooo]Z00Oooo]Z00?o0?mloookJ_oonfX02ooonfX00ol0
0_oooo]ZoookJP05oookJP07oml0oooonf[o01[ooookJ_l0;Ooooo]ZooGo000:oookJP03oonL0?oo
nf[ooo]Z00;ooo]Z00?o09WooookJ_oonfX01ooonfX00oooIP3oY03ooookJP06oookJP03o`3o0?oo
nf[ooo]Z03Wooo]Z1?l0000^oookJP03oola0?oonf[ooo]Z0<Kooo]Z000ZoookJP?oolT000?oo`0[
ooo90?oonfX00_oonfX01_o00?oooo]ZoookJ_oo0:?ooo]Zool0Q@?ooo]Z00Oo2_l0oookJ_oob@3o
oo]ZolGo0?oonf[ooh`000?ooo]Z00?oYOl0oookJ_oonfX00_oonfX01_noo`3ooo]ZoookJ_oonf[o
o`0koookJPCoolT000?oo`3>oookJ_oonfX01?oonfX01?oob@3oOP3ooookJ_oo2P05oookJP04ool0
o?oonf[ooo]ZoooC00;ooo]Z00?oolT0oookJ_oonfX02?oonfX00ooob@3ooo]ZoookJP08oookJP03
o`3oO?oonf[ooo]Z00[ooo]Z00?o00;ooookJ_oonfX01OoonfX01_oO0?ooE_l0o`0Joooonf[o02go
ooGo00Sooo]Z1ooUo`000ooonf[o09WooookJP08oookJP;oiOl01_oonfX00ol0o`3ooo]ZoookJP0k
oookJPCo0000;_oonfX00ooo<@3ooo]ZoookJP3]oookJP04o`3o/ol0eOooo`0[o`3o]PCooo]Z00?o
`03ooookJ_oo0:<00_oonfX02?oo08Gooo]ZoookJ_oonf[o2_l0oookJ_ooN`3oaOl00_oonfX01Ooo
S03ooo]ZoookJ_oonf[oYOl000?ooo]Z00Go_ol0oookJ_oonf[ooo]Zool0>`02oookJP05o`3oN_oo
nf[o097ooookJ_oo0<h01OoonfX01?l0S?ooOP3ooookJ_oo2P06oookJP03ool0o?oonf[oom<000?o
oo]Z00?o0?nIoookJ_oonfX01ooonfX00oooB03ooo]ZoookJP08oookJP03o`3oO?oonf[ooo]Z00[o
oo]Z00?o00;ooookJ_oonfX01OoonfX01ooO0?ooE_l0o`0Joooonf[o02gooookJ_oeo`002ooonfX0
1_ooW03ooo]ZoookJ_oonf[oF`3oo`2Io`Wooo]Z00?oofH0oookJ_oonfX01OoonfX00ol0o`3ooo]Z
oookJP0joookJPCo0000;_oonfX00ooo<@3ooo]ZoookJP36oookJP00:_oonfX2ooo90003ool0:ol0
okKooo]Z00;ooo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_oo08D3oookJP07o`[o0?oonf[oolT0oook
J_o5o`3ooo]Zoon<0003oookJP03ojGo0?oonf[ooo]Z00;ooo]Z00Ko_ol0oookJ_oonf[ooo]Zool0
>ooonfX3ooo90003oookJ_oo0<kooo]Z00Gooo]Z00CoolT0ogh0oooonf[oo`X01OoonfX01?oo0?co
oo]ZoookJ_ood`02oookJP03ooo90?oonf[ooo]Z00Sooo]Z00?oolT0oookJ_oonfX02?oonfX00ol0
ogcooo]ZoookJP0:oookJP03o`02oooonf[ooo]Z00Gooo]Z00Kog`3ooeKo0?l06_oooo]Zo`0]oooe
o`09oookJPKoiOl000?ooo]Zoe/0ool0VOl02?oonfX2onGo00Oooo]Z00?o0?l0oookJ_oonfX0>ooo
nfX4o`0002oooo]Z00?ooc40oookJ_oonfX0jooonfX01?l0ok?o0=Goool0:ol0okH4oookJP03ol00
oooonf[oo`2S00;ooo]Z00Soo`25oookJ_oonf[ooo]Zo`[o0?oonf[oog/0olGo00;ooo]Z00Gooh`0
oookJ_oonf[ooo]ZojGo0003oookJP05okoo0?oonf[ooo]ZoookJ_oo03/00_oonfX01Ol0og[ooo]Z
o`2Aoooonf[oo`3>00Kooo]Z00?o08cooookJ_oo2P001_oonfX00ooo0?cooo]ZoooC0003oookJP03
o`3oVOoonf[ooo]Z00Oooo]Z00?oodP0oookJ_oonfX02?oonfX00ol0ogcooo]ZoookJP0:oookJP03
o`02oooonf[ooo]Z00Gooo]Z00Oog`3ooeKo0?l06_oooo]Zo`0]oooonf[omOl000_ooo]Z00Kooi`0
oookJ_oonf[ooo]Zoe/0ool0VOl9oookJP03oomV0?nT0?oooo]Z00Gooo]Z00?o0?l0oookJ_oonfX0
>ooonfX4o`0002oooo]Z00?ooc40oookJ_oonfX0aOoonfX002[ooo]Z00?oolT0ool0:ol0okH00ooo
nfX01_o00?oooo]ZoookJ_oo0:?ooo]Zool0Q@?ooo]Z00Oo2_l0oookJ_oob@3ooo]ZolGo0?oonf[o
oh`000?ooo]Z00?oYOl0oookJ_oonfX00_oonfX01Onoo`3ooo]ZoookJ_oonf[oo`0k00;ooo]Z00Co
olT0o`2Aoooonf[oo`3>1_oonfX01?oob@3oOP3ooookJ_oo2P05oookJP04ool0o?oonf[ooo]ZoooC
00;ooo]Z00?oolT0oookJ_oonfX02?oonfX00ooob@3ooo]ZoookJP08oookJP03o`3oO?oonf[ooo]Z
00[ooo]Z00?o00;ooookJ_oonfX01_oonfX01_oO0?oooo]Zo`0Jool0;Ooooo]ZooGo00Sooo]Z1OoU
o`02oookJP03oe/0ool0VOoooo]Z00Sooo]Z00?oiOl0oookJ_oonfX01OoonfX00ol0o`3ooo]Zoook
JP0UoookJPGo001o1OoonfX5o`00O`Sooo]Z1?l0000_oookJP03oola0?oonf[ooo]Z0>_ooo]Z00?o
0=Goool0:ol0okH01?oonfX00oo00?oooo]Zool0X`02oookJP08ool0QOoonf[ooo]ZoookJ_l:o`3o
oo]Zoomk0?o5o`02oookJP05oon<0?oonf[ooo]ZoookJ_nUo`000ooonfX01Onoo`3ooo]ZoookJ_oo
nf[oo`0k00;ooo]Z00Go0?mjoookJ_l0TOoooo]Zool0cP06oookJP03o`2<oooonf[oo`X000Kooo]Z
00?oo`3loookJ_ood`000ooonfX00ol0oiWooo]ZoookJP07oookJP03oom80?oonf[ooo]Z00Sooo]Z
00?o0?mloookJ_oonfX02ooonfX00ol00_oooo]ZoookJP05oookJP04oml0oooonf[o01[oo`0]o`;o
oo]Z00?omOl0oookJ_oonfX02?oonfX01_ooW03ooo]ZoookJ_oonf[oF`3oo`2Io`Wooo]Z00?oofH0
oj@0oooonfX01_oonfX00ol0o`3ooo]ZoookJP0ToookJPGo001o1OoonfX5o`00O`Sooo]Z1?l0000_
oookJP03oola0?oonf[ooo]Z0<Gooo]Z000ZoookJP03ool0:ol0okKooo]Z00;ooo]Z00Ko`03ooook
J_oonf[oo`2SoookJ_oo08D3oookJP07o`[o0?oonf[oolT0oookJ_o5o`3ooo]Zoon<0003oookJP03
ojGo0?oonf[ooo]Z00;ooo]Z00Go_ol0oookJ_oonf[ooo]Zool0>`02oookJP04ooo90?l0TOoooo]Z
ool0cPKooo]Z00CoolT0ogh0oooonf[oo`X01OoonfX01?oo0?cooo]ZoookJ_ood`02oookJP03ooo9
0?oonf[ooo]Z00Sooo]Z00?oolT0oookJ_oonfX02?oonfX00ol0ogcooo]ZoookJP0;oookJP03o`02
oooonf[ooo]Z00Gooo]Z00Kog`3ooookJ_l06_oo02gooookJ_oeo`09oookJPCoiOl00ooonfX00ol0
VOoooo]ZoookJP07oookJP03oj@0ooooIP3ooo]Z00Gooo]Z00?o0?l0oookJ_oonfX09OoonfX7o`00
O`?ooo]Z1ol007l7oookJPCo0000;ooonfX00ooo<@3ooo]ZoookJP3[oookJP03ool0:ol0okKooo]Z
00?ooo]Z00?o`03ooookJ_oo0:<00_oonfX02?oo08Gooo]ZoookJ_oonf[o2_l0oookJ_ooN`3oaOl0
0_oonfX01OooS03ooo]ZoookJ_oonf[oYOl000?ooo]Z00Go_ol0oookJ_oonf[ooo]Zool0>`02oook
JP05o`3oN_oonf[o097ooookJ_oo0<h01_oonfX00ol0S?oooo]Zool:0006oookJP03ool0o?oonf[o
om<000?ooo]Z00?o0?nIoookJ_oonfX01ooonfX00oooB03ooo]ZoookJP08oookJP03o`3oO?oonf[o
oo]Z00_ooo]Z00?o00;ooookJ_oonfX01OoonfX01?oO0?oooo]Zo`0Jool0;Ol2oookJP03ooGo0?oo
nf[ooo]Z00Sooo]Z00?ooi`0oookJ_oonfX00_oonfX00ol0VOoooo]ZoookJP08oookJP03oomV0?oo
nf[ooo]Z00Gooo]Z00?o0?l0oookJ_oonfX09?oonfX7o`00O`?ooo]Z1ol007l7oookJPCo0000;ooo
nfX00ooo<@3ooo]ZoookJP35oookJP00:_oonfX01Ol0okKooo]ZoookJ_oonf[o`03o00;ooo]Z00go
o`2SoookJ_oo08Gooo]Zooo90?oonf[o2_l0oookJ_oob@3ooo]ZolGo0?oonf[ooh`000?ooo]Z00?o
YOl0oookJ_oonfX00_oonfX01Onoo`3ooo]ZoookJ_oonf[oo`0k00;ooo]Z00Go0?mjo`2Aoooonf[o
o`3>o`3ohP05oookJP04ooo90?mn0?oooo]Zool:00Gooo]Z00Coo`3loookJ_oonf[oom<00_oonfX0
0ooob@3ooo]ZoookJP08oookJP03ooo90?oonf[ooo]Z00Sooo]Z00?o0?mloookJ_oonfX02ooonfX0
0ol00_oooo]ZoookJP05oookJP06oml0oooonf[o01[ooookJ_l0;OoomOl02OoonfX4onGo00?ooo]Z
00?o09WooookJ_oonfX02?oonfX00oooIP3ooo]ZoookJP05oookJP03o`3o0?oonf[ooo]Z02Gooo]Z
0ol007l2oookJP?o001o0_oonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l0000_oookJP03
oola0?oonf[ooo]Z0>_ooo]Z00?o0?nfoookJ_oonfX00_oonfX00oo00?oooo]Zool0X`02oookJP08
ool0QOoonf[ooo]ZoookJ_l:o`3ooo]Zoomk0?o5o`02oookJP05oon<0?oonf[ooo]ZoookJ_nUo`00
0ooonfX01Onoo`3ooo]ZoookJ_oonf[oo`0k00;ooo]Z00Go0?mjoookJ_l0TOoooo]Zool0cP06oook
JP03o`2<oooonf[oo`X000Kooo]Z00?oo`3loookJ_ood`000ooonfX00ol0oiWooo]ZoookJP07oook
JP03oom80?oonf[ooo]Z00Sooo]Z00?o0?mloookJ_oonfX02ooonfX00ol00_oooo]ZoookJP05oook
JP07oml0oooonf[o01[ooookJ_l0;Ooooo]ZooGo000;oookJP06oonL0?oonf[ooo]ZoookJ_mK0?oo
09Wo2OoonfX00oooIP3oY03ooookJP06oookJP03o`3o0?oonf[ooo]Z02Cooo]Z0ol007l2oookJP?o
001o0_oonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l0000_oookJP03oola0?oonf[ooo]Z
0<Gooo]Z000]oookJP06ol00oooonf[ooo]Zool0Xooonf[oo`250_oonfX02?oob@3o2_l0oookJ_oo
b@3ooo]ZolGo0?oonf[ooh`00ooonfX00onUo`3ooo]ZoookJP02oookJP05okoo0?oonf[ooo]Zoook
J_oo03/00_oonfX01Ol0og[o097ooookJ_oo0<ko0?oR00Gooo]Z00CoolT0ogh0oooonf[oo`X01Ooo
nfX01?oo0?cooo]ZoookJ_ood`02oookJP03ooo90?oonf[ooo]Z00Sooo]Z00?oolT0oookJ_oonfX0
2?oonfX00ol0ogcooo]ZoookJP0;oookJP03o`02oooonf[ooo]Z00Gooo]Z00Oog`3ooookJ_l06_oo
oo]Zo`0]oooonf[omOl000Wooo]Z0_oUo`04oookJP03o`2Ioooonf[ooo]Z00Sooo]Z00?oofH0oook
J_oonfX01OoonfX00ol0o`3ooo]ZoookJP0UoookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l6oookJPCo0000;ooonfX00ooo<@3ooo]ZoookJP3_oookJP03ol00oooonf[o
o`2S00;ooo]Z00Soo`25oookJ_oonf[ooo]Zo`[o0?oonf[oog/0olGo00;ooo]Z00Gooh`0oookJ_oo
nf[ooo]ZojGo0003oookJP05okoo0?oonf[ooo]ZoookJ_oo03/00_oonfX01Ol0og[ooo]Zo`2Aoooo
nf[oo`3>00Kooo]Z00?o08cooookJ_oo2P001_oonfX01?oo0?cooo]ZoookJ_ood`02oookJP03o`3o
VOoonf[ooo]Z00Oooo]Z00?oodP0oookJ_oonfX02?oonfX00ol0ogcooo]ZoookJP0;oookJP03o`02
oooonf[ooo]Z00Gooo]Z00Oog`3ooookJ_l06_oooo]Zo`0]oooonf[omOl000_ooo]Z00Kooi`0oook
J_oonf[ooo]Zoe/0ool0VOl9oookJP03oomV0?nT0?oooo]Z00Kooo]Z00?o0?l0oookJ_oonfX09?oo
nfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX4o`0002oooo]Z
00?ooc40oookJ_oonfX0aOoonfX002cooo]Z00Ko`03ooookJ_oonf[oo`2SoookJ_oo08D2oookJP08
ooo90?l:o`3oolT0ooo90?oonf[oaOl0oookJ_ooS003oookJP03ojGo0?oonf[ooo]Z00;ooo]Z00Go
_ol0oookJ_oonf[ooo]Zool0>`02oookJP05o`3oN_l0TOoooo]Zool0c_l0on801OoonfX01?oob@3o
OP3ooookJ_oo2P05oookJP04ool0o?oonf[ooo]ZoooC00;ooo]Z00?oolT0oookJ_oonfX01?oonfX0
1Ooob@3ooo]ZoookJ_oonf[oolT000[ooo]Z00?o0?mloookJ_oonfX02ooonfX00ol00_oooo]Zoook
JP05oookJP07oml0oooonf[o01[ooookJ_l0;Ooooo]ZooGo000:oookJP03onGo0?oonf[ooo]Z00;o
oo]Z00?o09WooookJ_oonfX02?oonfX00oooIP3ooo]ZoookJP05oookJP03o`3o0?oonf[ooo]Z02Ko
oo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z1_l0000]oook
JP03oola0?oonf[ooo]Z0>kooo]Z00?o`03ooookJ_oo0:<00_oonfX02?oo08Gooo]ZoookJ_oonf[o
2_l0oookJ_ooN`3oaOl00_oonfX01OooS03ooo]ZoookJ_oonf[oYOl000?ooo]Z00Go_ol0oookJ_oo
nf[ooo]Zool0>`02oookJP05o`3oN_oonf[o097ooookJ_oo0<h01_oonfX00ol0S?oooo]Zool:0006
oookJP04ool0o?oonf[ooo]ZoooC00;ooo]Z00?o0?nIoookJ_oonfX01ooonfX00oooB03ooo]Zoook
JP08oookJP03o`3oO?oonf[ooo]Z00_ooo]Z00?o00;ooookJ_oonfX01OoonfX01ooO0?oooo]Zo`0J
oooonf[o02gooookJ_oeo`002ooonfX01_ooW03ooo]ZoookJ_oonf[oF`3oo`2Io`Wooo]Z00?oofH0
oj@0oooonfX01_oonfX00ol0o`3ooo]ZoookJP0UoookJP?o001o0ooonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l6oookJPKo0000;OoonfX00ooo<@3ooo]ZoookJP35oookJP00h_oonfX4
o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX4o`000?oooo]Ze_oo
nfX4o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX4o`000?Oooo]Z
003RoookJPSo001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000oooonf[FoookJPSo001o0_oo
nfX3o`00O`?ooo]Z0ol007l6oookJPCo0000mooonfX00>;ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o0ooonfX3o`00Oooooo]Zh?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007l3oookJP?o001ooooonfX2oookJP00h_oonfX3o`00O`Oooo]Z0ol007l3oookJP?o001ooooo
nf[PoookJP?o001o1ooonfX3o`00O`?ooo]Z0ol007oooookJP;ooo]Z003RoookJP?o001o1ooonfX3
o`00O`?ooo]Z0ol007oooookJ^3ooo]Z0ol007l7oookJP?o001o0ooonfX3o`00Oooooo]Z0_oonfX0
0>?ooo]Z0ol007l2oookJP?o001o0_oonfX3o`00O`04oookJ_l007oo001oo`00Oooooo]Zh_oonfX3
o`00O`;ooo]Z0ol007l2oookJP?o001o00Cooo]Zo`00Ool007oo001ooooonfX3oookJP00hooonfX7
o`00O`?ooo]Z1ol007oooookJ^;ooo]Z1ol007l3oookJPOo001ooooonfX3oookJP00iOoonfX4o`00
O`Gooo]Z1Ol007oooookJ^Gooo]Z1?l007l5oookJPGo001ooooonfX4oookJP00oooonf[ooookJ_oo
oo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[o
oookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00
oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[
oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Z
oooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooook
J_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z
003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooook
J^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooo
nf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oo
oo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]Zjooo
nfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oo
oo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[o
oookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00
oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[
oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Z
oooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooook
J_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z
003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooook
J^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooo
nf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oo
oo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]Zjooo
nfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oo
oo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00i_oonfX3
o`00O`Gooo]Z1Ol007oooookJ^Kooo]Z0ol007l5oookJPGo001ooooonfX4oookJP00i_oonfX3o`00
O`Cooo]Z1ol007oooookJ^Gooo]Z0ol007l4oookJPOo001ooooonfX3oookJP00i_oonfX3o`00O`?o
oo]Z1?l007l01?oonf[o001oo`00Ool007oooookJ^Gooo]Z0ol007l3oookJPCo001o00Cooo]Zo`00
Ool007oo001ooooonfX3oookJP00e_oonfX:o`00O`Kooo]Z0ol007l3oookJP?o001o0ooonfX3o`00
O`Kooo]Z1?l0003ooookJ/[ooo]Z2_l007l6oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oook
JPCo0000mooonfX0093ooo]Z2?ooN@000ooonf[ook40oookJP0AoookJP03o`2Moooonf[ooo]Z02Oo
oo]Z2_l007l6oookJP?o001o2OoonfX3o`00O`Kooo]Z1_l0000JoookJP03ofL0oooonf[ooo]Z01?o
oo]Z00?oo`1MoookJ_oonfX03_oonfX00oo30?oooo]ZoookJP0<oookJP;oV@3o00?ooo]Zofh0oooo
nfX03ooonfX00ol0o`_ooo]ZoookJP0<oookJP03o`2=oooonf[ooo]Z00Wooo]Z00?ooiT0oookJ_oo
nfX01ooonfX00ol0B?oooo]ZoookJP0EoookJP04of3o0?oonf[ooo]Zoon@00Cooo]Z00?oo`2Poook
J_oonfX00_oonfX01Ooo08_ooo]ZoookJ_oonf[o_03o00Gooo]Z00GoL_l0oookJ_oonf[ooo]Zo`H0
o`02oookJP03oeko0?oo02Kooo]Z00_ooo]Z00?o0=oooookJ_oonfX0]OoonfX00omAo`3ooo]Zoook
JP02oookJP03oona0?oonf[ooo]Z013ooo]Z00?o09gooookJ_oonfX09ooonfX:o`00O`Kooo]Z0ol0
07l9oookJP?o001o1_oonfX6o`0001_ooo]Z00?oI`3ooookJ_oonfX04_oonfX00ooo05gooo]Zoook
JP0>oookJP03ol<0oooonf[ooo]Z00gooo]Z00CoV@3ooookJ_oonf[oKP3o3ooonfX00ol0o`_ooo]Z
oookJP0<oookJP03o`2=oooonf[ooo]Z00Wooo]Z00?ooiT0oookJ_oonfX01ooonfX00ol0B?oooo]Z
oookJP0EoookJP05of3o0?oonf[ooo]ZoomO0?ooT0000ooonfX2ool0X0?ooo]Z00Goo`2;oookJ_oo
nf[ooo]Zok`0o`05oookJP03og;o0?oonf[ooo]Z00;ooo]Z00Co1P3ooookJ_mNo`3oo`0V3?oonfX0
0ol0gooooo]ZoookJP0UoookJP00TOoonfX6oomi00;ooo]Z00?ook40oookJ_oonfX04?oonfX00ol0
WOoooo]ZoookJP0goookJP?o001o2OoonfX3o`00O`Kooo]Z1?l0000LoookJP03ofL0oooonf[ooo]Z
01?ooo]Z00?oo`1MoookJ_oonfX03_oonfX00oo30?oooo]ZoookJP0<oookJP04oiT0oooonf[ooo]Z
ofh0oa3ooo]Z00?o0?l;oookJ_oonfX03?oonfX00ol0SOoooo]ZoookJP09oookJP03oonI0?oonf[o
oo]Z00Oooo]Z00?o04SooookJ_oonfX05OoonfX01?mPo`3ooo]ZoookJ_ooT003oookJP03ool0X?oo
nf[ooo]Z00;ooo]Z00Goo`2;oookJ_oonf[ooo]Zok`0o`05oookJP03og;o0?oonf[ooo]Z00;ooo]Z
00Co1P3ooookJ_mNo`3oo`0V3?oonfX01?l0gooooo]ZoookJ_oo0>6foookJP03oe7o0?oonf[ooo]Z
00;ooo]Z00?ook40oookJ_oonfX03ooonfX00ol0WOoooo]ZoookJP0goookJP?o001o2OoonfX3o`00
O`Kooo]Z1?l0000MoookJP03ofL0oooonf[ooo]Z01;ooo]Z00?oo`1MoookJ_oonfX03_oonfX00oo3
0?oooo]ZoookJP0=oookJP04oiT0oooonf[ooo]Zofh0o`oooo]Z00?o0?l;oookJ_oonfX03?oonfX0
0ol0SOoooo]ZoookJP09oookJP03oonI0?oonf[ooo]Z00Oooo]Z00?o04SooookJ_oonfX05OoonfX0
1OmPo`3ooo]ZoookJ_ooG`3ooi0000;ooo]Z00?oo`2PoookJ_oonfX00ooonfX01Ooo08_ooo]Zoook
J_oonf[o_03o00Gooo]Z00GoL_l0oookJ_oonf[ooo]Zo`H0o`02oookJP03oeko0?oo02Kooo]Z00[o
oo]Z00Go0=oooookJ_oonf[ooo]Zool0h@0ToookJP00TOoonfX5oomi00Cooo]Z00?ook40oookJ_oo
nfX04?oonfX00ol0WOoooo]ZoookJP0foookJP?o001o1?oonfX2o`00O`;ooo]Z1?l007l6oookJPCo
00006ooonfX00omW0?oooo]ZoookJP0CoookJP03ool0GOoonf[ooo]Z00kooo]Z00?o``3ooookJ_oo
nfX03?oonfX01?nI0?oooo]ZoookJ_m^0?l@oookJP03o`3o2ooonf[ooo]Z00cooo]Z00?o08gooook
J_oonfX02OoonfX00oooV@3ooo]ZoookJP07oookJP03o`18oooonf[ooo]Z01Gooo]Z00CoH?l0oook
J_oonf[ooi000ooonfX00ooo0:3ooo]ZoookJP02oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l01Ooo
nfX00ombo`3ooo]ZoookJP02oookJP04o`H0oooonf[oG_l0ool09Pcooo]Z00Go0=oooookJ_oonf[o
oo]Zool0h@2goookJP03oe7o0?oonf[ooo]Z00;ooo]Z00?ook40oookJ_oonfX03ooonfX00ol0WOoo
oo]ZoookJP0foookJP?o001o1?oonfX2o`00O`;ooo]Z1?l007l6oookJPCo00007?oonfX00omW0?oo
oo]ZoookJP0BoookJP03ool0GOoonf[ooo]Z00kooo]Z00?o``3ooookJ_oonfX03OoonfX01?nI0?oo
oo]ZoookJ_m^0?l?oookJP03o`3o2ooonf[ooo]Z00cooo]Z00?o08gooookJ_oonfX02OoonfX00ooo
V@3ooo]ZoookJP07oookJP03o`18oooonf[ooo]Z01Gooo]Z00GoH?l0oookJ_oonf[ooel0oon@0002
oookJP03ool0X?oonf[ooo]Z00?ooo]Z00Goo`2;oookJ_oonf[ooo]Zok`0o`05oookJP05og;o0?oo
nf[ooo]ZoookJ_l60?l00_oonfX00omNo`3oo`0VoookJP0:oookJP05o`3Ooooonf[ooo]ZoookJ_oo
0>409OoonfX009;ooo]Z0oooN@000ooonf[oDOl0oookJP03oookJP03oona0?oonf[ooo]Z00oooo]Z
00?o09gooookJ_oonfX0=_oonfX3o`00O`Cooo]Z1ol007l7oookJPCo00006ooonfX00omW0?oooo]Z
oookJP0BoookJP03ool0GOoonf[ooo]Z00kooo]Z00?o``3ooookJ_oonfX03?oonfX01?nI0?oooo]Z
oookJ_m^0?l@oookJP03o`3o2ooonf[ooo]Z00cooo]Z00?o08gooookJ_oonfX02OoonfX00oooV@3o
oo]ZoookJP07oookJP03o`18oooonf[ooo]Z01Gooo]Z00CoH?l0oookJ_oonf[ooi000ooonfX00ooo
0:3ooo]ZoookJP02oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l01OoonfX00ombo`3ooo]ZoookJP02
oookJP04o`H0oooonf[oG_l0ool09Pcooo]Z00Ko0=oooookJ_oonf[ooo]Zool0hOoo0;^hoookJP03
oe7o0?oonf[ooo]Z00;ooo]Z00?ook40oookJ_oonfX03ooonfX00ol0WOoooo]ZoookJP0eoookJP?o
001o1?oonfX7o`00O`Oooo]Z1?l0000LoookJP03ofL0oooonf[ooo]Z017ooo]Z00?oo`1MoookJ_oo
nfX03_oonfX00oo30?oooo]ZoookJP0=oookJP04oiT0oooonf[ooo]Zofh0o`oooo]Z00?o0?l;oook
J_oonfX03?oonfX00ol0SOoooo]ZoookJP09oookJP03oonI0?oonf[ooo]Z00Oooo]Z00?o04Sooook
J_oonfX05OoonfX01OmPo`3ooo]ZoookJ_ooG`3ooi0000;ooo]Z00?oo`2PoookJ_oonfX00ooonfX0
1Ooo08_ooo]ZoookJ_oonf[o_03o00Gooo]Z00GoL_l0oookJ_oonf[ooo]Zo`H0o`02oookJP03oeko
0?oo02Kooo]Z00[ooo]Z00Oo0=oooookJ_oonf[ooo]Zool0hOoonf[oo`2k02Cooo]Z002CoookJP05
oomi0?oonf[ooo]ZoookJ_mAo`001?oonfX00ooo/@3ooo]ZoookJP0>oookJP03o`2Moooonf[ooo]Z
03Kooo]Z0ol007l4oookJPKo001o2?oonfX4o`0001[ooo]Z00?oI`3ooookJ_oonfX04ooonfX00ooo
05gooo]ZoookJP0>oookJP03ol<0oooonf[ooo]Z00cooo]Z00CoV@3ooookJ_oonf[oKP3o3ooonfX0
0ol0o`_ooo]ZoookJP0<oookJP03o`2=oooonf[ooo]Z00Wooo]Z00?ooiT0oookJ_oonfX01ooonfX0
0ol0B?oooo]ZoookJP0EoookJP04of3o0?oonf[ooo]Zoon@00?ooo]Z00?oo`2PoookJ_oonfX00_oo
nfX01Ooo08_ooo]ZoookJ_oonf[o_03o00Gooo]Z00?oL_l0oookJ_oonfX00_oonfX01?l60?oooo]Z
oeko0?oo02H<oookJP06o`3Ooooonf[ooo]ZoookJ_oo0>7oo`2k^_oonfX00omAo`3ooo]ZoookJP02
oookJP03oona0?oonf[ooo]Z00kooo]Z00?o09gooookJ_oonfX0=OoonfX3o`00O`Cooo]Z1_l007l8
oookJPCo00006ooonfX00omW0?oooo]ZoookJP0BoookJP03ool0GOoonf[ooo]Z00kooo]Z00?o``3o
oookJ_oonfX03?oonfX01?nI0?oooo]ZoookJ_m^0?l?oookJP03o`3o2ooonf[ooo]Z00cooo]Z00?o
08gooookJ_oonfX02OoonfX00oooV@3ooo]ZoookJP07oookJP03o`18oooonf[ooo]Z01Gooo]Z00Go
H?l0oookJ_oonf[ooel0oon@0002oookJP03ool0X?oonf[ooo]Z00?ooo]Z00Goo`2;oookJ_oonf[o
oo]Zok`0o`05oookJP05og;o0?oonf[ooo]ZoookJ_l60?l00_oonfX00omNo`3oo`0VoookJP0:oook
JP07o`3Ooooonf[ooo]ZoookJ_oo0>7ooo]Zool0^`0UoookJP00V?oonfX01OmAo`3ooo]ZoookJ_oo
nf[ook40017ooo]Z00?oogT0oookJ_oonfX0<_oonfX6o`00O`Cooo]Z0_l007l<oookJPCo00006_oo
nfX00omW0?oooo]ZoookJP0BoookJP03ool0GOoonf[ooo]Z00kooo]Z00?o``3ooookJ_oonfX03?oo
nfX01?nI0?oooo]ZoookJ_m^0?l?oookJP03o`3o2ooonf[ooo]Z00cooo]Z00?o08gooookJ_oonfX0
2OoonfX00oooV@3ooo]ZoookJP07oookJP03o`18oooonf[ooo]Z01Gooo]Z00CoH?l0oookJ_oonf[o
oi000ooonfX00ooo0:3ooo]ZoookJP02oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l01OoonfX00omb
o`3ooo]ZoookJP02oookJP04o`H0oooonf[oG_l0ool09Pcooo]Z00Ko0=oooookJ_oonf[ooo]Zool0
hOoo0;^loookJP05oe7o0?oonf[ooo]ZoookJ_oo/@004OoonfX00ol0WOoooo]ZoookJP0aoookJPKo
001o1?oonfX2o`00O`cooo]Z1?l0000JoookJP03ofL0oooonf[ooo]Z01;ooo]Z00?oo`1MoookJ_oo
nfX03_oonfX00oo30?oooo]ZoookJP0=oookJP04oiT0oooonf[ooo]Zofh0o`oooo]Z00?o0?l;oook
J_oonfX02ooonfX00ol0SOoooo]ZoookJP09oookJP03oonI0?oonf[ooo]Z00Oooo]Z00?o04Sooook
J_oonfX05OoonfX01OmPo`3ooo]ZoookJ_ooG`3ooi0000;ooo]Z00?oo`2PoookJ_oonfX00ooonfX0
1Ooo08_ooo]ZoookJ_oonf[o_03o00Gooo]Z00GoL_l0oookJ_oonf[ooo]Zo`H0o`02oookJP03oeko
0?oo02Kooo]Z00[ooo]Z00Oo0=oooookJ_oonf[ooo]Zool0hOoonf[oo`2k02Kooo]Z002IoookJP05
oe7o0?oonf[ooo]ZoookJ_oo/@004?oonfX00oooN@3ooo]ZoookJP0boookJPKo001o1?oonfX2o`00
O`cooo]Z1?l0000JoookJP03ofL0oooonf[ooo]Z017ooo]Z00?oo`1MoookJ_oonfX03_oonfX00oo3
0?oooo]ZoookJP0<oookJP04oiT0oooonf[ooo]Zofh0o`oooo]Z00?o0?l;on/0oooonfX03?oonfX0
0ol0SOoooo]ZoookJP09oookJP03oonI0?oonf[ooo]Z00Oooo]Z00?o04SooookJ_oonfX05OoonfX0
1?mPo`3ooo]ZoookJ_ooT003oookJP03ool0X?oonf[ooo]Z00;ooo]Z00Goo`2;oookJ_oonf[ooo]Z
ok`0o`05oookJP03og;o0?oonf[ooo]Z00;ooo]Z00Co1P3ooookJ_mNo`3oo`0V3?oonfX01_l0gooo
oo]ZoookJ_oonf[oo`3Qool0^kkooo]Z00GoDOl0oookJ_oonf[ooo]Zoona000@oookJP03o`2Moooo
nf[ooo]Z037ooo]Z1_l007l4oookJP;o001o3?oonfX4o`0001[ooo]Z00?oI`3ooookJ_oonfX04Ooo
nfX00ooo05gooo]ZoookJP0>oookJP03ol<0oooonf[ooo]Z00gooo]Z00CoV@3ooookJ_oonf[oKP3o
3ooonfX00ol0o`_ooo]ZoookJP0;oookJP03o`2=oooonf[ooo]Z00Wooo]Z00?ooiT0oookJ_oonfX0
1ooonfX00ol0B?oooo]ZoookJP0EoookJP05of3o0?oonf[ooo]ZoomO0?ooT0000_oonfX00ooo0:3o
oo]ZoookJP03oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l01OoonfX01Ombo`3ooo]ZoookJ_oonf[o
1P3o00;ooo]Z00?oG_l0ool09_oonfX02_oonfX01ol0gooooo]ZoookJ_oonf[oo`3QoookJ_oo0;/0
9ooonfX009[ooo]Z00GoDOl0oookJ_oonf[ooo]Zoona000?oookJP;oogT0=OoonfX4o`00O`Gooo]Z
1ol007l6oookJPCo00006OoonfX00omW0?oooo]ZoookJP0BoookJP03ool0GOoonf[ooo]Z00kooo]Z
00?o``3ooookJ_oonfX03?oonfX01?nI0?oooo]ZoookJ_m^0?l?oookJP03o`3o2ooonf[ooo]Z00co
oo]Z00?o08gooookJ_oonfX02?oonfX00oooV@3ooo]ZoookJP07oookJP03o`18oooonf[ooo]Z01Go
oo]Z00CoH?l0oookJ_oonf[ooi001?oonfX01Ooo0:3ooo]ZoookJ_oonf[oo`2;00?ooo]Z00?o_03o
oookJ_oonfX00ooonfX00ombo`3ooo]ZoookJP02oookJP04o`H0oooonf[oG_l0ool09Pcooo]Z00Ko
0=oooookJ_oonf[ooo]Zool0hOoo0;_0oookJP05oe7o0?oonf[ooo]ZoookJ_oo/@004?oonfX00ol0
WOoooo]ZoookJP0boookJPCo001o1OoonfX7o`00O`Kooo]Z1?l0000IoookJP03ofL0oooonf[ooo]Z
01;ooo]Z00?oo`1MoookJ_oonfX03_oonfX00oo30?oooo]ZoookJP0<oookJP04oiT0oooonf[ooo]Z
ofh0o`oooo]Z00?o0?l;oookJ_oonfX03?oonfX00ol0SOoooo]ZoookJP08oookJP03oonI0?oonf[o
oo]Z00Oooo]Z00?o04SooookJ_oonfX05OoonfX01OmPo`3ooo]ZoookJ_ooG`3ooi0000?ooo]Z00?o
o`2PoookJ_oonfX00_oonfX01Ooo08_ooo]ZoookJ_oonf[o_03o00Gooo]Z00GoL_l0oookJ_oonf[o
oo]Zo`H0o`02oookJP03oeko0?oo02Kooo]Z00[ooo]Z00Oo0=oooookJ_oonf[ooo]Zool0hOoonf[o
o`2k02Sooo]Z002JoookJP03oe7o0?oonf[ooo]Z00;ooo]Z00?ook40oookJ_oonfX03OoonfX2oomi
03Gooo]Z0ol007l5oookJPOo001o1_oonfX4o`0001Wooo]Z00?oI`3ooookJ_oonfX04OoonfX00ooo
05gooo]ZoookJP0>oookJP03ol<0oooonf[ooo]Z00cooo]Z00CoV@3ooookJ_oonf[oKP3o3ooonfX0
0ol0o`_ooo]ZoookJP0<oookJP03o`2=oooonf[ooo]Z00Wooo]Z00?ooiT0oookJ_oonfX01_oonfX0
0ol0B?oooo]ZoookJP0EoookJP04of3o0?oonf[ooo]Zoon@00Cooo]Z00Goo`2PoookJ_oonf[ooo]Z
ool0R`03oookJP03ok`0oooonf[ooo]Z00?ooo]Z00?oL_l0oookJ_oonfX00_oonfX01?l60?oooo]Z
oeko0?oo02H<oookJP06o`3Ooooonf[ooo]ZoookJ_oo0>7oo`2k`OoonfX00omAo`3ooo]ZoookJP02
oookJP03oona0?oonf[ooo]Z00gooo]Z00?o09gooookJ_oonfX0<ooonfX3o`00O`Gooo]Z1ol007l6
oookJPCo00006OoonfX00omW0?oooo]ZoookJP0AoookJP03ool0GOoonf[ooo]Z00kooo]Z00?o``3o
oookJ_oonfX03OoonfX01?nI0?oooo]ZoookJ_m^0?l>oookJP03o`3o2ooonf[ooo]Z00cooo]Z00?o
08gooookJ_oonfX02OoonfX00oooV@3ooo]ZoookJP06oookJP03o`18oooonf[ooo]Z01Gooo]Z00Go
H?l0oookJ_oonf[ooel0oon@0003oookJP03ool0X?oonf[ooo]Z00;ooo]Z00Goo`2;oookJ_oonf[o
oo]Zok`0o`05oookJP05og;o0?oonf[ooo]ZoookJ_l60?l00_oonfX00omNo`3oo`0VoookJP0:oook
JP07o`3Ooooonf[ooo]ZoookJ_oo0>7ooo]Zool0^`0YoookJP00;OoonfX2ooo906cooo]Z00?oDOl0
oookJ_oonfX00_oonfX00ooo/@3ooo]ZoookJP0<oookJP?oogT0BOoonfX4o`0001Sooo]Z00?oI`3o
oookJ_oonfX04_oonfX00ooo05gooo]ZoookJP0=oookJP03ol<0oooonf[ooo]Z00cooo]Z00CoV@3o
oookJ_oonf[oKP3o3ooonfX00ol0o`_ooo]ZoookJP0<oookJP03o`2=oooonf[ooo]Z00Wooo]Z00?o
oiT0oookJ_oonfX01ooonfX00ol0B?oooo]ZoookJP0DoookJP04of3o0?oonf[ooo]Zoon@00Cooo]Z
00?oo`2PoookJ_oonfX00_oonfX01?oo08_ooo]ZoookJ_nl0?l5oookJP03og;o0?oonf[ooo]Z00;o
oo]Z00Co1P3ooookJ_mNo`3oo`0V3?oonfX01_l0gooooo]ZoookJ_oonf[oo`3Qool0^`Cooo]Z0_ni
0?nmoookJP05oe7o0?oonf[ooo]ZoookJ_oo/@004?oonfX00ol0WOoooo]ZoookJP17oookJPCo0000
6?oonfX00omW0?oooo]ZoookJP0BoookJP03ool0GOoonf[ooo]Z00gooo]Z00?o``3ooookJ_oonfX0
3OoonfX01?nI0?oooo]ZoookJ_m^0?l?oookJP03o`3o2ooonf[ooo]Z00_ooo]Z00?o08gooookJ_oo
nfX02OoonfX00oooV@3ooo]ZoookJP07oookJP03o`18oooonf[ooo]Z01Cooo]Z00GoH?l0oookJ_oo
nf[ooel0oon@0003oookJP03ool0X?oonf[ooo]Z00?ooo]Z00Coo`2;oookJ_oonf[o_03o1OoonfX0
1Ombo`3ooo]ZoookJ_oonf[o1P3o00;ooo]Z00?oG_l0ool09_oonfX02_oonfX01ol0gooooo]Zoook
J_oonf[oo`3QoookJ_oo0;/01?oonfX2okT0obCooo]Z000ZoookJPGoolT0KOoonfX00omAo`3ooo]Z
oookJP02oookJP03oona0?oonf[ooo]Z00_ooo]Z1?ooN@18oookJPCo00006?oonfX00omW0?oooo]Z
oookJP0AoookJP03ool0GOoonf[ooo]Z00kooo]Z00?o``3ooookJ_oonfX03?oonfX01?nI0?oooo]Z
oookJ_m^0?l>oookJP03o`3o2ooonf[ooo]Z00cooo]Z00?o08gooookJ_oonfX02OoonfX00oooV@3o
oo]ZoookJP07oookJP03o`18oooonf[ooo]Z01Cooo]Z00CoH?l0oookJ_oonf[ooi001?oonfX00ooo
0:3ooo]ZoookJP02oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l01?oonfX00ombo`3ooo]ZoookJP02
oookJP04o`H0oooonf[oG_l0ool09Pcooo]Z00Ko0=oooookJ_oonf[ooo]Zool0hOoo0;/4oookJP03
okT0oooonf[ooo]Z0;kooo]Z00GoDOl0oookJ_oonf[ooo]Zoona000?oookJP03o`2Moooonf[ooo]Z
04Oooo]Z1?l0000HoookJP03ofL0oooonf[ooo]Z017ooo]Z00?oo`1MoookJ_oonfX03_oonfX00oo3
0?oooo]ZoookJP0<oookJP04oiT0oooonf[ooo]Zofh0o`oooo]Z00?o0?l;oookJ_oonfX02ooonfX0
0ol0SOoooo]ZoookJP09oookJP03oonI0?oonf[ooo]Z00Oooo]Z00?o04SooookJ_oonfX05?oonfX0
1OmPo`3ooo]ZoookJ_oonf[ooi0000?ooo]Z00?oo`2PoookJ_oonfX00ooonfX01Ooo08_ooo]Zoook
J_oonf[o_03o00Cooo]Z00GoL_l0oookJ_oonf[ooo]Zo`H0o`02oookJP03oeko0?oo02Kooo]Z00[o
oo]Z00Oo0=oooookJ_oonf[ooo]Zool0hOoonf[oo`2k00Cooo]Z00?o^@3ooookJ_oonfX09?oonfX0
02[ooo]Z1Ooob@1^oookJP03oe7o0?oonf[ooo]Z00;ooo]Z00?ook40oookJ_oonfX02_oonfX5oomi
04Oooo]Z1?l0000GoookJP03ofL0oooonf[ooo]Z017ooo]Z00?oo`1MoookJ_oonfX03_oonfX00oo3
0?oooo]ZoookJP0<oookJP04oiT0oooonf[ooo]Zofh0o`kooo]Z00?o0?l;on/0oooonfX03?oonfX0
0ol0SOoooo]ZoookJP09oookJP03oonI0?oonf[ooo]Z00Oooo]Z00?o04SooookJ_oonfX05?oonfX0
1?mPo`3ooo]ZoookJ_ooT004oookJP03ool0X?oonf[ooo]Z00;ooo]Z00Goo`2;oookJ_oonf[ooo]Z
ok`0o`04oookJP03og;o0?oonf[ooo]Z00;ooo]Z00Co1P3ooookJ_mNo`3oo`0V3?oonfX01_l0gooo
oo]ZoookJ_oonf[oo`3Qool0^`Cooo]Z00Co^@3ooookJ_oonf[oFol0_ooonfX01OmAo`3ooo]Zoook
J_oonf[ook4000kooo]Z00?o09gooookJ_oonfX0AooonfX4o`0001Oooo]Z00?oI`3ooookJ_oonfX0
4OoonfX00ooo05gooo]ZoookJP0>oookJP03ol<0oooonf[ooo]Z00cooo]Z00CoV@3ooookJ_oonf[o
KP3o3ooonfX00ol0o`_ooo]ZoookJP0;oookJP03o`2=oooonf[ooo]Z00Wooo]Z00?ooiT0oookJ_oo
nfX01ooonfX00ol0B?oooo]ZoookJP0DoookJP05of3o0?oonf[ooo]ZoookJ_ooT0000ooonfX00ooo
0:3ooo]ZoookJP03oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l01?oonfX01Ombo`3ooo]ZoookJ_oo
nf[o1P3o00;ooo]Z00?oG_l0ool09_oonfX02_oonfX01ol0gooooo]ZoookJ_oonf[oo`3QoookJ_oo
0;/01?oonfX01?ni0?oooo]ZoookJ_mKo`0ToookJP00:_oonfX5ooo906oooo]Z00?oDOl0oookJ_oo
nfX00_oonfX00ooo/@3ooo]ZoookJP09oookJPGoogT0AooonfX4o`0001Oooo]Z00?oI`3ooookJ_oo
nfX04OoonfX00ooo05gooo]ZoookJP0=oookJP03ol<0oooonf[ooo]Z00cooo]Z00CoV@3ooookJ_oo
nf[oKP3o3_oonfX00ol0o`_oj`3ooookJP0=oookJP03o`2=oooonf[ooo]Z00Sooo]Z00?ooiT0oook
J_oonfX01ooonfX00ol0B?oooo]ZoookJP0DoookJP05of3o0?oonf[ooo]ZoomO0?ooT0000ooonfX0
0ooo0:3ooo]ZoookJP02oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l01?oonfX00ombo`3ooo]Zoook
JP02oookJP04o`H0oooonf[oG_l0ool09Pcooo]Z00Ko0=oooookJ_oonf[ooo]Zool0hOoo0;/4oook
JP05okT0oooonf[ooo]ZoookJ_mKo`00`?oonfX01OmAo`3ooo]ZoookJ_oonf[ook4000kooo]Z00?o
09gooookJ_oonfX0A_oonfX4o`0001Oooo]Z00?oI`3ooookJ_oonfX04OoonfX00ooo05gooo]Zoook
JP0=oookJP03ol<0oooonf[ooo]Z00gooo]Z00CoV@3ooookJ_oonf[oKP3o3_oonfX00ol0o`_ooo]Z
oookJP0<oookJP03o`2=oooonf[ooo]Z00Sooo]Z00?ooiT0oookJ_oonfX01ooonfX00ol0B?oooo]Z
oookJP0EoookJP05of3o0?oonf[ooo]ZoomO0?ooT0000_oonfX00ooo0:3ooo]ZoookJP03oookJP05
ool0Rooonf[ooo]ZoookJ_nl0?l01?oonfX01Ombo`3ooo]ZoookJ_oonf[o1P3o00;ooo]Z00?oG_l0
ool09_oonfX02_oonfX01ol0gooooo]ZoookJ_oonf[oo`3QoookJ_oo0;/01?oonfX01?ni0?oooo]Z
oookJ_mKo`0UoookJP00:_oonfX<ooo901OoobH0D_oonfX01OmAo`3ooo]ZoookJ_oonf[ook4000co
oo]Z1OooN@16oookJPCo00005_oonfX00omW0?oooo]ZoookJP0AoookJP03ool0GOoonf[ooo]Z00ko
oo]Z00?o``3ooookJ_oonfX03?oonfX01?nI0?oooo]ZoookJ_m^0?l>oookJP03o`3o2ooonf[ooo]Z
00cooo]Z00?o08gooookJ_oonfX02?oonfX00oooV@3ooo]ZoookJP07oookJP03o`18oooonf[ooo]Z
01Cooo]Z00GoH?l0oookJ_oonf[ooel0oon@0003oookJP03ool0X?oonf[ooo]Z00;ooo]Z00Goo`2;
oookJ_oonf[ooo]Zok`0o`04oookJP03og;o0?oonf[ooo]Z00;ooo]Z00Co1P3ooookJ_mNo`3oo`0V
3?oonfX01_l0gooooo]ZoookJ_oonf[oo`3Qool0^`Cooo]Z00?o^@3ooookJ_oonfX00_mKo`1<oook
JR?oobH0DooonfX01?mAo`3ooo]ZoookJ_oo/@0>oookJP03o`2Moooonf[ooo]Z04Kooo]Z1?l0000F
oookJP03ofL0oooonf[ooo]Z017ooo]Z00?oo`1MoookJ_oonfX03_oonfX00oo30?oooo]ZoookJP0<
oookJP04oiT0oooonf[ooo]Zofh0o`oooo]Z00?o0?l;oookJ_oonfX02ooonfX00ol0SOoooo]Zoook
JP08oookJP03oonI0?oonf[ooo]Z00Oooo]Z00?o04SooookJ_oonfX05OoonfX01OmPo`3ooo]Zoook
J_ooG`3ooi0000;ooo]Z00?oo`2PoookJ_oonfX00ooonfX01Ooo08_ooo]ZoookJ_oonf[o_03o00Co
oo]Z00GoL_l0oookJ_oonf[ooo]Zo`H0o`02oookJP03oeko0?oo02Kooo]Z00[ooo]Z00Oo0=oooook
J_oonf[ooo]Zool0hOoonf[oo`2k00Cooo]Z00Co^@3ooookJ_mKo`3oFol09_oonfX002[ooo]Z1_oo
b@0MoookJPSoobH0BooonfX01OmAo`3ooo]ZoookJ_oonf[ook4000_ooo]Z1_ooN@15oookJPGo0000
5OoonfX00omW0?oooo]ZoookJP0AoookJP03ool0GOoonf[ooo]Z00gooo]Z00?o``3ooookJ_oonfX0
3?oonfX01?nI0?oooo]ZoookJ_m^0?l>oookJP03o`3o2ooonf[ooo]Z00cooo]Z00?o08gooookJ_oo
nfX02?oonfX00oooV@3ooo]ZoookJP07oookJP03o`18oooonf[ooo]Z01Cooo]Z00GoH?l0oookJ_oo
nf[ooel0oon@0003oookJP03ool0X?oonf[ooo]Z00;ooo]Z00Goo`2;oookJ_oonf[ooo]Zok`0o`04
oookJP03og;o0?oonf[ooo]Z00;ooo]Z00Co1P3ooookJ_mNo`3oo`0V3?oonfX01_l0gooooo]Zoook
J_oonf[oo`3Qool0^`Cooo]Z00Co^@3ooookJ_oonf[oFol0LOoonfX9oolV04_ooo]Z00CoDOl0oook
J_oonf[ook403_oonfX00ol0WOoooo]ZoookJP15oookJPGo00005OoonfX00omW0?oooo]ZoookJP0A
oookJP03ool0GOoonf[ooo]Z00gooo]Z00?o``3ooookJ_oonfX03?oonfX01?nI0?oooo]ZoookJ_m^
0?l?oookJP03o`3o2ooonf[ooo]Z00_ooo]Z00?o08gooookJ_oonfX02?oonfX00oooV@3ooo]Zoook
JP07oookJP03o`18oooonf[ooo]Z01Gooo]Z00GoH?l0oookJ_oonf[ooel0oon@0002oookJP03ool0
X?oonf[ooo]Z00?ooo]Z00Goo`2;oookJ_oonf[ooo]Zok`0o`04oookJP05og;o0?oonf[ooo]Zoook
J_l60?l00_oonfX00omNo`3oo`0VoookJP0:oookJP07o`3Ooooonf[ooo]ZoookJ_oo0>7ooo]Zool0
^`04oookJP03okT0oooonf[oFol002Sooo]Z000ZoookJPKoolT09OoonfX7oolV04Gooo]Z00GoDOl0
oookJ_oonf[ooo]Zoona000:oookJPOoogT0A?oonfX4o`0001Gooo]Z00?oI`3ooookJ_oonfX04Ooo
nfX00ooo05gooo]ZoookJP0=oookJP03ol<0oooonf[ooo]Z00cooo]Z00CoV@3ooookJ_oonf[oKP3o
3_oonfX00ol0o`_ooo]ZoookJP0<oookJP03o`2=oooonf[ooo]Z00Wooo]Z00?ooiT0oookJ_oonfX0
1_oonfX00ol0B?oooo]ZoookJP0DoookJP05of3o0?oonf[ooo]ZoomO0?ooT0000ooonfX00ooo0:3o
oo]ZoookJP02oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l00ooonfX2onGo00Cooo]Z00Co1P3ooook
J_mNo`3oo`0V3?oonfX01_l0gooooo]ZoookJ_oonf[oo`3Qool0^`Cooo]Z00Co^@3ooookJ_oonf[o
Fol0NooonfX7oolV04Gooo]Z00CoDOl0oookJ_oonf[ook403OoonfX00ol0WOoooo]ZoookJP15oook
JPCo00005_oonfX00omW0?oooo]ZoookJP0@oookJP03ool0GOoonf[ooo]Z00gooo]Z00?o``3ooook
J_oonfX03OoonfX01?nI0?oooo]ZoookJ_m^0?l>oookJP03o`3o2ooonf[ooo]Z00_ooo]Z00?o08go
oookJ_oonfX02OoonfX00oooV@3ooo]ZoookJP06oookJP03o`18oooonf[ooo]Z01Gooo]Z00GoH?l0
oookJ_oonf[ooel0oon@0002oookJP03ool0X?oonf[ooo]Z00?ooo]Z00Goo`2;oookJ_oonf[ooo]Z
ok`0o`04oookJP05og;o0?oonf[ooo]ZoookJ_l60?l00_oonfX00omNo`3oo`0VoookJP0:oookJP07
o`3Ooooonf[ooo]ZoookJ_oo0>7ooo]Zool0^`04oookJP03okT0oooonf[oFol002Wooo]Z000Zoook
JPKoolT0;?oonfX5oolV043ooo]Z00?oDOl0oookJ_oonfX00_oonfX00ooo/@3ooo]ZoookJP07oook
JPSoogT0@ooonfX4o`0001Gooo]Z00?oI`3ooookJ_oonfX04OoonfX00ooo05gooo]ZoookJP0=oook
JP03ol<0oooonf[ooo]Z00cooo]Z00CoV@3ooookJ_oonf[oKP3o3OoonfX00ol0o`_oj`3ooookJP0<
oookJP03o`2=oooonf[ooo]Z00Wooo]Z00?ooiT0oookJ_oonfX01ooonfX00ol0B?oooo]ZoookJP0C
oookJP05of3o0?oonf[ooo]ZoomO0?ooT0000ooonfX00ooo0:3ooo]ZoookJP02oookJP05ool0Rooo
nf[ooo]ZoookJ_nl0?l00ooonfX3onGo00?ooo]Z00Co1P3ooookJ_mNo`3oo`0V3?oonfX01_l0gooo
oo]ZoookJ_oonf[oo`3Qool0^`Cooo]Z00Co^@3ooookJ_oonf[oFol0PooonfX5oolV043ooo]Z00Go
DOl0oookJ_oonf[ooo]Zoona000=oookJP03o`2Moooonf[ooo]Z04Cooo]Z1?l0000EoookJP03ofL0
oooonf[ooo]Z017ooo]Z00?oo`1MoookJ_oonfX03OoonfX00oo30?oooo]ZoookJP0<oookJP04oiT0
oooonf[ooo]Zofh0o`kooo]Z00?o0?l;oookJ_oonfX02ooonfX00ol0SOoooo]ZoookJP09oookJP03
oonI0?oonf[ooo]Z00Oooo]Z00?o04SooookJ_oonfX05?oonfX01OmPo`3ooo]ZoookJ_ooG`3ooi00
00;ooo]Z00?oo`2PoookJ_oonfX00ooonfX01Ooo08_ooo]ZoookJ_oonf[o_03o00Gooo]Z00CoL_l0
oookJ_oonf[o1P3o0_oonfX00omNo`3oo`0VoookJP0:oookJP07o`3Ooooonf[ooo]ZoookJ_oo0>7o
oo]Zool0^`04oookJP03okT0oooonf[oFol002[ooo]Z000^oookJP;oolT0<OoonfX5oolV03cooo]Z
00GoDOl0oookJ_oonf[ooo]Zoona0009oookJPWoogT0@_oonfX4o`0001Cooo]Z00?oI`3ooookJ_oo
nfX04OoonfX00ooo05gooo]ZoookJP0=oookJP03ol<0oooonf[ooo]Z00cooo]Z00CoV@3ooookJ_oo
nf[oKP3o3_oonfX00ol0o`_ooo]ZoookJP0;oookJP03o`2=oooonf[ooo]Z00Wooo]Z00?ooiT0oook
J_oonfX01ooonfX00ol0B?oooo]ZoookJP0CoookJP05of3o0?oonf[ooo]ZoomO0?ooT0000ooonfX0
0ooo0:3ooo]ZoookJP02oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l00_oonfX4onGo00?ooo]Z00Go
1P3ooookJ_mNo`3o037oool09P0;oookJP06o`3Ooooonf[ooo]ZoookJ_oo0>7oo`2k1?oonfX01?ni
0?oooo]ZoookJ_mKo`29oookJPGoobH0??oonfX01?mAo`3ooo]ZoookJ_oo/@0=oookJP03o`2Moooo
nf[ooo]Z04Cooo]Z1?l0000EoookJP03ofL0oooonf[ooo]Z013ooo]Z00?oo`1MoookJ_oonfX03Ooo
nfX00oo30?oooo]ZoookJP0<oookJP04oiT0oooonf[ooo]Zofh0o`oooo]Z00?o0?l;oookJ_oonfX0
2_oonfX00ol0SOoooo]ZoookJP09oookJP03oonI0?oonf[ooo]Z00Oooo]Z00?o04SooookJ_oonfX0
5?oonfX01OmPo`3ooo]ZoookJ_ooG`3ooi0000;ooo]Z00?oo`2PoookJ_oonfX00ooonfX01Ooo08_o
oo]ZoookJ_oonf[o_03o00Gooo]Z00CoL_l0oookJ_oonf[o1P3o0_oonfX00omNo`3oo`0VoookJP0:
oookJP07o`3Ooooonf[ooo]ZoookJ_oo0>7ooo]Zool0^`04oookJP03okT0oooonf[oFol002_ooo]Z
001VoookJPCoobH0>OoonfX01OmAo`3ooo]ZoookJ_oonf[ook4000Wooo]Z1_ooN@14oookJPCo0000
5?oonfX00omW0?oooo]ZoookJP0AoookJP03ool0GOoonf[ooo]Z00cooo]Z00?o``3ooookJ_oonfX0
3?oonfX01?nI0?oooo]ZoookJ_m^0?l>oookJP03o`3o2ooonf[ooo]Z00cooo]Z00?o08gooookJ_oo
nfX02?oonfX00oooV@3ooo]ZoookJP07oookJP03o`18oooonf[ooo]Z01?ooo]Z00GoH?l0oookJ_oo
nf[ooel0oon@0003oookJP03ool0X?oonf[ooo]Z00;ooo]Z00Goo`2;oookJ_oonf[ooo]Zok`0o`02
oookJPGoiOl00_oonfX01Ol60?oooo]Zoeko0?l0<Oooo`0V00_ooo]Z00Ko0=oooookJ_oonf[ooo]Z
ool0hOoo0;/4oookJP04okT0oooonf[ooo]Zoe_o08oooo]Z1?oo9P0ioookJP04oe7o0?oonf[ooo]Z
oona00gooo]Z00?o09gooookJ_oonfX0@ooonfX4o`0001Cooo]Z00?oI`3ooookJ_oonfX04OoonfX0
0ooo05gooo]ZoookJP0<oookJP03ol<0oooonf[ooo]Z00cooo]Z00CoV@3ooookJ_oonf[oKP3o3ooo
nfX00ol0o`_ooo]ZoookJP0;oookJP03o`2=oooonf[ooo]Z00Sooo]Z00?ooiT0oookJ_oonfX01ooo
nfX00ol0B?oooo]ZoookJP0DoookJP05of3o0?oonf[ooo]ZoomO0?ooT0000_oonfX00ooo0:3ooo]Z
oookJP03oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l01OoonfX01?mbo`3ooo]ZoookJ_l60?l2oook
JP03oeko0?oo02Kooo]Z00[ooo]Z00Oo0=oooookJ_oonf[ooo]Zool0hOoonf[oo`2k00Cooo]Z00?o
^@3ooookJ_mKo`00;?oonfX006[ooo]Z0ooo9P0goookJP05oe7o0?oonf[ooo]ZoookJ_oo/@002?oo
nfX3oomi0003oookJ_l0WOoooo]Z04Cooo]Z1?l0000CoookJP03ofL0oooonf[ooo]Z017ooo]Z00?o
o`1MoookJ_oonfX03OoonfX00oo30?oooo]ZoookJP0<oookJP04oiT0oooonf[ooo]Zofh0o`gooo]Z
00?o0?l;oookJ_oonfX03?oonfX00ol0SOoooo]ZoookJP08oookJP03oonI0?oonf[ooo]Z00Oooo]Z
00?o04SooookJ_oonfX04ooonfX01OmPo`3ooo]ZoookJ_oonf[ooi0000?ooo]Z00?oo`2PoookJ_oo
nfX00_oonfX01_oo08_ooo]ZoookJ_oonf[o_03ooookJPKoiOl00_oonfX01Ol60?oooo]Zoeko0?l0
<Oooo`0V00_ooo]Z00Ko0=oooookJ_oonf[ooo]Zool0hOoo0;/4oookJP04okT0oooonf[ooo]Zoe_o
09Cooo]Z0ooo9P0goookJP04oe7o0?oonf[ooo]Zoona00cooo]Z00?o09gooookJ_oonfX0@ooonfX4
o`0001Cooo]Z00?oI`3ooookJ_oonfX04?oonfX00ooo05gooo]ZoookJP0=oookJP03ol<0oooonf[o
oo]Z00cooo]Z00CoV@3ooookJ_oonf[oKP3o3_oonfX00ol0o`_ooo]ZoookJP0;oookJP03o`2=oooo
nf[ooo]Z00Sooo]Z00?ooiT0oookJ_oonfX01ooonfX00ol0B?oooo]ZoookJP0DoookJP05of3o0?oo
nf[ooo]ZoookJ_ooT0000_oonfX00ooo0:3ooo]ZoookJP03oookJP05ool0Rooonf[ooo]ZoookJ_nl
0?l01OoonfX01?mbo`3ooo]ZoookJ_l60?l2oookJP03oeko0?oo02Kooo]Z00[ooo]Z00Oo0=oooook
J_oonf[ooo]Zool0hOoonf[oo`2k00Cooo]Z00?o^@3ooookJ_mKo`00;OoonfX006gooo]Z0ooo9P0e
oookJP05oe7o0?oonf[ooo]ZoookJ_oo/@001ooonfX01OooN@3ooo]ZoookJ_oonf[o09go04Gooo]Z
1?l0000CoookJP03ofL0oooonf[ooo]Z013ooo]Z00?oo`1MoookJ_oonfX03OoonfX00oo30?oooo]Z
oookJP0<oookJP04oiT0oooonf[ooo]Zofh0o`cooo]Z0_oo:0000ol0o`_ooo]ZoookJP0;oookJP03
o`2=oooonf[ooo]Z00Sooo]Z00?ooiT0oookJ_oonfX01ooonfX00ol0B?oooo]ZoookJP0CoookJP05
of3o0?oonf[ooo]ZoookJ_ooT0001?oonfX01Ooo0:3ooo]ZoookJ_oonf[oo`2;00?ooo]Z00?o_03o
oookJ_oUo`001_oUo`02oookJP04o`H0oomNo`3o037oool09P_ooo]Z00Ko0=oooookJ_oonf[ooo]Z
ool0hOoo0;/4oookJP04okT0oooonf[ooo]Zoe_o09Sooo]Z0ooo9P0eoookJP04oe7o0?oonf[ooo]Z
oona00_ooo]Z00?o09gooookJ_oonfX0@ooonfX4o`0001?ooo]Z00?oI`3ooookJ_oonfX04?oonfX0
0ooo05gooo]ZoookJP0=oookJP03ol<0oooonf[ooo]Z00cooo]Z00CoV@3ooookJ_oonf[oKP3o3_oo
nfX00ol0o`_ooo]ZoookJP0;oookJP03o`2=oooonf[ooo]Z00Sooo]Z00?ooiT0oookJ_oonfX01ooo
nfX00ol0B?oooo]ZoookJP0DoookJP05of3o0?oonf[ooo]ZoookJ_ooT0000ooonfX00ooo0:3ooo]Z
oookJP02oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l01OoonfX02?mbo`3ooo]ZoookJ_oonf[o1P3o
oookJ_mNo`3oo`0V2ooonfX01ol0gooooo]ZoookJ_oonf[oo`3QoookJ_oo0;/01?oonfX00oni0?oo
oo]Zoe_o000^oookJP00L?oonfX3oolV03?ooo]Z00CoDOl0oookJ_oonf[ook403?oonfX00ol0WOoo
oo]ZoookJP12oookJPCo00004_oonfX00omW0?oooo]ZoookJP0AoookJP03ool0GOoonf[ooo]Z00co
oo]Z00?o``3ooookJ_oonfX03?oonfX01?nI0?oooo]ZoookJ_m^0?l<oookJP;oobP000?o0?l;oook
J_oonfX02ooonfX00ol0SOoooo]ZoookJP08oookJP03oonI0?oonf[ooo]Z00Oooo]Z00?o04Sooook
J_oonfX04ooonfX01OmPo`3ooo]ZoookJ_oonf[ooi0000Cooo]Z00Goo`2PoookJ_oonf[ooo]Zool0
R`03oookJP03ok`0oooonf[oiOl000KoiOl00_oonfX2oolX0003o`0aoooo02Kooo]Z00[ooo]Z00Ko
0=oooookJ_oonf[ooo]Zool0hOoo0;/4oookJP04okT0oooonf[ooo]Zoe_o00Wooo]Z00?oogT0oook
J_oonfX0T?oonfX3oolV03?ooo]Z00?oDOl0oookJ_oo/@003?oonfX00ol0WOoooo]ZoookJP12oook
JPCo00004ooonfX00omW0?oooo]ZoookJP0@oookJP03ool0GOoonf[ooo]Z00cooo]Z00?o``3ooook
J_oonfX03?oonfX01?nI0?oooo]ZoookJ_m^0?l?oookJP03o`3o2ooonf[ooo]Z00[ooo]Z00?o08go
oookJ_oonfX02?oonfX00oooV@3ooo]ZoookJP07oookJP03o`18oooonf[ooo]Z01Cooo]Z00GoH?l0
oookJ_oonf[ooo]Zoon@0003oookJP03ool0X?oonf[ooo]Z00;ooo]Z00Goo`2;oookJ_oonf[ooo]Z
ok`0o`05oookJP08og;o0?oonf[ooo]ZoookJ_l60?oooo]Zoeko0?oo02H;oookJP07o`3Ooooonf[o
oo]ZoookJ_oo0>7ooo]Zool0^`04oookJP03okT0oooonf[oFol000[ooo]Z00?ooo80oookJ_oonfX0
8_oonfX007?ooo]Z1?oo9P0`oookJP04oe7o0?oonf[ooo]Zoona00_ooo]Z00?o09gooookJ_oonfX0
@_oonfX4o`0001;ooo]Z00?oI`3ooookJ_oonfX04?oonfX00ooo05gooo]ZoookJP0=oookJP03ol<0
oooonf[ooo]Z00cooo]Z00?oV@3ooookJ_m^0?l03?oonfX2oolX0003o`3o2ooonf[ooo]Z00[ooo]Z
0_oo:00;oookJP03oonI0?oonf[ooo]Z00Kooo]Z00?o04SooookJ_oonfX04_oonfX2oolX00?ooo]Z
00?ooi00oookJ_oonfX00_oonfX00ooo0:3ooo]ZoookJP02oookJP04ool0Rooonf[ooo]Zok`0o`Wo
iOl000Gooo]ZoolX0?oo:03oobP0ool09P0;oookJP06o`3Ooooonf[ooo]ZoookJ_oo0>7oo`2k1?oo
nfX01?ni0?oooo]ZoookJ_mKo`09oookJP03oomi0?oonf[ooo]Z09Cooo]Z0ooo9P0aoookJP03oe7o
0?oonf[ook4000_ooo]Z00?o09gooookJ_oonfX0@_oonfX4o`0001?ooo]Z00?oI`3ooookJ_oonfX0
3ooonfX00ooo05gooo]ZoookJP0=oookJP03ol<0oooonf[ooo]Z00cooo]Z00CoV@3ooookJ_oonf[o
KP3o3_oonfX00ol0o`_ooo]ZoookJP0:oookJP03o`2=oooonf[ooo]Z00Wooo]Z00?ooiT0oookJ_oo
nfX01ooonfX00ol0B?oooo]ZoookJP0CoookJP05of3o0?oonf[ooo]ZoookJ_ooT0000ooonfX00ooo
0:3ooo]ZoookJP02oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l01OoonfX02?mbo`3ooo]ZoookJ_oo
nf[o1P3ooookJ_l0<Oooo`0V2ooonfX01ol0gooooo]ZoookJ_oonf[oo`3QoookJ_oo0;/01?oonfX0
0oni0?oooo]Zoe_o000:oookJP03ooob0?oonf[ooo]Z02?ooo]Z001goookJP?oobH0;OoonfX01OmA
o`3ooo]ZoookJ_oonf[ook4000_ooo]Z00?o09gooookJ_oonfX0@OoonfX4o`00017ooo]Z00?oI`3o
oookJ_oonfX04OoonfX00ooo05gooo]ZoookJP0<oookJP03ol<0oooonf[ooo]Z00cooo]Z00CoV@3o
oookJ_oonf[oKP3o2ooonfX2oolX0003o`3o2ooo:03ooo]Z00[ooo]Z0ooo:00:oookJP03oonI0?oo
nf[ooo]Z00Kooo]Z00?o04SooookJ_oonfX04_oonfX3oolX00;ooo]Z00?ooi00oookJ_oonfX00_oo
nfX00ooo0:3ooo]ZoookJP02oookJP04ool0Rooonf[ooo]ZoookJPWoiOl01?oo:0000ooo02Kooo]Z
oookJP09oookJP06o`3Ooooonf[ooo]ZoookJ_oo0>7oo`2k1?oonfX01?ni0?oooo]ZoookJ_mKo`09
oookJP03oomi0?oonf[ooo]Z09Sooo]Z0ooo9P0^oookJP04oe7o0?oonf[ooo]Zoona00_ooo]Z00?o
09gooookJ_oonfX0@OoonfX4o`0001;ooo]Z00?oI`3ooookJ_oonfX04?oonfX00ooo05gooo]Zoook
JP0<oookJP03ol<0oooonf[ooo]Z00cooo]Z00CoV@3ooookJ_oonf[oKP3o3_oonfX00ol0o`_ooo]Z
oookJP0;oookJP03o`2=oooonf[ooo]Z00Sooo]Z00?ooiT0oookJ_oonfX01ooonfX00ol0B?oooo]Z
oookJP0DoookJP04of3o0?oonf[ooo]Zoon@00?ooo]Z00?oo`2PoookJ_oonfX00_oonfX01Ooo08_o
oo]ZoookJ_oonf[o_03o00Gooo]Z00SoL_l0oookJ_oonf[ooo]Zo`H0oooonf[o037oool09P_ooo]Z
00Go0=oooookJ_oonf[ooo]Zool0h@02ool0^`Cooo]Z00?o^@3ooookJ_mKo`002_oonfX00ooolP3o
oo]ZoookJP0ToookJP00N_oonfX3oolV02_ooo]Z00GoDOl0oookJ_oonf[ooo]Zoona000:oookJP03
o`2Moooonf[ooo]Z047ooo]Z1?l0000AoookJP03ofL0oooonf[ooo]Z013ooo]Z00?oo`1MoookJ_oo
nfX03OoonfX00oo30?oooo]ZoookJP0;oookJP04oiT0oooonf[ooo]Zofh0o`_ooo]Z0ooo:0000ol0
o`_oobP0oookJP09oookJP?oobP02_oonfX00oooV@3ooo]ZoookJP07oookJP03o`18oooonf[ooo]Z
013ooo]Z1?oo:002oookJP03oon@0?oonf[ooo]Z00;ooo]Z00?oo`2PoookJ_oonfX00_oonfX01?oo
08_ooo]ZoookJ_oonfX:onGo00?oobP000?oo`0VoookJ_oonfX02OoonfX01_l0gooooo]ZoookJ_oo
nf[oo`3Qool0^`Cooo]Z00Co^@3ooookJ_oonf[oFol02OoonfX01?ooN@3ooo]ZoookJ_n6o`2Koook
JP?oobH0;?oonfX01?mAo`3ooo]ZoookJ_oo/@0:oookJP03o`2Moooonf[ooo]Z047ooo]Z1?l0000B
oookJP03ofL0oooonf[ooo]Z00oooo]Z00?oo`1MoookJ_oonfX03OoonfX00oo30?oooo]ZoookJP0;
oookJP04oiT0oooonf[ooo]Zofh0o`kooo]Z00?o0?l;oookJ_oonfX02ooonfX00ol0SOoooo]Zoook
JP08oookJP03oonI0?oonf[ooo]Z00Oooo]Z00?o04SooookJ_oonfX05?oonfX01?mPo`3ooo]Zoook
J_ooT003oookJP03ool0X?oonf[ooo]Z00;ooo]Z00Goo`2;oookJ_oonf[ooo]Zok`0o`05oookJP08
og;o0?oonf[ooo]ZoookJ_l60?oooo]Zo`0aoooo02H;oookJP06o`3Ooooonf[ooo]ZoookJ_oo0>7o
o`2k1OoonfX00oni0?oooo]Zoe_o000:oookJP04ooob0?oonf[oQ_l0ohKo02Cooo]Z001moookJP?o
obH0:OoonfX01?mAo`3ooo]ZoookJ_oo/@0;oookJP03o`2Moooonf[ooo]Z043ooo]Z1?l0000@oook
JP03ofL0oooonf[ooo]Z017ooo]Z00?oo`1MoookJ_oonfX03?oonfX00oo30?oooo]ZoookJP0<oook
JP03oiT0oooonf[oKP3o00[ooo]Z1?oo:0000ol0o`_oobP0oookJP08oookJPGoobP02OoonfX00ooo
V@3ooo]ZoookJP07oookJP03o`18oooonf[ooo]Z013ooo]Z1Ooo:0000ooonf[ooel0oon@0003oook
JP03ool0X?oonf[ooo]Z00;ooo]Z00Goo`2;oookJ_oonf[ooo]Zok`0o`02oookJPOoiOl00ooo:000
0ooo02Kooo]ZoookJP09oookJP06o`3Ooooonf[ooo]ZoookJ_oo0>7oo`2k1?oonfX01?ni0?oooo]Z
oookJ_mKo`08oookJP;oogT00_oonfX00on6o`3ooo]ZoookJP2MoookJP?oobH0:_oonfX00omAo`3o
oo]Zoona000;oookJP03o`2Moooonf[ooo]Z043ooo]Z1?l0000AoookJP03ofL0oooonf[ooo]Z013o
oo]Z00?oo`1MoookJ_oonfX03?oonfX00oo30?oooo]ZoookJP0<oookJP04oiT0oooonf[ooo]Zofh0
o`gooo]Z00?o0?l;on/0oooonfX02ooonfX00ol0SOoooo]ZoookJP08oookJP03oonI0?oonf[ooo]Z
00Oooo]Z00?o04SooookJ_oonfX05?oonfX01OmPo`3ooo]ZoookJ_ooG`3ooi0000;ooo]Z00?oo`2P
oookJ_oonfX00_oonfX01Ooo08_ooo]ZoookJ_oonf[o_03o00Gooo]Z00SoL_l0oookJ_oonf[ooo]Z
o`H0oooonf[o037oool09P_ooo]Z00Ko0=oooookJ_oonf[ooo]Zool0hOoo0;/5oookJP03okT0oooo
nf[oFol000[ooo]Z00?ooo80oookJ_n6o`009_oonfX0083ooo]Z0_oo9P0XoookJP04oe7o0?oonf[o
oo]Zoona00[ooo]Z00?o09gooookJ_oonfX0@?oonfX4o`00013ooo]Z00?oI`3ooookJ_oonfX04?oo
nfX00ooo05gooo]ZoookJP0<oookJP03ol<0oooonf[ooo]Z00cooo]Z00?oV@3ooookJ_m^0?l02_oo
nfX4oolX0003o`3o2ooo:03oobP000Sooo]Z1Ooo:00:oookJP03oonI0?oonf[ooo]Z00Kooo]Z00?o
04SooookJ_oonfX03ooonfX6oolX0003oookJ_ooG`3ooi0000?ooo]Z00?oo`2PoookJ_oonfX00_oo
nfX01Ooo08_ooo]ZoookJ_oonf[o_03o00Cooo]Z1_oUo`02oolX0003ool09_oo:03ooo]Z00Wooo]Z
00Ko0=oooookJ_oonf[ooo]Zool0hOoo0;/4oookJP04okT0oooonf[ooo]Zoe_o00Sooo]Z00Gooo80
oomi0?oonf[ooo]ZohKo002SoookJP;oobH0:OoonfX00omAo`3ooo]Zoona000:oookJP03o`2Moooo
nf[ooo]Z043ooo]Z1?l0000AoookJP03ofL0oooonf[ooo]Z00oooo]Z00?oo`1MoookJ_oonfX03?oo
nfX00oo30?oooo]ZoookJP0<oookJP04oiT0oooonf[ooo]Zofh0o`kooo]Z00?o0?l;oookJ_oonfX0
2_oonfX00ol0SOoooo]ZoookJP09oookJP03oonI0?oonf[ooo]Z00Kooo]Z00?o04SooookJ_oonfX0
5?oonfX01OmPo`3ooo]ZoookJ_ooG`3ooi0000;ooo]Z00?oo`2PoookJ_oonfX00_oonfX01Ooo08_o
oo]ZoookJ_oonf[o_03o00Gooo]Z00SoL_l0oookJ_oonf[ooo]Zo`H0oooonf[o037oool09P_ooo]Z
00Ko0=oooookJ_oonf[ooo]Zool0hOoo0;/5oookJP03okT0oooonf[oFol000Wooo]Z0_oolP000ooo
nf[oQ_l0oookJP0VoookJP00P_oonfX2oolV02Kooo]Z00GoDOl0oookJ_oonf[ooo]Zoona000:oook
JP03o`2Moooonf[ooo]Z03oooo]Z1?l0000?oookJP03ofL0oooonf[ooo]Z017ooo]Z00?oo`1Moook
J_oonfX03?oonfX00oo30?oooo]ZoookJP0;oookJP04oiT0oooonf[ooo]Zofh0o`Wooo]Z1Ooo:000
0ol0o`_oobP0oookJP07oookJPKoobP02OoonfX00oooV@3ooo]ZoookJP06oookJP03o`18oooonf[o
oo]Z00oooo]Z1ooo:0000oooG`3ooi00oookJP02oookJP03ool0X?oonf[ooo]Z00;ooo]Z00Goo`2;
oookJ_oonf[ooo]Zok`0o`04oookJP03onGo0?oo:03oiOl000?oiOl00_oo:0000ooo02KoobP0oook
JP09oookJP06o`3Ooooonf[ooo]ZoookJ_oo0>7oo`2k1?oonfX01?ni0?oooo]ZoookJ_mKo`08oook
JP05ooob0?oonf[ooo]ZoookJ_n6o`00Y_oonfX2oolV02Oooo]Z00CoDOl0oookJ_oonf[ook402_oo
nfX00ol0WOoooo]ZoookJP0ooookJPCo00004?oonfX00omW0?oooo]ZoookJP0@oookJP03ool0GOoo
nf[ooo]Z00cooo]Z00?o``3ooookJ_oonfX03?oonfX00onI0?oooo]Zofh0o`0>oookJP03o`3o2ooo
nf[ooo]Z00_ooo]Z00?o08gooookJ_oonfX02?oonfX00oooV@3ooo]ZoookJP06oookJP03o`18oooo
nf[ooo]Z01Cooo]Z00GoH?l0oookJ_oonf[ooel0oon@0002oookJP03ool0X?oonf[ooo]Z00;ooo]Z
00Goo`2;oookJ_oonf[ooo]Zok`0o`05oookJP08og;o0?oonf[ooo]ZoookJ_l60?oooo]Zo`0aoooo
02H;oookJP06o`3Ooooonf[ooo]ZoookJ_oo0>7oo`2k1OoonfX00oni0?oooo]Zoe_o0009oookJP04
ooob0?oonf[ooo]ZohKo02Sooo]Z0024oookJP;oobH09OoonfX01OmAo`3ooo]ZoookJ_oonf[oogT0
00Wooo]Z00?o09gooookJ_oonfX0?ooonfX5o`0000kooo]Z00?oI`3ooookJ_oonfX04?oonfX00ooo
05gooo]ZoookJP0<oookJP03ol<0oooonf[ooo]Z00cooo]Z00?oV@3ooookJ_m^0?l02OoonfX5oolX
0003o`3o2ooo:03oobP000Oooo]Z1_oo:009oookJP03oonI0?oonf[ooo]Z00Kooo]Z00?o04Sooook
J_oonfX03ooonfX7oolX0003oomO0?ooT03ooo]Z00;ooo]Z00?oo`2PoookJ_oonfX00_oonfX01Ooo
08_ooo]ZoookJ_oonf[o_03o00Cooo]Z00CoiOl0oolX0?oo:03oobP00ooUo`001?oo:03oo`0VoolX
0?oo:009oookJP06o`3Ooooonf[ooo]ZoookJ_oo0>7oo`2k1?oonfX01?ni0?oooo]ZoookJ_mKo`08
oookJP05ooob0?oonf[ooo]ZoookJ_n6o`00ZOoonfX3oolV02Gooo]Z00CoDOl0oookJ_oonf[ook40
2OoonfX00ol0WOoooo]ZoookJP0ooookJPGo00003ooonfX00omW0?oooo]ZoookJP0?oookJP03ool0
GOoonf[ooo]Z00cooo]Z00?o``3ooookJ_oonfX03?oonfX00onI0?oooo]Zofh0o`0>oookJP03o`3o
2ooonf[ooo]Z00_ooo]Z00?o08gooookJ_oonfX02?oonfX00oooV@3ooo]ZoookJP07oookJP03o`18
oooonf[ooo]Z01?ooo]Z00GoH?l0oookJ_oonf[ooel0oon@0002oookJP03ool0X?oonf[ooo]Z00;o
oo]Z00Goo`2;oookJ_oonf[ooo]Zok`0o`05oookJP08og;o0?oonf[ooo]ZoookJ_l60?oooo]Zo`0a
oooo02H;oookJP06o`3Ooooonf[ooo]ZoookJ_oo0>7oo`2k1OoonfX00oni0?oooo]Zoe_o0009oook
JP04ooob0?oonf[ooo]ZohKo02Wooo]Z0026oookJP;oobH09?oonfX00omAo`3ooo]ZoookJP02oomi
00Sooo]Z00?o09gooookJ_oonfX0?ooonfX4o`0000oooo]Z00?oI`3ooookJ_oonfX03ooonfX00ooo
05gooo]ZoookJP0=oookJP03ol<0oooonf[ooo]Z00_ooo]Z00?oV@3ooookJ_m^0?l02OoonfX5oolX
0004o`3o2ooo:03oobP0oolX00Gooo]Z2?oo:008oookJP03oonI0?oonf[ooo]Z00Kooo]Z00?o04So
oookJ_oonfX03_oonfX8oolX0003oomO0?ooT03ooo]Z00;ooo]Z00?oo`2PoookJ_oonfX00_oonfX0
1Ooo08_ooo]ZoookJ_oonf[o_03o00Gooo]Z00?oiOl0oolX0?oo:0000_oo:0000ooUo`3oobP0ool0
9P02oolX00Wooo]Z00Ko0=oooookJ_oonf[ooo]Zool0hOoo0;/4oookJP04okT0oooonf[ooo]Zoe_o
00Sooo]Z00Gooo80oookJ_oonf[ooo]ZohKo002]oookJP;oobH09?oonfX00omAo`3ooo]Zoona0009
oookJP03o`2Moooonf[ooo]Z03oooo]Z1?l0000?oookJP03ofL0oooonf[ooo]Z013ooo]Z00?oo`1M
oookJ_oonfX03?oonfX00oo30?oooo]ZoookJP0;oookJP04oiT0oooonf[ooo]Zofh0o`gooo]Z00?o
0?l;on/0oooonfX02ooonfX00ol0SOoooo]ZoookJP08oookJP03oonI0?oonf[ooo]Z00Oooo]Z00?o
04SooookJ_oonfX04ooonfX01OmPo`3ooo]ZoookJ_ooG`3ooi0000;ooo]Z00?oo`2PoookJ_oonfX0
0_oonfX01Ooo08_ooo]ZoookJ_oonf[o_03o00Gooo]Z00SoL_l0oookJ_oonf[ooo]Zo`H0oooonf[o
037oool09P_ooo]Z00Ko0=oooookJ_oonf[ooo]Zool0hOoo0;/5oookJP03okT0oooonf[oFol000Wo
oo]Z00Cooo80oookJ_oonf[oQ_l0:_oonfX008Sooo]Z0_oo9P0SoookJP03oe7o0?oonf[oogT000;o
ogT02?oonfX00ol0WOoooo]ZoookJP0noookJPCo00003_oonfX00omW0?oooo]ZoookJP0@oookJP03
ool0GOoonf[ooo]Z00cooo]Z00?o``3ooookJ_oonfX02ooonfX01?nI0?oooo]ZoookJ_m^0?l8oook
JPGoobP000Co0?l;oolX0?oo:03oobP01OoonfX8oolX00Sooo]Z00?ooiT0oookJ_oonfX01_oonfX0
0ol0B?oooo]ZoookJP0>oookJPSoobP000?ooel0oon@0?oonfX00_oonfX00ooo0:3ooo]ZoookJP02
oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l01OoonfX00ooUo`3ooo]ZoolX0004oolX0004ool09_oo
:03oobP0oolX00Sooo]Z00?o0=oooookJ_oonfX00_oo:0000ooo0;_ooo]ZoookJP02oookJP04okT0
oooonf[ooo]Zoe_o00Sooo]Z00Gooo80oookJ_oonf[ooo]ZohKo0005oookJP03ool0m?oonf[ooo]Z
0:Sooo]Z0_oo9P0SoookJP03oe7o0?oonf[ook4000Wooo]Z00?o09gooookJ_oonfX0?_oonfX4o`00
00oooo]Z00?oI`3ooookJ_oonfX03ooonfX00ooo05gooo]ZoookJP0<oookJP03ol<0oooonf[ooo]Z
00cooo]Z00?oV@3ooookJ_m^0?l03_oonfX00ol0o`_ooo]ZoookJP0:oookJP03o`2=oooonf[ooo]Z
00Sooo]Z00?ooiT0oookJ_oonfX01ooonfX00ol0B?oooo]ZoookJP0CoookJP05of3o0?oonf[ooo]Z
oomO0?ooT0000_oonfX00ooo0:3ooo]ZoookJP02oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l01Ooo
nfX02?mbo`3ooo]ZoookJ_oonf[o1P3ooookJ_l0<Oooo`0V2ooonfX01_l0gooooo]ZoookJ_oonf[o
o`3Qool0^`Gooo]Z00?o^@3ooookJ_mKo`002OoonfX01?oolP3ooo]ZoookJ_n6o`05oookJP;oo`3d
9?oonfX008[ooo]Z0_oo9P0QoookJP03oe7o0?oonf[ooo]Z00?oogT01ooonfX00ol0WOoooo]Zoook
JP0noookJPCo00003_oonfX00omW0?oooo]ZoookJP0?oookJP03ool0GOoonf[ooo]Z00cooo]Z00?o
``3ooookJ_oonfX02ooonfX01?nI0?oooo]ZoookJ_m^0?l;oookJP?oobP000Co0?l;oolX0?oo:03o
obP01?oonfX9oolX00Sooo]Z00?ooiT0oookJ_oonfX01_oonfX00ol0B?oooo]ZoookJP0=oookJPWo
obP000Gooi00oookJ_oonf[ooo]Zool0X004oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l01OoonfX0
1?oUo`3ooo]ZoookJ_oonfX3oolX0004ool09_oo:03oobP0oolX00Sooo]Z00?o0=oooookJ_oo:000
0_oo:0000ooo0;_ooo]ZoookJP02oookJP04okT0oooonf[ooo]Zoe_o00Sooo]Z00Gooo80oookJ_oo
nf[ooo]ZohKo0004oookJP;oo`3d[OoonfX2oolV027ooo]Z00CoDOl0oookJ_oonf[ook402?oonfX0
0ol0WOoooo]ZoookJP0noookJPCo00003_oonfX00omW0?oooo]ZoookJP0@oookJP03ool0GOoonf[o
oo]Z00_ooo]Z00?o``3ooookJ_oonfX03?oonfX00onI0?oooo]Zofh0o`0>oookJP03o`3o2ooonf[o
oo]Z00_ooo]Z00?o08gooookJ_oonfX02?oonfX00oooV@3ooo]ZoookJP06oookJP03o`18oooonf[o
oo]Z01?ooo]Z00GoH?l0oookJ_oonf[ooo]Zoon@0002oookJP03ool0X?oonf[ooo]Z00;ooo]Z00Go
o`2;oookJ_oonf[ooo]Zok`0o`05oookJP08og;o0?oonf[ooo]ZoookJ_l60?oooo]Zo`0aoooo02H;
oookJP06o`3Ooooonf[ooo]ZoookJ_oo0>7oo`2k1OoonfX00oni0?oooo]Zoe_o0009oookJP04ooob
0?oonf[ooo]ZohKo00Cooo]Z0_oo0?@VoookJP00S?oonfX2oolV023ooo]Z00?oDOl0oookJ_ooN@00
0oooN@07oookJP03o`2Moooonf[ooo]Z03gooo]Z1?l0000=oookJP03ofL0oooonf[ooo]Z013ooo]Z
00?oo`1MoookJ_oonfX03?oonfX00oo30?oooo]ZoookJP0;oookJP03oiT0oooonf[oKP3o00gooo]Z
00?oobP0o`3o2ooo:0000_oo:004oookJP[oobP01ooonfX00oooV@3ooo]ZoookJP06oookJP03o`18
oooonf[ooo]Z013ooo]Z1_oo:0001OooT03ooo]ZoookJ_oonf[oo`2P00Cooo]Z00Goo`2;oookJ_oo
nf[ooo]Zok`0o`05oookJP08onGo0?oonf[ooo]ZoookJ_l60?oooo]ZoolX0?oo02H4oolX00Oooo]Z
00?o0=oooookJ_oo:0000_oo:0000ooo0;_ooo]ZoookJP02oookJP04okT0oooonf[ooo]Zoe_o00So
oo]Z00Gooo80oookJ_oonf[ooo]ZohKo0004oookJP04ool0m?oonf[ooo]Zok<0ojkooo]Z0_oo9P0P
oookJP03oe7o0?oonf[ook4000Wooo]Z00?o09gooookJ_oonfX0?OoonfX4o`0000kooo]Z00?oI`3o
oookJ_oonfX03ooonfX00ooo05gooo]ZoookJP0<oookJP03ol<0oooonf[ooo]Z00_ooo]Z00CoV@3o
oookJ_oonf[oKP3o3OoonfX00ol0o`_ooo]ZoookJP0;oookJP03o`2=oooonf[ooo]Z00Sooo]Z00?o
oiT0oookJ_oonfX01_oonfX00ol0B?oooo]ZoookJP0CoookJP05of3o0?oonf[ooo]ZoookJ_ooT000
0_oonfX00ooo0:3ooo]ZoookJP02oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l01OoonfX02?mbo`3o
oo]ZoookJ_oonf[o1P3ooookJ_l0<Oooo`0V2ooonfX01_l0gooooo]ZoookJ_oonf[oo`3Qool0^`Go
oo]Z00?o^@3ooookJ_mKo`002OoonfX01?oolP3ooo]ZoookJ_n6o`04oookJP05ool0m?oonf[ooo]Z
oookJ_nc0?l09?oonfX008kooo]Z0_oo9P0OoookJP03oe7o0?ooN@3oogT000?oogT01_oonfX00ol0
WOoooo]ZoookJP0moookJPCo00003OoonfX00omW0?oooo]ZoookJP0?oookJP03ool0GOoonf[ooo]Z
00cooo]Z00?o``3ooookJ_oonfX02ooonfX00onI0?oooo]Zofh0o`0=oookJPKoobP01_oonfX7oolX
00Oooo]Z00?ooiT0oookJ_oonfX01_oonfX00ol0B?oooo]ZoookJP0BoookJPCoobP000?ooi00oolX
0?oonfX00_oonfX01Ooo0:3ooo]ZoookJ_oonf[oo`2;00?ooo]Z00?o_03ooookJ_oonfX00ooonfX0
2?oUo`3ooo]ZoookJ_oonf[o1P3ooookJ_oo:03oo`0V1?oo:007oookJP03o`3Ooooo:03oobP000;o
obP000?oo`2koookJ_oonfX00_oonfX01?ni0?oooo]ZoookJ_mKo`08oookJP05ooob0?oonf[ooo]Z
oookJ_n6o`001?oonfX01Ooo0?Cooo]ZoookJ_oonf[o/`3o0;3ooo]Z0_oo9P0OoookJP03oe7o0?oo
nf[ook4000Sooo]Z00?o09gooookJ_oonfX0?OoonfX4o`0000gooo]Z00?oI`3ooookJ_oonfX04?oo
nfX00ooo05gooo]ZoookJP0;oookJP03ol<0oooonf[ooo]Z00cooo]Z00?oV@3ooookJ_m^0?l03Ooo
nfX00ol0o`_oj`3ooookJP0;oookJP03o`2=oooonf[ooo]Z00Sooo]Z00?ooiT0oookJ_oonfX01ooo
nfX00ol0B?oooo]ZoookJP0BoookJP05of3o0?oonf[ooo]ZoookJ_ooT0000ooonfX01Ooo0:3ooo]Z
oookJ_oonf[oo`2;00?ooo]Z00?o_03ooookJ_oonfX00ooonfX00ombo`3ooo]ZoookJP02oookJP03
o`H0ool0<Oooo`0V00_ooo]Z00Ko0=oooookJ_oonf[ooo]Zool0hOoo0;/5oookJP03okT0oooonf[o
Fol000Wooo]Z00Cooo80oookJ_oonf[oQ_l01?oonfX01Ooo0?Cooo]ZoookJ_oonf[o/`3o02Gooo]Z
002@oookJP;oobH07OoonfX00omAo`3oogT0oomi0004oomi00Kooo]Z00?o09gooookJ_oonfX0??oo
nfX4o`0000gooo]Z00?oI`3ooookJ_oonfX03ooonfX00ooo05gooo]ZoookJP0<oookJP03ol<0oooo
nf[ooo]Z00[ooo]Z00CoV@3ooookJ_oonf[oKP3o3?oonfX3oolX0004oookJ_oo:03oobP0oolX00Oo
oo]Z1_oo:006oookJP03oonI0?oonf[ooo]Z00Kooo]Z00?o04SooookJ_oonfX04_oonfX01_oo:03o
oo]ZoolX0?oo:03ooi00oolX00?ooo]Z00Goo`2PoookJ_oonf[ooo]Zool0R`03oookJP03ok`0oooo
nf[ooo]Z00?ooo]Z00SoiOl0oookJ_oonf[ooo]Zo`H0oooonf[oobP0ool09P;ooo]Z0ooo:006oook
JP03o`3Ooooo:03oobP000;oobP000?oo`2koolX0?oonfX00_oonfX01?ni0?oooo]ZoookJ_mKo`08
oookJP05ooob0?oonf[ooo]ZoookJ_n6o`001?oonfX01Ooo0?Cooo]ZoookJ_oonf[o/`3o0;?ooo]Z
00?oobH0oookJ_oonfX07?oonfX00omAo`3ooo]Zoona0009oookJP03o`2Moooonf[ooo]Z03cooo]Z
1?l0000=oookJP03ofL0oooonf[ooo]Z00oooo]Z00?oo`1MoookJ_oonfX03?oonfX00oo30?oooo]Z
oookJP0;oookJP03oiT0oooonf[oKP3o00kooo]Z00?o0?l;oookJ_oonfX02_oonfX00ol0SOoooo]Z
oookJP08oookJP03oonI0?oonf[ooo]Z00Oooo]Z00?o04SooookJ_oonfX04_oonfX01OmPo`3ooo]Z
oookJ_oonf[ooi0000?ooo]Z00Goo`2PoookJ_oonf[ooo]Zool0R`03oookJP03ok`0oooonf[ooo]Z
00?ooo]Z00?oL_l0oookJ_oonfX00_oonfX00ol60?oo037oool09P0;oookJP06o`3Ooooonf[ooo]Z
oookJ_oo0>7oo`2k1OoonfX00oni0?oooo]Zoe_o0009oookJP04ooob0?oonf[ooo]ZohKo00Cooo]Z
00Goo`3doookJ_oonf[ooo]Zok<0o`0VoookJP00T_oonfX2oolV01cooo]Z00?oDOl0oomi0?ooN@00
1?ooN@05oookJP03o`2Moooonf[ooo]Z03cooo]Z1?l0000<oookJP03ofL0oooonf[ooo]Z00oooo]Z
00?oo`1MoookJ_oonfX03?oonfX00oo30?oooo]ZoookJP0;oookJP03oiT0oooonf[oKP3o00cooo]Z
0ooo:003oookJP03oolX0?oonf[ooo]Z00Kooo]Z1Ooo:007oookJP03oonI0?oonf[ooo]Z00Gooo]Z
00?o04SooookJ_oonfX04ooonfX01?oo:03ooo]ZoookJ_ooT002oolX00;ooo]Z00?oo`2PoookJ_oo
nfX00_oonfX01?oo08_ooo]ZoookJ_nl0?l5oookJP08onGo0?oonf[ooo]ZoookJ_l60?oooo]Zo`0a
oooo02H4oookJP03oolX0?oonf[ooo]Z00?ooo]Z00?oobP0o`3Ooooo:0000ooo:0000ooo0;_oobP0
oookJP02oookJP04okT0oooonf[ooo]Zoe_o00Sooo]Z00Gooo80oookJ_oonf[ooo]ZohKo0004oook
JP03ool0m?oonf[ooo]Z00;oobP0]OoonfX2oolV01gooo]Z00?oDOl0oookJ_oo/@002?oonfX00ol0
WOoooo]ZoookJP0loookJPCo00003OoonfX00omW0?oooo]ZoookJP0?oookJP03ool0GOoonf[ooo]Z
00_ooo]Z00?o``3ooookJ_oonfX02ooonfX01?nI0?oooo]ZoookJ_m^0?l=oookJP03o`3o2ooonf[o
oo]Z00[ooo]Z00?o08gooookJ_oonfX02OoonfX00oooV@3ooo]ZoookJP06oookJP03o`18oooonf[o
oo]Z01?ooo]Z00CoH?l0oookJ_oonf[ooi000ooonfX00ooo0:3ooo]ZoookJP02oookJP04ool0Rooo
nf[ooo]Zok`0o`Gooo]Z00?oL_l0oookJ_oonfX00_oonfX00ol60?oo037oool09P0;oookJP06o`3O
oooonf[ooo]ZoookJ_oo0>7oo`2k1OoonfX00oni0?oooo]Zoe_o0009oookJP04ooob0?oonf[ooo]Z
ohKo00Cooo]Z00?oo`3doookJ_oonfX00_nc0?lWoookJP00U?oonfX2oomi01[ooo]Z00?oDOl0oomi
0?ooN@001OooN@04oookJP03o`2Moooonf[ooo]Z03cooo]Z1?l0000<oookJP03ofL0oooonf[ooo]Z
00oooo]Z00?oo`1MoookJ_oonfX02ooonfX00oo30?oooo]ZoookJP0;oookJP03oiT0oooonf[oKP3o
00cooo]Z1?oo:00<oookJP03oolX0?oonf[oobP000;oobP01_oonfX00oooV@3ooo]ZoookJP05oook
JP03o`18oooonf[ooo]Z01?ooo]Z00KoobP0oookJ_oonf[ooi00oookJ_oo:002oookJP03ool0X?oo
nf[ooo]Z00;ooo]Z00Goo`2;oookJ_oonf[ooo]Zok`0o`04oookJP08onGo0?oonf[ooo]ZoookJ_l6
0?oooo]Zo`0aoooo02H:oookJP03oolX0?l0goooobP000?oobP000?oo`2koolX0?oo:0000_oonfX0
1?ni0?oooo]ZoookJ_mKo`08oookJP05ooob0?oonf[ooo]ZoookJ_n6o`001?oonfX00ooo0?Cooo]Z
oolX0003oolX0;Oooo]Z0_oo9P0KoookJP04oe7o0?oonf[ooo]Zoona00Sooo]Z00?o09gooookJ_oo
nfX0>ooonfX4o`0000cooo]Z00?oI`3ooookJ_oonfX03ooonfX00ooo05gooo]ZoookJP0;oookJP03
ol<0oooonf[ooo]Z00cooo]Z00?oV@3ooookJ_m^0?l03OoonfX00ol0o`_ooo]ZoookJP0;oookJP03
o`2=oooonf[ooo]Z00Sooo]Z00?ooiT0oookJ_oonfX01_oonfX00ol0B?oooo]ZoookJP0CoookJP04
of3o0?oonf[ooo]Zoon@00?ooo]Z00?oo`2PoookJ_oonfX00_oonfX01Ooo08_ooo]ZoookJ_oonf[o
_03o00Cooo]Z00?oL_l0oookJ_oonfX00_oonfX00ol60?oo037oool09P0;oookJP06o`3Ooooonf[o
oo]ZoookJ_oo0>7oo`2k1?oonfX2okT0o`03oookJ_mKo`3ooo]Z00Sooo]Z00Cooo80oookJ_oonf[o
Q_l01?oonfX01?oo0?Cooo]ZoookJ_nc0?lYoookJP00H_oonfX3oomi02oooo]Z1OooN@0HoookJPSo
ogT01?oonfX00ol0WOoooo]ZoookJP0koookJPCo00002ooonfX00omW0?oooo]ZoookJP0?oookJP03
ool0GOoonf[ooo]Z00cooo]Z00?o``3ooookJ_oonfX02_oonfX00onI0?oooo]Zofh0o`0<oookJPCo
obP03?oonfX01Ooo:03ooo]ZoookJ_oonf[oobP000Kooo]Z00?ooiT0oookJ_oonfX01OoonfX00ol0
B?oooo]ZoookJP0CoookJP05oolX0?oonf[ooo]ZoomO0?ooT0000ooonfX00ooo0:3ooo]ZoookJP02
oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l01?oonfX02?oUo`3ooo]ZoookJ_oonf[o1P3ooookJ_l0
<Oooo`0V2OoonfX2oolX0003o`3Ooooo:03oobP000;oobP000?oo`2koolX0?oo:0000_oonfX01?ni
0?oooo]ZoookJ_mKo`08oookJP05ooob0?oonf[ooo]ZoookJ_n6o`001?oonfX00ooo0?CoobP0oolX
0003oolX0003oookJ_oo0:[oo`2Z0;Oooo]Z00?oobH0oookJ_oonfX06OoonfX00omAo`3ooo]Zoona
0008oookJP03o`2Moooonf[ooo]Z03_ooo]Z1?l0000<oookJP03ofL0oooonf[ooo]Z00oooo]Z00?o
o`1MoookJ_oonfX02ooonfX00oo30?oooo]ZoookJP0;oookJP03oiT0oooonf[oKP3o00gooo]Z00?o
0?l;on/0oooonfX02ooonfX00ol0SOoooo]ZoookJP08oookJP03oonI0?oonf[ooo]Z00Kooo]Z00?o
04SooookJ_oonfX04ooonfX01OmPo`3ooo]ZoookJ_ooG`3ooi0000;ooo]Z00?oo`2PoookJ_oonfX0
0_oonfX01Ooo08_ooo]ZoookJ_oonf[o_03o00Cooo]Z00?oL_l0oookJ_oonfX00_oonfX00ol60?oo
037oool09P0;oookJP06o`3Ooooonf[ooo]ZoookJ_oo0>7oo`2k1?oonfX01?ni0?oooo]ZoookJ_mK
o`09oookJP04ooob0?oonf[ooo]ZohKo00Cooo]Z00Coo`3doookJ_oonf[o/`3o1?oonfX2ool0ZRCo
oo]Z001MoookJPSoogT0<?oonfX7oomi01Kooo]Z2?ooN@03oookJP03o`2Moooonf[ooo]Z03_ooo]Z
1?l0000;oookJP03ofL0oooonf[ooo]Z00kooo]Z00?oo`1MoookJ_oonfX03?oonfX00oo30?oooo]Z
oookJP0;oookJP03oiT0oooonf[oKP3o00[ooo]Z1_oo:00;oookJP03oolX0?oonf[ooo]Z00Sooo]Z
00?ooiT0oookJ_oonfX01OoonfX00ol0B?oooo]ZoookJP0CoookJP05oolX0?oonf[ooo]ZoomO0?oo
T0000ooonfX00ooo0:3ooo]ZoookJP02oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l01?oonfX02?oU
o`3ooo]ZoookJ_oonf[o1P3ooookJ_l0<Oooo`0V2OoonfX2oolX0003o`3Ooooo:03oobP000;oobP0
00?oo`2koolX0?oo:0000_oonfX01?ni0?oooo]ZoookJ_mKo`08oookJP05ooob0?oonf[ooo]Zoook
J_n6o`001?oonfX6oolX0003oookJ_oo0:[ooo]Z0;Wooo]Z0_oo9P0JoookJP03oe7o0?oonf[ook40
00Sooo]Z00?o09gooookJ_oonfX0>_oonfX4o`0000_ooo]Z00?oI`3ooookJ_oonfX03ooonfX00ooo
05gooo]ZoookJP0;oookJP03ol<0oooonf[ooo]Z00cooo]Z00?oV@3ooookJ_m^0?l03OoonfX00ol0
o`_ooo]ZoookJP0:oookJP03o`2=oooonf[ooo]Z00Sooo]Z00?ooiT0oookJ_oonfX01_oonfX00ol0
B?oooo]ZoookJP0CoookJP05of3o0?oonf[ooo]ZoomO0?ooT0000_oonfX00ooo0:3ooo]ZoookJP02
oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l01?oonfX00ombo`3ooo]ZoookJP02oookJP03o`H0ool0
<Oooo`0V00_ooo]Z00Ko0=oooookJ_oonf[ooo]Zool0hOoo0;/4oookJP04okT0oooonf[ooo]Zoe_o
00Wooo]Z00Cooo80oookJ_oonf[oQ_l01?oonfX01?oo0?Cooo]ZoookJ_nc0?l4oookJP03ool0Z_oo
nf[ooo]Z02Cooo]Z001HoookJPgoogT0<OoonfX9oomi01?ooo]Z2OooN@02oookJP03o`2Moooonf[o
oo]Z03_ooo]Z1?l0000;oookJP03ofL0oooonf[ooo]Z00kooo]Z00?oo`1MoookJ_oonfX03?oonfX0
0oo30?oooo]ZoookJP0:oookJP03oiT0oooonf[oKP3o00[ooo]Z1ooo:00:oookJP03oolX0?oonf[o
oo]Z00Sooo]Z00?ooiT0oookJ_oonfX01_oonfX00ol0B?oooo]ZoookJP0BoookJP05oolX0?oonf[o
oo]ZoomO0?ooT0000ooonfX00ooo0:3ooo]ZoookJP02oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l0
1?oonfX02?oUo`3ooo]ZoookJ_oonf[o1P3ooookJ_l0<Oooo`0V2ooonfX00ol0goooobP0oolX0002
oolX0006ool0^ooo:03oobP0oolX0?oonf[o^@3o0_oonfX00omKo`3ooo]ZoookJP06oookJP05ooob
0?oonf[ooo]ZoookJ_n6o`000ooonfX8oolX0003ool0Z_oonf[ooo]Z0;_ooo]Z0_oo9P0HoookJP04
oe7o0?oonf[ooo]Zoona00Oooo]Z00?o09gooookJ_oonfX0>_oonfX4o`0000_ooo]Z00?oI`3ooook
J_oonfX03ooonfX00ooo05gooo]ZoookJP0;oookJP03ol<0oooonf[ooo]Z00_ooo]Z00?oV@3ooook
J_m^0?l03OoonfX00ol0o`_ooo]ZoookJP0:oookJP03o`2=oooonf[ooo]Z00Sooo]Z00?ooiT0oook
J_oonfX01ooonfX00ol0B?oooo]ZoookJP0BoookJP05of3o0?oonf[ooo]ZoomO0?ooT0000_oonfX0
0ooo0:3ooo]ZoookJP02oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l01?oonfX00ombo`3ooo]Zoook
JP02oookJP03o`H0ool0<Oooo`0V00_ooo]Z00Ko0=oooookJ_oonf[ooo]Zool0hOoo0;/4oookJP04
okT0oooonf[ooo]Zoe_o00Sooo]Z0_oolP02oookJP03ohKo0?oonf[ooo]Z00;ooo]Z00Coo`3doook
J_oonf[o/`3o1?oonfX00ooo0:[ooo]ZoookJP0UoookJP00C?oonfX9oone013oogT0<_oonfX;oomi
013ooo]Z1oooN@05oookJP03o`2Moooonf[ooo]Z03[ooo]Z1?l0000:oookJP03ofL0oooonf[ooo]Z
00kooo]Z00?oo`1MoookJ_oonfX03?oonfX00oo30?oooo]ZoookJP0:oookJP03oiT0oooonf[oKP3o
00[ooo]Z1ooo:00;oookJP03oolX0?oonf[ooo]Z00Sooo]Z00?ooiT0oookJ_oonfX01OoonfX00ol0
B?oooo]ZoookJP0BoookJP05oolX0?oonf[ooo]ZoomO0?ooT0000ooonfX00ooo0:3ooo]ZoookJP02
oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l01?oonfX02?oUo`3ooo]ZoookJ_oonf[o1P3ooookJ_l0
<Oooo`0V2ooonfX00ol0gooooo]ZoookJP02oolX0006ool0^ooo:03oobP0oolX0?oonf[o^@3o0_oo
nfX00omKo`3ooo]ZoookJP06oookJP05ooob0?oonf[ooo]ZoookJ_n6o`000_oonfX9oolX0003ool0
Z_oonf[ooo]Z06oooo]Z4_oo]@0moookJP03oolV0?oonf[ooo]Z01Kooo]Z00CoDOl0oookJ_oonf[o
ok401ooonfX00ol0WOoooo]ZoookJP0ioookJPCo00002_oonfX00omW0?oooo]ZoookJP0?oookJP03
ool0GOoonf[ooo]Z00_ooo]Z00?o``3ooookJ_oonfX02ooonfX00onI0?oooo]Zofh0o`0=oookJP03
o`3o2ooonf[ooo]Z00_ooo]Z00?o08gooookJ_oonfX02?oonfX00oooV@3ooo]ZoookJP06oookJP03
o`18oooonf[ooo]Z01;ooo]Z00GoH?l0oookJ_oonf[ooel0oon@0002oookJP03ool0X?oonf[ooo]Z
00;ooo]Z00Goo`2;oookJ_oonf[ooo]Zok`0o`04oookJP03og;o0?oonf[ooo]Z00;ooo]Z00?o1P3o
o`0aoooo02H02ooonfX01_l0gooooo]ZoookJ_oonf[oo`3Qool0^`Cooo]Z00Co^@3ooookJ_oonf[o
Fol02?oonfX01OoolP3ooo]ZoookJ_oonf[oQ_l000Cooo]Z00Coo`3doookJ_oonf[o/`3o1?oonfX0
0ooo0:[ooo]ZoookJP0VoookJP00?_oonfX>oone00_ooo]Z3_ooN@04oone02oooo]Z2oooN@0?oook
JPGoogT000?ook40oookJ_oonfX01?oonfX00ol0WOoooo]ZoookJP0joookJPCo00002_oonfX00omW
0?oooo]ZoookJP0>oookJP03ool0GOoonf[ooo]Z00_ooo]Z00?o``3ooookJ_oonfX02ooonfX00onI
0?oooo]Zofh0o`09oookJPSoobP02_oonfX00ooo:03ooo]ZoookJP08oookJP03oonI0?oonf[ooo]Z
00Gooo]Z00?o04SooookJ_oonfX04_oonfX01Ooo:03ooo]ZoookJ_ooG`3ooi0000?ooo]Z00?oo`2P
oookJ_oonfX00_oonfX01Ooo08_ooo]ZoookJ_oonf[o_03o00Cooo]Z00SoiOl0oookJ_oonf[ooo]Z
o`H0oooonf[o037oool09P_ooo]Z00Ko0=oooookJ_oonf[oobP0oookJ_oo0;/4oolX0004okT0oooo
nf[ooo]Zoe_o00Sooo]Z00Kooo80oookJ_oonf[ooo]ZohKo0?oonfX:oolX0003ool0Z_oonf[ooo]Z
06;ooo]Z3_oo]@0BoookJPcookD0<_oonfX2oolV01Oooo]Z00?oDOl0oookJ_oo/@001ooonfX00ol0
WOoooo]ZoookJP0ioookJPCo00002_oonfX00omW0?oooo]ZoookJP0?oookJP03ool0GOoonf[ooo]Z
00[ooo]Z00?o``3ooookJ_oonfX03?oonfX00onI0?oooo]Zofh0o`0=oookJP03o`3o2ooonf[ooo]Z
00[ooo]Z00?o08gooookJ_oonfX02?oonfX00oooV@3ooo]ZoookJP06oookJP03o`18oooonf[ooo]Z
01;ooo]Z00GoH?l0oookJ_oonf[ooel0oon@0003oookJP05ool0X?oonf[ooo]ZoookJ_oo08/00ooo
nfX00onl0?oooo]ZoookJP02oookJP03og;o0?oonf[ooo]Z00;ooo]Z00?o1P3oo`0aoooo02H02ooo
nfX01_l0gooooo]ZoookJ_oonf[oo`3Qool0^`Cooo]Z00Co^@3ooookJ_oonf[oFol02?oonfX01Ooo
lP3ooo]ZoookJ_oonf[oQ_l000Cooo]Z00Coo`3doookJ_oonf[o/`3o1?oonfX00ooo0:[ooo]Zoook
JP0WoookJP00<ooonfX;oone01cooo]Z2_ooN@05oookJPOookD0:OoonfX:oomi013ooo]Z0oooN@00
0ooonf[ook40oookJP06oookJP03o`2Moooonf[ooo]Z03Wooo]Z1Ol00008oookJP03ofL0oooonf[o
oo]Z00kooo]Z00?oo`1MoookJ_oonfX03?oonfX00oo30?oooo]ZoookJP0:oookJP03oiT0oooonf[o
KP3o00Wooo]Z2?oo:00:oookJP03oolX0?oonf[ooo]Z00Sooo]Z00?ooiT0oookJ_oonfX01OoonfX0
0ol0B?oooo]ZoookJP0BoookJP05oolX0?oonf[ooo]ZoomO0?ooT0000ooonfX00ooo0:3ooo]Zoook
JP02oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l01OoonfX01ombo`3ooo]ZoookJ_l60?oooo]Zo`0a
oooo02H02ooonfX01ol0gooooo]ZoookJ_oo:03ooo]Zool0^ooonfX00ooo:0001?ni0?oooo]Zoook
J_mKo`08oookJP06ooob0?oonf[ooo]ZoookJ_n6o`3ooo]Z2_oo:0000ooo0:[ooo]ZoookJP02oook
JP;o0?lCEOoonfX:oone02cooo]Z1ooo]@0]oookJP03oolV0?oonf[ooo]Z01Gooo]Z00?oDOl0oook
J_oo/@001ooonfX00ol0WOoooo]ZoookJP0hoookJPGo00002?oonfX00omW0?oooo]ZoookJP0?oook
JP03ool0GOoonf[ooo]Z00_ooo]Z00?o``3ooookJ_oonfX02ooonfX00onI0?oooo]Zofh0o`0=oook
JP03o`3o2ooonf[ooo]Z00[ooo]Z00?o08gooookJ_oonfX02?oonfX00oooV@3ooo]ZoookJP06oook
JP03o`18oooonf[ooo]Z01;ooo]Z00GoH?l0oookJ_oonf[ooel0oon@0003oookJP05ool0X?oonf[o
oo]ZoookJ_oo08/00ooonfX00onl0?oooo]ZoookJP03oookJP07og;o0?oonf[ooo]ZoookJ_l60?oo
037oool09P0;oookJP06o`3Ooooonf[ooo]ZoookJ_oo0>7oo`2k1?oonfX01?ni0?oooo]ZoookJ_mK
o`08oookJP05ooob0?oonf[ooo]ZoookJ_n6o`001?oonfX01?oo0?Cooo]ZoookJ_nc0?l4oookJP03
ool0Z_oonf[ooo]Z00;ooo]Z0_l0oa<ToookJP00;?oonfX7oone02[ooo]Z1oooN@0<oookJPGookD0
9OoonfX8oomi017ooo]Z00?oogT0oookJ_mAo`000_oonfX00ooo/@3ooo]ZoookJP04oookJP03o`2M
oooonf[ooo]Z03Wooo]Z1?l00009oookJP03ofL0oooonf[ooo]Z00kooo]Z00?oo`1MoookJ_oonfX0
2ooonfX00oo30?oooo]ZoookJP0:oookJP03oiT0oooonf[oKP3o00Wooo]Z2Ooo:009oookJP03oolX
0?oonf[ooo]Z00Sooo]Z00?ooiT0oookJ_oonfX01OoonfX00ol0B?oooo]ZoookJP0BoookJP05oolX
0?oonf[ooo]ZoookJ_ooT0000ooonfX00ooo0:3ooo]ZoookJP02oookJP05ool0Rooonf[ooo]Zoook
J_nl0?l01OoonfX02?mbo`3ooo]ZoookJ_l60?oooo]Zo`0aoooo:03oo`0V2_oonfX01_l0gooooo]Z
oookJ_oo:03ooo]Zool0^`?ooo]Z00GoobP0okT0oooonf[ooo]Zoe_o0008oookJP05ooob0?oonf[o
oo]ZoookJ_n6o`000_oonfX:oolX00Cooo]Z00?o0?lCoookJ_oonfX0C_oonfX7oone03gooo]Z1Ooo
]@0YoookJP03oolV0?oonf[ooo]Z01Cooo]Z00CoDOl0oookJ_oonf[ook401_oonfX00ol0WOoooo]Z
oookJP0hoookJPCo00002OoonfX00omW0?oooo]ZoookJP0?oookJP03ool0GOoonf[ooo]Z00[ooo]Z
00?o``3ooookJ_oonfX02ooonfX00onI0?oooo]Zofh0o`0=oookJP03o`3o2ooonf[ooo]Z00[ooo]Z
00?o08gooookJ_oonfX02?oonfX00oooV@3ooo]ZoookJP06oookJP03o`18oooonf[ooo]Z01;ooo]Z
00GoH?l0oookJ_oonf[ooo]Zoon@0003oookJP05ool0X?oonf[ooo]ZoookJ_oo08/00ooonfX00onl
0?oooo]ZoookJP03oookJP08og;o0?oonf[ooo]ZoookJ_l60?oo037ooeko0?oo02H:oookJP06o`3O
oooonf[ooo]ZoookJ_oo0>7oo`2k1?oonfX01?ni0?oooo]ZoookJ_mKo`08oookJP05ooob0?oonf[o
oo]ZoookJ_n6o`001?oonfX01?oo0?Cooo]ZoookJ_nc0?l4oookJP03ool0Z_oonf[ooo]Z00;ooo]Z
00?o0?lCoookJ_oonfX09?oonfX002[ooo]Z0_oo]@0doookJPCoogT04OoonfX5oone027ooo]Z1_oo
N@0EoookJP03oe7o0?oonf[ook4000Oooo]Z00?o09gooookJ_oonfX0>?oonfX4o`0000Wooo]Z00?o
I`3ooookJ_oonfX03OoonfX00ooo05gooo]ZoookJP0<oookJP03ol<0oooonf[ooo]Z00[ooo]Z00?o
V@3ooookJ_m^0?l02ooonfX6oolX00[ooo]Z00?o08gooookJ_oonfX02?oonfX00oooV@3ooo]Zoook
JP05oookJP03o`18oooonf[ooo]Z017ooo]Z00GoobP0oookJ_oonf[ooo]Zoon@0003oookJP03ool0
X?oonf[ooo]Z00;ooo]Z00Goo`2;oookJ_oonf[ooo]Zok`0o`05oookJP08og;o0?oonf[ooo]Zo`H0
oooonf[o037ooolX0?oo02H:oookJP06o`3Ooooonf[ooo]ZoolX0?oonf[oo`2k1?oonfX01?ni0?oo
oo]ZoookJ_mKo`08oookJP05ooob0?oonf[ooo]ZoookJ_n6o`000ooonfX00ooo0?CoobP0oolX0006
oolX00Cooo]Z00?o0?lCoookJ_oonfX0C?oonfX3oone04Wooo]Z1?oo]@0VoookJP;oobH05OoonfX0
0omAo`3ooo]Zoona0006oookJP03o`2Moooonf[ooo]Z03Sooo]Z1?l00009oookJP03ofL0oooonf[o
oo]Z00kooo]Z00?oo`1MoookJ_oonfX02ooonfX00oo30?oooo]ZoookJP0;oookJP03oiT0oooonf[o
KP3o00cooo]Z00?o0?l;on/0oooonfX02ooonfX00ol0SOoooo]ZoookJP08oookJP03oonI0?oonf[o
oo]Z00Gooo]Z00?o04SooookJ_oonfX04_oonfX01OmPo`3ooo]ZoookJ_oonf[ooi0000?ooo]Z00Go
o`2PoookJ_oonf[ooo]Zool0R`03oookJP03ok`0oooonf[ooo]Z00?ooo]Z00SoL_l0oookJ_oonf[o
oo]Zo`H0ool0<OooG_l0ool09P[ooo]Z00Ko0=oooookJ_oonf[ooo]Zool0hOoo0;/4oookJP04okT0
oooonf[ooo]Zoe_o00Sooo]Z00Gooo80oookJ_oonf[ooo]ZohKo0004oookJP04ool0m?oonf[ooo]Z
ok<0o`Cooo]Z00?oo`2ZoookJ_oonfX00_oonfX00ol0oa?ooo]ZoookJP0UoookJP00HooonfX00ooo
N@3ooo]ZoookJP0DoookJPCookD07_oonfX5oomi0003oolV0?oonf[ooo]Z01?ooo]Z00?oDOl0oook
J_oo/@001_oonfX00ol0WOoooo]ZoookJP0hoookJPCo00002?oonfX00omW0?oooo]ZoookJP0>oook
JP03ool0GOoonf[ooo]Z00_ooo]Z00?o``3ooookJ_oonfX02_oonfX00onI0?oooo]Zofh0o`0=oook
JPGoobP02OoonfX00ol0SOoooo]ZoookJP08oookJP03oonI0?oonf[ooo]Z00Gooo]Z00?o04Sooook
J_oonfX04OoonfX01Ooo:03ooo]ZoookJ_oonf[ooi0000Cooo]Z00Goo`2PoookJ_oonf[ooo]Zool0
R`03oookJP03ok`0oooonf[ooo]Z00?ooo]Z00SoL_l0oookJ_oonf[o1P3ooookJ_l0<OooobP0ool0
9P[ooo]Z00Ko0=oooookJ_oonf[oobP0oookJ_oo0;/4oookJP04okT0oooonf[ooo]Zoe_o00Sooo]Z
00Gooo80oookJ_oonf[ooo]ZohKo0003oookJP03ool0m?oonf[ooo]Z00KoobP01?oonfX00ol0oa?o
oo]ZoookJP2MoookJPCookD09?oonfX00ooo9P3ooo]ZoookJP0CoookJP03oe7o0?oonf[ook4000Ko
oo]Z00?o09gooookJ_oonfX0=ooonfX4o`0000Sooo]Z00?oI`3ooookJ_oonfX03_oonfX00ooo05go
oo]ZoookJP0;oookJP03ol<0oooonf[ooo]Z00_ooo]Z00?oV@3ooookJ_m^0?l03OoonfX00ol0o`_o
oo]ZoookJP0:oookJP03o`2=oooonf[ooo]Z00Sooo]Z00?ooiT0oookJ_oonfX01OoonfX00ol0B?oo
oo]ZoookJP0BoookJP05of3o0?oonf[ooo]ZoookJ_ooT0000ooonfX01Ooo0:3ooo]ZoookJ_oonf[o
o`2;00?ooo]Z00?o_03ooookJ_oonfX00ooonfX02?mbo`3ooo]ZoookJ_oonf[o1P3oo`0aoomNo`3o
o`0V2_oonfX01_l0gooooo]ZoookJ_oonf[oo`3Qool0^`Cooo]Z00Co^@3ooookJ_oonf[oFol02?oo
nfX01OoolP3ooo]ZoookJ_oonf[oQ_l000Cooo]Z00Coo`3doookJ_oonf[o/`3o1?oonfX00ooo0:[o
oo]ZoookJP02oookJP03o`3o4ooonf[ooo]Z02Kooo]Z001noookJPCookD06ooonfX3oomi00;ooo]Z
00?oobH0oookJ_oonfX04_oonfX00omAo`3ooo]Zoona0007oookJP03o`2Moooonf[ooo]Z03Oooo]Z
1?l00008oookJP03ofL0oooonf[ooo]Z00gooo]Z00?oo`1MoookJ_oonfX03?oonfX00oo30?oooo]Z
oookJP0:oookJP03oiT0oom^0?oooo]Z00gooo]Z00?oobP0oookJ_oo:0000_oo:008oookJP03o`2=
oooonf[ooo]Z00Sooo]Z00?ooiT0oookJ_oonfX01OoonfX00ol0B?oooo]ZoookJP0BoookJP04of3o
0?oonf[ooo]Zoon@00Cooo]Z00Goo`2PoookJ_oonf[ooo]Zool0R`03oookJP03ok`0oooonf[ooo]Z
00?ooo]Z00SoL_l0oookJ_oonf[ooo]Zo`H0ool0<OooobP0ool09P[ooo]Z00Ko0=oooookJ_oonf[o
obP0oookJ_oo0;/4oookJP04okT0oooonf[ooo]Zoe_o00Sooo]Z00Gooo80oookJ_oonf[ooo]ZohKo
0003oookJP05ool0m?oonf[ooo]ZoolX0?oonfX01Ooo:003oookJP03o`3o4ooonf[ooo]Z0:;ooo]Z
1?oo]@0QoookJP03oolV0?oonf[ooo]Z01;ooo]Z00?oDOl0oookJ_oo/@001_oonfX00ol0WOoooo]Z
oookJP0goookJPCo00002?oonfX00omW0?oooo]ZoookJP0>oookJP03ool0GOoonf[ooo]Z00_ooo]Z
00?o``3ooookJ_oonfX02_oonfX00onI0?oooo]Zofh0o`0=oookJP03o`3o2ooonf[ooo]Z00[ooo]Z
00?o08gooookJ_oonfX02?oonfX00oooV@3ooo]ZoookJP06oookJP03o`18oooonf[ooo]Z01;ooo]Z
00CoH?l0oookJ_oonf[ooi000ooonfX01Ooo0:3ooo]ZoookJ_oonf[oo`2;00?ooo]Z00?o_03ooook
J_oonfX00ooonfX00ombo`3ooo]ZoookJP02oookJP03o`0aoomNo`3oo`0V00[ooo]Z00Ko0=oooook
J_oonf[ooo]Zool0hOoo0;/4oookJP04okT0oooonf[ooo]Zoe_o00Sooo]Z00Gooo80oookJ_oonf[o
oo]ZohKo0004oookJP04ool0m?oonf[ooo]Zok<0o`Cooo]Z00?oo`2ZoookJ_oonfX00_oonfX00ol0
oa?ooo]ZoookJP0WoookJP00P_oonfX4oone01Sooo]Z00?oogT0oookJ_oonfX00_oonfX2oolV01?o
oo]Z00?oDOl0oookJ_oo/@001_oonfX00ol0WOoooo]ZoookJP0goookJPCo00001ooonfX00omW0?oo
oo]ZoookJP0>oookJP03ool0GOoonf[ooo]Z00_ooo]Z00?o``3ooookJ_oonfX02_oonfX00onI0?oo
oo]Zofh0o`0=oookJP05oolX0?oonf[ooo]ZoookJ_oo:0002?oonfX00ol0SOoooo]ZoookJP08oook
JP03oonI0?oonf[ooo]Z00Gooo]Z00?o04SooookJ_oonfX04_oonfX01?mPo`3ooo]ZoookJ_ooT004
oookJP05ool0X?oonf[ooo]ZoookJ_oo08/00ooonfX00onl0?oooo]ZoookJP03oookJP08og;o0?oo
nf[ooo]ZoookJ_l60?oo037ooolX0?oo02H:oookJP06o`3Ooooonf[ooo]ZoolX0?oonf[oo`2k1?oo
nfX01?ni0?oooo]ZoookJ_mKo`08oookJP05ooob0?oonf[ooo]ZoookJ_n6o`000ooonfX01?oo0?Co
oo]ZoookJ_oo:003oookJP?oobP00ooonfX00ol0oa?ooo]ZoookJP2WoookJPCookD07_oonfX2oolV
01?ooo]Z00?oDOl0oookJ_oo/@001OoonfX00ol0WOoooo]ZoookJP0goookJPCo00001ooonfX00omW
0?oooo]ZoookJP0>oookJP03ool0GOoonf[ooo]Z00_ooo]Z00?o``3ooookJ_oonfX02ooonfX00onI
0?oooo]Zofh0o`0<oookJP03o`3o2ooonf[ooo]Z00[ooo]Z00?o08gooookJ_oonfX02?oonfX00ooo
V@3ooo]ZoookJP06oookJP03o`18oooonf[ooo]Z01;ooo]Z00CoH?l0oookJ_oonf[ooi000ooonfX0
1Ooo0:3ooo]ZoookJ_oonf[oo`2;00?ooo]Z00?o_03ooookJ_oonfX00ooonfX00ombo`3ooo]Zoook
JP02oookJP03o`0aoomNo`3oo`0V00_ooo]Z00Go0=oooookJ_oonf[oo`3Qool0^`04oookJP04okT0
oooonf[ooo]Zoe_o00Sooo]Z00Gooo80oookJ_oonf[ooo]ZohKo0004oookJP04ool0m?oonf[ooo]Z
ok<0o`?ooo]Z0_oo0:X4oookJP03o`3o4ooonf[ooo]Z02Sooo]Z0026oookJP?ookD07?oonfX00ooo
9P3ooo]ZoookJP0AoookJP03oe7o0?oo/@3ooo]Z00Kooo]Z00?o09gooookJ_oonfX0=_oonfX4o`00
00Oooo]Z00?oI`3ooookJ_oonfX03OoonfX00ooo05gooo]ZoookJP0<oookJP03ol<0oooonf[ooo]Z
00Wooo]Z00?oV@3ooookJ_m^0?l03OoonfX00oo[0?ooobP0oookJP0:oookJP03o`2=oooonf[ooo]Z
00Sooo]Z00?ooiT0oookJ_oonfX01OoonfX00ol0B?oooo]ZoookJP0BoookJP05of3o0?oonf[ooo]Z
oomO0?ooT0000ooonfX01Ooo0:3ooo]ZoookJ_oonf[oo`2;00?ooo]Z00?o_03ooookJ_oonfX00ooo
nfX02?mbo`3ooo]ZoookJ_oonf[o1P3oo`0aoooonf[oo`0V2_oonfX01_l0gooooo]ZoookJ_oo:03o
oo]Zool0^`Cooo]Z00Co^@3ooookJ_oonf[oFol02?oonfX01OoolP3ooo]ZoookJ_oonf[oQ_l000?o
oo]Z00Coo`3doookJ_oonf[oobP01?oonfX00ooo0:[oobP0oookJP02oookJP03o`3o4ooonf[ooo]Z
0:cooo]Z0ooo]@0MoookJP03oolV0?oonf[ooo]Z013ooo]Z00?oDOl0oookJ_oo/@001_oonfX00ol0
WOoooo]ZoookJP0foookJPCo00001ooonfX00omW0?oooo]ZoookJP0>oookJP03ool0GOoonf[ooo]Z
00_ooo]Z00?o``3ooookJ_oonfX02_oonfX00onI0?oooo]Zofh0o`0=oookJP03o`3o2ooonf[ooo]Z
00Wooo]Z00?o08gooookJ_oonfX02?oonfX00oooV@3ooo]ZoookJP06oookJP03o`18oooonf[ooo]Z
01;ooo]Z00GoH?l0oookJ_oonf[ooel0oon@0003oookJP04ool0X?oonf[ooo]Zool0R`Cooo]Z00?o
_03ooookJ_oonfX00_oonfX00ombo`3ooo]ZoookJP02oookJP03o`0aoooonf[oo`0V00_ooo]Z00Go
0=oooookJ_oonf[oo`3Qool0^`04oookJP04okT0oooonf[ooo]Zoe_o00Sooo]Z00Gooo80oookJ_oo
nf[ooo]ZohKo0004oookJP04ool0m?oonf[o/`3ook<0o`?ooo]Z00?oo`2ZoookJ_oonfX00ooonfX0
0ol0oa?ooo]ZoookJP0YoookJP00ROoonfX3oone01[ooo]Z0_oo9P0BoookJP03oe7o0?oo/@3ooo]Z
00Gooo]Z00?o09gooookJ_oonfX0=_oonfX4o`0000Oooo]Z00?oI`3ooookJ_oonfX03OoonfX00ooo
05gooo]ZoookJP0;oookJP03ol<0oooonf[ooo]Z00[ooo]Z00?oV@3ooookJ_m^0?l03?oonfX00oo[
0?ooobP0oookJP0;oookJP03o`2=oooonf[ooo]Z00Oooo]Z00?ooiT0oookJ_oonfX01_oonfX00ol0
B?oooo]ZoookJP0AoookJP05of3o0?oonf[ooo]ZoomO0?ooT0000ooonfX01Ooo0:3ooo]ZoookJ_oo
nf[oo`2;00?ooo]Z00?o_03ooookJ_oonfX00ooonfX02?mbo`3ooo]ZoookJ_oonf[o1P3oo`0aoooo
nf[oo`0V2_oonfX01_l0gooooo]ZoookJ_oo:03ooo]Zool0^`Cooo]Z00Co^@3ooookJ_oonf[oFol0
2?oonfX01OoolP3ooo]ZoookJ_oonf[oQ_l000?ooo]Z00Coo`3doookJ_oonf[oobP01?oonfX00ooo
0:[ooo]ZoookJP02oookJP03o`3o4ooonf[ooo]Z0;3ooo]Z0ooo]@0KoookJP;oobH04OoonfX00omA
o`3ooo]Zoona0005oookJP03o`2Moooonf[ooo]Z03Kooo]Z1?l00007oookJP03ofL0oooonf[ooo]Z
00gooo]Z00?oo`1MoookJ_oonfX02ooonfX00oo30?oooo]ZoookJP0:oookJP04oiT0oooonf[ooo]Z
ofh0o`cooo]Z00?o0?l;oookJ_oonfX02_oonfX00ol0SOoooo]ZoookJP07oookJP03oonI0?oonf[o
oo]Z00Kooo]Z00?o04SooookJ_oonfX04_oonfX01OmPo`3ooo]ZoookJ_ooG`3ooi0000?ooo]Z00Co
o`2PoookJ_oonf[oo`2;1?oonfX00onl0?oooo]ZoookJP02oookJP03og;o0?oonf[ooo]Z00;ooo]Z
00?o037ooookJ_oo02H02ooonfX01Ol0gooooo]ZoookJ_oo0>7oo`2k00Cooo]Z00Co^@3ooookJ_oo
nf[oFol02?oonfX01OoolP3ooo]ZoookJ_oonf[oQ_l000Cooo]Z00?oo`3doookJ_nc0?l01?oonfX0
0ooo0:[ooo]ZoookJP03oookJP03o`3o4ooonf[ooo]Z02[ooo]Z002<oookJP;ookD06_oonfX00ooo
9P3ooo]ZoookJP0?oookJP03oe7o0?oo/@3ooo]Z00Kooo]Z00?o09gooookJ_oonfX0=OoonfX4o`00
00Kooo]Z00?oI`3ooookJ_oonfX03OoonfX00ooo05gooo]ZoookJP0;oookJP03ol<0oooonf[ooo]Z
00[ooo]Z00?oV@3ooookJ_m^0?l03OoonfX00ooo:03ooo]ZoookJP0:oookJP03o`2=oooonf[ooo]Z
00Sooo]Z00?ooiT0oookJ_oonfX01OoonfX00ol0B?oooo]ZoookJP0AoookJP05of3o0?oonf[ooo]Z
oomO0?ooT0000ooonfX01Ooo0:3ooo]ZoookJ_oonf[oo`2;00?ooo]Z00?o_03ooookJ_oonfX00ooo
nfX01?mbo`3ooo]ZoookJ_oonfX2oolX0003oookJ_oo02Kooo]Z00Wooo]Z00Ko0=oooookJ_oonf[o
obP0oookJ_oo0;/4oookJP04okT0oooonf[ooo]Zoe_o00Sooo]Z00Gooo80oookJ_oonf[ooo]ZohKo
0003oookJP04ool0m?oonf[ooo]ZoolX00Cooo]Z00?oo`2ZoookJ_oonfX00_oonfX00ol0oa?ooo]Z
oookJP2doookJP?ookD06_oonfX00ooo9P3ooo]ZoookJP0?oookJP03oe7o0?oo/@3ooo]Z00Gooo]Z
00?o09gooookJ_oonfX0=OoonfX4o`0000Kooo]Z00?oI`3ooookJ_oonfX03_oonfX00ooo05gooo]Z
oookJP0:oookJP03ol<0oooonf[ooo]Z00[ooo]Z00CoV@3ooookJ_oonf[oKP3o3?oonfX00ol0o`_o
oo]ZoookJP0:oookJP03o`2=oooonf[ooo]Z00Sooo]Z00?ooiT0oookJ_oonfX01OoonfX00ol0B?oo
oo]ZoookJP0BoookJP05of3o0?oonf[ooo]ZoomO0?ooT0000ooonfX01?oo0:3ooo]ZoookJ_oo08/4
oookJP03ok`0oooonf[ooo]Z00;ooo]Z00?oL_l0oookJ_oonfX00_oonfX00ol0<Ooooo]Zool09P0;
oookJP05o`3Ooooonf[ooo]Zool0hOoo0;/01?oonfX01?ni0?oooo]ZoookJ_mKo`08oookJP05ooob
0?oonf[ooo]ZoookJ_n6o`001?oonfX00ooo0?Cooo]Zok<0o`04oookJP03ool0Z_oonf[ooo]Z00?o
oo]Z00?o0?lCoookJ_oonfX0:ooonfX008kooo]Z0ooo]@0HoookJP03oolV0?oonf[ooo]Z00oooo]Z
00?oDOl0oona0?oonfX01OoonfX00ol0WOoooo]ZoookJP0eoookJPCo00001_oonfX00omW0?oooo]Z
oookJP0=oookJP03ool0GOoonf[ooo]Z00_ooo]Z00?o``3ooookJ_oonfX02OoonfX00onI0?oooo]Z
ofh0o`0=oookJP03oolX0?oonf[ooo]Z00[ooo]Z00?o08gooookJ_oonfX02?oonfX00oooV@3ooo]Z
oookJP05oookJP03o`18oooonf[ooo]Z017ooo]Z00GoH?l0oookJ_oonf[ooel0oon@0003oookJP05
ool0X?oonf[ooo]ZoookJ_oo08/00ooonfX00onl0?oooo]ZoookJP03oookJP04og;o0?oonf[ooo]Z
oookJP?oobP000?oo`0VoookJ_oonfX02?oonfX01_l0gooooo]ZoookJ_oo:03ooo]Zool0^`Cooo]Z
00Co^@3ooookJ_oonf[oFol02?oonfX01OoolP3ooo]ZoookJ_oonf[oQ_l000?ooo]Z00Coo`3doook
J_oonf[oobP01?oonfX00ooo0:[ooo]ZoookJP02oookJP03o`3o4ooonf[ooo]Z0;Sooo]Z0_oo]@0I
oookJP03oolV0?oonf[ooo]Z00kooo]Z00?oDOl0oookJ_oo/@001OoonfX00ol0WOoooo]ZoookJP0e
oookJPCo00001_oonfX00omW0?oooo]ZoookJP0=oookJP03ool0GOoonf[ooo]Z00_ooo]Z00?o``3o
oookJ_oonfX02_oonfX00onI0?oooo]Zofh0o`0<oookJP03o`3o2oo[0?oooo]Z00[ooo]Z00?o08go
oookJ_oonfX02?oonfX00oooV@3ooo]ZoookJP05oookJP03o`18oooonf[ooo]Z01;ooo]Z00GoH?l0
oookJ_oonf[ooel0oon@0003oookJP04ool0X?oonf[ooo]Zool0R`Cooo]Z00?o_03ooookJ_oonfX0
0_oonfX00ombo`3ooo]ZoookJP02oookJP03o`H0ool0<Oooo`0V00_ooo]Z00Go0=oooookJ_oonf[o
o`3Qool0^`04oookJP04okT0oooonf[ooo]Zoe_o00Sooo]Z00Gooo80oookJ_oonf[ooo]ZohKo0004
oookJP03ool0m?oonf[o/`3o00Cooo]Z00?oo`2ZoookJ_oonfX00ooonfX00ol0oa?ooo]ZoookJP0/
oookJP00TOoonfX2oone01Oooo]Z00?oobH0oookJ_oonfX03ooonfX00ooo/@3ooo]ZoookJP04oook
JP03o`2Moooonf[ooo]Z03Gooo]Z1?l00006oookJP03ofL0oooonf[ooo]Z00cooo]Z00?oo`1Moook
J_oonfX02ooonfX00oo30?oooo]ZoookJP0:oookJP03oiT0oooonf[oKP3o00cooo]Z00?oj`3oo`3o
2ooonfX02_oonfX00ol0SOoooo]ZoookJP08oookJP03oonI0?oonf[ooo]Z00Gooo]Z00?o04Sooook
J_oonfX04OoonfX01OmPo`3ooo]ZoookJ_ooG`3ooi0000?ooo]Z00Goo`2PoookJ_oonf[ooo]Zool0
R`03oookJP03ok`0oooonf[ooo]Z00?ooo]Z00?oL_l0oookJ_oonfX01?oo:0000ooo02Kooo]Zoook
JP08oookJP06o`3Ooooonf[ooo]ZoolX0?oonf[oo`2k1?oonfX01?ni0?oooo]ZoookJ_mKo`08oook
JP05ooob0?oonf[ooo]ZoookJ_n6o`000ooonfX01?oo0?Cooo]ZoolX0?oo:004oookJP03ool0Z_oo
nf[ooo]Z00;ooo]Z00?o0?lCoookJ_oonfX02?oonfX00on6o`3ooo]ZoookJP2`oookJP?ookD05ooo
nfX00ooo9P3ooo]ZoookJP0>oookJP03oe7o0?oo/@3ooo]Z00Gooo]Z00?o09gooookJ_oonfX0=?oo
nfX4o`0000Kooo]Z00?oI`3ooookJ_oonfX03?oonfX00ooo05gooo]ZoookJP0;oookJP03ol<0oooo
nf[ooo]Z00[ooo]Z00CoV@3ooookJ_oonf[oKP3o3?oonfX00ol0o`_ooo]ZoookJP09oookJP03o`2=
oooonf[ooo]Z00Sooo]Z00?ooiT0oookJ_oonfX01_oonfX00ol0B?oooo]ZoookJP0AoookJP05of3o
0?oonf[ooo]ZoomO0?ooT0000ooonfX01?oo0:3ooo]ZoookJ_oo08/4oookJP03ok`0oooonf[ooo]Z
00;ooo]Z00?oL_l0oookJ_oonfX00_oonfX00ol60?oo037oool09P0;oookJP05o`3Ooooonf[ooo]Z
ool0hOoo0;/01?oonfX01?ni0?oooo]ZoookJ_mKo`08oookJP05ooob0?oonf[ooo]ZoookJ_n6o`00
1?oonfX00ooo0?Cooo]Zok<0o`04oookJP03ool0Z_oonf[ooo]Z00?ooo]Z00?o0?lCoookJ_oonfX0
1ooonfX2ohKo02Cooo]Z002CoookJP;ookD05_oonfX00ooo9P3ooo]ZoookJP0>oookJP03oolX0?oo
/@3ooo]Z00Gooo]Z00?o09gooookJ_oonfX0=?oonfX4o`0000Gooo]Z00?oI`3ooookJ_oonfX03Ooo
nfX00ooo05gooo]ZoookJP0;oookJP03ol<0oooonf[ooo]Z00Wooo]Z00?oV@3ooookJ_m^0?l03?oo
nfX00oo[0?oo0?l;oookJP0;oookJP03o`2=oooonf[ooo]Z00Oooo]Z00?ooiT0oookJ_oonfX01Ooo
nfX00ol0B?oooo]ZoookJP0BoookJP04of3o0?oonf[ooel0oon@00?ooo]Z00Goo`2PoookJ_oonf[o
oo]Zool0R`03oookJP03ok`0oooonf[ooo]Z00?ooo]Z00?oL_l0oookJ_oonfX01?oo:0000ooo02Ko
oo]ZoookJP08oookJP06o`3Ooooonf[ooo]ZoolX0?oonf[oo`2k1?oonfX01?ni0?oooo]ZoookJ_mK
o`07oookJP;ooo800ooonfX01on6o`3ooo]ZoookJ_oonf[oo`3doookJ_oo:0001OoonfX00ooo0:[o
oo]ZoookJP02oookJP03o`3o4ooonf[ooo]Z00Sooo]Z00?oQ_l0oookJ_oonfX0]?oonfX2oone01Ko
oo]Z00?oobH0oookJ_oonfX03OoonfX00omAo`3ooo]Zoona0005oookJP03o`2Moooonf[ooo]Z03Co
oo]Z1?l00005oookJP03ofL0oooonf[ooo]Z00gooo]Z00?oo`1MoookJ_oonfX02ooonfX00oo30?oo
oo]ZoookJP09oookJP04oiT0oooonf[ooo]Zofh0o`cooo]Z00?o0?l;oookJ_oonfX02_oonfX00ol0
SOoooo]ZoookJP07oookJP03oonI0?oonf[ooo]Z00Kooo]Z00?o04SooookJ_oonfX04OoonfX01OmP
o`3ooo]ZoookJ_ooG`3ooi0000?ooo]Z00Coo`2PoookJ_oonf[oo`2;1?oonfX00onl0?oooo]Zoook
JP02oookJP03og;o0?oonf[ooo]Z00;ooo]Z00?o1P3oo`0aoooo02H02ooonfX01Ol0gooooo]Zoook
J_oo0>7oo`2k00Cooo]Z00Co^@3ooookJ_oonf[oFol01ooonfX2ooob00?ooo]Z00?oQ_l0oookJ_oo
nfX00_oonfX00ooo0?Cooo]Zok<0o`04oookJP03ool0Z_oonf[ooo]Z00?ooo]Z00?o0?lCoookJ_oo
nfX01ooonfX00on6o`3ooo]ZoookJP0ToookJP00UOoonfX2oone01Gooo]Z00?oobH0oookJ_oonfX0
3OoonfX00ooo:03ook40oookJP05oookJP03o`2Moooonf[ooo]Z03Cooo]Z1?l00005oookJP03ofL0
oooonf[ooo]Z00cooo]Z00?oo`1MoookJ_oonfX02ooonfX00oo30?oooo]ZoookJP0:oookJP03oiT0
oom^0?oooo]Z00cooo]Z00?o0?l;oookJ_oonfX02_oonfX00ol0SOoooo]ZoookJP07oookJP03oonI
0?oonf[ooo]Z00Kooo]Z00?o04SooookJ_oonfX04OoonfX01?mPo`3ooo]ZoookJ_ooT003oookJP05
ool0X?oonf[ooo]ZoookJ_oo08/00ooonfX00onl0?oooo]ZoookJP03oookJP03og;o0?oonf[oobP0
00CoobP000?oo`0VoookJ_oonfX02?oonfX01_l0gooooo]ZoookJ_oo:03ooo]Zool0^`Cooo]Z00Co
^@3ooookJ_oonf[oFol01ooonfX01?oolP3ooo]ZoookJ_oonfX2ohKo00?ooo]Z00?oo`3doookJ_oo
:0001OoonfX00ooo0:[ooo]ZoookJP02oookJP03o`3o4ooonf[ooo]Z00Sooo]Z00?oQ_l0oookJ_oo
nfX0]ooonfX2oone01Gooo]Z00?oobH0oookJ_oonfX03OoonfX00omAo`3ook40oookJP05oookJP03
o`2Moooonf[ooo]Z03?ooo]Z1?l00005oookJP03ofL0oooonf[ooo]Z00cooo]Z00?oo`1MoookJ_oo
nfX02ooonfX00oo30?oooo]ZoookJP0:oookJP03oiT0oooonf[oKP3o00cooo]Z00?o0?l;oookJ_oo
nfX02_oonfX00ol0SOoooo]ZoookJP07oookJP03oonI0?oonf[ooo]Z00Kooo]Z00?o04SooookJ_oo
nfX04OoonfX01OmPo`3ooo]ZoookJ_oonf[ooi0000?ooo]Z00Coo`2PoookJ_oonf[oo`2;1?oonfX0
0onl0?oooo]ZoookJP02oookJP03og;o0?oonf[ooo]Z00;ooo]Z00?o1P3oo`0aoooo02H02ooonfX0
1Ol0gooooo]ZoookJ_oo0>7oo`2k00Cooo]Z00Co^@3ooookJ_oonf[oFol01ooonfX01?oolP3ooo]Z
oookJ_oonfX2ohKo00Cooo]Z00?oo`3doookJ_nc0?l01?oonfX00ooo0:[ooo]ZoookJP03oookJP03
o`3o4ooonf[ooo]Z00Oooo]Z00?oQ_l0oookJ_oonfX09OoonfX0077ooo]Z0oooN@0SoookJP?ookD0
4ooonfX00ooo9P3ooo]ZoookJP0=oookJP03oolX0?oo/@3ooo]Z00Cooo]Z00?o09gooookJ_oonfX0
=?oonfX4o`0000Cooo]Z00?oI`3ooookJ_oonfX03OoonfX00ooo05gooo]ZoookJP0:oookJP03ol<0
oooonf[ooo]Z00[ooo]Z00?oV@3ooookJ_m^0?l03?oonfX00ol0o`_ooo]ZoookJP0:oookJP03o`2=
oooonf[ooo]Z00Oooo]Z00?ooiT0oookJ_oonfX01_oonfX00ol0B?oooo]ZoookJP0AoookJP04of3o
0?oonf[ooo]Zoon@00?ooo]Z00Goo`2PoookJ_oonf[ooo]Zool0R`03oookJP03ok`0oooonf[ooo]Z
00?ooo]Z00?oL_l0oookJ_oo:0001?oo:0000ooo02Kooo]ZoookJP08oookJP06o`3Ooooonf[ooo]Z
oolX0?oonf[oo`2k1?oonfX01?ni0?oooo]ZoookJ_mKo`07oookJP05ooob0?oonf[ooo]ZoookJ_n6
o`001?oonfX00ooo0?Cooo]ZoolX0005oookJP03ool0Z_oonf[ooo]Z00;ooo]Z00?o0?lCoookJ_oo
nfX01ooonfX2ohKo0;cooo]Z0ooo]@0CoookJP03oolV0?oonf[ooo]Z00cooo]Z00?oDOl0oookJ_oo
/@001OoonfX00ol0WOoooo]ZoookJP0coookJPCo00001?oonfX00omW0?oooo]ZoookJP0=oookJP03
ool0GOoonf[ooo]Z00[ooo]Z00?o``3ooookJ_oonfX02_oonfX01?nI0?oooo]ZoookJ_m^0?l<oook
JP03o`3o2ooonf[ooo]Z00Wooo]Z00?o08gooookJ_oonfX01ooonfX00oooV@3ooo]ZoookJP06oook
JP03o`18oooonf[ooo]Z017ooo]Z00GoH?l0oookJ_oonf[ooo]Zoon@0003oookJP04ool0X?oonf[o
oo]Zool0R`Cooo]Z00?o_03ooookJ_oonfX00_oonfX00ombo`3ooo]ZoookJP02oookJP03o`H0ool0
<Oooo`0V00_ooo]Z00Go0=oooookJ_oonf[oo`3Qool0^`04oookJP04okT0oooonf[ooo]Zoe_o00Oo
oo]Z00Gooo80oookJ_oonf[ooo]ZohKo0005oookJP03ool0m?oonf[o/`3o00Cooo]Z00?oo`2Zoook
J_oonfX00ooonfX00ol0oa?ooo]ZoookJP06oookJP;oQ_l0:?oonfX006cooo]Z2?ooN@0VoookJP;o
okD04_oonfX00ooo9P3ooo]ZoookJP0<oookJP;oobP000?ook40oookJ_oonfX00ooonfX00ol0WOoo
oo]ZoookJP0coookJPGo00000ooonfX00omW0?oooo]ZoookJP0<oookJP03ool0GOoonf[ooo]Z00_o
oo]Z00?o``3ooookJ_oonfX02OoonfX00onI0?oooo]Zofh0o`0<oookJP03on/0ool0o`_ooo]Z00[o
oo]Z00?o08gooookJ_oonfX02?oonfX00oooV@3ooo]ZoookJP05oookJP03o`18oooonf[ooo]Z017o
oo]Z00CoH?l0oookJ_oonf[ooi001?oonfX01?oo0:3ooo]ZoookJ_oo08/3oookJP03ok`0oooonf[o
oo]Z00?ooo]Z00?oL_l0oookJ_oo:0001?oo:0000ooo02KoobP0oookJP08oookJP06o`3Ooooonf[o
oo]Zool0hOoonf[oo`2k1?oonfX01?ni0?oooo]ZoookJ_mKo`07oookJP05ooob0?oonf[ooo]Zoook
J_n6o`001?oonfX00ooo0?Cooo]ZoolX0005oookJP03ool0Z_oonf[ooo]Z00;ooo]Z00?o0?lCoook
J_oonfX01ooonfX00on6o`3ooo]ZoookJP2ooookJP;ookD04_oonfX00ooo9P3ooo]ZoookJP0<oook
JP03oe7o0?oonf[ook4000Gooo]Z00?o09gooookJ_oonfX0<_oonfX5o`0000?ooo]Z00?oI`3ooook
J_oonfX03?oonfX00ooo05gooo]ZoookJP0;oookJP03ol<0oooonf[ooo]Z00Wooo]Z00CoV@3ooook
J_oonf[oKP3o3?oonfX00ol0o`_ooo]ZoookJP09oookJP03o`2=oooonf[ooo]Z00Sooo]Z00?ooiT0
oookJ_oonfX01OoonfX00ol0B?oooo]ZoookJP0AoookJP05of3o0?oonf[ooo]ZoookJ_ooT0001?oo
nfX00ooo0:3ooo]Zool0R`04oookJP03ok`0oooonf[ooo]Z00;ooo]Z00?oL_l0oookJ_oonfX00_oo
nfX00ol60?oo037oool09P0;oookJP05o`3Ooooonf[ooo]Zool0hOoo0;/01?oonfX01?ni0?oooo]Z
oookJ_mKo`07oookJP05ooob0?oonf[ooo]ZoookJ_n6o`001OoonfX00ooo0?Cooo]Zok<0o`04oook
JP03ool0Z_oonf[ooo]Z00?ooo]Z00?o0?lCoookJ_oonfX01_oonfX00on6o`3ooo]ZoookJP0Xoook
JP00IooonfX=oomi02Sooo]Z0_oo]@0AoookJP03oolV0?oonf[ooo]Z00_ooo]Z0_oo:0000ooo/@3o
obP0oookJP03oookJP03o`2Moooonf[ooo]Z03?ooo]Z1?l00004oookJP03ofL0oooonf[ooo]Z00co
oo]Z00?oo`1MoookJ_oonfX02_oonfX00oo30?oooo]ZoookJP0:oookJP03oiT0oom^0?oooo]Z00[o
oo]Z0_oo00000ol0o`_ooo]ZoookJP09oookJP03o`2=oooonf[ooo]Z00Sooo]Z00?ooiT0oookJ_oo
nfX01OoonfX00ol0B?oooo]ZoookJP0AoookJP04of3o0?oonf[ooo]Zoon@00Cooo]Z00Goo`2Poook
J_oonf[ooo]Zool0R`02oookJP03ok`0oooonf[ooo]Z00?ooo]Z00?oL_l0oolX0?oo:0001?oo:000
0ooo02KoobP0oookJP08oookJP06o`3Ooooonf[ooo]Zool0hOoonf[oo`2k1?oonfX01?ni0?oooo]Z
oookJ_mKo`07oookJP05ooob0?oonf[ooo]ZoookJ_n6o`001?oonfX00ooo0?Cooo]ZoolX0005oook
JP04ool0Z_oonf[ooo]ZoookJP;oobP02OoonfX00on6o`3ooo]ZoookJP32oookJP;ookD04OoonfX0
0ooo9P3ooo]ZoookJP0<oookJP03oe7o0?oo/@3ooo]Z00Cooo]Z00?o09gooookJ_oonfX0<_oonfX4
o`0000Cooo]Z00?oI`3ooookJ_oonfX03?oonfX00ooo05gooo]ZoookJP0:oookJP03ol<0oooonf[o
oo]Z00[ooo]Z00?oV@3ooookJ_m^0?l03?oonfX00ol0o`_ooo]ZoookJP09oookJP03o`2=oooonf[o
oo]Z00Sooo]Z00?ooiT0oookJ_oonfX01OoonfX00ol0B?oooo]ZoookJP0BoookJP04of3o0?oonf[o
oo]Zoon@00Cooo]Z00Coo`2PoookJ_oonf[oo`2;0ooonfX00onl0?oooo]ZoookJP02oookJP03og;o
0?oonf[ooo]Z00;ooo]Z00?o1P3oo`0aoooo02H02ooonfX01Ol0gooooo]ZoookJ_oo0>7oo`2k00Co
oo]Z00Co^@3ooookJ_oonf[oFol01ooonfX01OoolP3ooo]ZoookJ_oonf[oQ_l000Gooo]Z00?oo`3d
oookJ_nc0?l01?oonfX00ooo0:[ooo]ZoookJP02oookJP;o0?lC2?oonfX00on6o`3ooo]ZoookJP0Y
oookJP00G?oonfX8ok00oa3oogT0:_oonfX2oone013ooo]Z00?oobH0oookJ_oonfX02_oonfX3oolX
0003oona0?oo:03ooo]Z00?ooo]Z00?o09gooookJ_oonfX0<_oonfX4o`0000?ooo]Z00?oI`3ooook
J_oonfX03?oonfX00ooo05gooo]ZoookJP0;oookJP03ol<0oooonf[ooo]Z00Wooo]Z00?oV@3ooook
J_m^0?l02_oonfX2ool00003o`3o2ooonf[ooo]Z00[ooo]Z00?o08gooookJ_oonfX01ooonfX00ooo
V@3ooo]ZoookJP05oookJP03o`18oooonf[ooo]Z017ooo]Z00CoH?l0oookJ_oonf[ooi001?oonfX0
1Ooo0:3ooo]ZoookJ_oonf[oo`2;00;ooo]Z00?o_03ooookJ_oonfX00ooonfX00ombo`3oobP0oolX
0004oolX0003ool09_oo:03oobP000Sooo]Z00Ko0=oooookJ_oonf[oo`3QoookJ_oo0;/4oookJP04
okT0oooonf[ooo]Zoe_o00Oooo]Z00Gooo80oookJ_oonf[ooo]ZohKo0003oookJP;oo`3d00?ooo]Z
oolX0?oonfX00ooonfX2ool0ZP?ooo]Z0ooo:008oookJP03ohKo0?oonf[ooo]Z08;ooo]Z4On`0?lb
oookJP;ookD04?oonfX00ooo9P3ooo]ZoookJP0;oookJP03oe7o0?oonf[ook4000Gooo]Z00?o09go
oookJ_oonfX0<OoonfX4o`0000?ooo]Z00?oI`3ooookJ_oonfX03?oonfX00ooo05gooo]ZoookJP0;
oookJP03ol<0oooonf[ooo]Z00Wooo]Z00?oV@3ooookJ_m^0?l03OoonfX00ol0o`_ooo]ZoookJP09
oookJP03o`2=oooonf[ooo]Z00Oooo]Z00?ooiT0oookJ_oonfX01OoonfX00ol0B?oooo]ZoookJP0B
oookJP04of3o0?oonf[ooo]Zoon@00Cooo]Z00Coo`2PoookJ_oonf[oo`2;0ooonfX00onl0?oooo]Z
oookJP02oookJP03og;o0?oonf[ooo]Z00;ooo]Z00?o1P3oo`0aoooo02H02ooonfX01Ol0gooooo]Z
oookJ_oo0>7oo`2k00Cooo]Z00Co^@3ooookJ_oonf[oFol01ooonfX01OoolP3ooo]ZoookJ_oonf[o
Q_l000Cooo]Z0_oo0?@00ooonf[o/`3ooookJP02oookJP;oo`2Z1?oonfX00ol0oa?ooo]ZoookJP07
oookJP03ohKo0?oonf[ooo]Z02[ooo]Z001?oookJPgo/03o2ooonfX=oomi00Ko/03o9_oonfX2oone
00oooo]Z00?oobH0oookJ_oonfX02_oonfX2oolX0003oona0?oo:03oobP000?ooo]Z00?o09gooook
J_oonfX0<_oonfX4o`0000?ooo]Z00?oI`3ooookJ_oonfX03?oonfX00ooo05gooo]ZoookJP0:oook
JP03ol<0oooonf[ooo]Z00Wooo]Z00?oV@3ooookJ_m^0?l02_oonfX2ool00003o`3o2ooonf[ooo]Z
00[ooo]Z00?o08gooookJ_oonfX01ooonfX00oooV@3ooo]ZoookJP06oookJP03o`18oooonf[ooo]Z
013ooo]Z00GoH?l0oookJ_oonf[ooel0oon@0003oookJP05ool0X?oonf[ooo]ZoookJ_oo08/00ooo
nfX00onl0?oooo]ZoookJP02oookJP03og;o0?oo:03oobP000CoobP000?oo`0VoolX0?oo:0002?oo
nfX01_l0gooooo]ZoookJ_oo0>7ooo]Zool0^`Cooo]Z00Co^@3ooookJ_oonf[oFol01ooonfX01Ooo
lP3ooo]ZoookJ_oonf[oQ_l000?ooo]Z00Coo`3doookJ_oonf[oobP01?oonfX01?oo0:[ooo]Zoook
J_oonfX4oolX00Sooo]Z00?oQ_l0oookJ_oonfX0M_oonfX=ok00oa7ooo]Z3On`0?lWoookJP03oone
0?oonf[ooo]Z00gooo]Z00?oobH0oookJ_oonfX03?oonfX00omAo`3ook40oookJP04oookJP03o`2M
oooonf[ooo]Z037ooo]Z1?l00003oookJP03ofL0oooonf[ooo]Z00cooo]Z00?oo`1MoookJ_oonfX0
2_oonfX00oo30?oooo]ZoookJP09oookJP04oiT0oooonf[ooo]Zofh0o`cooo]Z00?o0?l;oookJ_oo
nfX02OoonfX00ol0SOoooo]ZoookJP07oookJP03oonI0?oonf[ooo]Z00Kooo]Z00?o04SooookJ_oo
nfX04OoonfX01OmPo`3ooo]ZoookJ_ooG`3ooi0000?ooo]Z00Coo`2PoookJ_oonf[oo`2;1?oonfX0
1Onl0?oooo]ZoookJ_oonf[oL_l000Cooo]Z00?o1P3oo`0aoooo02H02ooonfX01Ol0gooooo]Zoook
J_oo0>7oo`2k00Cooo]Z00Co^@3ooookJ_oonf[oFol01ooonfX01OoolP3ooo]ZoookJ_oonf[oQ_l0
00Cooo]Z00Coo`3doookJ_oonf[o/`3o0ooonfX00ooo0:[ooo]ZoookJP03oookJP03o`3o4ooonf[o
oo]Z00Oooo]Z00?oQ_l0oookJ_oonfX0:ooonfX004Kooo]Z2On`0?lKoookJP[oogT01_oonfX8ok00
ob3ooo]Z0_oo]@0>oookJP03oolV0?oonf[ooo]Z00Wooo]Z0ooo:0000ooo/@3oobP0oolX0003oook
JP03o`2Moooonf[ooo]Z037ooo]Z1?l00002oookJP03ofL0oooonf[ooo]Z00cooo]Z00?oo`1Moook
J_oonfX02_oonfX00oo30?oooo]ZoookJP0:oookJP03oiT0oom^0?oooo]Z00Wooo]Z0ooo00000ol0
o`_ooo]ZoookJP09oookJP03o`2=oooonf[ooo]Z00Oooo]Z00?ooiT0oookJ_oonfX01_oonfX00ol0
B?oooo]ZoookJP0AoookJP04of3o0?oonf[ooel0oon@00?ooo]Z00Goo`2PoookJ_oonf[ooo]Zool0
R`03oookJP03ok`0oooonf[ooo]Z00;ooo]Z00?oL_l0oookJ_oonfX01?oo:0001?oo02KoobP0oolX
0?oo:007oookJP06o`3Ooooonf[ooo]Zool0hOoonf[oo`2k1?oonfX01?ni0?oooo]ZoookJ_mKo`07
oookJP05ooob0?oonf[ooo]ZoookJ_n6o`000ooonfX01?oo0?Cooo]ZoookJ_oo:004oookJP03ool0
Z_oonf[ooo]Z00GoobP02?oonfX00on6o`3ooo]ZoookJP1^oookJPWo/03o:ooonfX8ok00ob3ooo]Z
0_oo]@0>oookJP03oolV0?oonf[ooo]Z00_ooo]Z00?oDOl0oookJ_oo/@001OoonfX00ol0WOoooo]Z
oookJP0`oookJPCo00000ooonfX00omW0?oooo]ZoookJP0;oookJP03ool0GOoonf[ooo]Z00[ooo]Z
00?o``3ooookJ_oonfX02_oonfX00onI0?oooo]Zofh0o`0<oookJP03o`3o2ooonf[ooo]Z00Wooo]Z
00?o08gooookJ_oonfX01ooonfX00oooV@3ooo]ZoookJP06oookJP03o`18oooonf[ooo]Z017ooo]Z
00GoH?l0oookJ_oonf[ooel0oon@0003oookJP04ool0X?oonf[ooo]Zool0R`Cooo]Z00Go_03ooook
J_oonf[ooo]Zog;o0004oookJP03o`H0ool0<Oooo`0V00_ooo]Z00Go0=oooookJ_oonf[oo`3Qool0
^`04oookJP04okT0oooonf[ooo]Zoe_o00Oooo]Z00Gooo80oookJ_oonf[ooo]ZohKo0004oookJP04
ool0m?oonf[ooo]Zok<0o`?ooo]Z00?oo`2ZoookJ_oonfX00ooonfX00ol0oa?ooo]ZoookJP07oook
JP03ohKo0?oonf[ooo]Z02cooo]Z000noookJPSo/03o9ooonfX7oomi00kooo]Z1?n`0?lNoookJP;o
okD03OoonfX00ooo9P3ooo]ZoookJP08oookJP?oobP000Cook40oolX0?oo:03oobP00_oonfX00ol0
WOoooo]ZoookJP0aoookJPCo00000_oonfX00omW0?oooo]ZoookJP0<oookJP03ool0GOoonf[ooo]Z
00[ooo]Z00?o``3ooookJ_oonfX02OoonfX00onI0?oooo]Zofh0o`09oookJP?oo`0000?o0?l;ool0
0?oonfX02?oonfX2ool000Sooo]Z0_oo:008oookJP03o`18oooonf[ooo]Z017ooo]Z00CoH?l0oook
J_ooG`3ooi000ooonfX01Ooo0:3ooo]ZoookJ_oonf[oo`2;00?ooo]Z00?o_03ooookJ_oonfX00_oo
nfX01Ombo`3ooo]ZoookJ_oonf[o1P3o00;oobP000Coo`0VoolX0?oo:03oobP01ooonfX01_l0gooo
oo]ZoookJ_oo0>7ooo]Zool0^`Cooo]Z00Co^@3ooookJ_oonf[oFol01ooonfX01OoolP3ooo]Zoook
J_oonf[oQ_l000?ooo]Z00Coo`3doookJ_nc0?ooobP01?oonfX00ooo0:[ooo]ZoookJP06oolX00Oo
oo]Z00?oQ_l0oookJ_oonfX0IooonfX8ok00occooo]Z1?n`0?lNoookJP;ookD03OoonfX00ooo9P3o
oo]ZoookJP0;oookJP03oe7o0?oo/@3ooo]Z00Cooo]Z00?o09gooookJ_oonfX0<?oonfX4o`0000;o
oo]Z00?oI`3ooookJ_oonfX03?oonfX00ooo05gooo]ZoookJP0:oookJP03ol<0oooonf[ooo]Z00Wo
oo]Z00?oV@3ooookJ_m^0?l03?oonfX00ol0o`_ooo]ZoookJP09oookJP03o`2=oooonf[ooo]Z00Oo
oo]Z00?ooiT0oookJ_oonfX01_oonfX00ol0B?oooo]ZoookJP0AoookJP05of3o0?oonf[ooo]ZoomO
0?ooT0000ooonfX01?oo0:3ooo]ZoookJ_oo08/4oookJP05ok`0oooonf[ooo]ZoookJ_mbo`001?oo
nfX00ol60?oo037oool09P0;oookJP05o`3Ooooonf[ooo]Zool0hOoo0;/01?oonfX01?ni0?oooo]Z
oookJ_mKo`07oookJP05ooob0?oonf[ooo]ZoookJ_n6o`001?oonfX01?oo0?Cooo]Zok<0oonc0?l3
oookJP03ool0Z_oonf[ooo]Z00?ooo]Z00?o0?lCoookJ_oonfX01ooonfX00on6o`3ooo]ZoookJP0]
oookJP00>OoonfX5ok00oc;ooo]Z1?ooN@0BoookJP?o/03o7OoonfX00ooo]@3ooo]ZoookJP0;oook
JP03oolV0?oonf[ooo]Z00Sooo]Z0ooo:0001_oo/@3oobP0oolX0?oo:03ooo]Zo`2Moc?ooo]Z1?l0
00000ooonf[oI`3ooookJP0>oookJP03ool0GOoonf[ooo]Z00Wooo]Z00?o``3ooookJ_oonfX02Ooo
nfX00onI0?oooo]Zofh0o`09oookJP?oo`0000?o0?l;ool00?oonfX02?oonfX3ool000Oooo]Z0ooo
:007oookJP03o`18oooonf[ooo]Z017ooo]Z00CoH?l0oookJ_ooG`3ooi000ooonfX01Ooo0:3ooo]Z
oookJ_oonf[oo`2;00?ooo]Z00?o_03ooookJ_oonfX00_oonfX02?mbo`3ooo]ZoookJ_oonf[o1P3o
oookJ_oo:03oo`0V0ooo:007oookJP06o`3Ooooonf[ooo]Zool0hOoonf[oo`2k1?oonfX01?ni0?oo
oo]ZoookJ_mKo`07oookJP05ooob0?oonf[ooo]ZoookJ_n6o`000ooonfX00ooo0?Cooo]Zok<0o`05
oookJP03ool0Z_oonf[oobP000KoobP01ooonfX00on6o`3ooo]ZoookJP1SoookJPGo/03oB?oonfX4
ok00oacooo]Z00?ookD0oookJ_oonfX02ooonfX00ooo9P3ooo]ZoookJP0:oookJP03oe7o0?oonf[o
ok4000Cooo]Z00?o09gooookJ_oonfX0<?oonfX4o`0000;ooo]Z00?oI`3ooookJ_oonfX03?oonfX0
0ooo05gooo]ZoookJP09oookJP03ol<0oooonf[ooo]Z00Wooo]Z00CoV@3ooookJ_oonf[oKP3o3?oo
nfX00ol0o`_ooo]ZoookJP09oookJP03o`2=oooonf[ooo]Z00Oooo]Z00?ooiT0oookJ_oonfX01Ooo
nfX00ol0B?oooo]ZoookJP0AoookJP05of3o0?oonf[ooo]ZoomO0?ooT0000ooonfX01?oo0:3ooo]Z
oookJ_oo08/4oookJP05ok`0oooonf[ooo]ZoookJ_mbo`001?oonfX00ol60?oooo]Zool09P0;oook
JP05o`3Ooooonf[ooo]Zool0hOoo0;/01OoonfX00oni0?oooo]Zoe_o0007oookJP05ooob0?oonf[o
oo]ZoookJ_n6o`001?oonfX00ooo0?Cooo]Zok<0o`04oookJP03ool0Z_oonf[ooo]Z00?ooo]Z00?o
0?lCoookJ_oonfX01ooonfX00on6o`3ooo]ZoookJP0^oookJP00=?oonfX5ok00oc[ooo]Z00?oogT0
oookJ_oonfX04ooonfX5ok00oaWooo]Z0_oo]@0<oookJP03oolV0?oonf[ooo]Z00Oooo]Z1?oo:000
1_oo/@3oobP0oolX0?oo:03ooo]Zo`2Moc;ooo]Z1?l000000ooonf[oI`3ooookJP0=oookJP03ool0
GOoonf[ooo]Z00[ooo]Z00?o``3ooookJ_oonfX02OoonfX00onI0?oooo]Zofh0o`08oookJP?oo`00
00?o0?l;ool00?oo00002?oonfX3ool000Oooo]Z0ooo:007oookJP03o`18oooonf[ooo]Z017ooo]Z
00CoH?l0oolX0?oo:03ooi000ooonfX01Ooo0:3ooo]ZoookJ_oonf[oo`2;00?ooo]Z00?o_03ooook
J_oonfX00_oonfX02Ombo`3ooo]ZoookJ_oonf[o1P3ooookJ_oo:03oo`0VoookJP03oolX00Kooo]Z
00Ko0=oooookJ_oonf[oo`3QoookJ_oo0;/4oookJP04okT0oooonf[ooo]Zoe_o00Oooo]Z00Gooo80
oookJ_oonf[ooo]ZohKo0003oookJP03ool0m?oonf[o/`3o00Gooo]Z00?oo`2ZoolX0?oo:0001ooo
:005oookJP;oQ_l0HOoonfX5ok00oe7ooo]Z1On`0?lHoookJP;ookD03?oonfX00ooo9P3ooo]Zoook
JP0:oookJP03oe7o0?oo/@3ooo]Z00Cooo]Z00?o09gooookJ_oonfX0;ooonfX4o`0000;ooo]Z00?o
I`3ooookJ_oonfX02ooonfX00ooo05gooo]ZoookJP0:oookJP03ol<0oooonf[ooo]Z00Wooo]Z00?o
V@3ooookJ_m^0?l03?oonfX00ol0o`_ooo]ZoookJP09oookJP03o`2=oooonf[ooo]Z00Oooo]Z00?o
oiT0oookJ_oonfX01OoonfX00ol0B?oooo]ZoookJP0AoookJP05of3o0?oonf[ooo]ZoomO0?ooT000
0ooonfX01?oo0:3ooo]ZoookJ_oo08/4oookJP05ok`0oooonf[ooo]ZoookJ_mbo`001?oonfX00ol6
0?oooo]Zool09P0;oookJP05o`3Ooooonf[ooo]Zool0hOoo0;/01OoonfX00oni0?oooo]Zoe_o0007
oookJP05ooob0?oonf[ooo]ZoookJ_n6o`001?oonfX00ooo0?Cooo]Zok<0o`04oookJP03ool0Z_oo
nf[ooo]Z00?ooo]Z00?o0?lCoookJ_oonfX01ooonfX00on6o`3ooo]ZoookJP0_oookJP00;ooonfX5
ok00oe[ooo]Z1On`0?lFoookJP03oone0?oonf[ooo]Z00[ooo]Z00?oobH0oookJ_oonfX01_oonfX4
oolX0003oona0?oo:03ooo]Z00;ooo]Z00?o09gooookJ_oonfX0<?oonfX4o`000003oookJ_mW0?oo
oo]Z00gooo]Z00?oo`1MoookJ_oonfX02OoonfX00oo30?oooo]ZoookJP09oookJP03oiT0oooonf[o
KP3o00Sooo]Z1?oo00000ol0o`_oo`00ool00006oookJPGoo`001OoonfX5oolX00Kooo]Z00?o04So
oookJ_oonfX04OoonfX01?mPo`3oobP0oolX0?ooT003oookJP05ool0X?oonf[ooo]ZoookJ_oo08/0
0ooonfX00onl0?oooo]ZoookJP02oookJP08og;o0?oonf[ooo]ZoookJ_l60?oooo]ZoolX0?oo02H3
oookJP03oolX0?oonf[ooo]Z00Cooo]Z00Ko0=oooookJ_oonf[oo`3QoookJ_oo0;/4oookJP04okT0
oooonf[ooo]Zoe_o00Oooo]Z00Gooo80oookJ_oonf[ooo]ZohKo0003oookJP03ool0m?oonf[o/`3o
00Gooo]Z00?oo`2ZoolX0?oo:0001ooo:005oookJP03ohKo0?oonf[ooo]Z05cooo]Z1On`0?mKoook
JPGo/03o5OoonfX00ooo]@3ooo]ZoookJP0:oookJP03oolV0?oonf[ooo]Z00[ooo]Z00?ook40oook
J_oonfX00ooonfX00ol0WOoooo]ZoookJP0_oookJPCo000000?ooo]ZofL0oooonfX03OoonfX00ooo
05gooo]ZoookJP09oookJP03ol<0oooonf[ooo]Z00Wooo]Z00?oV@3ooookJ_m^0?l03?oonfX00ol0
o`_ooo]ZoookJP09oookJP03o`2=oooonf[ooo]Z00Oooo]Z00?ooiT0oookJ_oonfX01OoonfX00ol0
B?oooo]ZoookJP0AoookJP05of3o0?oonf[ooo]ZoookJ_ooT0000ooonfX01?oo0:3ooo]ZoookJ_oo
08/4oookJP03ok`0oooonf[ooo]Z00;ooo]Z00OoL_l0oookJ_oonf[ooo]Zo`H0oooonf[oo`0V00_o
oo]Z00Go0=oooookJ_oonf[oo`3Qool0^`05oookJP03okT0oooonf[oFol000Oooo]Z00Gooo80oook
J_oonf[ooo]ZohKo0004oookJP03ool0m?oonf[o/`3o00Cooo]Z00?oo`2ZoookJ_oonfX00ooonfX0
0ol0oa?ooo]ZoookJP07oookJP03ohKo0?oonf[ooo]Z033ooo]Z000ZoookJPGo/03oI?oonfX3ok00
oaCooo]Z00?ookD0oookJ_oonfX02OoonfX00ooo9P3ooo]ZoookJP06oookJPGoobP000?ook40oook
J_oonfX00_oonfX00ol0WOoooo]ZoookJP0_oookJPCo000000?oobP0oookJ_oonfX03?oonfX00ooo
05gooo]ZoookJP09oookJP03oomi0?oonf[ooo]Z00[ooo]Z00?oV@3oofh0oooonfX01ooonfX4ool0
0003o`3o2ooo003oo`0000Kooo]Z1Ooo0005oookJPGoobP01ooonfX00ol0B?oooo]ZoookJP0@oook
JPCoobP000Cooi00oookJ_oonf[oo`2P0ooonfX01Ooo08_ooo]ZoookJ_oonf[o_03o00Cooo]Z00So
L_l0oookJ_oonf[ooo]Zo`H0oooonf[oobP0ool09P[ooo]Z00Ko0=oooookJ_oonf[oo`3QoookJ_oo
0;/4oookJP04okT0oooonf[ooo]Zoe_o00Oooo]Z00?ooo80oookJ_oonfX00_n6o`03oookJP03ool0
m?oonf[o/`3o00Gooo]Z00?oo`2ZoolX0?oo:0001ooo:005oookJP03ohKo0?oonf[ooo]Z05Sooo]Z
1On`0?mUoookJP?o/03o4ooonfX00ooo]@3ooo]ZoookJP09oookJP03oolV0?oonf[ooo]Z00[ooo]Z
00?oDOl0oona0?oonfX00ooonfX00ol0WOoooo]ZoookJP0_oookJPCo000000?ooo]ZofL0oooonfX0
3?oonfX00ooo05gooo]ZoookJP09oookJP03ol<0oooonf[ooo]Z00[ooo]Z00?oV@3oofh0oooonfX0
2ooonfX00oo[0?oo0?l;oookJP09oookJP03o`2=oooonf[ooo]Z00Oooo]Z00?ooiT0oookJ_oonfX0
1_oonfX00ol0B?oooo]ZoookJP0@oookJP05of3o0?oonf[ooo]ZoookJ_ooT0000ooonfX01?oo0:3o
oo]ZoookJ_oo08/4oookJP03ok`0oooonf[ooo]Z00;ooo]Z00OoL_l0oookJ_oonf[ooo]Zo`H0oooo
nf[oo`0V00_ooo]Z00Go0=oooookJ_oonf[oo`3Qool0^`05oookJP03okT0oooonf[oFol000Oooo]Z
00?ooo80oookJ_oonfX00_n6o`04oookJP03ool0m?oonf[o/`3o00Cooo]Z00?oo`2ZoookJ_oonfX0
0_oonfX2o`3o4`Wooo]Z00?oQ_l0oookJ_oonfX0<OoonfX009Kooo]Z0_n`0?lCoookJP;oobP02_oo
nfX00ooo9P3ooo]ZoookJP06oookJP;oobP000?ooo]Zool00?oo/@001?oonfX00ol0WOoooo]Zoook
JP0JoookJP?o001o1OoonfX5o`00O`Sooo]Z1?l000000ooo:03ooo]ZoookJP0<oookJP03ool0GOoo
nf[ooo]Z00Wooo]Z00?oogT0oookJ_oonfX02OoonfX00onI0?oooo]Zofh0o`07oookJPCoo`0000Co
0?l;ool00?oo003oo`001OoonfX6ool000Cooo]Z1_oo:006oookJP03o`18oooonf[ooo]Z00oooo]Z
00?oo`00oolX0?oo:0000_oo:0001?ooT03ooo]ZoookJ_oo0:03oookJP05ool0Rooonf[ooo]Zoook
J_nl0?l01?oonfX02?mbo`3ooo]ZoookJ_oonf[o1P3ooookJ_oo:03oo`0V2_oonfX01_l0gooooo]Z
oookJ_oo0>7ooo]Zool0^`Cooo]Z00Co^@3ooookJ_oo:03oobP01ooonfX01?oolP3ooo]ZoookJ_n6
o`04oookJP03ool0m?oonf[o/`3o00Gooo]Z00?oo`2ZoookJ_oonfX02?oo:004oookJP03ohKo0?oo
nf[ooo]Z0<Kooo]Z0_n`0?lBoookJP;ookD02_oonfX00ooo9P3ooo]ZoookJP0:oookJP03oona0?oo
nf[ooo]Z00?ooo]Z00?o09gooookJ_oonfX06OoonfX3o`00O`Gooo]Z1Ol007l8oookJPCo000000?o
oo]ZofL0oooonfX03?oonfX00ooo05gooo]ZoookJP09oookJP03ol<0oooonf[ooo]Z00Wooo]Z00?o
V@3ooookJ_m^0?l03?oonfX00ol0o`_ooo]ZoookJP09oookJP03o`2=oooonf[ooo]Z00Kooo]Z00?o
oiT0oookJ_oonfX01_oonfX00ol0B?oooo]ZoookJP0@oookJP05of3o0?oonf[ooo]ZoookJ_ooT000
0ooonfX01?oo0:3ooo]ZoookJ_oo08/4oookJP03ok`0oooonf[ooo]Z00;ooo]Z00OoL_l0oookJ_oo
nf[ooo]Zo`H0oooonf[oo`0V00_ooo]Z00Go0=oooookJ_oonf[oo`3Qool0^`05oookJP03okT0oooo
nf[oFol000Oooo]Z00Cooo80oookJ_oonf[oQ_l01OoonfX00ooo0?Cooo]Zok<0o`04oookJP03ool0
Z_oonf[ooo]Z00;ooo]Z00?o0?lCoookJ_oonfX02?oonfX00on6o`3ooo]ZoookJP0boookJP00V?oo
nfX3ok00oa3ooo]Z1Ooo:008oookJP03oolV0?oonf[ooo]Z00Gooo]Z00?oobP0oookJ_oonfX00_oo
00000ooo/@3ooo]ZoookJP02oookJP03o`2Moooonf[ooo]Z01Wooo]Z0ol007l4oookJPOo001o1ooo
nfX3o`0000;oobP03OoonfX00ooo:03ooo]ZoookJP09oookJP;oogT02_oonfX00onI0?oooo]Zofh0
o`07oookJPWoo`000ooonfX8ool000?ooo]Z1_oo:006oookJP03o`18oooonf[ooo]Z00oooo]Z1Ooo
:0001?ooT03ooo]ZoookJ_oo0:04oookJP04ool0Rooonf[ooo]Zok`0o`Cooo]Z00?oL_l0oookJ_oo
nfX00_oo:0000ooonf[oobP0ool09P0:oookJP06o`3Ooooonf[ooo]Zool0hOoonf[oo`2k1?oonfX0
0oni0?ooobP0oolX0002oolX00Kooo]Z00Cooo80oookJ_oonf[oQ_l01?oonfX00ooo0?Cooo]Zok<0
o`05oookJP03ool0Z_oonf[ooo]Z00;ooo]Z1_oo:004oookJP03ohKo0?oonf[ooo]Z0<Wooo]Z0on`
0?lAoookJP03oone0?oonf[ooo]Z00Sooo]Z00?oobH0oookJ_oonfX02OoonfX00omAo`3ook40oook
JP03oookJP03o`2Moooonf[ooo]Z01Wooo]Z0ol007l4oookJPOo001o1ooonfX4o`000003ofL0oooo
nf[ooo]Z00_ooo]Z00?oo`1MoookJ_oonfX02OoonfX00oo30?oooo]ZoookJP09oookJP03oiT0oooo
nf[oKP3o00cooo]Z00?o0?l;oookJ_oonfX02OoonfX00ol0SOoooo]ZoookJP07oookJP03oonI0?oo
nf[ooo]Z00Gooo]Z00?o04SooookJ_oonfX04OoonfX01?mPo`3ooo]ZoookJ_ooT003oookJP05ool0
X?oonf[ooo]ZoookJ_oo08/00ooonfX00onl0?oooo]ZoookJP02oookJP07og;o0?oonf[ooo]Zoook
J_l60?oooo]Zool09P0;oookJP05o`3Ooooonf[ooo]Zool0hOoo0;/01OoonfX00oni0?oooo]Zoe_o
0007oookJP04ooob0?oonf[ooo]ZohKo00Gooo]Z00?oo`3doookJ_nc0?l01?oonfX00ooo0:[ooo]Z
oookJP02oookJP03o`3o4ooonf[ooo]Z00Oooo]Z0_n6o`0eoookJP00VooonfX2ok00o`oooo]Z1_oo
:007oookJP03oolV0?oonf[ooo]Z00Oooo]Z0_oo00000ooo/@3ooo]ZoookJP02oookJP03o`2Moooo
nf[ooo]Z01Wooo]Z0ol007l4oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX2o`0000?oobP0
3OoonfX00ooo:03ooo]ZoookJP08oookJP;oogT02ooonfX00onI0?ooKP3ooookJP09oookJPKoo`00
0ooonfX8ool000;ooo]Z2?oo:005oookJP03o`18oooonf[ooo]Z00kooo]Z00?oo`00oolX0?oo:000
0ooo:0001?ooT03oobP0oookJ_oo0:04oookJP04ool0Rooonf[ooo]Zok`0o`Cooo]Z00?oL_l0oook
J_oonfX01?oo:0000ooo02Kooo]ZoookJP08oookJP06o`3Ooooonf[ooo]Zool0hOoonf[oo`2k1?oo
nfX00oni0?ooobP0oolX0002oolX00Kooo]Z00Cooo80oookJ_oonf[oQ_l01?oonfX00ooo0?Cooo]Z
ok<0o`05oookJP03ool0Z_oonf[ooo]Z00;ooo]Z00?oobP0oookJ_oo:0001?oo:003oookJP03ohKo
0?oonf[ooo]Z00oooo]Z00?oolT0oookJ_oonfX0^ooonfX2ok00oa3ooo]Z0_oo]@09oookJP03oolV
0?oonf[ooo]Z00Wooo]Z00?oDOl0oona0?oonfX00_oonfX00ol0WOoooo]ZoookJP0IoookJP?o001o
1?oonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l000000omW0?oooo]ZoookJP0;oookJP03
ool0GOoonf[ooo]Z00Wooo]Z00?o``3ooookJ_oonfX02OoonfX00onI0?ooKP3ooookJP0;oookJP03
on/0ool0o`_ooo]Z00Wooo]Z00?o08gooookJ_oonfX01ooonfX00oooV@3ooo]ZoookJP05oookJP03
o`18oooonf[ooo]Z017ooo]Z00CoH?l0oookJ_oonf[ooi000ooonfX01Ooo0:3ooo]ZoookJ_oonf[o
o`2;00?ooo]Z00?o_03ooookJ_oonfX00_oonfX01ombo`3ooo]ZoookJ_oonf[o1P3ooookJ_oo02H0
2ooonfX01Ol0gooooo]ZoookJ_oo0>7oo`2k00Gooo]Z00?o^@3ooookJ_mKo`001ooonfX01?oolP3o
oo]ZoookJ_n6o`05oookJP03ool0m?oonf[o/`3o00Cooo]Z00?oo`2ZoookJ_oonfX00_oonfX00ol0
oa?ooo]ZoookJP07oookJP03ohKo0?oonf[ooo]Z03Gooo]Z002MoookJP;o/03o3_oonfX7oolX00Ko
oo]Z00?oobH0oookJ_oonfX01ooonfX2ool00005oona0?oonf[ooo]ZoookJ_l0WOl02ooonfX:o`00
O`Kooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z0_l00003oolX00cooo]Z0_oo:009oook
JP?oogT02_oonfX00onI0?oooo]Zofh0o`09oookJPOoo`000_oonfX9ool00003oookJ_oo:03oobP0
00KoobP01OoonfX00ol0B?oooo]ZoookJP0=oookJP03ool00?oo:03oobP000CoobP000Cooi00oolX
0?oonf[oo`2P1?oonfX01Ooo08_ooo]ZoookJ_oonf[o_03o00?ooo]Z00?oL_l0oookJ_oo:0000ooo
:0000ooo003oo`0VoookJP09oookJP06o`3Ooooonf[ooo]Zool0hOoonf[oo`2k1?oonfX00oni0?oo
obP0oolX0002oolX00Kooo]Z00Cooo80oookJ_oonf[oQ_l01?oonfX00ooo0?Cooo]Zok<0o`05oook
JP04ool0Z_oonf[ooo]ZoookJP;oobP00ooonfX3oolX00?ooo]Z00?oQ_l0oookJ_oonfX03_oonfX3
ooo90;oooo]Z0_n`0?l@oookJP03oone0?oonf[ooo]Z00Oooo]Z00?oobH0oookJ_oonfX02?oonfX0
0omAo`3ook40oookJP03oookJP03o`2Moooonf[ooo]Z00Sooo]Z2_l007l6oookJP?o001o0ooonfX3
o`00O`?ooo]Z0ol007l6oookJPCo000000?oI`3ooookJ_oonfX02_oonfX00ooo05gooo]ZoookJP09
oookJP03ol<0oooonf[ooo]Z00Wooo]Z00?oV@3ooookJ_m^0?l03?oonfX00ol0o`_ooo]ZoookJP08
oookJP03o`2=oooonf[ooo]Z00Oooo]Z00?ooiT0oookJ_oonfX01OoonfX00ol0B?oooo]ZoookJP0A
oookJP05of3o0?oonf[ooo]ZoomO0?ooT0000_oonfX01Ooo0:3ooo]ZoookJ_oonf[oo`2;00?ooo]Z
00?o_03ooookJ_oonfX00_oonfX01ombo`3ooo]ZoookJ_oonf[o1P3ooookJ_oo02H02_oonfX2o`3O
o`;ooo]Z00?oo`3Qool0^ooonfX01?oonfX00oni0?oooo]Zoe_o0007oookJP04ooob0?oonf[ooo]Z
ohKo00Cooo]Z0_oo0?@00ooonf[o/`3ooookJP03oookJP03ool0Z_oonf[ooo]Z00;ooo]Z00?o0?lC
oookJ_oonfX01ooonfX00on6o`3ooo]ZoookJP0foookJP00PooonfX5oolX01Oooo]Z0on`0?l<oook
JPWoobP01?oonfX00ooo9P3ooo]ZoookJP06oookJP;oo`0000?ook40ool00?oonfX00_oonfX00ooo
:03ooo]ZoookJP08oookJP[o001o1_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX00ol0
003oobP0oolX0002oolX0003o`000?oonf[ooo]Z00Sooo]Z0_oo:009oookJPCoogT02OoonfX00ooo
:03ooo]Zofh0o`09oookJPSoo`0000?ooo]Zool00?oo00001ooo00000ooonf[oobP0oolX0007oolX
00Gooo]Z00?o04SooookJ_oonfX03?oonfX00ooo003oobP0oolX0004oolX0004oon@0?oo:03ooo]Z
ool0X0Cooo]Z00Goo`2;oookJ_oonf[ooo]Zok`0o`03oookJP03og;o0?oo:03oobP000;oobP00_oo
00000ooo02Koo`00oookJP08oookJP06o`3Ooooonf[ooo]Zool0hOoonf[oo`2k0ooonfX00ooo:03o
^@3ooolX0004oolX00Gooo]Z00Cooo80oookJ_oonf[oQ_l01?oonfX00ooo0?Cooo]Zok<0o`04oook
JP;oo`2Z0ooonfX00ooo:03ooo]ZoookJP04oookJP05oolX0?oonf[ooo]ZoookJ_n6o`003ooonfX5
ooo90<7ooo]Z0on`0?l>oookJP03oone0?oonf[ooo]Z00Oooo]Z00?oobH0oookJ_oonfX02?oonfX0
0omAo`3ook40oookJP02oookJP03o`2Moooonf[ooo]Z00Sooo]Z2_l007l6oookJP?o001o0ooonfX3
o`00O`?ooo]Z0ol007l6oookJP?o000000?oI`3oo`000?l000002ooonfX00ooo05gooo]ZoookJP09
oookJP03ol<0oooonf[ooo]Z00Sooo]Z00?oV@3ooookJ_m^0?l03?oonfX00ol0o`_ooo]ZoookJP09
oookJP03o`2=oooonf[ooo]Z00Kooo]Z00?ooiT0oookJ_oonfX01_oonfX00ol0B?oooo]ZoookJP0@
oookJP05of3o0?oonf[ooo]ZoomO0?ooT0000_oonfX01Ooo0:3ooo]ZoookJ_oonf[oo`2;00?ooo]Z
00?o_03ooookJ_oonfX00_oonfX01ombo`3ooo]ZoookJ_oonf[o1P3ooookJ_oo02H02_oonfX01_l0
gooooo]ZoookJ_oonf[oo`3Qool0^`Gooo]Z00?o^@3ooookJ_mKo`001ooonfX01?oolP3ooo]Zoook
J_n6o`04oookJP04ool0m?oonf[ooo]Zok<0o`Cooo]Z00?oo`2ZoookJ_oonfX00_oonfX00ol0oa?o
oo]ZoookJP07oookJP03ohKo0?oonf[ooo]Z017ooo]Z0_l00OlToookJP00O?oonfX<oolX01[ooo]Z
0on`0?l:oookJP[oobP00_oonfX00ooo9P3ooo]ZoookJP06oookJP?oo`0000Gook40ool00?oonf[o
oo]ZoolX000JoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJP03o`000?oo:03oobP000;o
obP02_oonfX3oolX00Sooo]Z1OooN@08oookJP;oobP000?oKP3ooookJ_oonfX01ooonfX5ool00003
oookJ_oo003oo`0000Cooo]Z1ooo0009oolX00Gooo]Z00?o04SooookJ_oonfX02ooonfX2ool000Ko
obP000Cooi00oolX0?oo:03oo`2P1?oonfX01Ooo08_ooo]ZoookJ_oonf[o_03o00?ooo]Z00?oL_l0
oolX0?oo:0000_oo:002ool00003ool09_oo003ooo]Z00Sooo]Z00Ko0=oooookJ_oonf[oo`3Qoook
J_oo0;/2oookJP;oobP000?o^@3ooolX0?oo:0000ooo:005oookJP04ooob0?oonf[ooo]ZohKo00Co
oo]Z00?oo`3doookJ_nc0?l01?oonfX00ooo0:[ooo]ZoookJP02oookJP03oolX0?oonf[ooo]Z00So
oo]Z00?oQ_l0oookJ_oonfX03?oonfX7ooo90<Cooo]Z0on`0?l<oookJP03oone0?oonf[ooo]Z00Oo
oo]Z00?oobH0oookJ_oonfX01ooonfX00omAo`3ooo]Zoona0002oookJP03o`2Moooonf[ooo]Z01So
oo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol000000omW0?oooo]ZoookJP0:oookJP03
ool0GOoonf[ooo]Z00Wooo]Z00?o``3ooookJ_oonfX02OoonfX00onI0?ooKP3ooookJP0;oookJP03
o`3o2ooonf[ooo]Z00Wooo]Z00?o08gooookJ_oonfX01_oonfX00oooV@3ooo]ZoookJP06oookJP03
o`18oooonf[ooo]Z013ooo]Z00GoH?l0oookJ_oonf[ooel0oon@0002oookJP05ool0X?oonf[ooo]Z
oookJ_oo08/00ooonfX00onl0?oooo]ZoookJP02oookJP07og;o0?oonf[ooo]ZoookJ_l60?oooo]Z
ool09P0:oookJP06o`3Ooooonf[ooo]ZoookJ_oo0>7oo`2k1OoonfX00oni0?oooo]Zoe_o0007oook
JP04ooob0?oonf[ooo]ZohKo00Cooo]Z00Coo`3doookJ_oonf[o/`3o1?oonfX00ooo0:[ooo]Zoook
JP02oookJP03o`3o4ooonf[ooo]Z00Oooo]Z00?oQ_l0oookJ_oonfX04OoonfX00ol00Ooooo]Zoook
JP0ToookJP00H_oonfXFo`2/oa3oobP07OoonfX2ok00o`Wooo]Z2_oo:002oookJP03oolV0?oonf[o
oo]Z00Gooo]Z0ooo00001?oo/@3oo`00ool00?oonfX2oolX01Wooo]Z0ol007l3oookJP?o001o0ooo
nfX3o`00O`Kooo]Z1Ooo:009oookJPCoobP01ooonfX5oomi00Sooo]Z0_oo:0000ooonf[oKP3ooook
JP07oookJPGoo`000ooonfX00ooo003ooo]ZoookJP03oookJPGoo`000ooonfX7oolX00Cooo]Z00?o
04SooookJ_oonfX02_oonfX5ool000GoobP000?ooi00oolX0?oo0:001?oonfX01Ooo08_ooo]Zoook
J_oonf[o_03o00?ooo]Z00CoL_l0oolX0?oo:03oobP00ooo00000ooo02Koo`00oookJP08oookJP04
o`3Ooooonf[ooo]Zool0h@;oogT00_oonfX2oolX0003okT0oooo:03oobP000CoobP01?oonfX01?oo
lP3ooo]ZoookJ_n6o`04oookJP03ool0m?oonf[o/`3o00Cooo]Z00?oo`2ZoookJ_oonfX00_oonfX0
0ooo:03ooo]ZoookJP07oookJP;oQ_l03OoonfX9ooo908Cooo]Z7Ol0[?lVoookJP;o/03o2ooonfX0
0ooo]@3ooo]ZoookJP07oookJP03oolV0?oonf[ooo]Z00Oooo]Z00?oDOl0oona0?oonfX00_oonfX0
0ol0WOoooo]ZoookJP0GoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJP;o000000?oI`3o
o`000?oonfX02ooonfX00ooo05gooo]ZoookJP08oookJP03ol<0oooonf[ooo]Z00Wooo]Z00?oV@3o
oookJ_m^0?l02ooonfX00oo[0?oo0?l;oookJP09oookJP03o`2=oooonf[ooo]Z00Kooo]Z00?ooiT0
oookJ_oonfX01_oonfX00ol0B?oooo]ZoookJP0@oookJP05of3o0?oonf[ooo]ZoomO0?ooT0000_oo
nfX01Ooo0:3ooo]ZoookJ_oonf[oo`2;00?ooo]Z00?o_03ooookJ_oonfX00_oonfX01ombo`3ooo]Z
oookJ_oonf[o1P3ooookJ_oo02H02_oonfX01?l0gooooo]ZoookJ_oonfX2ool0^`Gooo]Z00?o^@3o
oookJ_mKo`001ooonfX01?oolP3ooo]ZoookJ_n6o`04oookJP04ool0m?oonf[o/`3ook<0o`Cooo]Z
00?oo`2ZoookJ_oonfX00_oonfX00ol0oa?ooo]ZoookJP07oookJP03ohKo0?oonf[ooo]Z017ooo]Z
00?o007ooookJ_oonfX09OoonfX005Oooo]Z2ol0[?lIoookJPgoobP07ooonfX2ok00o`Oooo]Z2_oo
:003oookJP03oolV0?oonf[ooo]Z00Gooo]Z0ooo00000ooo/@3oo`00ool00003oolX01Sooo]Z0ol0
07l3oookJP?o001o0ooonfX3o`00O`Gooo]Z1Ooo:009oookJPGoobP01_oonfX6oomi00Oooo]Z0ooo
:0000om^0?oooo]ZoookJP06oookJPKoo`002OoonfX5ool000Cooo]Z1Ooo:004oookJP03o`18oooo
nf[ooo]Z00[ooo]Z1ooo0003oolX0003oon@0?oo:03oo`2P00Cooo]Z00Goo`2;oookJ_oonf[ooo]Z
ok`0o`02oookJP04oolX0?mbo`3oobP0oolX00Coo`0000?oo`0Vool00?oo00002?oonfX00ol0gooo
oo]ZoookJP04oomi00?oobP000?o^@3ooolX0?oo:0001?oo:004oookJP04ooob0?oonf[ooo]ZohKo
00Cooo]Z00?oo`3doookJ_nc0?l01?oonfX00ooo0:[ooo]ZoookJP02oookJP03oolX0?oonf[ooo]Z
00Oooo]Z00?oQ_l0oookJ_oonfX02ooonfX:ooo907[ooo]Z2ol0[?lMoookJPWo0:co7ooonfX2ok00
o`[ooo]Z00?ookD0oookJ_oonfX01ooonfX00ooo9P3ooo]ZoookJP08oookJP04oona0?oonf[ooo]Z
o`2MoaWooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z0_l000000omW0?oo0000oookJP0:
oookJP03ool0GOoonf[ooo]Z00Wooo]Z00?o``3ooookJ_oonfX02OoonfX00onI0?ooKP3ooookJP0;
oookJP03o`3o2ooonf[ooo]Z00Wooo]Z00?o08gooookJ_oonfX01_oonfX00oooV@3ooo]ZoookJP05
oookJP03o`18oooonf[ooo]Z013ooo]Z00GoH?l0oookJ_oonf[ooo]Zoon@0002oookJP05ool0X?oo
nf[ooo]ZoookJ_oo08/00ooonfX00onl0?oooo]ZoookJP02oookJP07og;o0?oonf[ooo]ZoookJ_l6
0?oooo]Zool09P0:oookJP05o`3Ooooonf[ooo]ZoookJ_oo0;/01_oonfX00oni0?oooo]Zoe_o0007
oookJP04ooob0?oonf[ooo]ZohKo00Cooo]Z00?oo`3doookJ_nc0?l01OoonfX01?oo0:[ooo]Zoook
J_oonfX2o`3o4`Wooo]Z00?oQ_l0oookJ_oonfX04OoonfX00ol00Ooooo]ZoookJP0VoookJP00DOoo
nfX6o`2/obOooo]Z2_oo:005o`2/o`03ooo90?oonf[ooo]Z01Wooo]Z00?o/03ooookJ_oonfX01Ooo
nfX8oolX00Gooo]Z00?oobH0oookJ_oonfX01?oonfX3ool00004oona0?oo003oo`00ool000;oobP0
6?oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1OoonfX5oolX00Wooo]Z1Ooo:005oookJPOoogT0
1_oonfX4oolX0003ofh0oooonf[ooo]Z00Gooo]Z1ooo0008oookJP03ool00?oonf[ooo]Z00?oo`00
1?oonfX00ooo:03ooo]ZoolX0002oolX00?ooo]Z00?o04SooookJ_oonfX02_oonfX9ool00004oolX
0?ooT03oobP0oolX00Cooo]Z00Goo`2;oookJ_oonf[ooo]Zok`0o`02oookJP03oolX0?mbo`3oobP0
00Goo`0000?oo`0Vool00?oo00002?oonfX00ol0gooooo]ZoookJP04oomi00?oobP000?o^@3ooolX
0?oo:0001?oo:004oookJP04ooob0?oonf[ooo]ZohKo00Cooo]Z00?oo`3doookJ_nc0?l01?oonfX0
0ooo0:[ooo]ZoookJP02oookJP03oolX0?oonf[ooo]Z00Oooo]Z00?oQ_l0oookJ_oonfX02ooonfX:
ooo907Gooo]Z1_l0[?laoookJPGo0:co7?oonfX00on`0?oooo]ZoookJP08oookJP03oone0?oonf[o
oo]Z00Oooo]Z00?oobH0oookJ_oonfX01ooonfX01Ooo/@3ooo]ZoookJ_oonf[o09go01Sooo]Z0ol0
07l3oookJP?o001o0ooonfX3o`00O`Kooo]Z0_l000000omW0?oo0000oookJP0:oookJP03ool0GOoo
nf[ooo]Z00Sooo]Z00?o``3ooookJ_oonfX02OoonfX00onI0?oooo]Zofh0o`0;oookJP03o`3o2ooo
nf[ooo]Z00Wooo]Z00?o08gooookJ_oonfX01_oonfX00oooV@3ooo]ZoookJP05oookJP03o`18oooo
nf[ooo]Z013ooo]Z00GoH?l0oookJ_oonf[ooo]Zoon@0002oookJP05ool0X?oonf[ooo]ZoookJ_oo
08/00ooonfX00onl0?oooo]ZoookJP02oookJP07og;o0?oonf[ooo]ZoookJ_l60?oooo]Zool09P0:
oookJP05o`3Ooooonf[ooo]ZoookJ_oo0;/01_oonfX00oni0?oooo]Zoe_o0007oookJP04ooob0?oo
nf[ooo]ZohKo00Cooo]Z00?oo`3doookJ_nc0?l01OoonfX01Ooo0:[ooo]ZoookJ_oonf[o0?lC00[o
oo]Z00?oQ_l0oookJ_oonfX04OoonfX00ol00Ooooo]ZoookJP0WoookJP00BooonfX6o`2/oc3ooo]Z
1ooo:005ooo900;o0:co4Ooo000:oookJP;o/03o1_oonfX6oolX00Oooo]Z00?oobH0oookJ_oonfX0
0ooonfX4ool00004oona0?oo003oo`00ool000;oobP05?oonfX6o`00O`?ooo]Z0ol007l3oookJP?o
001o1?oonfX6oolX00Sooo]Z1Ooo:005oookJPOoogT01_oonfX4oolX0003ofh0oooonf[ooo]Z00Go
oo]Z1ooo0008oookJP03ool00?oonf[ooo]Z00;ooo]Z00?oo`00oookJ_oonfX00_oonfX01Ooo:03o
oo]ZoookJ_oonf[oobP000;ooo]Z0_oo:00?oookJPKoo`0000?oobP0oon@0?oo:0000_oo:003oook
JP05ool0Rooonf[ooo]ZoookJ_nl0?l00_oonfX00ooo:03oL_l0oolX0005ool00004ool09_oo003o
o`00ool000Oooo]Z00?o0=oooookJ_ooN@001?ooN@03oookJP03okT0oooo:03oobP000GoobP00ooo
nfX01?oolP3ooo]ZoookJ_n6o`04oookJP03ool0m?oonf[o/`3o00Cooo]Z00?oo`2ZoookJ_oonfX0
0_oonfX00ooo:03ooo]ZoookJP07oookJP03ohKo0?oonf[ooo]Z00cooo]Z2_oob@1_oookJPKo0:co
??oonfX5o`2/oaSooo]Z0_n`0?l9oookJP03oone0?oonf[ooo]Z00Oooo]Z00?oobH0oookJ_oonfX0
1ooonfX01?oo/@3ooo]ZoookJ_l0WOlEoookJPKo001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJP04
o`000?mW0?oo0000o`0000_ooo]Z00?oo`1MoookJ_oonfX02?oonfX00oo30?oooo]ZoookJP09oook
JP03oiT0oom^0?oooo]Z00_ooo]Z00?o0?l;oookJ_oonfX02?oonfX00ol0SOoooo]ZoookJP06oook
JP03oonI0?oonf[ooo]Z00Gooo]Z00?o04SooookJ_oonfX04?oonfX01OmPo`3ooo]ZoookJ_oonf[o
oi0000?ooo]Z00Coo`2PoookJ_oonf[oo`2;0ooonfX00onl0?oooo]ZoookJP02oookJP07og;o0?oo
nf[ooo]ZoookJ_l60?oooo]Zool09P0:oookJP05o`3Ooooonf[ooo]ZoookJ_oo0;/01_oonfX00oni
0?oooo]Zoe_o0007oookJP04ooob0?oonf[ooo]ZohKo00Cooo]Z00?oo`3doookJ_nc0?l01OoonfX0
1Ooo0:[ooo]ZoookJ_oonf[o0?lC00[ooo]Z00?oQ_l0oookJ_oonfX04?oonfX2o`01ob[ooo]Z0016
oookJPGo0:co=_oonfX3ooo900CoobP01_oob@03oookJPooo`003?oonfX2ok00o`Gooo]Z1Ooo:000
0ooo003ooo]ZoookJP04oookJP03oolV0?oonf[ooo]Z00Cooo]Z0ooo00000ooo/@3oo`00ool00002
ool000;oobP04ooonfX6o`00O`Cooo]Z0ol007l01?oonf[o001oo`00Ool007l5oookJPKoobP01ooo
nfX6oolX00Cooo]Z2?ooN@05oookJPCoobP000?oKP3ooookJ_oonfX01OoonfX8ool000Oooo]Z00?o
o`00oookJ_oonfX01ooonfX00ooo:03ooo]ZoookJP04oookJP?oobP04?oonfX4ool00003oolX0?oo
T03oobP000;oobP00ooonfX01Ooo08_ooo]ZoookJ_oonf[o_03o00?ooo]Z00?oL_l0ool00?oo0000
1?oo00001?oo02Koo`00ool00?oo0007oookJP03o`3OooooN@3oogT000GoogT00_oonfX00oni0?oo
oo]ZoolX0005oolX00;ooo]Z0_oolP02oookJP03ohKo0?oonf[ooo]Z00;ooo]Z00?oo`3doookJ_nc
0?l01?oonfX00ooo0:[ooo]ZoookJP02oookJP03oolX0?oonf[ooo]Z00Oooo]Z00?oQ_l0oookJ_oo
nfX03_oonfX8ooo906[ooo]Z1_l0[?m7oookJPGo0:co5OoonfX2ok00o`Sooo]Z0_oo]@07oookJP03
oolV0?oonf[ooo]Z00Oooo]Z00Cook40oookJ_oonf[o09go5OoonfX6o`00O`Cooo]Z0ol007l01?oo
nf[o001oo`00Ool007l7oookJP04o`000?mW0?oo0000o`0000[ooo]Z00?oo`1MoookJ_oonfX02?oo
nfX00oo30?oooo]ZoookJP09oookJP03oiT0oom^0?oooo]Z00_ooo]Z00?o0?l;oookJ_oonfX02?oo
nfX00ol0SOoooo]ZoookJP06oookJP03oonI0?oonf[ooo]Z00Kooo]Z00?o04SooookJ_oonfX04?oo
nfX01?mPo`3ooo]ZoookJ_ooT003oookJP04ool0X?oonf[ooo]Zool0R`?ooo]Z00?o_03ooookJ_oo
nfX00_oonfX01ombo`3ooo]ZoookJ_oonf[o1P3ooookJ_oo02H02_oonfX01Ol0gooooo]ZoookJ_oo
nf[oo`2k00Kooo]Z00?o^@3ooookJ_mKo`001_oonfX2ooob00;ooo]Z00?oQ_l0oookJ_oonfX00_oo
nfX00ooo0?Cooo]Zok<0o`05oookJP05ool0Z_oonf[ooo]ZoookJ_l0oa<02_oonfX00on6o`3ooo]Z
oookJP0@oookJP03o`01oooonf[ooo]Z02[ooo]Z0011oookJPGo0:co9?oonfXDool0MPWoolT000?o
obP0ooo90?oob@001?oob@05oookJPgoo`003_oonfX00on`0?oooo]ZoookJP03oookJP?oobP01?oo
0005oookJP03oolV0?oonf[ooo]Z00?ooo]Z0ooo00000ooo/@3oo`00ool00003ool000;oobP05?oo
nfX4o`00O`Cooo]Z1ol007l4oookJPOoobP01_oonfX7oolX00?ooo]Z2OooN@04oookJPGoobP000?o
KP3ooookJ_oonfX01?oonfX9ool0013ooo]Z00?oobP0oookJ_oonfX00ooonfX4oolX017ooo]Z0ooo
0006oolX00?ooo]Z00Coo`2;oookJ_oonf[o_03o0ooonfX00ombo`3oo`00ool00004ool00004ool0
9_oo003oo`00ool000Oooo]Z00?o0=oooomi0?ooN@001OooN@02oookJP04okT0oooonf[oobP0oook
JPGoobP000Cooo]Zooob0?oonf[ooo]Z0_n6o`04oookJP03ool0m?oonf[o/`3o00Cooo]Z00?oo`2Z
oookJ_oonfX00_oonfX00ooo:03ooo]ZoookJP07oookJP03ohKo0?oonf[ooo]Z013ooo]Z1_oob@1V
oookJPGo0:co9?oonfXLool0MQ;ooo]Z0_l0[?lEoookJP03ok00oooonf[ooo]Z00Oooo]Z00?ookD0
oookJ_oonfX01OoonfX00ooo9P3ooo]ZoookJP06oookJP05oona0?oonf[ooo]ZoookJ_l0WOl05_oo
nfX4o`00O`Cooo]Z1ol007l7oookJP04o`000?mW0?oo0000o`0000[ooo]Z00?oo`1MoookJ_oonfX0
2?oonfX00oo30?oooo]ZoookJP08oookJP03oiT0oooonf[oKP3o00_ooo]Z00?o0?l;oookJ_oonfX0
4OoonfX00oooV@3ooo]ZoookJP06oookJP03o`18oooonf[ooo]Z013ooo]Z00CoH?l0oookJ_oonf[o
oi000ooonfX01Ooo0:3ooo]ZoookJ_oonf[oo`2;00;ooo]Z00?o_03ooookJ_oonfX00_oonfX01omb
o`3ooo]ZoookJ_oonf[o1P3ooookJ_oo02H02_oonfX01Ol0gooooo]ZoookJ_oonf[oo`2k00Kooo]Z
00?o^@3ooookJ_mKo`001_oonfX00ooolP3ooo]ZoookJP02ohKo00Cooo]Z00?oo`3doookJ_nc0?l0
1OoonfX01Ooo0:[ooo]ZoookJ_oonf[o0?lC00[ooo]Z00?oQ_l0oookJ_oonfX04?oonfX00ol00Ooo
oo]ZoookJP0[oookJP00??oonfX5o`2/oagooo]Z3?oo07HGoookJPgoolT00_oo07H5oookJP[oo`00
4?oonfX2ok00o`Cooo]Z00?oobP0oookJ_oonfX01Ooo0004oookJP03oolV0?oonf[ooo]Z00;ooo]Z
1?oo00000ooo/@3oo`00ool00004oolX01Gooo]Z0ol007l5oookJPGo001o1?oonfX8oolX00Gooo]Z
2?oo:005oookJPOoogT00ooonfX5oolX0003ofh0oooonf[ooo]Z00Oooo]Z1_oo000AoookJP03oonI
0?oonf[ooo]Z00;ooo]Z1Ooo:00@oookJP03ool00?oonf[ooo]Z00KoobP00ooonfX01?oo08_ooo]Z
oolX0?oo:003oookJP04og;o0?oonf[ooo]ZoookJP?oo`0000?oo`0Vool00?oo00000_oo0006oook
JP03o`3OooooN@3oogT000KoogT000Cooo]ZokT0oooonf[oobP00ooonfX3oolX0005oookJ_oolP3o
oo]ZoookJ_n6o`001OoonfX00ooo0?Cooo]Zok<0o`04oookJP03ool0Z_oonf[ooo]Z00;ooo]Z00?o
obP0oookJ_oonfX01ooonfX00on6o`3ooo]ZoookJP0@oookJP03ooo90?oonf[oolT000CoolT00_oo
nfX2obl0oegooo]Z1Ol0[?lMoookJPcoo`1f7?oonfX;ool0MQoooo]Z00?o/03ooookJ_oonfX01ooo
nfX00ooo]@3ooo]ZoookJP05oookJP03oolV0?oonf[ooo]Z00Kooo]Z00Cook40oookJ_oonf[o09go
5ooonfX3o`00O`Gooo]Z1Ol007l8oookJP04ofL0ool0003o0000o`0000Wooo]Z00?oo`1MoookJ_oo
nfX02?oonfX00oo30?oooo]ZoookJP09oookJP03oiT0oom^0?oooo]Z00[ooo]Z00?o0?l;oookJ_oo
nfX04_oonfX00oooV@3ooo]ZoookJP05oookJP03o`18oooonf[ooo]Z013ooo]Z00GoH?l0oookJ_oo
nf[ooel0oon@0002oookJP05ool0X?oonf[ooo]ZoookJ_oo08/00_oonfX00onl0?oooo]ZoookJP02
oookJP07og;o0?oonf[ooo]ZoookJ_l60?oooo]Zool09P0:oookJP05o`3Ooooonf[ooo]ZoookJ_oo
0;/01_oonfX00oni0?oooo]Zoe_o0006oookJP04ooob0?oonf[ooo]ZohKo00Gooo]Z00?oo`3doook
J_nc0?l01OoonfX01Ooo0:[ooo]ZoookJ_oonf[o0?lC00[ooo]Z00?oQ_l0oookJ_oonfX04?oonfX0
0ol00Ooooo]ZoookJP06oookJP;o;`3o9?oonfX003Oooo]Z1Ol0[?lIoookJPWoo`1f9_oonfX:ooo9
00;ooo]Z1ooo07H8ool001;ooo]Z00?o/03ooookJ_oonfX01OoonfX6ool000;ooo]Z00?oobH0oook
J_oonfX00_oonfX4ool00003oona0?oonf[oobP000GoobP0:?oonfX5oolX00Cooo]Z2Ooo:007oook
JP04ol<0ooooN@3oogT0oomi00?ooo]Z1_oo:0000om^0?oooo]ZoookJP08oookJPGoo`004?oonfX0
1?ooV@3ooo]ZoookJ_oonfX6oolX013ooo]Z00?oo`00oookJ_oonfX01ooo:002oookJP03ool0Rooo
nf[oobP000;oobP00_oonfX00ombo`3ooo]ZoookJP02oookJP03oolX0?oo003oo`0V00Coo`001Ooo
nfX00oooN@3o0=oooomi0007oomi0004oookJ_ni0?oooo]ZoolX00Gooo]Z00?oobP0oookJ_oolP00
0_oonfX00on6o`3ooo]ZoookJP03oookJP03ool0m?oonf[o/`3o00Cooo]Z00?oo`2ZoookJ_oonfX0
0_oonfX00ooo:03ooo]ZoookJP07oookJP03ohKo0?oonf[ooo]Z013ooo]Z00CoolT0oookJ_oonf[o
oo]Z0ooob@02oookJP03obl0oooonf[ooo]Z05Sooo]Z1Ol0[?lIoookJPWoo`1f<ooonfX7ool0MQWo
oo]Z00?o/03ooookJ_oonfX01ooonfX00ooo]@3ooo]ZoookJP04oookJP03oolV0?oonf[ooo]Z00Ko
oo]Z00Gook40oookJ_oonf[ooo]Zo`2Mo`0[oookJP04ofL0ool0003o0000o`0000Wooo]Z00?oo`1M
oookJ_oonfX02?oonfX00oo30?oooo]ZoookJP08oookJP03oiT0oooonf[oKP3o00_ooo]Z00?o0?l;
oookJ_oonfX04OoonfX00oooV@3ooo]ZoookJP05oookJP03o`18oooonf[ooo]Z013ooo]Z00GoH?l0
oookJ_oonf[ooel0oon@0002oookJP05ool0X?oonf[ooo]ZoookJ_oo08/00ooonfX01Onl0?oooo]Z
oookJ_oonf[oL_l000?ooo]Z00?o1P3ooookJ_oo02H02_oonfX01Ol0gooooo]ZoookJ_oonf[oo`2k
00Kooo]Z00?o^@3ooookJ_mKo`001_oonfX01?oolP3ooo]ZoookJ_n6o`05oookJP03ool0m?oonf[o
/`3o00Gooo]Z00Goo`2ZoookJ_oonf[ooo]Zo`3o4`0:oookJP03ohKo0?oonf[ooo]Z013ooo]Z00?o
007ooookJ_oonfX01_oonfX00ol_0?oooo]ZoookJP0ToookJP00<_oonfX5o`2/oaSooo]Z1_oo07Hb
oookJPOoolT02OoonfX2ool0MPKoo`004ooonfX00on`0?oooo]ZoookJP04oookJPOoo`000_oonfX0
0ooo9P3ooo]ZoookJP02oookJP?oo`0000?ooo]Zoona0?oo:0001_oo:00XoookJP04ofL0ool0003o
obP0oolX00Kooo]Z1_oo:007oookJP05ol<0oooonf[ooo]ZoookJ_ooN@000_oonfX6oolX0003ofh0
oooo:03ooo]Z00Wooo]Z00?oo`00oookJ_oo00000_oo000?oookJP04oonI0?oonf[ooo]ZoookJPOo
obP03ooonfX00ooo003ooo]ZoookJP07oolX00;ooo]Z00?oo`2;oolX0?oo:0000_oo:002oookJP03
og;o0?oonf[ooo]Z00;ooo]Z00?oobP0ool00?oo02H01Ooo0004oookJP03oomi0?l0goooogT000Oo
ogT000Cooo]ZokT0oooonf[oobP01ooonfX01?oolP3ooo]ZoookJ_n6o`05oookJP03ool0m?oonf[o
/`3o00Cooo]Z00?oo`2ZoookJ_oonfX00_oonfX00ooo:03ooo]ZoookJP06oookJP;oQ_l04_oonfX0
0ooob@3ooo]ZoookJP03oookJP04ooo90?oonf[ooo]Zobl0oeKooo]Z1Ol0[?lHoookJPKoo`1f@ooo
nfX3ool0MQOooo]Z00?o/03ooookJ_oonfX01ooonfX00ooo]@3ooo]ZoookJP04oookJP03oolV0?oo
nf[ooo]Z00Kooo]Z00Cook40oookJ_oonf[o09go:ooonfX01?mW0?oo0000o`000?l00008oookJP03
ool0GOoonf[ooo]Z00Sooo]Z00?o``3ooookJ_oonfX02OoonfX00onI0?ooKP3ooookJP0:oookJP03
o`3o2ooonf[ooo]Z017ooo]Z00?ooiT0oookJ_oonfX01OoonfX00ol0B?oooo]ZoookJP0@oookJP05
of3o0?oonf[ooo]ZoomO0?ooT0000_oonfX01Ooo0:3ooo]ZoookJ_oonf[oo`2;00?ooo]Z00Go_03o
oookJ_oonf[ooo]Zog;o0003oookJP03o`H0oooonf[oo`0V00[ooo]Z00Go0=oooookJ_oonf[ooo]Z
ool0^`06oookJP03okT0oooonf[oFol000Kooo]Z00Cooo80oookJ_oonf[oQ_l01OoonfX00ooo0?Co
oo]Zok<0o`05oookJP05ool0Z_oonf[ooo]ZoookJ_l0oa<02OoonfX2ohKo01;ooo]Z00?o007ooook
J_oonfX01_oonfX00ol_0?oooo]ZoookJP0UoookJP00;ooonfX3o`2/oaSooo]Z1Ooo07HkoookJPCo
olT03?oonfX01?oo07Koo`00ool00?oo000EoookJP;oobP01OoonfX8ool00003oookJ_oo:03oobP0
00;ooo]Z00Goo`00oookJ_oonf[ooo]Zoona0007oolX02Oooo]Z00?oI`3oo`000?l000000_l00008
oookJP04ool0GOoo:03oobP0oolX00Oooo]Z00?o``3ooookJ_oonfX00ooonfX6oolX0003ofh0oooo
:03ooo]Z00Wooo]Z00Goo`00oookJ_oonf[ooo]Zool0000?oookJP04oonI0?oonf[ooo]ZoookJPOo
obP03ooonfX00ooo003ooo]ZoookJP08oolX0003oookJ_oo:03oobP000?oobP00_oonfX00ombo`3o
oo]ZoookJP02oookJP03oolX0?oo003oo`0V00;ooo]Z0ooo0005oookJP03o`3Ooooo003oogT000Oo
ogT000?o^@3ooookJ_oo:0001ooonfX01?oolP3ooo]ZoookJ_n6o`04oookJP;oobP000?ooo]Zok<0
oooonfX00ooonfX01_oo0:[ooo]ZoookJ_oonf[o0?lCoolX00Sooo]Z00?oQ_l0oookJ_oonfX04Ooo
nfX00ooob@3ooo]ZoookJP06oookJP03obl0oooonf[ooo]Z00;ool00D?oonfX3o`2/oaSooo]Z1Ooo
07I<oookJP?oo`1f5OoonfX2ok00o`oooo]Z00?oobH0oookJ_oonfX01OoonfX01?oo/@3ooo]Zoook
J_l0WOlZoookJP03ofL0ool0003o000000;o00002?oonfX00ooo05gooo]ZoookJP08oookJP03ol<0
oooonf[ooo]Z00Sooo]Z00?oV@3oofh0oooonfX02_oonfX00ol0o`_ooo]ZoookJP0AoookJP03oonI
0?oonf[ooo]Z00Kooo]Z00?o04SooookJ_oonfX03ooonfX01OmPo`3ooo]ZoookJ_ooG`3ooi0000;o
oo]Z00Goo`2PoookJ_oonf[ooo]Zool0R`03oookJP05ok`0oooonf[ooo]ZoookJ_mbo`000ooonfX0
0ol60?oooo]Zool09P0:oookJP05o`3Ooooonf[ooo]ZoookJ_oo0;/01_oonfX00oni0?oooo]Zoe_o
0006oookJP04ooob0?oonf[ooo]ZohKo00Cooo]Z0_oo0?@00ooonf[o/`3ooookJP04oookJP03ool0
Z_oonf[ooo]Z00;o0?lC2OoonfX00on6o`3ooo]ZoookJP0@oookJP;o007o2?oonfX00ol_0?oooo]Z
oookJP02ooo002Cooo]Z000/oookJP?o0:co5_oonfX5ool0MT?ooo]Z00?oolT0oookJ_oonfX03Ooo
nfX01?oo003oo`1fool0M_oo07HBoookJPGoobP00_oonfX9ool000?oobP01_oonfX00ooo/@3oobP0
oolX0005oolX02Kooo]Z00?oI`3oo`000?l000000_l00007oookJP05ool0GOoonf[ooo]ZoookJ_oo
:0001_oonfX00oo30?oooo]ZoookJP06oookJPCoobP000?oKP3ooolX0?oonfX07?oonfX00oooV@3o
oo]ZoookJP09oolX00kooo]Z00?oo`00oookJ_oonfX02?oo:0000ooonf[oobP0oolX0004oolX0003
oookJ_mbo`3ooo]Z00?ooo]Z00?oobP0ool00?oo02H01?oonfX00ooo003ooo]ZoookJP02oookJP03
ool00?l0goooo`0000;oo`001_ooN@000oni0?oooo]ZoolX0007oookJP04ooob0?oonf[ooo]ZohKo
00?ooo]Z1?oo:0001?nc0?oooo]ZoookJ_oonfX2ool0ZP?ooo]Z00?o0?lCoookJ_oonfX01ooonfX0
0on6o`3ooo]ZoookJP0AoookJP03ooo90?oonf[ooo]Z00Kooo]Z00Co;`3ooookJ_oonf[ool00Cooo
nfX3o`2/oaKooo]Z1Ooo07IDoookJP?oo`1f5?oonfX00on`0?oooo]ZoookJP0<oookJP03oolV0?oo
nf[ooo]Z00Kooo]Z00Cook40oookJ_oonf[o09go:OoonfX00omW0?oo0000o`000002o`0000Sooo]Z
00?oo`1MoookJ_oonfX01ooonfX00oo30?oooo]ZoookJP09oookJP03oiT0oom^0?oooo]Z01gooo]Z
00?ooiT0oookJ_oonfX01_oonfX00ol0B?oooo]ZoookJP0?oookJP05of3o0?oonf[ooo]ZoookJ_oo
T0000_oonfX01Ooo0:3ooo]ZoookJ_oonf[oo`2;00?ooo]Z00Go_03ooookJ_oonf[ooo]Zog;o0003
oookJP03o`H0oooonf[oo`0V00[ooo]Z00Go0=oooookJ_oonf[ooo]Zool0^`06oookJP03okT0oooo
nf[oFol000Kooo]Z00Cooo80oookJ_oonf[oQ_l01?oonfX01?oo0?Cooo]ZoookJ_nc0?l4oookJP;o
o`2Z0_oonfX00ol0oa?ooo]ZoookJP08oookJP03ohKo0?oonf[ooo]Z013ooo]Z00?o007ooookJ_oo
nfX01ooonfX01?l_0?oooo]ZoookJ_oo`00VoookJP00:_oonfX2o`2/oaCooo]Z1Ooo07ILoookJPCo
o`1f3ooonfX6oolX0003oookJ_oo003oo`0000Ooo`000ooo:005oookJP03oona0?oo:03oobP000Ko
obP09OoonfX00omW0?oo0000o`000002o`0000Oooo]Z00?oo`1MoookJ_oonfX02?oonfX00oo30?oo
oo]ZoookJP07oookJP;oobP000?oKP3ooolX0?oo:0007OoonfX00oooV@3ooo]ZoolX0008oolX00ko
oo]Z00?oo`00oookJ_oonfX03ooo:002oookJP07og;o0?oonf[ooo]ZoookJ_oo:03oo`00ool09P08
oookJP;oo`0000Ko0=ooool00?oo003oo`00oomi0?oo0003oomi00;o^@3o00?ooo]ZoolX0?oonfX0
1_oonfX01?oolP3ooo]ZoookJ_n6o`03oookJPCoobP000Go/`3ooookJ_oonf[ooo]Zool0ZP04oook
JP03o`3o4ooonf[ooo]Z00Oooo]Z00?oQ_l0oookJ_oonfX04OoonfX00ooob@3ooo]ZoookJP06oook
JP04obl0oooonf[ooo]Zooo004kooo]Z0_l0[?lDoookJPGoo`1fG?oonfX4ool0MQ7ooo]Z0_n`0?l=
oookJP03oolV0?oonf[ooo]Z00Gooo]Z00Cook40oookJ_oonf[o09go:OoonfX00omW0?oo0000o`00
0002o`0000Oooo]Z00?oo`1MoookJ_oonfX02?oonfX00oo30?oooo]ZoookJP08oookJP03oiT0oom^
0?oooo]Z01kooo]Z00?ooiT0oookJ_oonfX01OoonfX00ol0B?oooo]ZoookJP0?oookJP05of3o0?oo
nf[ooo]ZoookJ_ooT0000_oonfX01Ooo0:3ooo]ZoookJ_oonf[oo`2;00?ooo]Z00?o_03ooookJ_oo
nfX00_oonfX01_mbo`3ooo]ZoookJ_l60?oooo]Zool09P[ooo]Z00Go0=oooookJ_oonf[ooo]Zool0
^`05oookJP;o^@3o00?ooo]Zoe_o0?oonfX01OoonfX01?oolP3ooo]ZoookJ_n6o`04oookJP04ool0
m?oonf[ooo]Zok<0o`Cooo]Z00Goo`2ZoookJ_oonf[ooo]Zo`3o4`0:oookJP03ohKo0?oonf[ooo]Z
013ooo]Z00?o007ooookJ_oonfX01_oonfX01Ol0O?oo;`3ooookJ_oonf[ool0002Oooo]Z000koook
JPGoo`1fIOoonfX3ool0MPgooo]Z1ooo:008ool000CoobP01OoonfX6oolX02Kooo]Z00?oI`3ooook
J_l000001?l00005oookJP03ool0GOoonf[ooo]Z00Sooo]Z00?o``3ooookJ_oonfX02?oonfX01?nI
0?oooo]Zofh0oooo:00MoookJP03oonI0?oonf[oobP000WoobP04OoonfX00oooG`3oobP0oolX000<
oolX0003oookJ_mbo`3ooo]Z00;ooo]Z00?oobP0ool00?oo02H02?oonfX2ool00005o`3Ooooo003o
o`00ool00?ooN@000_oo00001_oonf[oogT0okT0ooooN@3ooo]ZoolX00Oooo]Z00Cooo80oookJ_oo
nf[oQ_l00_oonfX4oolX00;oo`000ooonfX00ooo0:[ooo]ZoookJP02oookJP03o`3o4ooonf[ooo]Z
00Oooo]Z00?oQ_l0oookJ_oonfX04OoonfX00ooob@3ooo]ZoookJP06oookJP04obl0oooonf[ooo]Z
ooo0063ooo]Z1Ooo07IUoookJP?oo`1f4?oonfX00on`0?oooo]ZoookJP0;oookJP03oolV0?oonf[o
oo]Z00Gooo]Z00?ook40oookJ_l0WOl0:?oonfX00omW0?oooo]Zo`000004o`0000Kooo]Z00?oo`1M
oookJ_oonfX01ooonfX00oo30?oooo]ZoookJP09oookJP03oiT0oom^0?oooo]Z01gooo]Z00?ooiT0
oookJ_oonfX01OoonfX00ol0B?oooo]ZoookJP0CoookJP05oon@0?oonf[ooo]ZoookJ_oo0:000_oo
nfX01Ooo08_ooo]ZoookJ_oonf[o_03o00Cooo]Z00KoL_l0oookJ_oonf[o1P3ooookJ_oo02H:oook
JP05o`3Ooooonf[ooo]ZoookJ_oo0;/01OoonfX01?ni0?oooo]ZoookJ_mKo`06oookJP04ooob0?oo
nf[ooo]ZohKo00Cooo]Z00Coo`3doookJ_nc0?oo/`3o1?oonfX01Ooo0:[ooo]ZoookJ_oonf[o0?lC
00[ooo]Z00?oQ_l0oookJ_oonfX04?oonfX00ol00Ooooo]ZoookJP06oookJP05o`1lool_0?oooo]Z
oookJ_oo`000:?oonfX003Oooo]Z1?oo07I]oookJP;oo`1f3?oonfX9oolX00Goo`0000?ooo]ZoolX
0?oo:0000_oo:004oookJP?oobP00_oo000WoookJP03ool00?oonf[o000000?o00001_oonfX00ooo
05gooo]ZoookJP07oookJP03ol<0oooonf[ooo]Z00Sooo]Z00GoV@3ooookJ_m^0?oooo]ZoolX000L
oookJP03oonI0?oonf[ooo]Z00;ooo]Z1ooo:00AoookJP03oomO0?ooT03ooo]Z00coobP000?ooo]Z
og;o0?oonfX00_oonfX01?oo:03oo`00oookJ_oo02H7oookJP;oo`0000Go0=ooool00?oo003oo`00
oomi0002ool000;ooo]Z00Co^@3ooomi0?oonf[oobP01ooonfX01OoolP3ooo]ZoookJ_n6o`3ooo]Z
00CoobP01?oo0002oookJP03ool0Z_oonf[ooo]Z00;ooo]Z00?o0?lCoookJ_oonfX01ooonfX00on6
o`3ooo]ZoookJP0@oookJP;oolT01ooonfX2obl0o`;ooo]Z00?ool00oookJ_oonfX0FooonfX4ool0
MVgooo]Z0_oo07H?oookJP;o/03o3?oonfX00ooo9P3ooo]ZoookJP04oookJP04oona0?oonf[ooo]Z
o`2MobOooo]Z00?oI`3ooookJ_l000000ol00007oookJP03ool0GOoonf[ooo]Z00Oooo]Z00?o``3o
oookJ_oonfX02?oonfX00onI0?ooKP3ooookJP0MoookJP03oonI0?oonf[ooo]Z00Gooo]Z00?o04So
oookJ_oonfX04ooonfX01OooT03ooo]ZoookJ_oonf[oo`2P00;ooo]Z00Goo`2;oookJ_oonf[ooo]Z
ok`0o`04oookJP07og;o0?oonf[ooo]Zo`H0oooonf[oG_l0ool09P09oookJP05o`3Ooooonf[ooo]Z
oookJ_oo0;/01OoonfX01?ni0?oooo]ZoookJ_mKo`06oookJP04ooob0?oonf[ooo]ZohKo00Cooo]Z
00?oo`3doookJ_nc0?l01OoonfX01Ooo0:[ooo]ZoookJ_oonf[o0?lC00[ooo]Z00?oQ_l0oookJ_oo
nfX04?oonfX00ol00Ooooo]ZoookJP06oookJP;o;`3o0_oonfX00ooo`03ooo]ZoookJP0WoookJP00
<ooonfX4ool0MW?ooo]Z00?oo`1foookJ_oonfX02OoonfX;oolX00;oo`000_oonfX6oolX00;ooo]Z
0_oo:0001?oonf[oo`00ool00?oo000VoookJP03ool00?oonf[o000000?o00001_oonfX00ooo05go
oo]ZoookJP07oookJP03ol<0oooonf[ooo]Z00Sooo]Z00?oV@3oofh0oooonfX07OoonfX00oooV@3o
oo]ZoookJP04oookJPKoobP04?oonfX01?ooG`3ooi00oookJ_oonfX;oolX0003oookJ_mbo`3ooo]Z
00;ooo]Z00CoobP0ool00?oonf[oo`0V2OoonfX01Ol0goooo`00ool00?oo003oogT000?oo`0000Go
oo]ZokT0oooonf[ooo]ZoolX0007oookJP04ooob0?oonf[ooo]ZohKo00GoobP01?oo0002oookJP03
ool0Z_oonf[ooo]Z00;ooo]Z00?o0?lCoookJ_oonfX01ooonfX00on6o`3ooo]ZoookJP0@oookJP03
ooo90?oonf[ooo]Z00Kooo]Z00?o;`3ooookJ_oonfX00_oo`004oookJP;o0?nVE?oonfX4ool0MW?o
oo]Z00?oo`1foookJ_oonfX03_oonfX00on`0?oooo]ZoookJP0:oookJP03oolV0?oonf[ooo]Z00Co
oo]Z00?ook40oookJ_l0WOl09ooonfX00omW0?oooo]Zo`000003o`0000Kooo]Z00?oo`1MoookJ_oo
nfX02?oonfX00oo30?oooo]ZoookJP07oookJP03oiT0oom^0?oooo]Z01gooo]Z00?ooiT0oookJ_oo
nfX01_oonfX00ol0B?oooo]ZoookJP0BoookJP05oon@0?oonf[ooo]ZoookJ_oo0:000ooonfX01?oo
08_ooo]ZoookJ_nl0?l4oookJP07og;o0?oonf[ooo]Zo`H0oooonf[oG_l0ool09P09oookJP05o`3O
oooonf[ooo]ZoookJ_oo0;/01OoonfX01?ni0?oooo]ZoookJ_mKo`06oookJP04ooob0?oonf[ooo]Z
ohKo00Cooo]Z00?oo`3doookJ_nc0?l01OoonfX01Ooo0:[ooo]ZoookJ_oonf[o0?lC00[ooo]Z00?o
Q_l0oookJ_oonfX03ooonfX2o`01o`Sooo]Z00?o;`3ooookJ_oonfX00_oo`004oookJP;o0?nV9?oo
nfX0033ooo]Z0ooo07IhoookJP;oo`1f2_oonfX;oolX00?ooo]Z1ooo:002oookJP;oobP00ooo000U
oookJP;oo`0000?ooo]Zo`000?l000000_l00005oookJP03ool0GOoonf[ooo]Z00Oooo]Z00?o``3o
oookJ_oonfX02?oonfX00onI0?oooo]Zofh0o`0NoookJP03oonI0?oonf[ooo]Z00Cooo]Z1Ooo:00@
oookJP05oomO0?ooT03ooo]ZoookJ_oo:0000_oonfX9oolX0008og;o0?oonf[ooo]ZoookJ_l60?oo
o`00oookJ_oo02H9oookJP05o`3Ooooonf[oo`00ool00?ooN@000ooo00001Ooonf[o^@3ooookJ_oo
nf[oobP000Oooo]Z00Cooo80oookJ_oonf[oQ_l01?oo:005ool000;ooo]Z00?oo`2ZoookJ_oonfX0
0_oonfX00ol0oa?ooo]ZoookJP07oookJP03ohKo0?oonf[ooo]Z013ooo]Z00?oolT0oookJ_oonfX0
1_oonfX01?l_0?oooo]ZoookJ_oo`005oookJP03o`3oY_lco`3o<ol0057ooo]Z0ooo07IhoookJP;o
o`1f3ooonfX00on`0?oooo]ZoookJP09oookJP03oolV0?oonf[ooo]Z00Cooo]Z00Cook40oookJ_oo
nf[o09go9_oonfX00omW0?oooo]Zo`000003o`0000Kooo]Z00?oo`1MoookJ_oonfX01ooonfX00oo3
0?oooo]ZoookJP08oookJP03oiT0oom^0?oooo]Z01gooo]Z00?ooiT0oookJ_oonfX01OoonfX00ol0
B?oooo]ZoookJP0BoookJP05oon@0?oonf[ooo]ZoookJ_oo0:000ooonfX01?oo08_ooo]ZoookJ_nl
0?l4oookJP07og;o0?oonf[ooo]ZoookJ_l60?ooG_l0ool09P09oookJP05o`3Ooooonf[ooo]Zoook
J_oo0;/01OoonfX01?ni0?oooo]Zoe_o0?mKo`06oookJP04ooob0?oonf[ooo]ZohKo00Cooo]Z00?o
o`3doookJ_nc0?l01OoonfX01Ooo0:[ooo]ZoookJ_oonf[o0?lC00[ooo]Z00?oQ_l0oookJ_oonfX0
3ooonfX00ol00Ooooo]ZoookJP07oookJP04obl0oooonf[ooo]Zooo000Gooo]Z00?o0?nVoc?o0?lc
o`009?oonfX002cooo]Z1?oo07ImoookJP;oo`1f2OoonfX:oolX00Cooo]Z1ooo:0001?oonf[oobP0
oolX0?oo:003ool002?ooo]Z0ooo00000ooonf[o0000o`000002o`0000Gooo]Z00?oo`1MoookJ_oo
nfX01ooonfX00oo30?oooo]ZoookJP08oookJP03oiT0oom^0?oooo]Z01gooo]Z00?ooiT0oookJ_oo
nfX01?oonfX00ooo:03ooo]ZoookJP03oolX00oooo]Z00Gooel0oon@0?oonf[ooo]ZoolX0003oook
JP03ool0Rooo:03oobP000GoobP000SoL_l0oookJ_oonf[ooo]Zo`H0ool0<Ooooo]Zool09PSooo]Z
0_oo:003oookJP03oomi0?oo003oo`0000;oo`0000Co^@3ooookJ_oonf[oFol01ooonfX01?oolP3o
oo]ZoookJ_n6o`03oolX00Ooo`0000?ooo]Zool0Z_oonfX00ooonfX00ol0oa?ooo]ZoookJP07oook
JP03ohKo0?oonf[ooo]Z013ooo]Z00?oolT0oookJ_oonfX01_oonfX01?l_0?oooo]ZoookJ_oo`005
oookJP04o`3oY_lco`3oC`3oodl0odgooo]Z1?oo07ImoookJP;oo`1f3_oonfX00on`0?oooo]Zoook
JP09oookJP03oolV0?oonf[ooo]Z00?ooo]Z00Cook40oookJ_oonf[o09go9OoonfX00omW0?oooo]Z
oookJP04o`0000Kooo]Z00?oo`1MoookJ_oonfX01ooonfX00oo30?oooo]ZoookJP07oookJP03oiT0
oom^0?oooo]Z01gooo]Z00?ooiT0oookJ_oonfX01OoonfX00ol0B?oooo]ZoookJP0BoookJP05oon@
0?oonf[ooo]ZoookJ_oo0:000ooonfX01?oo08_ooo]ZoookJ_nl0?l4oookJP07og;o0?oonf[ooo]Z
oookJ_l60?oo037oool09P09oookJP05o`3Ooooonf[ooo]ZoookJ_oo0;/01OoonfX00oni0?oooo]Z
oe_o0007oookJP04ooob0?oonf[ooo]ZohKo00Cooo]Z00?oo`3doookJ_nc0?l01OoonfX01Ooo0:[o
oo]ZoookJ_oonf[o0?lC00[ooo]Z00?oQ_l0oookJ_oonfX03ooonfX00ol00Ooooo]ZoookJP06oook
JP05o`1lool_0?oooo]ZoookJ_oo`0001OoonfX01?l0ojKo<ol0odl0oom?0?lToookJP00:_oonfX2
ool0MX?ooo]Z0ooo07H7oookJPSoobP01OoonfX<oolX00?oo`008_oonfX3ool00003oookJ_l0003o
000000;o00001?oonfX00ooo003ooo]ZoookJP07oookJP03ol<0oooonf[ooo]Z00Sooo]Z00?oV@3o
oookJ_m^0?l07OoonfX00oooV@3ooo]ZoookJP04oookJP03oolX0?oonf[ooo]Z00;ooo]Z00?oobP0
oookJ_oonfX03OoonfX01OooG`3ooi00oookJ_oonf[oobP000?ooo]Z00?oo`2;oookJ_oonfX01Ooo
:0002?mbo`3ooo]ZoookJ_oonf[o1P3oo`0aoooonf[oo`0V2?oonfX3oolX00;ooo]Z00?oogT0oook
J_oo00000_oo00001?ni0?oooo]ZoookJ_mKo`07oookJP04ooob0?oonf[ooo]ZohKo00;oobP02?oo
00000ooonf[oo`2ZoookJP03oookJP03o`3o4ooonf[ooo]Z00Oooo]Z00?oQ_l0oookJ_oonfX04?oo
nfX00ooob@3ooo]ZoookJP06oookJP04obl0oooonf[ooo]Zooo000Gooo]Z00?o0?nVoc?o0?m?0?l0
COoonfX2ool0MX?ooo]Z0ooo07H<oookJP03ok00oooonf[ooo]Z00Wooo]Z00?oobH0oookJ_oonfX0
0ooonfX01?oo/@3ooo]ZoookJ_l0WOlToookJP03ofL0oooonf[ooo]Z00Co00001OoonfX00ooo05go
oo]ZoookJP07oookJP03ol<0oooonf[ooo]Z00Oooo]Z00?oV@3ooookJ_m^0?l07OoonfX00oooV@3o
oo]ZoookJP05oookJP03o`18oooonf[ooo]Z01;ooo]Z00Gooi00oookJ_oonf[ooo]Zool0X003oook
JP04ool0Rooonf[ooo]Zok`0o`Cooo]Z00OoL_l0oookJ_oonf[ooo]Zo`H0ool0<Oooo`0V00Wooo]Z
00Go0=oooookJ_oonf[ooo]Zool0^`05oookJP03okT0oooonf[oFol000Oooo]Z00Cooo80oookJ_oo
nf[oQ_l01?oonfX00ooo0?Cooo]Zok<0o`05oookJP05ool0Z_oonf[ooo]ZoookJ_l0oa<02_oonfX0
0on6o`3ooo]ZoookJP0?oookJP03o`01oooonf[ooo]Z00Kooo]Z00Go07coobl0oooonf[ooo]Zooo0
0005oookJP03o`3oY_lco`3oC`3o02Kooo]Z002boookJP;oo`1f1OoonfX7oolX0003ool00?oonf[o
oo]Z00Cooo]Z3?oo:003ool0023ooo]Z1?oo00000ooonf[o0000o`000002o`0000Cooo]Z00?oo`00
oookJ_oonfX01ooonfX00oo30?oooo]ZoookJP07oookJP03oiT0oooonf[oKP3o01gooo]Z00?ooiT0
oookJ_oonfX01?oonfX00ooo:03ooo]ZoookJP0CoookJP04oon@0?oonf[ooo]ZoolX00?ooo]Z00Co
o`2;oookJ_oonf[oobP00_oonfX2oolX0004og;o0?oonf[ooo]ZoookJP;oo`0000?ooo]Zool09_oo
nfX01_oonfX4oolX00;ooo]Z00KoogT0oookJ_oonf[ooo]Zool00?ni0?l2oookJP03oe_o0?oonf[o
oo]Z00Gooo]Z00Kooo80oookJ_oonf[oQ_l0oookJ_oo:009ool00003ool0Z_oonf[ooo]Z00;ooo]Z
00?o0?lCoookJ_oonfX01ooonfX00on6o`3ooo]ZoookJP0@oookJP03ooo90?oonf[ooo]Z00Kooo]Z
00Co;`3ooookJ_oonf[ool001OoonfX00ol0ojKo<ol0odl0o`3FoookJP;oo`1f2ooonfX00on`0?oo
oo]ZoookJP08oookJP03oolV0?oonf[ooo]Z00?ooo]Z00?ook40oookJ_oonfX09OoonfX00omW0?oo
oo]ZoookJP04o`0000Gooo]Z00?oo`1MoookJ_oonfX01ooonfX00oo30?oooo]ZoookJP07oookJP03
oiT0oom^0?oooo]Z01cooo]Z00?ooiT0oookJ_oonfX01OoonfX00ol0B?oooo]ZoookJP0BoookJP05
oon@0?ooG`3ooo]ZoookJ_oo0:000ooonfX01?oo08_ooo]ZoookJ_nl0?l4oookJP07og;o0?oonf[o
oo]ZoookJ_l60?oo037oool09P09oookJP05o`3Ooooonf[ooo]ZoookJ_oo0;/01OoonfX00oni0?oo
oo]Zoe_o0007oookJP04ooob0?oonf[ooo]ZohKo00Cooo]Z00?oo`3doookJ_nc0?l01OoonfX01Ooo
0:[ooo]ZoookJ_oonf[o0?lC00[ooo]Z00?oQ_l0oookJ_oonfX03ooonfX00ol00Ooooo]ZoookJP06
oookJP05o`1lool_0?oooo]ZoookJ_oo`0001?oonfX2o`3oYP03oc?o0?m?0?oooo]Z02Kooo]Z002d
oookJP;oo`1f1?oonfX5oolX00?oo`001OoonfX<oolX00?oo`008?oonfX4ool00003oookJ_l0003o
000000;o00000ooonfX2ool000Sooo]Z00?o``3ooookJ_oonfX02?oonfX00onI0?ooKP3ooookJP0K
oookJP;oo`001ooonfX00ol0B?oooo]ZoookJP0BoookJP04oon@0?oonf[ooo]ZoolX00?ooo]Z00Co
o`2;oookJ_oonf[oobP01?oonfX01?mbo`3ooo]ZoookJ_oonfX3ool00003ool09_oonf[ooo]Z00Go
oo]Z1Ooo:0000ooonf[oogT0oookJP03oookJP04okT0oooonf[ooo]Zoe_o00Oooo]Z00Gooo80oook
J_oonf[oQ_l0oookJP0:ool00004ool0Z_oonf[ooo]ZoookJP;o0?lC2?oonfX2ohKo01;ooo]Z00?o
olT0oookJ_oonfX01_oonfX01?l_0?oooo]ZoookJ_oo`004oookJP;o0?nV00?o<ol0odl0oooonfX0
f?oonfX2ool0MP[ooo]Z00?o/03ooookJ_oonfX02?oonfX00ooo9P3ooo]ZoookJP02oookJP03oona
0?oonf[ooo]Z02Gooo]Z00?oI`3ooookJ_oonfX01?l00004oookJP03ool0GOoonf[ooo]Z00Oooo]Z
00?o``3ooookJ_oonfX01ooonfX00onI0?ooKP3ooookJP0LoookJP03oonI0?oonf[ooo]Z00Kooo]Z
00?o04SooookJ_oonfX04OoonfX01OooT03ooel0oookJ_oonf[oo`2P00?ooo]Z00Coo`2;oookJ_oo
nf[o_03o1?oonfX01ombo`3ooo]ZoookJ_oonf[o1P3ooookJ_oo02H02OoonfX01Ol0gooooo]Zoook
J_oonf[oo`2k00Gooo]Z00?o^@3ooookJ_mKo`001ooonfX01?oolP3ooo]ZoookJ_n6o`04oookJP03
ool0m?oonf[o/`3o00Gooo]Z00Goo`2ZoookJ_oonf[ooo]Zo`3o4`09oookJP;oQ_l04OoonfX00ol0
0Ooooo]ZoookJP06oookJP05o`1lool_0?oooo]ZoookJ_oo`0001?oonfX01?l0ojKo<ol0oc?o0?m?
0?lXoookJP00]_oonfX00ooo07Kooo]ZoookJP02oookJP?oobP000?ooo]Zool00?oo00000ooo0004
oookJPKoobP000?ooo]ZoolX0?oo:0000ooo:003ool001kooo]Z1Ooo00000ooonf[o0000o`000002
o`0000;ooo]Z0ooo0008oookJP03ol<0oooonf[ooo]Z00Oooo]Z00?oV@3ooookJ_m^0?l06ooonfX3
ool000Kooo]Z00?o04SooookJ_oonfX04_oonfX01OooT03ooo]ZoookJ_oonf[oo`2P00;ooo]Z00Co
o`2;oookJ_oonf[oobP01OoonfX00ombo`3ooo]Zool00003ool00003ool09_oonf[ooo]Z00Cooo]Z
1_oo:0000ooonf[oo`2koookJP03oookJP04okT0oooonf[ooo]Zoe_o00Oooo]Z00Gooo80oookJ_oo
nf[oQ_l0oookJP0:ool00005ool0Z_oonf[ooo]ZoookJ_l0oa<02OoonfX00on6o`3ooo]ZoookJP0@
oookJP03o`01oooob@3ooo]Z00Kooo]Z0_l_0?l2oookJP03ooo00?oonf[ooo]Z00;ooo]Z00Co0?nV
oookJ_lco`3oC`3og?oonfX00ooo07Kooo]ZoookJP08oookJP03ok00oooonf[ooo]Z00Oooo]Z00?o
obH0oookJ_oonfX00ooonfX00ooo/@3ooo]ZoookJP0ToookJP03ofL0oooonf[ooo]Z00Co00001?oo
nfX00ooo05gooo]ZoookJP07oookJP03ol<0oooonf[ooo]Z00Oooo]Z00?oV@3oofh0oooonfX07?oo
nfX00oooV@3ooo]ZoookJP05oookJP03o`18oooonf[ooo]Z017ooo]Z00?ooi00oomO0?oonfX00_oo
nfX01?oo0:3ooo]ZoookJ_oo08/2oookJP03ok`0oooonf[ooo]Z00;ooo]Z00OoL_l0oookJ_oonf[o
oo]Zo`H0oooonf[oo`0V00Wooo]Z00Go0=oooookJ_oonf[ooo]Zool0^`05oookJP03okT0oooonf[o
Fol000Oooo]Z00Cooo80oookJ_oonf[oQ_l01?oonfX00ooo0?Cooo]Zok<0o`04oookJP;oo`2Z0ooo
nfX00ol0oa?ooo]ZoookJP07oookJP03ohKo0?oonf[ooo]Z00oooo]Z0_l00Ol8oookJP;o;`3o00?o
oo]Zooo00?oo`0001?oonfX01?l0ojKo<ol0odl0oom?0?lYoookJP00]ooonfX00ooo07Kooo]Zoook
JP02oookJP03oolX0?oonf[ooo]Z00Ooo`000_oonfX5oolX0003ool00?oonf[oobP000GoobP00ooo
000LoookJPGoo`000_oonfX4o`0000;ooo]Z0ooo0008oookJP03ol<0oooonf[ooo]Z00Oooo]Z00?o
V@3ooolX0?oonfX06_oonfX3ool000Kooo]Z00?o04SooookJ_oonfX04OoonfX2oiCo00?ooo]Z00Co
o`2PoookJ_oonf[oo`2;0_oonfX00ooo:03ooo]ZoookJP03oookJP03og;o0?oo003oo`0000?oo`00
00?oo`0VoookJ_oonfX00ooonfX7oolX0003oookJ_oo0;_ooo]Z00?ooo]Z00Co^@3ooookJ_oonf[o
Fol01ooonfX01?oolP3ooo]ZoookJ_n6o`04oookJPSoo`000ooonfX00ol0oa?ooo]ZoookJP07oook
JP03ohKo0?oonf[ooo]Z013ooo]Z00?o007ooookJ_oonfX01_oonfX01Ol_0?oo07cooookJ_oonf[o
ol0000Cooo]Z00Co0?nVoookJ_m?0?ooC`3og_oonfX2ool0MPWooo]Z00?o/03ooookJ_oonfX01ooo
nfX00ooo9P3ooo]ZoookJP03oookJP03oona0?oonf[ooo]Z02;ooo]Z00CoI`3ooookJ_oonf[ooo]Z
1?l00003oookJP03ool0GOoonf[ooo]Z00Oooo]Z00?o``3ooookJ_oonfX01ooonfX00onI0?ooKP3o
oookJP0LoookJP03oonI0?oonf[ooo]Z00Gooo]Z00?o04SooookJ_oonfX04OoonfX00oooT03ooel0
oookJP02oookJP04ool0X?oonf[ooo]Zool0R`;ooo]Z00?o_03ooookJ_oonfX00_oonfX01ombo`3o
oo]ZoookJ_oonf[o1P3ooookJ_oo02H02OoonfX01Ol0gooooo]ZoookJ_oonf[oo`2k00Gooo]Z00?o
^@3ooookJ_mKo`001ooonfX01?oolP3ooo]ZoookJ_n6o`04oookJP03ool0m?oonf[o/`3o00Cooo]Z
00?oo`2ZoookJ_oonfX00_oonfX00ol0oa?ooo]ZoookJP07oookJP03ohKo0?oonf[ooo]Z00oooo]Z
00?o007ooookJ_oonfX01_oonfX01Ol0O?oo;`3ooookJ_oonf[ool0000Gooo]Z00?o0?nVoc?o0?m?
0?l0:ooonfX00;Sooo]Z00?oo`1foookJ_oonfX01OoonfX8ool000?oobP000Cooo]Zool00?oo003o
o`001ooo:002ool001cooo]Z1Ooo0002oookJPCo000000?ooo]Zool00?oo00000_oo0007oookJP03
ol<0oooonf[ooo]Z00Oooo]Z00?oo`00oolX0?oo:0006_oonfX4ool000Gooo]Z00?o04SooookJ_oo
nfX04OoonfX3oiCo00;ooo]Z00Ooo`2PoookJ_oonf[ooo]Zool0Rooonf[oobP000Gooo]Z00?oL_l0
ool00?oo00000ooo00000ooo02Kooo]ZoookJP03oookJPSoobP000?oo`2koookJ_oonfX00_oonfX0
1?ni0?oooo]ZoookJ_mKo`07oookJP04ooob0?oonf[ooo]ZohKo00Cooo]Z00?oobP0oookJ_oo0000
1Ooo0003oookJP03o`3o4ooonf[ooo]Z00Oooo]Z00?oQ_l0oookJ_oonfX04?oonfX00ol00Ooooo]Z
oookJP06oookJP03obl0oooonf[ooo]Z00;ool001?oonfX00ol0ojKooo]Zodl0o`3RoookJP03ool0
M_oonf[ooo]Z00Oooo]Z00?o/03ooookJ_oonfX01ooonfX00ooo9P3ooo]ZoookJP02oookJP03oona
0?oonf[ooo]Z02;ooo]Z00CoI`3ooookJ_oonf[ooo]Z1?l00003oookJP03ool0GOoonf[ooo]Z00Oo
oo]Z00?o``3ooookJ_oonfX01_oonfX00onI0?oooo]Zofh0o`0LoookJP03oonI0?oonf[ooo]Z00Go
oo]Z00?o04SooookJ_oonfX04_oonfX01OooT03ooo]ZoookJ_oonf[oo`2P00;ooo]Z00Coo`2;oook
J_oonf[o_03o1?oonfX01ombo`3ooo]ZoookJ_oonf[o1P3ooookJ_oo02H02OoonfX01Ol0gooooo]Z
oookJ_oonf[oo`2k00Gooo]Z00?o^@3ooookJ_mKo`001ooonfX01?oolP3ooo]ZoookJ_n6o`04oook
JP03ool0m?oonf[o/`3o00Cooo]Z00?oo`2ZoookJ_oonfX00_oonfX00ol0oa?ooo]ZoookJP07oook
JP03ohKo0?oonf[ooo]Z00oooo]Z00?o007ooookJ_oonfX01_oonfX01Ol0O?oo;`3ooookJ_oonf[o
ol0000Cooo]Z0_l0ojH00olco`3oC`3ooookJP0[oookJP00^OoonfX2ool0MPKooo]Z2?oo00000ooo
:03ooo]ZoookJP03ool000SoobP00_oo000JoookJPKoo`000_oonfX4o`0000Goo`001ooonfX00oo3
0?oooo]ZoookJP06oookJP04ool00?oo:03oobP0oolX01Wooo]Z1Ooo0005oookJP03o`18oooonf[o
oo]Z00oooo]Z1?nDo`02oookJP05ool0X?oonf[ooo]ZoookJ_oo08/00_oonfX00onl0?oooo]Zoook
JP02oookJP03og;o0?oo003oo`0000?oo`0000?oo`0Vool00?oonfX00_oonfX9oolX0003ool0^ooo
nf[ooo]Z00;ooo]Z00Co^@3ooookJ_oonf[oFol01ooonfX01?oolP3ooo]ZoookJ_n6o`04oookJP04
oolX0?oonf[oo`00oookJPGoo`000_oonfX00ol0oa?ooo]ZoookJP07oookJP03ohKo0?oonf[ooo]Z
013ooo]Z00?o007ooookJ_oonfX01_oonfX01?l_0?oooo]ZoookJ_oo`005oookJP03o`3oY_oonf[o
C`3o0>Cooo]Z0_oo07HAoookJP03oolV0?oonf[ooo]Z00?ooo]Z00?ook40oookJ_oonfX09OoonfX4
o`0000?ooo]Z00?oo`1MoookJ_oonfX01_oonfX00oo30?oooo]ZoookJP07oookJP03oiT0oom^0?oo
oo]Z01cooo]Z00?ooiT0oookJ_oonfX01?oonfX00ol0B?oooo]ZoookJP0BoookJP05oon@0?oonf[o
oo]ZoookJ_oo0:000_oonfX01Ooo08_ooo]ZoookJ_oonf[o_03o00?ooo]Z00OoL_l0oookJ_oonf[o
oo]Zo`H0oooonf[oo`0V00Wooo]Z00Go0=oooookJ_oonf[ooo]Zool0^`05oookJP03okT0oooonf[o
Fol000Oooo]Z00Cooo80oookJ_oonf[oQ_l01?oonfX00ooo0?Cooo]Zok<0o`04oookJP03ool0Z_oo
nf[ooo]Z00;ooo]Z00?o0?lCoookJ_oonfX01ooonfX00on6o`3ooo]ZoookJP0?oookJP03o`01oooo
nf[ooo]Z00Kooo]Z00Go07coobl0oooonf[ooo]Zooo00004oookJP04o`3oY_oonf[o<ol0odl0obgo
oo]Z002koookJP;oo`1f1OoonfX9ool00004oookJ_oo003oo`00ool000WoobP00_oo000IoookJPKo
o`000_oonfX4o`0000Goo`001_oonfX00oo30?oooo]ZoookJP06oookJP04ool00?oo:03oobP0oolX
01Sooo]Z1_oo0005oookJP03o`18oooonf[ooo]Z00oooo]Z1OnDo`000ooonf[oo`2PoookJP02oook
JP04ool0Rooonf[ooo]Zok`0o`?ooo]Z00?oo`00og;o0?oo00001?oo00000ooo02Koo`00oookJP02
oookJP[oobP01?oonfX01?ni0?oooo]ZoookJ_mKo`07oookJP04ooob0?oonf[ooo]ZohKo00Cooo]Z
00?oobP0oookJ_oo00000ooonfX3ool000;ooo]Z00?o0?lCoookJ_oonfX01ooonfX00on6o`3ooo]Z
oookJP0@oookJP03o`01oooonf[ooo]Z00Kooo]Z00Co;`3ooookJ_oonf[ool001?oonfX2o`3oYP03
oc?o0?m?0?oooo]Z0>Kooo]Z0_oo07H@oookJP03oolV0?oonf[ooo]Z00;ooo]Z00?ook40oookJ_oo
nfX09OoonfX4o`0000;ooo]Z00?oo`1MoookJ_oonfX01ooonfX00oo30?oooo]ZoookJP06oookJP03
oiT0oooonf[oKP3o01cooo]Z00?ooiT0oookJ_oonfX01?oonfX00ol0B?oooo]ZoookJP0BoookJP05
oon@0?oonf[ooo]ZoookJ_oo0:000_oonfX01Ooo08_ooo]ZoookJ_oonf[o_03o00?ooo]Z00OoL_l0
oookJ_oonf[ooo]Zo`H0oooonf[oo`0V00Wooo]Z00Go0=oooookJ_oonf[ooo]Zool0^`05oookJP03
okT0oooonf[oFol000Oooo]Z00Cooo80oookJ_oonf[oQ_l01?oonfX00ooo0?Cooo]Zok<0o`04oook
JP03ool0Z_oonf[ooo]Z00;ooo]Z00?o0?lCoookJ_oonfX01ooonfX00on6o`3ooo]ZoookJP0?oook
JP03o`01oooonf[ooo]Z00Kooo]Z00Go07coobl0oooonf[ooo]Zooo00004oookJP04o`3oY_lco`3o
C`3oodl0obkooo]Z002CoookJP?oo`009ooonfX2ool0MP?ooo]Z3_oo0006oolX00;oo`006_oonfX7
ool000;ooo]Z0ol00005ool000Oooo]Z00?o``3ooookJ_oonfX01OoonfX00ooo003oobP0oolX0002
oolX01Oooo]Z1ooo0004oookJP03o`18oooonf[ooo]Z00kooo]Z1_nDo`000ooonf[oo`2PoookJP02
oookJP04ool0Rooonf[ooo]Zok`0o`?ooo]Z00?oo`00og;o0?oo00001?oo00000ooo02Koo`00ool0
0002oookJP[oobP01?oonfX01?ni0?oooo]ZoookJ_mKo`07oookJP04ooob0?oonf[oobP0oolX00Co
oo]Z00?oobP0oookJ_oo00000ooonfX00ooo0:[ooo]Zool00002oookJP03o`3o4ooonf[ooo]Z00Oo
oo]Z00?oQ_l0oookJ_oonfX03ooonfX2o`01o`Sooo]Z00Co;`3ooookJ_oonf[ool001?oonfX01?l0
ojKooo]Zoc?o0?m?0?oZoookJP03ool0M_oonf[ooo]Z01?ooo]Z00?ook40oookJ_oonfX09?oonfX4
o`0000;ooo]Z00?oo`1MoookJ_oonfX01_oonfX00oo30?oooo]ZoookJP07oookJP03oiT0oom^0?oo
oo]Z01_ooo]Z00?ooiT0oookJ_oonfX01?oonfX00ol0B?oooo]ZoookJP0BoookJP05oon@0?oonf[o
oo]ZoookJ_oo0:000_oonfX01Ooo08_ooo]ZoookJ_oonf[o_03o00?ooo]Z00OoL_l0oookJ_oonf[o
oo]Zo`H0oooonf[oo`0V00Wooo]Z00Go0=oooookJ_oonf[ooo]Zool0^`05oookJP03okT0oooonf[o
Fol000Oooo]Z00Cooo80oookJ_oonf[oQ_l01?oonfX00ooo0?Cooo]Zok<0o`04oookJP03ool0Z_oo
nf[ooo]Z00;ooo]Z00?o0?lCoookJ_oonfX01ooonfX00on6o`3ooo]ZoookJP0?oookJP03o`01oooo
nf[ooo]Z00Kooo]Z00?o07coobl0oooonfX00_oo`004oookJP03o`3oY_lco`3oC`3o033ooo]Z002?
oookJPOoo`00:OoonfX2oomi00;ooo]Z2?oo0002oookJP?oo`000ooo:002ool001cooo]Z2?oo0002
oookJP;o00001_oo0007oookJP03ol<0oooonf[ooo]Z00Cooo]Z00?oo`00oolX0?oo:0000ooo:00F
oookJPOoo`001?oonfX00ol0B?oooo]ZoookJP0>oookJPOoU?l000Goo`2PoookJ_oonf[ooo]Zool0
R`02oookJP06ok`0oooonf[ooo]ZoookJ_oo003oL_l01Ooo00000ooo02Koo`00ool00005oookJPSo
obP00ooonfX01?ni0?oooo]ZoookJ_mKo`07oookJP03ooob0?oo:03oobP000;oobP00ooonfX00ooo
:03ooo]Zool00003oookJP03ool0Z_oonf[ooo]Z00;ooo]Z00?o0?lCoookJ_oonfX01ooonfX00on6
o`3ooo]ZoookJP0?oookJP03o`01oooonf[ooo]Z00Kooo]Z00Go07coobl0oooonf[ooo]Zooo00004
oookJP04o`3oY_oonf[o<ol0odl0oncooo]Z0_oo07HCoookJP03oona0?oonf[ooo]Z02Cooo]Z1?l0
00000ooonf[oo`1MoookJP08oookJP03ol<0oooonf[ooo]Z00Kooo]Z00?oV@3ooookJ_m^0?l06ooo
nfX00oooV@3ooo]ZoookJP05oookJP03o`18oooonf[ooo]Z017ooo]Z00Gooi00oomO0?oonf[ooo]Z
ool0X002oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l00ooonfX01ombo`3ooo]ZoookJ_oonf[o1P3o
oookJ_oo02H02OoonfX01Ol0gooooo]ZoookJ_oonf[oo`2k00Gooo]Z00?o^@3ooookJ_mKo`001ooo
nfX01?oolP3ooo]ZoookJ_n6o`04oookJP03ool0m?oonf[o/`3o00Cooo]Z00?oo`2ZoookJ_oonfX0
0_oonfX00ol0oa?ooo]ZoookJP07oookJP03ohKo0?oonf[ooo]Z00oooo]Z00?o007ooookJ_oonfX0
1_oonfX01?l0O?oo;`3ooookJ_oo`004oookJP;o0?nV00?o<ol0odl0oooonfX0<?oonfX007Sooo]Z
0_oo:00BoookJP[oo`00:OoonfX4oomi0003oookJ_oo003oo`0000Coo`000ooonfX3ool00003oolX
0?oo003oo`0000?oo`007_oonfX5ool000;ooo]Z0_l00006ool000Kooo]Z00?o``3ooookJ_oonfX0
1?oonfX00ooo003oobP0oolX0004oolX01Gooo]Z2?oo0003oookJP03o`18oooonf[ooo]Z00kooo]Z
1onDo`001Ooo0:3ooo]ZoookJ_oonf[oo`2;00;ooo]Z00?o_03ooookJ_oonfX00_oonfX00ombo`3o
o`00ool00003ool00004ool09_oo003oo`00ool000Kooo]Z1_oo:003oookJP04okT0oooonf[ooo]Z
oe_o00Oooo]Z00?ooo80oolX0?oo:0000_oo:003oookJP03oolX0?oonf[oo`0000?ooo]Z00?oo`2Z
oookJ_oonfX00_oonfX00ol0oa?ooo]ZoookJP07oookJP03ohKo0?oonf[ooo]Z00oooo]Z00?o007o
oookJ_oonfX01_oonfX2obl0o`;ooo]Z00?ool00oookJ_oonfX00_oonfX01?l0ojKooo]Zodl0oom?
0?l;oookJP;oo`2<h_oonfX00ooo07Kooo]ZoookJP0@oookJP03oona0?oonf[ooo]Z02Cooo]Z1Ol0
0009oookJP03ol<0oooonf[ooo]Z00Oooo]Z00?oV@3oofh0oooonfX06ooonfX00oooV@3ooo]Zoook
JP04oookJP03o`18oooonf[ooo]Z017ooo]Z00Gooi00oomO0?oonf[ooo]Zool0X002oookJP05ool0
Rooonf[ooo]ZoookJ_nl0?l00ooonfX01ombo`3ooo]ZoookJ_oonf[o1P3ooookJ_oo02H02OoonfX0
1Ol0gooooo]ZoookJ_oonf[oo`2k00Gooo]Z00?o^@3ooookJ_mKo`001ooonfX01?oolP3ooo]Zoook
J_n6o`04oookJP03ool0m?oonf[o/`3o00Cooo]Z00?oo`2ZoookJ_oonfX00_oonfX00ol0oa?ooo]Z
oookJP07oookJP03ohKo0?oonf[ooo]Z00kooo]Z0_l00Ol8oookJP;o;`3o00?ooo]Zooo00?oonfX0
0ooonfX01?l0ojKooo]Zoc?o0?m?0?l<oookJP;oo`2<9?oonfX007Gooo]Z1Ooo:00>oookJPkoo`00
:_oonfX4oomi00Goo`001?oonfX:ool0023ooo]Z0_oo0002oookJP03o`000?oo003oo`0000Goo`00
1_oonfX00oo30?oooo]ZoookJP03oookJP03ool00?oo:03oobP000CoobP05OoonfX9ool000?ooo]Z
00?o04SooookJ_oonfX03?oonfX9oiCo0004ool0X?oonf[ooo]Zool0R`;ooo]Z00?o_03ooookJ_oo
nfX00_oonfX00ombo`3ooo]ZoookJP03ool00004ool09_oo003oo`00ool000Kooo]Z00?oobP0oook
J_oo:0000ooo:003oookJP04okT0oooonf[ooo]Zoe_o00Oooo]Z00?ooo80oolX0?oo:0000_oo:003
oookJP03oolX0?oonf[oo`0000?ooo]Z00?oo`2ZoookJ_oonfX00_oonfX00ol0oa?ooo]ZoookJP07
oookJP03ohKo0?oonf[ooo]Z00oooo]Z00?o007ooookJ_oonfX01_oonfX01Ol_0?oooo]ZoookJ_oo
nf[ool0000Cooo]Z00?o0?nVoookJ_m?0?l03?oonfX00ooo08coogl0oomo003SoookJP03ool0M_oo
nf[ooo]Z013ooo]Z00?ook40oookJ_oonfX08ooonfX4o`0000[ooo]Z00?o``3ooookJ_oonfX01_oo
nfX00onI0?oooo]Zofh0o`0KoookJP03oonI0?oonf[ooo]Z00Cooo]Z00?o04SooookJ_oonfX04Ooo
nfX01OooT03ooel0oookJ_oonf[oo`2P00;ooo]Z00Goo`2;oookJ_oonf[ooo]Zok`0o`04oookJP06
og;o0?oonf[ooo]Zo`H0oooonf[oo`0V2OoonfX01Ol0gooooo]ZoookJ_oonf[oo`2k00Gooo]Z00?o
^@3ooookJ_mKo`001ooonfX01?oolP3ooo]ZoookJ_n6o`04oookJP03ool0m?oonf[o/`3o00Cooo]Z
00?oo`2ZoookJ_oonfX00_oonfX00ol0oa?ooo]ZoookJP07oookJP03ohKo0?oonf[ooo]Z00kooo]Z
00?o007ooookJ_oonfX01_oonfX01Ol0O?oo;`3ooookJ_oonf[ool0000Cooo]Z00Co0?nVoookJ_m?
0?ooC`3o3?oonfX00ooo08coogl0oomo000ToookJP00LooonfX7oolX00Wooo]Z0olJo`0Aool002[o
oo]Z1?ooN@03ool000Kooo]Z2_oo000SoookJPSoo`001OoonfX00oo30?oooo]ZoookJP03oookJP03
ool00?oo:03oobP000GoobP05?oonfX9ool000?ooo]Z00?o04SooookJ_oonfX03?oonfX9oiCo0004
ool0X?oonf[ooo]Zool0R`;ooo]Z00?o_03ooookJ_oonfX00_oonfX01ombo`3ooo]ZoookJ_l60?oo
oo]Zool00?oo02H01?oo0005oookJP04oolX0?oonf[ooo]ZoookJP?oobP000?ooo]ZoolX0?oo:000
0_oonfX00omKo`3ooo]ZoookJP04oookJP03oolX0?oolP3oobP000CoobP000Gooo]Zool0m?oo:03o
oo]Zool00003oookJP03ool0Z_oonf[ooo]Z00;ooo]Z00?o0?lCoookJ_oonfX01ooonfX00on6o`3o
oo]ZoookJP0?oookJP03o`01oooonf[ooo]Z00Kooo]Z00?o;`3ooookJ_oonfX00_oo`003oookJP;o
0?nV00?o<ol0odl0oooonfX02ooonfX00ooo08coogl0oookJP2VoookJPoo6_l0<?oonfX00ooo07Ko
oo]ZoookJP0?oookJP03oona0?oonf[ooo]Z02?ooo]Z1?l00009oookJP03ol<0oooonf[ooo]Z00Oo
oo]Z00?oV@3oofh0oooonfX06_oonfX00oooV@3ooo]ZoookJP04oookJP03o`18oooonf[ooo]Z01;o
oo]Z00Cooi00oookJ_oonf[oo`2P0_oonfX01Ooo08_ooo]ZoookJ_oonf[o_03o00Cooo]Z00KoL_l0
oookJ_oonf[o1P3ooookJ_oo02H9oookJP05o`3Ooooonf[ooo]ZoookJ_oo0;/01OoonfX00oni0?oo
oo]Zoe_o0007oookJP04ooob0?oonf[ooo]ZohKo00?ooo]Z0_oo0?@00ooonf[o/`3ooookJP03oook
JP03ool0Z_oonf[ooo]Z00;ooo]Z00?o0?lCoookJ_oonfX01ooonfX00on6o`3ooo]ZoookJP0>oook
JP03o`01oooonf[ooo]Z00Kooo]Z00Go07coobl0oooonf[ooo]Zooo00004oookJP03o`3oY_lco`3o
C`3o00gooo]Z00?oo`2<oomo0?oonfX09OoonfX0077ooo]Z00?oobP0ool00?oo00001_oo:002oook
JPOo6_l01_oonfX>ool002[ooo]Z1OooN@000ooo003oogT0oomi0005oookJP[oo`008ooonfX2o`00
00Koo`001OoonfX00oo30?oooo]ZoookJP02oookJP03ool00?oo:03oobP000KoobP05_oonfX7ool0
00;ooo]Z00?o04SooookJ_oonfX03?oonfX9oiCo0004ool0X?oonf[ooo]Zool0R`;ooo]Z00?o_03o
oookJ_oonfX00_oonfX01ombo`3ooo]Zool00?oo003ooo]Zool00?oo02H01?oo0005oookJP08oolX
0?oonf[ooo]ZoookJ_oo0;_ooo]ZoolX0?oonfX3oolX0003oookJ_mKo`3ooo]Z00Cooo]Z0_oo:000
0ooolP3oobP0oolX0003oolX0005oookJ_oo0?Cooo]ZoookJ_oo00000_oonfX2oolX00?ooo]Z0_oo
0008oookJP;oQ_l04?oonfX2o`01o`Sooo]Z00Co;`3ooookJ_oonf[ool001?oonfX01?l0ojKooo]Z
oc?o0?m?0?l<oookJP03ool0S?ooO`3ooo]Z0:3ooo]Z1olJo`10oookJP03ool0M_oonf[ooo]Z03Co
oo]Z1?l00009oookJP03ol<0oooonf[ooo]Z00Kooo]Z00?oV@3ooookJ_m^0?l06ooonfX00oooV@3o
oo]ZoookJP03oookJP03o`18oooonf[ooo]Z01;ooo]Z00Cooi00oookJ_oonf[oo`2P0_oonfX01Ooo
08_ooo]ZoookJ_oonf[o_03o00Cooo]Z00KoL_l0oookJ_oonf[o1P3ooookJ_oo02H9oookJP05o`3O
oooonf[ooo]ZoookJ_oo0;/01OoonfX00oni0?oooo]Zoe_o0007oookJP04ooob0?oonf[ooo]ZohKo
00?ooo]Z00Coo`3doookJ_oonf[o/`3o0ooonfX2ool0ZP?ooo]Z0_l0oa<8oookJP;oQ_l04?oonfX0
0ol00Ooooo]ZoookJP06oookJP05o`1lool_0?oooo]ZoookJ_oo`0000ooonfX2o`3oYP03oc?o0?m?
0?oooo]Z00cooo]Z00?oo`2<oomo0?oonfX09_oonfX006kooo]Z00?oobP0ool00?oo00000ooo0007
oolX0003oa[o0?oonf[ooo]Z00oooo]Z2_oo000[oookJPWoogT00ooonfX;ool002;ooo]Z1?l00000
1?oonf[oo`00ool00?oo0004oookJP03ol<0oooonf[ooo]Z00;ooo]Z00?oo`00oolX0?oo:0001_oo
:00HoookJPGoo`0000?ooo]Zool00?oo00003OoonfX4ool000KoU?l000Coo`2PoookJ_oonf[oo`2;
0ooonfX01_nl0?oooo]ZoookJ_oonf[oL_l0oookJPCoo`0000?oo`0VoookJ_oonfX00ooo0004oook
JP05oolX0?oonf[ooo]ZoookJ_oo0;/00_oonfX4oolX0003oookJ_mKo`3ooo]Z00Cooo]Z0_oo:000
0ooolP3oobP0oolX0003oolX0006oookJ_oo0?Cooo]ZoookJ_oo003ooo]Z1?oo:0000ooonf[oo`00
ool00002ool000Oooo]Z00?oQ_l0oookJ_oonfX03ooonfX00ol00Ooooo]ZoookJP07oookJP04obl0
oooonf[ooo]Zooo000Cooo]Z00Co0?nVoookJ_lco`3oC`3o2ooonfX00ooo08coogl0oomo0002oook
JP;o0P3oUooonfX7oa[o04Sooo]Z00?oo`1foookJ_oonfX0<ooonfX4o`0000Sooo]Z00?o``3ooook
J_oonfX01ooonfX00onI0?ooKP3ooookJP0JoookJP03oonI0?oonf[ooo]Z00?ooo]Z00?o04Sooook
J_oonfX04_oonfX01?ooT03ooo]ZoookJ_oo0:02oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l01?oo
nfX01_mbo`3ooo]ZoookJ_l60?oooo]Zool09PWooo]Z00Go0=oooookJ_oonf[ooo]Zool0^`05oook
JP03okT0oooonf[oFol000Oooo]Z00Cooo80oookJ_oonf[oQ_l00ooonfX01?oo0?Cooo]ZoookJ_nc
0?l3oookJP03ool0Z_oonf[ooo]Z00;ooo]Z00?o0?lCoookJ_oonfX01ooonfX00on6o`3ooo]Zoook
JP0?oookJP03o`01oooonf[ooo]Z00Kooo]Z0_l_0?l00ooonf[ool00ooo00003oookJP04o`3oY_oo
nf[o<ol0odl0o`cooo]Z00?oo`2<oomo0?ooO`000_oonfX2o`80obCooo]Z001/oookJP03oolX0?oo
003oo`0000Goo`001ooo:00>oookJPkoo`00;?oonfX:oomi0003oookJ_oo003oo`0000?oo`0000?o
oo]Zool00?oo00001?oo000QoookJPCo00000ooonfX00ooo003ooo]ZoookJP02oookJP05ol<0oooo
nf[ooo]ZoookJ_oo00002Ooo:00GoookJP03ool00?oonf[oo`0000Koo`003?oonfX6ool000CoU?l0
00Coo`2PoiCo0?oonf[oo`2;0ooonfX01Onl0?oooo]ZoookJ_oonf[oL_l000Goo`0000?oo`0Voook
J_oonfX00_oonfX00ooo003ooo]ZoookJP02oookJP06oolX0?oonf[ooo]ZoookJ_oo0;_ooo]Z1Ooo
:0000ooonf[oFol0oookJP03oookJP?oobP000?ooo80oolX0?oo:0001?oo:0001?oo0?Cooo]Zoook
J_oo0005oolX00Goo`001ooonfX00on6o`3ooo]ZoookJP0?oookJP03o`01oooonf[ooo]Z00Kooo]Z
0_l_0?l2oookJP03ooo00?oonf[ooo]Z00;ooo]Z00Co0?nVoookJ_m?0?ooC`3o2ooonfX00ooo08co
ogl0oookJP02oookJP03o`80oooonf[ooo]Z093ooo]Z1olJo`1@oookJP03ool0M_oonf[ooo]Z03;o
oo]Z1?l00008oookJP03ol<0oooonf[ooo]Z00Kooo]Z00?oV@3ooookJ_m^0?l06_oonfX00oooV@3o
oo]ZoookJP04oookJP03o`18oooonf[ooo]Z017ooo]Z00Cooi00oookJ_oonf[oo`2P0_oonfX01Ooo
08_ooo]ZoookJ_oonf[o_03o00Cooo]Z00KoL_l0oookJ_oonf[o1P3ooookJ_oo02H9oookJP05o`3O
oooonf[ooo]ZoookJ_oo0;/01OoonfX00oni0?oooo]Zoe_o0007oookJP04ooob0?oonf[ooo]ZohKo
00?ooo]Z00Coo`3doookJ_oonf[o/`3o0ooonfX00ooo0:[ooo]ZoookJP02oookJP03o`3o4ooonf[o
oo]Z00Oooo]Z00?oQ_l0oookJ_oonfX03ooonfX00ol00Ooooo]ZoookJP06oookJP04obl0oooonf[o
oo]Zooo000Cooo]Z00Co0?nVoookJ_m?0?ooC`3o3?oonfX00ooo08coogl0oookJP02oookJP03o`80
oooonf[ooo]Z02Cooo]Z001YoookJP;o6_l02_oo0006oolX00Kooo]Z1_l/o`0@ool000Sooo]Z0ooo
000RoookJP[oogT000Cooo]Zool00?oo003oo`000_oonfX7ool0023ooo]Z1?l00008oookJP03ol<0
oooonf[ooo]Z00Coo`001ooo:00JoookJPGoo`003?oonfX6ool00008oiCo0?oo003oU?l0oiCo0?oo
0:3oU?l0oookJ_oo08/3oookJP05ok`0oooonf[ooo]ZoookJ_mbo`001Ooo00000ooo02Kooo]Zoook
JP07oookJP06oolX0?oonf[ooo]ZoookJ_oo0;_ooo]Z1_oo:0000ooo003ooo]ZoookJP02oookJP?o
obP000?ooo80oolX0?oo:0001?oo:0000ooo0?Cooo]ZoookJP05oolX00Koo`001ooonfX00on6o`3o
oo]ZoookJP0?oookJP03o`01oooonf[ooo]Z00Kooo]Z00Go;`3ooookJ_oonf[ooo]Zooo00004oook
JP03o`3oY_oonf[oC`3o00cooo]Z00?oo`2<oomo0?oonfX00_oonfX00ol20?oooo]ZoookJP2;oook
JPKo6_l00ooonfX4oon300_ooo]Z4ol/o`0coookJP03ool0M_oonf[ooo]Z037ooo]Z1?l00008oook
JP03ol<0oooonf[ooo]Z00Oooo]Z00?oKP3ooookJ_oonfX07ooonfX00ol0B?oooo]ZoookJP0Aoook
JP04oon@0?oonf[ooo]Zool0X0;ooo]Z00Goo`2;oookJ_oonf[ooo]Zok`0o`04oookJP06og;o0?oo
nf[ooo]Zo`H0oooonf[oo`0V2OoonfX01Ol0gooooo]ZoookJ_oonf[oo`2k00Gooo]Z00?o^@3ooe_o
0?mKo`001ooonfX01?oolP3ooo]ZoookJ_n6o`03oookJP03ool0m?oonf[ooo]Z00Cooo]Z00?oo`2Z
oookJ_oonfX00_oonfX00ol0oa?ooo]ZoookJP07oookJP03ohKo0?oonf[ooo]Z00oooo]Z00?o007o
oookJ_oonfX01_oonfX01?l_0?oooo]ZoookJ_oo`004oookJP03o`3oY_oonf[oC`3o00gooo]Z00?o
o`2<oomo0?oonfX00_oonfX00ol20?oooo]ZoookJP0UoookJP00IOoonfX3oa[o00goo`001_oo:006
obco00Cooo]Z0_oo0002oolX00;ooo]Z3?oo0004oookJPOoo`008_oonfX:oomi0003oookJ_oo003o
oo]Z00?ooo]Z2?oo000OoookJPCo00001ooonfX00oo30?oooo]ZoookJP03oookJPCoo`001Ooo:00K
oookJPCoo`003_oonfX3ool00003oiCo0?oo003oo`0000;oo`000_nDo`001Ooo08_ooo]ZoookJ_oo
nf[o_03o00?ooo]Z00?oL_l0ool00?oo00000ooo00000ooo02Kooo]ZoookJP07oookJP05o`3Ooooo
nf[ooo]ZoookJ_oo0;/01ooo:002ool000Cooo]Z0_oo:0000ooolP3oobP0oolX0005oolX00;ooo]Z
1Ooo:007ool000Kooo]Z00?oQ_l0oookJ_oonfX03ooonfX00ol00Ooooo]ZoookJP06oookJP05obl0
oooonf[ooo]ZoookJ_oo`0000ooonfX2o`3oYP03oookJ_m?0?oooo]Z00_ooo]Z00?oo`2<oomo0?oo
nfX00_oonfX00ol20?oooo]ZoookJP28oookJPCo6_l01?oonfX5oon300Oooo]Z2?l/o`17oookJP03
ool0M_oonf[ooo]Z033ooo]Z1?l00007oookJP03ol<0oooonf[ooo]Z00Sooo]Z00?oKP3ooookJ_oo
nfX07_oonfX00ol0B?oooo]ZoookJP0AoookJP04oon@0?oonf[ooo]Zool0X0;ooo]Z00Goo`2;oook
J_oonf[ooo]Zok`0o`04oookJP06og;o0?oonf[ooo]Zo`H0oooonf[oo`0V2_oonfX01?l0gooooo]Z
oookJ_oo0;/5oookJP03okT0oomKo`3ooo]Z00Oooo]Z00Cooo80oookJ_oonf[oQ_l00ooonfX00ooo
0?Cooo]ZoookJP04oookJP03ool0Z_oonf[ooo]Z00;ooo]Z00?o0?lCoookJ_oonfX01ooonfX00on6
o`3ooo]ZoookJP0>oookJP;o007o2?oonfX01?l_0?oooo]ZoookJ_oo`003oookJP;o0?nV00?ooo]Z
odl0oooonfX03?oonfX01?oo08coogl0oookJ_oonfX2o`80obSooo]Z001PoookJPGo6_l000?ooo]Z
ool00?oo00003Ooo0007oolX00Kooo]Z1Ooo0002oolX00Oooo]Z1ooo00000ooonf[oo`00ool00008
ool002?ooo]Z2?ooN@07oookJPWoo`007_oonfX4o`0000Oooo]Z00?o``3ooookJ_oonfX01OoonfX0
0ooo003oKP3oool00003oolX01_ooo]Z1?oo000@oookJP03ool00?nDo`3oo`0000Coo`0000?oU?l0
ool0RooonfX00_oonfX01Onl0?oooo]ZoookJ_oo003oL_l000Goo`0000?oo`0VoookJ_oonfX01ooo
nfX01?l0gooooo]ZoookJ_oonfX9oolX0003ool00?oonf[ooo]Z00Cooo]Z00?ooo80oolX0?oo:000
1Ooo:0000ooonf[oobP0oolX0003oolX00Soo`001_oonfX00on6o`3ooo]ZoookJP0?oookJP03o`01
oooonf[ooo]Z00Kooo]Z00Go;`3ooookJ_oonf[ooo]Zooo00003oookJP04o`3oY_oonf[o<ol0odl0
o`_ooo]Z00?oo`2<oomo0?ooO`000ooonfX00ol20?oooo]ZoookJP25oookJPCo6_l00ooonfX5oon3
00Oooo]Z1Ol/o`1@oookJP03ool0M_oonf[ooo]Z02oooo]Z1?l00007oookJP03ol<0oooonf[ooo]Z
00Oooo]Z00?oKP3ooookJ_oonfX07ooonfX00ol0B?oooo]ZoookJP0@oookJP07oon@0?oonf[ooo]Z
oookJ_oo0:3ooo]Zool0R`03oookJP03ok`0oooonf[ooo]Z00;ooo]Z00KoL_l0oookJ_oonf[o1P3o
oookJ_oo02H:oookJP04o`3Ooooonf[ooo]Zool0^`Gooo]Z00?o^@3ooe_o0?oonfX01ooonfX01?oo
lP3ooo]ZoookJ_n6o`03oookJP03ool0m?oonf[ooo]Z00Cooo]Z00?oo`2ZoookJ_oonfX00_oonfX0
0ol0oa?ooo]ZoookJP07oookJP03ohKo0?oonf[ooo]Z00kooo]Z00?o007ooookJ_oonfX01_oonfX2
obl0o`;ooo]Z00Sool00oookJ_oonf[ooo]Zo`3oY_oonf[o<ol0odl0o`cooo]Z00?oo`2<oomo0?oo
O`000_oonfX00ol20?oooo]ZoookJP0XoookJP00G?oonfX4oa[o00?ooo]Z0_ooP`0@ool000OoobP0
1?oonfX7ool000;oobP02ooonfX>ool002Cooo]Z1_ooN@09oookJPKoo`008?oonfX4o`0000Kooo]Z
00?o``3ooookJ_oonfX01ooonfX01Om^0?ooo`00ool00?oonf[oobP001Wooo]Z1_oo000@oookJP03
ool00?ooT03oo`0000?oo`000_oonfX01Ooo08_ooo]ZoookJ_nl0?oooo]Z00;oo`0000?oL_l0ool0
0?oo00000ooo00000ooo02Kooo]ZoookJP07oookJP04o`3Ooooonf[ooo]ZoookJPWoobP000?oo`00
oookJ_oonfX01?oonfX00ooolP3ooo]ZoolX000:oolX00[oo`001OoonfX00on6o`3ooo]ZoookJP0>
oookJP;o007o2?oonfX01Ol_0?oooo]ZoookJ_oonf[ool0000?ooo]Z00Co0?nVoookJ_lco`3oC`3o
2ooonfX00ooo08coogl0oookJP03oookJP03o`80oooonf[ooo]Z08;ooo]Z1?lJo`02oookJPGooh<0
1ooonfX5obco05Kooo]Z00?oo`1foookJ_oonfX0;_oonfX4o`0000Kooo]Z00?o``3ooookJ_oonfX0
1ooonfX00om^0?oooo]ZoookJP0OoookJP03o`18oooonf[ooo]Z013ooo]Z00Gooel0oon@0?oonf[o
oo]Zool0X002oookJP04ool0Rooonf[ooo]Zok`0o`Cooo]Z00KoL_l0oookJ_oonf[o1P3ooookJ_oo
02H:oookJP04o`3Ooooonf[ooo]Zool0^`Gooo]Z00?o^@3ooe_o0?oonfX01ooonfX01?oolP3ooo]Z
oookJ_n6o`03oookJP03ool0m?oonf[ooo]Z00Cooo]Z00?oo`2ZoookJ_oonfX00_oonfX00ol0oa?o
oo]ZoookJP06oookJP;oQ_l04?oonfX00ol00Ooooo]ZoookJP06oookJP05obl0ool0O?oooo]Zoook
J_oo`0000ooonfX01?l0ojKooo]Zoc?o0?m?0?l<oookJP03ool0S?ooO`3ooo]Z00;ooo]Z00?o0P3o
oookJ_oonfX0:OoonfX005Sooo]Z1?lJo`04oookJP?ooh<01_oonfX2obco00?oobP01ooo0007oolX
0003oookJ_oo003oo`0000Soo`000_oo:004oookJPGo0?o14?oo000ToookJPGoogT02_oonfX3ool0
02?ooo]Z1?l00006oookJP03ol<0oooonf[ooo]Z00Oooo]Z00?oKP3ooookJ_oo00006_oonfX7ool0
00oooo]Z00?oo`00oon@0?oo00001?oo00000ooonf[oo`2;oookJP02ool00004oookJ_oo003oo`00
og;o00Goo`0000?oo`0Vool00?oonfX01ooonfX01?l0gooooo]ZoookJ_oonfX9oolX00;oo`001Ooo
nfX01?oolP3ooo]ZoolX0?oonfX9oolX00[oo`001OoonfX00on6o`3ooo]ZoookJP0>oookJP03o`01
oooonf[ooo]Z00Kooo]Z0_l_0?l2oookJP;ool000ooonfX01?l0ojKooo]Zodl0oom?0?l;oookJP03
ool0S?ooO`3ooo]Z00?ooo]Z00?o0P3ooookJ_oonfX0OooonfX4oa[o00?ooo]Z0oooP`07oookJPGo
;?l07_oonfXAo`3o`Bgooo]Z00?oo`1foookJ_oonfX0;OoonfX4o`0000Kooo]Z00?o``3ooookJ_oo
nfX01ooonfX00om^0?oooo]ZoookJP0NoookJP03o`18oooonf[ooo]Z013ooo]Z00Gooel0oon@0?oo
nf[ooo]Zool0X002oookJP04ool0Rooonf[ooo]Zok`0o`Cooo]Z00KoL_l0oookJ_oonf[o1P3ooook
J_oo02H:oookJP05o`3Ooooonf[ooo]ZoookJ_oo0;/01?oonfX00oni0?ooFol0oookJP07oookJP04
ooob0?oonf[ooo]ZohKo00?ooo]Z00?oo`3doookJ_oonfX01?oonfX00ooo0:[ooo]ZoookJP02oook
JP03o`3o4ooonf[ooo]Z00Kooo]Z00?oQ_l0oookJ_oonfX03ooonfX00ol00Ooooo]ZoookJP06oook
JP03obl0oooonf[ooo]Z00;ool000ooonfX01?l0ojKooo]Zoc?o0?m?0?l<oookJP03ool0S?ooO`3o
oo]Z00;ooo]Z00?o0P3ooookJ_oonfX0:_oonfX005Cooo]Z1?lJo`04oookJPCooh<01OoonfX4obco
00_ooo]Z1ooo:00=ool000;oobP00ol0ol48oookJPgoo`009OoonfX3oomi0003oookJ_oo07Kooo]Z
00Sooo]Z00?oo`00oookJ_oonfX08ooonfX4o`0000Gooo]Z00?o``3ooookJ_oonfX01ooonfX00om^
0?oooo]ZoookJP0JoookJPOoo`003ooonfX7ool00003oookJ_oo08_ooo]Z00Goo`0000?oL_l0ool0
0?oo00000ooo00000ooo02Koo`00oookJP07oookJP03o`3Ooooonf[ooo]Z00;ooo]Z00?oo`2koolX
0?oo:0001_oo:0000ooo003ooo]ZoookJP03oookJP03ooob0?oonf[oobP000?ooo]Z2?oo:009ool0
00Gooo]Z00?oQ_l0oookJ_oonfX03_oonfX00ol00Ooooo]ZoookJP06oookJP05obl0oooonf[ooo]Z
oookJ_oo`0001?oonfX00ol0ojKooo]Zodl0o`0<oookJP03ool0S?ooO`3ooo]Z00;ooo]Z0_l20?mn
oookJPCo6_l00ooonfX4oon300Kooo]Z1?l/o`0HoookJPCo04So1ol0ol4ooookJP03ool0M_oonf[o
oo]Z02cooo]Z1?l00005oookJP03ol<0oooonf[ooo]Z00Oooo]Z00?oKP3ooookJ_oonfX07ooonfX0
0ol0B?oooo]ZoookJP0?oookJP05oomO0?ooT03ooo]ZoookJ_oo0:000_oonfX01Ooo08_ooo]Zoook
J_oonf[o_03o00?ooo]Z00KoL_l0oookJ_oonf[o1P3ooookJ_oo02H:oookJP05o`3Ooooonf[ooo]Z
oookJ_oo0;/01?oonfX00oni0?ooFol0oookJP07oookJP04ooob0?oonf[ooo]ZohKo00?ooo]Z00?o
o`3doookJ_oonfX00ooonfX2ool0ZPCooo]Z00?o0?lCoookJ_oonfX01_oonfX00on6o`3ooo]Zoook
JP0?oookJP03o`01oooonf[ooo]Z00Kooo]Z00Co;`3ooookJ_oonf[ool001?oonfX01?l0ojKooo]Z
oc?o0?m?0?l<oookJP04ool0S?ooO`3ooo]ZoookJP;o0P3o;OoonfX004_ooo]Z0_oo:003oookJPCo
6_l01?oonfX4oon300Gooo]Z1?l/o`0CoookJQ3oo`000_oo:00?oookJPWoo`009_oonfX01OooN@3o
oo]ZoookJ_oonf[oo`1f02kooo]Z1?l00005oookJP03ol<0oooonf[ooo]Z00Oooo]Z00?oKP3ooook
J_oonfX06OoonfX8ool000oooo]Z1ooo00000ooo08_oo`00ool00002ool000;ooo]Z00?oL_l0ool0
0?oo00000ooo00000ooo02Koo`00ool00007oookJP03o`3Ooooonf[ooo]Z00;ooo]Z00?oo`2koook
J_oo00001_oo:002ool000Cooo]Z00?ooo80oookJ_oo:0000ooonfX00ooo0?Cooo]ZoolX0002oook
JPGoobP02?oo0003oookJP;oQ_l04?oonfX00ol00Ooooo]ZoookJP06oookJP05obl0oooonf[ooo]Z
oookJ_oo`0000ooonfX2o`3oYP03oookJ_m?0?oooo]Z00[ooo]Z0_oo08`01OooO`3ooo]ZoookJ_oo
nf[o0P3o07cooo]Z1?lJo`04oookJP?ooh<01OoonfX5obco01Gooo]Z1ol0B?l2o`3o`DSooo]Z00?o
o`1foookJ_oonfX0;?oonfX4o`0000Gooo]Z00?o``3ooookJ_oonfX01ooonfX00om^0?oooo]Zoook
JP0NoookJP03o`18oooonf[ooo]Z013ooo]Z00Cooi00oookJ_oonf[oo`2P0_oonfX01Ooo08_ooo]Z
oookJ_oonf[o_03o00?ooo]Z00KoL_l0oookJ_oonf[o1P3ooookJ_oo02H:oookJP05o`3Ooooonf[o
oo]ZoookJ_oo0;/01?oonfX00oni0?ooFol0oookJP07oookJP04ooob0?oonf[ooo]ZohKo00?ooo]Z
00?oo`3doookJ_oonfX00ooonfX00ooo0:[ooo]ZoookJP02oookJP;o0?lC2?oonfX00on6o`3ooo]Z
oookJP0?oookJP03o`01oooonf[ooo]Z00Gooo]Z0_l_0?l2oookJP04ooo00?oonf[ooo]ZoookJP;o
0?nV00?ooo]Zodl0oom?0?l02ooonfX2ool0S004oomo0?oonf[ooo]Zo`80oboooo]Z001:oookJP?o
obP00olJo`05oookJP?ooh<01OoonfX4obco00;ooo]Z0_oo:00@oookJP;o04So4Ooo0002oolX01;o
oo]Z1_oo000[oookJP03ool0M_oonf[ooo]Z02_ooo]Z1?l00004oookJP03ol<0oooonf[ooo]Z00Oo
oo]Z00?oo`00oookJ_oonfX06OoonfX8ool000oooo]Z1ooo00000ooo08_oo`00ool00003ool00003
oookJ_mbo`3ooo]Z00Coo`0000?oo`0Vool00?oo00001ooonfX00ol0gooooo]ZoookJP02oookJP04
ool0^ooo003oo`00ool000KoobP000?oo`00oookJ_oonfX00_oonfX00ooolP3ooo]ZoolX0003oook
JP03ool0m?oonf[ooo]Z00?ooo]Z1_oo:006ool000?ooo]Z00?oQ_l0oookJ_oonfX03ooonfX00ol0
0Ooooo]ZoookJP06oookJP05obl0oooonf[ooo]ZoookJ_oo`0000ooonfX01?l0ojKooo]Zoc?o0?m?
0?l;oookJP03ool0S?ooO`3oogl000?ooo]Z00?o0P3ooookJ_oonfX0N?oonfX3oa[o00Gooo]Z0ooo
P`04oookJPCo;?l05?oonfX6o`18o`;o0?o1D?oonfX00ooo07Kooo]ZoookJP0[oookJPCo00001?oo
nfX00oo30?oooo]ZoookJP07oookJP03ofh0oooonf[ooo]Z01kooo]Z00?o04SooookJ_oonfX04?oo
nfX01?ooT03ooo]ZoookJ_oo0:02oookJP05ool0Rooonf[ooo]ZoookJ_nl0?l00ooonfX01_mbo`3o
oo]ZoookJ_l60?oooo]Zool09P[ooo]Z00Go0=oooookJ_oonf[ooo]Zool0^`04oookJP03okT0oomK
o`3ooo]Z00Oooo]Z00Cooo80oookJ_oonf[oQ_l00ooonfX00ooo0?Cooo]ZoookJP03oookJP03ool0
Z_oonf[ooo]Z00;ooo]Z00?o0?lCoookJ_oonfX01ooonfX00on6o`3ooo]ZoookJP0?oookJP03o`01
oooonf[ooo]Z00Gooo]Z00Go;`3oo`1loooonf[ooo]Zooo00003oookJP04o`3oY_oonf[o<ol0odl0
o`cooo]Z00?oo`2<oomo0?ooO`000_oonfX00ol20?oooo]ZoookJP0^oookJP00B?oonfX6oolX00?o
oo]Z0ooo:0000oooP`3ooo]ZoookJP02oookJPCo;?l01OoonfX3oolX00_ooo]Z1Ol0B?l3o`3o`@So
oo]Z2?oo0002oolX01Kooo]Z0_oo000/oookJP03ool0M_oonf[ooo]Z02[ooo]Z1Ol00003oookJP03
ol<0oooonf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX06?oonfX9ool000gooo]Z3_oo00000ooonf[o
L_l0oookJP02oookJP;oo`0000Coo`0Vool00?oo003oo`001_oonfX00ol0gooooo]ZoookJP02oook
JP05ool0^ooo003oo`00ool00?oo:0000_oo0003oolX0003ool00?oonf[ooo]Z00;ooo]Z00?ooo80
oookJ_oo:0000ooonfX00ooo0?Cooo]ZoookJP03oookJP03oolX0?oonf[ooo]Z00?oobP000?oo`00
oolX0?oo00001?oo0002oookJP03ohKo0?oonf[ooo]Z00kooo]Z0_l00Ol8oookJP05obl0oooonf[o
oo]ZoookJ_oo`0000ooonfX01?l0ojKooo]Zoc?o0?m?0?l;oookJP03ool0S?ooO`3ooo]Z00?ooo]Z
00?o0P3ooookJ_oonfX0MOoonfX4oa[o00Cooo]Z1?ooP`03oookJPCo;?l04ooonfX5o`18o`?o0?o1
E_oonfX00ooo07Kooo]ZoookJP0ZoookJPGo00000ooonfX00oo30?oooo]ZoookJP07oookJP03ofh0
oooonf[ooo]Z01kooo]Z00?o04SooookJ_oonfX03ooonfX01?ooT03ooo]ZoookJ_oo0:02oookJP05
ool0Rooonf[ooo]ZoookJ_nl0?l00ooonfX01_mbo`3ooo]ZoookJ_l60?oooo]Zool09P[ooo]Z00Go
0=oooookJ_oonf[ooo]Zool0^`04oookJP03okT0oomKo`3ooo]Z00Oooo]Z00Cooo80oookJ_oonf[o
Q_l00ooonfX00ooo0?Cooo]ZoookJP03oookJP03ool0Z_oonf[ooo]Z00;ooo]Z00?o0?lCoookJ_oo
nfX01ooonfX00on6o`3ooo]ZoookJP0>oookJP;o007o1ooonfX01Ol_0?oo07cooookJ_oonf[ool00
00?ooo]Z00Co0?nVoookJ_lco`3oC`3o3?oonfX00ooo08coogl0oookJP02oookJP03o`80oooonf[o
oo]Z02oooo]Z0016oookJP_oobP01OoonfX3obco00Oooo]Z1Ooo:006oookJPGo04So0ol0ol5Loook
JP03ool0M_oonf[ooo]Z02Wooo]Z1?l00004oookJP03ol<0oooonf[ooo]Z00Kooo]Z0_oo000Loook
JPKoo`003OoonfX>ool000;ooo]Z00KoL_l0oookJ_oonf[oo`00oookJ_oo02H3ool000Kooo]Z00?o
0=oooookJ_oonfX00_oonfX01Ooo0;_ooo]ZoookJ_oonf[oobP000Coo`0000?oobP0ool00?oo0000
0_oonfX2ooob0003oookJ_oo:03ooo]Z00;ooo]Z00?oo`3doookJ_oonfX00ooonfX00ooo:03ooo]Z
oookJP02oookJP03oolX0?oo003oobP000;ooo]Z0ooo0002oookJP03ohKo0?oonf[ooo]Z00kooo]Z
00?o007ooookJ_oonfX01_oonfX2obl0o`;ooo]Z0_oo`003oookJP04o`3oY_oonf[oC`3oodl0o`_o
oo]Z00?oo`2<oomo0?oonfX00_oonfX2o`80ogGooo]Z0olJo`05oookJP?ooh<01?oonfX3obco01;o
oo]Z1Ol0B?l3o`3o`Ecooo]Z00?oo`1foookJ_oonfX0:OoonfX4o`0000Cooo]Z00?o``3ooookJ_oo
nfX01_oonfX00om^0?oooo]ZoookJP0NoookJP03o`18oooonf[ooo]Z00oooo]Z00Cooi00oookJ_oo
nf[oo`2P0_oonfX01Ooo08_ooo]ZoookJ_oonf[o_03o00Cooo]Z00GoL_l0oookJ_l60?oooo]Zool0
9P0:oookJP05o`3Ooooonf[ooo]ZoookJ_oo0;/01?oonfX00oni0?ooFol0oookJP06oookJP;ooo80
0_oonfX01On6o`3ooo]ZoookJ_oonf[oo`3d00Gooo]Z00?oo`2ZoookJ_oonfX00_oonfX00ol0oa?o
oo]ZoookJP06oookJP;oQ_l04?oonfX00ol00Ooooo]ZoookJP06oookJP05obl0ool0O?oooo]Zoook
J_oo`0000ooonfX01?l0ojKooo]Zoc?o0?m?0?l<oookJP04ool0S?ooO`3ooo]ZoookJP;o0P3o<_oo
nfX004?ooo]Z0_lJo`0:oolX00Cooo]Z0ol/o`08oookJP_oobP00_l0B?l3o`3o`F7ooo]Z00?oo`1f
oookJ_oonfX0:OoonfX4o`0000?ooo]Z00?o``3ooookJ_oonfX01_oonfX2ool001kooo]Z1Ooo000<
oookJPooo`0000Sooo]Zog;o0?oonf[ooo]Zool00?oonf[oo`0VoookJP?oo`001OoonfX00ol0gooo
oo]ZoookJP02oookJP06ool0^ooonf[ooo]ZoookJ_oo:03ooo]Z1_oo0002oookJP04ooob0?oonf[o
oo]ZoolX00?ooo]Z00?oo`3doookJ_oonfX00ooonfX00ooo:03ooo]ZoookJP03oookJP03ool00?oo
:03ooo]Z00?ooo]Z00Coo`00oookJ_oonf[oQ_l04?oonfX00ol00Ooooo]ZoookJP06oookJP05obl0
ool0O?oooo]ZoookJ_oo`0001?oonfX00ol0ojKooo]Zodl0o`0;oookJP;oo`2<00Googl0oookJ_oo
nf[ooo]Zo`80o`1doookJP?o6_l01OoonfX3oon300Cooo]Z0ol/o`0@oookJPGo04So0ol0ol5Roook
JP03ool0M_oonf[ooo]Z02Sooo]Z1?l00003oookJP03ol<0oooonf[ooo]Z00Oooo]Z00?oKP3ooook
J_oonfX07OoonfX00ol0B?oooo]ZoookJP0?oookJP04oon@0?oonf[ooo]Zool0X0?ooo]Z00Coo`2;
oookJ_oonf[o_03o1?oonfX01Ombo`3ooo]Zo`H0oooonf[oo`0V00[ooo]Z00Go0=oooookJ_oonf[o
oo]Zool0^`04oookJP03okT0oomKo`3ooo]Z00Kooo]Z00?ooo80oookJ_oonfX00_n6o`03oookJP03
ool0m?oonf[ooo]Z00?ooo]Z00?oo`2ZoookJ_oonfX00_oonfX00ol0oa?ooo]ZoookJP06oookJP03
ohKo0?oonf[ooo]Z00oooo]Z00?o007ooookJ_oonfX01OoonfX2obl0o`04o`1loooonf[ooo]Zooo0
00?ooo]Z00Co0?nVoookJ_lco`3oC`3o2ooonfX2ool0S004oomo0?oonf[ooo]Zo`80ocCooo]Z0010
oookJP?o6_l03?oo:0001?oonf[o;?l0obco0?l/o`0:oookJPWoobP00ol0ol56oookJP?oobP07_oo
nfX00ooo07Kooo]ZoookJP0XoookJPCo00000ooonfX00oo30?oooo]ZoookJP05oookJP?oo`008?oo
nfX3ool000gooo]Z00?ooi00ool00?oo00002_oo00001Ooonf[oL_l0oookJ_oonf[oo`0000;ooo]Z
00Coo`0VoookJ_oonf[oo`001OoonfX00ol0gooooo]ZoookJP02oookJP08ool0^ooonf[ooo]Zoook
J_oo:03ooo]Zool00?oonfX5ool00005oookJ_oolP3ooo]ZoookJ_n6o`000ooonfX00ooo0?Cooo]Z
oookJP03oookJP03oolX0?oonf[ooo]Z00?ooo]Z00?oo`00oookJ_oonfX01_oonfX00on6o`3ooo]Z
oookJP0>oookJP03o`01oooonf[ooo]Z00Kooo]Z00Go;`3ooookJ_oonf[ooo]Zooo00003oookJP;o
0?nV00?ooo]Zodl0oooonfX02_oonfX00ooo08cooo]Zoomo0003oookJP03o`80oooonf[ooo]Z00co
oo]Z0_lMo`1RoookJP?o6_l01?oonfX4oon300Cooo]Z0ol/o`0@oookJP?o04So0ol0ol5XoookJP03
ool0M_oonf[ooo]Z02Oooo]Z1?l00003oookJP03ol<0oooonf[ooo]Z00Kooo]Z00?oKP3ooookJ_oo
nfX0;ooonfX01?ooT03ooo]ZoookJ_oo0:03oookJP04ool0Rooonf[ooo]Zok`0o`Cooo]Z00?oL_l0
oookJ_l60?l00_oonfX00ooo02Kooo]ZoookJP07oookJP05o`3Ooooonf[ooo]ZoookJ_oo0;/01?oo
nfX00oni0?ooFol0oookJP06oookJP04ooob0?oonf[ooo]ZohKo00Cooo]Z00?oo`3doookJ_oonfX0
0ooonfX00ooo0:[ooo]ZoookJP02oookJP03o`3o4ooonf[ooo]Z00Kooo]Z00?oQ_l0oookJ_oonfX0
3ooonfX00ol00Ooooo]ZoookJP05oookJP04obl0ool0O?oooo]ZoookJP;ool000_oonfX2o`3oYP03
oookJ_lco`3oC`3o00_ooo]Z00?oo`2<oookJ_ooO`000_oonfX00ol20?oooo]ZoookJP0=oookJP;o
7Ol09?oonfX003gooo]Z0olJo`000ooonf[oobP0oolX000<oolX0003obco0?oonf[ooo]Z00Wooo]Z
2ooo:012oookJP?oo`001ooo:00OoookJP03ool0M_oonf[ooo]Z02Oooo]Z1?l00002oookJP03ol<0
oooonf[ooo]Z00Gooo]Z1?oo000QoookJP03ool00?oonf[ooo]Z00_ooo]Z00?ooi00oookJ_oonfX0
2ooo00000ombo`3ooo]ZoookJP03oookJP03ool09_oonf[ooo]Z00Kooo]Z00?o0=oooookJ_oonfX0
0_oonfX01ooo0;_ooo]ZoookJ_oonf[oobP0oookJ_oo00000ooonfX3ool00005oookJ_oolP3ooo]Z
oookJ_n6o`000ooonfX00ooo0?Cooo]ZoookJP03oookJP03oolX0?oonf[ooo]Z00?ooo]Z00?oo`00
oookJ_oonfX01_oonfX00on6o`3ooo]ZoookJP0>oookJP03o`01oooonf[ooo]Z00Kooo]Z00Go;`3o
oookJ_oonf[ooo]Zooo00003oookJP04o`3oY_oonf[ooo]Zodl0o`_ooo]Z00?oo`2<oookJ_ooO`00
0ooonfX00ol20?oooo]ZoookJP0<oookJP03oago0?mSo`3oHol005oooo]Z0olJo`04oookJP?ooh<0
1OoonfX3obco00oooo]Z1?l0B?l2o`3o`Fgooo]Z00?oo`1foookJ_oonfX09_oonfX4o`0000;ooo]Z
00?o``3ooookJ_oonfX01ooonfX00om^0?oooo]ZoookJP0^oookJP04oon@0?oonf[ooo]Zool0X0?o
oo]Z00Coo`2;oookJ_oonf[o_03o1?oonfX00ombo`3ooo]ZoookJP02oookJP03ool09_oonf[ooo]Z
00Oooo]Z00Go0=oooookJ_oonf[ooo]Zool0^`04oookJP03okT0oomKo`3ooo]Z00Kooo]Z00Cooo80
oookJ_oonf[oQ_l01?oonfX00ooo0?Cooo]ZoookJP03oookJP03ool0Z_oonf[ooo]Z00;ooo]Z00?o
0?lCoookJ_oonfX01_oonfX00on6o`3ooo]ZoookJP0?oookJP03o`01oooonf[ooo]Z00Gooo]Z00Go
;`3oo`1loooonf[ooo]Zooo00003oookJP05o`3oY_oonf[ooo]Zoc?o0?m?0?l02ooonfX00ooo08co
oo]Zoomo0002oookJP03o`80oooonf[ooo]Z00gooo]Z00?o7Ol0of?o0?mSo`009?oonfX003_ooo]Z
0_lJo`03oookJQ3oobP02OoonfX>oolX02_ooo]Z0_oo:00@oookJPOoo`001ooo:00PoookJP03ool0
M_oonf[ooo]Z02Kooo]Z1?l00002oookJP03ol<0oooonf[ooo]Z00Cooo]Z1Ooo000^oookJP05oon@
0?oonf[ooo]Zool00?oonfX02Ooo00000ombo`3ooo]ZoookJP03oookJP03ool09_oonf[ooo]Z00Ko
oo]Z00?o0=oooookJ_oonfX00_oonfX01ooo0;_ooo]ZoookJ_oonf[o^@3ooookJ_oo00001OoonfX0
0ooo003ooo]Zooob0002oookJP03ohKo0?oonf[ooo]Z00;oo`001OoonfX00ooo:03ooo]ZoookJP03
oookJP03ool00?oonf[ooo]Z00Kooo]Z00?oQ_l0oookJ_oonfX03_oonfX00ol00Ooooo]ZoookJP06
oookJP05obl0oooonf[ooo]ZoookJ_oo`0000ooonfX01?l0ojKooo]ZoolX0?m?0?l;oookJP03ool0
S?ooO`3oogl000;ooo]Z0_l20?l>oookJP03oago0?mSo`3ooo]Z05kooo]Z0_lJo`04oookJP?ooh<0
1OoonfX3obco00oooo]Z0ol0B?l00ol0ol7ooo]ZoookJP1aoookJP03ool0M_oonf[ooo]Z02Gooo]Z
1?l00002oookJP03ol<0oooonf[ooo]Z00Kooo]Z00?oKP3ooookJ_oonfX0;_oonfX01?ooT03ooo]Z
oookJ_oo0:03oookJP04ool0Rooonf[ooo]Zok`0o`Cooo]Z00?oL_l0oookJ_oonfX00_oonfX00ooo
02Kooo]ZoookJP07oookJP05o`3Ooooonf[ooo]ZoookJ_oo0;/01?oonfX00oni0?ooFol0oookJP06
oookJP04ooob0?oonf[ooo]ZohKo00?ooo]Z0_oo0?@5oookJP03ool0Z_oonf[ooo]Z00;ooo]Z00?o
0?lCoookJ_oonfX01_oonfX00on6o`3ooo]ZoookJP0?oookJP03o`01oooonf[ooo]Z00Gooo]Z00Go
;`3oo`1loooonf[ooo]Zooo00003oookJP03o`3oY_oonf[o<ol000;oC`3o2ooonfX01?oo08coogl0
oomo0?oonfX2o`80o`oooo]Z00?o7Ol0of?o0?oonfX09OoonfX003Sooo]Z0olJo`03oookJP03oon3
0?oo:03oobP000KoobP00ol/o`0>oookJPooobP0:?oonfX5oolX00goo`2c2_oo0007oolX027ooo]Z
00?oo`1foookJ_oonfX09OoonfX4o`0000;ooo]Z00?o``3ooookJ_oonfX01?oonfX4ool002kooo]Z
00?ooi00oookJ_oonfX00ooonfX00ooo08_oo`00ool00005ool00003og;o0?oonf[ooo]Z00?ooo]Z
00?oo`0VoookJ_oonfX01_oonfX00ol0gooooo]ZoookJP02oookJP07ool0^ooonf[ooo]ZoookJ_ni
0?oooo]Zool00007oookJP04ooob0?oonf[ooo]ZohKo00;ooo]Z0ooo0003oookJP03ool0Z_oo:03o
oo]Z00Cooo]Z00?oo`00oookJ_oonfX01_oonfX00on6o`3ooo]ZoookJP0=oookJP;o007o1ooonfX2
obl0o`;ooo]Z0_oo`003oookJP05o`3oY_oo:03oobP0odl0oooo:0002OoonfX2ool0S005oomo0?oo
nf[ooo]ZoookJ_l20?l03_oonfX2oago0003of?o0?oonf[ooo]Z05_ooo]Z0olJo`03oookJP?ooh<0
1OoonfX3obco00kooo]Z00Co0?o1o`18ool0B?oo04So>?oonfXLool0/b?ooo]Z00?oo`1foookJ_oo
nfX09OoonfX4o`0000;ooo]Z00?o``3ooookJ_oonfX01_oonfX00om^0?oooo]ZoookJP0]oookJP03
oon@0?oonf[ooo]Z00Cooo]Z00Coo`2;oookJ_oonf[o_03o1?oonfX00ombo`3ooo]ZoookJP02oook
JP03ool09_oonf[ooo]Z00Oooo]Z00Go0=oooookJ_oonf[ooo]Zool0^`04oookJP03okT0oomKo`3o
oo]Z00Kooo]Z00Cooo80oookJ_oonf[oQ_l00ooonfX00ooo0?Cooo]ZoookJP03oookJP;oo`2Z1?oo
nfX00ol0oa?ooo]ZoookJP06oookJP03ohKo0?oonf[ooo]Z00kooo]Z0_l00Ol6oookJP;o;`3o00Co
07cooookJ_oonf[ool000ooonfX01?l0ojKooo]Zoc?o0?m?0?l;oookJP;oo`2<00Coogl0oookJ_oo
nf[o0P3o3ooonfX2oago0003of?o0?oonf[ooo]Z02Gooo]Z000eoookJP?o6_l00ooonfX3oon300Ko
oo]Z0ol/o`0>oookJP;o04So2?oo:00[oookJP?oo`2c1ooo:009oookJPkoo`001ooo:00@ool001;o
oo]Z00?oo`1foookJ_oonfX09?oonfX4o`000003oookJ_o30?oooo]Z00Gooo]Z1Ooo000^oookJP04
oon@0?oonf[ooo]ZoookJP;oobP00_oonfX5ool00003og;o0?oonf[ooo]Z00?ooo]Z00?oo`0Voook
J_oonfX01OoonfX2ool000Cooo]Z00Ooo`2koookJ_oonf[ooo]ZokT0oooonf[oo`0000Oooo]Z00Go
oo80oookJ_oonf[oQ_l0oookJP04ool000?ooo]Z00?oo`2ZoookJ_oonfX01?oonfX00ooo003ooo]Z
oookJP05oookJP;oobP03ooonfX00ol00Ooooo]ZoookJP06oookJP05obl0oooonf[ooo]ZoookJ_oo
`0000ooonfX00ooo:03o0?nVoolX0002odl0o`03oolX0?oonf[ooo]Z00Oooo]Z00?oo`2<oookJ_oo
O`000ooonfX00ol20?oooo]ZoookJP0<oookJP03oago0?l=0?ooHol000;ooo]Z0_mYo`1GoookJP?o
6_l00ooonfX3oon300Gooo]Z0ol/o`0>oookJPCo04So<_oonfX9ool0/acooo]Z1Ooo0;<OoookJP03
ool0M_oonf[ooo]Z02Cooo]Z1?l000000ooonf[o``3ooookJP07oookJP03ofh0oooonf[ooo]Z02ko
oo]Z00?ooi00oookJ_oonfX00ooonfX01?oo08_ooo]ZoookJ_nl0?l4oookJP03og;o0?oonf[ooo]Z
00;ooo]Z00?oo`0VoookJ_oonfX01ooonfX01Ol0gooooo]ZoookJ_oonf[oo`2k00Cooo]Z00?o^@3o
oe_o0?oonfX01_oonfX01?oolP3ooo]ZoookJ_n6o`03oookJP03ool0m?oonf[ooo]Z00?ooo]Z00?o
o`2ZoookJ_oonfX00ooonfX00ol0oa?ooo]ZoookJP05oookJP;oQ_l04?oonfX00ol00Ooooo]Zoook
JP05oookJP03obl0ool0O?oooo]Z00;ooo]Z00Sool00oookJ_oonf[ooo]Zo`3oY_oonf[o<ol0odl0
o`_ooo]Z00?oo`2<oookJ_ooO`000_oonfX00ol20?oooo]ZoookJP0=oookJP03oago0?mSo`3ooo]Z
00;ooo]Z0_mYo`0ToookJP00<_oonfX3oa[o00?ooo]Z0oooP`06oookJP?o;?l03_oonfX3o`18oboo
oo]Z1_oo0;<00ooonf[oobP0oolX0007oolX00;ooo]Z1Ol0G?l@ool000OoobP00_oonfX>ool001?o
oo]Z00?oo`1foookJ_oonfX08ooonfX4o`000003oookJ_o30?oooo]Z00Cooo]Z1_oo000]oookJP04
oon@0?oonf[ooo]ZoookJP?oobP00_oonfX5ool00003og;o0?oonf[ooo]Z00;ooo]Z00?oo`0Voook
J_oonfX01OoonfX3ool000?ooo]Z00Goo`2koookJ_oonf[ooo]ZokT0o`08oookJP;ooo800_oonfX0
0on6o`3oo`00ool00003ool000?ooo]Z00?oo`2ZoookJ_oonfX02ooonfX4oolX00kooo]Z00?o007o
oookJ_oonfX01_oonfX01Ol_0?oooo]ZoookJ_oonf[ool0000;ooo]Z00GoobP0o`3oY_l0ojKoobP0
odl0o`02oolX00Wooo]Z00?oo`2<oookJ_ooO`000ooonfX00ol20?oooo]ZoookJP0<oookJP03oago
0?mSo`3ooo]Z00;ooo]Z00?oJOl0oiX0oonJ0?l0E?oonfX3oa[o00?ooo]Z0oooP`05oookJP?o;?l0
3_oonfX3o`18oboooo]Z1ooo0;<<oookJPoo05co3ooonfX3ool0/agooo]Z00?oo`1foookJ_oonfX0
8ooonfX4o`000003oookJ_o30?oooo]Z03Oooo]Z00?ooi00oookJ_oonfX01?oonfX00ooo08_ooo]Z
ok`0o`04oookJP03og;o0?oonf[ooo]Z00;ooo]Z00?oo`0VoookJ_oonfX01ooonfX01Ol0gooooo]Z
oookJ_oonf[oo`2k00Cooo]Z00?o^@3ooookJ_oonfX01OoonfX2ooob00;ooo]Z00GoQ_l0oookJ_oo
nf[ooo]Zool0m005oookJP03ool0Z_oonf[ooo]Z00_ooo]Z00?oQ_l0oookJ_oonfX03ooonfX00ol0
0Ooooo]ZoookJP05oookJP03obl0ool0O?oooo]Z00;ooo]Z00?ool00oookJ_oonfX00_l0ojH00ooo
nf[o<ol0odl0o`0;oookJP03ool0S?oonf[oogl000;ooo]Z00?o0P3ooookJ_oonfX03OoonfX00olM
o`3oHol0oookJP02oookJP03ofWo0?nJ0?ooVP3o02Cooo]Z000`oookJP;o6_l01?oonfX2oon300Ko
oo]Z0ol/o`0>oookJP?o04So;OoonfX5ool0/`Cooo]Z3?oo:002o`1Lo`Sooo]Z3_oo0006oolX00Co
oo]Z3?oo000CoookJP03ool0M_oonf[ooo]Z02?ooo]Z1?l000000ooonf[o``3ooookJP03oookJPKo
o`00;OoonfX01?ooT03ooo]ZoookJ_oonfX3oolX00;ooo]Z00?oo`00oookJ_oonfX00_oo00000omb
o`3ooo]ZoookJP02oookJP03ool09_oonf[ooo]Z00Cooo]Z1?oo0003oookJP05ool0^ooonf[ooo]Z
oookJ_ni0?l02?oonfX01OoolP3ooo]ZoookJ_oonf[oQ_l000Koo`000_oonfX00ooo0:[ooo]Zoook
JP0:oookJPGoobP03_oonfX00ol00Ooooo]ZoookJP06oookJP05obl0oooonf[ooo]ZoookJ_oo`000
0ooo:0001?l0ojKoobP0oolX0?m?0?l2oolX00Wooo]Z00?oo`2<oookJ_ooO`000ooonfX00ol20?oo
oo]ZoookJP0<oookJP03oago0?mSo`3ooo]Z00;ooo]Z00CoJOl0oiX0oooo8@3oob40D_oonfX2oa[o
00?ooo]Z0oooP`05oookJP?o;?l03_oonfX3o`18obgooo]Z1Ooo0;<:oookJPWo05co8OoonfX2ool0
/a_ooo]Z00?oo`1foookJ_oonfX08ooonfX4o`000003oookJ_o30?oooo]Z03Kooo]Z00?ooi00oook
J_oonfX01?oonfX00ooo08_ooo]Zok`0o`04oookJP03og;o0?oonf[ooo]Z00;ooo]Z00?oo`0Voook
J_oonfX01ooonfX01Ol0gooooo]ZoookJ_oonf[oo`2k00Cooo]Z00?o^@3ooookJ_oonfX01OoonfX0
1OoolP3ooo]ZoookJ_oonf[oQ_l000?ooo]Z00?oo`3doookJ_oonfX00ooonfX00ooo0:[ooo]Zoook
JP0;oookJP03ohKo0?oonf[ooo]Z00oooo]Z00?o007ooookJ_oonfX01OoonfX01?l_0?oo07cooook
J_oonfX2ooo000;ooo]Z00Go0?nVoookJ_lco`3o<ol0odl0o`0;oookJP03ool0S?oonf[oogl000;o
oo]Z00?o0P3ooookJ_oonfX03?oonfX2oago0006of?o0?oonf[ooo]ZoookJ_mYo`3oVP3o0_oo8@0T
oookJP00;OoonfX3oa[o00?ooo]Z0oooP`06oookJP;o;?l03OoonfX4o`18obgooo]Z0ooo0;<7oook
JPooobP03OoonfX:ool000Cooo]Z0_oo:006oookJP[oo`005?oonfX00ooo07Kooo]ZoookJP0Roook
JPCo000000?o``3ooookJ_oonfX00_oonfX7ool002cooo]Z00?ooi00oookJ_oonfX01Ooo:006oook
JP03og;o0?oonf[ooo]Z00;ooo]Z00?oo`0VoookJ_oonfX00ooonfX5ool000;ooo]Z0_oo0;/3oook
JP03okT0oooonf[ooo]Z00Kooo]Z00Gooo80oookJ_oonf[ooo]ZohKo0006ool000;ooo]Z00?oo`2Z
oookJ_oonfX02OoonfX6oolX00kooo]Z00?o007ooookJ_oonfX01_oonfX01Ol_0?oooo]ZoookJ_oo
nf[ool0000?oobP000Co0?nVoolX0?oo:03oC`3o0ooo:007oookJP;oo`2<0_ooO`02oookJP;o0P3o
3OoonfX2oago0007of?o0?oonf[ooo]ZoookJ_mYo`3oVP3ooolQ0002ool0cdoooo]Z0olJo`03oook
JP;ooh<01_oonfX2obco00gooo]Z1?l0B?l]oookJP?oo`2c2OoonfX6o`1LodSooo]Z00?oo`1foook
J_oonfX08_oonfX4o`000003ol<0oooonf[ooo]Z03Gooo]Z00?ooi00oookJ_oonfX01?oonfX00ooo
08_ooo]ZoookJP04oookJP03og;o0?oonf[ooo]Z00;ooo]Z00?oo`0VoookJ_oonfX01ooonfX00ol0
gooooo]ZoookJP02ool0^`Cooo]Z00?o^@3ooookJ_oonfX01OoonfX01OoolP3ooo]ZoookJ_oonf[o
Q_l000?ooo]Z00?oo`3doookJ_oonfX00ooonfX00ooo0:[ooo]ZoookJP0;oookJP03ohKo0?oonf[o
oo]Z00oooo]Z00?o007ooookJ_oonfX01OoonfX01Ol_0?oo07cooookJ_oonf[ool0000?ooo]Z00Go
0?nVoookJ_lco`3ooo]Zodl0o`0:oookJP;oo`2<0_ooO`000ooonf[o0P3oo`80o`0>oookJP03oago
0?mSo`3ooo]Z00?ooo]Z00?oJOl0oiX0oooo8@000_oo0<lToookJP00:ooonfX2oa[o00Cooo]Z0_oo
P`06oookJP?o;?l03?oonfX3o`18o`03o`3o`Ooonf[ooo]Z02[ooo]Z1?oo0;<7oookJP;o05co4?oo
:00AoookJPKoo`003_oonfX7ool001Kooo]Z00?oo`1foookJ_oonfX08OoonfX4o`000004ol<0oooo
nf[ooo]ZoookJPSoo`00:ooonfX00oooT03ooo]ZoookJP05oolX00Kooo]Z00?oL_l0oookJ_oonfX0
0_oonfX00ooo02Kooo]ZoookJP03oookJPKoo`0000?ooo]Zool0^ooonfX00ooonfX00oni0?oooo]Z
oookJP06oookJP05ooob0?oonf[ooo]Zool00?n6o`001ooo00000ooonf[oo`2ZoookJP09oookJPSo
obP03OoonfX00ol00Ooooo]ZoookJP05oookJP04o`1lool_0?oooo]ZoookJP;ool000ooo:0001?l0
ojKoobP0oolX0?m?0?l3oolX00Oooo]Z00?oo`2<oookJ_ooO`000ooonfX00ol20?oooo]ZoookJP0<
oookJP03oago0?l=0?ooHol000?ooo]Z00CoJOl0oiX0oooo8@3oo`3?C_oonfX3oa[o00?ooo]Z0ooo
P`05oookJP?o;?l03?oonfX3o`18o`03o`3o`Ooonf[ooo]Z02[ooo]Z1?oo0;<7oookJPGo05coCooo
nfX00ooo07Kooo]ZoookJP0QoookJPCo000000?o``3ooookJ_oonfX0=?oonfX00oooT03ooo]Zoook
JP04oookJP03ool0Rooonf[ooo]Z00Cooo]Z00?oL_l0oookJ_oonfX00_oonfX00ooo02Kooo]Zoook
JP07oookJP04o`3Ooooonf[ooo]Zool0^`Gooo]Z00?o^@3ooookJ_oonfX01OoonfX01OoolP3ooo]Z
oookJ_oonf[oQ_l000?ooo]Z00?oo`3doookJ_oonfX00ooonfX00ooo0:[ooo]ZoookJP0;oookJP03
ohKo0?oonf[ooo]Z00oooo]Z00?o007ooookJ_oonfX01OoonfX01Ol_0?oo07cooookJ_oonf[ool00
00?ooo]Z00Go0?nVoookJ_lco`3ooo]Zodl0o`0:oookJP03ool0S?oonf[oogl000;ooo]Z00?o0P3o
oookJ_oonfX03?oonfX2oago0004of?o0?oonf[ooo]ZoookJP;oJOl000?oVP3ooolQ0?oo0<l09_oo
nfX002[ooo]Z00Co6_l0oookJ_oonf[ooo]Z0oooP`05oookJP?o;?l03?oonfX3o`18o`03o`3o`Ooo
nf[ooo]Z02[ooo]Z0ooo0;<6oookJPGo05co1ooonfX;oolX01Gooo]Z0_oo000@oookJPGoo`005ooo
nfX00ooo07Kooo]ZoookJP0PoookJP?o000000?o``3ooookJ_oonfX01?oonfX6ool002[ooo]Z00?o
oi00oookJ_oonfX01_oo:005oookJP03og;o0?oonf[ooo]Z00;ooo]Z00?oo`0VoookJ_oonfX00_oo
nfX7ool00003oookJ_oo0;_ooo]Z00?ooo]Z00?o^@3ooookJ_oonfX01_oonfX01OoolP3ooo]Zoook
J_oo003oQ_l000Ooo`0000?ooo]Zool0Z_oonfX02?oonfX9oolX00cooo]Z0_l00Ol7oookJP;o;`3o
0_oonfX00ooo`03ooo]ZoolX0002oolX0004o`3oY_oo:03oC`3oodl0o`?oobP01ooonfX00ooo08co
oo]Zoomo0003oookJP03o`80oooonf[ooo]Z00cooo]Z00?o7Ol0of?o0?oonfX00_oonfX2ofWo00;o
ob4000?oo`3?oookJ_oonfX0C?oonfX01?lJo`3ooo]ZoookJ_oonfX3oon300Gooo]Z0ol/o`0<oook
JP?o04So00?o0?o1oookJ_oonfX0:_oonfX3ool0/`Kooo]Z1Ol0G?mEoookJP03ool0M_oonf[ooo]Z
023ooo]Z0ol000000oo30?oooo]ZoookJP0doookJP03oon@0?oonf[ooo]Z00Cooo]Z00?oo`2;oook
J_oonfX01?oonfX00ombo`3ooo]ZoookJP02oookJP03ool09_oonf[ooo]Z00Oooo]Z00Co0=oooook
J_oonf[oo`2k1OoonfX00oni0?oooo]ZoookJP05oookJP05ooob0?oonf[ooo]ZoookJ_n6o`000ooo
nfX00ooo0?Cooo]ZoookJP03oookJP03ool0Z_oonf[ooo]Z00_ooo]Z00?oQ_l0oookJ_oonfX03_oo
nfX2o`01o`Kooo]Z0_l_0?l3oookJP07ooo00?oonf[ooo]ZoookJ_l0ojKooo]Zoc?o0002odl0o`[o
oo]Z00?oo`2<oookJ_ooO`000_oonfX00ol20?oooo]ZoookJP0<oookJP03oago0?l=0?oooo]Z00?o
oo]Z00GoJOl0oiX0oooo8@3oob40ool0c`0WoookJP00:ooonfX3oon300Gooo]Z0ol/o`0<oookJP?o
04So00?o0?o1oookJ_oonfX0:OoonfX4ool0/`?oo`0000?ooo]Zo`1Lool0G?l00ol0G?lCoookJPCo
obP0:OoonfX3ool001Oooo]Z00?oo`1foookJ_oonfX08?oonfX3o`000003ol<0oooonf[ooo]Z00Ko
oo]Z0ooo000[oookJP03oon@0?oo:03oobP000GoobP01OoonfX00ombo`3ooo]ZoookJP02oookJP04
ool09_oonf[ooo]ZoookJPWoo`0000?oo`2koookJ_oonfX00_oonfX00oni0?oooo]ZoookJP06oook
JP05ooob0?oonf[ooo]Zool00?n6o`001ooo00000ooonf[oo`2ZoookJP07oookJP[oobP03?oonfX0
0ol00Ooooo]ZoookJP06oookJP05obl0oooonf[ooo]ZoookJ_oo`0000ooonfX2o`3oYP03oolX0?m?
0?ooobP000?oobP01ooonfX00ooo08cooo]Zoomo0003oookJP03o`80oooonf[ooo]Z00_ooo]Z0_lM
o`002OmSo`3ooo]ZoookJ_oonf[oJOl0oiX0oooo8@3ooo]Zool0c`03oookJP03o`3o^?oonf[ooo]Z
04[ooo]Z0oooP`05oookJP?o;?l03?oonfX3o`18o`03o`3o`Ooonf[ooo]Z02Wooo]Z1?oo0;<4oook
JPGo05coF_oonfX00ooo07Kooo]ZoookJP0PoookJP?o000000?o``3ooookJ_oonfX0=?oonfX00ooo
T03ooo]ZoookJP03oookJP03ool0Rooonf[ooo]Z00Cooo]Z00?oL_l0oookJ_oonfX00_oonfX00ooo
02Kooo]ZoookJP07oookJP04o`3Ooooonf[ooo]Zool0^`Gooo]Z00?o^@3ooookJ_oonfX01OoonfX0
1OoolP3ooo]ZoookJ_oonf[oQ_l000?ooo]Z00?oo`3doookJ_oonfX00_oonfX2ool0ZPgooo]Z00?o
Q_l0oookJ_oonfX03_oonfX00ol00Ooooo]ZoookJP05oookJP03obl0ool0O?oooo]Z00;ooo]Z00?o
ol00oookJ_oonfX00_l0ojH00ooonf[o<ol0odl0o`0;oookJP03ool0S?oonf[oogl000;ooo]Z00?o
0P3ooookJ_oonfX03?oonfX00olMo`3o3@3ooookJP03oookJP05ofWo0?nJ0?ooob40oookJ_oo0<l0
0_oonfX2o`3o^2Cooo]Z000ZoookJP03oon30?oonf[ooo]Z00Cooo]Z0_l/o`0<oookJP?o04So00?o
0?o1oookJ_oonfX0:?oonfX4ool0/`04oookJ_oo003oo`00ool000Co05co0_oo0015oookJP03ool0
0?oonf[ooo]Z01Kooo]Z00?oo`1foookJ_oonfX07ooonfX3o`000003ol<0ool0003ooo]Z00Sooo]Z
00?oo`00oookJ_oonfX0:?oonfX00oooT03oobP0oolX0006oolX00Gooo]Z00GoL_l0oookJ_oonf[o
oo]Zool09P03oookJPWoo`0000?oo`2koookJ_oonfX00_oonfX00oni0?oooo]ZoookJP06oookJP05
ooob0?oonf[ooo]ZoookJ_n6o`002?oo00000ooo0:[ooo]ZoookJP06oookJP[oobP03?oonfX00ol0
0Ooooo]ZoookJP06oookJP05obl0oooonf[ooo]ZoookJ_oo`0000ooonfX01?l0ojKooo]ZoolX0?m?
0?l5oolX00Gooo]Z0_oo08`01?oonf[oogl0oookJ_oonfX2o`80o`gooo]Z00?o7Ol0o`d0oomSo`00
0ooonfX00omYo`3oVP3ooolQ0002ool0c`?ooo]Z00?o0?nhoookJ_oonfX0B_oonfX00oooP`3ooo]Z
oookJP04oookJP;o;?l03?oonfX3o`18o`03o`3o`Ooonf[ooo]Z02Sooo]Z1?oo0;<5oookJP?o05co
H?oonfX00ooo07Kooo]ZoookJP0OoookJP?o000000?o``3oo`000?oonfX0<ooonfX00oooT03ooo]Z
oookJP03oookJP03ool0Rooonf[ooo]Z00Gooo]Z00GoL_l0oookJ_oonf[ooo]Zool09P09oookJP04
o`3Ooooonf[ooo]Zool0^`Gooo]Z00?o^@3ooookJ_oonfX01OoonfX01OoolP3ooo]ZoookJ_oonf[o
Q_l000?ooo]Z00?oo`3doookJ_oonfX00_oonfX00ooo0:[ooo]ZoookJP0<oookJP03ohKo0?oonf[o
oo]Z00kooo]Z00?o007ooookJ_oonfX01OoonfX00ol_0?oo07cooookJP02oookJP05ooo00?oonf[o
oo]Zo`3oY_oonfX00_lco`000om?0?oooo]ZoookJP08oookJP;oo`2<00?ooo]Zoomo0?oonfX00_l2
0?l=oookJP;o7Ol000?oHol0oookJ_oonfX00_oonfX00omYo`3oVP3ooolQ0002ool0c`;ooo]Z00?o
0?nhoookJ_oonfX09?oonfX002kooo]Z0ol/o`0<oookJP;o04So0_l0ol4WoookJPGoo`2c0ooonfX2
ool000?o05co1_oo001NoookJP03ool0M_oonf[ooo]Z01oooo]Z0_l000000oo30?oo0000oookJP0c
oookJP03oon@0?oo:03oobP000KoobP01OoonfX00ombo`3ooo]ZoookJP02oolX00?ooo]Z2Ooo0000
0ooo0;_ooo]ZoookJP02oookJP03okT0oooonf[ooo]Z00Kooo]Z00Gooo80oookJ_oonf[ooo]ZohKo
0002oookJPKoo`0000?oo`2ZoookJ_oonfX01ooonfX:oolX00_ooo]Z00?o007ooookJ_oonfX01Ooo
nfX00ol0O?oo;`3ooookJP02oookJP08ooo00?oonf[ooo]ZoookJ_l0ojKooo]ZoolX0?m?0?l5oolX
00Gooo]Z00Coo`2<oookJ_oonf[oogl00_oonfX00ol20?oooo]ZoookJP0<oookJP03oago0?l=0?oo
oo]Z00?ooo]Z00CoJOl0oiX0oooo8@3oo`3?1?oonfX00ol0okSooo]ZoookJP1?oookJP?o;?l03?oo
nfX2o`18o`;o0?o1:?oonfX4ool0/`Kooo]Z0ol0G?l01?oonf[o06;oo`1Rool0H_mOoookJP03ool0
M_oonf[ooo]Z01oooo]Z0_l000000oo30?oo0000oookJP0coookJP03oon@0?oonf[ooo]Z00?ooo]Z
00?oo`2;oookJ_oonfX01OoonfX01Ombo`3ooo]ZoookJ_oonf[oo`0V00Wooo]Z00Co0=oooookJ_oo
nf[oo`2k1OoonfX00oni0?oooo]ZoookJP05oookJP05ooob0?oonf[ooo]ZoookJ_n6o`000ooonfX0
0ooo0?Cooo]ZoookJP02oookJP03ool0Z_oonf[ooo]Z00_ooo]Z0_n6o`0@oookJP03o`01oooonf[o
oo]Z00Gooo]Z00?o;`3oo`1loooonfX00_oonfX02?oo`03ooo]ZoookJ_l0ojKooo]Zoc?o0?oonf[o
C`3o2_oonfX01_oo08cooo]ZoookJ_ooO`3ooo]Zo`80o`kooo]Z00?o7Ol0o`d0oooonfX00ooonfX2
ofWo0003oolQ0?oonf[oo`3?00?ooo]Z00?o0?nhoookJ_oonfX09OoonfX002_ooo]Z0ol/o`0<oook
JP?o04So00?o0?o1oookJ_oonfX09?oonfX4ool0/`Oooo]Z0ol0G?l:ool002;ooo]Z0_ooN@0joook
JP;oobP07ooonfX2o`000003ol<0ool0003ooo]Z03;ooo]Z00?ooi00oolX0?oo:0001ooo:004oook
JP03og;o0?oonf[ooo]Z00?oobP01?oonfX8ool000Cooo]Z00?o^@3ooookJ_oonfX01_oonfX01Ooo
lP3ooo]ZoookJ_oonf[oQ_l000;ooo]Z00?oo`00oookJ_oo00000ooo00000ooo0:[ooo]ZoookJP09
oookJPSoobP02ooonfX00ol00Ooooo]ZoookJP05oookJP04o`1lool_0?oooo]ZoookJP;ool000ooo
nfX01?l0ojKoobP0oolX0?m?0?l2oookJP?oobP01OoonfX01?oo08cooo]Zoomo0?ooO`02oookJP03
o`80oooonf[ooo]Z00cooo]Z00?o7Ol0of?o0?oonfX00ooonfX01?mYo`3oob40oookJ_oo0<l3oook
JP;o0?nhCooonfX3obco00cooo]Z0ol0B?l00ol0ol7ooo]ZoookJP0UoookJPCoo`2c1ooonfX3o`1L
o`Co06;oHooonfX00ooo07Kooo]ZoookJP0NoookJP;o000000?o``3oo`000?oonfX0<_oonfX00ooo
T03ooo]ZoookJP03oookJP03ool0Rooonf[ooo]Z00Gooo]Z00?oL_l0oookJ_oonfX00_oonfX00ooo
02Kooo]ZoookJP06oookJP04o`3Ooooonf[ooo]Zool0^`Gooo]Z00?o^@3ooookJ_oonfX01OoonfX0
1OoolP3ooo]ZoookJ_oonf[oQ_l000?ooo]Z00?oo`3doookJ_oonfX00_oonfX00ooo0:[ooo]Zoook
JP0;oookJP03ohKo0?oonf[ooo]Z00oooo]Z00?o007ooookJ_oonfX01OoonfX01?l_0?oooo]Zoook
J_oonfX2ooo000;ooo]Z00?o0?nVoookJ_lco`000_m?0?l:oookJP06ool0S?oonf[oogl0oomo0?oo
nf[o0P3o3_oonfX00olMo`3o3@3ooookJP03oookJP05ofWo0?nJ0?ooob40oookJ_oo0<l00_oonfX2
o`3o^2Sooo]Z000ZoookJP03obco0?oonf[ooo]Z00[ooo]Z0ol0B?l2o`3o`BGooo]Z0ooo0;<8oook
JP?o05co3_oo000NoookJPGoogT0>_oonfX3oolX01kooo]Z0_l000000oo30?oo0000oookJP0aoook
JP03oon@0?oonf[ooo]Z00OoobP01?oonfX00ombo`3ooo]ZoolX0003oolX00Kooo]Z1_oo0004oook
JP03okT0oooonf[ooo]Z00Kooo]Z00?ooo80oookJ_oonfX00_oo0002oookJP04ool00?oonf[ooo]Z
oookJP;oo`0000?oo`2ZoookJ_oonfX02ooonfX6oolX00_ooo]Z00?o007ooookJ_oonfX01OoonfX0
1Ol0O?oo;`3ooookJ_oonf[ool0000Cooo]Z00Co0?nVoolX0?oonf[oC`3o1?oonfX00ooo:03ooo]Z
oookJP03oookJP03ool0S?oonf[oogl000?ooo]Z00?o0P3ooookJ_oonfX02ooonfX2oago0003of?o
0?oonf[ooo]Z00;ooo]Z00CoJOl0oolQ0?oonf[oo`3?0ooonfX01?l0okSooo]ZoookJ_oonfX2o`3o
cD_ooo]Z00?o;?l0oookJ_oonfX02ooonfX2o`18o`;o0?o19_oonfX3ool0/`Sooo]Z0ol0G?l3o`1R
o`Oooo]Z0ooo;P1NoookJP03ool0M_oonf[ooo]Z01gooo]Z0_l000000oo30?oo0000oookJP0aoook
JP03oon@0?oonf[ooo]Z00?ooo]Z00?oo`2;oookJ_oonfX01OoonfX00ombo`3ooo]ZoookJP02oook
JP03ool09_oonf[ooo]Z00Kooo]Z00Co0=oooookJ_oonf[oo`2k1OoonfX00oni0?oooo]ZoookJP05
oookJP03ooob0?oonf[ooo]Z00;oQ_l00ooonfX00ooo0?Cooo]ZoookJP02oookJP03ool0Z_oonf[o
oo]Z00_ooo]Z00?oQ_l0oookJ_oonfX03ooonfX00ol00Ooooo]ZoookJP05oookJP05obl0oooonf[o
oo]ZoookJ_oo`0000ooonfX01?l0ojKooo]Zoc?o0?m?0?l;oookJP03ool0S?oonf[oogl000;ooo]Z
00?o0P3ooookJ_oonfX02ooonfX2oago0003of?o0?oonf[ooo]Z00;ooo]Z00GoJOl0oolQ0?oo8@3o
oo]Zool0c`02oookJP03o`3o^?oonf[ooo]Z00;ooo]Z0_l0oldToookJP00=OoonfX2o`18o`?o0?o1
9?oonfX3ool0/`Sooo]Z0ol0G?l@ool001gooo]Z1oooN@0koookJP?oobP07OoonfX01?l0003o``3o
o`000?l0000boookJP04oon@0?oonf[ooo]ZoookJPKoobP00ooonfX00ombo`3oobP0oolX0003oolX
00Sooo]Z1Ooo0002oookJP;oo`002?oonfX00ooolP3ooo]Zool00003ool00003oookJ_oo003ooo]Z
00Cooo]Z00?oo`2ZoookJ_oonfX02ooonfX00ooo:03ooo]ZoolX0004oolX00Wooo]Z0_l00Ol7oook
JP;o;`3o0_oonfX00ooo`03ooo]ZoookJP02oookJP04o`3oY_oo:03oC`3oodl0o`Wooo]Z0_oo08`0
1?oonf[oogl0oookJ_oonfX2o`80o`gooo]Z00?o7Ol0o`d0oomSo`000ooonfX2ofWo0003oolQ0?oo
0<ooo`3?00?ooo]Z00Go0?nhoookJ_oonf[ooo]Zo`3oc@1IoookJP;o04So0_l0ol4UoookJP?oo`2c
2?oonfX3o`1Lo`?o06;o1_oonfX4ool^06;ooo]Z00?oo`1foookJ_oonfX07?oonfX01?l0003o``3o
o`000?l0000boookJP03oon@0?oonf[ooo]Z00;ooo]Z00?oo`2;oookJ_oonfX01OoonfX00ombo`3o
oo]ZoookJP02oookJP03ool09_oonf[ooo]Z00Kooo]Z00Co0=oooookJ_oonf[oo`2k1?oonfX2okT0
o`Oooo]Z00Cooo80oookJ_oonf[oQ_l01?oonfX00ooo0?Cooo]ZoookJP02oookJP03ool0Z_oonf[o
oo]Z00_ooo]Z00?oQ_l0oookJ_oonfX03_oonfX2o`01o`Kooo]Z0_l_0?l3oookJP05ooo00?oonf[o
oo]ZoookJ_l0ojH00_lco`000om?0?oooo]ZoookJP08oookJP;oo`2<00?ooo]Zoomo0?oonfX00_l2
0?l=oookJP03oago0?l=0?ooHol000Cooo]Z00?oJOl0oolQ0?oonfX00_oo0<l2oookJP03o`3o^?oo
nf[ooo]Z00;ooo]Z00?o0?o=oookJ_oonfX09?oonfX003;ooo]Z0ol0B?l2o`3o`BGooo]Z0_oo0;<8
oookJP?o05co00?o06;oool00?oo00004?oo000KoookJPWoogT000?ooo]Zokko0?nno`005onno`0Q
oookJPCoobP07?oonfX01?l0003o``3oo`000?l0000aoookJP03oon@0?oonf[ooo]Z00?ooo]Z1?oo
:003oookJP03og;o0?oo:03oobP000CoobP01ooonfX00ooo003ooo]Zool00002ool00003oookJ_oo
003oo`0000;oo`001ooonfX00ooolP3oo`00ool00003ool00003oookJ_oo003ooo]Z00Cooo]Z00?o
o`2ZoookJ_oonfX02ooonfX01?oo:03ooo]ZoookJ_oonfX3oolX00Wooo]Z00?o007ooookJ_oonfX0
1_oonfX01Ol_0?oooo]ZoookJ_oonf[ool0000?ooo]Z0_l0ojH00ooo:03oC`3ooookJP09oookJP04
ool0S?oonf[oogl0oomo00;ooo]Z00?o0P3ooookJ_oonfX03?oonfX00olMo`3o3@3ooookJP03oook
JP04ofWo0?oo8@3oob40ool0c`?ooo]Z0_l0okP3oookJP03o`3ocOoonf[ooo]Z05Gooo]Z0ol0B?l0
0ol0ol7ooo]ZoookJP0SoookJP?oo`2c2?oonfX3o`1Lo`;o06;o1_oonfX3oomL0003ool^0?oonf[o
oo]Z02Wooo]Z6Onno`0SoookJP03ool0M_oonf[ooo]Z01_ooo]Z00Co0000ol<0ool0003o0000<Ooo
nfX00oooT03ooo]ZoookJP03oookJP03ool0Rooonf[ooo]Z00Cooo]Z00?oL_l0oookJ_oonfX00_oo
nfX00ooo02Kooo]ZoookJP06oookJP04o`3Ooooonf[ooo]Zool0^`Cooo]Z00?o^@3ooookJ_oonfX0
1_oonfX01?oolP3ooo]ZoookJ_n6o`04oookJP03ool0m?oonf[ooo]Z00;ooo]Z00?oo`2ZoookJ_oo
nfX02ooonfX00on6o`3ooo]ZoookJP0>oookJP03o`01oooonf[ooo]Z00Gooo]Z00?o;`3oo`1loooo
nfX00_oonfX00ooo`03ooo]ZoookJP02o`3oYP03oc?o0?oonf[oC`3o00[ooo]Z00Koo`2<oookJ_oo
O`3oogl0oookJ_l20?l>oookJP03oago0?l=0?oooo]Z00?ooo]Z0_mYo`000ooo8@3ooo]Zool0c`02
oookJP;o0?nh1?oonfX00ol0olgooo]ZoookJP0UoookJP00<?oonfX2o`18o`?o0?o19?oonfX3ool0
/`Oooo]Z0ol0G?l3o`1RoaCoo`005ooonfX=oomi01Wooo]Z1_nno`0KoookJPGoobP06ooonfX01?l0
003o``3oo`000?l0000`oookJP03oon@0?oonf[ooo]Z00?ooo]Z00?oo`2;oookJ_oo:0000_oo:002
oookJP03og;o0?oo:03oobP000CoobP01ooonfX01?oo003ooo]ZoookJ_oo0;/6ool000Oooo]Z00?o
oo80ool00?oo00000ooo00000ooonf[oo`00oookJP04oookJP03ool0Z_oonf[ooo]Z00_ooo]Z00?o
obP0oookJ_oonfX00ooonfX00ooo:03ooo]ZoookJP07oookJP03o`01oooonf[ooo]Z00Gooo]Z00Co
07coobl0oooonf[ooo]Z0_oo`003oookJP04o`3oY_oo:03ooo]Zodl0o`[ooo]Z00?oo`2<oookJ_oo
O`000ooonfX00ol20?oooo]ZoookJP0;oookJP;o7Ol000?oHol0oookJ_oonfX00_oonfX01?mYo`3o
ob40oookJ_oo0<l3oookJP03o`3o^?oonf[ooo]Z00;ooo]Z00?o0?o=oookJ_oonfX0E?oonfX2o`18
o`;o0?o19?oonfX3ool0/`Sooo]Z0ol0G?l2o`1Ro`Kooo]Z0oooG0000ooo;P3ooo]ZoookJP0Toook
JPSo__l06OoonfX6okko01gooo]Z00?oo`1foookJ_oonfX06ooonfX01?l0003o``3oo`000?l0000`
oookJP03oon@0?oonf[ooo]Z00?ooo]Z00?oo`2;oookJ_oonfX01?oonfX00ombo`3ooo]ZoookJP02
oookJP03ool09_oonf[ooo]Z00Kooo]Z00Co0=oooookJ_oonf[oo`2k1?oonfX00oni0?oooo]Zoook
JP06oookJP04ooob0?oonf[ooo]ZohKo00Cooo]Z00?oo`3doookJ_oonfX00_oonfX00ooo0:[ooo]Z
oookJP0;oookJP03ohKo0?oonf[ooo]Z00kooo]Z00?o007ooookJ_oonfX01OoonfX01?l_0?oo07co
oookJ_oonfX2ooo000;ooo]Z00Go0?nVoookJ_lco`3ooo]Zodl0o`0:oookJP03ool0S?oonf[oogl0
00;ooo]Z00?o0P3ooookJ_oonfX03?oonfX00olMo`3oHol0oookJP03oookJP05ofWo0?oo8@3oob40
oookJ_oo0<l00_oonfX00ol0okSooo]ZoookJP02oookJP;o0?o=:?oonfX002gooo]Z0ol0B?l2o`3o
`BCooo]Z0ooo0;<7oookJP?o05co0ol0H_l00ooonf[oo`00ool0000Dool001Gooo]Z3oooN@0;oook
JP;oobP03ooonfX3ool000Ko__l05_oonfX5oolX01[ooo]Z00Co``3oo`000?l0003o0000;ooonfX0
0oooT03ooo]ZoookJP03oookJP08ool0Rooonf[ooo]ZoookJ_oo:03ooo]ZoolX0?mbo`07oolX00Wo
oo]Z00?oo`2kool00?oo00001?oo0006oookJP03ool00?oolP3oo`0000Goo`001OoonfX2ool000go
oo]Z00?oobP0oookJ_oonfX03OoonfX00ol00Ooooo]ZoookJP05oookJP05o`1lool_0?oooo]Zoook
J_oo`0001?oonfX01?l0ojKoobP0oookJ_m?0?l:oookJP03ool0S?oonf[oogl000?ooo]Z00?o0P3o
oookJ_oonfX02ooonfX00olMo`3o3@3oof?o0004oookJP04ofWo0?oo8@3oo`3?ool0c`?ooo]Z00Co
0?nhoookJ_oonf[ooo]Z0_l0old3oookJP;oo`26CooonfX3o`18o`03o`3o`Ooonf[ooo]Z02?ooo]Z
0_oo0;<8oookJP?o05co0_l0H_l5oookJPCooe`09OoonfX5okko02Oooo]Z1_nno`0HoookJP03ool0
M_oonf[ooo]Z01[ooo]Z00Co``3oo`000?l0003o0000;ooonfX00oooT03ooo]ZoookJP03oookJP03
ool0Rooonf[ooo]Z00Cooo]Z00?oL_l0oookJ_oonfX00_oonfX00ooo02Kooo]ZoookJP09oookJP03
ool0^ooonf[ooo]Z00;ooo]Z00?o^@3ooookJ_oonfX01_oonfX01?oolP3ooo]ZoookJ_n6o`08oook
JP;oo`2Z3OoonfX00on6o`3ooo]ZoookJP0>oookJP03o`01oooonf[ooo]Z00Gooo]Z00Go;`3ooook
J_oonf[ooo]Zooo00003oookJP03o`3oY_oonf[o<ol000;oC`3o2_oonfX00ooo08cooo]Zoomo0002
oookJP03o`80oooonf[ooo]Z00_ooo]Z0_lMo`000omSo`3ooo]ZoookJP02oookJP03ofWo0?oo8@3o
oo]Z00;oo`3?0_oonfX00ol0okSooo]ZoookJP02oookJP03o`3ocOoonf[ooo]Z00;ooo]Z0_oo08HT
oookJP00:ooonfX2o`18o`?o0?o19?oonfX2ool0/`Oooo]Z0ol0G?l3o`1Ro`;ooo]Z3_oo000Loook
JP;o__l04?ooN@08oookJPGoobP02ooonfX7ool000Kooo]Z0onno`0CoookJPKoobP06OoonfX01?oo
:03o0000o`000?l0000^oookJP03oon@0?oonf[ooo]Z00?ooo]Z00?oo`2;oookJ_oonfX00ooonfX0
0ooo:03oL_l0oolX0006oolX00Wooo]Z00?oo`2kool00?oo00001Ooo0004oookJP;oo`0000?ooo80
ool00?oo00001?oo0004oookJPCoo`003?oonfX00ooo:03ooo]ZoookJP0=oookJP03o`01oooonf[o
oo]Z00Gooo]Z00Go07coobl0oooonf[ooo]Zooo00004oookJP04o`3oY_oo:03ooo]Zodl0o`Wooo]Z
0_oo08`01?oonf[oogl0oookJ_oonfX2o`80o`gooo]Z00?o7Ol0o`d0oooonfX00ooonfX01?nJ0?oo
JOl0oolQ0?oo0<l4oookJP05o`3o^?oonf[ooo]ZoookJ_l0old01?oonfX00ooo08Kooo]ZoookJP1=
oookJP;o04So0_l0ol4ToookJP?oo`2c1ooonfX3o`1Lo`;o06;o1OoonfX3oomL0003ool^0?oonf[o
oo]Z027ooo]Z1Onno`0boookJP?o__l05OoonfX00ooo07Kooo]ZoookJP0JoookJP04ol<0ool0003o
0000o`0002kooo]Z00?ooi00oookJ_oonfX00ooonfX00ooo08_ooo]ZoookJP04oookJP03og;o0?oo
nf[ooo]Z00;ooo]Z00?oo`0VoookJ_oonfX02OoonfX00ooo0;_ooo]ZoookJP02oookJP03okT0oooo
nf[ooo]Z00Kooo]Z00Cooo80oookJ_oonf[oQ_l02?oonfX00ooo0:[ooo]ZoookJP0<oookJP03ohKo
0?oonf[ooo]Z00kooo]Z00?o007ooookJ_oonfX01OoonfX01Ol_0?oooo]ZoookJ_oonf[ool0000?o
oo]Z00Co0?nVoookJ_lco`3oC`3o2_oonfX2ool0S0;oogl000?ooo]Zo`80ool20?l03OoonfX00olM
o`3o3@3ooookJP03oookJP05oiX0oomYo`3oob40oookJ_oo0<l00ooonfX01?l0okSooo]ZoookJ_oo
nfX2o`3oc@Cooo]Z00?oo`26oookJ_oonfX09?oonfX002[ooo]Z00?o04Soo`3o`Ol0ol409?oonfX3
ool0/`Kooo]Z0ol0G?l3o`1Ro`Cooo]Z3ooo000GoookJPGo__l02ooonfX7oomi00Gooo]Z2?oo:008
oookJP[oo`002OoonfX2okko017ooo]Z1ooo:00HoookJP04oolX0?l0003o0000o`0002gooo]Z00?o
oi00oookJ_oonfX00ooonfX00ooo08_ooo]ZoookJP03oookJP03oolX0?mbo`3oobP000KoobP02Ooo
nfX8ool000?ooo]Z0ooo00000ooolP3oo`00ool00004ool000?ooo]Z1Ooo000;oookJP03ohKo0?oo
:03ooo]Z00gooo]Z0_l00Ol7oookJP05o`1lool_0?oooo]ZoookJ_oo`0001?oonfX01?l0ojKoobP0
oookJ_m?0?l9oookJP04ool0S?oonf[oogl0oomo00;ooo]Z00?o0P3ooookJ_oonfX02ooonfX2oago
0003o`d0oooonf[ooo]Z00;ooo]Z0_mYo`000ooonf[oo`3?oookJP02oookJP;o0?nh0ooonfX00ol0
olgooo]ZoookJP02oookJP03ool0Q_oonf[ooo]Z04cooo]Z0_l0B?l00ol0ol7ooo]ZoookJP0Roook
JP?oo`2c1ooonfX3o`1Lo`;o06;o1OoonfX3oomL0003ool^0?oonf[ooo]Z023ooo]Z1?nno`0joook
JP?o__l04ooonfX00ooo07Kooo]ZoookJP0IoookJP04ol<0ool0003o0000o`0002gooo]Z00?ooi00
oookJ_oonfX00ooonfX00ooo08_ooo]ZoookJP04oookJP03og;o0?oonf[ooo]Z00;ooo]Z00?oo`0V
oookJ_oonfX02_oonfX01Ooo0;_ooo]ZoookJ_oonf[o^@3o00Sooo]Z00Cooo80oookJ_n6o`3oQ_l0
2?oonfX00ooo0:[ooo]ZoookJP0;oookJP;oQ_l03ooonfX2o`01o`Oooo]Z00Go;`3ooookJ_oonf[o
oo]Zooo00003oookJP04o`3oY_lco`3o<ol0odl0o`[ooo]Z00?oo`2<oookJ_ooO`000_oonfX00ol2
0?oooo]ZoookJP0<oookJP03oago0?l=0?oooo]Z00?ooo]Z0_mYo`000ooonf[oo`3?ool0c`02oook
JP;o0?nh0ooonfX00ol0olgooo]ZoookJP03oookJP03ool0Q_oonf[ooo]Z02Gooo]Z000ZoookJP03
o`3o`Ooonf[ooo]Z02;ooo]Z0_oo0;<6oookJP?o05co0ol0H_l5oookJP03oomL0?oo003oo`0000Ko
o`006ooonfX4okko01Wooo]Z2ooo:004oookJPkoo`002ooonfX4oolX00kooo]Z1ooo:00:oookJPGo
001o1ooonfX2oolX00?o0000;?oonfX00oooT03ooo]ZoookJP03oookJP03ool0Rooonf[ooo]Z00Co
oo]Z00?oL_l0oolX0?oo:0001_oo:007oookJP[oo`000_oonfX3ool00003ooob0?oo003oo`0000Co
o`000_oonfX6ool000_ooo]Z00?oQ_l0oookJ_oonfX03OoonfX00ol00Ooooo]ZoookJP06oookJP;o
;`3o00?ooo]Zooo00?oo`0001?oonfX01?l0ojKooo]Zodl0oom?0?l9oookJP03ool0S?oonf[oogl0
00?ooo]Z00?o0P3ooookJ_oonfX02ooonfX00olMo`3o3@3oof?o0004oookJP04ofWo0?oo8@3oo`3?
ool0c`?ooo]Z00Co0?nhoookJ_oonf[ooo]Z0_l0old3oookJP;oo`26CooonfX00ol0ol7ooo]Zoook
JP0RoookJP;oo`2c1ooonfX3o`1Lo`;o06;o1OoonfX3oomL0003ool^0?oonf[ooo]Z01oooo]Z1?nn
o`11oookJP;o__l04OoonfX00ooo07Kooo]ZoookJP0<oookJPGo001o2?oonfX01?o30?oo0000o`00
0?l0000/oookJP03oon@0?oonf[ooo]Z00Cooo]Z00?oo`2;oookJ_oonfX00ooonfX00ombo`3ooo]Z
oookJP02oookJP03ool09_oonf[ooo]Z00[ooo]Z00Goo`2koookJ_oonf[ooo]ZokT0o`08oookJP03
ooob0?oonf[oQ_l000Wooo]Z00?oo`2ZoookJ_oonfX02ooonfX00on6o`3ooo]ZoookJP0>oookJP03
o`01oooonf[ooo]Z00Gooo]Z0_l_0?l2oookJP;ool000ooonfX01?l0ojKo<ol0oookJ_m?0?l:oook
JP03ool0S?ooO`3oogl000;ooo]Z00?o0P3ooookJ_oonfX03?oonfX00olMo`3oHol0oookJP03oook
JP04ofWo0?oo8@3ooo]Zool0c`?ooo]Z00?o0?nhoookJ_oonfX00_oonfX00ol0olgooo]ZoookJP02
oookJP;oo`26:?oonfX004cooo]Z0ooo0;<2oolX00Cooo]Z0_l0G?l2oolX0003o`1Roooonf[ooo]Z
00?ooo]Z0oooG00PoookJPCo__l06_oonfX?oolX0003og7o0?oo003oo`0000koo`003OoonfX7oolX
00Wooo]Z2?oo:008oookJPOo001o1OoonfX3oolX00?o0000:ooonfX00oooT03ooo]ZoookJP03oook
JP03ool0Rooonf[ooo]Z00Cooo]Z00?oL_l0oookJ_oonfX01_oo:007oookJP[oo`000ooonfX2ool0
0003ooob0?oo003oo`0000goo`002_oonfX00on6o`3ooo]ZoookJP0=oookJP03o`01oooonf[ooo]Z
00Gooo]Z00Go07coobl0oooonf[ooo]Zooo00004oookJP;o0?nV00?ooo]Zodl0oooonfX02OoonfX0
0ooo08cooo]Zoomo0003oookJP03o`80oooonf[ooo]Z00_ooo]Z00?o7Ol0o`d0oooonfX01?oonfX0
0omYo`3oob40ool0c`04oookJP05o`3o^?oonf[ooo]ZoookJ_l0old01?oonfX00ooo08Kooo]Zoook
JP1aoookJP?oo`2c1_oonfX3o`1Lo`;o06;o1OoonfX3oomL0003ool^0?oonf[ooo]Z01kooo]Z1?nn
o`0MoookJQGoLOl05OoonfX2okko013ooo]Z00?oo`1foookJ_oonfX02_oonfX7o`00O`Kooo]Z00?o
``3oo`000?l000000_l0000[oookJP03oon@0?oonf[ooo]Z00Cooo]Z00?oo`2;oookJ_oonfX01?oo
nfX01Ombo`3ooo]ZoookJ_oonf[oo`0V00cooo]Z00Goo`2koookJ_oonf[ooo]ZokT0o`08oookJP03
ooob0?oonf[oQ_l000Wooo]Z00?oo`2ZoookJ_oonfX02ooonfX00on6o`3ooo]ZoookJP0>oookJP03
o`01oooonf[ooo]Z00Gooo]Z00Go;`3ooookJ_oonf[ooo]Zooo00003oookJP;o0?nV00?o<ol0odl0
oom?0?l02_oonfX00ooo08coogl0oookJP02oookJP03o`80oooonf[ooo]Z00_ooo]Z0_lMo`05oook
JP04ofWo0?oo8@3ooo]Zool0c`?ooo]Z00Co0?nhoookJ_oonf[ooo]Z0_l0old4oookJP03ool0Q_oo
nf[ooo]Z02Sooo]Z0019oookJP?oo`2c00?ooo]ZoolX0?oo:0000ooo:003o`1Lo`;oobP01OoonfX3
oomL023ooo]Z0onno`0JoookJP;oLOl04Ooo:005oookJPcoo`003_oonfX;oolX00Cooo]Z2Ooo:006
oookJPCo001o00Cooo]Zo`00Ool007oo001o1OoonfX3oolX00?o0000:_oonfX00oooT03ooo]Zoook
JP03oookJP03ool0Rooonf[ooo]Z00Cooo]Z00?oL_l0oookJ_oonfX00_oonfX5oolX00Oooo]Z2Ooo
0005oookJP03ooob0?oo003oo`0000goo`002_oonfX00on6o`3ooo]ZoookJP0=oookJP03o`01oooo
nf[ooo]Z00Gooo]Z00Go07coobl0oooonf[ooo]Zooo00004oookJP04o`3oY_lco`3ooo]Zodl0o`[o
oo]Z00?oo`2<oomo0?ooO`000ooonfX00ol20?oooo]ZoookJP0:oookJP;o7Ol000?o3@3ooookJ_oo
nfX00_oonfX2ofWo0003oookJ_oo0<oooo]Z00;ooo]Z0_l0okP3oookJP03o`3ocOoonf[ooo]Z00;o
oo]Z00?oo`26oookJ_oonfX0KooonfX3ool0/`Kooo]Z0ol0G?l2o`1Ro`Kooo]Z0_ooG0000ooo;P3o
oo]ZoookJP0MoookJPCo__l06_oonfX7og7o02cooo]Z0_nno`0?oookJP03ool0M_oonf[ooo]Z00So
oo]Z1?l007l01?oonf[o001oo`00Ool007l6oookJP03ol<0ool0003o000000;o0000:_oonfX00ooo
T03ooo]ZoookJP04oookJP03ool0Rooonf[ooo]Z00Cooo]Z00GoL_l0oookJ_oonf[ooo]Zool09P0<
oookJP05ool0^ooonf[ooo]ZoookJ_ni0?l02?oonfX00ooolP3ooo]ZohKo0009oookJP03ool0Z_oo
nf[ooo]Z00_ooo]Z00?oQ_l0oookJ_oonfX03_oonfX00ol00Ooooo]ZoookJP05oookJP05obl0oooo
nf[ooo]ZoookJ_oo`0000ooonfX01?l0ojKooo]Zoc?o0?m?0?l;oookJP03ool0S?ooO`3ooo]Z00;o
oo]Z00?o0P3ooookJ_oonfX02ooonfX00olMo`3o3@3ooookJP03oookJP;oJOl000?ooo]Zool0cooo
0<l00_oonfX2o`3o^0?ooo]Z00?o0?o=oookJ_oonfX00ooonfX00ooo08Kooo]ZoookJP0YoookJP00
AooonfX2ool0/`;ooo]Z1?oo:003o`1Lo`?oobP01?oonfX3oomL01oooo]Z1?nno`0IoookJPCoLOl0
1ooonfX<oolX00[ooo]Z1ooo000?oookJPgoobP00_oonfX6oolX00Ko001o0_oonfX3o`00O`?ooo]Z
0ol007l3oookJPCoobP00ol0000ZoookJP03oon@0?oonf[ooo]Z00;ooo]Z00?oo`2;oookJ_oonfX0
1?oonfX00ombo`3ooo]ZoookJP02oookJP03ool09_oonf[oobP000;oobP01ooonfX00ooo0;_ooo]Z
ool00007ool000Cooo]Z00?ooo80oookJ_oo00003Ooo0009oookJP;oQ_l03ooonfX00ol00Ooooo]Z
oookJP05oookJP05o`1lool_0?oooo]ZoookJ_oo`0001?oonfX01?l0ojKo<ol0oookJ_m?0?l9oook
JP;oo`2<00Coogl0oookJ_oonf[ooo]Z0_l20?l<oookJP03oago0?l=0?oo3@3o00Cooo]Z00CoJOl0
oolQ0?oo0<ooo`3?0ooonfX00ol0okSooo]ZoookJP02oookJP04o`3ocOoonf[ooo]ZoookJP;oo`26
1_oonfX2oh00ofSooo]Z0_oo0;<7oookJP;o05co0_l0H_l6oookJP?ooe`07ooonfX3okko01[ooo]Z
1?mao`0eoookJP;o__l03?oonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1OoonfX00oo30?oo0000
o`000002o`0002[ooo]Z00?ooi00oookJ_oonfX00ooonfX00ooo08_ooo]ZoookJP04oookJP05og;o
0?oonf[ooo]ZoookJ_oo02H03?oonfX01Ooo0;_ooo]ZoookJ_oonf[o^@3o00Sooo]Z00?ooo80oook
J_n6o`002OoonfX00ooo0:[ooo]ZoookJP0;oookJP03ohKo0?oonf[ooo]Z00kooo]Z00?o007ooook
J_oonfX01?oonfX00ol0O?oo;`3ooookJP02oookJP05ooo00?oonf[ooo]ZoookJ_l0ojH00_lco`00
0om?0?oooo]ZoookJP08oookJP03ool0S?ooO`3oogl000;ooo]Z0_l20?l=oookJP03oago0?l=0?oo
oo]Z00?ooo]Z00CoJOl0oolQ0?oonf[oo`3?0ooonfX00ol0okSooo]ZoookJP02oookJP03o`3ocOoo
nf[ooo]Z00;ooo]Z0_oo08H6oookJP;oP03o9?oonfX004Cooo]Z0ooo0;<3oookJP?oobP00_l0G?l7
oolX0004oookJ_ooG03ooe`0oolX01kooo]Z0onno`0JoookJP?oLOl04ooonfX4oolX00oooo]Z0_oo
000@oookJPcoobP00_oonfX5oolX0003ool00?l007oo001o00Co001o2?oonfX3o`00O`?ooo]Z1?oo
:005o`0002Oooo]Z00Cooi00oookJ_oonf[ooo]Z0_oo0006oookJP03og;o0?oonf[ooo]Z00;ooo]Z
00Goo`0VoookJ_oonf[ooo]ZoolX0007oookJP04ool0^ooonf[ooo]ZoookJPKoo`000ooonfX2ooob
0003oookJ_oo003ooo]Z00coo`002OoonfX00on6o`3ooo]ZoookJP0=oookJP;o007o1ooonfX00ol0
O?oo;`3ooookJP02ooo000Cooo]Z00Co0?nVoc?o0?oonf[oC`3o2OoonfX00ooo08cooo]Zoomo0003
oookJP03o`80oooonf[ooo]Z00_ooo]Z00?o7Ol0o`d0oomSo`001?oonfX00omYo`3oob40ool0c`04
oookJP04o`3o^?oonf[ooo]ZoookJP;o0?o=0ooonfX00ooo08Kooo]ZoookJP05oookJP03oh00oooo
nf[ooo]Z06Gooo]Z0ooo0;<6oookJP?o05co0_l0H_l5oookJP?ooe`000?oobh0oookJ_oonfX06ooo
nfX4okko01[ooo]Z0omao`0koookJP;o__l02_oonfX:o`00O`Sooo]Z0ol007l5oookJP03ol<0ool0
003o000000Co00009ooonfX00oooT03ooo]ZoookJP03oookJP03ool0Rooonf[ooo]Z00Cooo]Z00Go
L_l0oookJ_oonf[ooo]Zool09P0<oookJP05ool0^ooonf[ooo]ZoookJ_ni0?l01ooonfX2ooob0003
oookJ_n6o`3ooo]Z00Sooo]Z00?oo`2ZoookJ_oonfX02ooonfX00on6o`3ooo]ZoookJP0=oookJP;o
007o1_oonfX01?l0O?oo;`3ooookJ_oonfX2ooo000?ooo]Z00Co0?nVoc?o0?oonf[oC`3o2_oonfX0
0ooo08coogl0oookJP02oookJP03o`80oooonf[ooo]Z00_ooo]Z0_lMo`000omSo`3ooo]ZoookJP02
oookJP04ofWo0?oo8@3ooo]Zool0c`?ooo]Z00Co0?nhoookJ_oonf[ooo]Z0_l0old4oookJP03ool0
Q_oonf[ooo]Z00Gooo]Z00?oP03ooookJ_oonfX09?oonfX004;ooo]Z0_oo0;<5oookJP04oolX0?l0
G?oo05coo`1Lo`OoobP00oooG00NoookJP?o__l06OoonfX4og7o03cooo]Z2_oo:003oookJP?oobP0
1?oo000=oookJP?o001o0_oonfX5oolX00?o0000:?oonfX01?ooT03ooo]ZoookJ_oonfX3ool000Go
oo]Z00?oL_l0oookJ_oonfX00_oonfX00ooo02Kooo]ZoookJP09oookJP06ool0^ooonf[ooo]Zoook
J_oo003ooo]Z1Ooo0002oookJP04ooob0?oonf[ooo]Zool000?ooo]Z2ooo0008oookJP03ohKo0?oo
nf[ooo]Z00gooo]Z00?o007ooookJ_oonfX01_oonfX2obl0o`03oookJ_oo`03ooo]Z00Cooo]Z00Co
0?nVoookJ_oonf[oC`3o2OoonfX00ooo08cooo]Zoomo0003oookJP03o`80oooonf[ooo]Z00_ooo]Z
00?o7Ol0o`d0oooonfX00ooonfX2ofWo0003oookJ_oo0<oooo]Z00;ooo]Z0_l0okP3oookJP03o`3o
cOoonf[ooo]Z00;ooo]Z00?oo`26oookJ_oonfX01OoonfX00on00?oooo]ZoookJP1ToookJP;oo`2c
1ooonfX2o`1Lo`;o06;o1_oonfX2oomL0003ool^0?oonf[ooo]Z01_ooo]Z0onno`0JoookJPCoLOl0
@?oonfX00onno`3ooo]ZoookJP0IoookJP?o001o1OoonfX00oo30?oo0000o`000002o`0002Sooo]Z
00?ooi00oookJ_oonfX00ooonfX00ooo08_ooo]ZoookJP04oookJP05og;o0?oonf[ooo]ZoookJ_oo
02H03?oonfX01Ooo0;_ooo]ZoookJ_oonf[o^@3o00Oooo]Z00Cooo80oookJ_oonf[oQ_l02OoonfX0
0ooo0:[ooo]ZoookJP0:oookJP;oQ_l03ooonfX00ol00Ooooo]ZoookJP05oookJP;o;`3o0_oonfX0
0ooo`03ooo]ZoookJP02oookJP04o`3oY_lco`3ooo]Zodl0o`[ooo]Z00?oo`2<oomo0?oonfX00_oo
nfX00ol20?oooo]ZoookJP0;oookJP03oago0?l=0?oooo]Z00?ooo]Z0_mYo`000ooo8@3oo`3?ool0
c`02oookJP;o0?nh0ooonfX00ol0olgooo]ZoookJP03oookJP03ool0Q_oonf[ooo]Z00Gooo]Z00?o
P03ooookJ_oonfX09OoonfX003oooo]Z0ooo0;<5oookJP03oolX0?l0G?oo05co00OoobP00oooG003
oolX01_ooo]Z0onno`0HoookJPCoLOl0@_oonfX8oolX0005ool00?oonf[ooo]ZoookJ_oo:0001_oo
0007oookJP;o001o0_oonfX4o`00O`03oookJ_oo:03oobP000?oobP01?l0000WoookJP04oon@0?oo
nf[ooo]ZoookJP?oo`001OoonfX00ombo`3ooo]ZoookJP02oookJP03ool09_oonf[ooo]Z00Wooo]Z
00?oo`2koookJ_oonfX01OoonfX3ool000;ooo]Z00?ooo80oookJ_oonfX01_oonfX9ool000Sooo]Z
00?oQ_l0oookJ_oonfX03OoonfX00ol00Ooooo]ZoookJP05oookJP05o`1lool_0?oooo]ZoookJ_oo
`0001OoonfX01?l0ojKooo]Zodl0oom?0?l9oookJP03ool0S?ooO`3oogl000?ooo]Z00?o0P3ooook
J_oonfX02_oonfX2oago0003o`d0oooonf[ooo]Z00;ooo]Z00CoJOl0oiX0oooonf[oo`3?0ooonfX0
0ol0okSooo]ZoookJP02oookJP04o`3ocOoonf[ooo]ZoookJP;oo`261ooonfX00on00?oooo]Zoook
JP1RoookJP?oo`2c1_oonfX3o`1Lo`;o06;o1OoonfX3oomL0003ool^0?oonf[ooo]Z01[ooo]Z0onn
o`0IoookJPCoLOl0AOoonfX00onno`3ooo]ZoookJP0CoookJP;o001o0_oonfX4o`00O`Cooo]Z00?o
``3ooookJ_l000000ol0000WoookJP03oon@0?oonf[ooo]Z00?ooo]Z00?oo`2;oookJ_oonfX01?oo
nfX01Ombo`3ooo]ZoookJ_oonf[oo`0V00cooo]Z00?oo`2koookJ_oonfX02OoonfX00ooolP3ooo]Z
oookJP0:oookJP03ool0Z_oonf[ooo]Z00[ooo]Z00?oQ_l0oookJ_oonfX03_oonfX00ol00Ooooo]Z
oookJP05oookJP05obl0oooonf[ooo]ZoookJ_oo`0001?oonfX01?l0ojKo<ol0odl0oom?0?l:oook
JP;oogl00ooonfX00ol20?oooo]ZoookJP0;oookJP03oago0?l=0?oooo]Z00?ooo]Z00CoJOl0oiX0
oooonf[oo`3?0ooonfX00ol0okSooo]ZoookJP02oookJP03o`3ocOoonf[ooo]Z00;ooo]Z0_oo08H6
oookJP;oP03o:?oonfX003cooo]Z0ooo0;<6oookJP?o05co3ooo:00HoookJP?o__l04?oonfX2ool0
00Gooo]Z1?mao`0SoookJP;oo`008_oonfX6oolX00Goo`0000?ooo]Zool00?oo00001Ooo0006oook
JPOo001o0_oonfX5oolX00Co00009_oonfX00oooT03ooo]ZoookJP05ool000Cooo]Z00?oL_l0oook
J_oonfX00_oonfX00ooo02Kooo]ZoookJP09oookJP03ool0^ooonf[ooo]Z00Oooo]Z00Coo`00oook
J_oonf[ooo802ooonfX6ool000Sooo]Z00?oQ_l0oookJ_oonfX03OoonfX00ol00Ooooo]ZoookJP05
oookJP05o`1lool_0?oooo]ZoookJ_oo`0001?oonfX2o`3oYP03oookJ_m?0?oooo]Z00Sooo]Z0_oo
08`01?ooO`3ooo]ZoookJ_oonfX2o`80o`cooo]Z00?o7Ol0o`d0oomSo`001?oonfX01?mYo`3oob40
ool0cooo0<l3oookJP04o`3o^?oonf[ooo]ZoookJP;o0?o=0ooonfX00ooo08Kooo]ZoookJP06oook
JP04oh00oooonf[ooo]ZoookJP;o/_l0GOoonfX3ool0/`Oooo]Z0_l0G?l2o`1Ro`Kooo]Z0_ooG000
0ooo;P3ooo]ZoookJP0JoookJP?o__l06?oonfX4og7o05oooo]Z1ol007l5oookJP03ol<0oooonf[o
000000?o00009_oonfX00oooT03ooo]ZoookJP03oookJP03ool0Rooonf[ooo]Z00Cooo]Z00GoL_l0
oookJ_oonf[ooo]Zool09P0<oookJP03ool0^ooonf[ooo]Z00Wooo]Z00?ooo80oookJ_oonfX02_oo
nfX00ooo0:[ooo]ZoookJP0:oookJP03ohKo0?oonf[ooo]Z00kooo]Z00?o007ooookJ_oonfX01?oo
nfX00ol0O?oo;`3ooookJP02oookJP04ooo00?oonf[ooo]ZoookJP;o0?nV00?o<ol0odl0oooonfX0
2OoonfX00ooo08coogl0oookJP02oookJP;o0P3o3OoonfX00olMo`3oHol0oookJP03oookJP04ofWo
0?oo8@3ooo]Zool0c`?ooo]Z00?o0?nhoookJ_oonfX00_oonfX00ol0olgooo]ZoookJP02oookJP03
ool0Q_oonf[ooo]Z00Gooo]Z00?oP03ooookJ_oonfX00_oonfX2ok;o02Cooo]Z000joookJP;oogT0
1_oonfX3o`1Loa;oobP05_oonfX2okko01;ooo]Z0ooo00000ooonf[oLOl0og7o0002og7o02Cooo]Z
1Ooo000SoookJPCoobP03ooo0005oookJPKo001o0_oonfX6oolX00Co00009OoonfX00oooT03ooo]Z
oookJP05ool000Cooo]Z00?oL_l0oookJ_oonfX00_oonfX00ooo02Kooo]ZoookJP09oookJP03ool0
^ooonf[ooo]Z00[ooo]Z00?ooo80oookJ_oonfX02_oonfX6ool000Kooo]Z0_n6o`0?oookJP03o`01
oooonf[ooo]Z00Gooo]Z00?o07coobl0oooonfX00_oo`004oookJP04o`3oY_lco`3ooo]Zodl0o`Wo
oo]Z00?oo`2<oookJ_ooO`000ooonfX00ol20?oooo]ZoookJP0;oookJP03oago0?l=0?oooo]Z00?o
oo]Z0_mYo`000ooonf[oo`3?oookJP03oookJP05o`3o^?oonf[ooo]ZoookJ_l0old01?oonfX00ooo
08Kooo]ZoookJP05oookJP;oP03o0ooonfX00onbo`3ooo]ZoookJP1KoookJP;oo`2c1ooonfX3o`1L
o`;o06;o1OoonfX3oomL0003ool^0?oonf[ooo]Z01[ooo]Z0_nno`0GoookJPCoLOl0HooonfX6o`00
O`Kooo]Z00?o``3ooookJ_l000000ol0000UoookJP03oon@0?oonf[ooo]Z00?ooo]Z00?oo`2;oook
J_oonfX01?oonfX01Ombo`3ooo]ZoookJ_oonf[oo`0V00cooo]Z00?oo`2koookJ_oonfX02OoonfX0
0ooolP3ooo]ZoookJP0:oookJP03ool0Z_oonf[ooo]Z00[ooo]Z00?oQ_l0oookJ_oonfX03_oonfX0
0ol00Ooooo]ZoookJP04oookJP04o`1lool_0?oooo]ZoookJP;ool000ooonfX01?l0ojKo<ol0oook
J_m?0?l:oookJP03ool0S?ooO`3ooo]Z00;ooo]Z00?o0P3ooookJ_oonfX02ooonfX2oago00Cooo]Z
0_mYo`000ooo8@3oo`3?ool0c`03oookJP04o`3o^?oonf[ooo]ZoookJP;o0?o=1?oonfX00ooo08Ko
oo]ZoookJP05oookJP03oh00oooonf[ooo]Z00;ooo]Z00?o/_l0oookJ_oonfX09?oonfX003Sooo]Z
0_ooN@06oookJP;o05co00?ooo]Zo`1Roooo:0004ooo:00BoookJP?o__l04ooonfX2ool000?oLOl0
9_oonfX7ool002Cooo]Z0ooo:00@ool000Cooo]Z0_l007l6oookJPKoobP01?l0000ToookJP03oon@
0?oonf[ooo]Z00Koo`000_oonfX2ooo900Cooo]Z00?oo`0VoookJ_oonfX02OoonfX00ooo0;_ooo]Z
oookJP0:oookJP03ooob0?oonf[ooo]Z00[ooo]Z00?oo`00oookJ_oonfX00ooo0006oookJP03ohKo
0?oonf[ooo]Z00gooo]Z0_l00Ol7oookJP04o`1lool_0?oooo]Zooo000Gooo]Z00Co0?nVoc?o0?m?
0?ooC`3o2OoonfX00ooo08coogl0oomo0003oookJP03o`80oooonf[ooo]Z00[ooo]Z0_lMo`000ol=
0?oooo]ZoookJP02oookJP04ofWo0?nJ0?oooo]Zool0c`?ooo]Z0_l0okP3oookJP04o`3ocOoonf[o
oo]ZoookJP;oo`261ooonfX00on00?oooo]ZoookJP02oookJP03ok;o0?oonf[ooo]Z05[ooo]Z0_oo
0;<7oookJP;o05co0_l0H_l6oookJP;ooe`000?oobh0oookJ_oonfX06_oonfX3okko01Kooo]Z0oma
o`1WoookJP;o001o2_oonfX00oo30?oooo]Zo`000003o`0002Cooo]Z00?ooi00oookJ_oonfX00ooo
nfX00ooo08_ooo]ZoookJP04oookJP05og;o0?oonf[ooo]ZoookJ_oo02H02ooonfX2ool0^`_ooo]Z
00?ooo80oookJ_oonfX02_oonfX00ooo0:[ooo]ZoookJP0:oookJP03ohKo0?oonf[ooo]Z00gooo]Z
0_l00Ol6oookJP05o`1lool_0?oooo]ZoookJ_oo`0001?oonfX01?l0ojKo<ol0odl0oom?0?l:oook
JP;oogl00ooonfX00ol20?oooo]ZoookJP0;oookJP03oago0?l=0?oooo]Z00?ooo]Z00CoJOl0oiX0
oooonf[oo`3?0ooonfX2o`3o^0?ooo]Z00?o0?o=oookJ_oonfX00_oonfX2ool0QPOooo]Z00?oP03o
oookJ_oonfX00_oonfX00onbo`3ooo]ZoookJP0UoookJP00;OoonfX2oomi00Oooo]Z0_ooN@06oook
JP;o05co00?ooo]Zo`1Roooo:0004?oo:00DoookJP?o__l05?oonfX4og7o00?oo`009?oonfX9ool0
02Gooo]Z00?oobP0ool00?oo00004?oo0003oookJP;o001o1OoonfX7oolX00Co00008ooonfX00ooo
T03ooo]Zool00006ool000;ooo]Z0ooob@03oookJP03ool09_oonf[ooo]Z00Wooo]Z00?oo`2koook
J_oonfX02_oonfX00ooolP3ooo]ZoookJP0:oookJP03ool00?oonf[ooo]Z00;ooo]Z00?oo`00oook
J_oonfX01?oonfX00on6o`3ooo]ZoookJP0=oookJP03o`01oooonf[ooo]Z00Kooo]Z0_l_0?l00ooo
nf[ool00oookJP03oookJP;o0?nV00?o<ol0odl0oooonfX02OoonfX00ooo08coogl0oookJP03oook
JP03o`80oooonf[ooo]Z00[ooo]Z00?o7Ol0o`d0ool=0?l01?oonfX01?mYo`3oob40ool0cooo0<l3
oookJP04o`3o^?oonf[ooo]ZoookJP;o0?o=0ooonfX00ooo08Kooo]ZoookJP06oookJP04oh00oooo
nf[ooo]ZoookJP;o/_l0FooonfX2ool0/`Kooo]Z0ol0G?l2o`1Ro`Gooo]Z0oooG0000ooo;P3ooo]Z
oookJP0IoookJP?o__l05OoonfX4og7o06[ooo]Z0_l007l:oookJP03ol<0oooonf[o000000?o0000
8ooonfX00oooT03ooo]ZoookJP03oookJP03ool0Rooonf[ooo]Z00Cooo]Z00GoL_l0oookJ_oonf[o
oo]Zool09P0;oookJP03ool0^ooonf[ooo]Z00[ooo]Z00?ooo80oookJ_oonfX02_oonfX00ooo0:[o
oo]ZoookJP0:oookJP03ohKo0?oonf[ooo]Z00gooo]Z00?o007ooookJ_oonfX01OoonfX2obl0o`;o
oo]Z00Cool00oookJ_oonf[ooo]Z0_l0ojH00olco`3oC`3ooookJP0:oookJP03oomo0?oonf[ooo]Z
00;ooo]Z00?o0P3ooookJ_oonfX02ooonfX00olMo`3o3@3ooookJP03oookJP04ofWo0?oo8@3oo`3?
ool0c`?ooo]Z00?o0?nhoookJ_oonfX00_oonfX00ol0olgooo]ZoookJP02oookJP03ool0Q_oonf[o
oo]Z00Gooo]Z0_n00?l3oookJP;o/_l0:?oonfX002cooo]Z0oooN@05oookJP;oogT01OoonfX3o`1L
o`03oookJ_l0H_oo06;o00[oobP06_oonfX2okko01Cooo]Z0omao`08ool001?ooo]Z0_oo:00;oook
JPgoo`009OoonfX@ool000Kooo]Z1Ol007l8oolX00Co00008ooonfX00oooT03oo`00ool00006ool0
00CoolT00_oonfX2ool000_ooo]Z00?oo`2koookJ_oonfX02_oonfX00ooolP3ooo]ZoookJP0Foook
JP03ohKo0?oonf[ooo]Z00gooo]Z00?o007ooookJ_oonfX01OoonfX01Ooo:03o;`3ooookJ_oonf[o
ol0000Cooo]Z00Co0?nVoc?o0?oonf[oC`3o2_oonfX00ooo08coogl0oookJP03oookJP03o`80oooo
nf[ooo]Z00[ooo]Z00?o7Ol0o`d0oooonfX00ooonfX2ofWo0003oookJ_oo0<oooo]Z00?ooo]Z00Go
0?nhoookJ_oonf[ooo]Zo`3oc@04oookJP03ool0Q_oonf[ooo]Z00Kooo]Z00GoP03ooookJ_oonf[o
oo]Zok;o001KoookJP;oo`2c1_oonfX2o`1Lo`03oookJ_l0H_oo06;o00Gooo]Z0_ooG0000ooo;P3o
oo]ZoookJP0JoookJP;o__l05OoonfX3og7o00Gooo]Z0_l01_lUoookJP?o0?oE@?oonfX7o`00O`?o
oo]Z00?o``3ooookJ_oonfX01?l0000SoookJP03oon@0?oonf[ooo]Z00;ooo]Z00?oo`2;oookJ_oo
nfX01?oonfX01Ombo`3ooo]ZoookJ_oonf[oo`0V00_ooo]Z00?oo`2koookJ_oonfX02_oonfX00ooo
lP3ooo]ZoookJP0GoookJP03ohKo0?oonf[ooo]Z00gooo]Z00?o007ooookJ_oonfX01?oonfX00ol0
O?oo;`3ooookJP02oookJP05ooo00?oonf[ooo]ZoookJ_l0ojH00_lco`000om?0?oooo]ZoookJP09
oookJP03oomo0?oonf[ooo]Z00;ooo]Z00?o0P3ooookJ_oonfX02ooonfX00olMo`3ooo]ZoookJP02
oookJP;oJOl000?oob40ool0cooonfX00ooonfX00ol0okSooo]ZoookJP02oookJP03o`3ocOoonf[o
oo]Z00;ooo]Z00?oo`26oookJ_oonfX01OoonfX00on00?oooo]ZoookJP02oookJP03ok;o0?oonf[o
oo]Z02Sooo]Z000[oookJPGoogT000Cooo]Zoomi0?ooN@3oogT01OoonfX2o`1Lo`;ooo]Z0_l0H_l0
0ooonf[oobP0oolX0008oolX01Sooo]Z0onno`0CoookJP?oLOl000?ooo]Zool00?oo00002?oo000B
oookJP?oobP02OoonfX?ool001_ooo]Z0ooo:008oookJPgoo`002?oonfX7o`00O`03oookJ_oo:03o
obP000?oobP01?l0000RoookJP03oon@0?oo003oo`0000Koo`001Ooob@001?oonf[oo`00ool00?oo
000:oookJP03ool0^ooonf[ooo]Z00[ooo]Z00?ooo80oookJ_oonfX05OoonfX2ool000oooo]Z00?o
007ooookJ_oonfX01?oonfX2oolX0004obl0oooo:03ooo]Zooo000Cooo]Z00Co0?nVoc?o0?m?0?oo
C`3o2OoonfX00ooo08coogl0oomo0003oookJP;oobP02ooonfX2oago0003o`d0oooonf[ooo]Z00;o
oo]Z00CoJOl0oiX0oooonf[oo`3?0ooonfX2oolX00?ooo]Z00Co0?o=oookJ_oonf[ooo]Z0_oo08H7
oookJP;oP03o0_oonfX2ok;o05Wooo]Z0ooo0;<6oookJP;o05co00?ooo]Zo`1Rool0H_l01OoonfX2
oomL0003ool^0?oonf[ooo]Z01Wooo]Z0onno`0DoookJP?oLOl01OoonfX3o`06ob;ooo]Z1Ol0omE3
oookJPOo001o0ooonfX00oo30?oooo]ZoookJP04o`0002;ooo]Z00?ooi00oookJ_oonfX00_oonfX0
0ooo08_ooo]ZoookJP04oookJP03og;o0?oonf[ooo]Z00;ooo]Z00?oo`0VoookJ_oonfX02?oonfX0
0ooo0;_ooo]ZoookJP0:oookJP03ooob0?oonf[ooo]Z01Kooo]Z0_n6o`0?oookJP03o`01oooonf[o
oo]Z00Cooo]Z00?o07coobl0oooonfX00_oonfX02?oo`03ooo]ZoookJ_oonf[o0?nVoc?o0?oonf[o
C`3o2_oonfX00ooo08coogl0oookJP02oookJP;o0P3o3?oonfX2oago00Cooo]Z00CoJOl0oiX0oooo
8@3oo`3?0ooonfX2o`3o^0?ooo]Z0_l0old3oookJP;oo`261ooonfX01?n00?oooo]ZoookJ_oonfX2
ok;o02_ooo]Z000ZoookJPOoogT01_oonfX2o`1Lo`;ooo]Z0_l0H_l00ooonf[oobP0oolX000:oolX
01Gooo]Z0onno`0CoookJP?oLOl00_oonfX<ool0013ooo]Z1Ooo:006oookJP;o0?oE4?oo000Foook
JP;oo`001_oo:009oookJPKoo`000_oonfX3ool0017ooo]Z0ooo0002oolX00Co00008OoonfX00ooo
T03oo`00ool00005ool000KoolT01?oo000:oookJP03ool0^ooonf[ooo]Z00[ooo]Z00?ooo80oook
J_oonfX05?oonfX4ool000kooo]Z00?o007ooookJ_oonfX00ooonfX3oolX0004obl0oooo:03ool00
ooo000Cooo]Z00?o0?nVoc?o0?m?0?l02_oonfX01?oo08coogl0oookJ_oonfX5oolX00[ooo]Z00?o
7Ol0oookJ_l=0?l01?oonfX01OmYo`3oVP3oool0cooo0<oooo]Z00GoobP000?ooo]Zo`3ocOl0old0
0ooonfX00ooo08Kooo]ZoookJP06oookJP05oh00oooonf[ooo]ZoookJ_nbo`00FOoonfX2ool0/`Ko
oo]Z0ol0G?l00ooonf[o06;oo`1Ro`04oookJP?ooe`000?oobh0oookJ_oonfX06OoonfX2okko01Co
oo]Z0omao`05oookJP?o00Ko8?oonfX5o`3oeEGooo]Z1?l0000QoookJP03oon@0?oonf[ooo]Z00Wo
oo]Z00?oL_l0oookJ_oonfX00_oonfX00ooo02Kooo]ZoookJP08oookJP03ool0^ooonf[ooo]Z00[o
oo]Z00?ooo80oookJ_oonfX05_oonfX00on6o`3ooo]ZoookJP0=oookJP;o007o1_oonfX01?l0O?oo
;`3ooookJ_oonfX2ooo000?ooo]Z00Co0?nVoc?o0?m?0?ooC`3o2_oonfX2oomo00?ooo]Z00?o0P3o
oookJ_oonfX02ooonfX00olMo`3o3@3ooookJP03oookJP04ofWo0?nJ0?ooo`3?ool0c`?ooo]Z00?o
0?nhoookJ_oonfX00_oonfX00ol0olgooo]ZoookJP02oookJP03ool0Q_oonf[ooo]Z00Gooo]Z0_n0
0?l3oookJP03ok;o0?oonf[ooo]Z02_ooo]Z000ZoookJPOoogT00ooonfX3o`1Lo`04oookJ_l0H_oo
06;oo`1Ro`;ooo]Z3_oo:00AoookJP?o__l04ooonfX3og7o00Cooo]Z3Ooo000>oookJPSoobP00_oo
nfX3o`3oe@_ooo]Z2?oo0005oookJP;oobP02ooonfX5ool000KoobP02_oonfX5ool000;ooo]Z00?o
o`00oookJ_oonfX04?oonfX4ool000;ooo]Z1?l0000PoookJP03oon@0?oonf[ooo]Z00Goo`001ooo
b@04ool000Wooo]Z00?oo`2koookJ_oonfX02_oonfX00ooolP3ooo]ZoookJP0CoookJPGoo`003_oo
nfX00ol00Ooooo]ZoookJP02oookJPCoobP000?o;`3ooolX0?oo`0001?oonfX2o`3oYP;oC`3o2_oo
nfX00ooo08coogl0oookJP06oolX00[ooo]Z00?o7Ol0oomi0?ooN@000ooonfX2ofWo0003oookJ_oo
0<oooo]Z00KoobP000?ooo]Zo`3ocOoonfX00ooonfX00ooo08Kooo]ZoookJP06oookJP05oh00oooo
nf[ooo]ZoookJ_nbo`00F?oonfX2ool0/`Kooo]Z0_l0G?l01?oonf[o06;oo`1Rool0H_l4oookJP;o
oe`000?oobh0oookJ_oonfX06OoonfX3okko01?ooo]Z0omao`05oookJP?o00Ko8?oonfX3o`3oeE[o
oo]Z1?l0000PoookJP03oon@0?oonf[ooo]Z00Wooo]Z00?oL_l0oookJ_oonfX00_oonfX00ooo02Ko
oo]ZoookJP08oookJP03ool0^ooonf[ooo]Z00[ooo]Z00?ooo80oookJ_oonfX05_oonfX00on6o`3o
oo]ZoookJP0=oookJP03o`01oooonf[ooo]Z00Gooo]Z00Go07coobl0oooonf[ooo]Zooo00003oook
JP;o0?nV00?o<ol0odl0oooonfX02_oonfX00oooO`3ooo]ZoookJP02oookJP03o`80oooonf[ooo]Z
00_ooo]Z00?o7Ol0o`d0oooonfX00_oonfX2ofWo0003oolQ0?oo0<oooo]Z00?ooo]Z00?o0?nhoook
J_oonfX00_oonfX00ol0olgooo]ZoookJP02oookJP03ool0Q_oonf[ooo]Z00Gooo]Z00?oP03ooook
J_oonfX00_oonfX00onbo`3ooo]ZoookJP0/oookJP00:_oonfX7oomi0003oookJ_l0G?oo05co00;o
oo]Z0_l0H_l4oookJP[oobP05?oonfX2okko01Cooo]Z0_mao`06oookJPooo`003?oonfX9oolX00;o
0?oE4_oonfX4ool000;ooo]Z1Ooo:008oookJPSoo`001_oo:002oookJPcoo`005_oonfX4ool000;o
oo]Z1?l0000OoookJP03oon@0?oonf[ooo]Z00;ooo]Z0ooo0007ooo900Coo`002OoonfX00ooo0;_o
oo]ZoookJP09oookJP;oobP05?oonfX6ool000gooo]Z0_l00Ol3oookJPOoobP000?ool00oookJ_oo
nfX00_oonfX00ol0ojKoo`00odl0o`0:oookJP03ool0S?ooO`3oogl000OoobP02OoonfX2oago00?o
ogT00_oonfX01?mYo`3oVP3ooookJ_oo0<l7oolX0003oookJ_l0olgooo]Z00;ooo]Z0_oo08H8oook
JP03oh00oooonf[ooo]Z00;o/_l0EooonfX2ool0/`Gooo]Z0ol0G?l00ooonf[o06;oo`1Ro`04oook
JP?ooe`000?oobh0oookJ_oonfX06?oonfX3okko01Cooo]Z0_mao`05oookJP?o00Ko8?oonfX3o`3o
eEgooo]Z1?l0000PoookJP03oon@0?oonf[ooo]Z00Sooo]Z00?oL_l0oookJ_oonfX00_oonfX00ooo
02Kooo]ZoookJP08oookJP03ool0^ooonf[ooo]Z00Wooo]Z0_oolP0HoookJP03ohKo0?oonf[ooo]Z
00gooo]Z00?o007ooookJ_oonfX01OoonfX2obl0o`;ooo]Z00Gool00oookJ_oonf[ooo]Zo`3oYP02
oc?o0003odl0oooonf[ooo]Z00Sooo]Z00?oo`2<oomo0?oonfX00_oonfX2o`80o`cooo]Z0_lMo`04
oookJP04ofWo0?nJ0?ooob40ool0c`?ooo]Z0_l0okP3oookJP;o0?o=0ooonfX2ool0QPOooo]Z00Co
P03ooookJ_oonf[ooo]Z0_nbo`0_oookJP00:_oonfX6oomi00;o05co0_oonfX2o`1Ro`Cooo]Z00?o
oe`0oolX0?oo:0000_oo:00HoookJP?o__l04ooonfX3og7o00Kooo]Z00?o00Koool00?oo00001_oo
000BoookJP_oobP04_oonfX6ool000OoobP01Ol04ol;ool000KoobP02ooo00000ooonf[oo`00oook
JP0EoookJPGoo`000_oonfX4o`0001kooo]Z00?ooi00oookJ_oonfX01?oonfX9ooo900?oo`002Ooo
nfX00ooo0;_ooo]ZoookJP08oookJPCoobP04_oonfX8ool000cooo]Z00Co007ooookJ_oonf[ooo]Z
2Ooo:003oookJP05ool00?l0ojKoo`00odl0oooo00002OoonfX00ooo08coogl0oolX0007oolX00So
oo]Z00?oogT0oago0?ooN@000oooN@02oookJP04ofWo0?nJ0?ooo`3?ool0c`OoobP000?ooo]Zo`3o
cOoonfX00_oonfX00ooo08Kooo]ZoookJP07oookJP04oh00oooonf[ooo]Zok;o05Sooo]Z00?oo`2c
oookJ_oonfX00ooonfX2o`1Lo`;ooo]Z0_l0H_l4oookJP;ooe`00_oo;P0JoookJP;o__l05?oonfX3
og7o00Gooo]Z0_l01_lOoookJPCo0?oE7?oonfXHo`0Cobcooo]Z1?l0000OoookJP03oon@0?oonf[o
oo]Z00Sooo]Z00?oL_l0oookJ_oonfX00_oonfX00ooo02Kooo]ZoookJP08oookJP03ool0^ooonf[o
oo]Z00Wooo]Z00?ooo80oookJ_oonfX05ooonfX00on6o`3ooo]ZoookJP0=oookJP03o`01oooonf[o
oo]Z00Gooo]Z00Go;`3ooookJ_oonf[ooo]Zooo00003oookJP04o`3oY_lco`3oC`3oodl0o`[ooo]Z
0_ooO`03oookJP03o`80oooonf[ooo]Z00_ooo]Z00?o7Ol0o`d0oooonfX00ooonfX01?mYo`3oVP3o
ool0cooo0<l3oookJP03o`3o^?oonf[ooo]Z00;ooo]Z00?o0?o=oookJ_oonfX00_oonfX00ooo08Ko
oo]ZoookJP06oookJP05oh00oooonf[ooo]ZoookJ_nbo`00<OoonfX002[ooo]Z0oooN@03o`1Lo`;o
oo]Z0_l0H_l4oookJP;ooe`000?oobh0oookJ_oonfX05ooonfX3okko01?ooo]Z0omao`03oookJP;o
o`0000Cooo]Zo`06ool01_oo00Ko6OoonfX=oolX013ooo]Z1_oo000:oolX0003oookJ_oo003oo`00
00goo`001Ooo:00;ool001Sooo]Z1_oo00000ooonf[o0000o`000002o`0001gooo]Z00?ooi00oook
J_oonfX01?oonfX9ooo900Coo`002?oonfX00ooo0;_ooo]ZoookJP07oookJPGoobP04OoonfX9ool0
00cooo]Z00?o007ooookJ_oonfX02_oo:002oookJP03ool00?l0ojKo0?nV00;oC`3o00?oo`00oook
J_oonfX01_oonfX00ooo:03oo`2<oomo0008oolX00Oooo]Z0_ooN@000olMo`3oogT0oomi0002oomi
0005oookJ_mYo`3oJOl0oolX0?oo0<l02?oo:002o`3oc@?ooo]Z00?oo`26oookJ_oonfX01_oonfX2
oh00o`;ooo]Z00?o/_l0oookJ_oonfX0FooonfX2o`1Lo`;ooo]Z0_l0H_l4oookJP;ooe`000?oobh0
oookJ_oonfX06?oonfX3okko01?ooo]Z0omao`05oookJP?o00Ko7OoonfX4o`3oeA[ooo]Z1_l04ol8
oookJPCo0?nV3?oonfX2o`0Cob[ooo]Z1?l0000NoookJP03oon@0?oonf[ooo]Z00Sooo]Z00?oL_l0
oookJ_oonfX00_oonfX00ooo02Kooo]ZoookJP08oookJP03ool0^ooonf[ooo]Z00Wooo]Z00?ooo80
oookJ_oonfX05ooonfX00on6o`3ooo]ZoookJP0=oookJP03o`01oooonf[ooo]Z00Gooo]Z00?o;`3o
oookJ_oonfX00_oo`002oookJP;o0?nV00?o<ol0odl0oooonfX02_oonfX00oooO`3ooo]ZoookJP02
oookJP03o`80oooonf[ooo]Z00_ooo]Z00?o7Ol0of?o0?oonfX00_oonfX2ofWo0003oiX0oooo0<oo
oo]Z00?ooo]Z00?o0?nhoookJ_oonfX00_oonfX00ol0olgooo]ZoookJP02oookJP03ool0Q_oonf[o
oo]Z00Gooo]Z0_n00?l3oookJP03ok;o0?oonf[ooo]Z033ooo]Z000[oookJP;o05co0ooonfX2o`1R
o`Cooo]Z0_ooG0000ooo;P3ooo]ZoookJP0GoookJP;o__l05?oonfX2og7o00Gooo]Z0ooo00000ol0
1_oooo]ZoookJP0IoookJPooobP03_oonfX4ool000goobP04?oo0005oolX00[oo`006?oonfX7ool0
0003oookJ_l0003o000000?o00007?oonfX00oooT03ooo]ZoookJP03oookJP[oolT00ooo0008oook
JP03ool0^ooonf[ooo]Z00Kooo]Z1_oo:00@oookJP[oo`003?oonfX00ol00Ooooo]ZoookJP0:oolX
0006oookJ_oo003oo`00o`3oY_oo003oC`3o0_oo0008oookJP03oolX0?ooO`3oogl000SoobP01Ooo
nfX3oomi00;o7Ol01?ooN@000ooo:03oJOl0oolX000:oolX0004o`3ocOoonf[ooo]ZoookJP;oo`26
2?oonfX00on00?oooo]ZoookJP02ok;o05_ooo]Z0ol0G?l2oookJP;o06;o1?oonfX2oomL0003ool^
0?oonf[ooo]Z01Sooo]Z0_nno`0DoookJP;oLOl01OoonfX3o`06oacooo]Z1?l0omDJoookJPCo01?o
2?oonfX6o`3oYScooo]Z1Ol0000MoookJP03oon@0?oonf[ooo]Z00Sooo]Z00GoL_l0oookJ_oonf[o
oo]Zool09P0:oookJP03ool0^ooonf[ooo]Z00Wooo]Z00?ooo80oookJ_oonfX05_oonfX2ohKo00ko
oo]Z0_l00Ol6oookJP05o`1lool_0?oooo]ZoookJ_oo`0000ooonfX01?l0ojKo<ol0oc?o0?m?0?l:
oookJP03ool0S?ooO`3ooo]Z00;ooo]Z0_l20?l<oookJP;o7Ol01?oonfX01?mYo`3oVP3ooolQ0?oo
0<l3oookJP;o0?nh1?oonfX01?l0olgooo]ZoookJ_oonfX2ool0QPOooo]Z00CoP03ooookJ_oonf[o
oo]Z0_nbo`0coookJP00:_oonfX01?l0G?oooo]ZoookJ_oonfX2o`1Ro`Cooo]Z0_ooG00JoookJP;o
__l05?oonfX2og7o00Gooo]Z1_oo00000ooonf[oo`00ool0000FoookJP03o`3oeOoo:03oobP000ko
obP02ooonfX00ol04oooo`00ool00002ool000ooobP01OoonfX;ool000GoobP02_oo000HoookJPOo
o`0000?ooo]Zo`000?l000000_l0000LoookJP03oon@0?oonf[ooo]Z00Kooo]Z1ooob@04ool000Oo
oo]Z00?oo`2koookJ_oonfX01OoonfX8oolX00oooo]Z2_oo000<oookJP03o`01oooonf[ooo]Z00[o
obP00ooo00000ol0ojKoo`00odl0o`02ool000Sooo]Z00?oo`2<oomo0?oo:0002Ooo:003oookJPCo
ogT000?o7Ol0oomi0?ooN@000_ooN@000ooo:03oJOl0ofWo000;oolX0005o`3ocOoonf[ooo]Zoook
J_oo08H02?oonfX2oh00o`;ooo]Z00?o/_l0oookJ_oonfX03OoonfX2ob?o04_ooo]Z00Co05cooook
J_oonf[ooo]Z0_l0H_l4oookJP;ooe`000?oobh0oookJ_oonfX06?oonfX2okko01?ooo]Z0omao`05
oookJP;o00Ko1?oonfX2o`3oF1Kooo]Z0ol0omDJoookJPCo01?o0ol0Y?l00ooonf[o0?nVo`3oYP06
o`3oYT;ooo]Z1?l0000MoookJP03oon@0?oonf[ooo]Z00Sooo]Z00GoL_l0oookJ_oonf[ooo]Zool0
9P0:oookJP03ool0^ooonf[ooo]Z00Wooo]Z00?ooo80oookJ_oonfX05_oonfX00on6o`3ooo]Zoook
JP0=oookJP03o`01oooonf[ooo]Z00Gooo]Z0_l_0?l2oookJP08ooo00?oonf[ooo]ZoookJ_l0ojKo
<ol0oookJ_m?0?l:oookJP03ool0S?ooO`3ooo]Z00;ooo]Z00?o0P3ooookJ_oonfX02ooonfX00olM
o`3o3@3ooookJP02oookJP;oJOl000?oVP3ooolQ0?oo0<l00ooonfX00ol0okSooo]ZoookJP02oook
JP;o0?o=0ooonfX00ooo08Kooo]ZoookJP05oookJP;oP03o0ooonfX00onbo`3ooo]ZoookJP0=oook
JP;o8ol09?oonfX002cooo]Z0_l0H_l3oookJP?ooe`06_oonfX2okko01?ooo]Z0omao`04oookJP;o
00Ko2?oo000EoookJP?o0?oE4?oonfX2oolX00Gooo]Z1?l04ol4ool00003o`3oY_oo:03oobP000oo
obP00ooonfX2ool000Kooo]Z1?oo0003oookJP;oobP00_oonfX8ool001Oooo]Z2?oo00000ooonf[o
0000o`000002o`0001_ooo]Z00?ooi00oookJ_oonfX02?oonfX6ooo900?oo`001ooonfX00ooo0;_o
oo]ZoookJP04oookJPWoobP04?oonfX:ool000_ooo]Z00?o007ooookJ_oo:0002_oo:003ool00003
o`3oY_m?0?ooC`3o00;oo`002?oonfX00ooo08coogl0oookJP09oolX00?ooo]Z1?ooN@000olMo`3o
ogT0oomi0003oolX0003ofWo0?oo:03oobP000WoobP00_l0old3oookJP03ool0Q_oonf[ooo]Z00Ko
oo]Z00GoP03ooookJ_oonf[ooo]Zok;o000?oookJP03ob?o0?oonf[ooo]Z04gooo]Z0_l0H_l3oook
JP?ooe`06_oonfX3okko01?ooo]Z0_mao`05oookJP?o00Ko1?oonfX2o`3oF1Gooo]Z0ol0omDHoook
JPCo01?o0ol0Y?l6o`3oYT[ooo]Z1?l0000LoookJP03oon@0?oonf[ooo]Z00Sooo]Z00?oL_l0oook
J_oonfX03?oonfX00ooo0;_ooo]ZoookJP09oookJP03ooob0?oonf[ooo]Z01Kooo]Z00?oQ_l0oook
J_oonfX03OoonfX00ol00Ooooo]ZoookJP05oookJP05obl0oooonf[ooo]ZoookJ_oo`0000ooonfX0
1?l0ojKo<ol0odl0oom?0?l9oookJP03ool0S?ooO`3oogl000?ooo]Z00?o0P3ooookJ_oonfX02ooo
nfX00olMo`3oHol0oookJP02oookJP04ofWo0?nJ0?ooob40ool0c`?ooo]Z0_l0okP4oookJP03o`3o
cOoonf[ooo]Z00;ooo]Z00?oo`26oookJ_oonfX01OoonfX00on00?oooo]ZoookJP02oookJP03ok;o
0?oonf[ooo]Z00gooo]Z00?o8ol0oookJ_oonfX09?oonfX002[ooo]Z0_l0H_l3oookJP;ooe`000?o
obh0oookJ_oonfX06?oonfX2okko017ooo]Z0_oo:002og7o00Cooo]Z0ol01_l:ool001;ooo]Z0ol0
omDBoookJP?oobP00_oonfX3o`0Co`03oookJ_l0Y?oo0:Co00;oo`000ol0ojH:ool000SoobP000?o
oo]Zool00?oo00000_oo000CoookJPKoo`005ooonfX8ool00003oookJ_l0003o000000;o00006_oo
nfX00oooT03ooo]ZoookJP09oookJP03og;o0?oob@3oolT000;oolT01?oo0006oookJP03ool0^ooo
nf[ooo]Z00?ooo]Z2ooo:00AoookJPSoo`002ooonfX00ol00Ooooo]ZoolX000;oolX0004ool00?l0
ojKo0?nVodl0o`?oo`002?oonfX2oomo00?ooo]Z1ooo:004oookJP?oogT000?o7Ol0oomi0?oo:000
0ooo:0000omYo`3oobP0oolX0002oolX00;ooo]Z1Ooo:0001?l0olgoobP0oookJ_oonfX2ool0QPSo
oo]Z00?oP03ooookJ_oonfX00_nbo`0?oookJP04ob?o0?oonf[ooed0oomM04_ooo]Z0_l0H_l3oook
JP;ooe`000?oobh0oookJ_oonfX06?oonfX2okko01Cooo]Z0_mao`04oookJP?o00Ko1?oonfX3o`3o
F1Cooo]Z0ol0omDGoookJPCo01?o1?l0Y?l3o`3oYU3ooo]Z1?l0000KoookJP03oon@0?oonf[ooo]Z
00Sooo]Z00?oL_l0oookJ_oonfX03?oonfX00ooo0;_ooo]ZoookJP09oookJP03ooob0?oonf[ooo]Z
01Kooo]Z00?oQ_l0oookJ_oonfX03OoonfX00ol00Ooooo]ZoookJP05oookJP05obl0oooonf[ooo]Z
oookJ_oo`0000_oonfX2o`3oYP03oc?o0?m?0?oooo]Z00Wooo]Z00?oo`2<oomo0?oonfX00_oonfX2
o`80o`cooo]Z00?o3@3ooago0?mSo`000ooonfX01?mYo`3oVP3ooolQ0?oo0<l3oookJP03o`3o^?oo
nf[ooo]Z00?ooo]Z00Co0?o=oookJ_oonf[ooo]Z0_oo08H7oookJP04oh00oooonf[ooo]ZoookJP;o
/_l03ooonfX01?lSo`3ooo]ZoomM0?ooG@0ToookJP00;OoonfX2oomL0003ool^0?oonf[ooo]Z01So
oo]Z0_nno`0BoookJP03oolX0?mao`3oLOl000Cooo]Z0_oo:002oookJP_oo`003ooonfX3o`3oeA?o
oo]Z1Ooo:002o`0Co`Co0:Co00Cooo]Zo`3oY_l0ojKo0?nV5?oonfX6ool001Gooo]Z0ooo000Goook
JPWoo`0000?ooo]Zo`000?l000000_l0000JoookJP03oon@0?oonf[ooo]Z00Sooo]Z00?oL_l0oook
J_oonfX00ooob@03ool000Kooo]Z00?oo`2koookJ_oonfX00ooonfX;oolX01?ooo]Z1_oo000:oook
JP;o007o0_oonfX;oolX0004ool00?l0ojKoo`00odl0o`Coo`001_oonfX00ooo08coogl0oookJP03
oookJP03oolX0?oonf[oobP000CoobP01_oonfX2oago00CoobP00_mYo`04oolX00;ooo]Z00?oobP0
oookJ_oo:0000_oo:0001Ol0olgoobP0oookJ_oonf[oo`2600Sooo]Z0_n00?l2oookJP03ok;o0?oo
nf[ooo]Z00kooo]Z00?o8ol0oookJ_ooG@00D?oonfX2oomL0003ool^0?oonf[ooo]Z01Sooo]Z0_nn
o`0CoookJP?oLOl01?oonfX2o`06o`Gooo]Z0_l0oePEoookJP;o0?oE5ooonfX3o`0Co`05oookJ_l0
Y?oo0:Coo`2ToooonfX00ol0ojICoookJPCo00006ooonfX00oooT03ooo]ZoookJP07oookJP03og;o
0?oonf[ooo]Z00cooo]Z00?oo`2koookJ_oonfX02OoonfX00ooolP3ooo]ZoookJP0FoookJP03ohKo
0?oonf[ooo]Z00cooo]Z0_l00Ol7oookJP03obl0oooonf[ooo]Z00;ool000_oonfX01?l0ojKo<ol0
oookJ_m?0?l:oookJP03ool0S?ooO`3ooo]Z00;ooo]Z00?o0P3ooookJ_oonfX02ooonfX2oago00?o
oo]Z0_mYo`000onJ0?ooob40ool0c`03oookJP03o`3o^?oonf[ooo]Z00?ooo]Z00Go0?o=oookJ_oo
nf[ooo]Zool0QP07oookJP;oP03o0ooonfX00onbo`3ooo]ZoookJP0=oookJP;o8ol000?ooo]ZoomM
0?oonfX09OoonfX002_ooo]Z0_ooG00JoookJP?o__l04ooonfX2og7o00?oobP000?ooo]ZoolX0?oo
:0000ooonfX<ool000cooo]Z0ol0omDDoookJPSoobP000?o0:CooookJ_l0ojH00ol0ojHEoookJPSo
o`005ooonfX00ooo003ooo]ZoookJP0HoookJPKoo`0000?ooo]Zo`000?l000000_l0000IoookJP03
oon@0?oonf[ooo]Z00Sooo]Z00?oL_l0oookJ_oonfX00_oonfX01?oob@3oo`00ool00?oo0006oook
JP03ool0^ooonf[ooo]Z00Gooo]Z2Ooo:00DoookJPKoo`002OoonfX00ol00Ooooo]ZoookJP03oook
JPWoobP000Coo`00o`3oY_oo003oC`3o1?oo0006oookJP03ool0S?ooO`3ooo]Z00?ooo]Z00CoobP0
oookJ_oonf[ooo]Z0ooo:006oookJP03oago0?oo:03oobP000?oobP000?oJOl0oolX0?oo:0000ooo
:0000ooonf[oobP0oolX0003oookJP;o0?o=00CoobP0oookJ_oonf[oo`262?oonfX00on00?oooo]Z
oookJP02ok;o00oooo]Z0_lSo`02oomM04oooo]Z0_ooG00KoookJP;o__l04ooonfX2og7o00Gooo]Z
0_l01_l5oookJP;o0?mH5?oonfX3o`3oeAKooo]Z0ol04ol01?oonf[o0:Coo`2Tool0Y?l4o`3oYUKo
oo]Z1?l0000JoookJP03oon@0?oonf[ooo]Z00Oooo]Z00?oL_l0oookJ_oonfX03?oonfX00ooo0;_o
oo]ZoookJP09oookJP03ooob0?oonf[ooo]Z01Kooo]Z00?oQ_l0oookJ_oonfX03?oonfX00ol00Ooo
oo]ZoookJP06oookJP04obl0oooonf[ooo]Zooo000?ooo]Z00Co0?nVoc?o0?m?0?ooC`3o2OoonfX2
ool0S005oomo0?oonf[ooo]ZoookJ_l20?l03OoonfX00olMo`3oHol0oookJP02oookJP03ofWo0?nJ
0?ooob4000;oo`3?0_oonfX2o`3o^0Cooo]Z0_l0old3oookJP03ool0Q_oonf[ooo]Z00Gooo]Z00Co
P03ooookJ_oonf[ooo]Z0_nbo`0?oookJP04ob?o0?oonf[ooed0oomM02Oooo]Z000ZoookJP03oomL
0?oonf[ooo]Z01Sooo]Z0_nno`0CoookJP?oLOl01_oo:003oookJPooo`002OoonfX2o`3oeAKooo]Z
1ooo:004o`3oYP_ooo]Z0_oo:00:oookJP_oo`00=OoonfX2ool00003oookJ_l0003o000000;o0000
6?oonfX00oooT03ooo]ZoookJP08oookJP03og;o0?oonf[ooo]Z00Cooo]Z0ooo0005oookJP03ool0
^ooonf[ooo]Z00Oooo]Z2?oo:00CoookJP03ool00?oonf[ooo]Z00?oo`002OoonfX00ol00Ooooo]Z
oookJP05oookJPOoobP00_l0ojH2odl0o`Coo`001_oonfX2oolX00?ooo]Z0_oo:005oookJP03oolX
0?oonf[ooo]Z00Cooo]Z00?o7Ol0oomi0?oo:0000_oo:002ofWo00OoobP01?oonfX01?l0olgooo]Z
oolX0?oonfX2ool0QPOooo]Z0_n00?l2oookJP03ok;o0?oonf[ooo]Z00kooo]Z00?o8ol0oookJ_oo
G@001?oonfX00ol0;?oooo]ZoookJP19oookJP03oomL0?oonf[ooo]Z01Wooo]Z0_nno`0CoookJP;o
LOl01OoonfX2o`06o`Cooo]Z0ol0oePDoookJP;o0?oE5_oonfX3o`0Co`03oookJ_l0Y?oo0:Co00Co
0?nVF_oonfX4o`0001Wooo]Z00?ooi00oookJ_oonfX01ooonfX00ombo`3ooo]ZoookJP0<oookJP03
ool0^ooonf[ooo]Z00Wooo]Z00?ooo80oookJ_oonfX05_oonfX00on6o`3ooo]ZoookJP0<oookJP03
o`01oooonf[ooo]Z00Gooo]Z0_l_0?l2oookJP07ooo00?oonf[ooo]ZoookJ_l0ojKo<ol0odl0o`0:
oookJP03ool0S?ooO`3oogl000;ooo]Z0_l20?l<oookJP03o`d0oolMo`3oHol000;ooo]Z0_mYo`00
0onJ0?ooob40ool0c`03oookJP03o`3o^?oonf[ooo]Z00?ooo]Z00Co0?o=oookJ_oonf[ooo]Z0_oo
08H6oookJP;oP03o0ooonfX00onbo`3ooo]ZoookJP0=oookJP;o8ol000?ooo]ZoomM0?oonfX00_oo
nfX2o`0/obCooo]Z0013oookJP;o__l04ooonfX2og7o00WoobP00_oonfX;ool000cooo]Z0_l0omDF
oookJPKoobP00ol0ojH2oolX00cooo]Z0ooo:008oookJPgoo`00>?oonfX4o`0001Sooo]Z00?ooi00
oookJ_oonfX01ooonfX00ombo`3ooo]ZoookJP06oookJP03ool00?oonf[ooo]Z00?ooo]Z00?oo`2k
oookJ_oonfX02?oonfX00ooolP3oobP0oolX0004oolX01Sooo]Z00?oo`00oookJ_oonfX01ooonfX0
0ol00Ooooo]ZoookJP04oookJP03o`1loooo:03oobP000CoobP000Cooo]Zo`3oY_oo003oC`3o1Ooo
0005oookJPCoobP00_oonfX00ooo:03ooo]ZoookJP0:oookJP;o7Ol000GoHol0oookJ_oonf[oobP0
ofWo0008oolX00?ooo]Z0_l0old3oookJP03ool0Q_oonf[ooo]Z00Kooo]Z00GoP03ooookJ_oonf[o
oo]Zok;o000@oookJP03ob?o0?oonf[ooed000Cooo]Z00?o02cooookJ_oonfX0HooonfX3okko01;o
oo]Z0omao`05oookJP;o00Ko1?oonfX2o`3oF1Gooo]Z0_l0omDFoookJP;o01?o00?ooo]Zo`2Tool0
Y?l00ol0ojHLoookJP?ookL0?ooonfX4o`0001Sooo]Z00?ooi00oookJ_oonfX02?oonfX00ombo`3o
oo]ZoookJP0;oookJP03ool0^ooonf[ooo]Z00Wooo]Z00?ooo80oookJ_oonfX09OoonfX00ol00Ooo
oo]ZoookJP05oookJP05obl0ool0O?oooo]ZoookJ_oo`0000_oonfX2o`3oYP03oc?o0?m?0?oooo]Z
00Wooo]Z00?oo`2<oomo0?oonfX00_oonfX00ol20?oooo]ZoookJP0;oookJP;o7Ol00ooonfX01OmY
o`3oVP3ooolQ0?oo8@3oo`3?00?ooo]Z00?o0?nhoookJ_oonfX00_oonfX2o`3oc@?ooo]Z00?oo`26
oookJ_oonfX01OoonfX00on00?oooo]ZoookJP02oookJP03ok;o0?oonf[ooo]Z00gooo]Z00Co8ol0
oookJ_ooG@3ooed00ooonfX00ol0;?oooo]ZoookJP0ToookJP00@OoonfX2okko01?ooo]Z0_mao`00
0ooonf[oobP0oolX0008oolX0003o`3oF?oo003oo`0000;oo`004_oonfX2o`3oeAKooo]Z1Ooo:003
o`3oYPKoobP02OoonfX6oolX00Gooo]Z3ooo000EoookJP;oobP08OoonfX4o`0001Oooo]Z00?ooi00
oookJ_oonfX01ooonfX00ombo`3ooo]ZoookJP0<oookJP03ool0^ooonf[ooo]Z00Sooo]Z00?ooo80
oookJ_oonfX01Ooo:00PoookJP;o007o1_oonfX01?l0O?ooobP0oookJ_oo`003oolX0004oookJ_l0
ojKoo`00odl0o`;ooo]Z0ooo0004oookJPGoobP00_oonfX00ooo:03ooo]ZoookJP0:oookJP03oago
0?ooN@3oHol000?ooo]Z00?oJOl0oolX0?oo:0001_oo:003oookJP03o`3ocOoonf[ooo]Z00;ooo]Z
00?oo`26oookJ_oonfX01_oonfX00on00?oooo]ZoookJP02ok;o013ooo]Z00?o8ol0oomM0?ooG@00
0ooonfX2o`0/ofCooo]Z0_nno`0CoookJP;oLOl01OoonfX3o`06o`Cooo]Z0_l0oePDoookJP?o0?oE
5OoonfX3o`0Co`;o0:Co0ol0ojHKoookJPCookL0@_oonfX4o`0001Oooo]Z00?ooi00oookJ_oonfX0
2?oonfX00ombo`3ooo]ZoookJP0;oookJP03ool0^ooonf[ooo]Z00Wooo]Z00?ooo80oookJ_oonfX0
9?oonfX2o`01o`Oooo]Z00?o;`3ooookJ_oonfX00_oo`002oookJP04o`3oY_lco`3oC`3oodl0o`Wo
oo]Z0_oo08`01OooO`3ooo]ZoookJ_oonf[o0P3o00cooo]Z00?o3@3ooago0?mSo`000ooonfX00omY
o`3oVP3ooolQ0002ool0c`;ooo]Z0_l0okP4oookJP03o`3ocOoonf[ooo]Z00;ooo]Z00?oo`26oook
J_oonfX01OoonfX01?n00?oooo]ZoookJ_oonfX2ok;o00oooo]Z00?o8ol0oookJ_ooG@000ooonfX2
o`0/obOooo]Z000ooookJP;o__l04ooonfX2og7o00;ooo]Z2Ooo:002o`3oF1Cooo]Z0ol0omDEoook
JP;o01?o0ooo:003o`3oYPWoobP02?oonfX7oolX00;ooo]Z0_oo]`0@ool001;ooo]Z1Ooo:00Qoook
JPCo00005_oonfX00oooT03ooo]ZoookJP07oookJP03og;o0?oonf[ooo]Z00cooo]Z00?oo`2koook
J_oonfX02?oonfX00ooolP3ooo]ZoookJP02oookJP?oobP08?oonfX00ol00Ooooo]ZoookJP05oook
JP04o`1loooo:03ooo]Zooo000;ooo]Z00GoobP0o`3oY_l0ojKoo`00odl0o`04oookJP04ool00?oo
nf[ooo]ZoookJPKoobP000?ooo]Zo`80oooo:0003?oonfX00olMo`3oHol0of?o0002oookJP;oJOl0
00?oobP0oolQ0?oo:0001?oo:004oookJP04o`3ocOoonf[ooo]ZoookJP;oo`261ooonfX2oh00o`;o
oo]Z00?o/_l0oookJ_oonfX03_oonfX2ob?o0003oomM0?oonf[ooo]Z00;ooo]Z00?o02cooookJ_oo
nfX0H_oonfX2okko01?ooo]Z0_mao`05oookJP;o00Ko1OoonfX2o`3oF1Cooo]Z0_l0omDFoookJP;o
01?o0_l0Y?l3o`3oYQ[ooo]Z1?oo]`16oookJPCo00005_oonfX00oooT03ooo]ZoookJP08oookJP03
og;o0?oonf[ooo]Z00_ooo]Z00?oo`2koookJ_oonfX02OoonfX00ooolP3ooo]ZoookJP0ToookJP03
o`01oooonf[ooo]Z00Kooo]Z00Co;`3ooookJ_oonf[ool000ooonfX00ol0ojKo<ol0odl0o`0:oook
JP03ool0S?ooO`3oogl000;ooo]Z0_l20?l<oookJP03o`d0oolMo`3oHol000;ooo]Z0_mYo`000onJ
0?ooob40ool0c`03oookJP03o`3o^?oonf[ooo]Z00;ooo]Z0_l0old3oookJP;oo`261_oonfX2oh00
o`?ooo]Z00?o/_l0oookJ_oonfX03OoonfX2ob?o00;ooed00ooonfX00ol0;?oooo]ZoookJP0Woook
JP00?OoonfX2okko01?ooo]Z0_mao`02oookJPWoobP00_l0oeP3oolX017ooo]Z0_l0omDFoookJP;o
01?o00?o0:CooolX0?oo:0000_l0ojH4oolX00kooo]Z2_oo:0000ooo]`3ooo]ZoookJP0OoookJPSo
obP01_oonfX4ool001Oooo]Z1?l0000EoookJP03oon@0?oonf[ooo]Z00Oooo]Z00?oL_l0oookJ_oo
nfX03?oonfX00ooo0;_ooo]ZoookJP08oookJP03ooob0?oonf[ooo]Z00Cooo]Z00?oobP0oookJ_oo
nfX07_oonfX00ol00Ooooo]ZoookJP05oookJP04obl0oooo:03ooo]Zooo000?ooo]Z00Co0?nVoook
J_oo003oC`3o1ooonfX8oolX0003o`80oooonf[ooo]Z00[ooo]Z0_lMo`002?mSo`3ooo]ZoookJ_oo
nf[oJOl0oolX0?oo8@3oo`3?0_oonfX3oolX00?ooo]Z0_l0old3oookJP03ool0Q_oonf[ooo]Z00Ko
oo]Z00GoP03ooookJ_oonf[ooo]Zok;o000@oookJP03ob?o0?ooG@3ooed000?ooo]Z0_l0;?mSoook
JP;o__l04ooonfX2og7o00Gooo]Z0_l01_l4oookJP?o0?mH5?oonfX2o`3oeAKooo]Z00Co01?oo`2T
ool0Y?oo0:Co0_l0ojHIoookJPCookL0B_oonfX4o`0001Gooo]Z00?ooi00oookJ_oonfX02?oonfX0
0ombo`3ooo]ZoookJP0;oookJP03ool0^ooonf[ooo]Z00Wooo]Z00?ooo80oookJ_oonfX09?oonfX0
0ol00Ooooo]ZoookJP05oookJP;o;`3o0_oonfX01ooo`03ooo]ZoookJ_oonf[o0?nVoc?o0?m?0?l0
2_oonfX00ooo08coogl0oookJP02oookJP03o`80oooonf[ooo]Z00_ooo]Z0_lMo`03oookJP05ofWo
0?nJ0?oooo]ZoolQ0?oo0<l00ooonfX00ol0okSooo]ZoookJP02oookJP03o`3ocOoonf[ooo]Z00;o
oo]Z00?oo`26oookJ_oonfX01OoonfX01?n00?oooo]ZoookJ_oonfX2ok;o00oooo]Z00?o8ol0oook
J_ooG@001?oonfX00ol0;?oooo]ZoookJP0XoookJP00>ooonfX2okko01?ooo]Z0_mao`03oookJPSo
obP00_l0oeP00ooo:03ooo]ZoookJP0AoookJP;o0?oE5OoonfX2o`0Co`?o0:Co00?ooo]Zo`3oY_l0
ojH04ooonfX;oolX01oooo]Z2ooo:0000ooonf[oo`00ool00007ool001Oooo]Z1?l0000CoookJP;o
iOl02OoonfX00ombo`3ooo]ZoookJP0<oookJP03ool0^ooonf[ooo]Z00Sooo]Z00?ooo80oookJ_oo
nfX09?oonfX2o`01o`Kooo]Z00Go07coobl0oooonf[ooo]Zooo00003oookJP04o`3oY_oonf[oC`3o
odl0o`Kooo]Z2Ooo:0000ol20?oooo]ZoookJP0:oookJP03oago0?ooN@3oHol000;ooo]Z0_mYo`00
0ooo:03oob40ool0c`03oookJP03o`3o^?oo:03ooo]Z00;ooo]Z00?o0?o=oookJ_oonfX00_oonfX0
0ooo08Kooo]ZoookJP05oookJP;oP03o0_oonfX2ok;o00oooo]Z0_lSo`000oooG@3ooo]ZoookJP02
oookJP03o`0/oooonf[ooo]Z067ooo]Z0_nno`0CoookJP;oLOl01OoonfX2o`06o`Cooo]Z0_l0oePD
oookJP?o0?oE5OoonfX2o`0Co`;o0:Co00?ooo]Zo`3oY_l0ojH06?oonfX3oong04kooo]Z1?l0000D
oookJP03oon@0?oonf[ooo]Z00Sooo]Z00?oL_l0oookJ_oonfX02ooonfX00ooo0;_ooo]ZoookJP09
oookJP03ooob0?oonf[ooo]Z02?ooo]Z0_l00Ol7oookJP05obl0ool0O?oooo]ZoookJ_oo`0000_oo
nfX2o`3oYP03oookJ_m?0?oooo]Z00Wooo]Z00?oo`2<oomo0?oonfX00_oonfX00ol20?oooo]Zoook
JP0:oookJP03o`d0oolMo`3oHol000;ooo]Z0_mYo`001?nJ0?ooob40oolQ0?oo0<l2oookJP;o0?nh
0ooonfX2o`3oc@Cooo]Z00?oo`26oookJ_oonfX01?oonfX2oh00o`?ooo]Z00?o/_l0oookJ_oonfX0
3OoonfX2ob?o00;ooed00ooonfX2o`0/ob_ooo]Z000ioookJP;o__l04ooonfX2og7o00Cooo]Z1_oo
:003o`3oF1Cooo]Z0_l0omDEoookJP;o01?o0_l0Y?l01?oonf[o0?nVo`3oY_l0ojHDoookJPcoobP0
7?oonfX>oolX00[oo`005ooonfX4o`0001;ooo]Z0ooUo`08oookJP03og;o0?oonf[ooo]Z00cooo]Z
00?oo`2koookJ_oonfX02?oonfX00ooolP3ooo]ZoookJP0ToookJP03o`01oooonf[ooo]Z00Gooo]Z
0_l_0?l00ooonf[ool00ooo00002oookJP;o0?nV00?ooo]Zodl0oooonfX01OoonfX:oolX00gooo]Z
00?o7Ol0of?o0?mSo`000_oonfX01?mYo`3oobP0oookJ_oo8@04oookJP04o`3o^?oonf[ooo]Zoook
JP;o0?o=0ooonfX2ool0QPOooo]Z00GoP03ooookJ_oonf[ooo]Zok;o000@oookJP03ob?o0?ooG@3o
oed000?ooo]Z0_l0;?mRoookJP;o__l04ooonfX2og7o00Gooo]Z0_l01_l4oookJP;o0?mH5?oonfX2
o`3oeAKooo]Z0_l04ol2o`2To`?o0?nV5ooonfX3oong057ooo]Z1?l0000DoookJP03oon@0?oonf[o
oo]Z00Oooo]Z00?oL_l0oookJ_oonfX02ooonfX00ooo0;_ooo]ZoookJP09oookJP03ooob0?oonf[o
oo]Z02?ooo]Z00?o007ooookJ_oonfX01_oonfX00ol_0?oooo]ZoookJP02ooo000;ooo]Z00Co0?nV
oookJ_m?0?ooC`3o2OoonfX00ooo08coogl0oomo0002oookJP;o0P3o3?oonfX2oago0008of?o0?oo
nf[ooo]ZofWo0?nJ0?oooo]ZoolQ0?oo0<l3oookJP03o`3o^?oonf[ooo]Z00;ooo]Z00?o0?o=oook
J_oonfX00_oonfX2ool0QPKooo]Z00?oP03ooookJ_oonfX00_oonfX00onbo`3ooo]ZoookJP0=oook
JP03ob?o0?oonf[ooed000Cooo]Z00?o02cooookJ_oonfX0:ooonfX003Oooo]Z0_nno`0BoookJP?o
LOl01?oonfX01?l01_ooobP0oolX0?oo:002oookJP;o0?mH5OoonfX2o`3oeACooo]Z0ol04ol2o`2T
o`03oookJ_l0ojKo0?nV01Gooo]Z3ooo:00FoookJP?o0?l^4?oo:00:ool001Oooo]Z1?l0000Aoook
JP?oiOl02OoonfX00ombo`3ooo]ZoookJP0;oookJP03ool0^ooonf[ooo]Z00Sooo]Z00?ooo80oook
J_oonfX09?oonfX00ol00Ooooo]ZoookJP05oookJP04obl0oooonf[ooo]Zooo000?ooo]Z00Co0?nV
oookJ_oonf[oC`3o1_oonfX:oolX00cooo]Z0_lMo`001_mSo`3ooo]ZoookJ_oonf[oJOl0oolX00;o
ob401?oonfX01Ol0okSooo]ZoookJ_oonf[o0?o=00Cooo]Z00?oo`26oookJ_oonfX01_oonfX00on0
0?oooo]ZoookJP02ok;o00oooo]Z0_lSo`000oooG@3ooo]ZoookJP02oookJP03o`0/oooonf[ooo]Z
063ooo]Z0_nno`0BoookJP?oLOl01OoonfX2o`06o`Cooo]Z0_l0oePDoookJP;o0?oE5OoonfX2o`0C
o`?o0:Co0_l0ojHHoookJP;ookL08OoonfXAo`3o;R;ooo]Z1?l0000CoookJP03oon@0?oonf[ooo]Z
00Oooo]Z00?oL_l0oookJ_oonfX02ooonfX00ooo0;_ooo]ZoookJP09oookJP03ooob0?oonf[ooo]Z
02?ooo]Z00?o007ooookJ_oonfX01OoonfX2obl0o`;ooo]Z00Oool00oookJ_oonf[ooo]Zo`3oY_oo
nf[oC`3o00[ooo]Z00?oo`2<oomo0?oonfX00_oonfX00ol20?oooo]ZoookJP0;oookJP03oago0?mS
o`3ooo]Z00;ooo]Z00GoJOl0oiX0oooonf[oob40ool0c`03oookJP03o`3o^?oonf[ooo]Z00;ooo]Z
00?o0?o=oookJ_oonfX00_oonfX00ooo08Kooo]ZoookJP05oookJP04oh00oooonf[ooo]ZoookJP;o
/_l03_oonfX2ob?o00;ooed00ooonfX2o`0/obkooo]Z000eoookJP;o__l04_oonfX2og7o00Gooo]Z
0_l01_l4oookJP;o0?mH5OoonfX2o`3oeACooo]Z0_l04ol3o`2To`?o0?nV5_oonfX;oolX01Gooo]Z
1_l0obh7oookJPcoobP02Ooo000HoookJPGo00003ooonfX4onGo00Sooo]Z00?oL_l0oookJ_oonfX0
2ooonfX00ooo0;_ooo]ZoookJP07oookJP;oo`009_oonfX00ol00Ooooo]ZoookJP04oookJP05o`1l
ool_0?oooo]ZoookJ_oo`0000ooonfX01?l0ojKooo]ZoookJ_m?0?l7oookJP[oobP02ooonfX00olM
o`3o3@3oof?o0002oookJP;oJOl000?oobP0oolQ0?oo0<l00ooonfX2o`3o^0?ooo]Z00Co0?o=oook
J_oonf[ooo]Z0_oo08H7oookJP;oP03o0_oonfX00onbo`3ooo]ZoookJP0>oookJP03ob?o0?ooG@3o
oed000Cooo]Z00?o02cooookJ_oonfX0GooonfX2okko01;ooo]Z0_mao`06oookJP;o00Ko1?oonfX2
o`3oF1Cooo]Z0_l0omDEoookJP;o01?o0_l0Y?l3o`3oYQOooo]Z0ooo]`0MoookJPKo0?l^<ooonfX5
o`00017ooo]Z00?ooi00oookJ_oonfX01ooonfX00ombo`3ooo]ZoookJP0;oookJP03ool0^ooonf[o
oo]Z00Sooo]Z0_oolP0UoookJP03o`01oooonf[ooo]Z00Gooo]Z00Go;`3oo`1loooonf[ooo]Zooo0
0003oookJP03o`3oY_oonf[oC`3o00[ooo]Z00?oo`2<oomo0?oonfX00_oonfX00ol20?oooo]Zoook
JP0:oookJP;o7Ol000?oHol0oookJ_oonfX00_mYo`001?nJ0?ooob40oolQ0?oo0<l2oookJP;o0?nh
0ooonfX2o`3oc@?ooo]Z0_oo08H6oookJP;oP03o0ooonfX00onbo`3ooo]ZoookJP0=oookJP03ob?o
0?oonf[ooed000Cooo]Z00?o02cooookJ_oonfX0;_oonfX003?ooo]Z0_nno`0BoookJP;oLOl01Ooo
nfX2o`06o`Cooo]Z0_l0oePDoookJP?o0?oE5?oonfX2o`0Co`;o0:Co00?ooo]Zo`3oY_l0ojH05ooo
nfX00ooo]`3oobP0oolX0002oolX01Sooo]Z1Ol0obhBoookJPOoobP02Ooo000HoookJPCo00003ooo
nfX4onGo00Sooo]Z00?oL_l0oookJ_oonfX02_oonfX2oolX00Sooo]Z1?oo000ToookJP;o007o1_oo
nfX2obl0o`;ooo]Z00?ool00oookJ_oonfX00_l0ojH00ooonf[oC`3oodl0o`09oookJPSoobP02_oo
nfX2oago0008of?o0?oonf[ooo]ZoookJ_mYo`3oVP3ooookJ_oo8@04oookJP04o`3o^?oonf[ooo]Z
oookJP;o0?o=0ooonfX00ooo08Kooo]ZoookJP06oookJP05oh00oooonf[ooo]ZoookJ_nbo`003ooo
nfX2ob?o0003oomM0?oonf[ooo]Z00;ooo]Z0_l0;?l:oookJP;o0?_oE?oonfX2okko01;ooo]Z0_ma
o`05oookJP?o00Ko0ooonfX3o`3oF1?ooo]Z0ol0omDDoookJP?o01?o0_l0Y?l2o`3oYQSooo]Z0_oo
]`0JoookJPKo0?l^>OoonfX4o`0001;ooo]Z00?ooi00oookJ_oonfX01_oonfX00ombo`3ooo]Zoook
JP0;oookJP03ool0^ooonf[ooo]Z00Sooo]Z00?ooo80oookJ_oonfX08ooonfX2o`01o`Oooo]Z00Go
;`3ooookJ_oonf[ooo]Zooo00002oookJP;o0?nV0_m?0?l:oookJP04ool0S?ooO`3ooo]ZoookJP;o
0P3o3?oonfX00olMo`3oHol0oookJP02oookJP05ofWo0?nJ0?oooo]ZoolQ0?oo0<l00ooonfX00ol0
okSooo]ZoookJP02oookJP03o`3ocOoonf[ooo]Z00;ooo]Z00?oo`26oookJ_oonfX01OoonfX01?n0
0?oooo]ZoookJ_oonfX2ok;o00kooo]Z0_lSo`02oomM00Cooo]Z00?o02cooookJ_oonfX02OoonfX2
o`3kobCooo]Z000aoookJP;o__l04_oonfX2og7o00Gooo]Z0_l01_l4oookJP;o0?mH5?oonfX2o`3o
e@cooo]Z0_ooN@06oookJP?o01?o0_l0Y?l00ooonf[o0?nVo`3oYP0FoookJP?ookL06_oonfX3o`3o
;Qcooo]Z0_oo:003oookJPKoo`006?oonfX4o`0000gooo]Z1_oUo`07oookJP03og;o0?oonf[ooo]Z
00[ooo]Z0ooo:006oookJPGoo`009?oonfX00ol00Ooooo]ZoookJP05oookJP03obl0oooonf[ooo]Z
00;oolT00_oonfX01?l0ojKooo]ZoookJ_m?0?l:oookJP03ool0S?oo:03oobP000GoobP02_oonfX0
0olMo`3o3@3oof?o0003oookJP04ofWo0?nJ0?oooo]ZoolQ00Cooo]Z00Go0?nhoookJ_oonf[ooo]Z
o`3oc@04oookJP03ool0Q_oonf[ooo]Z00Gooo]Z0_n00?l2oookJP;o/_l03ooonfX00olSo`3ooo]Z
oomM0004oookJP03o`0/oooonf[ooo]Z00Wooo]Z00?o0?_ooookJ_oonfX0D_oonfX2okko01;ooo]Z
0_mao`05oookJP;o00Ko1?oonfX2o`3oF1Cooo]Z0_l0omDEoookJP;o01?o00?ooo]Zo`2Tool0Y?l0
0_l0ojHGoookJP?ookL06OoonfX3o`3o;Soooo]Z1?l0000AoookJP03oon@0?oonf[ooo]Z00Kooo]Z
00?oL_l0oookJ_oonfX02ooonfX00ooo0;_ooo]ZoookJP08oookJP03ooob0?oonf[ooo]Z02?ooo]Z
00?o007ooookJ_oonfX01_oonfX00ol_0?oooo]ZoookJP02ooo000;ooo]Z00?o0?nVoookJ_m?0?l0
2ooonfX2oomo00;ooo]Z00?o0P3ooookJ_oonfX02_oonfX2oago0009of?o0?oonf[ooo]ZoookJ_mY
o`3oVP3ooookJ_oo8@3oo`3?00?ooo]Z00Co0?nhoookJ_oonf[ooo]Z0_l0old3oookJP;oo`261_oo
nfX2oh00o`?ooo]Z00?o/_l0oookJ_oonfX03OoonfX00olSo`3ooo]ZoomM0004oookJP;o02co2ooo
nfX00ol0nooooo]ZoookJP0ToookJP00;ooonfX2okko01;ooo]Z0_mao`05oookJP;o00Ko1?oonfX2
oolX01Cooo]Z0_l0omD=oookJP?oogT01?oonfX2o`0Co`03oookJ_l0Y?oo0:Co00?o0?nV5OoonfX3
oong01[ooo]Z0ol0obhXoookJP;oo`006?oonfX4o`0000cooo]Z1ooUo`06oookJP03og;o0?oonf[o
oo]Z00Wooo]Z1?oo:005oookJPKoo`009?oonfX00ol00Ooooo]ZoookJP04oookJP;o;`3o1Ooob@00
0ooonf[o0?nVoookJP02odl0o`[ooo]Z00Coo`2<oolX0?oonf[ooo]Z1Ooo:009oookJP03oago0?mS
o`3oHol000;ooo]Z0_mYo`000onJ0?ooob40oolQ0003oookJP;o0?nh0_oonfX2o`3oc@?ooo]Z0_oo
08H7oookJP05oh00oooonf[ooo]ZoookJ_nbo`003ooonfX2ob?o00;ooed00ooonfX2o`0/o`[ooo]Z
0_l0nomCoookJP;o__l04_oonfX2og7o00Gooo]Z0_l01_l4oookJP;o0?mH5?oonfX2o`3oeACooo]Z
0ol04ol00ooonf[o0:Coo`3oYP02o`3oYQKooo]Z0ooo]`0IoookJP?o0?l^@_oonfX4o`00017ooo]Z
00?ooi00oookJ_oonfX01OoonfX00ombo`3ooo]ZoookJP0;oookJP03ool0^ooonf[ooo]Z00Sooo]Z
00?ooo80oookJ_oonfX08ooonfX00ol00Ooooo]ZoookJP05oookJP;o;`3o0_oonfX00ooo`03ooo]Z
oookJP02o`3oYP03oookJ_m?0?oooo]Z00Wooo]Z00?oo`2<oomo0?oonfX00_oonfX00ol20?oooo]Z
oookJP0:oookJP03oago0?mSo`3oHol000;ooo]Z0_mYo`001?nJ0?ooob40oolQ0?oo0<l2oookJP;o
0?nh0ooonfX00ol0olgooo]ZoookJP02oookJP03ool0Q_oonf[ooo]Z00Gooo]Z00CoP03ooookJ_oo
nf[ooo]Z0_nbo`0>oookJP;o8ol00_ooG@04oookJP03o`0/oooonf[ooo]Z00Wooo]Z0_l0nolWoook
JP00;OoonfX2okko01;ooo]Z0_mao`03oookJP;oobP00_l01_l4oookJP;oobP05?oonfX2o`3oe@ko
oo]Z1OooN@001?oonf[oogT0oomi0?oonfX2o`2To`;o0?nV5OoonfX3oong01[ooo]Z0ol0obi5oook
JPCo00002ooonfX7onGo00Oooo]Z00?oL_l0oookJ_oonfX01ooonfX5oolX00Gooo]Z1ooo000Roook
JP;o007o1_oonfX00ol_0?ooo`00ooo90004ooo900;o0?nV00?ooo]Zodl0oooonfX02OoonfX2ool0
S005oolX0?oonf[ooo]Zo`80oooonfX00ooo:008oookJP;o7Ol000SoHol0oookJ_oonf[ooo]ZofWo
0?nJ0?oooo]ZoolQ00Cooo]Z00Go0?nhoookJ_oonf[ooo]Zo`3oc@04oookJP03ool0Q_oonf[ooo]Z
00Gooo]Z0_n00?l3oookJP03ok;o0?oonf[ooo]Z00gooo]Z00?o8ol0oookJ_ooG@001?oonfX00ol0
;?oooo]ZoookJP09oookJP03o`3koooonf[ooo]Z057ooo]Z0_nno`0BoookJP;oLOl01OoonfX2o`06
o`Cooo]Z0_l0oePDoookJP;o0?oE5?oonfX2o`0Co`03oookJ_l0Y?oo0:Co00;o0?nV5_oonfX3oong
01Wooo]Z0ol0obi5oookJPCo00004?oonfX00oooT03ooo]ZoookJP06oookJP03og;o0?oonf[ooo]Z
00[ooo]Z00?oo`2koookJ_oonfX02?oonfX00ooolP3ooo]ZoookJP0SoookJP03o`01oooonf[ooo]Z
00Gooo]Z00Go;`3oo`1loooonf[ooo]Zooo00002oookJP04o`3oY_oonf[oC`3oodl0o`[ooo]Z00Co
o`2<oomo0?oonf[ooo]Z0_l20?l<oookJP03oago0?mSo`3ooo]Z00;ooo]Z00GoJOl0oiX0oooonf[o
ob40ool0c`03oookJP04o`3o^?oonf[ooo]ZoookJP;o0?o=0ooonfX2ool0QPKooo]Z0_n00?l3oook
JP03ok;o0?oonf[ooo]Z00gooo]Z00?o8ol0oookJ_ooG@001?oonfX2o`0/o`_ooo]Z00?o0?_ooook
J_oonfX09ooonfX002_ooo]Z0_nno`0BoookJP;oLOl01?oonfX3oolX00Cooo]Z0_oo:00CoookJP?o
0?oE3_oonfX8oomi00?o0:Co0_l0ojHEoookJP;ookL06_oonfX3o`3o;P[ooo]Z0_oo000loookJPCo
00002_oonfX8onGo00Kooo]Z00?oL_l0oookJ_oonfX01ooonfX6oolX00?ooo]Z2?oo000RoookJP03
o`01oooonf[ooo]Z00?ooo]Z0_oo00000ol_0?ooo`00ool00004ooo90004o`3oY_oonf[ooo]Zodl0
o`[ooo]Z00Coo`2<oomo0?oo:03ooo]Z0_l20?l3oookJP03oolX0?oonf[ooo]Z00Kooo]Z00?o7Ol0
o`d0oomSo`000_oonfX2ofWo0003oiX0oooo8@3oob4000?ooo]Z0_l0okP3oookJP04o`3ocOoonf[o
oo]ZoookJP;oo`261ooonfX01?n00?oooo]ZoookJ_oonfX2ok;o00oooo]Z00?o8ol0oolX0?oo:000
0ooonfX2o`0/o`[ooo]Z0_l0nomBoookJP;o__l04_oonfX2og7o00Gooo]Z0_l01_l4oookJP;o0?mH
4ooonfX3o`3oeACooo]Z0_l04ol00ooonf[o0:Coo`2To`02o`3oYQGooo]Z0ooo]`0IoookJP?o0?l^
B?oonfX4o`0000oooo]Z00?ooi00oookJ_oonfX01_oonfX00ombo`3ooo]ZoookJP0:oookJP03ool0
^ooonf[ooo]Z00Sooo]Z00?ooo80oookJ_oonfX08_oonfX2o`01o`Oooo]Z00?o;`3ooookJ_oonfX0
0_oo`002oookJP03o`3oY_oonf[oC`3o00_ooo]Z0_ooO`02oookJP03o`80oooonf[ooo]Z00[ooo]Z
0_lMo`000omSo`3ooo]ZoookJP02ofWo0004oiX0oooo8@3oob40ool0c`;ooo]Z0_l0okP3oookJP03
o`3ocOoonf[ooo]Z00;ooo]Z00?oo`26oookJ_oonfX01OoonfX01?n00?oooo]ZoookJ_oonfX2ok;o
00oooo]Z00?o8ol0oomM0?ooG@001?oonfX00ol0;?oooo]ZoookJP09oookJP;o0?_o:_oonfX002[o
oo]Z00?o__l0oookJ_oonfX04?oonfX2og7o00Cooo]Z00?o00KooolX0?oo:0000ooo:0000ooonf[o
obP0oolX000CoookJP;o0?oE4?oonfX7oomi00;o0:Co00?ooo]Zo`3oY_l0ojH05OoonfX2oong01Wo
oo]Z00?o0?l^ool00?oo00003?oonfX3ool003cooo]Z1?l00009oookJPSoiOl01_oonfX00ombo`3o
oo]ZoookJP06oookJPOoobP00_oonfX:ool0027ooo]Z00?o007ooookJ_oonfX00_oonfX6ool000Co
olT000Co0?nVoookJ_m?0?ooC`3o2_oonfX01Ooo08coogl0oookJ_oonf[o0P3o00cooo]Z0_lMo`02
of?o00;ooo]Z00CoJOl0oiX0oooonf[oob401?oonfX01?l0okSooo]ZoookJ_oonfX2o`3oc@?ooo]Z
00?oo`26oookJ_oonfX01OoonfX2oh00o`?ooo]Z00?o/_l0oookJ_oonfX03OoonfX5oolX00;ooo]Z
00?o02cooookJ_oonfX02OoonfX00ol0nooooo]ZoookJP1AoookJP03okko0?oonf[ooo]Z013ooo]Z
0_mao`04oookJP?o00Ko1?oonfX2o`3oF1?ooo]Z0_l0omDDoookJP?o01?o00?ooo]Zo`2Tool0Y?l0
0_l0ojHEoookJP;ookL06OoonfX3o`3o;T_ooo]Z1?l0000>oookJP03oon@0?oonf[ooo]Z00Kooo]Z
00?oL_l0oookJ_oonfX02_oonfX00ooo0;_ooo]ZoookJP08oookJP03ooob0?oonf[ooo]Z02;ooo]Z
00?o007ooookJ_oonfX01OoonfX2obl0o`;ooo]Z00?ool00oookJ_oonfX00_l0ojH00ooonf[oC`3o
oookJP0:oookJP05oomo0?oonf[ooo]ZoookJ_l20?l03?oonfX00olMo`3oHol0of?o0002oookJP05
ofWo0?nJ0?oooo]ZoolQ0?oo0<l00ooonfX01?l0okSooo]ZoookJ_oonfX2o`3oc@?ooo]Z0_oo08H6
oookJP;oP03o0ooonfX00onbo`3ooo]ZoookJP0=oookJP;o8ol000?ooed0oookJ_oonfX00ooonfX0
0ol0;?oooo]ZoookJP08oookJP;o0?_o;?oonfX003cooo]Z00?oLOl0oookJ_oonfX00_oonfX2o`06
o`OoobP04ooonfX2o`3oeA7ooo]Z1_ooN@02o`2To`?o0?nV5OoonfX2oong01Sooo]Z0ol0obh3ool0
00_ooo]Z1Ooo000koookJPCo00002?oonfX9onGo00Gooo]Z00?oL_l0oookJ_oonfX01OoonfX9oolX
0003oookJ_oo003oo`0000Soo`008?oonfX2o`01o`?ooo]Z1ooo0004ooo90003o`3oY_oonf[oC`3o
00[ooo]Z0_oo08`01?ooO`3ooo]Zool00?oo000<oookJP03oago0?l=0?ooHol000?ooo]Z00CoJOl0
oiX0oooo8@3oob401?oonfX01Ol0okSooo]ZoookJ_oonf[o0?o=00?ooo]Z0_oo08H7oookJP04oh00
oooonf[ooo]ZoookJP;o/_l03_oonfX6oolX0003oookJ_l0;?oo02co00_ooo]Z00?o0?_ooookJ_oo
nfX01OoonfX2ool0ZUgooo]Z00?oLOl0oookJ_oonfX00_oonfX2o`06o`Gooo]Z0_l0oePCoookJP;o
0?oE5?oonfX2o`0Co`03oookJ_l0Y?oo0:Co00?o0?nV5OoonfX2oong01Sooo]Z0ol0obi>oookJPCo
00003_oonfX00oooT03ooo]ZoookJP05oookJP03og;o0?oonf[ooo]Z00[ooo]Z00?oo`2koookJ_oo
nfX02?oonfX00ooolP3ooo]ZoookJP0RoookJP03o`01oooonf[ooo]Z00Gooo]Z00Go;`3ooookJ_oo
nf[ooo]Zooo00002oookJP04o`3oY_oonf[ooo]Zodl0o`[ooo]Z00Coo`2<oomo0?oonf[ooo]Z0_l2
0?l;oookJP;o7Ol000KoHol0oookJ_oonf[ooo]ZofWo0?nJ0?l2oolQ0005ool0cooonf[ooo]Zoook
J_l0okP00ooonfX00ol0olgooo]ZoookJP02oookJP03ool0Q_oonf[ooo]Z00Gooo]Z00?oP03ooook
J_oonfX00_oonfX00onbo`3ooo]ZoookJP0=oookJP03ob?o0?oonf[ooed000Cooo]Z0_l0;?l:oook
JP03o`3koooonf[ooo]Z00Kooo]Z0_oo0:XToookJP00>_oonfX2og7o00?ooo]Z0_l01_l00ooonf[o
obP0oolX0006oolX017ooo]Z0_l0omDAoookJPKoogT00_l0Y?l2o`3oYP?oogT04_oonfX3oong01Oo
oo]Z0ol0obh00ooonf[oo`00ool00004ool000Sooo]Z1ooo000koookJPCo00002_oonfX6onGo00Go
oo]Z00?oL_l0oookJ_oonfX01OoonfX9oolX00;ooo]Z2Ooo000PoookJP03o`01oooonf[ooo]Z00Wo
o`000ooob@02o`3oYP;oC`3o2_oonfX00ooo08coogl0oomo0004ool000_ooo]Z00?o7Ol0of?o0?mS
o`000_oonfX2ofWo0003oiX0oooo8@3oo`3?00?ooo]Z0_l0okP3oookJP05o`3ocOoonf[ooo]Zoook
J_oo08H01ooonfX2oh00o`?ooo]Z00?o/_l0oookJ_oonfX02ooonfX8oolX0003oookJ_l0;?oooo]Z
00[ooo]Z0_l0nol7oookJP03ool0Z_oooP3oooh005_ooo]Z0_mao`03oookJP;o00Ko1OoonfX2o`3o
F1?ooo]Z0_l0omDDoookJP;o01?o00?ooo]Zo`2Tool0Y?l00_l0ojHEoookJP?ookL05ooonfX3o`3o
;U7ooo]Z1?l0000=oookJP03oon@0?oonf[ooo]Z00Gooo]Z00?oL_l0oookJ_oonfX02_oonfX00ooo
0;_ooo]ZoookJP0]oookJP03o`01oooonf[ooo]Z00Cooo]Z00?o07coobl0oooonfX00_oonfX01Ooo
`03ooo]Zo`3oY_l0ojKooo]Z00;oC`3o2_oonfX2oomo00;ooo]Z00?o0P3ooookJ_oonfX02_oonfX0
0olMo`3ooo]Zof?o0002oookJP;oJOl000CoVP3ooolQ0?oo0<ooo`3?0_oonfX2o`3o^0?ooo]Z00Co
0?o=oookJ_oonf[ooo]Z0_oo08H6oookJP;oP03o0ooonfX2ok;o00kooo]Z0_lSo`02oomM00Cooo]Z
00?o02cooookJ_oonfX02?oonfX2o`3ko`Sooo]Z00?oo`2Zooon0?oooP009?oonfX003Sooo]Z0_ma
o`03oookJP;o00Ko00?ooo]ZoolX0?oo:0002?oo:00?oookJP;o0?oE4_oonfX5oomi00;o0:Co0_l0
ojH2oomi01?ooo]Z0_oo]`0GoookJP?o0?l^0ooonfX7ool000Oooo]Z2Ooo000joookJPCo00002ooo
nfX5onGo00Cooo]Z00?oL_l0oookJ_oonfX01OoonfX9oolX00Cooo]Z2?oo000OoookJP03o`01oooo
nf[oo`0000[oo`000_oob@000ol0ojKoolT0odl0o`0:oookJP;oo`2<00?oogl0ool00?oo00000ooo
000:oookJP;o7Ol000KoHol0oookJ_oonf[ooo]ZofWo0?nJ0?l2oolQ00Cooo]Z00Co0?nhoookJ_oo
nf[ooo]Z0_l0old3oookJP03ool0Q_oonf[ooo]Z00Gooo]Z00?oP03ooookJ_oonfX00_oonfX00onb
o`3ooo]ZoookJP0:oookJPWoobP000?ooo]Zo`0/oooonfX02_oonfX00ol0nooooo]ZoookJP05oook
JP;oo`2Z00?oooh0ofko0?m^o`00FOoonfX2og7o00?ooo]Z0_l01_l6oookJP03o`3oF?oonf[ooo]Z
017ooo]Z0_l0omDCoookJP?o01?o00?ooo]Zo`2Tool0Y?l00_l0ojHEoookJP;ookL05ooonfX3o`3o
;UCooo]Z1?l0000<oookJP03oon@0?oonf[ooo]Z00Kooo]Z00?oL_l0oookJ_oonfX02OoonfX00ooo
0;_ooo]ZoookJP0]oookJP03o`01oooonf[ooo]Z00Cooo]Z0_l_0?l2oookJP;ool0000Gooo]Zo`3o
Y_oonf[ooo]Zodl0o`0:oookJP03ool0S?ooO`3ooo]Z00;ooo]Z00?o0P3ooookJ_oonfX02OoonfX2
oago00;oHol00_oonfX01OmYo`3oVP3ooolQ0?oo8@3oo`3?00?ooo]Z00Co0?nhoookJ_oonf[ooo]Z
0_l0old3oookJP03ool0Q_oonf[ooo]Z00Gooo]Z00?oP03ooookJ_oonfX00_oonfX00onbo`3ooo]Z
oookJP0=oookJP03ob?o0?oonf[ooed000Cooo]Z0_l0;?l:oookJP03o`3koooonf[ooo]Z00Kooo]Z
00?oo`2Zooon0?oooP000_m^o`0ToookJP00=_oonfX2og7o00?ooo]Z0_l01_l2oookJPcoobP03Ooo
nfX00ol0omGooo]ZoookJP0AoookJPCoogT000Co0:Coo`3oY_l0ojKo0?nV5OoonfX2oong01Oooo]Z
0_l0obh4oookJP[oo`001OoonfX:ool003[ooo]Z1?l0000;oookJP03oon@0?oonf[oiOl000;oiOl0
0ooonfX00ombo`3ooo]ZoookJP07oookJPSoobP01OoonfX6ool001kooo]Z0_l00Ol00ooonf[oo`00
ool00009ool000;oolT000?o0?nVooo90?m?0?l02_oonfX00ooo08coogl0oomo0005ool000[ooo]Z
00?o7Ol0o`d0oomSo`000_oonfX2ofWo0003oiX0oooo8@3oo`3?00Cooo]Z00Go0?nhoookJ_oonf[o
oo]Zo`3oc@03oookJP;oo`261_oonfX2oh00o`?ooo]Z0_nbo`0:oookJP_oobP00_l0;?l:oookJP;o
0?_o1ooonfX01?oo0:[oooh0ooon0?m^o`1IoookJP;oLOl00ooonfX2o`06o`Kooo]Z0_l0oePCoook
JP03o`3oeOoonf[ooo]Z017ooo]Z0_l04ol2oookJP04o`2Tool0ojKo0?nVo`3oYQGooo]Z0_oo]`0G
oookJP;o0?l^EooonfX4o`0000_ooo]Z00?ooi00oookJ_oonfX01_oonfX00ombo`3ooo]ZoookJP09
oookJP03ool0^ooonf[ooo]Z02cooo]Z0_l00Ol6oookJP05obl0oooonf[ooo]ZoookJ_oo`0000_oo
nfX01?l0ojKooo]ZoookJ_m?0?l:oookJP;oogl00_oonfX2o`80o`_ooo]Z00?o7Ol0o`d0oomSo`00
0_oonfX2ofWo0004oiX0oooo8@3ooo]Zool0c`?ooo]Z00Go0?nhoookJ_oonf[ooo]Zo`3oc@03oook
JP;oo`261_oonfX2oh00o`?ooo]Z0_nbo`0>oookJP;o8ol00_ooG@04oookJP03o`0/oooonf[ooo]Z
00Sooo]Z0_l0nol8oookJP04ool0Z_oooP3ooc00ofko02Kooo]Z000doookJP;oLOl00ooonfX2o`06
o`?ooo]Z2_oo:00>oookJP;o0?oE4_oonfX01Ol04oooogT0oomi0?ooN@3o0:Co00;o0?nV5_oonfX2
oong01Kooo]Z0ol0obh5oookJP_oo`000ooonfX=ool001_ooo]Z0_ooN@0LoookJPCo00002ooonfX0
1?ooT03ooo]ZoookJ_oUo`03oookJP03og;o0?oonf[ooo]Z00Wooo]Z1_oo:007oookJPGoo`007Ooo
nfX00ol00Ooooo]Zool0000;ool00003ooo90?ooN@3oogT000;oobP02OoonfX00ooo003oo`2<oomo
0006ool000[ooo]Z00?o7Ol0of?o0?mSo`000_oonfX01OmYo`3oVP3ooolQ0?oo8@3oobP000?ooo]Z
0_oo0002oookJP;o0?o=0ooonfX00ooo08Kooo]ZoookJP05oookJP03oh00oooonf[ooo]Z00;ooo]Z
00?o/_l0oookJ_oonfX02OoonfX;oolX0003o`0/oooonf[ooo]Z00Wooo]Z00?o0?_ooookJ_oonfX0
1OoonfX2ool0ZP03ooon0?oonf[oK_l005Sooo]Z0_mao`03oookJP;o00Ko1_oonfX2o`3oF1?ooo]Z
0_l0omDBoookJP;o01?o0_oonfX00ol0Y?oo0?nVo`3oYP0FoookJP;ookL05_oonfX3o`3o;P[ooo]Z
0_oooP0;oookJP;oocL0@?oonfX4o`0000_ooo]Z00?ooi00oookJ_oonfX01OoonfX00ombo`3ooo]Z
oookJP09oookJP03ool0^ooonf[ooo]Z02cooo]Z00?o007ooookJ_oonfX01?oonfX00ol0O?oo;`3o
oookJP02oookJP05ooo00?oonf[o0?nVo`3oY_oonfX00_m?0?l:oookJP05oomo0?oonf[ooo]Zoook
J_l20?l03?oonfX00olMo`3ooo]Zof?o0002oookJP04ofWo0?nJ0?ooob40oolQ00;oo`3?0_oonfX2
o`3o^0;ooo]Z0_l0old3oookJP03ool0Q_oonf[ooo]Z00Gooo]Z00?oP03ooookJ_oonfX00_oonfX0
0onbo`3ooo]ZoookJP0=oookJP03ob?o0?oonf[ooed000Gooo]Z00?o02cooookJ_oonfX02?oonfX0
0ol0nooooo]ZoookJP06oookJP05ool0Z_oooP3oooh0oookJ_m^o`009ooonfX003;ooo]Z0_mao`04
oookJP03o`06oooonf[ooo]Z00;ooo]Z1ooo:00@oookJP;o0?oE4_oonfX2o`0Co`;ooo]Z00?o0:Co
o`3oY_l0ojH05_oonfX2oong01Kooo]Z0_l0obh7oookJPcoo`000_oonfX>ool001Wooo]Z1?ooN@0L
oookJPCo00002_oonfX00oooT03ooo]ZoookJP04oookJP03og;o0?oonf[ooo]Z00Wooo]Z0_oo0005
oolX00Sooo]Z0ooo000MoookJP03o`01oooonf[oo`0000[oo`000_ooN@05oolX00Oooo]Z00Coo`00
ool0S?oo08coogl01_oo0009oookJP;o7Ol000OoHol0oookJ_oonf[ooo]ZofWo0?nJ0?ooob4000?o
obP01Ooo00000ooonf[o0?o=oookJP02oookJP;oo`261_oonfX2oh00o`?ooo]Z0_nbo`0<oookJP_o
obP02_oonfX2o`3ko`Oooo]Z00?oo`2Zooon0?oooP000_m^o`1GoookJP;oLOl01?oonfX00ol01_oo
oo]ZoookJP04oookJP;o0?mH4ooonfX2o`3oeA;ooo]Z0_l04ol2oookJP03o`2Tool0ojKo0?nV01Ko
oo]Z0_oo]`0FoookJP;o0?l^2_oonfX3ooon00[ooo]Z0ooo=`12oookJPCo00002_oonfX00oooT03o
oo]ZoookJP05oookJP03og;o0?oonf[ooo]Z00Wooo]Z00?oo`2koookJ_oonfX0;?oonfX00ol00Ooo
oo]ZoookJP04oookJP;o;`3o0_oonfX2ooo00005oookJ_l0ojKooo]ZoookJ_m?0?l02_oonfX01?oo
08coogl0oookJ_oonfX2o`80o`cooo]Z00?o7Ol0of?o0?mSo`000_oonfX01OmYo`3oVP3ooolQ0?oo
nf[oo`3?00?ooo]Z00Go0?nhoookJ_oonf[ooo]Zo`3oc@03oookJP;oo`261_oonfX2oh00o`?ooo]Z
0_nbo`0>oookJP;o8ol000?ooo]ZoomM0?oonfX00ooonfX2o`0/o`Wooo]Z0_l0nol8oookJP;oooh0
00?ooc00ofko0?m^o`00:?oonfX0033ooo]Z0_mao`04oookJP;o00Ko1?oonfX5oolX017ooo]Z0_l0
omDBoookJP;o01?o0_oonfX00ol0Y?oo0?nVo`3oYP0FoookJP;ookL05_oonfX2o`3o;POooo]Z6Ooo
00000ooonf[oo`00ool00003ool001Kooo]Z1_ooN@0LoookJPCo00002OoonfX00oooT03ooo]Zoook
JP04oookJP03og;o0?oonf[ooo]Z00Wooo]Z0ooo00001?oonf[oobP0oolX0?oo:00:oookJP03ool0
0?oonf[ooo]Z01_ooo]Z00?o007ooookJ_oonfX02Ooo0002oomi00KoobP01ooonfX01?oo003oo`2<
oomo0?ooO`06ool000Wooo]Z00?o7Ol0of?o0?mSo`000_oonfX2oolX0003ool00?oo8@3oobP000;o
obP01Ooo00000ooonf[o0?o=oookJP02oookJP03ool0Q_oonf[ooo]Z00Gooo]Z00?oP03ooookJ_oo
nfX00_oonfX00onbo`3ooo]ZoookJP0=oookJPWoobP02_oonfX00ol0nooooo]ZoookJP05oookJP;o
o`2Z00?oooh0oookJ_m^o`001OoonfX00oob0?oooo]ZoookJP1?oookJP;oLOl01?oonfX2o`06o`Go
oo]Z0_l0oePCoookJP;o0?oE4_oonfX2o`0Co`;ooo]Z00?o0:Coo`3oY_l0ojH05_oonfX2oong01Ko
oo]Z0_l0obh:oookJP;oooh02_oonfX3oolg04Gooo]Z1?l00009oookJP03oon@0?oonf[ooo]Z00Go
oo]Z00?oL_l0oookJ_oonfX02OoonfX00ooo0;_ooo]ZoookJP0[oookJP;o007o1_oonfX01Ol_0?oo
oo]ZoookJ_oonf[ool0000;ooo]Z00Co0?nVoookJ_oonf[oC`3o2_oonfX2oomo00;ooo]Z00?o0P3o
oookJ_oonfX02_oonfX2oago0003of?o0?oonf[ooo]Z00;oJOl000CoVP3ooolQ0?oo0<ooo`3?0_oo
nfX2o`3o^0?ooo]Z00Go0?o=oookJ_oonf[ooo]Zool0QP07oookJP03oh00oooonf[ooo]Z00;ooo]Z
00?o/_l0oookJ_oonfX03OoonfX01?lSo`3ooo]ZoomM0?ooG@04oookJP03o`0/oooonf[ooo]Z00So
oo]Z00?o0?_ooookJ_oonfX01_oonfX01Ooo0:[oooh0ool`0?oonf[oK_l000Cooo]Z0_ob0?lToook
JP00;ooonfX00omao`3ooo]ZoookJP02oookJP;o00Ko1?oonfX00ol0oeSoobP0oolX000CoookJP;o
0?oE4_oonfX2o`0Co`;ooo]Z00?o0:Coo`3oY_l0ojH05OoonfX3oong00Gooo]Z0_oo000?oookJP;o
0?l^2?oonfX<ool000;ooo]Z00?oocL0ool00?oo00000_oo0006oookJPOoo`005?oonfX9oomi01_o
oo]Z1Ol00008oookJP03oon@0?oonf[ooo]Z00?ooo]Z00?oL_l0oookJ_oonfX02?oonfX4ool000?o
oo]Z00?oobP0oookJ_oonfX09OoonfX2o`01o`Cooo]Z1Ooo0003oomi00OoobP01ooonfX2ool0S003
oomo0?oo003oo`0000Koo`001ooonfX01?l=0?oo7Ol0of?o0?oonfX5oolX0004ool00?oo:03oobP0
oolX00Goo`000_l0old2oookJP;oo`261_oonfX2oh00o`?ooo]Z0_nbo`0>oookJP;o8ol02?oo:009
oookJP;o0?_o1_oonfX2ool0ZP;oooh000?ooo]Zofko0?oonfX01?oonfX00oob0?oooo]ZoookJP1?
oookJP03og7o0?oonf[ooo]Z00;ooo]Z0_l01_l5oookJP;o0?mH4ooonfX2o`3oeA;ooo]Z0_l04ol3
oookJP;o0?nV5_oonfX2oong01Kooo]Z0_l0obh9oookJP?oooh02_oonfX2oolg04Sooo]Z1Ol00008
oookJP03oon@0?oonf[ooo]Z00Cooo]Z00?oL_l0oookJ_oonfX02OoonfX00ooo0;_ooo]ZoookJP0[
oookJP03o`01oooonf[ooo]Z00Gooo]Z00?o;`3ooookJ_oonfX00_oo`0001?oonf[o0?nVo`3oY_oo
nfX2odl0o`Wooo]Z00?oo`2<oomo0?oonfX00_oonfX00ol20?oooo]ZoookJP0:oookJP03oago0?oo
nf[oHol000;ooo]Z00GoJOl0oiX0oooo8@3ooo]Zool0c`03oookJP04o`3o^?oonf[ooo]ZoookJP;o
0?o=0_oonfX2ool0QPKooo]Z0_n00?l3oookJP;o/_l03_oonfX2ob?o0003oookJ_ooG@3ooo]Z00?o
oo]Z0_l0;?l9oookJP;o0?_o1ooonfX01_oo0:[oooh0ooon0?oo<03ooo]Zofko00Cooo]Z00?olP3o
oookJ_oonfX09?oonfX002gooo]Z0_mao`03oookJP;o00Ko1?oonfX2o`3oF1Gooo]Z00?o0?oEoook
J_oonfX04?oonfX2o`0Co`;ooo]Z00?o0:Coo`3oY_l0ojH05OoonfX2oong00Oooo]Z0ooo000=oook
JP;o0?l^2?oonfX00ooooP3oo`00ool00004ool000?oobP00ooo0003oolg00[ooo]Z2Ooo000Aoook
JP_oogT02Ol0YolBoookJPCo00002?oonfX00oooT03ooo]ZoookJP03oookJP03og;o0?oonf[ooo]Z
00Oooo]Z1Ooo000[oookJP03o`01oooonf[ooo]Z00Gooo]Z0_oo0002oomi00WoobP01ooonfX00ooo
08cooo]Zoomo0008ool000Oooo]Z0_lMo`07oolX0004ool00?oo:03oobP0oolX00Goo`0000Go0?o=
oookJ_oonf[ooo]Zool0QP07oookJP03oh00oooonf[ooo]Z00;ooo]Z00?o/_l0oookJ_oonfX03Ooo
nfX00olSo`3ooo]ZoolX0002oookJPGoobP02OoonfX00ol0nooooo]ZoookJP05oookJP04ool0Z_oo
nf[oooh0oookJP;oK_l01?oonfX2oo80oe3ooo]Z0_mao`03oookJP;o00Ko1OoonfX2o`3oF1Cooo]Z
00?o0?oEoookJ_oonfX04?oonfX2o`0Co`?ooo]Z00?o0:Coo`3oY_oonfX05OoonfX2oong01Kooo]Z
0_l0obh9oookJP;oooh01_oonfX2ohKo00?ooo]Z0_oo=`0ZoookJPoo0:Oo4OoonfX4o`0000Sooo]Z
00?ooi00oookJ_oonfX01?oonfX00ombo`3ooo]ZoookJP09oookJP03ool0^ooonf[ooo]Z02[ooo]Z
0_l00Ol7oookJP04obl0oooonf[ooo]Zooo000;ooo]Z00Co0?nVoookJ_oonf[oC`3o2_oonfX01?oo
08coogl0oookJ_oonfX2o`80o`_ooo]Z00Co3@3ooago0?mSo`3oHol00_oonfX00omYo`3oVP3ooolQ
0002ool0c`?ooo]Z00Go0?nhoookJ_oonf[ooo]Zo`3oc@03oookJP03ool0Q_oonf[ooo]Z00Gooo]Z
00?oP03ooookJ_oonfX00_oonfX00onbo`3ooo]ZoookJP0=oookJP04ob?o0?oonf[ooo]ZoomM00?o
oo]Z0_l0;?l:oookJP03o`3koooonf[ooo]Z00Kooo]Z00Coo`2Zooon0?oo<03ooo]Z0_m^o`03oook
JP;olP3o9ooonfX002_ooo]Z0_mao`03oookJP;o00Ko1?oonfX2o`3oF1Gooo]Z0_l0omDBoookJP04
o`0Coooonf[ooo]Zo`2To`;o0?nV5OoonfX2oong00Sooo]Z1Ooo000:oookJP;o0?l^2?oonfX2ooon
00?ooo]Z0ooo0005oolX00;oocL000?oo`00oookJ_oonfX02OoonfX:ool000oooo]Z3OooN@09oook
JPWoobP02OoonfX4o`0000Oooo]Z00?ooi00oookJ_oonfX01?oonfX00ombo`3ooo]ZoookJP06oook
JPKoo`00:_oonfX00ol00Ooooo]ZoookJP05oookJP?oogT02_oo:007oookJP03ool0S?oo003oo`00
00;ooo]Z1_oo0007oookJP03oago0?oo:03oobP000KoobP000Coo`00oolX0?oo:03oobP01?oo0002
o`3oc@;ooo]Z0_oo08H6oookJP;oP03o0ooonfX2ok;o00kooo]Z0_lSo`02oolX00?ooo]Z00Co02co
oolX0?oo:03oobP02?oonfX2o`3ko`Kooo]Z0_oo0:X2ooon0003oookJ_m^o`3ooo]Z00Cooo]Z00?o
lP3ooookJ_oonfX00_oo03]<oookJP;oLOl00ooonfX2o`06o`Gooo]Z0_l0oePDoookJP;o0?oE4_oo
nfX01Ol04ooooo]ZoookJ_oonf[o0:Co00;o0?nV5OoonfX2oong01Kooo]Z0_l0obh8oookJP?oooh0
1_oonfX2ohKo00;ooo]Z0ooo=`0XoookJPCo0:Oo3ooonfX3o`2Wo`kooo]Z1?l00007oookJP03oon@
0?oonf[ooo]Z00Cooo]Z00?oL_l0oookJ_oonfX02OoonfX00ooo0;_ooo]ZoookJP0ZoookJP03o`01
oooonf[ooo]Z00Sooo]Z0_oo`002oookJP04o`3oY_oonf[ooo]Zodl0o`[ooo]Z0_ooO`02oookJP03
o`80oooonf[ooo]Z00[ooo]Z00?o3@3ooago0?mSo`000_oonfX2ofWo0003oolQ0?oo0<ooo`3?00?o
oo]Z0_l0okP2oookJP;o0?o=0_oonfX2ool0QPKooo]Z0_n00?l3oookJP;o/_l03_oonfX2ob?o0003
oookJ_ooG@3ooed000?ooo]Z00?o02cooookJ_oonfX02OoonfX00ol0nooooo]ZoookJP05oookJP04
ool0Z_oooP3oooh0ool`00;oK_l01?oonfX01?ob0?oooo]ZoookJ_oonfX2ool0>bCooo]Z000Zoook
JP03oomi0?oonf[ooo]Z00;ooo]Z00?o00KooookJ_oonfX00_oonfX2o`3oF1Gooo]Z0_l0omDBoook
JP;o01?o00Cooo]Zo`2Tool0Y?oo0?nV5OoonfX2oong00Wooo]Z2?oo0005oookJP?o0?l^0_oo:005
oookJP?oooh01?oonfX3ool000KoobP01?oo0009oookJP_oo`003OoonfX@oomi00[ooo]Z3ooo:000
0ooonf[o0000o`000002o`0000Kooo]Z00?ooi00oookJ_oonfX01?oonfX00ombo`3ooo]ZoookJP05
oookJPOoo`00:_oonfX00ol00Ooooo]ZoookJP05oookJP?oogT02_oo:006oookJPGoo`0000?ooo]Z
ool00?oo00001?oo0006oookJP03o`d0oooo:03oobP000OoobP000Coo`00oolX0?oo:03oobP01?oo
00001Ol0olgooo]ZoookJ_oonf[oo`2600Oooo]Z00CoP03ooookJ_oonf[ooo]Z0_nbo`0?oookJP03
ob?o0?oonf[oobP000?ooo]Z0_l0;?l2oookJP03oolX0?oonf[ooo]Z00Kooo]Z00?o0?_ooookJ_oo
nfX01OoonfX01?oo0:[ooo]Zooon0?oo<002ofko00Cooo]Z0_ob0?l2oookJP03ool0>ooonf[ooo]Z
04_ooo]Z00?oLOl0oookJ_oonfX00_oonfX00ol01_oooo]ZoookJP03oookJP;o0?mH5?oonfX2o`3o
eA;ooo]Z0_l04ol2oookJP03o`2Tool0ojKo0?nV01Gooo]Z0_oo]`0?oookJP;o05;o1OoonfX2o`3o
;PSooo]Z0_oooP06oookJP?oQ_l00_oonfX2oolg013ooo]Z0_m9o`0EoookJPCo0:Oo5_oonfX00ol0
Yooooo]ZoookJP0;oookJPCo00001_oonfX00oooT03ooo]ZoookJP04oookJP03og;o0?oonf[ooo]Z
03Kooo]Z00?o007ooookJ_oonfX02?oonfX00ooo`03ooo]ZoookJP02o`3oYP03oookJ_m?0?ooC`3o
00Wooo]Z00?oo`2<oomo0?oonfX00_oonfX00ol20?oooo]ZoookJP0:oookJP;o7Ol000OoHol0oook
J_oonf[oJOl0oiX0oooo8@3oo`3?00Cooo]Z00Go0?nhoookJ_oonf[ooo]Zo`3oc@03oookJP03ool0
Q_oonf[ooo]Z00Gooo]Z00CoP03ooookJ_oonf[ooo]Z0_nbo`0?oookJP04ob?o0?oonf[ooo]ZoomM
00?ooo]Z0_l0;?l:oookJP;o0?_o1ooonfX01Ooo0:[oooh0ool`0?oo<03oK_l000Cooo]Z0_ob0?l3
oookJP03ool0>ooonf[ooo]Z02Cooo]Z000]oookJP;o00Ko0ooonfX2o`3oF1Gooo]Z0_l0omDBoook
JP;o01?o00?ooo]Zo`2Tool0Y?l00_l0ojHDoookJP;ookL02_oonfX8ool000Cooo]Z0_l0obh2oook
JP?oobP00ooonfX2ooon00Kooo]Z0ooo0008oolX00[ooo]Z3_oo000:oookJP03o`2WooooN@3oogT0
00ooogT02ooonfX>oolX0003oookJ_l0003o000000;o00001OoonfX00oooT03ooo]ZoookJP03oook
JP;oogT01_oonfX9ool002Sooo]Z0_ooN@08oookJP?oogT02_oo:003oookJPOoo`0000Cooo]Zool0
0?oonf[ooo]Z0ooo0005oookJP_oobP000?oo`00oolX0?oo:0000_oo:003ool00003o`3ocOoonf[o
oo]Z00;oo`261_oonfX2oh00o`?ooo]Z00?o/_l0oookJ_oonfX03OoonfX2ob?o0003oookJ_oo:03o
oo]Z00;ooo]Z00?o02cooookJ_oonfX02OoonfX2o`3ko`Kooo]Z0_oo0:X2ooon00;oK_l01OoonfX0
0oob0?oooo]ZoookJP02ool0>e7ooo]Z0_l01_l4oookJP;o0?mH5?oonfX2o`3oeA;ooo]Z0_l04ol2
oookJP03o`2Tool0ojKo0?nV01Gooo]Z0_oo]`0?oookJP;o05;o1OoonfX2o`3o;PSooo]Z0_oooP06
oookJP;oQ_l00ooonfX2oolg013ooo]Z0_m9o`0DoookJP?o0:Oo6ooonfX00ol0Yooooo]ZoookJP0:
oookJPCo00001OoonfX00oooT03ooo]ZoookJP04oookJP03og;o0?oonf[ooo]Z03Gooo]Z0_l00Ol9
oookJP;ool000_oonfX01?l0ojKooo]ZoookJ_m?0?l:oookJP03ool0S?ooO`3ooo]Z00;ooo]Z00?o
0P3ooookJ_oonfX02OoonfX01Ol=0?oo7Ol0of?o0?mSo`3ooo]Z00;oJOl00_oo8@001?oo0<oooo]Z
oookJ_oonfX2o`3o^0?ooo]Z00?o0?o=oookJ_oonfX00_oo08H6oookJP;oP03o0ooonfX00onbo`3o
oo]ZoookJP0=oookJP;o8ol000?ooo]ZoomM0?ooG@000ooonfX00ol0;?oooo]ZoookJP09oookJP03
o`3koooonf[ooo]Z00Gooo]Z00Coo`2Zooon0?oooP3ooc000_m^o`04oookJP04oo80oooonf[ooo]Z
oookJP;oo`0k9ooonfX002_ooo]Z0_l01_l4oookJP03o`3oF?oonf[ooo]Z01?ooo]Z0_l0omDBoook
JP;o01?o00?ooo]Zo`2Tool0Y?l00_l0ojHDoookJP;ookL02ooonfX:ool00003oookJ_l0obko0?l^
00?ooo]Z1Ooo:002ooon00Oooo]Z0_oo000:oolX00Wooo]Z2ooo000;oookJP?o0:Oo7ooonfX;oolX
0003ool00?oonf[o000000?o00001OoonfX00oooT03ooo]ZoookJP02oookJP?oogT01OoonfX9ool0
02Kooo]Z1OooN@08oookJP04ooo00?ooN@3oogT0oomi00SoobP000?ooo]Zool00?oo00001ooo0006
oookJP03ool00?oonf[ooo]Z00?ooo]Z2ooo:0000ooo003oobP0oolX0002oolX00;oo`000_l0old2
oookJP03ool0Q_oonf[ooo]Z00Gooo]Z00CoP03ooookJ_oonf[ooo]Z0_nbo`0?oookJP04ob?o0?oo
nf[oobP0oolX00;ooo]Z0_l0;?l;oookJP03o`3koooonf[ooo]Z00Gooo]Z00Goo`2ZoookJ_oooP3o
oc00ofko0005oookJP;olP3o0_oonfX00ooo03_ooo]ZoookJP1?oookJP;o00Ko1?oonfX2o`3oF1Co
oo]Z0_l0omDBoookJP;o01?o0_oonfX00ol0Y?oo0?nVo`3oYP0EoookJP;ookL03ooonfX2o`1Bo`Go
oo]Z0_l0obh7oookJP?oooh01_oonfX2ohKo00?ooo]Z0_oo=`0@oookJP;oBOl04ooonfX3o`2Wob_o
oo]Z1?l00005oookJP03oon@0?oonf[ooo]Z00Cooo]Z00?oL_l0oookJ_oonfX0=?oonfX00ol00Ooo
oo]ZoookJP08oookJP05ooo00?oonf[ooo]ZoookJ_l0ojH00_oonfX00om?0?oooo]ZoookJP07oook
JP03ool0S?ooO`3oogl000oooo]Z00?o3@3ooago0?mSo`000_oonfX01?mYo`3oVP3ooolQ0?oo0<l4
oookJP04o`3o^?oonf[ooo]ZoookJP;o0?o=0_oonfX00ooo08Kooo]ZoookJP05oookJP04oh00oooo
nf[ooo]ZoookJP;o/_l03ooonfX01?lSo`3ooo]ZoookJ_ooG@03oookJP;o02co2_oonfX2o`3ko`Oo
oo]Z00?oo`2Zooon0?oo<0000_m^o`04oookJP;olP3o0ooonfX00ooo03_ooo]ZoookJP0WoookJP00
:_oonfX00ol01_oooo]ZoookJP02oookJP;o0?mH5?oonfX2o`3oeA;ooo]Z0_l04ol00ooonf[o0:Co
o`2To`02o`3oYQCooo]Z0_oo]`0<oookJP_oo`0000?oogT0oookJ_oonfX00_oonfX6oolX00Oooo]Z
00?oQ_l0ool00?oo00003?oo:007oookJPOoo`003_oonfX2o`2WobCooo]Z2Ooo:003ool000?o0000
1?oonfX00oooT03ooo]ZoookJP02oookJP?oogT01OoonfX9ool002Gooo]Z1_ooN@07oookJP;ool00
0_oonfX2oomi0003odl0oooo:03oobP000CoobP02_oo000<oookJP03o`d0oooo:03oobP000goobP0
0_oo00000ol0olgoo`00oookJP02ool0QPKooo]Z0_n00?l3oookJP03ok;o0?oonf[ooo]Z00gooo]Z
0_lSo`000ooonf[oobP0oookJP02oookJP03o`0/oooonf[ooo]Z00Wooo]Z0_l0nol6oookJP;oo`2Z
0_oooP02ofko00Cooo]Z0_ob0?l2oookJP;oo`0kDOoonfX00ol01_oooo]ZoookJP02oookJP;o0?mH
5?oonfX2o`3oeA;ooo]Z0_l04ol2oookJP;o0:Co00?o0?nVoookJ_oonfX04ooonfX2oong00kooo]Z
0ol0D_l5oookJP;o0?l^1ooonfX2ooon00Oooo]Z0_n6o`03oookJP;oocL04?oonfX2odWo01;ooo]Z
0ol0Yol^oookJPCo00001?oonfX00oooT03ooo]ZoookJP04oookJP03og;o0?oonf[ooo]Z03Cooo]Z
00?o007ooookJ_oonfX01ooonfX2ooo000;ooo]Z0_l0ojH00ooonf[oC`3oodl0o`09oookJP03ool0
S?ooO`3ooo]Z00oooo]Z00?o3@3ooago0?mSo`000_oonfX01?mYo`3oVP3ooolQ0?oo0<l4oookJP05
o`3o^?oonf[ooo]ZoookJ_l0old00_oonfX2ool0QPKooo]Z0_n00?l3oookJP03ok;o0?oonf[ooo]Z
00gooo]Z0_lSo`02oookJP05oomM0?oonf[ooo]ZoookJ_l0;?l02ooonfX00ol0nooooo]ZoookJP05
oookJP05ool0Z_oooP3oooh0ool`0?m^o`001?oonfX2oo80o`?ooo]Z0_oo03/ZoookJP00;OoonfX2
o`3oF1Cooo]Z0_l0omDBoookJP;o01?o0_oonfX00ol0Y?oo0?nVo`3oYP0DoookJP;ookL03OoonfX=
ool000?ooo]Z2?oo:004oookJP;oQ_l00_oonfX<oolX00Kooo]Z00?oBOl0ool00?oo00000ooo000>
oookJP?o0:Oo9ooonfX7oolX00Coo`000ol00004oookJP03oon@0?oonf[ooo]Z00GoogT01_oonfX8
ool002?ooo]Z1oooN@07oookJP08ooo00?oonf[ooo]ZoookJ_l0ojKooo]Zodl0ooooN@05oolX00[o
o`002ooonfX00ol=0?ooobP0oolX000>oolX0006ool00?l0olgo0?o=ool00?oonf[oo`261ooonfX0
1?n00?oooo]ZoookJ_oonfX2ok;o00oooo]Z00Co8ol0oookJ_ooG@3oobP00_oonfX2o`0/o`_ooo]Z
00?o0?_ooookJ_oonfX01OoonfX01Ooo0:[ooo]Zooon0?oo<03oK_l000Gooo]Z00GolP3ooookJ_oo
nf[ooo]Zool0>`1FoookJP;o0?mH5?oonfX2o`3oeA;ooo]Z0_l04ol2oookJP;o0:Co0_l0ojHDoook
JP;ookL03_oonfX2o`1Bo`Kooo]Z0_l0obh7oookJP;oooh01ooonfX2ohKo00Cooo]Z00?oocL0oook
J_oonfX03_oonfX2odWo017ooo]Z0ol0YolaoookJPCo00001?oonfX00oooT03ooo]ZoookJP03oook
JP03og;o0?oonf[ooo]Z03Cooo]Z00?o007ooookJ_oonfX01ooonfX01Ooo`03ooo]ZoookJ_oonf[o
0?nV00;ooo]Z00?oC`3ooookJ_oonfX01ooonfX2ool0S003oomo0?oonf[ooo]Z00gooo]Z00?o3@3o
oago0?lMo`000_oonfX2ofWo0003oolQ0?oo0<oooo]Z00?ooo]Z0_l0okP2oookJP;o0?o=0_oonfX0
0ooo08Kooo]ZoookJP05oookJP04oh00oooonf[ooo]ZoookJP;o/_l03ooonfX00olSo`3ooo]Zoook
JP02oomM00;ooo]Z0_l0;?l:oookJP;o0?_o1ooonfX00ooo0:[oooh0ool`0002ofko00Cooo]Z00?o
lP3ooookJ_oonfX00_oonfX00ooo03_ooo]ZoookJP0ZoookJP00:ooonfX2o`3oF1Cooo]Z0_l0omDB
oookJP;o01?o0_oonfX00ol0Y?oo0?nVo`3oYP0DoookJP;ookL03_oonfX;ool000?oogT000?ooo]Z
oolX0?oo:0002?oo:002oookJP;oQ_l00ooonfX7oolX00?ooo]Z1?oo:003oookJP;oBOl01_oo000;
oookJP?o0:Oo:ooonfX00ooo003oobP0oolX0003oolX00?oo`001?l00003oookJP03ooo90?oonf[o
oo]Z00GoogT02?oonfX6ool0027ooo]Z2OooN@06oookJP;ool000_oonfX2o`3oYP03oookJ_m?0?oo
oo]Z00;oogT00ooo:00:ool000[ooo]Z3_oo:0001_oonf[oobP0oolX0?oo:03ooo]Zo`3oc@;oo`00
0_oo08H6oookJP;oP03o0ooonfX00onbo`3ooo]ZoookJP0=oookJP;o8ol00_ooG@02oookJP;o02co
2ooonfX2o`3ko`Kooo]Z0_oo0:X2ooon00;oK_l01?oonfX2oo80o`;ooo]Z0_oo03]EoookJP;o0?mH
5?oonfX2o`3oeA;ooo]Z0_l04ol2oookJP;o0:Co0_l0ojHDoookJP;ookL03_oonfX2o`1Bo`Kooo]Z
0_l0obh7oookJP;oooh01ooonfX2ohKo00Cooo]Z0_oo=`0>oookJP?oBOl04?oonfX3o`2WocCooo]Z
1?l00003oookJP03oon@0?oonf[ooo]Z00?ooo]Z00?oL_l0oookJ_oonfX0=?oonfX00ol00Ooooo]Z
oookJP07oookJP03ooo00?oonf[ooo]Z00;o0?nV0_oonfX00om?0?oooo]ZoookJP07oookJP03ool0
S?ooO`3oogl000oooo]Z00?o3@3ooago0?mSo`000_oonfX01?mYo`3oVP3ooolQ0?oo0<l4oookJP05
o`3o^?oonf[ooo]ZoookJ_l0old00_oonfX2ool0QPKooo]Z0_n00?l3oookJP03ok;o0?oonf[ooo]Z
00gooo]Z0_lSo`000ooonf[ooed0oomM0002oookJP;o02co2ooonfX00ol0nooooo]ZoookJP05oook
JP03ool0Z_oooP3oooh000;oK_l01?oonfX2oo80o`?ooo]Z0_oo03/]oookJP00:_oonfX00ol0oeSo
001oo`00O`05oookJPGo001o2?oonfX2o`3oeA;ooo]Z0_l04ol2oookJP03o`2Tool0ojKo0?nV01Go
oo]Z00?ookL0oookJ_l007l00_l007l5oookJPGo001o00?ooo]Zool00?oo00001Ooo0008oomi00_o
obP00_n6o`04oookJPGoobP01OoonfX5oolX00?oBOl000?ooo]Zool00?oo00001_oo0005o`00O`;o
oo]Z0ol0Yol`oookJP04ool00?oo:03oobP0oolX00?oo`001?l00003oookJP03ooo90?oonf[oogT0
00GoogT02OoonfX5ool001oooo]Z2_ooN@04o`00O`;ooo]Z00Gool00oookJ_oonf[ooo]Zo`3oYP02
oookJP07odl0oooonf[ooo]ZoookJ_ooN@3ooo]ZoolX0002oookJPWoo`001ooonfX7oolX0003oook
J_oo:03oo`0000KoobP000Cooo]Zool00?oonf[oobP00_l0old00ooonf[oo`00ool0QP04oookJP?o
001o00CoP03ooookJ_oonf[ooo]Z0_nbo`04o`00O`_ooo]Z00?o8ol0oookJ_ooG@000ooonfX00ol0
;?oooo]ZoookJP0:oookJP03o`3koooonf[ooo]Z00Gooo]Z00?oo`2ZoookJ_oooP000_m^o`05oook
JP05oo80oooonf[ooo]ZoookJ_oo03/01?oonfX3o`00O`Gooo]Z1Ol007m5oookJP04o`3oF?l007oo
001oo`00O`Gooo]Z1Ol007l7oookJP;o0?oE4ooonfX00ol04ooooo]ZoookJP02o`2To`;o0?nV5Ooo
nfX01?oo]`3o001oo`00Ool007l5oookJPGo001o00?ooo]Zo`1Bool0D_l01_oonfX2o`3o;POooo]Z
0_oooP07oookJP;oQ_l01?oonfX2oolg00kooo]Z0_m9o`09oookJPGo001o0_oonfX3o`2WocOooo]Z
1?l00003oookJP03oon@0?oonf[ooo]Z00;ooo]Z00?oL_l0oookJ_oonfX0=?oonfX00ol00Ooooo]Z
oookJP05o`00O`03oookJ_oo`03ool0000;ooo]Z00?o0?nVoookJ_oonfX00_m?0?l9oookJP03ool0
S?ooO`3ooo]Z00kooo]Z00?o3@3ooago0?lMo`000ooonfX00omYo`3oob40oolQ0005oookJP03o`3o
^?oonf[ooo]Z00;o0?o=0_oonfX00ooo08Kooo]ZoookJP02oookJP?o001o00CoP03ooookJ_oonf[o
oo]Z0_nbo`04o`00O`_ooo]Z00Co8ol0oookJ_oonf[ooed00ooonfX00ol0;?oooo]ZoookJP09oook
JP;o0?_o1ooonfX01?oo0:[oooh0ool`0?m^o`05oookJP04oo80oooonf[ooo]ZoookJP;oo`0k1?oo
nfX3o`00O`Gooo]Z1Ol007lNoookJP00:_oonfX3o`00O`Cooo]Z1ol007l5oookJP;o0?oE4ooonfX0
0ol04ooooo]ZoookJP02o`2To`03o`3oY_oonf[ooo]Z01?ooo]Z0_oo]`02oookJP?o001o1?oonfX5
o`00O`04o`1Boooo003oo`00ool000;ooo]Z2_ooN@0=oolX00?ooo]Z00?oocL0oolX0?oo:0002?oo
nfX7oolX0003oookJ_oo003oo`0000Soo`001Ol007l2o`2WocCooo]Z00?oo`00oolX0?oo00000_oo
00000ooonf[o0000o`000002o`0000;ooo]Z0_oob@06oomi00_ooo]Z0ooo000OoookJP[oogT01_l0
07l01_oo`03ooo]ZoookJ_oonf[o0?nVoookJP;oC`3o2OoonfX8ool000Gooo]Z2Ooo:0000omYo`3o
obP0ool00006oolX00Cooo]Z00?o0?o=oookJ_oonfX00_oo:005oookJP03o`00Oon00?ooP03o00?o
oo]Z00?o/_l0o`00Ool007l01Ol007l8oookJP;o8ol00_ooG@02oookJP;o02co2ooonfX2o`3ko`Ko
oo]Z0_oo0:X2ooon0003ofko0?oonf[ooo]Z00?ooo]Z0_ob0?l2oookJP;oo`0k1OoonfX3o`00O`Co
oo]Z1ol007m5oookJP?o001o1?oonfX7o`00O`Gooo]Z00?o0?oEoookJ_oonfX04OoonfX2o`0Co`;o
oo]Z00?o0:CooookJ_l0ojH05OoonfX2oong0004oookJ_l007oo001oo`00O`Cooo]Z1Ol007l2o`1B
o`Oooo]Z00?o0?l^oookJ_oonfX01_oonfX00ooooP3ooo]ZoookJP05oookJP;oQ_l01?oonfX2oolg
00gooo]Z0om9o`05oookJP;ooj800ooonfX6o`00O`;o0:Oo>_oonfX4o`0000;ooo]Z00?ooi00oook
J_oonfX00ooonfX00ombo`3ooo]ZoookJP0coookJP03o`01oooonf[ooo]Z00Ko001o00Gool00oook
J_oonf[ooo]Zo`3oYP02oookJP03odl0oooonf[ooo]Z00Oooo]Z0_oo08`00oooO`3ooo]ZoookJP0=
oookJP03o`d0oolMo`3oHol000;ooo]Z0_mYo`000ooo8@3oo`3?oookJP07oookJP03o`3ocOoonf[o
oo]Z00;oo`261OoonfX00ol007ooP03ooh00o`03oookJP03ok;o0?l007oo001o00Go001o2?oonfX2
ob?o0003oookJ_ooG@3ooed000;ooo]Z0_l0;?l;oookJP03o`3koooonf[ooo]Z00Gooo]Z00?oo`2Z
ooon0?oooP000_m^o`04oookJP;olP3o0ooonfX00ooo03_ooo]ZoookJP04oookJP?o001o1?oonfX7
o`00Oagooo]Z000ZoookJP?o001o0ooonfX4o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0_l0omDC
oookJP;o01?o00?ooo]Zo`2Tool0Y?l00_l0ojHDoookJP;ookL01?oonfX3o`00O`Cooo]Z0ol007l2
o`1Bo`;o001o0ooonfX:oomi00_oobP01?oonfX2oolg00[ooo]Z2Ooo:00;ool00005o`00Oooonf[o
0:Ooo`2Wool007l0=_oonfX4ool00003oookJ_l0003o000000;o000000?ooo]Zooo90?ooN@001ooo
N@0<oookJP03ool00?oonf[ooo]Z01kooo]Z2_ooN@02o`00O`04oookJ_l007oool00ooo000;ooo]Z
0_l0ojH00ooonf[oC`3ooookJP09oookJP03ool0S?oo003oo`0000Goo`000ooonfX;oolX0004ofWo
0?oonf[oobP0ool0c`GoobP01?oonfX00ol0olgoobP0oolX0003oolX00Gooo]Z00CoP03oo`00Ool0
07oooo]Z0_nbo`001Ooonf[o001oo`00Ool007oooo]Z00?o001o1ooonfX00olSo`3ooed0oomM0003
oookJP03o`0/oooonf[ooo]Z00[ooo]Z00?o0?_ooookJ_oonfX01?oonfX2ool0ZP04oookJ_oooP3o
K_l0ofko00Gooo]Z00?olP3ooookJ_oonfX00_oo03/7oookJP?o001o0_oonfX2o`1?o`?o001o00Co
oo]Zo`00Ool007oo001oAOoonfX3o`00O`?ooo]Z1?l007l01?oonf[o001oo`00Ool007l3oookJP;o
0?oE4_oonfX2o`0Co`;ooo]Z0_l0Y?l2o`3oYQCooo]Z0_oo]`03oookJP?o001o1?oonfX3o`00O`;o
05;o0_l007l5oookJP;o0?l^1ooonfX2ooon00Kooo]Z0_n6o`04oookJP;oocL03OoonfX2odWo00Ko
oo]Z0_ooXP04oookJPCo001o00Cooo]Zo`2Wool0Yooo001o>ooonfX4o`000003oookJ_ooT03ooo]Z
00Cooo]Z00?oL_l0oookJ_oonfX0<_oonfX2o`01o`;ooo]Z1?l007l01Ooonf[o001oooo00?l007oo
oo]Z00;o0?nV00?ooo]Zodl0oom?0?l02OoonfX00ooo08cooo]Zoomo000>oookJP03o`d0oolMo`3o
7Ol000?ooo]Z00?oJOl0oookJ_oo8@002OoonfX01?l0olgooo]ZoookJ_oo08H7oookJP04oh00ool0
07oo001ooookJP;o/_l000Gooo]Zo`00Ool007oo001ooookJP03o`00O`Oooo]Z00Co8ol0oookJ_oo
G@3ooed00ooonfX00ol0;?oooo]ZoookJP0:oookJP03o`3koooonf[ooo]Z00Cooo]Z0_oo0:X00ooo
oP3oK_l0ofko0005oookJP04oo80oooonf[ooo]ZoookJP;oo`0k1ooonfX3o`00O`;ooo]Z0_l0Col3
o`00O`04oookJ_l007oo001oo`00Oagooo]Z000JoookJP[o001o1_oonfX3o`00O`?ooo]Z0ol007l3
oookJP?o001o0_l0omDCoookJP;o01?o0_oonfX00ol0Y?oo0?nVo`3oYP0<oookJPSo001o0_oo]`06
oookJP?o001o0ooonfX2o`00O`;o05;o0_oonfX3o`00O`03oookJ_ooN@3oogT000GoogT00ooonfX:
oolX00Cooo]Z0_oo=`0;oookJP[oobP02?oo0003o`00O`;o0:Oo00Cooo]Zo`00Ool007oo001o=_oo
nfX3ool00003oookJ_l0003o000000;o000000?oolT0oomi0?ooN@001_ooN@0_oookJPSoogT00_l0
07l2oookJP05ooo00?l007oo001oo`00Ool0ojH00_oonfX00om?0?oooo]ZoookJP07oookJP;oobP0
0ooonfX4ool000?ooo]Z2_oo:002ofWo0003oolQ0?oo:03oo`3?00;ooo]Z0ooo:003oookJP;o0?o=
1Ooo:004oookJP;oP03o0ol007l00onbo`3ooo]ZoookJP03o`00O`?ooo]Z0ol007l4oookJP;oobP0
00Cooed0oookJ_oonf[ooo]Z0_l0;?l;oookJP;o0?_o1_oonfX01Ooo0:[ooo]Zooon0?oooP3oK_l0
00Gooo]Z0_ob0?l2oookJP03ool0>ooonf[ooo]Z00Oooo]Z0ol007l00ooonf[o04oooookJP03o`00
O`?ooo]Z0ol007ldoookJP[o001o1_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o0_l0omDBoook
JP;o01?o0_oonfX2o`2To`;o0?nV2ooonfX9o`00O`;ookL01OoonfX3o`00O`?ooo]Z0ol007l00ol0
D_oooo]ZoookJP03o`00O`;ooo]Z0_l0obh7oookJP;oooh01_oonfX2ohKo00Cooo]Z0_oo=`0=oook
JP;oBOl00_oonfX4o`00O`;ooj801?l007l2oookJP?o001o0_l0Yol01?oonf[o001oo`00Ool007lj
oookJPCo000000?ooo]Zoon@0?oonfX00ooonfX00ombo`3ooo]ZoookJP0boookJP03o`01oooonf[o
oo]Z00;ooo]Z0ol007l2oookJP04ooo00?l007oo001oo`3oYP;ooo]Z00?oC`3ooookJ_oonfX01ooo
nfX2ool0S0oooo]Z00Co3@3ooago0?lMo`3oHol00_oonfX2ofWo00;oob402?oonfX2o`3oc@03oook
J_oo08Koo`2600Kooo]Z0_n00?l3o`00O`03ok;o0?oonf[ooo]Z00?o001o0ooonfX3o`00O`Cooo]Z
0_lSo`000ooonf[ooed0oookJP02oookJP;o02co2ooonfX2o`3ko`Kooo]Z00Coo`2Zooon0?oooP3o
K_l01OoonfX2oo80o`;ooo]Z0_oo03/9oookJP?o001o00?ooo]Zo`1?oooonfX00ol007l3oookJP?o
001o7?oonfX001[ooo]Z2_l007l6oookJP?o001o2OoonfX00ol007oo0?oEo`3oe@0CoookJP;o01?o
0_oonfX00ol0Y?oo0?nVo`3oYP0>oookJPKo001o0_oo]`02o`00O`Kooo]Z0ol007l3oookJP;o05;o
00Co001ooookJ_oonf[ooo]Z0ol007l5oomi00Cooo]Z00?oooh0oolX0?oo:0002Ooo:0001?oonf[o
ocL0oolg0?oo=`0<oookJPcoobP00ooo0002o`00O`?ooo]Z0_l0Yol3oookJP?o001o=ooonfX00ooo
003ooo]ZoookJP03o`000003ooo90?ooN@3oogT000OoogT0;ooonfX00ol00OooogT0oomi0004oomi
00?ooo]Z0_oo`0001?oonf[o001oo`3oY_l0ojH2oookJP03odl0oooonf[ooo]Z00Gooo]Z1Ooo:003
oookJP?oo`001?oonfX9oolX0004ofWo0?oonf[oob40ool0c`Gooo]Z00GoobP0oookJ_oo:03oobP0
o`3oc@06oolX00Cooo]Z00CoP03ooookJ_oonf[o001o0_nbo`03oookJP?o001o0ooonfX3o`00O`04
oookJ_oo:03oobP0oolX00;ooed00ooonfX00ol0;?oooo]ZoookJP0:oookJP03o`3koooonf[ooo]Z
00Cooo]Z0_oo0:X01?oonf[oooh0ofko0?m^o`04oookJP;olP3o0_oonfX2ool0>`[ooo]Z0_l007l2
o`1?o`Sooo]Z0ol007ldoookJP[o001o1_oonfX3o`00O`Wooo]Z00?o001oo`3oeOl0omD04ooonfX0
0ol04ooooo]ZoookJP02o`2To`;o0?nV3OoonfX7o`00O`;ookL000?o001ooookJ_oonfX01?oonfX3
o`00O`?ooo]Z00?o001oo`1Bool0D_l00ooonfX3o`00O`;o0?l^1ooonfX2ooon00Kooo]Z0_n6o`04
oookJP;oocL03_oonfX00om9o`3ooo]ZoookJP02oookJP;o001o0_ooXP06o`00O`?ooo]Z0_l0Yol3
oookJP?o001o>_oonfX4o`000003oon@0?oonf[ooo]Z00;ooo]Z00?oL_l0oookJ_oonfX0<OoonfX2
o`01o`Sooo]Z0_oo`0001_oonf[o0?nVo`3oY_l007oooo]Zodl0o`Wooo]Z00?oo`2<oookJ_oonfX0
3_oonfX00ol=0?oo7Ol0of?o0003oookJP04ofWo0?oonf[oob40ool0c`Sooo]Z00Co0?o=oookJ_oo
nf[oo`261ooonfX01?n00?oooo]ZoookJ_l007l2ok;o00?ooo]Z0ol007l3oookJP?o001o0ooonfX0
1?lSo`3ooo]ZoomM0?ooG@03oookJP03o`0/oooonf[ooo]Z00[ooo]Z00?o0?_ooookJ_oonfX01?oo
nfX2ool0ZP03ooon0?m^o`3oK_l000Cooo]Z0_ob0?l3oookJP03ool0>ooonf[ooo]Z00Wooo]Z0_l0
07l2o`1?o`Sooo]Z0ol007lLoookJP00:_oonfX3o`00O`Sooo]Z0_l0omD2o`00Oa7ooo]Z0_l04ol2
oookJP;o0:Co00?o0?nVoookJ_oonfX04_oonfX2oong00[ooo]Z0ol007l00ooonf[o05;oo`1Bo`03
o`00O`?ooo]Z00Co001oo`3o;_ooN@3oogT01_oonfX2ooon00;ooo]Z2Ooo:002oolg00kooo]Z2_oo
:003ool000Kooo]Z0_l0Yol5oookJP?o001o>_oonfX2o`000003ooo90?ooN@3oogT000OoogT0;_oo
nfX2o`01o`03oookJ_ooN@3oogT000?oogT00ooonfX01Ooo`03ooo]ZoookJ_oonf[o0?nV00;o001o
0_oo0005oookJPOoobP01OoonfX00ooo003ooo]ZoookJP04oookJPKoobP00_mYo`02oolQ0003ool0
cooonf[ooo]Z00?ooo]Z0ooo:002o`3oc@KoobP00ooonfX2oh00o`;ooo]Z0_nbo`02o`00O`?ooo]Z
0ol007l3oookJP03o`00Oooo:03oobP000;oobP00_ooG@03oookJP;o02co2_oonfX3oolX00Kooo]Z
00?oo`2ZoookJ_oooP000_m^o`05oookJP05oo80oooonf[ooo]ZoookJ_oo03/03?oonfX2o`1?o`03
o`00Oooonf[ooo]Z00;oo`2a1OoonfX3o`00OdCooo]Z0ol007l8oookJP;o0?oE0_l007lAoookJP;o
01?o00Gooo]Zo`2Tool0Y?oooo]Zo`3oYP0DoookJP;ookL02OoonfX3o`00O`;ooo]Z0_l0D_l2o`00
O`?ooo]Z00?o001oo`3o;_l0obh01ooonfX2ooon00Kooo]Z0_n6o`04oookJP;oocL03_oonfX2odWo
00Gooo]Z0_ooXP09oookJP;o0:Oo1OoonfX3o`00Oc[ooo]Z1?l000000oooT03ooo]ZoookJP02oook
JP03og;o0?oonf[ooo]Z02oooo]Z0_l00Ol9oookJP04ooo00?oonf[ooo]Zo`3oYP;o001o0_m?0?l8
oookJP;oo`2<3ooonfX01?l=0?oo7Ol0oago0?mSo`02oookJP;oJOl00_oo8@08oookJP;o0?o=00?o
oo]Zool0Q_oo08H01_oonfX2oh00o`;ooo]Z0_nbo`02o`00O`?ooo]Z0ol007l3oookJP?o001o00?o
oo]Zob?o0?lSo`000_ooG@03oookJP;o02co2ooonfX2o`3ko`Gooo]Z0_oo0:X00ooooP3oK_l0ofko
0005oookJP04oo80oooonf[ooo]ZoookJP;oo`0k3?oonfX2o`1?o`03o`00Oooonf[ooo]Z00;oo`2a
1OoonfX3o`00Oacooo]Z000ZoookJP?o001o1?oonfX2o`00O`;o0?oE1?l007l?oookJP;o01?o0_oo
nfX2o`2To`;o0?nV5?oonfX00ooo]`3ooo]ZoookJP0:oookJP?o001o00?o05;ooookJ_oonfX00ol0
07l2oookJP;o0?l^0_l007l6oookJP04ooon0?oonf[ooo]ZoookJPSoobP00_oo=`000ooo:03ooo]Z
oookJP0<oookJPOoobP000?ooj80ool00?oo00002?oonfX2o`2Wo`;ooo]Z0_l007l2oookJPCo001o
>_oonfX00ol0003oolT0ooo90002ooo900OoogT0;OoonfX00ol00Ooooo]ZoookJP02oookJP?oogT0
0ooonfX00ooo`03o001ooookJP02o`3oYPCoo`000ooonfX9oolX00gooo]Z00?o3@3ooolX0?oo:000
0_oo:0001?mYo`3oobP0oolQ0?oo0<l5oookJPCoobP000?o0?o=oolX0?oo:0001Ooo:003oookJP06
oh00oooonf[ooo]ZoookJ_nbo`3ooo]Z0ol007l3oookJP?o001o00?ooo]ZoolX0?oo:0001?oo:000
0oooG@3oobP0oookJP02oookJP03o`0/oooonf[ooo]Z00Kooo]Z1_oo:005oookJP;oo`2Z00?ooo]Z
ooon0?m^o`001OoonfX2oo80o`;ooo]Z0_oo03/<oookJP04o`1?ool007oo001oo`00O`;oo`2a0_oo
nfX2o`00O`;ooo]Z1?l007m4oookJP?o001o1?oonfX2o`00O`;o0?oE1?l007l?oookJP;o01?o00Co
oo]Zo`2Tool0Y?oooo]Z0_l0ojHCoookJP;ookL02ooonfX3o`00O`;o05;o00Cooo]Zo`00Ool007oo
001o0_oonfX2o`3o;P;o001o1_oonfX00ooooP3ooo]ZoookJP04oookJP;oQ_l01?oonfX2oolg00ko
oo]Z0_m9o`05oookJP;ooj802OoonfX2o`2Wo`;ooo]Z0_l007l2oookJPCo001o>_oonfX3o`000003
oon@0?oonf[ooo]Z00;ooo]Z00?oL_l0oookJ_oonfX0;ooonfX00ol00Ooooo]ZoookJP07oookJP;o
ol0000?o001oo`3oY_l0ojH00_l007l00om?0?oo001ooookJP07oookJP03ool0S?oonf[ooo]Z00ko
oo]Z00?o3@3ooago0?mSo`000_oonfX2ofWo0003oookJ_oo8@3oo`3?00Sooo]Z00Co0?o=oookJ_oo
nf[oo`261ooonfX01_n00?oooo]ZoookJ_oonf[o/_l0oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol0
07l00olSo`3ooo]ZoomM0004oookJP03o`0/oooonf[ooo]Z00Wooo]Z0_l0nol6oookJP04ool0Z_oo
nf[oooh0ofko00Gooo]Z0_ob0?l2oookJP;oo`0k3OoonfX01?l0Cooo001oo`00Ool007l2ool0/@;o
oo]Z0_l007l2oookJPCo001o7?oonfX002[ooo]Z0ol007l4oookJP;o0?oE1Ol007l?oookJP03o`0C
oooonf[ooo]Z00;o0:Co0_l0ojHDoookJP;ookL03OoonfX00ol007oo05;oo`1Bo`03oookJP?o001o
00?ooo]Zo`3o;_oonfX00ol007l4oookJP;oooh00ooonfX7oolX00;oocL01?oo:00<oookJPGoobP0
00?ooo]ZoonR0?ooXP002OoonfX2o`2Wo`Cooo]Z1ol007lkoookJPKoolT01OooN@0/oookJP;o007o
1_oonfX00oooN@3ooo]ZoookJP02ooo000;o001o1_oo00000ooonf[oobP0oolX0009oolX00_ooo]Z
00?oobP0o`d0oolMo`001?oo:0001?mYo`3oobP0oolQ0?oo0<l6oookJP_oobP00_oonfX2oh00o`;o
oo]Z0_nbo`02oookJP?o001o0ooonfX00ol007ooobP0oolX0005oolX00;ooed000?oobP0oookJ_oo
nfX00_l0;?l6oookJPSoobP01OoonfX00ooo0:[ooo]Zooon0002ofko00Gooo]Z00?olP3ooookJ_oo
nfX00_oo03/<oookJP;o04oo00Cooo]Zo`00Ool007ooo`2a1?oonfX7o`00OdGooo]Z0ol007l4oook
JP;o0?oE1Ol007l>oookJP;o01?o00Cooo]Zo`2Tool0Y?oooo]Z0_l0ojHDoookJP03oong0?oonf[o
oo]Z00_ooo]Z00?o001oo`1Bool0D_l00ooonfX3o`00O`03oookJ_l0obkooo]Z00?o001o1?oonfX2
ooon00Kooo]Z00?oQ_l0oookJ_oonfX00_oonfX2oolg00oooo]Z00?oBOl0oookJ_oonfX00ooonfX2
oonR00Wooo]Z0_l0Yol4oookJPOo001o>ooonfX3o`000005oon@0?oonf[ooo]ZoookJ_mbo`00<?oo
nfX2o`01o`Wooo]Z00Cool00oookJ_l007oo0?nV0_l007l2odl0o`03o`00Oooonf[ooo]Z00Kooo]Z
00?oo`2<oookJ_oonfX03OoonfX01?l=0?oo7Ol0oago0?mSo`02oookJP04ofWo0?oonf[oob40oolQ
00Sooo]Z0_l0old00ooonf[oo`26ool0QP06oookJP;oP03o0_oonfX2ok;o00;ooo]Z0ol007l3oook
JP?o001o0ooonfX00ol007oo8ol0ob?o0002oomM00?ooo]Z0_l0;?l;oookJP03o`3koooonf[ooo]Z
00Cooo]Z0_oo0:X00ooooP3oK_l0ofko0005oookJP05oo80oooonf[ooo]ZoookJ_oo03/03OoonfX2
o`1?o`04oookJ_l007oo001oool0/@Cooo]Z1ol007lMoookJP00:_oonfX3o`00O`?ooo]Z00?o0?oE
o`00Ool007l01?l007l>oookJP;o01?o0_oonfX00ol0Y?oo0?nVo`3oYP0DoookJP;ookL03_oonfX2
o`1Bo`;o001o0ooonfX2o`00O`;o0?l^0_oonfX3o`00O`;ooo]Z0_oooP04oookJPKoobP00_oo=`03
oolX00cooo]Z00CoobP0odWo0?oo:03oobP00_oonfX3oonR00Wooo]Z0_l0Yol6oookJPKo001o>ooo
nfX7ooo90003og;o0?oonf[oogT000;oogT0:ooonfX00ol00Ooooo]ZoookJP08oookJP03ooo00?oo
nf[oo`0000Ooo`003?oo:009oookJP?oobP00_lMo`03oolX00;oJOl000?oobP0ool0cooonfX01?oo
nfX>oolX00;oP03o0ooonfX00onbo`3ooo]ZoookJP02oookJP?o001o0_oonfX7oolX00;ooed00_oo
:002oookJP03o`0/oooonf[ooo]Z00;ooo]Z2ooo:004oookJP;oo`2Z00?ooo]Zooon0?m^o`001Ooo
nfX2oo80o`;ooo]Z00?oo`0koookJ_oonfX02ooonfX01?l0Cooooo]ZoookJ_oonfX2ool0/@03o`00
Oooonf[ooo]Z00;ook/01_l007m6oookJP?o001o0ooonfX00ol0omGo001oo`00O`04o`00O`kooo]Z
00Go01?ooookJ_oonf[o0:CooookJP02o`3oYQCooo]Z0_oo]`0>oookJP03o`1Bool007oo001o00?o
oo]Z0_l007l2o`3o;P;ooo]Z0ol007l2oookJP;oooh01_oonfX2ohKo00?ooo]Z0_oo=`0?oookJP;o
BOl01?oonfX2oonR00Wooo]Z0_l0Yol6oookJPKo001o??oonfX3o`000004oon@0?oonf[ooo]Zog;o
033ooo]Z00?o007ooookJ_oonfX01ooonfX2ooo00003oookJ_l0ojKo0?nV00;o001o00?oC`3oo`00
Ool007l01ooonfX2ool0S0oooo]Z0_lMo`000omSo`3ooo]ZoookJP02ofWo00;oob4000?oo`3?oook
J_oonfX01OoonfX2o`3oc@;ooo]Z00?oo`26oookJ_oonfX01OoonfX01On00?oooo]ZoookJ_oonf[o
/_l000Cooo]Z0ol007l3oookJP?o001o0ooonfX00olSo`3ooed0oomM0004oookJP03o`0/oooonf[o
oo]Z00Wooo]Z0_l0nol5oookJP;oo`2Z00?ooo]Zooon0?m^o`001OoonfX2oo80o`;ooo]Z0_oo03/=
oookJP04o`1?oooonf[ooo]ZoookJP;oo`2a00?o001ooookJ_oonfX00_oo^`06o`00Oakooo]Z000W
oookJPKo001o0_oonfX01?l0omGooo]Zo`00Ool007l@oookJP;o01?o0_oonfX2o`2To`03o`3oY_oo
nf[ooo]Z01;ooo]Z0_oo]`0>oookJP;o05;o1?l007l3oookJP;o0?l^00Co001ooookJ_oonf[ooo]Z
0ol007l00ooonf[oooh0oookJP04oookJPKoobP000?oocL0oookJ_oonfX03_oonfX2odWo00;ooo]Z
00?oo`00oonR0?ooXP002ooonfX00ol0Yooooo]ZoookJP02oookJP;oo`000_oonfX2o`00OaWooo]Z
00?oo`00oookJ_oonfX08_oonfX7ooo90005oolX0?oonf[ooo]ZoookJ_ooN@00:ooonfX00ol00Ooo
oo]ZoookJP08oookJP[oo`0000?ooo]ZoolX0?oo:0002Ooo:007oookJPCoobP000?o3@3ooago0?oo
:0000ooo:0001?mYo`3ooo]ZoolX0?oo0003oookJQ3oobP000CoP03ooookJ_oonf[ooo]Z0_nbo`02
oookJPKo001o0_oonfX6oolX0005oomM0?oo:03oobP0oolX0?oonfX00_l0;?l3oookJPcoobP00ooo
nfX2ool0ZP04oookJ_oooP3oK_l0ofko00Cooo]Z0_ob0?l2oookJP;oo`0k3?oonfX2o`1?o`04oook
J_l007oo001oool0/@?o001o00Cooo]Zoonk0?oonf[ooo]Z0_l007m7oookJPKo001o00Cooo]Zo`3o
eOl0omGooo]Z0_l007l@oookJP;o01?o00Gooo]Zo`2Tool0Y?oooo]Zo`3oYP0DoookJP;ookL03Ooo
nfX00ol007oo05;oo`1Bo`03o`00O`?ooo]Z0_l0obh01?l007oooo]ZoookJ_oonfX3o`00O`03oook
J_oooP3ooo]Z00Gooo]Z0_n6o`04oookJP03oolg0?oonf[ooo]Z00gooo]Z0_m9o`04oookJP;ooj80
2_oonfX00ol0Yooooo]ZoookJP06oookJP;o001o@?oonfX2o`000005oon@0?l0003ooo]ZoookJ_mb
o`00;_oonfX2o`01o`Wooo]Z00Kool00oookJ_oonf[o0?nVoookJ_l007l2odl0o`Wooo]Z00?oo`2<
oookJ_oonfX03OoonfX01?l=0?oo7Ol0of?o0?mSo`02oookJP03ofWo0?oonf[oob4000;oo`3?1ooo
nfX00ol0olgooo]ZoookJP02ool0QPKooo]Z0_n00?l2oookJP;o/_l00_oonfX6o`00O`?ooo]Z0ol0
07l01?oonf[o8ol0ob?o0?ooG@02o`00O`;ooo]Z0_l0;?l:oookJP;o0?_o1_oonfX00ooo0:[ooo]Z
ooon0002ofko00Gooo]Z00?olP3ooookJ_oonfX00_oo03/=oookJP;o04oo00Cooo]Zo`00Ool007oo
o`2a0ol007l2oonk00;ooo]Z0_l007lRoookJP009ooonfX6o`00O`;o0?oE0_oonfX2o`00O`kooo]Z
0_l04ol2oookJP;o0:Co0_l0ojHDoookJP03oong0?oonf[ooo]Z00cooo]Z0_oo:006o`00O`04oook
J_l0obko0?l^oookJP?o001o00Cooo]Zo`00Ool007oo001o0_oooP04oookJP04ohKo0?oo:03oobP0
oolX00;ooo]Z0_oo=`0?oookJP;oBOl00ooo:002oonR00_ooo]Z0_l0Yol4oookJP?oo`000_oonfX2
o`00OaSooo]Z0_oo000SoookJPOoolT00_oo:0000ooo003ooo]ZoookJP0[oookJP03o`01oooonf[o
oo]Z00Oooo]Z2ooo0003oookJPWoobP01_oonfX5oolX00;o7Ol00ooo:002ool000;oob4000?oo`00
oolX0?oo:0002_oo:0000ooonf[oobP0oolX0004oolX0005oh00oooonf[ooo]ZoookJ_nbo`001?oo
nfX6o`00O`?ooo]Z0ooo:002ool000?oobP000?ooo]Zo`0/oooonfX01?oonfX;oolX00?ooo]Z00?o
o`2ZoookJ_oooP000_m^o`05oookJP05oo80oooonf[ooo]ZoookJ_oo03/03?oonfX2o`1?o`?ooo]Z
0_oo0;43o`00O`;ook/00ooonfX2o`00OdOooo]Z1_l007l01?l0omGooo]ZoookJ_oonfX2o`00O`ko
oo]Z0_l04ol01?oonf[o0:Coo`2ToooonfX2o`3oYQ?ooo]Z0_oo]`0>oookJP;o05;o1Ol007l01?oo
nf[o0?l^o`3o;_oonfX3o`00O`04oookJ_l007oo001oo`00O`;oooh01OoonfX2ohKo00Cooo]Z0_oo
=`0>oookJP;oBOl01?oonfX2oonR00[ooo]Z0_l0Yol9oookJP;o001o@?oonfX2o`000004oon@0?l0
003ooo]Zog;o02kooo]Z00?o007ooookJ_oonfX01ooonfX2ooo00003oookJ_l0ojKo0?nV00;ooo]Z
00?oC`3oo`00OooonfX01ooonfX2ool0S0oooo]Z0_lMo`000omSo`3ooo]ZoookJP02ofWo00;oob40
00?oo`3?oookJ_oonfX01OoonfX2o`3oc@;ooo]Z00?oo`26oookJ_oonfX01OoonfX01On00?oooo]Z
oookJ_oonf[o/_l000Cooo]Z1_l007l4oookJP;o001o00?o8ol0oomM0?ooG@000_l007l2oookJP03
o`0/oooonf[ooo]Z00Sooo]Z0_l0nol6oookJP;oo`2Z00?oooh0ofko0?m^o`001OoonfX2oo80o`;o
oo]Z00?oo`0koookJ_oonfX02ooonfX2o`1?o`?ooo]Z0_oo0;43o`00O`03oonk0?oonf[ooo]Z00;o
oo]Z0_l007lRoookJP00:OoonfX3o`00O`03o`3oeOoonf[ooo]Z00?ooo]Z1ol007l7oookJP03o`0C
oooonf[ooo]Z00;o0:Co0_ooN@0DoookJP;ookL02?oonfX00ooo:03ooo]ZoookJP03oookJP03oolX
0?oonf[ooo]Z00;ooo]Z0ol007l2o`3o;P?ooo]Z1Ol007l2ooon00Gooo]Z00?oQ_l0oookJ_oonfX0
0_oonfX2oolg00kooo]Z0om9o`06oolX00;oo`002?oonfX2o`2Wo`Gooo]Z1Ooo0002oookJPOo001o
4OoonfX4ool0027ooo]Z1ooob@02oolX0003oookJ_oo003oo`0002_ooo]Z00?o007ooookJ_oonfX0
1_oonfX2ooo000[oo`001?l007l00ooonf[oobP0oolX0005oolX00Oooo]Z0ooo:002oago00;oobP0
1?oo00000ooo8@3oo`00oolX000<oolX00;ooo]Z1Ooo:003oookJP;o/_l01ooonfX4o`00O`?ooo]Z
1Ooo0002oolX0003o`00Ool0;?oooo]Z00Kooo]Z2Ooo:002oookJP;oo`2Z00?ooo]Zooon0?m^o`00
1OoonfX2oo80o`;ooo]Z0_oo03/<oookJP04o`1?oooonf[ooo]ZoookJP;oo`2a0_oonfX01?l007oo
ok/0oonk0?l007l5oookJPOo001o@ooonfX2o`00O`;o0?oE1OoonfX7o`00O`Kooo]Z0_l04ol01?oo
nf[o0:Coo`2ToooonfX2o`3oYQ?ooo]Z0_oo]`0?oookJP04o`1Boooonf[ooo]ZoookJP?o001o0_l0
obh3oookJPGo001o0_oooP06oookJP03ohKo0?oonf[ooo]Z00;ooo]Z0_oo=`0>oookJP;oBOl01?oo
nfX2oonR00[ooo]Z0_l0Yol<oookJPOo001o>_oonfX2o`000003oon@0?l0003oL_l002kooo]Z00?o
007ooookJ_oonfX01_oonfX2ooo000;ooo]Z00Ko0?nVoookJ_oonf[ooo]Zodl0oooonfX7o`00O`;o
o`2<3ooonfX2oago00;oHol00_oonfX00omYo`3ooo]ZoolQ0002ool0c`Kooo]Z0_l0old2oookJP;o
o`261_oonfX2oh00o`;ooo]Z0_nbo`07oookJPCo001o1?oonfX2ob?o0003oomM0?l007oo001o00;o
001o00?ooo]Zo`0/oooonfX02OoonfX00ol0nooooo]ZoookJP04oookJP;oo`2Z00?ooo]Zooon0?m^
o`001OoonfX2oo80o`;ooo]Z0_oo03/=oookJP04o`1?oooonf[ooo]ZoookJP;oo`2a0_oonfX01?l0
07oook/0oonk0?l007l5oookJPOo001o7?oonfX002[ooo]Z00?o001oo`3oeOl007l01OoonfX7o`00
O`Gooo]Z0_l04ol00ooonf[o0:Coo`2To`02oomi01Cooo]Z0_oo]`09oookJP;oobP00ooonfX2oolX
00Kooo]Z00?o001oo`3o;_l007l01OoonfX3o`00O`03ooon0?l007oooo]Z00?ooo]Z0_n6o`03oook
JP;oocL03_oonfX2odWo00;ooo]Z1ooo:002ool000Kooo]Z0_l0Yol6oookJPOoo`0000?ooo]Zo`00
Ool007l01Ol007l@oookJPGoo`008ooonfX4ooo900?oobP01?oo000XoookJP;o007o2?oonfX01?oo
`03ooo]ZoookJ_l0ojH8ool000Co001o0_oo08`00ooonf[oobP0oolX0003oolX00Wooo]Z00?oobP0
oago0?oo:0002Ooo000;oolX00Gooo]Z0ooo:002oookJP;o/_l02_oonfX3o`00O`Ooo`000_oo:002
o`0/o`Sooo]Z2?oo:002oookJP03ool0Z_oonf[oooh000;oK_l01?oonfX2oo80o`;ooo]Z0_oo03/<
oookJP;o04oo0ooonfX00ooo0;7ooo]ZoookJP02oookJP04oonk0?l007oo001oo`00O`;ooo]Z0_oo
03<00ooonf[o001oo`00O`05o`00OdCooo]Z00?o0?oEo`00Ool007l01OoonfX7o`00O`Gooo]Z00Go
01?ooookJ_l0Y?oo0:CooookJP02o`3oYQCooo]Z00?ookL0oookJ_oonfX03OoonfX2o`1Bo`Gooo]Z
00?o001oo`3o;_l007l01OoonfX3o`00O`03ooon0?l007oooo]Z00Cooo]Z0_n6o`03oookJP;oocL0
3_oonfX2odWo00Gooo]Z00?ooj80oookJ_oonfX02?oonfX2o`2Wo`kooo]Z1ol007ljoookJP;o0000
00?ooi00o`000?mbo`00;?oonfX2o`01o`Sooo]Z00?ool00oookJ_oonfX00_l0ojH6oookJPKo001o
00?oo`2<oookJ_oonfX03_oonfX00olMo`3ooo]Zof?o0002oookJP;oJOl00_oo8@000ooo0<oooo]Z
oookJP04oookJP;o0?o=0ooonfX00ooo08Kooo]ZoookJP05oookJP03oh00oooonf[ooo]Z00;o/_l0
2_oonfX3o`00O`?ooo]Z00?o8ol0oomM0?ooG@001?l007l2o`0/o`Wooo]Z0_l0nol6oookJP03ool0
Z_oonf[oooh000;oK_l01OoonfX00oob0?oooo]ZoookJP02ool0>`gooo]Z0_l0Col3oookJP04ool0
/Ooonf[ooo]ZoookJP;ook/00ol007l2oookJP;oo`0c00?ooo]Zo`00Ool007l01Ol007lLoookJP00
:_oonfX00ol0omGooo]ZoookJP0?oookJP;o01?o0_oonfX00ol0Y?oooo]Zoomi000EoookJP03oong
0?oonf[ooo]Z00Sooo]Z1_oo:007oookJP;o0?l^2?oonfX2ooon00Gooo]Z00?oQ_l0oookJ_oonfX0
0_oonfX00ooo=`3ooo]ZoookJP0<oookJP;oBOl000?oo`00oookJ_oonfX02Ooo:002ool000?ooo]Z
0_l0Yol7oookJPSoo`005ooonfX7ool002Cooo]Z00?oogT0oolX0?oo:0000ooo:004ool002Kooo]Z
00?o007ooookJ_oonfX01_oonfX2ooo00003oookJ_l0ojKo0?nV00;ooo]Z1_oo0004oookJP03ool0
S?oonf[ooo]Z00;ooo]Z0ooo:009oookJP03oago0?oo003oo`0000[oo`0000?ooo]ZoolX0?oo:000
1ooo:005oookJP;oP03o00CoobP0oookJ_oonf[o/_l03?oonfX9ool000;oobP000?o02cooookJ_oo
nfX02?oonfX7oolX0004oookJ_oo0:[oo`2Zooon00;oK_l01OoonfX01Oob0?oooo]ZoookJ_oonf[o
o`0k00gooo]Z00Co04oooookJ_oonf[ooo]Z0_oo0;43oookJP;ook/01OoonfX00ooo03?ooo]Zoook
JP1;oookJP03o`3oeOoonf[ooo]Z013ooo]Z0_l04ol01Ooonf[o0:CooookJ_oonf[o0?nV01Cooo]Z
0_oo]`0>oookJP;o05;o1_oonfX2o`3o;PSooo]Z0_oooP05oookJP;oQ_l01?oonfX00ooo=`3ooo]Z
oookJP0<oookJP;oBOl01OoonfX2oonR00?ooo]Z0_l0oe44oookJP;o0:OoDOoonfX01?l0003ooi00
o`000?l0000/oookJP03o`01oooonf[ooo]Z00Kooo]Z0_oo`002oookJP03o`3oY_oonf[ooo]Z00[o
oo]Z0_oo08`?oookJP;o7Ol00_mSo`02oookJP04ofWo0?oo8@3oob40ool0c`Oooo]Z00Co0?o=oook
J_oonf[ooo]Z0_oo08H6oookJP;oP03o0_oonfX00onbo`3ooo]ZoookJP0>oookJP;o8ol000?ooed0
oookJ_oonfX00ooonfX00ol0;?oooo]ZoookJP07oookJP;o0?_o1_oonfX2ool0ZP03ooon0?m^o`3o
K_l000Gooo]Z0_ob0?l2oookJP03ool0>ooonf[ooo]Z00cooo]Z00Co04oooookJ_oonf[ooo]Z0_oo
0;42oookJP;ook/01_oonfX00ooo03?ooo]ZoookJP0ToookJP00>OoonfX00oooN@3ooo]Zo`0Co`02
oookJP;o0:Co0_ooN@0DoookJP;ookL02_oonfX6oolX00Kooo]Z0_l0obh8oookJP;oooh01OoonfX2
ohKo00?ooo]Z0_oo=`0=oookJP;oBOl000Cooo]Zool00?oo003ooo]Z2ooo:002ool00003oookJ_l0
Yooooo]Z00Oooo]Z2_oo000EoookJPSoo`008ooonfX00oooN@3oobP0oolX0005oolX00Coo`008ooo
nfX2o`01o`Oooo]Z0_oo`002oookJP03o`3oY_oonf[ooo]Z00;ooo]Z1Ooo0003oookJP;oo`2<1_oo
nfX00ooo:03ooo]ZoookJP06oookJPkoo`000_oonfX8oolX00Gooo]Z00CoP03ooookJ_oonf[ooo]Z
0_nbo`0:oookJP_oo`0000?ooo]ZoolX0?l0;?l02OoonfX2oolX00;ooo]Z1?oo:002ool0ZP03oook
J_oooP3oK_l000Gooo]Z0_ob0?l2oookJP;oo`0k3?oonfX2o`1?o`?ooo]Z00Coo`2aoookJ_oonf[o
oo]Z0_oo^`05oookJP;oo`0cGooonfX2o`0Co`04oookJ_l0Y?oo0:CooookJP;o0?nV4ooonfX2oong
00oooo]Z00?o05;ooookJ_oonfX01?oonfX2o`3o;PSooo]Z0_oooP06oookJP03ohKo0?oonf[ooo]Z
00;ooo]Z0_oo=`0=oookJP;oBOl01OoonfX2oonR00?ooo]Z0_l0oe45oookJP03o`2Woooonf[ooo]Z
00[ooo]Z0_oL0?m5oookJP04o`000?ooT03o0000o`0002[ooo]Z0_l00Ol7oookJP;ool000ooonfX0
0ol0ojKooo]ZoookJP09oookJP;oo`2<3ooonfX2oago00;oHol00_oonfX2ofWo0003oolQ0?oo0<oo
o`3?00Kooo]Z0_l0old3oookJP03ool0Q_oonf[ooo]Z00Gooo]Z00?oP03ooookJ_oonfX00_nbo`0@
oookJP03ob?o0?ooG@3ooed000Cooo]Z0_l0;?l8oookJP;o0?_o1ooonfX01?oo0:[ooo]Zooon0?m^
o`05oookJP;olP3o0_oonfX2ool0>`gooo]Z0_l0Col3oookJP05ool0/Ooonf[ooo]ZoookJ_oo^`00
1_oonfX2ool0<bOooo]Z000hoookJP;oogT000Co01?ooookJ_l0Y?oo0:Co0_ooN@0DoookJP;ookL0
2ooonfX7oolX00Cooo]Z0_l0obh9oookJP03ooon0?oonf[ooo]Z00Cooo]Z00CoQ_l0oookJ_oonf[o
oo]Z0_oo=`0>oookJP03odWo0?oonf[ooo]Z00?oo`002_oo:004ool00003o`2Woooonf[ooo]Z00Ko
oo]Z3?oo000CoookJPWoo`008ooonfX9oolX00Coo`008OoonfX00ol00Ooooo]ZoookJP05oookJP;o
ol000_oonfX2o`3oYPKooo]Z0ooo0003oookJP03ool0S?oonf[ooo]Z00cooo]Z4?oo0002oookJP03
o`3ocOoo:03oobP000GoobP01?oonfX2oh00o`;ooo]Z0_nbo`0;oookJP_oo`0000?ooo]Zo`0/oooo
nfX02?oonfX2oolX00Cooo]Z0ooo:0000ooo0:[ooo]Zooon0002ofko00Cooo]Z0_ob0?l2oookJP;o
o`0k3?oonfX2o`1?o`?ooo]Z0_oo0;43oookJP03oonk0?oonf[ooo]Z00Cooo]Z00?oo`0coookJ_oo
nfX0G_oonfX01Ol04ooooo]Zo`2Tool0Y?oooo]Z00;o0?nV4ooonfX2oong00oooo]Z0_l0D_l5oook
JP;o0?l^2OoonfX00ooooP3ooo]ZoookJP04oookJP;oQ_l00ooonfX2oolg00kooo]Z00?oBOl0oook
J_oonfX01?oonfX00oooXP3ooo]ZoookJP02oookJP03o`3oDOoonf[ooo]Z00?ooo]Z0_l0Yol;oook
JP;og03oAooonfX4o`0002Wooo]Z00?o007ooookJ_oonfX01_oonfX01?oo`03ooo]ZoookJ_oonfX2
o`3oYP_ooo]Z00?oo`2<oookJ_oonfX03_oonfX00olMo`3o3@3oof?o0003oookJP04ofWo0?oo8@3o
ob40ool0c`Kooo]Z0_l0old3oookJP;oo`261_oonfX2oh00o`03oookJ_nbo`3o/_l0013ooo]Z00?o
8ol0oomM0?ooG@001OoonfX00ol0;?oooo]ZoookJP07oookJP03o`3koooonf[ooo]Z00Gooo]Z0_oo
0:X00ooooP3oK_l0ofko0005oookJP03oo80oooonf[ooo]Z00;oo`0k3OoonfX2o`1?o`?ooo]Z0_oo
0;42oookJP;ook/01OoonfX2ool0<bWooo]Z000goookJPCoogT000?o0:CooookJ_ooN@005OoonfX0
0ooo]`3ooo]ZoookJP0:oookJPWoobP00_oonfX00ol0obkooo]ZoookJP07oookJP;oooh01OoonfX2
ohKo00?ooo]Z00?oocL0oookJ_oo00003?oonfX2odWo00;ooo]Z0ooo0008oolX00Soo`001ooonfX:
ool001Gooo]Z2ooo000QoookJP_oobP000?oo`00oookJ_oonfX07ooonfX2o`01o`Oooo]Z00Gool00
oookJ_oonf[ooo]Zo`3oYP09oookJP03ool00?oonf[oo`0000;oo`003?oonfXBool000;ooo]Z00Co
0?o=oookJ_oonf[ooo]Z1?oo:004oookJP05oh00oooonf[ooo]ZoookJ_nbo`003OoonfX:ool000;o
obP02OoonfX00ooo:03ooo]ZoookJP05oookJP;oo`2Z00?ooo]Zooon0?m^o`001OoonfX01Oob0?oo
oo]ZoookJ_oonf[oo`0k00gooo]Z00Co04oooookJ_oonf[ooo]Z0_oo0;43oookJP;ook/01_oonfX0
0ooo03?ooo]ZoookJP1MoookJP;o01?o0_l0Y?l00ooonf[o0?nVo`3oYP0DoookJP03oong0?oonf[o
oo]Z00kooo]Z00?o05;ooookJ_oonfX01?oonfX00ol0obkooo]ZoookJP07oookJP;oooh01_oonfX0
1?n6o`3ooo]ZoookJ_oonfX2oolg00kooo]Z0_m9o`05oookJP;ooj8000?ood`0oookJ_oonfX00_l0
oe44oookJP;o0:Oo2ooonfX2om`0odWooo]Z1?l0000WoookJP;o007o1ooonfX2ooo000;ooo]Z0_l0
ojH;oookJP;oo`2<3ooonfX2oago0004of?o0?oonf[ooo]ZoookJP;oJOl000?oob40ool0cooonfX0
1_oonfX00ol0olgooo]ZoookJP02oookJP03ool0Q_oonf[ooo]Z00Cooo]Z0_n00?l2oookJP03ok;o
0?oonf[ooo]Z00kooo]Z0_lSo`000oooG@3ooo]ZoookJP03oookJP;o02co2?oonfX2o`3ko`Kooo]Z
0_oo0:X00ooonf[oooh0ofko0005oookJP;olP3o0_oonfX00ooo03_ooo]ZoookJP0<oookJP04o`1?
oooonf[ooo]ZoookJP;oo`2a0_oonfX2oonk00Kooo]Z00?oo`0coookJ_oonfX0:OoonfX003Kooo]Z
1oooN@0DoookJP;ookL03?oonfX;oolX0003o`3o;_oonf[ooo]Z00Kooo]Z0_oooP06oookJP04ohKo
0?oonf[ooo]ZoookJP;oocL000?ooo]Zool00?oo00002ooonfX01?m9o`3ooo]ZoookJ_oonfX3ool0
00KoobP02?oo0009oookJPOoo`006?oonfX9ool002?ooo]Z1_oo:0000ooo003oobP0oolX0004oolX
01oooo]Z0_l00Ol7oookJP;ool000_oonfX2o`3oYPSooo]Z1_oo000:oookJQCoo`0000?ooo]Zo`3o
cOl0old00ooonfX01?oo08KoobP0oolX0?oo:003oookJP;oP03o0_oonfX2ok;o00oooo]Z2Ooo0009
oookJP03o`3koooo:03ooo]Z00Gooo]Z0_oo0:X01?oonf[oooh0ofko0?m^o`04oookJP;olP3o0_oo
nfX2ool0>`cooo]Z0_l0Col3oookJP04ool0/Ooonf[ooo]ZoookJP;ook/01_oonfX2ool0<ekooo]Z
0_l04ol00ooonf[o0:CooookJP02o`3oYQCooo]Z0_oo]`0?oookJP;o05;o1OoonfX2o`3o;PSooo]Z
0_oooP06oookJP;oQ_l00ooonfX00ooo=`3ooo]ZoookJP0=oookJP03odWo0?oonf[ooo]Z00?ooo]Z
0_ooXP000oooC03ooo]ZoookJP02o`3oD@Cooo]Z0_l0Yol<oookJP03om`0oooonf[ooo]Z01cooo]Z
0_l0ooL[oookJPCo00009_oonfX00ol00Ooooo]ZoookJP06oookJP05ooo00?oonf[ooo]ZoookJ_l0
ojH03?oonfX00ooo08cooo]ZoookJP0>oookJP03oago0?mSo`3oHol000?ooo]Z00CoJOl0oolQ0?oo
nf[oo`3?1_oonfX2o`3oc@Cooo]Z00?oo`26oookJ_oonfX01?oonfX00on00?oooo]ZoookJP02ok;o
013ooo]Z00?o8ol0oomM0?ooG@001?oonfX2o`0/o`Sooo]Z0_l0nol7oookJP03ool0Z_oonf[oooh0
00;oK_l01OoonfX00oob0?oooo]ZoookJP02ool0>`gooo]Z0_l0Col3oookJP05ool0/Ooonf[ooo]Z
oookJ_oo^`001_oonfX2ool0<bcooo]Z000XoookJPco000000?o01?ooomi0?ooN@001OooN@0Co`00
00;ookL03Ol0000:oolX0003o`3o;_l0003o000000Oo000000?oooh0o`000?l000001?l00002ohKo
00;o00000_oo=`02o`0000Coo`000_l00002ool000Co00000_m9o`03o`0000?oo`001?oo:007ool0
0003o`2Wool0003o000000Wo00001Ooo000Jo`0000Ooo`002?l000000ooo003o0000o`00000Jo`00
00coobP08?l000000ol00Ooo0000o`000005o`0000;ool000ol000000ol0ojKo0000o`000005o`00
00Soo`002?l0000Fool00003o`000?l0olgo000000;o00000_oo08H2o`000003oolX0?l0003o0000
00;oP03o0_l00002ok;o00oo00000_lSo`08ool000Wo000000?o0?_oo`000?l000001Ol000000ooo
0:[o0000ooon0002ofko00Co00000_ob0?l2o`0000;oo`0k3?l00002o`1?o`?o00000_oo0;43o`00
0003oonk0?l0003o000000Go000000?oo`0co`000?l000002?l00018oookJPgo000000Ko01?oo`00
0?l0Y?oo0:Coo`000?l0ojHDo`0000;ookL04?l000000ol0D_oo0000o`000003o`0000;o0?l^2Ol0
00000ooooP3o0000o`000004o`0000;oQ_l00ol00002oolg00Oo00000_oog005o`0000;oBOl01Ol0
00000oooXP3ood`0o`000002o`000003o`3oDOl0003o000000?o000000?o0:Ooo`000?l000002_l0
0002om`0oago00000_l0ooMFo`000003o`01ool0003o000000Go00000_oo`002o`0000;o0?nV2ol0
0002ool0S0oo000000?o3@3ooago0?mSo`001?l000000omYo`3oob40o`000007o`000003o`3ocOl0
003o000000;o00000_oo08H5o`0000;oP03o00?o0000ok;o0?nbo`004?l00002ob?o0003oomM0?l0
003o000000;o00000_l0;?l9o`000003o`3kool0003o000000Go00000_oo0:X00ooooP3oK_l0ofko
0005o`0000;olP3o00?o0000ool0>ooo03/03Ol00002o`1?o`?o00000_oo0;42o`0000;ook/01_l0
00000ooo03?o0000o`000009o`0002?ooo]Z000XoookJP_o000000?o01?ooomi0?ooN@001oooN@0A
o`000003oong0?l0003o000000co00002?oo:002o`3o;PKo000000?oo`00o`000?l000000_oooP02
o`0000;oo`000_l000001On6o`3o0000o`000?l0003oocL000?o00001ooo0005o`000003odWo0?l0
003o000000;o00000_oo00000oooXP3oobP0oolX0007ool00003o`000?l0Yooo0:Oo00[o000000?o
g03oool00?oo00005ol000000ooo:03o0000o`000003o`0000Coo`003?l000000ooo003o0000o`00
000>o`000003ool00?l0003o000000So00002ooo:00Po`0000;o007o1ol000001?oo`03o0000o`00
0?l00002o`3oYPCo00002ooo0007o`0000_oo`0000?o0000ool00?oo00002Ooo0002o`3oc@?o0000
00?oo`26o`000?l000001?l000001On00?oo0000o`000?l0003o/_l000oo00000_lSo`02ool00003
oolX0?oo003oo`0000Coo`002?l00002o`3ko`Ko00000_oo0:X00ol0003oooh0ofko0005o`000003
oo80ool0003o000000;oo`0k3Ol000000ol0Cooo0000o`000002o`000004ool0/Ol0003o0000o`00
00;ook/01_l00002ool0<`_o0000B?oonfX;o`0000;o01?o0_l0Y?l00ol0003o0?nVo`3oYP0Do`00
0003oong0?l0003o000000ko00000_l0D_l4o`0000;o0?l^2Ol00002ooon00;o00000_mGo`02o`00
0004ohKo0?l0003o0000o`0000;oocL01ol00002oooL00Go00000_m9o`05o`0000;ooj8000?ood`0
o`000?l000000_l0oe44o`0000;o0:Oo2ol00002om`0oago00000_l0ooMFo`0000;o007o1ol00000
0ooo`03o0000o`000002o`3oYP_o00000_oo08`?o`000003o`d0oolMo`3o7Ol000Go000000?oob40
o`000?l000001_l00002o`3oc@Co000000?oo`26o`000?l000000ol00002oh00o`;o000000?o/_l0
o`000?l000003_l00002ob?o00;ooed00ol00002o`0/o`Wo00000_l0nol7o`000004ool0Z_l0003o
ooh0ofko00Go00000_ob0?l2o`000003ool0>ol0003o000000co000000?o04ooo`000?l000000_l0
00000ooo0;7o0000o`000002oonk00Ko00000_oo03<<o`0002?ooo]Z000XoookJPWo00000_l04ol:
oomi00oo00000_oo]`0>o`0000KoobP00_l000000ol0obko0000o`000005o`0000;oo`000_oooP02
o`0000;oo`000_l00002ohKo00;o00000_oo=`03o`0000Ooo`001Ol000000om9o`3o0000o`000002
o`000003ool00?ooXP3ooj8000Woo`0000?o0000o`2Wool000002_l000000ooL0?oo0000o`00000G
o`0000;oobP00ol000000ol0ooOoo`00ool0000>o`0000?oo`003ol000000ooo003o0000o`000007
o`0000SoobP000?oo`00oolX0?l000007ol00002o`01o`So000000Gool00o`000?l0003o0000o`3o
YP04o`0000coo`002?l0000:ool000?o00001_oo0002o`000004ool00?l0olgo0000o`0000?oo`00
1Ol00002oh00o`;o00000_oo:00>o`0000;o8ol000?oobP0ool00?oo:0000ooo:004ool000Oo0000
0_l0nol6o`0000;oo`2Z00Co0000ooon0?m^o`3oK_l01?l00002oo80o`;o000000?oo`0ko`000?l0
00002ol00002o`1?o`?o00000_oo0;42o`0000;ook/01_l00002ool0<`go0000B?oonfX9o`0000;o
01?o00?o0000o`2Tool000000_l0ojHDo`0000;ookL03ol00002o`1Bo`Go000000?o0?l^o`000?l0
00001ol00002ooon00?o000000?oEol0o`000?l000000_n6o`03o`000003oolg0?l0003o000000Ko
000000?oom`0o`000?l000001?l000000om9o`3o0000o`000003o`0000;ooj8000?ood`0o`000?l0
00000_l0oe45o`000003o`2Wool0003o000000[o000000?og03oo`000?l000006ol00002o`3omeGo
00000ol00Ol7o`0000;ool000_l000000ol0ojKo0000o`00000:o`000003ool0S?l0003o000000ko
000000?o3@3ooago0?l000003_l000000ol0olgo0000o`000002o`0000;oo`261?l00002oh00o`;o
00000_nbo`0?o`0000;o8ol000?o0000oomM0?l000000_l00002o`0/o`[o000000?o0?_oo`000?l0
00001Ol00002ool0ZP03ooon0?m^o`3oK_l000Go000000?olP3oo`000?l000000_oo03/=o`0000;o
04oo0ol00002ool0/@03o`000?oo^`3ook/000Oo000000?oo`0co`000?l000003?l0000SoookJP00
:?oonfX8o`000003o`0Cool0003oogT000_oogT03?l00002oong00oo00001?oo:003o`0000;o0?l^
1ol00002ool00005ooon0?oo003o0000o`000?oo00000ol000001On6o`3o0000o`000?l0003oocL0
00Co00002Ooo0002o`0000;oBOl01?l000000ooo003ooj80ool00007ool000;o00000_l0Yol:o`00
00;og03o6Ol00004oolX0003o`000?l0ooOo000000oo00001Ooo000=o`0000?oo`002?l00002ool0
00SoobP07_l00002o`01o`Wo000000?ool00o`000?l000000_l0ojH5o`0000_oo`002_l00008ool0
00Go00001?oo0002o`0000;o0?o=1?oo0005o`0000;oP03o00?o0000oolX0?oo:0000_oo:00=o`00
00;o8ol000?o0000oolX0?oo00001Ooo:003ool000Oo000000?o0?_oo`000?l000001Ol000000ooo
0:[o0000ooon0002ofko00Co00000_ob0?l2o`0000;oo`0k3?l00002o`1?o`?o00000_oo0;43o`00
0003oonk0?l0003o000000Go000000?oo`0co`000?l000003Ol00018oookJPSo000000Co01?oo`00
0?l0Y?oo0:Co0_l0ojHEo`000003oong0?l0003o000000ko000000?o05;oo`000?l000000ol00002
o`3o;PWo000000Coooh0o`000?l0003o00000_mGo`02o`000004ohKo0?l0003o0000o`0000;oocL0
1ol00002oooL00Go00000_m9o`05o`000003oonR0?ooC03o000000;o000000?o0?mAo`000?l00000
0ol00002o`2Wo`_o00000_oL0?lMo`000003o`3omol0003o000005?o00000_l00Ol9o`000003ooo0
0?l0003o000000;o0?nV3?l000000ooo08co0000o`00000=o`0000;o3@3o00?o7Ol0o`000?l00000
3?l00002o`3oc@?o00000_oo08H5o`000005oh00ool0003o0000o`000?nbo`003ol00002ob?o00;o
000000Gooed0o`000?l0003o0000o`0/o`0:o`0000;o0?_o1ol000001?oo0:[o0000ooon0?m^o`05
o`0000;olP3o00?o0000ool0>ooo03/03Ol00002o`1?o`?o00000_oo0;42o`000003oonk0?l0003o
000000Go00000_oo03<?o`0002?ooo]Z000ZoookJP04o`000?oonf[ooo]ZoookJP;o01?o00?ooo]Z
oomi0?ooN@002?ooN@0>oookJP03oong0?oonf[ooo]Z00gooo]Z00?o05;ooolX0?oo:0001?oonfX2
o`3o;PSooo]Z00?oo`00ooon0?oooP001?oo0002oookJP;oQ_l00_oonfX2oolg00Cooo]Z2ooo0000
0om9o`3ooo]ZoookJP03oookJP;ooj801Ooo0005oookJP03o`2Woooonf[ooo]Z00Sooo]Z0_oL0?l@
oookJP03o`000?oonf[ooo]Z00Oooo]Z1_oo:00@oookJPKoo`003?oonfX5ool000Kooo]Z1?oo0007
oolX01cooo]Z0_l00Ol9oookJP;ool000_oonfX00ol0ojKooo]ZoookJP06oookJPWoo`001ooonfX0
1Ol0003oo`00ool00?oo003o3@3o00Koo`001_oonfX3ool00003oookJ_oo003o0?o=00Goo`001Ooo
nfX00on00?ooobP0oolX0004oolX00gooo]Z00?o8ol0oookJ_oonfX00_oonfX7oolX0003ool00?oo
nf[ooo]Z00?ooo]Z00?o0000o`3kool0nol01_oonfX2ool0ZP03oookJ_oooP3oK_l000Cooo]Z0_ob
0?l2oookJP;oo`0k3OoonfX00ol0Cooooo]ZoookJP02oookJP04ool0/Ooonf[ooo]ZoookJP;ook/0
1_oonfX2ool0<`kooo]Z00?o0000oookJ_oonfX0BOoonfX01?l0003ooo]ZoookJ_oonfX2o`0Co`04
oookJ_l0Y?oo0?nVo`3oYQGooo]Z0_oo]`0?oookJP;o05;o1?oonfX2o`3o;PWooo]Z0_oooP02oook
JP;oEol000Co0000oookJ_n6o`3oQ_l00_oonfX2oolg00Oooo]Z0_oog006oookJP03odWo0?oonf[o
oo]Z00?ooo]Z0_ooXP03oookJP;o0?mA1OoonfX00ol0Yooooo]ZoookJP09oookJP;og03o3ooonfX0
0ol0003ooo]ZoookJP0;oookJP;o0?og<_oonfX00ol0okKooo]Zo`000003o`0001cooo]Z0_l00Ol9
oookJP;ool000_oonfX00ol0ojKooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00;o3@3o00?oHol0
oookJ_oonfX03OoonfX01?l0olgooo]ZoookJ_oonfX2ool0QPGooo]Z0_n00?l2oookJP;o/_l03ooo
nfX00olSo`3ooo]ZoookJP04oookJP;o02co2?oonfX00ol0003o0?_oo`3ko`07oookJP;oo`2Z00?o
ooh0ofko0?m^o`001?oonfX2oo80o`;ooo]Z00?oo`0koookJ_oonfX03?oonfX00ol0Cooooo]Zoook
JP02oookJP03ool0/Ooonf[ooo]Z00;ook/01_oonfX2ool0<`oooo]Z00?o0000oookJ_oonfX08_oo
nfX002cooo]Z0_l04ol00ooonf[o0:Cooomi0006oomi013ooo]Z0_oo]`0>oookJP;o05;o1_oonfX0
0ol0obkooo]ZoookJP07oookJP;oooh01Ooo00000ooonf[oQ_l0ohKo0002oookJP;oocL01OoonfX:
ool000;oBOl01?oonfX2oonR00Coo`0000?o0?mAoookJ_oonfX00ooonfX2o`2Wo`Cooo]Z00?oobP0
oookJ_oonfX00ooonfX00ooL0?oooo]ZoookJP0IoookJPOoobP03ooonfX8ool000[ooo]Z1_oo0008
oookJPCoo`000_oo:0001?oo003oobP0oolX0?oo:00IoookJP;o007o2?oonfX3ooo000;ooo]Z0_l0
ojH9oookJPSoo`001_oonfX4ool000;o3@3o1_oo0007oookJP[oo`000ooonfX9oolX00cooo]Z0_lS
o`05oookJPOoobP01OoonfX2o`3ko`Kooo]Z0_oo0:X01?oonf[oooh0ofko0?m^o`04oookJP03oo80
oooonf[ooo]Z00;oo`0k3OoonfX2o`1?o`?ooo]Z0_oo0;42oookJP;ook/01_oonfX2ool0<ekooo]Z
0_l04ol01?oonf[o0:Coo`2Tool0ojHFoookJP03oong0?oonf[ooo]Z00gooo]Z0_l0D_l5oookJP03
o`3o;_oonf[ooo]Z00Oooo]Z0_oooP03oookJP03oeOo0?oonf[ooo]Z00;oQ_l00ooonfX00ooo=`3o
oo]ZoookJP06oookJP03oooL0?oonf[ooo]Z00Cooo]Z0_m9o`04oookJP;ooj8000Good`0oookJ_oo
nf[ooo]Zo`3oD@05oookJP;o0:Oo2ooonfX00ooL0?oooo]ZoookJP0LoookJP03o`3omooonf[ooo]Z
037ooo]Z00?o0?nfoookJ_oonfX01?l0000JoookJP;o007o2?oonfX3ooo000;ooo]Z0_l0ojHKoook
JP;o3@3o0_mSo`0>oookJP;o0?o=0_oonfX2ool0QPGooo]Z0_n00?l2oookJP;o/_l03ooonfX2ob?o
00Gooo]Z0_l0;?l:oookJP03o`3koooonf[ooo]Z00Gooo]Z0_oo0:X00ooooP3oK_l0ofko0005oook
JP03oo80oooonf[ooo]Z00;oo`0k3OoonfX2o`1?o`?ooo]Z0_oo0;400ooonf[ook/0oonk0007oook
JP03ool0<ooonf[ooo]Z03Cooo]Z000[oookJP04o`0Coooonf[ooo]Zo`2To`GoogT04OoonfX2oong
00oooo]Z00?o05;ooookJ_oonfX01?oonfX2o`3o;PSooo]Z0_oooP07ool00005ohKo0?oonf[ooo]Z
oookJ_oo=`001_oonfX8ool000;ooo]Z00?oBOl0oookJ_oonfX00_oonfX2oonR00;oo`000_oonfX2
o`3oD@03ooo90?oonf[ooo]Z00;ooo]Z00?o0:OooookJ_oonfX01?oonfX01?oo:03ooo]ZoookJ_oo
nfX2om`0oa_ooo]Z2Ooo:00=oookJP[oo`002?oonfX8ool000;ooo]Z00?oogT0oookJ_oonfX00ooo
nfX01_oo:03oo`00ool00?oo003oobP0ool000?oobP06?oonfX00ol00Ooooo]ZoookJP05oookJP?o
ogT00_oonfX3o`3oYPcooo]Z1_oo0005oookJPGoo`0000?o3@3oool00?oo00001Ooo0006oookJP_o
o`003?oo:00:oookJP?oo`001OoonfX2oolX0003oookJ_oo:03oobP000?oobP01OoonfX00ol0nooo
oo]ZoookJP05oookJP03ool0Z_oonf[oooh000;oK_l01?oonfX2oo80o`;ooo]Z00?oo`0koookJ_oo
nfX02ooonfX2o`1?o`?ooo]Z0_oo0;42oookJP;ook/01ooonfX00ooo03?ooo]ZoookJP1MoookJP04
o`0Coooonf[ooo]Zo`2To`;o0?nV5OoonfX2oong00oooo]Z00?o05;ooookJ_oonfX00ooonfX2o`3o
;PSooo]Z0_oooP03oookJP;oEol00_oonfX01?n6o`3ooo]ZoookJ_oonfX2oolg00Oooo]Z0_oog006
oookJP03odWo0?oonf[ooo]Z00;ooo]Z0_ooXP001?ooC03ooo]ZoookJ_oonfX2o`3oD@Gooo]Z00?o
0:OooookJ_oonfX02OoonfX2om`0oakooo]Z00?o0?ogoookJ_oonfX0<OoonfX01?l0okKooo]Zoook
J_oonfX4o`0001Wooo]Z00?o007ooookJ_oonfX01_oonfX2ooo000;ooo]Z0ol0ojHLoookJP03o`d0
oooonf[oHol000kooo]Z0_l0old2oookJP;oo`261_oonfX01On00?oooo]ZoookJ_oonf[o/_l000oo
oo]Z0_lSo`05oookJP;o02co2_oonfX2o`3ko`Oooo]Z00Coo`2ZoookJ_oooP3oK_l01OoonfX2oo80
o`03oookJ_oo03_oo`0k00gooo]Z0_l0Col3oookJP;oo`2a0_oonfX00ooo^`3ooo]ZoookJP05oook
JP;oo`0c=ooonfX002[ooo]Z00Co01?ooookJ_l0Y?oo0?nV0_ooN@0DoookJP03oong0?oonf[ooo]Z
00gooo]Z0_l0D_l5oookJP;o0?l^2OoonfX00ooooP3oo`00ool00005ool000;oQ_l00_oo0002oolg
00Kooo]Z1_oo0003oookJP;oBOl01?oonfX00oooXP3ood`0oookJP02oookJP;o0?mA00Gooo]Zooo9
0?oob@3oolT0oookJP02ooo900Kooo]Z0ooo:0000ooonf[og03ooookJP0KoookJP_oobP02ooonfX9
ool000Wooo]Z2_oo00000ooonf[oogT0oomi0002oookJP;o0?nf0_oonfX3ool000CoobP05?oonfX4
oolX00Cooo]Z1OooN@02oookJP;o0?nV4?oonfX4ool000Kooo]Z0ooo0002o`d0o`Goo`0000?ooo]Z
ool00?oonfX00ooonfX=ool000coobP01ooonfX6ool000Cooo]Z00?o02cooolX0?oonfX00ooonfX3
oolX00Cooo]Z0_l0nol6oookJP;oo`2Z00?oooh0ofko0?m^o`001?oonfX2oo80o`;ooo]Z0_oo03/=
oookJP03o`1?oooonf[ooo]Z00;ooo]Z00?oo`2aoookJ_oonfX00_oo^`07oookJP;oo`0cGooonfX0
0ol04ooooo]Zo`2To`02o`3oYQGooo]Z0_oo]`0?oookJP;o05;o1?oonfX2o`3o;PWooo]Z00Coooh0
oookJ_oonf[ooo]Z0_mGo`02oookJP;oQ_l00_oonfX2oolg00Oooo]Z0_oog006oookJP;oBOl01?oo
nfX00oooXP3ood`0oookJP02oookJP;o0?mA1OoonfX2o`2Wo`_ooo]Z00?og03ooookJ_oonfX07?oo
nfX2o`3omc?ooo]Z00?o0?nfoookJ_oonfX00_oonfX4o`0001Oooo]Z0_l00Ol7oookJP;ool000_oo
nfX2o`3oYQgooo]Z0_l=0?l00ooonf[oHol0oookJP0<oookJP;o0?o=0_oonfX2ool0QPKooo]Z0_n0
0?l2oookJP;o/_l03_oonfX2ob?o00Gooo]Z0_l0;?l;oookJP03o`3koooonf[ooo]Z00Gooo]Z0_oo
0:X00ooooP3oK_l0ofko0004oookJP;olP3o0_oonfX00ooo03_ooo]ZoookJP0<oookJP04o`1?oooo
nf[ooo]ZoookJP;oo`2a0_oonfX2oonk00Kooo]Z0_oo03<ioookJP00:ooonfX00ol0Y?oo0?nVoook
JP0DoookJP;ookL03_oonfX2o`1Bo`Kooo]Z00?o0?l^oookJ_oonfX01ooonfX2ooon00Koo`000_n6
o`02ool00003oookJ_oo=`3ooo]Z00Kooo]Z1?oo0004oookJP;oBOl01?oonfX2oonR0005oom<0?oo
nf[ooo]ZoookJ_l0oe400_oonfX5ooo900Oooo]Z1Ooo:00LoookJP[oobP03?oonfX7ool000Sooo]Z
00CoobP0oookJ_oonf[ooo]Z2?oo0002oookJPCoogT000?o0?nfoookJ_oonfX00_oonfX2oolX0003
ool00?oo:03oobP000;oobP03ooonfX7oolX00?ooo]Z1oooN@000ooonf[o0?nVo`3oYP0BoookJP?o
o`002?oonfX2o`d0o`Koo`000ooonfX@ool000coobP01OoonfX8ool000Cooo]Z00?o02cooookJ_oo
nfX01OoonfX01?oo:03ooo]ZoookJ_oonfX2o`3ko`Kooo]Z0_oo0:X00ooonf[oooh0ofko0004oook
JP;olP3o00Cooo]ZoolX0?oo:03oobP03OoonfX2o`1?o`?ooo]Z0_oo0;42oookJP03oonk0?oonf[o
oo]Z00Gooo]Z0_oo03=RoookJP03o`2Tool0ojKooo]Z01Gooo]Z00?ookL0oookJ_oonfX03OoonfX2
o`1Bo`Gooo]Z00?o0?l^oookJ_oonfX01ooonfX2ooon00?ooo]Z00?oEol0oookJ_oonfX00_n6o`03
oookJP03oolg0?oonf[ooo]Z00Kooo]Z00?oom`0oookJ_oonfX01?oonfX2odWo00Cooo]Z0_ooXP00
1OooC03ooo]ZoookJ_oonf[o0?mA00Kooo]Z00?o0:OooookJ_oonfX02OoonfX2om`0oakooo]Z00?o
0?ogoookJ_oonfX04OoonfX2ool/01kooo]Z0_l0okH5oookJPCo00005?oonfX3o`01o`Oooo]Z0_oo
`003oookJP03o`3oY_oonf[ooo]Z01_ooo]Z0_l=0?l@oookJP05o`3ocOoonf[ooo]ZoookJ_oo08H0
1_oonfX2oh00o`;ooo]Z0_nbo`0?oookJP03ob?o0?oonf[ooo]Z00?ooo]Z0_l0;?l;oookJP;o0?_o
1_oonfX2ool0ZP03ooon0?m^o`3oK_l000Cooo]Z0_ob0?l2oookJP;oo`0k3OoonfX2o`1?o`?ooo]Z
00?oo`2aoookJ_oonfX00_oo^`07oookJP03ool0<ooonf[ooo]Z03Wooo]Z000ZoookJP03o`2Tool0
ojKooo]Z01?ooo]Z0_oo]`0?oookJP03o`1Boooonf[ooo]Z00Cooo]Z0_l0obh8oookJP;oooh000?o
oo]Zool00?oo00001?oo00001?n6o`3oo`00oookJ_oonfX2oolg00Kooo]Z00?oom`0ool00?oo0000
1_oonfX00om9o`3ooo]ZoookJP02oookJP;ooj8000Cood`0oookJ_oonf[ooo]Z0_l0oe42oookJPKo
olT01_oonfX6oolX01_ooo]Z2?oo:00>oookJPKoo`002_oonfX00ooo:03ooo]ZoookJP06ool000Co
oo]Z1_ooN@03oookJPWoobP02OoonfX;oolX00[oogT000?ooo]Zo`3oY_oonfX05?oonfX00ooo003o
oo]ZoookJP05oookJP;o3@3o00?ooo]Zool00?oo00001?oo0002oookJQ7oo`003?oo:002oookJP_o
o`000ooonfX2o`0/o`_ooo]Z00?o0?_ooookJ_oonfX01OoonfX00ooo0:[ooo]Zooon0002ofko00Co
oo]Z00?olP3ooolX0?oo:0000ooo:00<oookJP;o04oo0ooonfX2ool0/@;ooo]Z0_oo^`06oookJP;o
o`0cHooonfX00ol0Y?oo0?nVoookJP0DoookJP;ookL03ooonfX00ol0D_oooo]ZoookJP03oookJP;o
0?l^2?oonfX2ooon00?ooo]Z0_mGo`02oookJP04ohKo0?oonf[ooo]ZoookJP;oocL01ooonfX2oooL
00Kooo]Z00?oBOl0oookJ_oonfX00_oonfX2oonR0004oom<0?oonf[ooo]ZoookJP;o0?mA1OoonfX2
o`2Wo`_ooo]Z00?og03ooookJ_oonfX07?oonfX2o`3oma?ooo]Z00?oob`0oookJ_oonfX07OoonfX0
0ol0okKooo]ZoookJP05oookJPCo00004_oonfX2o`01o`Sooo]Z0_oo`004oookJP03o`3oY_oonf[o
oo]Z01[ooo]Z0_l=0?l@oookJP;o0?o=2_oonfX01On00?oooo]ZoookJ_oonf[o/_l000oooo]Z0_lS
o`05oookJP03o`0/oooonf[ooo]Z00[ooo]Z00?o0?_ooookJ_oonfX01?oonfX2ool0ZP03oookJ_oo
oP3oK_l000Gooo]Z00?olP3ooookJ_oonfX00_oo03/=oookJP;o04oo0ooonfX2ool0/@;ooo]Z00?o
ok/0oookJ_oonfX01OoonfX2ool0<ccooo]Z000ZoookJP03o`3oY_oonf[ooo]Z01;ooo]Z00?ookL0
oookJ_oonfX03OoonfX2o`1Bo`Gooo]Z0_l0obh9oookJP03ooon0?oonf[ooo]Z00Goo`000_n6o`02
oookJP;oocL01ooonfX00ooog03ooo]ZoookJP05oookJP;oBOl01?oonfX00oooXP3ood`0oom<0003
oookJP04o`3oDOoonf[oo`00oookJPSoolT01?oonfX8oolX01Wooo]Z1_oo:00:oookJP03oolX0?oo
nf[ooo]Z00?ooo]Z1?oo000<oookJP?oobP01Ooo0006oookJPOoogT00_oonfX9oolX00Gooo]Z00?o
o`00oolX0?oo:0002ooo:007oomi00GoobP07?oonfX2o`d0o`?ooo]Z1Ooo0003oookJP[oo`0000?o
oo]Zool00?oo00000ooo000<oolX0003oookJ_oo003oo`0000[oo`000ooonfX00ol0;?oooo]Zoook
JP08oookJP?oo`001_oonfX2ool0ZP03ooon0?m^o`3oK_l000?ooo]Z00?oobP0oo80ooob0?l01Ooo
:00<oookJP04o`1?oooonf[ooo]ZoookJP;oo`2a0_oonfX2oonk00Oooo]Z00?oo`0coookJ_oonfX0
HooonfX00ol0ojKooo]ZoookJP0CoookJP03oong0?oonf[ooo]Z00gooo]Z0_l0D_l4oookJP;o0?l^
2OoonfX01?oooP3ooo]ZoookJ_oonfX2oeOo00;ooo]Z0_n6o`03oookJP03oolg0?oonf[ooo]Z00Ko
oo]Z00?oom`0oookJ_oonfX01?oonfX2odWo00Cooo]Z00?ooj80oom<0?ooC0000ooonfX00ol0oe7o
oo]ZoookJP03oookJP03o`11ool0Yooooo]Z00[ooo]Z0_oL0?lMoookJP;o0?og5?oonfX00ooo;03o
oo]ZoookJP0@oookJP03o`0goooonf[ooo]Z00[ooo]Z00?o0?nfoookJ_oonfX01_oonfX4o`00017o
oo]Z00?o007ooookJ_oonfX01_oonfX2ooo000?ooo]Z0ol0ojHKoookJP;o3@3o4?oonfX2o`3oc@[o
oo]Z0_n00?l2oookJP;o/_l03_oonfX2ob?o00Gooo]Z0_l0;?l;oookJP;o0?_o1OoonfX2ool0ZP04
oookJ_oooP3oK_l0ofko00Cooo]Z0_ob0?l2oookJP03ool0>ooonf[ooo]Z00cooo]Z00Co04oooook
J_oonf[ooo]Z0_oo0;42oookJP;ook/01_oonfX2ool0<ckooo]Z000moookJP;ookL03_oonfX2o`1B
o`Kooo]Z00?o0?l^oookJ_oonfX01ooonfX2ooon00;ooo]Z1?oo0002ohKo00?ooo]Z00?oocL0oook
J_oonfX01OoonfX2oooL00Oooo]Z00?oBOl0oookJ_oonfX00_oonfX2oonR0004oom<0?oonf[ooo]Z
oookJP;oobP000?ooo]Zool00?oo00002_oob@02oookJP[oobP05ooonfX4oolX00gooo]Z00?oobP0
oookJ_oonfX00_oonfX3ool000gooo]Z1Ooo:002ool000Oooo]Z2OooN@000ooonf[oo`00ool00007
ool00003oookJ_oo003oo`0000?oo`003?oo:0000oooN@3oobP0oolX0008oolX01cooo]Z0_l=0?l6
oookJP?oo`001OoonfX7ool000Cooo]Z0ooo0006oolX0003oookJ_oo:03oobP000?oobP00_oonfX;
ool000;ooo]Z0_l0;?l7oookJPGoo`001_oonfX2ool0ZP04ool`0?oooP3oK_l0oookJP?oobP00_ob
0?l6oolX00_ooo]Z0_l0Col3oookJP03ool0/Ooonf[ooo]Z00;ook/01ooonfX2ool0<g[ooo]Z0_oo
]`0>oookJP;o05;o1OoonfX00ol0obkooo]ZoookJP07oookJP;oooh00ooonfX00omGo`3ooo]Zoook
JP02ohKo00?ooo]Z0_oo=`07oookJP;oom`01_oonfX00om9o`3ooo]ZoookJP02oookJP;ooj8000Co
od`0oookJ_oonf[ooo]Z0_l0oe45oookJP;o0:Oo2ooonfX00ooL0?oooo]ZoookJP0LoookJP03o`3o
mooonf[ooo]Z01?ooo]Z00?oob`0oookJ_oonfX04?oonfX00ol0=ooooo]ZoookJP0:oookJP03o`3o
]_oonf[ooo]Z00Oooo]Z1?l0000IoookJP03ooo00?oonf[ooo]Z00?o0?nV7?oonfX2o`d0oa7ooo]Z
00?o0?o=oookJ_oonfX02OoonfX00on00?oooo]ZoookJP02ok;o00kooo]Z0_lSo`05oookJP;o02co
2ooonfX2o`3ko`Gooo]Z0_oo0:X01?oonf[oooh0ofko0?m^o`04oookJP;olP3o0_oonfX2ool0>`go
oo]Z0_l0Col2oookJP;oo`2a0_oonfX2oonk00Oooo]Z00?oo`0coookJ_oonfX0?_oonfX003cooo]Z
00?ookL0oookJ_oonfX03OoonfX00ol0D_oooo]ZoookJP04oookJP;o0?l^2?oonfX2ooon00;ooo]Z
00?oEol0ool00?oo00000_oonfX01?n6o`3ooo]ZoookJ_oonfX2oolg00Oooo]Z00?oom`0oookJ_oo
nfX01OoonfX2odWo00Cooo]Z00?ooj80oom<0?ooC0000_oo:0001?oonf[oobP0oookJ_oonfX2ool0
00WoolT01?oonfX8oolX01Oooo]Z00?o0?ogoolX0?oo:0003ooonfX3oolX0003oookJ_oo;03oo`00
00oooo]Z1_oo:008oookJPSoogT01OoonfX3ool000GoobP01_oo000EoolX01[ooo]Z0ooo:009oook
JP03ool00?oonf[ooo]Z00Cooo]Z1_oo0005oookJP03oolX0?oo003oobP000GoobP00ooonfX3oolX
00Cooo]Z2Ooo00000ooonf[o02coo`0/o`06oookJPOoo`001OoonfX2ool0ZP04ool`0?oooP3oK_l0
ofko00CoobP000?olP3ooolX0?oo:0001Ooo:00:oookJP;o04oo0ooonfX2ool0/@;ooo]Z00?ook/0
oookJ_oonfX01OoonfX2ool0<g_ooo]Z00?ookL0oookJ_oonfX03OoonfX00ol0D_oooo]ZoookJP03
oookJP;o0?l^2?oonfX2ooon00?ooo]Z0_mGo`02oookJP03ohKo0?oonf[ooo]Z00;ooo]Z00?oocL0
oookJ_oonfX01_oonfX00ooog03ooo]ZoookJP04oookJP;oBOl01?oonfX00oooXP3ood`0oom<0003
oookJP03o`3oDOoonf[ooo]Z00?ooo]Z0_l0Yol;oookJP;og03o7OoonfX2o`3omaCooo]Z0_oo;00B
oookJP03o`0goooonf[ooo]Z00[ooo]Z00?o0?nfoookJ_oonfX02?oonfX4o`0001Oooo]Z0_oo`002
oookJP03o`3oY_oonf[ooo]Z01_ooo]Z0_l=0?lMoookJP;oP03o00?ooo]Zok;o0?nbo`003ooonfX0
0olSo`3ooo]ZoookJP04oookJP03o`0/oooonf[ooo]Z00Wooo]Z0_l0nol6oookJP05ool0Z_oonf[o
oc00ooon0?m^o`001OoonfX00oob0?oooo]ZoookJP02ool0>`gooo]Z0_l0Col2oookJP;oo`2a0ooo
nfX00ooo^`3ooo]ZoookJP05oookJP;oo`0c@OoonfX003[ooo]Z0_oo]`0>oookJP;o05;o1_oonfX0
0ol0obkooo]ZoookJP07oookJP05ooon0?oonf[ooo]ZoookJ_mGo`000ooonfX2ohKo00?ooo]Z00?o
ocL0oookJ_oonfX01OoonfX2oooL00Kooo]Z0_m9o`04oookJP;ooj8000?ood`0oolX0?oo:0000ooo
:002oookJP;oo`001ooob@06oookJPKoobP06OoonfX00ol0ooOooo]ZoookJP0?oookJPGoobP04Ooo
nfX7oolX00Kooo]Z1oooN@07oookJP?oo`001_oo:005ool001CoobP05ooonfX5oolX01?ooo]Z1?oo
0005oookJP;oP03o1_oo:005oookJP03oolX0?oonf[ooo]Z00?ooo]Z2?oo00000ooonf[o02cooook
JP03oookJP[oo`001?oonfX2ool0ZP04oookJ_oo:03oobP0oolX00;ooo]Z0_oo:002oo80o`OoobP0
2OoonfX2o`1?o`?ooo]Z0_oo0;42oookJP;ook/01ooonfX00ooo03?ooo]ZoookJP1ioookJP;ookL0
3_oonfX2o`1Bo`Gooo]Z00?o0?l^oookJ_oonfX01ooonfX00ooooP3ooo]ZoookJP02oookJP03oeOo
0?oonf[ooo]Z00;oQ_l00ooonfX2oolg00Oooo]Z0_oog005oookJP;oBOl01?oonfX2oonR0004oom<
0?oonf[ooo]ZoookJP;o0?mA1OoonfX00ol0Yooooo]ZoookJP0:oookJP03om`0oooonf[ooo]Z01co
oo]Z00?o0?ogoookJ_oonfX04_oonfX2ool/01;ooo]Z0_l0=ol<oookJP03o`3o]_oonf[ooo]Z00Wo
oo]Z1?l0000BoookJPGool000_oonfX2o`3oYQgooo]Z00?o3@3ooookJ_oonfX06ooonfX2oh00o`;o
oo]Z00?o/_l0oookJ_oonfX03OoonfX2ob?o00Gooo]Z0_l0;?l:oookJP;o0?_o1_oonfX2ool0ZP04
ool`0?oooP3oK_l0ofko00Cooo]Z0_ob0?l00ooonf[oo`0kool0>`0=oookJP;o04oo0_oonfX2ool0
/@?ooo]Z0_oo^`06oookJP;oo`0c@ooonfX003Wooo]Z00?ookL0oookJ_oonfX03?oonfX2o`1Bo`Ko
oo]Z0_l0obh8oookJP;oooh00_oonfX2oeOo00?ooo]Z00CoQ_l0oookJ_oonf[ooo]Z0_oo=`07oook
JP03oooL0?oonf[ooo]Z00Gooo]Z00?oBOl0oookJ_oonfX00ooonfX00oooXP3ood`0oom<0006oolX
0003oookJ_oo003oo`0000GoolT000?oo`00oookJ_oonfX01OoonfX5oolX01[ooo]Z00?o0?ogoook
J_oonfX01_oonfX00ooo003ooo]ZoookJP06oookJPOoobP03ooonfX9oolX00Gooo]Z1_ooN@08oook
JP?oo`001_oo:006ool000KoobP00_oo0009oolX01Kooo]Z1ooo:00DoookJP?oo`001?oonfX2oh00
o`?ooo]Z1?oo:00<oookJPOoo`000_l0;?l3oookJP_oo`001?oonfX5oolX00?ooo]Z2ooo:008oook
JP;o04oo0ooonfX2ool0/@04oookJ_oo:03oobP0oolX00Oooo]Z0_oo03=joookJP;ookL03_oonfX2
o`1Bo`Gooo]Z0_l0obh8oookJP;oooh00ooonfX2oeOo00;ooo]Z00?oQ_l0oookJ_oonfX00_oonfX0
0ooo=`3ooo]ZoookJP06oookJP03oooL0?oonf[ooo]Z00Cooo]Z00?oBOl0oookJ_oonfX00ooonfX0
0oooXP3ood`0oom<0003oookJP03o`3oDOoonf[ooo]Z00?ooo]Z0_l0Yol<oookJP03om`0oooonf[o
oo]Z01_ooo]Z0_l0ooLDoookJP03ool/0?oonf[ooo]Z017ooo]Z00?o03OooookJ_oonfX02ooonfX0
0ol0okKooo]ZoookJP0:oookJPCo00002_oonfX8ooo000Gooo]Z0_l0ojHMoookJP;o3@3o6ooonfX3
oh00o`;ooo]Z0_nbo`0?oookJP03ob?o0?oonf[ooo]Z00?ooo]Z0_l0;?l:oookJP;o0?_o1_oonfX2
ool0ZP04ool`0?oooP3oK_l0ofko00Cooo]Z0_ob0?l2oookJP03ool0>ooonf[ooo]Z00_ooo]Z0_l0
Col3oookJP04ool0/Ooonf[ooo]ZoookJP;ook/01ooonfX00ooo03?ooo]ZoookJP13oookJP00=ooo
nfX2oong00kooo]Z00?o05;ooookJ_oonfX01OoonfX00ol0obkooo]ZoookJP06oookJP;oooh00ooo
nfX01?mGo`3ooo]ZoookJ_oonfX2ohKo00?ooo]Z00?oocL0oookJ_oonfX01OoonfX2oooL00Kooo]Z
0_m9o`05oookJP03oonR0?ooC03oobP000SoobP000Coo`00ooo90?oob@3oolT01Ooo0005oookJPCo
obP06_oonfX2o`3om`Wooo]Z00?oo`00oookJ_oonfX01OoonfX9oolX00gooo]Z2?oo:006oookJPGo
ogT02_oonfX3ool000OoobP01_oo0004oolX00?oo`002?oo:00CoookJP[oobP05_oonfX01?oo003o
oo]ZoookJ_oonfX2oh00o`?ooo]Z0_nbo`03oolX00oooo]Z1?oo00000ol0;?oooo]ZoookJP03oook
JP[oo`000_oonfXEoolX00Oooo]Z0_l0Col4oookJPKoobP01_oonfX2ool0<g_ooo]Z00?ookL0oook
J_oonfX03OoonfX00ol0D_oooo]ZoookJP04oookJP03o`3o;_oonf[ooo]Z00Kooo]Z0_oooP04oook
JP03oeOo0?oonf[ooo]Z00;oQ_l00ooonfX2oolg00Oooo]Z0_oog005oookJP;oBOl01OoonfX00ooo
XP3ood`0oookJP02oookJP;o0?mA1OoonfX00ol0Yooooo]ZoookJP0:oookJP;og03o7OoonfX00ol0
ooOooo]ZoookJP0BoookJP;oob`04ooonfX00ol0=ooooo]ZoookJP0;oookJP03o`3o]_oonf[ooo]Z
00_ooo]Z1Ol0000doookJP03o`d0oooonf[ooo]Z01Wooo]Z0_n00?l3oookJP;o/_l05_oonfX00ol0
;?oooo]ZoookJP08oookJP;o0?_o1_oonfX2ool0ZP04ool`0?oooP3oooh0ofko00Cooo]Z0_ob0?l2
oookJP;oo`0k3?oonfX2o`1?o`?ooo]Z0_oo0;42oookJP;ook/01ooonfX2ool0<dKooo]Z000foook
JP03oong0?oonf[ooo]Z00cooo]Z0_l0D_l6oookJP;o0?l^2?oonfX01?oooP3ooo]ZoookJ_oonfX2
oeOo00;ooo]Z0_n6o`03oookJP;oocL01ooonfX00ooog03ooo]ZoookJP05oookJP03odWo0?oonf[o
oo]Z00?ooo]Z0_ooXP0<oolX00Koo`001_oonfX2oolX01cooo]Z00?o0?ogoookJ_oonfX02?oonfX3
ool000Gooo]Z2ooo:00;oookJPOoobP000?oo`00oookJ_oonfX01?oonfX4oomi00cooo]Z0ooo0007
oolX00Coo`0000?ooo]Zool00?oo:0000_oo:005ool000KoobP04_oonfX;oolX01Wooo]Z0_n00?l2
oookJP?oo`000ooonfX00ooo:03ooo]ZoookJP0>oookJPCoo`001ooonfX7ool0013oobP000?ooo]Z
oolX0?oo:0001Ooo:006oookJP;o04oo0ooonfX8oolX00Gooo]Z0_oo03=koookJP;ookL03_oonfX2
o`1Bo`Gooo]Z0_l0obh8oookJP03ooon0?oonf[ooo]Z00;ooo]Z0_mGo`000ooonf[oQ_l0ohKo0004
oookJP03oolg0?oonf[ooo]Z00Kooo]Z00?oom`0oookJ_oonfX01?oonfX00om9o`3ooo]ZoookJP03
oookJP;ooj8000Good`0oookJ_oonf[ooo]Zo`3oD@05oookJP;o0:Oo3?oonfX00ooL0?oooo]Zoook
JP0LoookJP03o`3omooonf[ooo]Z017ooo]Z0_oo;00CoookJP;o03Oo3OoonfX00ol0okKooo]Zoook
JP0<oookJPCo0000<ooonfX2o`d0oa[ooo]Z0_n00?l3oookJP;o/_l05_oonfX2o`0/o`Wooo]Z0_l0
nol6oookJP;oo`2Z00?ooc00ooon0?oooP000_m^o`03oookJP;olP3o0_oonfX2ool0>`cooo]Z0_l0
Col3oookJP;oo`2a0_oonfX2oonk00Oooo]Z0_oo03=8oookJP00=?oonfX2oong00gooo]Z0_l0D_l6
oookJP;o0?l^2?oonfX2ooon00?ooo]Z00GoEol0oookJ_oonf[ooo]ZohKo0003oookJP;oocL01ooo
nfX2oooL00Kooo]Z0_m9o`000ooo:03ooo]ZoookJP02oookJP03oonR0?oo:03ooo]Z00[oobP01Ooo
0007oookJP03om`0oooo:03ooo]Z01cooo]Z00?o0?ogoookJ_oonfX02?oonfX5ool000Cooo]Z2Ooo
:00=oookJPGoobP01?oo0005oookJP;oogT03_oonfX3ool000OoobP00ooo0003oookJP03ool00?oo
:03oo`0000Goo`001?oo:0000oooN@3ooo]ZoookJP0AoookJP[oobP05ooonfX8ool001;ooo]Z1_oo
0009oookJPGoo`004ooo:002oookJPCoobP01_oonfX00ol0Cooooo]ZoolX000:oolX00Cooo]Z0_oo
03<ToookJP;oo`23EOoonfX2oong00kooo]Z0_l0D_l5oookJP;o0?l^2?oonfX2ooon00Cooo]Z00Co
Eol0oookJ_oonf[oQ_l01?oonfX2oolg00Oooo]Z0_oog005oookJP;oBOl01OoonfX00oooXP3ood`0
oookJP02oookJP;o0?mA1OoonfX00ol0Yooooo]ZoookJP0:oookJP;og03o7OoonfX2o`3oma?ooo]Z
00?oob`0oookJ_oonfX04_oonfX00ol0=ooooo]ZoookJP0<oookJP03o`3o]_oonf[ooo]Z00gooo]Z
1?l0000`oookJP?o3@3o6_oonfX2oh00o`?ooo]Z0_nbo`0FoookJP;o02co2OoonfX2o`3ko`Kooo]Z
0_oo0:X00ooo<03oooh0ooon0002ofko00?ooo]Z0_ob0?l3oookJP03ool0>ooonf[ooo]Z00_ooo]Z
00Co04oooookJ_oonf[ooo]Z0_oo0;43oookJP03oonk0?oonf[ooo]Z00Gooo]Z0_oo03<ToookJP;o
o`239?oonfX003;ooo]Z0_oo]`0>oookJP03o`1Boooonf[ooo]Z00Gooo]Z00?o0?l^oookJ_oonfX0
1ooonfX01?oooP3ooo]ZoookJ_oonfX2oeOo00;ooo]Z0_n6o`03oookJP03oolg0?oonf[ooo]Z00Ko
oo]Z00?oom`0oookJ_oonfX01?oonfX2odWo0005oookJ_oo:03oobP0oolX0?oonfX00_ooXP000ooo
:03ooo]ZoolX0007oolX00;o0:Oo0ooo0009oookJP03om`0oooonf[ooo]Z00Oooo]Z00?oo`00oook
J_oonfX04_oonfX00ol0ooOooo]ZoookJP08oookJPKoo`000ooonfX7oolX00oooo]Z0ooo:008ool0
00?ooo]Z0_ooN@0>oookJP;oo`000_l00005oolX00?ooo]Z00?oo`00oookJ_oonfX00_oonfX7ool0
0004oookJ_oo:03oobP0oolX01?ooo]Z0ooo0007oolX01Cooo]Z3?oo000>oookJP[oo`002OoonfX0
0ooo003ooo]Zool00003ool0017oobP01?oonfX3oolX00Gooo]Z00?o04oooolX0?oo:0002ooo:004
oookJP03ool0<ooonf[ooo]Z02;ooo]Z0_oo08=FoookJP03oong0?oonf[ooo]Z00gooo]Z00?o05;o
oookJ_oonfX01?oonfX00ol0obkooo]ZoookJP07oookJP03ooon0?oonf[ooo]Z00;ooo]Z0_mGo`00
0ooonf[oQ_l0ohKo0004oookJP03oolg0?oonf[ooo]Z00Kooo]Z00?oom`0oookJ_oonfX01?oonfX0
0om9o`3ooo]ZoookJP03oookJP;ooj8000Good`0oookJ_oonf[ooo]Zo`3oD@05oookJP;o0:Oo3?oo
nfX00ooL0?oooo]ZoookJP0LoookJP03o`3omooonf[ooo]Z01;ooo]Z00?oob`0oookJ_oonfX04_oo
nfX00ol0=ooooo]ZoookJP0<oookJP03o`3o]_oonf[ooo]Z00kooo]Z1?l0000]oookJP?o3@3o6ooo
nfX2oh00o`?ooo]Z0_nbo`0FoookJP;o02co2_oonfX00ol0nooooo]ZoookJP04oookJP;oo`2Z00?o
oc00ooon0?oooP000_m^o`03oookJP;olP3o0ooonfX2ool0>`cooo]Z0_l0Col2oookJP;oo`2a0ooo
nfX2oonk00Kooo]Z0_oo03<ToookJP;oo`239_oonfX0037ooo]Z00?ookL0oookJ_oonfX03?oonfX2
o`1Bo`Kooo]Z0_l0obh8oookJP;oooh00ooonfX00omGo`3ooo]ZoookJP02ohKo00?ooo]Z0_oo=`07
oookJP;oom`01_oonfX00om9o`3ooo]ZoookJP04oolX0004oonR0?oo:03ooo]ZoookJPKoobP00_oo
nfX00ol0Yoooo`00ool0000:oookJP;og03o2_oonfX00ooo003ooo]ZoookJP0@oookJP;o0?og2_oo
nfX9ool000KoobP04?oonfX2oolX00Soo`001?oonfX00oooN@3ooo]ZoookJP0>oookJP?oo`0000?o
0000oolX0?oo:0002ooonfX5ool000Cooo]Z00?oobP0oookJ_oonfX02ooonfX:ool000KoobP04?oo
nfX@ool000cooo]Z3?oo000=oookJP;oo`000_oo0:X?oolX00Kooo]Z00?oobP0oookJ_oonfX04Ooo
:003oookJP;oo`0c8ooonfX2ool0PeKooo]Z0_oo]`0>oookJP;o05;o1OoonfX2o`3o;PSooo]Z0_oo
oP04oookJP04oeOo0?oonf[oQ_l0ohKo00Cooo]Z0_oo=`07oookJP;oom`01OoonfX2odWo00Gooo]Z
00?ooj80oom<0?oonfX00_oonfX2o`3oD@Gooo]Z00?o0:OooookJ_oonfX02_oonfX2om`0oagooo]Z
0_l0ooL<oookJP;o0>Go1_oonfX00ooo;03ooo]ZoookJP0BoookJP03o`0goooonf[ooo]Z00cooo]Z
00?o0?nfoookJ_oonfX03ooonfX4o`0002[ooo]Z0ol=0?lKoookJP?oP03o0ooonfX2ok;o01Kooo]Z
0_l0;?lAoookJP;oo`2Z00?ooo]Zooon0?oooP000_m^o`04oookJP04oo80oooonf[ooo]ZoookJP;o
o`0k3?oonfX2o`1?o`;ooo]Z0_oo0;43oookJP;ook/01_oonfX2ool0<bCooo]Z0_oo08<XoookJP00
;ooonfX2oong00kooo]Z00?o05;ooookJ_oonfX01OoonfX00ol0obkooo]ZoookJP07oookJP04ooon
0?oonf[ooo]ZoookJP;oEol00_oonfX00on6o`3ooo]ZoookJP02oookJP03oolg0?oonf[ooo]Z00Ko
oo]Z00?oom`0oookJ_oonfX01?oonfX2odWo00;ooo]Z0ooo:002oonR00;oobP000?ooo]ZoolX0?oo
:0000_oo:003oookJP;o0:Oo3?oonfX00ooL0?oooo]ZoookJP09oookJP?oo`004?oonfX00ol0ooOo
oo]ZoookJP09oookJP[oo`000ooo:00@oookJP04ool00?l0=oooobP0oookJPOoo`001OoonfX00ol0
okKooo]ZoookJP0>oookJPKoo`0000?o0000oookJ_oonfX02_oonfX2ool0013ooo]Z3Ooo0002oook
JPCoobP03_oonfXBool000gooo]Z2ooo000:oookJPGoobP000?oo`2Zooon0?oooP003Ooo:008oook
JQ?oobP00_oonfX2ool0<b?ooo]Z0_oo08=GoookJP03oong0?oonf[ooo]Z00gooo]Z00?o05;ooook
J_oonfX01?oonfX00ol0obkooo]ZoookJP07oookJP03ooon0?oonf[ooo]Z00;ooo]Z0_mGo`000ooo
nf[oQ_l0oookJP04oookJP03oolg0?oonf[ooo]Z00Kooo]Z00?oom`0oookJ_oonfX01?oonfX00om9
o`3ooo]ZoookJP03oookJP;ooj8000Good`0oookJ_oonf[ooo]Zo`3oD@05oookJP;o0:Oo3?oonfX0
0ooL0?oooo]ZoookJP0LoookJP03o`3omooonf[ooo]Z00_ooo]Z00?o0>GooookJ_oonfX01OoonfX0
0ooo;03ooo]ZoookJP0BoookJP05o`0goooonf[ooo]ZoookJ_oob@002_oonfX00ol0okKooo]Zoook
JP0@oookJPCo0000:OoonfX00ol=0?oooo]ZoookJP0JoookJP;oP03o1?oonfX2ok;o01Kooo]Z0_l0
;?lBoookJP06ool0Z_oonf[oooh0ooon0?oonf[oK_l01?oonfX2oo80o`;ooo]Z0_oo03/<oookJP;o
04oo0_oonfX2ool0/@?ooo]Z0_oo^`06oookJP;oo`0c9?oonfX2ool0Pb[ooo]Z000^oookJP03oong
0?oonf[ooo]Z00cooo]Z0_l0D_l6oookJP;o0?l^2?oonfX2ooon00?ooo]Z00?oEol0oookJ_oonfX0
0_n6o`03oookJP;oocL01ooonfX2oolX00Kooo]Z00CoBOl0oookJ_oonf[ooo]Z0ooo:0000oooXP3o
obP0oolX0004oolX00Gooo]Z00?o0:OooookJ_oonfX02_oonfX2om`0o`_ooo]Z1_oo000<oookJP;o
0?og3?oonfX;ool001;ooo]Z00?o03OooookJ_oonfX01_oo0006oookJP03o`3o]_oonf[ooo]Z00oo
oo]Z1ooo000<oookJP03ool00?oonf[ooo]Z00oooo]Z3?oo0003oookJP?oobP03ooonfXAool000oo
oo]Z2Ooo0009oookJPGoobP00oooN@0>oolX00Wooo]Z4_oo:0000ooonf[oo`0cool0<`0SoookJP;o
o`231?oonfX4ooo904oooo]Z0_oo]`0>oookJP;o05;o1OoonfX2o`3o;PSooo]Z0_oooP04oookJP04
oeOo0?oonf[oQ_l0ohKo00Cooo]Z0_oo=`07oookJP;oom`01OoonfX2odWo00Gooo]Z00?ooj80oom<
0?ooC0000_oonfX2o`3oD@Gooo]Z00?o0:OooookJ_oonfX02_oonfX2om`0o`oooo]Z0_ooR@0<oook
JP;o0?og3OoonfX00ol0iOoooo]ZoookJP05oookJP03ool/0?oonf[ooo]Z01;ooo]Z00Go03Oooook
J_oonf[ooo]Zooo9000:oookJP03o`3o]_oonf[ooo]Z017ooo]Z1?l00015oookJP03oh00oooonf[o
oo]Z00?ooo]Z00?o/_l0oookJ_oonfX05?oonfX2o`0/oa;ooo]Z0_oo0:X2ooon0003oookJ_m^o`3o
K_l000?ooo]Z0_ob0?l2oookJP;oo`0k3?oonfX2o`1?o`;ooo]Z0_oo0;43oookJP;ook/01ooonfX0
0ooo03?ooo]ZoookJP0RoookJP;oo`23;?oonfX002cooo]Z0_oo]`0>oookJP03o`1Boooonf[ooo]Z
00Gooo]Z00?o0?l^oookJ_oonfX01ooonfX01?oooP3ooo]ZoookJ_oonfX2oeOo00;ooo]Z00?oQ_l0
oookJ_oonfX00_oonfX00ooo=`3ooo]ZoookJP06oookJP03oolX0?oonf[ooo]Z00Cooo]Z0_m9o`03
oookJP;oobP00_ooXP07oolX00?ooo]Z00?o047oo`2WoooonfX02ooonfX00ooL0?oooo]ZoookJP0:
oookJPKoo`002ooonfX2o`3om`gooo]Z1_oo00000ooonf[oob`0ool00004ool0013ooo]Z00?o03Oo
ool00?oo00001Ooo0007oookJP03o`3o]_oo003ooo]Z013ooo]Z2?oo000NoookJPWoo`001_oonfX0
0ooo:03ooo]ZoookJP0?oookJPkoo`004OoonfX7ool000_ooo]Z00?oobP0oomi0?ooN@000oooN@00
1?oo:03oK_l0oolX0?oo:002oookJPWoobP02OoonfX2o`1?oa3oobP00_oo03<SoookJP;oo`231?oo
nfX6ooo904gooo]Z0_oo]`0?oookJP03o`1Boooonf[ooo]Z00Cooo]Z00?o0?l^oookJ_oonfX01ooo
nfX00ooooP3ooo]ZoookJP02oookJP;oEol000?ooo]ZohKo0?oonfX00ooonfX2oolg00Sooo]Z00?o
om`0oookJ_oonfX01?oonfX00om9o`3ooo]ZoookJP03oookJP;ooj8000Good`0oookJ_oonf[ooo]Z
o`3oD@05oookJP03o`11ool0Yooooo]Z00_ooo]Z00?og03ooookJ_oonfX03_oonfX00oooR@3ooo]Z
oookJP0;oookJP03o`3omooonf[ooo]Z00_ooo]Z0_l0iOl6oookJP;oob`05?oonfX01Ol0=ooooo]Z
oookJ_oonf[oolT000[ooo]Z00?o0?nfoookJ_oonfX04_oonfX4o`00067ooo]Z00?o02cooookJ_oo
nfX04?oonfX2ool0ZP;oooh000?ooo]Zofko0?m^o`000ooonfX2oo80o`;ooo]Z0_oo03/<oookJP;o
04oo0_oonfX2ool0/@Cooo]Z00?ook/0oookJ_oonfX01OoonfX2ool0<b?ooo]Z0_oo08<^oookJP00
:ooonfX00ooo]`3ooo]ZoookJP0<oookJP;o05;o1_oonfX2o`3o;PSooo]Z0_oooP03oookJP03oeOo
0?oonf[ooo]Z00;oQ_l00ooonfX2oolg0003oookJ_oo:03ooo]Z00Cooo]Z0_oo:006oookJP03odWo
0?oonf[ooo]Z00?ooo]Z0_ooXP07oolX00Cooo]Z0_l0Yol;oookJP;og03o3?oonfX8ool000Wooo]Z
00?o0?ogoookJ_oonfX03?oonfX5ool000;ooo]Z00?oob`0ool00?oo00001Ooo000=oookJP03oolX
0?l0=oooo`0000Goo`002?oonfX01?l0okKooo]Zool00?oo000?oookJPSoo`007ooonfX8ool001Wo
oo]Z1ooo00000ooonf[oo`00ool00003ool001?ooo]Z1Ooo000:oookJPOoogT00_m^o`02oolX00;o
oo]Z00GolP3ooolX0?oo:03ooo]Zool0>`04oolX00Sooo]Z0_l0Col2oookJPSoobP00ooonfX4oolX
0003ool0<ooonf[ooo]Z02;ooo]Z00?oo`23oookJ_oonfX01?oonfX6ooo904cooo]Z00?ookL0oook
J_oonfX03OoonfX2o`1Bo`Gooo]Z0_l0obh8oookJP;oooh01?oonfX01?mGo`3ooo]ZohKo0?n6o`04
oookJP03oolg0?oonf[ooo]Z00Kooo]Z0_oog005oookJP;oBOl01?oonfX2oonR00;ood`00_oonfX2
o`3oD@Gooo]Z0_l0Yol;oookJP;og03o3ooonfX2oon900gooo]Z00?o0?ogoookJ_oonfX02ooonfX0
0ol0iOoooo]ZoookJP05oookJP03ool/0?oonf[ooo]Z01?ooo]Z00Go03OooookJ_oonf[ooo]Zooo9
000:oookJP03o`3o]_oonf[ooo]Z01?ooo]Z1?l0001boookJP;oo`2Z0_oooP000ooonf[oK_l0ofko
0003oookJP;olP3o0ooonfX00ooo03_ooo]ZoookJP0:oookJP;o04oo0_oonfX2ool0/@Cooo]Z0_oo
^`06oookJP;oo`0c9?oonfX00ooo08?ooo]ZoookJP08oookJP;o0?nH9?oonfX002[ooo]Z00?ookL0
oookJ_oonfX03?oonfX00ol0D_oooo]ZoookJP05oookJP03o`3o;_oonf[ooo]Z00Kooo]Z0_oooP03
oookJP;oEol000?ooo]ZohKo0?n6o`001?oonfX01Ooo=`3ooo]ZoookJ_oonf[oobP000Cooo]Z00?o
obP0oookJ_oonfX01?oonfX2odWo00Gooo]Z00?ooj80oolX0?oo:0001?oo:005oookJP03o`11ool0
Yooooo]Z00_ooo]Z00?og03ooookJ_oonfX02ooonfX:ool000Kooo]Z0_l0ooL>oookJPCoo`000ooo
nfX00ooo;03oo`00ool00007ool000cooo]Z00?o03Ooool00?oo00001?oo0008oookJP03o`3o]_oo
nf[oo`0000?oo`003_oonfX7ool00003o`000?oonf[ooo]Z01kooo]Z1_oo000KoookJPGoo`000_oo
nfX4ool001Cooo]Z1?oo0007oookJPWoogT00_m^o`03oolX0003oookJ_ob0?oolP3o00;ooo]Z0_oo
03/01?oonf[oobP0oolX0?oo:008oookJP04o`1?oooonf[ooo]ZoookJPSoobP01?oonfX3oolX0003
ool0<ooonf[ooo]Z027ooo]Z0_oo08<8oookJPGoolT0BooonfX00ooo]`3ooo]ZoookJP0=oookJP03
o`1Boooonf[ooo]Z00Cooo]Z00?o0?l^oookJ_oonfX01_oonfX2ooon00Cooo]Z0_mGo`02ohKo00Co
oo]Z0_oo=`08oookJP03oooL0?oonf[ooo]Z00Cooo]Z00?oBOl0oookJ_oonfX00ooonfX00oooXP3o
oo]Zoom<0003oookJP03o`3oDOoonf[ooo]Z00Cooo]Z00?o0:OooookJ_oonfX02_oonfX00ooL0?oo
oo]ZoookJP0>oookJP03oon90?oonf[ooo]Z00_ooo]Z0_l0ooL=oookJP03o`3Uoooonf[ooo]Z00Co
oo]Z0_oo;0000ooonf[o02goo`0]o`0BoookJP05o`0goooonf[ooo]ZoookJ_oob@002_oonfX00ol0
okKooo]ZoookJP0DoookJPCo0000L?oonfX2ool0ZP;oooh000?ooc00ofko0?m^o`000ooonfX2oo80
o`?ooo]Z0_oo03/;oookJP;o04oo0_oonfX2ool0/@Cooo]Z0_oo^`06oookJP;oo`0c9?oonfX2ool0
P`Wooo]Z0_l0oiPVoookJP00=ooonfX2o`1Bo`Kooo]Z0_l0obh8oookJP03ooon0?oonf[ooo]Z00;o
oo]Z00CoEol0oookJ_oonf[oQ_l01?oonfX2oolg00?ooo]Z0ooo:002oookJP03oolX0?oonf[ooo]Z
00?ooo]Z0_m9o`05oookJP;ooj801Ooo:006oookJP;o0:Oo2ooonfX2om`0o`kooo]Z2?oo0007oook
JP03o`3omooonf[ooo]Z00gooo]Z0_oo0004oookJP;oob`02ooo0009oookJP;o03Oo2?oo0006oook
JP03o`3o]_oonf[oo`0000Goo`002ooonfX2oolX00Koo`000_l0000PoookJPCoo`007OoonfX4ool0
00?ooo]Z0ooo000EoookJP?oo`001_oonfX9oomi00;oK_l01?oo:002oo80o`;ooo]Z0_oo03/4oook
JP03oolX0?oonf[ooo]Z00Gooo]Z0_l0Col2oookJP;oobP00_oonfX2oolX0003oonk0?oo:03ooo]Z
00Gooo]Z00?oo`0coolX0?oonfX08_oonfX2ool0P`Wooo]Z00?o9_l0ooo90?oob@000ooob@1Ioook
JP;o05;o1OoonfX2o`3o;PSooo]Z00?oooh0oookJ_oonfX00ooonfX00omGo`3ooo]ZohKo0005oook
JP03oolg0?oonf[ooo]Z00Kooo]Z0_oog005oookJP;oBOl01?oonfX2oonR0004oookJ_ooC03ooo]Z
oookJP;o0?mA1OoonfX2o`2Wo`_ooo]Z0_oL0?l?oookJP;oohT03OoonfX00ol0ooOooo]ZoookJP0<
oookJP03o`3Uoooonf[ooo]Z00Cooo]Z00Coob`0oookJ_oonf[o02go4_oonfX2o`0go`;ooo]Z0_oo
b@0:oookJP03o`3o]_oonf[ooo]Z01Gooo]Z1?l0001^oookJP;oo`2Z0_oooP000ooo<03oK_l0ofko
0003oookJP;olP3o0ooonfX2ool0>`_ooo]Z0_l0Col2oookJP;oo`2a1?oonfX2oonk00Kooo]Z0_oo
03<ToookJP;oo`232OoonfX00olVo`3o0?nHoookJP0WoookJP00=_oonfX00ol0D_oooo]ZoookJP05
oookJP03o`3o;_oonf[ooo]Z00Kooo]Z0_oooP03oookJP;oobP000?ooo]ZohKo0?n6o`001?oonfX0
0ooo=`3ooo]ZoookJP02oookJPKoobP01OoonfX00om9o`3ooo]ZoookJP04oookJP03oonR0?oo:03o
obP000;oobP00_l0oe45oookJP03o`11ool0Yooooo]Z00_ooo]Z00?og03ooookJ_oonfX03OoonfX6
ool000Sooo]Z0_l0ooL>oookJP03o`3Uoooo003ooo]Z00Cooo]Z00?oob`0oookJ_oonfX02Ooo000:
oookJP03o`0goooo:03oobP000Woo`001?oonfX00ol0okKooo]ZoookJP07ool000[ooo]Z0ooo:004
ool000?o00008?oonfX3ool001kooo]Z0ooo0005oookJP03ool00?oonf[ooo]Z01Gooo]Z00?oo`00
oookJ_oonfX01OoonfX8oomi0003ofko0?ooN@3ooo]Z00;oobP00_ob0?l2oookJP;oo`0k3?oonfX2
o`1?o`;ooo]Z00?oo`2aoolX0?oonfX00ooonfX2oonk0003oolX0?oonf[ooo]Z00;ooo]Z0oooN@0S
oookJP;oo`232OoonfX01?lVo`3oolT0ooo90?oonfX4ooo905Oooo]Z0_l0D_l6oookJP03o`3o;_oo
nf[ooo]Z00Kooo]Z0_oooP04oookJP;oEol00_n6o`04oookJP;oocL02?oonfX00ooog03ooo]Zoook
JP04oookJP03odWo0?oonf[ooo]Z00?ooo]Z00Cooj80oookJ_ooC03ood`00_oonfX00ol0oe7ooo]Z
oookJP04oookJP03o`2Woooonf[ooo]Z00[ooo]Z00?og03ooookJ_oonfX03_oonfX00oooR@3ooo]Z
oookJP0;oookJP;o0?og3OoonfX2o`3Uo`Gooo]Z0_oo;002oookJP03o`0]oooonf[ooo]Z013ooo]Z
00Go03OooookJ_oonf[ooo]Zooo9000:oookJP;o0?nf6?oonfX4o`0006cooo]Z0_oo0:X2ooon0003
ool`0?m^o`3oK_l000?ooo]Z0_ob0?l3oookJP;oo`0k2ooonfX2o`1?o`;ooo]Z0_oo0;44oookJP;o
ok/01_oonfX2ool0<bCooo]Z0_oo08<9oookJP03obKo0?l0oiSo0?nH02Wooo]Z000eoookJP03o`1B
oooonf[ooo]Z00Cooo]Z0_l0obh8oookJP03ooon0?oonf[ooo]Z00;ooo]Z00CoobP0oookJ_oonf[o
Q_l01?oonfX2oolg00Cooo]Z1_oo:004oookJP;oBOl01OoonfX2oonR00?oobP000?ooo]Zo`3oDOoo
nfX01OoonfX2o`2Wo`_ooo]Z0_oL0?l?oookJPGoo`002OoonfX00ol0ooOooo]ZoookJP0=oookJP03
o`3Uoooonf[ooo]Z00Cooo]Z00?oob`0oookJ_oonfX01ooo000<oookJP03o`0goooo:03oobP000So
o`001OoonfX00ol0okKooo]ZoookJP09ool000Sooo]Z1_oo:0000ooo003o0000o`000002o`00027o
oo]Z00?oo`00oookJ_oonfX07_oonfX00ooo003ooo]ZoookJP0ToookJP03ool0Z_ooN@3oogT000?o
ogT00_m^o`000oooN@3ooo]ZoookJP02oo80o`04oookJ_oo003oo`00ool000cooo]Z0_l0Col2oook
JP;oo`2a1?oonfX2oonk0003oookJ_oo:03oogT000GoogT08ooonfX2ool0P`[ooo]Z0_oob@03oook
JP?oolT0EooonfX00ol0D_oooo]ZoookJP04oookJP;o0?l^2?oonfX00ooooP3ooo]ZoookJP03oook
JP03oeOo0?oonf[oQ_l000Gooo]Z00?oocL0oookJ_oonfX01_oonfX2oooL00Gooo]Z0_m9o`04oook
JP;ooj8000Cooo]Zoom<0?oonf[ooo]Z0_l0oe45oookJP;o0:Oo2ooonfX2om`0oa3ooo]Z00?oohT0
oookJ_oonfX02ooonfX00ol0ooOooo]ZoookJP0<oookJP03o`3Uoooonf[ooo]Z00Cooo]Z00Goob`0
oookJ_oonf[ooo]Zo`0]o`0AoookJP;o03Oo0ooonfX00ooo@`3ooo]ZoookJP08oookJP03o`3o]_oo
nf[ooo]Z01Sooo]Z1?l0001YoookJP?oo`2Z0_oooP000ooo<03oK_l0ofko0003oookJP;olP3o0ooo
nfX2ool0>`cooo]Z00?o04oooookJ_oonfX00_oo0;44oookJP;ook/01_oonfX2ool0<bCooo]Z0_oo
08<9oookJP03obKo0?l0oiSo0?nH02_ooo]Z000coookJP;o05;o1_oonfX00ol0obkooo]ZoookJP06
oookJP;oooh00ooonfX2oolX0003oookJ_n6o`3oQ_l000Cooo]Z00?oocL0oookJ_oonfX00ooonfX8
oolX00;ooo]Z00?oBOl0oookJ_oonfX01?oonfX00oooXP3ood`0oolX0003oookJP03o`3oDOoonf[o
oo]Z00?ooo]Z00?o047oo`2WoooonfX02ooonfX00ooL0?oooo]ZoookJP0>oookJPCoo`002_oonfX0
0ol0ooOooo]ZoookJP0=oookJP03o`3Uoooonf[ooo]Z00?ooo]Z0_oo;002oookJPKoo`003OoonfX0
0ol0=ooooo]ZoolX0007ool00003oolX0?oonf[ooo]Z00?ooo]Z00Co0?nfoookJ_oonf[ooo]Z1ooo
000:oookJPOoobP01?l0001WoookJP;oo`2Z00Cooc00ooon0?ooN@3oogT00_m^o`02oomi0003oook
J_ob0?oolP3o00Coo`003?oonfX2o`1?o`;ooo]Z0_oo0;44oookJP;ook/02OooN@0RoookJP;oo`23
2_oonfX2ooo900Kooo]Z00?oolT0oookJ_oonfX0E?oonfX2o`1Bo`Kooo]Z00?o0?l^oookJ_oonfX0
1_oonfX2ooon00Cooo]Z0_mGo`02ohKo00Cooo]Z0_oo=`08oookJP03oooL0?oonf[ooo]Z00Cooo]Z
00?oBOl0oookJ_oonfX00ooonfX01?ooXP3ooo]Zoom<0?ooC002oookJP03o`3oDOoonf[ooo]Z00Co
oo]Z00?o0:OooookJ_oonfX02_oonfX00ooL0?oooo]ZoookJP0>oookJP;oohT03OoonfX00ol0ooOo
oo]ZoookJP0<oookJP03o`3Uoooonf[ooo]Z00?ooo]Z0_oo;003oookJP03o`0]oooonf[ooo]Z00oo
oo]Z00?o03OooookJ_oonfX00_oonfX00ooo@`3ooo]ZoookJP08oookJP03o`3o]_oonf[ooo]Z01Wo
oo]Z1?l0001WoookJP;oo`2Z00Cooo]Zooon0?oooP3ooc000_m^o`03oookJP;olP3o0_oonfX3ool0
>`cooo]Z0_l0Col00ooonf[oo`2aool0/@04oookJP;ook/01_oonfX2ool0<bCooo]Z0_oo08<:oook
JP;o0?nH;OoonfX003;ooo]Z00?o05;ooookJ_oonfX01?oonfX2o`3o;PSooo]Z00?oooh0oookJ_oo
nfX00_oonfX01?oo:03ooo]ZoookJ_n6o`04oookJP;oocL01OoonfX9oolX00;oBOl01OoonfX2oonR
0004oom<0?oonf[ooo]ZoookJP;o0?mA1OoonfX2o`2Wo`_ooo]Z0_oL0?l@oookJP;oo`003?oonfX0
0ol0ooOooo]ZoookJP0=oookJP03o`3Uoooonf[ooo]Z00?ooo]Z00Coob`0oookJ_oonf[ooo]Z1?oo
000?oookJP04o`0goooonf[oobP0oolX00Goo`0000?oobP0oookJ_oonfX01?oonfX01?l0okKooo]Z
oookJ_oonfX7ool000_ooo]Z2?oo:004o`0006Cooo]Z0_oo0:X00ooooP3oo`00ool00003ool000?o
ogT00_ob0?l5ool000cooo]Z00?o04oooookJ_oonfX00_oo0;44oookJP;ook/02_ooN@0QoookJP;o
o`232_oonfX2ooo905kooo]Z00?o05;ooookJ_oonfX01?oonfX2o`3o;PSooo]Z00?oooh0oookJ_oo
nfX00ooonfX00omGo`3ooo]ZohKo0004oookJP;oocL02?oonfX2oooL00Gooo]Z0_m9o`04oookJP;o
oj8000?ooo]Zoom<0?oonfX00_oonfX00ol0oe7ooo]ZoookJP03oookJP;o0:Oo2ooonfX2om`0oa3o
oo]Z00?oohT0oookJ_oonfX02ooonfX2o`3om`kooo]Z00?o0>GooookJ_oonfX00ooonfX00ooo;03o
oo]ZoookJP02oookJP03o`0]oooonf[ooo]Z00oooo]Z00?o03OooookJ_oonfX00_oonfX00ooo@`3o
oo]ZoookJP08oookJP03o`3o]_oonf[ooo]Z01[ooo]Z1Ol0001ToookJP;oo`2Z0ooooP000ooonf[o
K_l0ofko0003oookJP;olP3o0_oonfX2ool0>`gooo]Z0_l0Col00ooonf[oo`2aool0/@04oookJP;o
ok/01_oonfX2ool0<bCooo]Z0_oo08<:oookJP;o0?nH;ooonfX0033ooo]Z0_l0D_l6oookJP03o`3o
;_oonf[ooo]Z00Kooo]Z0_oooP03oookJP;oobP00_oonfX00on6o`3ooo]ZoookJP02oookJP03oolg
0?oonf[ooo]Z00Gooo]Z2?oo:0000om9o`3ooo]ZoookJP03oookJP;ooj800_ooC003oookJP03o`3o
DOoonf[ooo]Z00?ooo]Z00?o047oo`2WoooonfX02ooonfX00ooL0?oooo]ZoookJP04oookJP03ool0
0?oonf[ooo]Z00;ooo]Z0_oo0003oookJP03oon90?oo003ooo]Z00cooo]Z00?o0?ogoookJ_oonfX0
3?oonfX2o`3Uo`Gooo]Z00Coob`0oookJ_oonf[ooo]Z0ooo000?oookJP;o03Oo00?ooo]ZoolX0?oo
:0001?oo00000ooo:03ooo]ZoookJP05oookJP04o`3o]_oonf[ooo]ZoookJPKoo`003?oonfX7oolX
00;oo`000ol0001PoookJQKoo`002ooonfX2o`1?o`?oo`2a1OoonfX00ooo^`3oogT0oomi0009oomi
023ooo]Z0_oo08<:oookJP03obKo0?oob@3ooo]Z05gooo]Z0_l0D_l6oookJP03o`3o;_oonf[ooo]Z
00Kooo]Z0_oooP04oookJP;oEol000?ooo]ZohKo0?oonfX00ooonfX00ooo=`3ooo]ZoookJP07oook
JP03oooL0?oonf[ooo]Z00Cooo]Z00?oBOl0oookJ_oonfX00_oonfX2oonR0003oookJ_ooC03ood`0
00;ooo]Z0_l0oe45oookJP03o`2Wool0@Ooooo]Z00[ooo]Z00?og03ooookJ_oonfX02OoonfX2oom6
00?ooo]Z0_ooR@0=oookJP03o`3omooonf[ooo]Z00cooo]Z0_l0iOl5oookJP03ool/0?oonf[ooo]Z
00;ooo]Z00?o02gooookJ_oonfX03_oonfX2o`0go`?ooo]Z00?oolT0oom30?oonfX02OoonfX00ol0
okKooo]ZoookJP0FoookJP03ojGo0?oonf[ooo]Z00;ooo]Z1?l0001SoookJP;oo`2Z0_oooP001?oo
<03oK_l0ofko0?m^o`03oookJP;olP3o0_oonfX2ool0>`gooo]Z0_l0Col00ooonf[oo`2aool0/@05
oookJP03oonk0?oonf[ooo]Z00Cooo]Z0_oo03<ToookJP;oo`232_oonfX00olVo`3o0?nHoookJP0`
oookJP00;ooonfX00ol0D_oooo]ZoookJP05oookJP03o`3o;_oonf[ooo]Z00Gooo]Z00?oobP0ooon
0?oonfX00ooonfX00ooo:03ooo]ZoookJP02ohKo00?ooo]Z0_oo=`07oookJPKoobP00_oonfX00om9
o`3ooo]ZoookJP03oookJP03oonR0?oonf[ood`000?ooo]Z0_l0oe45oookJP;o0:Oo2ooonfX2om`0
o`Oooo]Z00Goo`00oookJ_oonf[ooo]Zool00004oookJP03oon90?oonf[ooo]Z00_ooo]Z0_l0ooL8
oookJP03oolX0?oonf[ooo]Z00?ooo]Z00?o0>GooookJ_oonfX01?oonfX01Ooo;03ooo]ZoookJ_l0
;Oooo`00017ooo]Z00?o03OooookJ_oonfX00ooo:003ool000Sooo]Z00?o0?nfoookJ_oonfX00_oo
nfX4ool000kooo]Z1_oo:0000ooo003ooo]Zo`000003o`0005cooo]Z6Ooo000:oookJP;o04oo0_oo
0;46oookJP;ook/00_oonfX9oomi01oooo]Z0_oo08<:oookJP03obKo0?oob@3oolT005kooo]Z00?o
05;ooookJ_oonfX01OoonfX00ol0obkooo]ZoookJP06oookJP03ooon0?oonf[ooo]Z00;ooo]Z0_mG
o`000ooonf[oQ_l0ohKo0003oookJP;oocL02?oonfX2oooL00Gooo]Z0_m9o`04oookJP04oonR0?oo
nf[ooo]Zoom<00?ooo]Z00?o0?mAoookJ_oonfX00ooonfX2o`2Wo`_ooo]Z0_oL0?l;oookJP03oom6
0?oonf[ooo]Z00;ooo]Z00?oohT0oookJ_oonfX03?oonfX00ol0ooOooo]ZoookJP0<oookJP03o`3U
oooonf[ooo]Z00Cooo]Z00Coob`0oookJ_oonf[ooo]Z0_l0;Ol@oookJP03o`0goooonf[ooo]Z00;o
oo]Z00?oolT0oom30?oonfX02OoonfX00ol0okKooo]ZoookJP04oookJP03ol00oooonf[ooo]Z013o
oo]Z00?oYOl0oookJ_oonfX00_oonfX4o`00067ooo]Z0_oo0:X2ooon0003ool`0?m^o`3oK_l000Co
oo]Z0_ob0?l01?oonf[oo`0kool0>ooo03/=oookJP;o04oo00?ooo]Zool0/Ooo0;401OoonfX2oonk
00Gooo]Z0_oo03<ToookJP;oo`232_oonfX00olVo`3o0?nHo`3oV00boookJP00;OoonfX2o`1Bo`Ko
oo]Z0_l0obh7oookJP;oooh00ooonfX2oolX00;ooo]Z00?oQ_l0oookJ_oonfX00_oonfX00ooo=`3o
oo]ZoookJP06oookJPGoobP00_oonfX2odWo00Cooo]Z0_ooXP000ooonf[ood`0oookJP02oookJP03
o`3oDOoonf[ooo]Z00?ooo]Z00?oobP0o`2WoooonfX02_oonfX2om`0o`Sooo]Z1Ooo0004oookJP03
oon90?oonf[ooo]Z00_ooo]Z00?o0?ogoookJ_oonfX02?oonfX00ooo:03ooo]ZoookJP02oookJP03
o`3Uoooonf[ooo]Z00?ooo]Z0_oo;002oookJP03o`0]oooonf[ooo]Z013ooo]Z00Co03OooookJ_oo
nf[ooo]Z0_oo:002ool000Wooo]Z00?o0?nfoookJ_oonfX00_oonfX4ool000oooo]Z1Ooo:0000ooo
003ooo]ZoookJP04o`0005Sooo]Z1?oo:00Hool000Sooo]Z0ol0Col2ool0/@Kooo]Z0_oo^`04oook
JPOoogT07ooonfX2ool0P`_ooo]Z00?o0?nHooo90?oob@003OoonfX2on3o04kooo]Z0_l0D_l6oook
JP;o0?l^1ooonfX2ooon00Cooo]Z00CoEol0oookJ_oonf[oQ_l01?oonfX00ooo=`3ooo]ZoookJP07
oookJP03oooL0?oonf[ooo]Z00Cooo]Z00?oBOl0oookJ_oonfX00_oonfX2oonR0003oookJ_ooC03o
od`000;ooo]Z0_l0oe45oookJP03o`2Wool0@Ooooo]Z00[ooo]Z00?og03ooookJ_oonfX02OoonfX2
oom600Cooo]Z00?oohT0oookJ_oonfX03?oonfX00ol0ooOooo]ZoookJP0<oookJP03o`3Uoooonf[o
oo]Z00?ooo]Z0_oo;003oookJP03o`0]oooonf[ooo]Z00oooo]Z00Co03OooookJ_oonf[ooo]Z0_oo
b@000ooo@`3ooo]ZoookJP08oookJP03o`3o]_oonf[ooo]Z00Cooo]Z00?o`03ooookJ_oonfX04?oo
nfX00onUo`3ooo]ZoookJP03oookJPCo0000G_oonfX2ool0ZP?oooh000?ooc00ofko0?m^o`001?oo
nfX2oo80o`03oookJ_oo03_oo`0k00gooo]Z0ol0Col00ooonf[oo`2aool0/@05oookJP;ook/01Ooo
nfX2ool0<bCooo]Z0_oo08<:oookJP03obKo0?l0oiSo0?nH00kooo]Z0_oPo`0ToookJP00;?oonfX0
0ol0D_oooo]ZoookJP05oookJP03o`3o;_oonf[ooo]Z00Kooo]Z00Koooh0oolX0?oo:03oobP0oook
J_oo:002oookJP;oQ_l00ooonfX2oolg00Sooo]Z1?oo:003oookJP03odWo0?oonf[ooo]Z00?ooo]Z
00Cooj80oookJ_ooC03ood`00ooonfX00ol0oe7ooo]ZoookJP03oookJP;o0:Oo2ooonfX00ooL0?oo
oo]ZoookJP07oookJPGoo`000ooonfX2oon900gooo]Z00?o0?ogoookJ_oonfX02?oonfX3oolX00;o
oo]Z00?o0>GooookJ_oonfX00ooonfX01Ooo;03ooo]ZoookJ_oonf[o02go017ooo]Z00?oobP0o`0g
oooonfX00_oonfX00ooo:03ood<0ool0000:oookJP03o`3o]_oo:03ooo]Z00?ooo]Z0_oo000@oook
JPGoobP000Coo`00oookJ_oonf[ooo]Z1?l0001EoookJPSoobP05Ooo0008oookJP;o04oo00?ooo]Z
ool0/Ooo0;401_oonfX2oonk00Gooo]Z1oooN@0NoookJP;oo`232ooonfX2o`3oV0kooo]Z0_oPo`1?
oookJP03o`1Boooonf[ooo]Z00Gooo]Z00?o0?l^oookJ_oonfX01_oonfX00ooooP3ooo]ZoookJP02
oookJP;oEol000?ooo]ZohKo0?n6o`000ooonfX2oolg00Sooo]Z0_oog005oookJP;oBOl01?oonfX0
1?ooXP3ooo]ZoookJ_ooC003oookJP03o`3oDOoonf[ooo]Z00?ooo]Z0_l0Yol<oookJP03om`0oooo
nf[ooo]Z00Wooo]Z00?oodH0oookJ_oonfX00_oonfX2oon900gooo]Z0_l0ooL>oookJP03o`3Uoooo
nf[ooo]Z00?ooo]Z00?oob`0oookJ_oonfX00_oonfX00ol0;Ooooo]ZoookJP0?oookJP05o`0goooo
nf[ooo]ZoookJ_oob@000_oo@`0:oookJP03o`3o]_oonf[ooo]Z00Cooo]Z00?o`03ooookJ_oonfX0
4OoonfX00onUo`3ooo]ZoookJP03oookJPCo0000G?oonfX2ool0ZP;oooh000Cooc00ofko0?m^o`3o
K_l01?oonfX2oo80o`;ooo]Z00?oo`0koookJ_oonfX02ooonfX2o`1?o`;ooo]Z0_oo0;45oookJP;o
ok/01OoonfX2ool0<bCooo]Z0_oo08<:oookJP03obKo0?l0oiSo0?nH00kooo]Z0_oPo`0VoookJP00
:ooonfX00ol0D_oooo]ZoookJP04oookJP;o0?l^1ooonfX2ooon00GoobP00_oonfX00on6o`3ooo]Z
oookJP02oookJP03oolg0?oonf[ooo]Z00Oooo]Z0_oo:004oookJP;oBOl01OoonfX00oooXP3ooo]Z
oom<0003oookJP;o0?mA1OoonfX00ol0Yooooo]ZoookJP09oookJP;og03o2OoonfX6ool000;ooo]Z
00?oohT0oookJ_oonfX03?oonfX00ol0ooOooo]ZoookJP08oookJPKoobP01OoonfX01Ooo;03ooo]Z
oookJ_oonf[o02go01;ooo]Z00Ko03OooookJ_oonf[ooo]ZoolX0?oo@`0;oookJP03o`3o]_oonf[o
obP000?ooo]Z00?oo`00oookJ_oonfX03OoonfX2oolX0003oookJ_oo:03oobP000;oobP000?oo`00
oookJ_oonfX00_oonfX4o`0005Gooo]Z1ooo:0000ooooP3oo`00ool0000;ool000;ooo]Z1Ooo0006
oookJP?o04oo0ooo0003oookJPGoo`001OoonfX2oomi00;ooo]Z1?ooN@0MoookJP;oo`232ooonfX2
o`3oV0kooo]Z0_oPo`1@oookJP03o`1Boooonf[ooo]Z00Cooo]Z0_l0obh7oookJP;oooh01?oonfX0
1?mGo`3ooo]ZoookJ_n6o`04oookJP03oolg0?oonf[ooo]Z00Oooo]Z00?oom`0oookJ_oonfX01?oo
nfX00om9o`3ooo]ZoookJP03oookJP04oonR0?oonf[ood`0oom<00;ooo]Z0_l0oe45oookJP03o`2W
ool0@Ooooo]Z00[ooo]Z0_oL0?l:oookJP;oodH01?oonfX00oooR@3ooo]ZoookJP0<oookJP03o`3o
mooonf[ooo]Z00cooo]Z0_l0iOl5oookJP03ool/0?oonf[ooo]Z00;ooo]Z00?o02gooookJ_oonfX0
3ooonfX01_l0=ooooo]ZoookJ_oonf[oolT0oom300_ooo]Z00?o0?nfoookJ_oonfX01?oonfX00oo0
0?oooo]ZoookJP0BoookJP03ojGo0?oonf[ooo]Z00?ooo]Z1?l0001JoookJP;oo`2Z0_oooP000ooo
<03ooo]Zofko0005oookJP;olP3o4?oonfX2o`1?o`;ooo]Z0_oo0;45oookJP;ook/01OoonfX2ool0
<bCooo]Z0_oo08<:oookJP03obKo0?l0oiSo0?nH00kooo]Z0_oPo`0XoookJP00:_oonfX00ol0D_oo
oo]ZoookJP04oookJP03o`3o;_oonf[ooo]Z00Kooo]Z00?oooh0oookJ_oo:0001Ooo:0000ooonf[o
Q_l0oookJP02oookJP;oocL02?oonfX00ooog03oobP0oookJP04oookJP03odWo0?oonf[ooo]Z00?o
oo]Z0_ooXP02oom<00?ooo]Z00?o0?mAoookJ_oo:0000ooonfX00ooo:03o0:OooookJP0:oookJP03
om`0oooonf[ooo]Z00Sooo]Z2?oo00000oooR@3ooo]ZoookJP0<oookJP03o`3omooo003ooo]Z00So
oo]Z1ooo:004oookJP05ool/0?oonf[ooo]ZoookJ_l0;Ol04_oonfX01_l0=oooobP0oolX0?oob@3o
obP0oom300_ooo]Z00?o0?nfoookJ_oo:0000_oo:0000ooonf[oo`00oookJP0?oookJPKoobP000?o
o`00oookJ_oonfX00ooonfX4o`0005Kooo]Z0ooo:003ooon00;oobP02ooo0003oookJPCoo`001Ooo
nfX>ool000Gooo]Z00?oo`0coomi0?oonfX00ooonfX3oomi01gooo]Z00?oo`23oookJ_oonfX02Ooo
nfX2o`3oV0oooo]Z00?oh?l0oookJ_oonfX0CooonfX00ol0D_oooo]ZoookJP04oookJP03o`3o;_oo
nf[ooo]Z00Kooo]Z00?oooh0oookJ_oonfX00_oonfX2oeOo00;ooo]Z00CoQ_l0oookJ_oonf[ooo]Z
0_oo=`08oookJP;oom`01_oonfX00om9o`3ooo]ZoookJP02oookJP;ooj8000?ooo]Zoom<0?oonfX0
0_oonfX00ol0oe7ooo]ZoookJP04oookJP03o`2Woooonf[ooo]Z00[ooo]Z00?og03ooookJ_oonfX0
2OoonfX00oooAP3ooo]ZoookJP02oookJP;oohT03_oonfX00ol0ooOooo]ZoookJP0<oookJP03o`3U
oooonf[ooo]Z00Cooo]Z00Coob`0oookJ_oonf[ooo]Z0_l0;OlAoookJP06o`0goooonf[ooo]Zoook
J_oob@3ood<02ooonfX00ol0okKooo]ZoookJP04oookJP03ol00oooonf[ooo]Z01;ooo]Z00?oYOl0
oookJ_oonfX01?oonfX4o`0005Sooo]Z00Goo`2Zooon0?oooP3oooh0ool`0007oookJP;olP3o3ooo
nfX3o`1?o`;ooo]Z0_oo0;44oookJP?ook/01OoonfX2ool0<bCooo]Z0_oo08<;oookJP;o0?nH3_oo
nfX2on3o02[ooo]Z000_oookJP;o0?l^2?oonfX00ooooP3ooo]ZoolX0005oolX00;oQ_l00ooonfX0
0ooo=`3ooo]ZoookJP07oookJP03oooL0?oonf[ooo]Z00Cooo]Z00?oBOl0oookJ_oonfX00ooonfX0
0oooXP3ooo]Zoom<0003oookJP;o0?mA00Gooo]ZoolX0?oo:03oobP0oookJP02o`2Wo`[ooo]Z0_oL
0?l:oookJP[oo`003?oonfX2o`3om`04oookJ_oo003ooo]ZoookJP;oo`001OoonfX9oolX00;oob`0
0ooonfX00ol0;Ooooo]ZoookJP0?oookJP;o03Oo1?oo:0000ooo@`3ooo]ZoookJP09oookJP03o`3o
]_oonf[ooo]Z00CoobP000?o`03ooookJ_oonfX03OoonfX6oolX0003ool00?oonf[ooo]Z00Cooo]Z
1?l0001EoookJP04ool0Z_oo:03oooh0ooon00CoobP02ooo0004oookJP?oo`0000?ooo]Zool00?oo
00004?oo0004oookJP;oo`0c1ooonfX00oooN@3ooo]ZoookJP0JoookJP;oo`232_oonfX2o`3oV0oo
oo]Z0_oPo`1GoookJP;o0?l^2?oonfX00ooooP3ooo]ZoookJP02oookJP03oeOo0?oonf[ooo]Z00;o
Q_l00ooonfX00ooo=`3ooo]ZoookJP07oookJP03oooL0?oonf[ooo]Z00Cooo]Z0_m9o`04oookJP04
oonR0?oonf[ood`0oom<00;ooo]Z0_l0oe45oookJP;o0:Oo2ooonfX2om`0o`_ooo]Z00?oodH0oook
J_oonfX00_oonfX00oooR@3ooo]ZoookJP0<oookJP;o0?og1OoonfX2o`3o]`Oooo]Z00?o0>Gooook
J_oonfX00ooonfX2ool/00?ooo]Z00?o02gooookJ_oonfX04?oonfX01_l0=ooooo]ZoookJ_oonf[o
olT0oom300_ooo]Z00?o0?nfoookJ_oonfX01OoonfX00oo00?oooo]ZoookJP0@oookJP03o`3o9?nU
o`3ooo]Z00Kooo]Z1?l0001EoookJP;oo`2Z0_oooP000ooo<03ooo]ZoookJP07oookJP03oo80oooo
nf[ooo]Z00gooo]Z0_l0Col3oookJP;oo`2a1?oonfX2oonk00Kooo]Z0_oo03<ToookJP;oo`232ooo
nfX2o`3oV0kooo]Z0_oPo`0/oookJP00;_oonfX00ol0obkooo]ZoookJP06oookJP;oooh000?ooo]Z
oolX0?oo:0001?oo:0001?n6o`3oobP0oolX0?oo:002oolg00Sooo]Z0_oog005oookJP;oBOl01Ooo
nfX00oooXP3ood`0oom<0003oookJP03o`3oDOoonf[ooo]Z00CoobP000?o0:OooookJ_oonfX02Ooo
nfX00ooL0?oooo]ZoookJP09oookJPWoo`003OoonfX00ol0ooOooo]ZoookJP04ool000Kooo]Z2_oo
:004oookJP03o`0]oooonf[ooo]Z00oooo]Z00?o03OooookJ_oo:0001Ooo:00:oookJP03o`3o]_oo
nf[ooo]Z00KoobP03ooonfX6oolX00Oooo]Z1?l0001CoookJP;oo`2Z0_oooP05oolX0003ool00?oo
nf[oo`0000Soo`001_oonfXDool000?ooo]Z0_oo03<ToookJP;oo`232_oonfX2o`3oV003obKo0?oo
nf[ooo]Z00cooo]Z0_oPo`1HoookJP03o`3o;_oonf[ooo]Z00Kooo]Z0_oooP03oookJP;oEol00_oo
nfX01?n6o`3ooo]ZoookJ_oonfX2oolg00Sooo]Z0_oog006oookJP03odWo0?oonf[ooo]Z00?ooo]Z
00?ooj80oookJ_ooC0000ooonfX00ol0oe7ooo]ZoookJP04oookJP03o`2Wool0@Ooooo]Z00[ooo]Z
00?og03ooookJ_oonfX02OoonfX2oom600Cooo]Z00?oohT0oookJ_oonfX03?oonfX00ol0ooOooo]Z
oookJP04oookJP03o`3o]ooonf[ooo]Z00Gooo]Z0_l0iOl5oookJP03ool/0?oonf[ooo]Z00;ooo]Z
00?o02gooookJ_oonfX04?oonfX01_l0=ooooo]ZoookJ_oonf[oolT0oom300_ooo]Z00?o0?nfoook
J_oonfX01OoonfX00oo00?oooo]ZoookJP0AoookJP03ojGo0?oonf[ooo]Z00Kooo]Z1?l0001Coook
JP;oo`2Z0_oooP0JoookJP;o04oo0ooonfX2ool0/@?ooo]Z0ooo^`06oookJP;oo`0c9?oonfX2ool0
P`_ooo]Z0_l0oiP>oookJP;oh?l0;_oonfX002cooo]Z0_l0obh8oookJP03ooon0?oonf[ooo]Z00Go
obP00_n6o`02oolX0003oookJ_oo=`3ooo]Z00Sooo]Z00?oom`0oookJ_oonfX01?oonfX00om9o`3o
oo]ZoookJP03oookJP;ooj8000?ood`0oookJ_oonfX00_oonfX00ol0oe7ooo]ZoookJP03oolX00;o
0:Oo00?oobP0oookJ_oonfX01ooonfX2om`0o`_ooo]Z1ooo00000oooR@3ooo]ZoookJP0<oookJP03
o`3omooonf[oo`0000Goo`001OoonfX<oolX00;ooo]Z00?o02gooookJ_oonfX03ooonfX00ol0=ooo
oo]ZoolX0007oolX00Sooo]Z00?o0?nfoookJ_oonfX02?oo:00>oookJPOoobP01_oonfX4o`00053o
oo]Z0ooo0:X2ooon00;ooo]Z1?oo:004oookJP03ool00?oonf[oo`0000?oo`002?oonfXBool000;o
oo]Z0ooo03<ToookJP;oo`232OoonfX01?oo:03o0?nHo`3oV?oo:00>oookJP;oh?l0F?oonfX2o`3o
;PSooo]Z00Coooh0oookJ_oonf[ooo]Z0_mGo`02oookJP;oQ_l00ooonfX00ooo=`3ooo]ZoookJP07
oookJP03oooL0?oonf[ooo]Z00Cooo]Z0_m9o`04oookJP;ooj800_ooC003oookJP03o`3oDOoonf[o
oo]Z00?ooo]Z0_l0Yol;oookJP;og03o2ooonfX00oooAP3ooo]ZoookJP02oookJP;oohT03_oonfX0
0ol0ooOooo]ZoookJP04oookJP03o`3o]ooonf[ooo]Z00Gooo]Z00?o0>GooookJ_oonfX01?oonfX0
0ooo;03ooo]ZoookJP02oookJP03o`0]oooonf[ooo]Z013ooo]Z00Ko03OooookJ_oonf[ooo]Zooo9
0?oo@`0;oookJP03o`3o]_oonf[ooo]Z00Gooo]Z00?o`03ooookJ_oonfX04OoonfX00onUo`3ooo]Z
oookJP07oookJPCo0000D?oonfX3ool0ZP;oooh06_oonfX2o`1?o`?ooo]Z0_oo0;43oookJP;ook/0
1_oonfX3ool0<bCooo]Z0_oo08<;oookJP;o0?nH3_oonfX2on3o033ooo]Z000[oookJP03o`3o;_oo
nf[ooo]Z00Kooo]Z0_oooP02oookJPGoobP000CoQ_l0oolX0?oonf[ooo]Z0_oo=`09oookJP03oooL
0?oonf[ooo]Z00?ooo]Z0_m9o`05oookJP03oonR0?oonf[ood`000?ooo]Z0_l0oe42oookJP?oobP0
00?o0:OooolX0?oo:0000_oo:007oookJP03om`0oooonf[ooo]Z00[ooo]Z1Ooo00000ooonf[oohT0
oookJP0=oookJP;o0?og0_oonfX7ool000?ooo]Z1ooo:0000ooonf[oob`0oolX0004oolX0003ool0
0?oonf[ooo]Z00oooo]Z00?o03OooookJ_oo:0002Ooo:006oookJP04o`3o]_oonf[ooo]ZoookJPWo
obP03?oonfX9oolX00Gooo]Z1?l00017oookJPWoo`000ooooP04oookJP?oobP01ooonfX3ool000So
oo]Z0_l0Col@ool00003oookJ_oo03?oo`0c02Gooo]Z0_oo08<6oookJPCoobP00_l0oiP00ooo:03o
oo]ZoookJP0<oookJP;oh?l0FOoonfX00ol0obkooo]ZoookJP06oookJP;oooh00ooonfX01OmGo`3o
oo]ZoookJ_oonf[oQ_l000?ooo]Z0_oo=`09oookJP03oooL0?oonf[ooo]Z00Cooo]Z00?oBOl0oook
J_oonfX00ooonfX00oooXP3ooo]Zoom<0003oookJP;o0?mA1OoonfX00ol0Yooo047ooookJP0:oook
JP03om`0oooonf[ooo]Z00Wooo]Z0_ooAP04oookJP03oon90?oonf[ooo]Z00gooo]Z00?o0?ogoook
J_oonfX01?oonfX00ol0okOok`3ooookJP05oookJP03o`3Uoooonf[ooo]Z00Cooo]Z00Coob`0oook
J_oonf[ooo]Z0_l0;OlBoookJP04o`0goooonf[ooo]ZoookJP;ood<02ooonfX00ol0okKooo]Zoook
JP05oookJP03ol00oooonf[ooo]Z017ooo]Z00?oYOl0o`3o9?oonfX02?oonfX4o`0004kooo]Z0_oo
0:X3ooon01[ooo]Z0_l0Col3oookJP;oo`2a0_oonfX3oonk00Kooo]Z0_oo03<UoookJP;oo`232ooo
nfX2o`3oV0kooo]Z0_oPo`0boookJP00:_oonfX00ol0obkooo]ZoookJP06oookJP04ooon0?oonf[o
oo]ZoookJPGoobP000GoQ_l0oookJ_oonf[ooo]Zoolg0009oookJP;oom`01OoonfX00om9o`3ooo]Z
oookJP04oookJP03oonR0?ooC03ood`000?ooo]Z00Co0?mAoookJ_oonf[ooo]Z0_oo:002o`2Wo`Ko
obP01OoonfX00ooL0?oooo]ZoookJP0:oookJP?oo`000ooonfX00oooR@3ooo]ZoookJP0<oookJP04
o`3omooonf[ooo]ZoookJPWoo`000_oonfX5oolX00;ooo]Z00?oob`0oolX0?oo:0001?oo:002ool0
00oooo]Z00?o03OooookJ_oo:0002?oo:007oookJP04o`3o]_oonf[ooo]ZoookJPSoobP03_oonfX3
oolX0004ojGo0?oo:03oobP0oolX00Oooo]Z1?l0000ooookJPkoo`000ooooP08oookJP03oolX0?oo
nf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX01OoonfX2o`1?o`;ooo]Z3ooo0002ool0<bCooo]Z0ooo
:003oookJPOoobP00_l0oiP2oolX00gooo]Z0_oPo`1JoookJP03o`3o;_oonf[ooo]Z00Kooo]Z00Co
ooh0oookJ_oonf[ooo]Z0_mGo`03oookJP05ohKo0?oonf[ooo]ZoookJ_oo=`002OoonfX2oooL00Go
oo]Z0_m9o`05oookJP03oonR0?ooC03ood`000?ooo]Z00?o0?mAoookJ_oonfX00ooonfX2o`2Wo`co
oo]Z00?og03ooookJ_oonfX02OoonfX00oooAP3ooo]ZoookJP03oookJP03oon90?oonf[ooo]Z00co
oo]Z0_l0ooL5oookJP;o0?ng1_oonfX2o`3Uo`Gooo]Z0_oo;003oookJP03o`0]oooonf[ooo]Z017o
oo]Z00Go03OooookJ_oonf[ooo]Zoom3000<oookJP03o`3o]_oonf[ooo]Z00Gooo]Z00?o`03ooook
J_oonfX04_oonfX00onUo`3ooo]ZoookJP08oookJPCo0000BooonfX2ool0ZP?oooh06_oonfX3o`1?
o`?ooo]Z0_oo0;43oookJP03oonk0?oonf[ooo]Z00Gooo]Z0_oo03<UoookJP;oo`232ooonfX2o`3o
V0kooo]Z0_oPo`0doookJP00<_oonfX01?oooP3ooo]ZoookJ_oonfX3oolX0003oookJ_n6o`3oQ_l0
00;ooo]Z0_oo=`09oookJP03oooL0?oonf[ooo]Z00Cooo]Z00?oBOl0oookJ_oonfX01?oonfX00ooo
XP3ood`0oookJP02oookJP;o0?mA1?oonfX00ooo:03o0:OooolX0005oolX00Kooo]Z00?og03ooook
J_oonfX02OoonfX00oooAP3oo`00oookJP03oookJP;oobP03OoonfX2o`3om`?ooo]Z2ooo0004oolX
00?ooo]Z00?oob`0oookJ_oo:0001?oo:004ool000;ooo]Z00?oo`00oookJ_oonfX02?oonfX00ol0
=ooooo]ZoookJP07oolX0003ool00?oonf[ooo]Z00Cooo]Z0_l0okH4oookJPOoobP03_oonfX3oolX
0004ojGo0?oo:03oobP0oolX00Sooo]Z1?l0000HoookJP;oo`009OoonfX:ool000Coooh06ooonfX2
o`1?o`Cooo]Z1_oo0003oookJPCoo`000_oo03<QoookJPKoobP00_oonfX8oolX00;o0?nH0ooo:00<
oookJP;oh?l0I?oonfX01OoooP3ooo]ZoookJ_oonf[oEol000?ooo]Z0_n6o`02oookJP;oocL02Ooo
nfX00ooog03ooo]ZoookJP04oookJP03odWo0?oonf[ooo]Z00Cooo]Z00?ooj80oom<0?oonfX00_oo
nfX2o`3oD@Gooo]Z00?o0:Ooo`11oooonfX02_oonfX2om`0o`[ooo]Z0_ooAP04oookJP;oohT03_oo
nfX00ol0ooOooo]ZoookJP04oookJP03o`3o]oo_0?oooo]Z00Gooo]Z00?o0>GooookJ_oonfX01?oo
nfX00ooo;03ooo]ZoookJP02oookJP03o`0]oooonf[ooo]Z017ooo]Z00Go03OooookJ_oonf[ooo]Z
oom3000;oookJP;o0?nf1ooonfX00oo00?oooo]ZoookJP0BoookJP03ojGo0?l0obCooo]Z00Wooo]Z
1?l00018oookJP03ool0Z_oooP3oooh000;oooh06ooonfX2o`1?o`Gooo]Z00?oo`2aoookJ_oonfX0
2OoonfX2ool0<bGooo]Z0_oo08<;oookJP;o0?nH3_oonfX2on3o03Kooo]Z000`oookJP;oooh00_oo
nfX00omGo`3oobP0oookJP02oookJP05ohKo0?oonf[ooo]ZoookJ_oo=`002OoonfX2oooL00Gooo]Z
0_m9o`05oookJP;ooj8000Good`0oookJ_oonf[ooo]Zo`3oD@05oookJP;o0:Oo1?oo:007oookJP;o
g03o2ooonfX00oooAP3ooo]ZoookJP03oookJP03oolX0?oonf[ooo]Z00cooo]Z00?o0?ogoookJ_oo
nfX00_oonfX:ool00003oookJ_oo:03oobP000Cooo]Z0_oo;0000ooonf[oobP0oolX0003oolX00Ko
o`0000?ooo]Zool00?oo00002?oonfX00ol0=ooooo]ZoookJP06oolX00Coo`001?oonfX00ol0okKo
oo]ZoookJP03oookJPKoobP04?oonfX2oolX0004ojGo0?oo:03oobP0oolX00Wooo]Z1?l0000Hoook
JPGoo`008ooonfX5ool000Coooh00_oo000KoookJP;o04oo1ooonfX4ool000Cooo]Z0ooo00000ooo
03?ooo]ZoookJP0LoookJP[oobP00ooonfX6oolX00;o0?nH1?oo:00:oookJP?oh?l0I?oonfX2ooon
00;ooo]Z0_mGo`03oookJP05ohKo0?oonf[ooo]ZoookJ_oo=`002OoonfX2oooL00Gooo]Z0_m9o`05
oookJP;ooj8000Good`0oookJ_oonf[ooo]Zo`3oD@05oookJP;o0:Oo3?oonfX00ooL0?oooo]Zoook
JP09oookJP03oom60?oonf[ooo]Z00?ooo]Z00?oohT0oookJ_oonfX03OoonfX00ol0ooOooo]Zoook
JP04oookJP03o`3o]oo_0?oooo]Z00Gooo]Z00?o0>GooookJ_oonfX01?oonfX00ooo;03ooo]Zoook
JP02oookJP03o`0]oooonf[ooo]Z00?ooo]Z0_l0oOl<oookJP05o`0goooonf[ooo]Zooo90?oo@`00
2ooonfX00ol0okKooo]ZoookJP06oookJP03ol00oooonf[ooo]Z01?ooo]Z00?oYOl0oookJ_oonfX0
2OoonfX4o`0004Gooo]Z1?oooP0MoookJP;o04oo4OoonfX2ool0<bGooo]Z0_oo08<;oookJP;o0?nH
3OoonfX3on3o03Sooo]Z000_oookJP05ooon0?oonf[ooo]ZoookJ_mGo`000ooonfX2ohKo00?ooo]Z
00?oocL0oookJ_oonfX01ooonfX00ooog03ooo]ZoookJP04oookJP03odWo0?oonf[ooo]Z00Cooo]Z
00?ooj80oom<0?oonfX00ooonfX00ol0oe7ooo]ZoookJP03oookJP03o`2Woooo:03oobP000;oobP0
2?oonfX00ooL0?oooo]ZoookJP0:oookJP03oom60?oo:03ooo]Z00?ooo]Z00?oobP0oookJ_oonfX0
3?oonfX00ol0ooOooo]ZoookJP03oookJPSoo`0000?ooo]Zo`3Uoooo:0001OoonfX00ooo;03ooo]Z
oookJP05oolX00_oo`001_oonfX00ol0=ooooo]ZoookJP05oolX0003oookJ_oo003oo`0000Coo`00
0_oonfX00ol0okKooo]ZoookJP04oookJPCoobP04_oonfX2oolX0003ojGo0?oo:03oobP000[ooo]Z
1Ol0000GoookJPOoo`000_oonfX3oolX01cooo]Z00?oo`00ooon0?oooP000_oooP04ool001Cooo]Z
2Ooo:009oookJP?oo`001?oonfX2ool0<`03ool00?oonf[ooo]Z01_ooo]Z3?oo:005oookJP?oobP0
0_l0oiP5oolX00Wooo]Z0_oPo`1VoookJP05ooon0?oonf[ooo]ZoookJ_mGo`000ooonfX2ohKo00?o
oo]Z00?oocL0oookJ_oonfX01ooonfX00ooog03ooo]ZoookJP04oookJP03odWo0?oonf[ooo]Z00Co
oo]Z00?ooj80oom<0?oonfX00ooonfX00ol0oe7ooo]ZoookJP03oookJP03o`2Wool0@Ooooo]Z00_o
oo]Z00?og03ooookJ_oonfX02OoonfX00oooAP3ooo]ZoookJP03oookJP03oon90?oonf[ooo]Z00co
oo]Z0_l0ooL5oookJP;o0?ng00?ok`3ooookJ_oonfX00ooonfX2o`3Uo`Kooo]Z00Coob`0oookJ_oo
nf[ooo]Z0_l0;Ol5oookJP03o`3moooonf[ooo]Z00_ooo]Z00Go03OooookJ_oonf[oolT0oom3000;
oookJP03o`3o]_oonf[ooo]Z00Kooo]Z00?o`03ooookJ_oonfX04ooonfX00ol0obCoYOl0oookJP0:
oookJPGo0000@?oonfX4ooon01oooo]Z0_l0Col@oookJP?oo`0c9OoonfX2ool0P`[ooo]Z00?o9_l0
o`3oV?l0oiP03OoonfX2on3o03_ooo]Z000]oookJP;oooh00ooonfX01OmGo`3ooo]ZoookJ_oonf[o
Q_l000?ooo]Z0_oo=`09oookJP03oooL0?oonf[ooo]Z00?ooo]Z0_m9o`06oookJP03oonR0?ooC03o
oo]Z00;ooo]Z0_l0oe45oookJP04o`2Woooo:03oobP0oolX00Wooo]Z00?og03ooookJ_oonfX02Ooo
nfX2oom600?oobP000?ooo]ZoolX0?oo:0003OoonfX2o`3om`Gooo]Z2_oo0006oookJP03ool/0?oo
nf[ooo]Z00KoobP03?oo0003oookJP;o03Oo0ooonfX3oolX00;ooo]Z2?oo00000ol0okKooo]Zoook
JP04oookJPCoobP04_oonfX2oolX0003ojGo0?oo:03oobP000_ooo]Z1?l0000HoookJPWoo`001ooo
:00FoookJP?oooh01ooo000=oookJPooobP03?oonfX00ooo003ooo]ZoookJP03ool0<b3ooo]Z2ooo
:006oookJP03oolX0?l0oiSo0?nH00GoobP02OoonfX2on3o06Kooo]Z0_oooP03oookJP05oeOo0?oo
nf[ooo]ZoookJ_n6o`000ooonfX2oolg00Wooo]Z00?oom`0oookJ_oonfX00ooonfX2odWo00Kooo]Z
00?ooj80oom<0?oonfX00_oonfX2o`3oD@Gooo]Z00?o0:Ooo`11oooonfX02_oonfX2om`0o`[ooo]Z
0_ooAP04oookJP;oohT03_oonfX00ol0ooOooo]ZoookJP04oookJP03o`3o]oo_0?oooo]Z00Gooo]Z
00?o0>GooookJ_oonfX01OoonfX01Ooo;03ooo]ZoookJ_oonf[o02go00Kooo]Z00?o0?gooookJ_oo
nfX00ooonfX2ool0X@Gooo]Z0_l0=ol2oookJP03ooo90?oo@`3ooo]Z00Gooo]Z0_l0ok<3oookJP03
o`3o]_oonf[ooo]Z00Kooo]Z00?o`03ooookJ_oonfX04ooonfX00ol0obCoYOl0oookJP0;oookJPCo
0000?_oonfX3ooon023ooo]Z0ol0Col?oookJP?oo`0c9_oonfX2ool0P`[ooo]Z00?o9_l0o`3oV?l0
oiP03OoonfX2on3o03gooo]Z000/oookJP04ooon0?oonf[ooo]ZoookJP;oEol00_oonfX2ohKo00?o
oo]Z00?oocL0oookJ_oonfX01ooonfX2oooL00Gooo]Z00?oBOl0oookJ_oonfX01?oonfX2oonR00Co
oo]Z00?o0?mAoookJ_oonfX00ooonfX2o`2Wo`03oolX0?oonf[ooo]Z00Sooo]Z0_oL0?l;oookJP03
oom60?oonf[oobP000CoobP03_oonfX00ol0ooOooo]ZoookJP04oookJPWoo`0000?o0>GooookJ_oo
nfX00ooonfX2ool/00?ooo]Z1Ooo:00>ool00003oookJ_l0=ooooo]Z00?ooo]Z0_oo:004oookJPWo
o`001OoonfX3oolX01Cooo]Z0_oo:0000onUo`3ooo]ZoookJP0;oookJPCo00006?oonfX9ool000[o
obP03_oonfX5ooon00?ooo]Z1Ooo000?oookJPkoobP03OoonfX3ool0<bCooo]Z2Ooo:006oookJP;o
0?nH1_oo:008oookJP;oh?l0IooonfX01?oooP3ooo]ZoookJ_oonfX2oeOo00;ooo]Z0_n6o`03oook
JP03oolg0?oonf[ooo]Z00Oooo]Z0_oog005oookJP03odWo0?oonf[ooo]Z00Cooo]Z0_ooXP001Ooo
C03ooo]ZoookJ_oonf[o0?mA00Gooo]Z0_l0Yol<oookJP03om`0oooonf[ooo]Z00Wooo]Z00?oodH0
oookJ_oonfX00ooonfX00oooR@3ooo]ZoookJP0=oookJP03o`3omooonf[ooo]Z00Cooo]Z00?o0?ng
onl0oooonfX01OoonfX00ol0iOoooo]ZoookJP04oookJP;oob`00ooonfX00ol0;Ooooo]ZoookJP04
oookJP03o`3moooonf[ooo]Z00?ooo]Z00?oo`2QoookJ_oonfX01?oonfX01_l0=ooooo]ZoookJ_oo
nf[oolT0oom300Kooo]Z00?o0?ncoookJ_oonfX00_oonfX00ol0okKooo]ZoookJP06oookJP03ol00
oooonf[ooo]Z01Cooo]Z00?oYOl0oookJ_oonfX02ooonfX4o`0003Wooo]Z1OoooP0PoookJP?o04oo
4?oonfX2ool0<bOooo]Z0_oo08<:oookJP?o0?nH3OoonfX2on3o03oooo]Z000[oookJP05ooon0?oo
nf[ooo]ZoookJ_mGo`000ooonfX01?n6o`3ooo]ZoookJ_oonfX2oolg00Wooo]Z00?oom`0oookJ_oo
nfX01?oonfX00om9o`3ooo]ZoookJP04oookJP03oonR0?ooC03ooo]Z00;ooo]Z0_l0oe45oookJP03
o`2Woooo:03ooo]Z00[ooo]Z00?og03ooookJ_oonfX02_oonfX00oooAP3ooo]ZoolX0005oolX00go
oo]Z00?o0?ogoookJ_oonfX01?oonfX7ool000;ooo]Z00?o0>GooookJ_oonfX00ooonfX00ooo;03o
oo]ZoookJP02oookJPCoobP000?ooo]Zool00?oo00003Ooo00000ol0=ooooo]ZoookJP02oookJP03
oolX0?oonf[ooo]Z00?ooo]Z2?oo0007oookJP03oolX0?oonf[ooo]Z01?ooo]Z0_oo:0000onUo`3o
oo]ZoookJP0<oookJPCo00006?oonfX9ool000koobP01?oonfX6ooon00Sooo]Z0ooo000BoookJP_o
obP03?oonfX3ool0<bOooo]Z1ooo:006oookJP;o0?nH0ooonfX4oolX00Oooo]Z0_oPo`1XoookJP05
ooon0?oonf[ooo]ZoookJ_mGo`000ooonfX01?n6o`3ooo]ZoookJ_oonfX2oolg00Wooo]Z00?oom`0
oookJ_oonfX01?oonfX00om9o`3ooo]ZoookJP04oookJP03oonR0?ooC03ooo]Z00;ooo]Z0_l0oe45
oookJP03o`2Wool0@Ooooo]Z00_ooo]Z00?og03ooookJ_oonfX02OoonfX00oooAP3ooo]ZoookJP02
oookJP;oohT03ooonfX00ol0ooOooo]ZoookJP04oookJP03o`3o]oo_0?oooo]Z00Gooo]Z00?o0>Go
oookJ_oonfX01?oonfX00ooo;03ooo]ZoookJP02oookJP03o`0]oooonf[ooo]Z00?ooo]Z0_l0oOl5
oookJP03ool0XOoonf[ooo]Z00Cooo]Z00Co03OooookJ_oonf[ooo]Z0_oo@`06oookJP03o`3o/ooo
nf[ooo]Z00;ooo]Z00?o0?nfoookJ_oonfX01_oonfX00oo00?oooo]ZoookJP0DoookJP03ojGo0?oo
nf[ooo]Z00cooo]Z1?l0000ToookJP?oooh03?oonfX6ooon02;ooo]Z0ol0Col@oookJP?oo`0c9ooo
nfX2ool0P`[ooo]Z0_l0oiP>oookJP;oh?l0@OoonfX002[ooo]Z00?oooh0oookJ_oonfX00_mGo`03
oookJP05ohKo0?oonf[ooo]ZoookJ_oo=`002OoonfX2oooL00Gooo]Z0_m9o`06oookJP03oonR0?oo
C03ooo]Z00;ooo]Z00?o0?mAoookJ_oonfX00ooonfX2o`2Wo`cooo]Z00?og03ooookJ_oonfX02Ooo
nfX2oom60003oookJ_oo:03oobP000KoobP02_oonfX2o`3om`Kooo]Z00?o0?ngool00?oo00000ooo
0003oookJP03o`3Uoooonf[ooo]Z00?ooo]Z00?oob`0oookJ_oonfX00_oonfX2oolX00?ooo]Z1_oo
00000ooonf[oo`00ool00006ool00003o`0goooonf[ooo]Z00;ooo]Z00?ood<0oookJ_oonfX00ooo
nfX7ool00003o`3o]_oonf[ooo]Z00Gooo]Z00?oobP0oookJ_oonfX05?oonfX00ooo:03oYOl0oook
JP0>oookJPCo00006?oonfX9ool0013oobP00_oooP0?oookJP03ool00?oonf[ooo]Z017ooo]Z2Ooo
:00<oookJP;oo`0c:OoonfX7oolX00Cooo]Z0ol0oiP5oookJP?oobP01_oonfX2on3o06Wooo]Z00?o
ooh0oookJ_oonfX00_mGo`03oookJP05ohKo0?oonf[ooo]ZoookJ_oo=`002OoonfX2oooL00Gooo]Z
0_m9o`06oookJP03oonR0?ooC03ooo]Z00;ooo]Z00?o0?mAoookJ_oonfX00ooonfX2o`2Wo`cooo]Z
0_oL0?l;oookJP03oom60?oonf[ooo]Z00;ooo]Z00?oohT0oookJ_oonfX03OoonfX2o`3om`Gooo]Z
0_l0okL7oookJP03o`3Uoooonf[ooo]Z00Cooo]Z00?oob`0oookJ_oonfX00_oonfX00ol0;Ooooo]Z
oookJP03oookJP03o`3moooonf[ooo]Z00Cooo]Z00?oo`2QoookJ_oonfX01?oonfX01Ol0=ooooo]Z
oookJ_oonf[ood<000Oooo]Z00?o0?ncoookJ_oonfX00_oonfX00ol0okKooo]ZoookJP06oookJP03
ol00oooonf[ooo]Z01Cooo]Z00?oYOl0oookJ_oonfX03OoonfX4o`0002Oooo]Z3?oooP0UoookJP?o
04oo4OoonfX2ool0<bSooo]Z0_oo08<:oookJP;o0?nH3_oonfX2on3o04?ooo]Z000/oookJP04oeOo
0?oonf[ooo]ZoookJP;oQ_l00_oonfX2oolg00Wooo]Z00?oom`0oookJ_oonfX01?oonfX00om9o`3o
oo]ZoookJP04oookJP;ooj801?oonfX00ol0oe7ooo]ZoookJP03oookJP03o`2Wool0@Ooooo]Z00_o
oo]Z00?og03ooookJ_oonfX02OoonfX00oooAP3ooo]ZoookJP0:oolX00Sooo]Z00?o0?ogoookJ_oo
nfX01OoonfX00ol0okOoo`00ool00002ool000Cooo]Z00?o0>GooookJ_oonfX00ooonfX02?oo;03o
oo]ZoookJ_oonf[o02gooolX0?oonf[oo`000ooonfX4ool000;ooo]Z1ooo00000ooonf[o03Oooook
JP03oookJP03oom30?oonf[ooo]Z00Cooo]Z1Ooo00000ooonf[o0?nfoookJP06oookJP03ol00oooo
nf[ooo]Z01Gooo]Z00?oYOl0oookJ_oonfX03_oonfX4o`0000Oooo]Z2Ooo0008oookJPWoo`003Ooo
:00WoookJP;o04oo1ooo:00:oookJP?oo`0c:OoonfX2oolX00;ooo]Z1?oo:003oookJP;o0?nH00?o
obP0oookJ_oonfX01_oonfX00ooo:03ooo]ZoookJP03oookJP;oh?l07_oonfX2ooX0odgooo]Z00Co
Eol0oookJ_oonf[ooo]Z0_n6o`02oookJP;oocL02OoonfX00ooog03ooo]ZoookJP04oookJP03odWo
0?oonf[ooo]Z00Cooo]Z0_ooXP001OooC03ooo]ZoookJ_oonf[o0?mA00Gooo]Z00?o0:Ooo`11oooo
nfX02ooonfX00ooL0?oooo]ZoookJP09oookJP;oodH01?oonfX00oooR@3ooo]ZoookJP0=oookJP03
o`3omooonf[ooo]Z00Cooo]Z00?o0?ngonl0oooonfX01_oonfX00ol0iOoooo]ZoookJP04oookJP04
ool/0?oonf[ooo]ZoookJP;o02go1OoonfX00ol0oOoooo]ZoookJP03oookJP;oo`2Q1_oonfX01Ol0
=ooooo]ZoookJ_oonf[ood<000Oooo]Z00?o0?ncoookJ_oonfX00_oonfX00ol0okKooo]ZoookJP06
oookJP03ol00oooonf[ooo]Z01Cooo]Z00?oYOl0o`3o9?oonfX03_oonfX4o`0005Gooo]Z0ol0ColA
oookJP?oo`0c:?oonfX2ool0P`[ooo]Z0_l0oiP>oookJP;oh?l07ooonfX2ooX0obCooo]Z000[oook
JP05oeOo0?oonf[ooo]ZoookJ_n6o`000ooonfX00ooo=`3ooo]ZoookJP08oookJP03oooL0?oonf[o
oo]Z00?ooo]Z0_m9o`06oookJP03oonR0?ooC03ooo]Z00;ooo]Z0_l0oe45oookJP03o`2Wool0@Ooo
oo]Z00[ooo]Z0_oL0?l:oookJP;oodH00ooonfX8oolX00Wooo]Z00?o0?ogoookJ_oonfX01OoonfX0
0ol0okOoo`00ool00005oookJP;o0>Go1OoonfX01Ooo;03ooo]ZoookJ_oonf[o02go00?ooo]Z0_oo
00001?oonf[oo`00ool00?oo0003oookJPKoo`000_oonfX00ol0=ooooo]ZoookJP02oookJP03oom3
0?oonf[ooo]Z00Cooo]Z1?oo0002oookJP03o`3o]_oonf[ooo]Z00Gooo]Z00?o`03ooookJ_oonfX0
5OoonfX00ooo:03oYOl0oookJP0?oookJPCo00001ooonfX9ool000Sooo]Z1?oo0005oookJPWoobP0
:?oonfX3o`1?o`;ooo]Z1Ooo:009oookJP?oo`0c:_oonfX00ooo08?oobP0oookJP03oookJP?oobP0
0_oonfX2o`3oV003obKo0?oonf[ooo]Z00cooo]Z0_oPo`0NoookJP;onP3oC_oonfX01OmGo`3ooo]Z
oookJ_oonf[oQ_l000?ooo]Z00?oocL0oookJ_oonfX02?oonfX00ooog03ooo]ZoookJP03oookJP;o
BOl01_oonfX00oooXP3ood`0oookJP02oookJP;o0?mA1OoonfX00ol0Yooo047ooookJP0;oookJP03
om`0oooonf[ooo]Z00Wooo]Z00?oodH0oookJ_oonfX00_oonfX2oon900oooo]Z00?o0?ogoookJ_oo
nfX01?oonfX00ol0okOok`3ooookJP05oookJP;o0>Go1_oonfX01Ooo;03ooo]ZoookJ_oonf[o02go
00Kooo]Z00?o0?gooookJ_oonfX00ooonfX00ooo0:7ooo]ZoookJP05oookJP05o`0goooonf[ooo]Z
oookJ_oo@`001ooonfX00ol0ok?ooo]ZoookJP02oookJP03o`3o]_oonf[ooo]Z00Kooo]Z00?o`03o
oookJ_oonfX05OoonfX00onUo`3ooo]ZoookJP0>oookJPCo0000D_oonfX3o`1?oa7ooo]Z0ooo03<Y
oookJP;oo`232OoonfX00olVo`3o0?nHo`3oV00>oookJP;oh?l07ooonfX2ooX0obKooo]Z000Zoook
JP03oeOo0?oonf[ooo]Z00;oQ_l00_oonfX2oolg00Wooo]Z0_oog005oookJP03odWo0?oonf[ooo]Z
00Gooo]Z00?ooj80oookJ_oonfX00_oonfX00ol0oe7ooo]ZoookJP03oookJP;o0:Oo3?oonfX00ooL
0?oooo]ZoookJP09oookJP03oom60?oonf[ooo]Z00;ooo]Z1_oo:00;oookJP03o`3omooonf[ooo]Z
00Cooo]Z0_l0okL00ooo003ooo]ZoookJP04oookJP03o`3Uoooonf[ooo]Z00;ooo]Z00?oo`00ool/
0?oo;0000_oo00000ooonf[o02gooookJP02oookJPKoo`001?oonfX4ool000?ooo]Z00Ko03Oooook
J_oonf[ooo]Zooo90?oo@`07oookJP?oo`000_oonfX00ol0okKooo]ZoookJP05oookJP03ol00oooo
nf[ooo]Z01Kooo]Z00?oYOl0oookJ_oonfX03ooonfX4o`0000Sooo]Z2?oo000AoookJPKoobP06Ooo
nfXAool00003o`1?oooonf[ooo]Z00?ooo]Z0ooo:008oookJP?oo`0c:_oonfX3ool0P`Oooo]Z00Co
obP0oookJ_l0oiSo0?nH3_oonfX3on3o01kooo]Z0_oj0?m?oookJP03oeOo0?oonf[ooo]Z00;oQ_l0
0_oonfX2oolg00Wooo]Z0_oog005oookJP03odWo0?oonf[ooo]Z00Gooo]Z00?ooj80oom<0?oonfX0
0_oonfX00ol0oe7ooo]ZoookJP03oookJP;o0:Oo3?oonfX2om`0o`_ooo]Z00?oodH0oookJ_oonfX0
0_oonfX00oooR@3ooo]ZoookJP0=oookJP;o0?og1OoonfX2o`3o]`03onl0oooonf[ooo]Z00Cooo]Z
00?o0>GooookJ_oonfX01?oonfX2ool/00;o4_l000?ooo]Zo`0]oooonfX01OoonfX00ol0oOoo0?n^
oookJP03oookJP03ool0XOoonf[ooo]Z00Gooo]Z00Go03OooookJ_oonf[ooo]Zoom30007oookJP03
o`3o/ooonf[ooo]Z00;ooo]Z00?o0?nfoookJ_oonfX01_oonfX00oo00?oooo]ZoookJP0EoookJP03
ojGo0?l0obCooo]Z00oooo]Z1?l0001>oookJPCo04oo4OoonfX3ool0<bWooo]Z0ooo08<9oookJP?o
0?nH3_oonfX2on3o01oooo]Z0_oj0?lXoookJP00;?oonfX01On6o`3ooo]ZoookJ_oonf[oocL000[o
oo]Z00?oom`0oookJ_oonfX01?oonfX00om9o`3ooo]ZoookJP04oookJP;ooj801?oonfX00ol0oe7o
oo]ZoookJP03oookJP03o`2Wool0@Ooooo]Z00_ooo]Z00?og03ooookJ_oonfX02OoonfX00oooAP3o
oo]ZoookJP02oookJPGoobP02ooonfX2o`3om`Kooo]Z00?o0?ngonl0oooonfX01_oonfX00ol0iOoo
oo]ZoookJP03oookJP03ool00?oonf[oo`0000;ooo]Z00Co02gooookJ_oonf[ooo]Z0_oo00001?l0
oOooo`00ool00?oo0004oookJP?oo`001?oonfX01_l0=ooooo]ZoookJ_oonf[oolT0oom300Gooo]Z
00Coo`00oookJ_oo003oo`000ooonfX00ol0okKooo]ZoookJP05oookJP03ol00oooonf[ooo]Z01Ko
oo]Z00?oYOl0oookJ_oonfX04?oonfX4o`0000Sooo]Z1ooo0008oookJP03ool00?oonf[ooo]Z00Oo
oo]Z0_oo:00MoookJPooo`002OoonfX00ooo:03ooo]ZoookJP03oookJPCoo`0c:_oonfX3ool0P`Wo
oo]Z00?o9_l0o`3oV?l0oiP03_oonfX2on3o01oooo]Z0_oj0?mCoookJP05ohKo0?oonf[ooo]Zoook
J_oo=`002_oonfX00ooog03ooo]ZoookJP04oookJP03odWo0?oonf[ooo]Z00Cooo]Z0_ooXP04oook
JP03o`3oDOoonf[ooo]Z00?ooo]Z00?o0:Ooo`11oooonfX02ooonfX00ooL0?oooo]ZoookJP09oook
JP;oodH00ooonfX2oon900oooo]Z00?o0?ogoookJ_oonfX01?oonfX00ol0okOok`3ooookJP06oook
JP03o`3Uoooonf[ooo]Z00Cooo]Z00?oob`0oookJ_lBo`000_oonfX00ol0;Ooooo]ZoookJP03oook
JP;o0?go1OoonfX00ooo0:7ooo]ZoookJP05oookJP05o`0goooonf[ooo]ZoookJ_oo@`001ooonfX0
0ol0ok?ooo]ZoookJP02oookJP03o`3o]_oonf[ooo]Z00Kooo]Z00?o`03ooookJ_oonfX05OoonfX0
0onUo`3o0?lToookJP0@oookJPCo0000B_oonfX4o`1?oa7ooo]Z1?oo03<YoookJP?oo`232OoonfX0
0olVo`3o0?nHo`3oV00?oookJP;oh?l07ooonfX2ooX0ob[ooo]Z000[oookJP05ohKo0?oonf[ooo]Z
oookJ_oo=`002OoonfX2oooL00Gooo]Z0_m9o`06oookJP03oonR0?ooC03ooo]Z00;ooo]Z0_l0oe44
oookJP;o0:Oo00?o047ooookJ_oonfX02_oonfX00ooL0?oooo]ZoookJP08oookJP;oodH01?oonfX4
oolX00cooo]Z00?o0?ogoookJ_oonfX01OoonfX00ol0okOok`3ooookJP06oookJP03o`3Uoooonf[o
oo]Z00?ooo]Z0ooo0002oookJP04o`0]oooonf[ooo]ZoookJP;oo`0000?o0?goool00?oo00000ooo
0002oookJP;oo`001OoonfX01_l0=ooooo]ZoookJ_oonf[oolT0oom300Kooo]Z0_oo00001Ooob@3o
oo]ZoookJ_oonf[o0?nf00Oooo]Z00?o`03ooookJ_oonfX05_oonfX00ol0obCoYOl0oookJP0Aoook
JPCo00002?oonfX7ool000;ooo]Z0ooo0003oookJP03ool00?oonf[ooo]Z02Kooo]Z3Ooo000>oook
JP?oo`0c:ooonfX3ool0P`Wooo]Z0_lVo`02o`3oV0kooo]Z0_oPo`0OoookJP;onP3oE?oonfX01On6
o`3ooo]ZoookJ_oonf[oocL000Wooo]Z0_oog005oookJP;oBOl01_oonfX00oooXP3ood`0oookJP02
oookJP;o0?mA1?oonfX2o`2Wo`03o`11oooonf[ooo]Z00[ooo]Z00?og03ooookJ_oonfX02OoonfX0
0oooAP3ooo]ZoookJP02oookJP03oon90?oonf[ooo]Z00kooo]Z00?o0?ogoookJ_oonfX01?oonfX0
0ol0okOok`3ooookJP06oookJP03o`3Uoooonf[ooo]Z00Cooo]Z00Coob`0oookJ_lBo`3ooo]Z0_l0
;Ol5oookJP03o`3mool0ojkooo]Z00Cooo]Z00?oo`2QoookJ_oonfX01OoonfX01Ol0=ooooo]Zoook
J_oonf[ood<000Oooo]Z00?o0?ncoookJ_oonfX00_oonfX00ol0okKooo]ZoookJP06oookJP03ol00
oooonf[ooo]Z01Kooo]Z00?oYOl0oookJ_oonfX04?oonfX4o`0004Sooo]Z0_l0ColAoookJPCoo`0c
:ooonfX2ool0P`Wooo]Z0_lVo`02o`3oV0kooo]Z0ooPo`0OoookJP;onP3o;?oonfX002[ooo]Z00?o
Q_l0oookJ_oonfX00_oo=`09oookJP03oooL0?oonf[ooo]Z00Cooo]Z00?oBOl0oookJ_oonfX01?oo
nfX2oonR00Cooo]Z00?o0?mAoookJ_oonfX00ooonfX00ol0Yooo047ooookJP0;oookJP;og03o2_oo
nfX00oooAP3ooo]ZoookJP03oookJP;oobP03_oonfX00ol0ooOooo]ZoookJP04oookJP;o0?ng00?o
k`3ooookJ_oonfX01OoonfX00ol0iOoooo]ZoookJP03oookJPGoo`0000?o02gooookJ_oonfX00_oo
nfX00ooo003o0?goool00007ool000Gooo]Z0_l0=ol3oookJP03ooo90?oo@`3ooo]Z00Gooo]Z00?o
o`00o`3o/ooob@000_oob@000ooonf[o0?nfoookJP06oookJP03ol00oooonf[ooo]Z01Kooo]Z00?o
0?lTojGo0?oonfX04_oonfX4o`0000Wooo]Z3?oo00001?oonf[oo`00ool00?oo000;oookJP;oo`00
6ooonfX:ool000gooo]Z0ooo03<[oookJP?oo`232_oonfX01?lVo`3o0?nHo`3oV?l0oiP>oookJP;o
h?l07ooonfX2ooX0oeGooo]Z00?oQ_l0oookJ_oonfX00_oo=`09oookJP03oooL0?oonf[ooo]Z00Co
oo]Z00?oBOl0oookJ_oonfX01?oonfX2oonR0005oom<0?oonf[ooo]ZoookJ_l0oe401OoonfX00ol0
Yooo047ooookJP0;oookJP;og03o2ooonfX00oooAP3ooo]ZoookJP02oookJP03oon90?oonf[ooo]Z
00gooo]Z0_l0ooL5oookJP;o0?ng00?ok`3ooookJ_oonfX01OoonfX00ol0iOoooo]ZoookJP04oook
JP05ool/0?oonf[o4_l0oookJ_l0;Ol01_oonfX00ol0oOoo0?n^oookJP03oookJP;oo`2Q1_oonfX2
o`0go`?ooo]Z00?ood<0oookJ_oonfX01OoonfX00ol0ok?ooo]ZoookJP02oookJP03o`3o]_oonf[o
oo]Z00Kooo]Z00?o`03ooookJ_oonfX05_oonfX00onUo`3ooo]ZoookJP0AoookJPCo0000F?oonfX3
ool0<bcooo]Z0ooo08<9oookJP04obKo0?l0oiSo0?nHo`3oV0kooo]Z0_oPo`0PoookJP;onP3o;_oo
nfX002cooo]Z00?oocL0oookJ_oonfX01ooonfX2oooL00Gooo]Z0_m9o`06oookJP03oonR0?ooC03o
oo]Z00?ooo]Z00?o0?mAoookJ_oonfX00ooonfX00ol0Yooo047ooookJP0;oookJP03om`0oooonf[o
oo]Z00Wooo]Z00?oodH0oookJ_oonfX00_oonfX00oooR@3oobP0oookJP0>oookJP03o`3omooonf[o
oo]Z00Cooo]Z00?o0?ngonl0oooonfX01ooonfX00ol0iOoooo]ZoookJP03oookJPOoo`000ooonfX0
0ooo003o0?goool00005ool00003ool0XOoonf[ooo]Z00Cooo]Z00?o03OooookJ_oonfX00_oonfX0
0ooob@3ood<0oookJP05oookJP03ool00?l0ok?oolT000CoolT01ooonfX00oo00?oooo]ZoookJP0F
oookJP03o`3o9?nUo`3ooo]Z01?ooo]Z0_l00002ool000Wooo]Z4Ooo000:oookJPGoo`006?oonfX8
ool000cooo]Z0ooo03<[oookJP?oo`232_oonfX01?lVo`3o0?nHo`3oV?l0oiP?oookJP;oh?l07ooo
nfX2ooX0oeWooo]Z00?oocL0oookJ_oonfX01ooonfX2oooL00Gooo]Z0_m9o`06oookJP03oonR0?oo
C03ooo]Z00?ooo]Z00?o0?mAoookJ_oonfX00ooonfX00ol0Yooo047ooookJP0;oookJP03om`0oooo
nf[ooo]Z00[ooo]Z00CoodH0oookJ_oonf[ooo]Z0_ooR@0?oookJP03o`3omooonf[ooo]Z00Cooo]Z
00?o0?ngonl0ooo_0?l01ooonfX00ol0iOoooo]ZoookJP04oookJP05ool/0?oonf[o4_l0oookJ_l0
;Ol01_oonfX00ol0oOoo0?n^oookJP03oookJP03ool0XOoonf[ooo]Z00Gooo]Z00?o03OooookJ_oo
nfX00_oonfX00ooo@`3ooo]ZoookJP05oookJP03o`3o/ooonf[ooo]Z00;ooo]Z00?o0?nfoookJ_oo
nfX01_oonfX00oo00?oooo]ZoookJP0FoookJP03ojGo0?oonf[ooo]Z01;ooo]Z1?l0001EoookJP?o
o`0c;?oonfX3ool0P`Wooo]Z00Co9_l0o`3oV?l0oiSo0?nH3ooonfX2on3o023ooo]Z0_oj0?l`oook
JP00:ooonfX00ooo=`3ooo]ZoookJP07oookJP03oooL0?oonf[ooo]Z00Cooo]Z00?oBOl0oookJ_oo
nfX01OoonfX00oooXP3ooo]ZoookJP02oookJP;o0?mA1?oonfX2o`2Wo`gooo]Z00?og03ooookJ_oo
nfX02?oonfX2oolX00Cooo]Z00?oohT0oookJ_oonfX03_oonfX00ol0ooOooo]ZoookJP04oookJP03
o`3o]oo_0?oooo]Z00Kooo]Z0_l0iOl5oookJPWoo`0000?ooo]Zool00?l0oOl01Ooo00000ooonf[o
o`2QoookJP05oookJP03o`0goooonf[ooo]Z00;ooo]Z0_oo@`07oookJP03o`3o/ooo003oolT000Go
olT01OoonfX00oo00?oooo]ZoookJP0GoookJP03o`3o9?nUo`3ooo]Z01?ooo]Z0_l00005ool000Ko
oo]Z4_oo0009oookJPOoo`005_oonfX6ool000_ooo]Z0ooo03<YoookJPGoo`002?oonfX3ool000?o
0?nH3ooonfX3on3o01oooo]Z0_oj0?l<oookJP;oool0C?oonfX00ooo=`3ooo]ZoookJP07oookJP03
oooL0?oonf[ooo]Z00Cooo]Z00?oBOl0oookJ_oonfX01OoonfX00oooXP3ood`0oookJP02oookJP;o
0?mA1?oonfX2o`2Wo`gooo]Z00?og03ooookJ_oonfX02OoonfX2oom600?ooo]Z00?oohT0oookJ_oo
nfX03_oonfX00ol0ooOooo]ZoookJP04oookJP03o`3o]oo_0?oooo]Z00Kooo]Z0_l0iOl6oookJP03
ool/0?oonf[o4_l000;o02go1_oonfX00ol0oOoo0?n^oookJP03oookJP03ool0XOoonf[ooo]Z00Go
oo]Z00Co03OooookJ_oonf[ooo]Z0_oo@`07oookJP03o`3o/ooonf[ooo]Z00;o0=Go00?o0?nfoook
J_oonfX01_oonfX00oo00?oooo]ZoookJP0GoookJP03ojGo0?oonf[ooo]Z01;ooo]Z1?l0001Boook
JP?oo`0c;OoonfX2ool0P`[ooo]Z00?o9_l0o`3oV?l0oiP04?oonfX2on3o023ooo]Z0_oj0?l<oook
JP;oool09?oonfX002[ooo]Z00?oocL0oookJ_oonfX01_oonfX2oooL00Kooo]Z00?oBOl0oookJ_oo
nfX01?oonfX2oonR00Cooo]Z00?o0?mAoookJ_oonfX00ooonfX00ol0Yooo047ooookJP0;oookJP;o
g03o2_oonfX00ooo:03ooo]ZoookJP03oookJP03oon90?oonf[ooo]Z00gooo]Z0_l0ooL5oookJP;o
0?ng00?ok`3ooookJ_oonfX01OoonfX00ol0iOoooo]ZoookJP03oookJP03ool/0?oo003oo`0000Ko
o`000_oonfX00ooo003o0?goool00003ool000;ooo]Z00?oo`2QoookJ_oonfX01?oonfX00ol0=ooo
oo]ZoookJP02oookJP03oom30?oonf[ooo]Z00Kooo]Z00?o0?ncool00?oob@001ooob@03oookJP03
ol00oooonf[ooo]Z01Oooo]Z00?o0?lTojGo0?oonfX05?oonfX2o`0000Ooo`000ooonfX5oolX00oo
o`0000?oobP0oookJ_oonfX01OoonfX9ool000;ooo]Z1?oo:00?oookJP?oo`002_oonfX3ool0<bGo
oo]Z2_oo0003oookJPOoo`000ol0oiP@oookJP;oh?l08?oonfX2ooX0o`_ooo]Z0oooo`1=oookJP03
oolg0?oonf[ooo]Z00Kooo]Z0_oog006oookJP03odWo0?oonf[ooo]Z00Cooo]Z0_ooXP001OooC03o
oo]ZoookJ_oonf[o0?mA00Gooo]Z00?o0:Ooo`11oooonfX02ooonfX2om`0o`_ooo]Z00?oodH0oook
J_oonfX00_oonfX00oooR@3ooo]ZoookJP0>oookJP03o`3omooonf[ooo]Z00?ooo]Z0_l0okL00oo_
0?oooo]ZoookJP05oookJP03o`3Uoooonf[ooo]Z00Cooo]Z0_oo;002oa;o0003o`0]oooonf[ooo]Z
00Cooo]Z0_l0oOl5oookJP03ool0XOoonf[ooo]Z00Gooo]Z00Ko03OooookJ_oonf[ooo]Zoom30?oo
b@07oookJP06o`3o/ooonf[ooo]Zo`3Eoooonf[o0?nf2?oonfX00oo00?oooo]ZoookJP0GoookJP03
ojGo0?oonf[ooo]Z01?ooo]Z1?l0001?oookJP?oo`0c;OoonfX3ool0P`Wooo]Z00Co9_l0o`3oV?l0
oiSo0?nH4?oonfX2on3o023ooo]Z0_oj0?l;oookJP?oool09_oonfX003;ooo]Z00?oom`0oookJ_oo
nfX01?oonfX2odWo00Kooo]Z00?ooj80oom<0?oonfX00ooonfX00ol0oe7ooo]ZoookJP03oookJP03
o`2Wool0@Ooooo]Z00_ooo]Z00?og03ooookJ_oonfX02OoonfX00ooo:03ooo]ZoookJP03oookJP03
oon90?oonf[ooo]Z00gooo]Z00?o0?ogoookJ_oonfX01?oonfX00ol0okOok`3ooookJP07oookJP03
o`3Uoooonf[ooo]Z00?ooo]Z00?oob`0oookJ_oo00001Ooo0004oookJP04o`3moooo003oo`00ool0
00?ooo]Z00?oo`2QoookJ_oonfX01?oonfX00ol0=ooooo]ZoookJP02oookJP03oom30?oonf[ooo]Z
00Kooo]Z00?o0?ncool00?oo00002Ooob@000ooonf[o`03ooookJP0HoookJP03o`3o9?nUo`3ooo]Z
01Gooo]Z0_l00008ool000;ooo]Z1_oo:00>ool000;oobP01_oonfX;ool000WoobP02_oonfX00ooo
003ooo]ZoookJP04oookJPKoo`0c9?oonfXEool000?o0?nH0_oo000?oookJP;oh?l08?oonfX2ooX0
o`_ooo]Z0_ooo`1HoookJP03oooL0?oonf[ooo]Z00Cooo]Z0_m9o`06oookJP03oonR0?ooC03ooo]Z
00?ooo]Z00?o0?mAoookJ_oonfX00ooonfX00ol0Yooo047ooookJP0;oookJP03om`0oooonf[ooo]Z
00[ooo]Z00?oodH0oookJ_oonfX00_oonfX00oooR@3ooo]ZoookJP0=oookJP;o0?og1OoonfX00ol0
okOooo]Zonl0o`07oookJP03o`3Uoooonf[ooo]Z00Cooo]Z00Goob`0oookJ_lBo`3ooo]Zo`0]o`06
oookJP03o`3mool0ojkooo]Z00Cooo]Z00?oo`2QoookJ_oonfX01OoonfX01_l0=ooooo]ZoookJ_oo
nf[ood<0ooo900Oooo]Z00Ko0?ncoookJ_oonf[o0=GooookJ_l0okH8oookJP03ol00oooonf[ooo]Z
01Oooo]Z00?oYOl0oookJ_oonfX05?oonfX4o`0004Wooo]Z1_oo03<]oookJP?oo`232_oonfX3o`3o
V17ooo]Z0_oPo`0PoookJP;onP3o2ooonfX2oooo02Wooo]Z000aoookJP03oooL0?oonf[ooo]Z00Co
oo]Z00?oBOl0oookJ_oonfX01?oonfX2oonR00Cooo]Z0_l0oe44oookJP;o0:Oo3OoonfX00ooL0?oo
oo]ZoookJP09oookJP03oolX0?oonf[ooo]Z00;ooo]Z0_ooR@0?oookJP03o`3omooonf[ooo]Z00Co
oo]Z00?o0?ngonl0oooonfX01ooonfX00ol0iOoooo]ZoookJP03oookJP03ool/0?oonf[oo`0000Co
o`001OoonfX00ol0oOooo`00ool00004oookJP03ool0XOoonf[ooo]Z00Cooo]Z00?o03OooookJ_oo
nfX00_oonfX00ooo@`3ooo]ZoookJP06oookJP03o`3o/ooo003oo`0000SoolT00_oonfX00oo00?oo
oo]ZoookJP0HoookJP03ojGo0?oonf[ooo]Z00Kooo]Z0_oo000=oookJP;o00002?oo0003oookJPGo
obP03ooo0002oolX00Cooo]Z3?oo000>oolX00Gooo]Z1ooo03<ZoookJP_oo`000_oonfX6ool000;o
0?nH0ooo000>oookJP?oh?l07ooonfX3ooX0o`_ooo]Z0_ooo`1IoookJP03oooL0?oonf[ooo]Z00Co
oo]Z00?oBOl0oookJ_oonfX01?oonfX2oonR0004oom<0?oonf[ooo]ZoookJP;o0?mA1?oonfX2o`2W
o`gooo]Z00?og03ooookJ_oonfX02_oonfX01?ooAP3ooo]ZoookJ_oonfX2oon900oooo]Z00?o0?og
oookJ_oonfX01?oonfX00ol0okOooo]Zonl0o`07oookJP03o`3Uoooonf[ooo]Z00Cooo]Z00Goob`0
oookJ_lBo`3ooo]Zo`0]o`06oookJP03o`3mool0ojkooo]Z00Cooo]Z00?oo`2QoookJ_oonfX01Ooo
nfX01_l0=ooooo]ZoookJ_oonf[ood<0ooo900Oooo]Z00Ko0?ncoookJ_oonf[o0=GooookJ_l0okH8
oookJP03ol00oooonf[ooo]Z01Oooo]Z00?o0?lTojGo0?oonfX05OoonfX5o`0002gooo]Z1?oo03<@
oookJPOoo`0c<?oonfX3ool0P`[ooo]Z00?o9_l0o`3oV?l0oiP04OoonfX3on3o01oooo]Z0ooj0?l:
oookJP03ool0]oooo`3oool002_ooo]Z000_oookJP;oom`01OoonfX2odWo00Kooo]Z00?ooj80oom<
0?oonfX00ooonfX00ol0oe7ooo]ZoookJP03oookJP03o`2Wool0@Ooooo]Z00_ooo]Z0_oL0?l:oook
JP;oobP01?oonfX00oooR@3ooo]ZoookJP0>oookJP03o`3omooonf[ooo]Z00?ooo]Z0_oo:0000oo_
0?oooo]ZoookJP05oookJP;o0>Go1OoonfX00ooo;03ooo]Zool00003ool000Kooo]Z00?o0?goool0
0?oonfX01?oonfX00ooo0:7ooo]ZoookJP04oookJP03o`0goooonf[ooo]Z00;ooo]Z00Good<0oook
J_oonf[ooo]ZoolX0004oookJP03o`3o/ooo003oo`0000OoolT00ooonfX00oo00?oooo]ZoookJP0H
oookJP03ojGo0?oonf[ooo]Z00Oooo]Z0ooo000<oookJP03o`000?oo003oo`0000Koo`001?oonfX6
oolX00?oo`001Ooo:0000ooonf[oo`00ool00004ool000;oobP00ooonfX<ool0013oobP00ooo03<a
oookJP[oo`000ooonfX3ool000?o0?nH1?oo000=oookJP;oh?l08?oonfX2ooX0o`_ooo]Z0oooo`1I
oookJP;oom`01OoonfX2odWo00Kooo]Z00?ooj80oom<0?ooC0000ooonfX00ol0oe7ooo]ZoookJP03
oookJP03o`2Wool0@Ooooo]Z00cooo]Z00?og03ooookJ_oonfX02OoonfX2oom600?ooo]Z00?oohT0
oookJ_oonfX03_oonfX00ol0ooOooo]ZoookJP03oookJP;o0?ng0_o_0?l6oookJP;o0>Go1_oonfX0
0ooo;03ooo]Zoa;o0002o`0]o`Kooo]Z00?o0?goo`3o[_oonfX01?oonfX00ooo0:7ooo]ZoookJP05
oookJP06o`0goooonf[ooo]ZoookJ_oo@`3oolT01ooonfX01_l0ok?ooo]ZoookJ_l0eOoooo]Zo`3o
]PSooo]Z00?o`03ooookJ_oonfX05ooonfX00ol0obCoYOl0oookJP0FoookJPCo0000<_oonfX@ool0
<cCooo]Z0ooo08<;oookJP?o0?nH4OoonfX2on3o023ooo]Z0_oj0?l;oookJP?oool0;OoonfX002ko
oo]Z00?oom`0oookJ_oonfX01?oonfX00om9o`3ooo]ZoookJP05oookJP03oonR0?oonf[ooo]Z00?o
oo]Z00?o0?mAoookJ_oonfX00ooonfX00ol0Yooo047ooookJP0;oookJP03om`0oooonf[ooo]Z00Go
oo]Z00GoobP0oookJ_oonf[ooo]ZoolX0005oookJP03oon90?oonf[ooo]Z00gooo]Z0_l0ooL5oook
JP03oolX0?o_0?ook`3o00Oooo]Z00?o0>GooookJ_oonfX01?oonfX00ooo;03ooo]Zool00002ool0
00Kooo]Z00?o0?n^o`3moooonfX01OoonfX00ooo0:7ooo]ZoookJP04oookJP06o`0goooonf[ooo]Z
oookJ_oob@3ood<01?oonfX2oolX00;ooo]Z00Co0?ncoookJ_oo003oo`001Ooob@04oookJP03ol00
oooonf[ooo]Z01Sooo]Z00?oYOl0oookJ_oonfX01ooonfX6ool000[ooo]Z00?o0000ool00?oo0000
1Ooo0005oookJPkoobP00_oonfX6ool000;oobP00_oonfX;ool00003oookJ_oo:03oobP000_oobP0
>?oonfX7ool000Gooo]Z00?oo`00o`3oV?l0oiP01Ooo000<oookJP?oh?l08?oonfX2ooX0o`_ooo]Z
0_ooo`1KoookJP03oooL0?oonf[ooo]Z00Cooo]Z00?oBOl0oookJ_oonfX01OoonfX00oooXP3ood`0
oookJP03oookJP03o`3oDOoonf[ooo]Z00?ooo]Z00?o0:Ooo`11oooonfX02ooonfX2om`0o`_ooo]Z
00?oodH0oookJ_oonfX00_oonfX00oooR@3ooo]ZoookJP0=oookJP;o0?og1OoonfX00ol0okOooo]Z
onl0o`07oookJP03o`3Uoooonf[ooo]Z00Cooo]Z0_oo;0000ooonf[o4_l0o`0]o`07oookJP03o`3m
ool0ojkooo]Z00Cooo]Z00?oo`2QoookJ_oonfX01OoonfX01_l0=ooooo]ZoookJ_oonf[ood<0ooo9
00Oooo]Z00Ko0?ncoookJ_oonf[o0=GooookJ_l0okH8oookJP03ol00oooonf[ooo]Z01Oooo]Z00?o
0?lTojGo0?oonfX05ooonfX4o`0000cooo]Z00?o00;ooookJ_oonfX0IOoonfX2ool0P`_ooo]Z00?o
9_l0o`3oV?l0oiP04OoonfX3on3o01oooo]Z0ooj0?l;oookJP;oool0<?oonfX002cooo]Z0_oog006
oookJP03odWo0?oonf[ooo]Z00Cooo]Z0_ooXP04oookJP;o0?mA1?oonfX2o`2Wo`cooo]Z0_oL0?l8
oookJP04oolX0?oonf[ooo]ZoolX00Gooo]Z00?oohT0oookJ_oonfX03OoonfX00ol0ooOooo]Zoook
JP04oookJP03oolX0?o_0?oooo]Z00Oooo]Z00?o0>GooookJ_oonfX01?oonfX01Ooo;03ooo]Zool0
0?oo003o02go00Kooo]Z00?o0?n^o`3moooonfX01OoonfX00ooo0:7ooo]ZoookJP04oookJP06o`0g
oooonf[ooo]ZoookJ_oob@3ood<01?oonfX5oolX0003oookJ_oo003oo`0000CoolT01OoonfX00oo0
0?oooo]ZoookJP09oookJP03ool00?oonf[ooo]Z00gooo]Z00?oYOl0oookJ_oonfX01ooonfX7ool0
00Wooo]Z00?o0000ool00?oo00001Ooo0006oookJPgoobP00_oonfX7ool000;oobP000?ooo]Zool0
0?oo00000_oo0008oookJPWoobP0??oonfX6ool000Cooo]Z0ol0oiP6ool000_ooo]Z0_oPo`0Poook
JP?onP3o2ooonfX2oooo05_ooo]Z0_oog006oookJP03odWo0?oonf[ooo]Z00Cooo]Z0_ooXP001?oo
C03ooo]ZoookJ_oonfX2o`3oD@Cooo]Z0_l0Yol=oookJP03om`0oooonf[ooo]Z00[ooo]Z00?oodH0
oookJ_oonfX00_oonfX00oooR@3ooo]ZoookJP0=oookJP03o`3omooonf[ooo]Z00Cooo]Z00?o0?ng
oookJ_o_0?l01ooonfX00ol0iOoooo]ZoookJP04oookJP05ool/0?oonf[ooo]Zoa;o0?l0;Ol01ooo
nfX00ol0oOoooo]ZoookJP04oookJP03ool0XOoonf[ooo]Z00Gooo]Z00Go03OooookJ_oonf[ooo]Z
oom30008oookJP06o`3o/ooonf[ooo]Zo`3Eoooonf[o0?nf2?oonfX00oo00?oooo]ZoookJP0Hoook
JP03o`3o9?nUo`3ooo]Z01Oooo]Z1?l0000<oookJP03o`02oooonf[ooo]Z013ooo]Z00?o0?nHoook
J_oonfX0GOoonfX3o`3oV13ooo]Z0ooPo`0PoookJP;onP3o2ooonfX00ooo0;Ooool0oooo000boook
JP00:ooonfX00ooog03ooo]ZoookJP04oookJP;oBOl01_oonfX00oooXP3ood`0oookJP03oookJP03
o`3oDOoonf[ooo]Z00?ooo]Z00?o0:Ooo`11oooonfX02ooonfX00ooL0?oooo]ZoookJP07oookJPCo
obP01?oonfX2oon900oooo]Z00?o0?ogoookJ_oo:0000_oonfX2ool00003oolX0?o_0?oooo]Z00Oo
oo]Z00?o0>GooookJ_oonfX00ooonfX2ool/0004oa;o0?oo003ooo]Zo`0]o`Kooo]Z0_oo:006oook
JP03ool0XOoonf[ooo]Z00Cooo]Z00Ko03OooookJ_oonf[ooo]Zooo90?oo@`04oookJPKoobP000?o
oo]Zool00?oo00000ooob@05oookJP03ol00oooonf[ooo]Z00[ooo]Z0_oo000=oookJP03ojGo0?oo
nf[ooo]Z00Sooo]Z2Ooo0007oookJP03o`000?oo003oo`0000Coo`001ooonfX=oolX0003oookJ_oo
003oo`0000Ooo`000_oo:00<oookJPKoobP0?ooonfX5ool000?ooo]Z0_l0oiP3oookJPGoo`002_oo
nfX2on3o023ooo]Z0_oj0?l;oookJP?oool0G?oonfX00ooog03ooo]ZoookJP04oookJP;oBOl01_oo
nfX00oooXP3ood`0oom<0003oookJP03o`3oDOoonf[ooo]Z00?ooo]Z00?o0:Ooo`11oooonfX03?oo
nfX00ooL0?oooo]ZoookJP0:oookJP04oom60?oonf[ooo]ZoookJP;oohT03ooonfX00ol0ooOooo]Z
oookJP03oookJP;o/ol000?ooo]Zonl0oooonfX01_oonfX00ol0iOoooo]ZoookJP04oookJP05ool/
0?oonf[o4_l0oa;o0?l0;Ol01_oonfX2o`3mo`Kooo]Z00?oo`2QoookJ_oonfX01OoonfX01Ol0=ooo
oo]ZoookJ_oonf[ood<000Sooo]Z00Ko0?ncoookJ_oonf[o0=GooookJ_l0okH7oookJP;o`03o6_oo
nfX00ol0obCoYOl0oookJP0HoookJPCo00003OoonfX00ol00_oooo]ZoookJP0@oookJP03o`3oV?oo
nf[ooo]Z05[ooo]Z0_l0oiPAoookJP;oh?l08OoonfX2ooX0o`_ooo]Z0oooo`0doookJP00:_oonfX0
0ooog03ooo]ZoookJP04oookJP03odWo0?oonf[ooo]Z00Cooo]Z0_ooXP05oookJP03o`3oDOoonf[o
oo]Z00?ooo]Z00?o0:Ooo`11oooonfX02ooonfX00ooL0?oooo]ZoookJP07oookJPGoobP00ooonfX0
0oooR@3ooo]ZoookJP0=oookJP;o0?og0_oonfX01?oo:03ooo]Zool00?oo0002oolX00Sooo]Z00?o
0>Goool00?oo00000ooonfX00ooo;03ooo]Zoa;o0002oookJP03o`0]oooonf[oobP000Cooo]Z00?o
obP0oookJ_oonfX01OoonfX00ooo0:7ooo]ZoookJP03oookJP;o03Oo0ooonfX00ooob@3ood<0oook
JP04oookJPOoobP000?ooo]Zooo90?oob@001_oonfX00oo00?oooo]ZoookJP0:oookJPCoo`002ooo
nfX00onUo`3ooo]ZoookJP08oookJPcoo`001OoonfX00ol0003oo`00ool00003ool000Sooo]Z3Ooo
:00:ool000?oobP02ooonfX2oolX04Cooo]Z0_oo0002oookJP?o0?nH1_oonfX2ool000Wooo]Z0ooP
o`0PoookJP;onP3o2ooonfX2oooo017ooo]Z0_li0?m;oookJP03oooL0?oonf[ooo]Z00Cooo]Z00?o
BOl0oookJ_oonfX01?oonfX2oonR0003oom<0?oonf[ooo]Z00;ooo]Z00?o0?mAoookJ_oonfX00ooo
nfX00ol0Yooo047ooookJP0;oookJP;og03o2ooonfX2oom600?ooo]Z00?oohT0oookJ_oonfX03_oo
nfX00ol0ooOooo]ZoookJP02oookJP03o`08oonco`3o0?ng00;ok`3o1ooonfX01?l0iOoooo]Zo`3o
hOl0on43oookJP05ool/0?oonf[o4_l0oookJ_l0;Ol01_oonfX00ol0oOoo0?n^oookJP05oookJP03
ool0XOoonf[ooo]Z00Cooo]Z0_l0=ol3oookJP03oom30?oonf[ooo]Z00Kooo]Z00Ko0?ncoookJ_oo
nf[o0=GooookJ_l0okH7oookJP03ol00oooonf[ooo]Z01Wooo]Z00?o0?lTojGo0?oonfX06OoonfX4
o`0000gooo]Z00?o00;ooookJ_oonfX04OoonfX2o`3oV5Oooo]Z0ol0oiP@oookJP?oh?l08?oonfX3
ooX0o`[ooo]Z00?oo`2goooo0?ooo`004OoonfX2ocT0obCooo]Z000`oookJP03odWo0?oonf[ooo]Z
00Cooo]Z00?ooj80oom<0?oonfX00ooonfX2o`3oD@Cooo]Z0_l0Yol<oookJP;og03o2OoonfX7oolX
0003oookJ_ooR@3ooo]Z00kooo]Z00Co0?ogoookJ_oonf[ooo]Z0_oo:0000ooo003oobP0oolX0004
oookJP04ool00?oonf[ooo]Zool000;o0>Go00?oo`00oookJ_oonfX00_oonfX00ooo;03ooo]Zoa;o
0002oookJP03o`0]oooonf[ooo]Z00;oobP00_oonfX00ooo:03ooo]ZoolX0004oookJP;oobP01Ooo
nfX00ol0=ooooo]ZoookJP02oookJP03ooo90?oo@`3ooo]Z00Cooo]Z2Ooo:007oookJP03ol00oooo
nf[ooo]Z00_ooo]Z1Ooo0009oookJP03ojGo0?oonf[ooo]Z00Wooo]Z1ooo00000ooonf[oo`00ool0
0003ool000Cooo]Z00?o0000ool00?oo00000_oo000:oookJPCoobP000?ooo]ZoolX0?oo:0001_oo
:002oookJPKoo`001Ooo:01@oookJP04ool00?oonf[o0?nHo`3oV0Wooo]Z00?oo`00oookJ_oonfX0
1_oonfX2on3o023ooo]Z0ooj0?l;oookJP;oool04OoonfX2ocT0oe?ooo]Z00?oBOl0oookJ_oonfX0
1?oonfX00oooXP3ood`0oom<0003oookJP;o0?mA1?oonfX2o`2Wo`gooo]Z00?og03ooookJ_oonfX0
2_oonfX00oooAP3ooo]ZoookJP02oookJP03oon90?oonf[ooo]Z00gooo]Z0_l0ooL4oookJP04o`08
oonco`3o0?ngonl0o`Kooo]Z00Go01Ooo`3Uool0iOoooo]Zo`3oh@04oookJP05ool/0?oonf[o4_l0
oookJ_l0;Ol01_oonfX00ol0oOoo0?n^oookJP04oookJP;oo`2Q1_oonfX00ol0=ooooo]ZoookJP02
oookJP03oom30?oonf[ooo]Z00Kooo]Z00Ko0?ncoookJ_oonf[o0=GooookJ_l0okH7oookJP03ol00
oooonf[ooo]Z01Wooo]Z00?o0?lTojGo0?oonfX06_oonfX4o`0000gooo]Z00?o00;ooookJ_oonfX0
1?oonfX00oooc@3ooo]ZoookJP0<oookJP03o`3oV?oonf[ooo]Z057ooo]Z0ol0oiPAoookJP;oh?l0
8OoonfX2ooX0o`_ooo]Z00?oo`2goooo0?ooo`004?oonfX3ocT0obKooo]Z000_oookJP03odWo0?oo
nf[ooo]Z00Cooo]Z00?ooj80oom<0?oonfX00ooonfX00ol0oe7ooo]ZoookJP03oookJP03o`2Wool0
@Ooooo]Z00_ooo]Z00?og03ooookJ_oonfX02?oonfX9oolX00oooo]Z00Co0?ogool00?oonf[ooo]Z
0_oo:0000ooo003oobP0oolX0005oookJP06ool00?oonf[oo`00o`3Uoooonf[oo`001?oonfX01?oo
;03ooo]Zoa;o0?oonfX2o`0]o`;ooo]Z1Ooo:002oookJP05oolX0?oonf[ooo]ZoookJ_oo:0001_oo
nfX00ol0=ooooo]ZoookJP02oookJP;ood<01_oonfX7oolX0003o`3o]_oonf[ooo]Z00Gooo]Z00?o
`03ooookJ_oonfX02ooonfX7ool000Oooo]Z00?o0?lTojGo0?oonfX02_oonfX6ool00003oookJ_oo
003oo`0000Koo`000_oonfX00ol0003oo`00ool00002ool000[ooo]Z1?oo:002oookJPOoobP01Ooo
nfX3ool000KoobP0C_oonfX3o`3oV17ooo]Z0ooPo`0PoookJP;onP3o2ooonfX3oooo013ooo]Z0oli
0?mDoookJP03odWo0?oonf[ooo]Z00Cooo]Z00?ooj80oom<0?oonfX00ooonfX00ol0oe7ooo]Zoook
JP03oookJP03o`2Wool0@Ooooo]Z00cooo]Z00?og03ooookJ_oonfX02_oonfX00oooAP3ooo]Zoook
JP02oookJP03oon90?oonf[ooo]Z00gooo]Z00?o0?ogoookJ_oonfX00ooonfX01?l02?oo/ol0oook
J_o_0?l6oookJP05o`0Gool0iOoooo]ZoookJ_l0on400ooonfX2ool/0004oookJ_lBo`3o02goo`0]
o`Kooo]Z00?o0?goo`3o[_oonfX01?oonfX00ooo0:7ooo]ZoookJP05oookJP04o`0goooonf[ooo]Z
oookJP;ood<02?oonfX01_l0ok?ooo]ZoookJ_l0eOoooo]Zo`3o]POooo]Z00?o`03ooookJ_oonfX0
6_oonfX00onUo`3ooo]ZoookJP0JoookJP;o000000?oom<0o`000?oonfX03?oonfX00ol00_oooo]Z
oookJP04oookJP03ooo=0?oo0;[ooo]Z00gooo]Z0_l0oiQ>oookJP?o0?nH4OoonfX3on3o023ooo]Z
0ooj0?l;oookJP?oool04?oonfX2ocT0obWooo]Z000]oookJP;oBOl01OoonfX2oonR00Gooo]Z00?o
0?mAoookJ_oonfX00ooonfX00ol0Yooo047ooookJP0;oookJP03om`0oooonf[ooo]Z00Sooo]Z2?oo
:0000oooR@3ooo]ZoookJP0<oookJP;o0?og00Cooo]Zool00?oo:03oobP00_oo0004oolX00?ooo]Z
0ooo00000ol0iOoooo]Zool00004oookJP05ool/0?oonf[o4_l0oookJ_l0;Ol00ooonfX6oolX0006
oookJ_oo:03oobP0oolX0?oonf[oobP01_oonfX00ol0=ooooo]ZoookJP02oookJP03oom30?oonf[o
oo]Z00Gooo]Z1ooo:0000ol0okKooo]ZoookJP05oookJP03ol00oooonf[ooo]Z00cooo]Z2?oo0005
oookJP03o`3o9?nUo`3ooo]Z00[ooo]Z1_oo0002oookJPSoo`000_oo:0001?l0003oo`00ool00?oo
000;oookJPCoobP00_oonfX7oolX00Oooo]Z2?oo:01:oookJP?o0?nH4OoonfX3on3o027ooo]Z0_oj
0?l;oookJP;oool04OoonfX2ocT0oeGooo]Z0_m9o`05oookJP;ooj8000?ood`0oookJ_oonfX00_oo
nfX00ol0oe7ooo]ZoookJP03oookJP03o`2Wool0@Ooooo]Z00cooo]Z00?og03ooookJ_oonfX02_oo
nfX01?ooAP3ooo]ZoookJ_oonfX2oon900oooo]Z00?o0?ogoookJ_oonfX00ooonfX2ok?o0003oook
J_o_0?oooo]Z00Gooo]Z00Go01Ooo`3Uoooonf[ooo]Zo`3oh@03oookJP05ool/0?oonf[ooo]Zoa;o
0?l0;Ol01ooonfX00ol0oOoo0?n^oookJP04oookJP03ool0XOoonf[ooo]Z00Gooo]Z00Ko03Oooook
J_oonf[ooo]Zoom30?oob@08oookJP06o`3o/ooonf[ooo]Zo`3Eoooonf[o0?nf1ooonfX00oo00?oo
oo]ZoookJP0?oookJP03oomk0?oonf[ooo]Z00Sooo]Z00?oYOl0oookJ_oonfX03?oonfX00ol0TOoo
oo]ZoookJP0<oookJP;o000000?oom<0o`000?oonfX03?oonfX00ol00_oooo]ZoookJP05oookJP03
ooo=0?oonf[ooo]Z00_ooo]Z0_oPo`000ooonf[o0?nHo`3oV019oookJP?o0?nH4OoonfX3on3o027o
oo]Z0_oj0?l;oookJP03ool0]oooo`3oool0017ooo]Z0_li0?l[oookJP00;?oonfX00om9o`3ooo]Z
oookJP04oookJP03oonR0?ooC03ooo]Z00?ooo]Z0_l0oe45oookJP03o`2Woooonf[ooo]Z00[ooo]Z
0_oL0?l;oookJPKoobP000?oohT0oookJ_oonfX03OoonfX00ol0ooOooo]Zool00004ool000OoobP0
00?ooo]Zool00?oo00001?oo0004oookJP05ool/0?oonf[o4_l0oookJ_l0;Ol01?oonfX;oolX00Ko
oo]Z00?o03OooookJ_oonfX00_oonfX00ooo@`3ooo]ZoookJP05oookJPKoobP000?ooo]Zo`3o]_oo
nfX01_oonfX00oo00?oooo]ZoookJP0<oookJPOoo`001_oonfX00ol0obCoYOl0oookJP0;oookJPGo
o`000ooonfX8ool000GoobP000?o0000oookJ_oonfX02_oonfX3oolX00?ooo]Z1_oo:007oookJP[o
obP000?o0?nHoookJ_oonfX0@_oonfX3o`3oV17ooo]Z0ooPo`0QoookJP?onP3o2ooonfX2oooo017o
oo]Z0_li0?mFoookJP03odWo0?oonf[ooo]Z00Cooo]Z00?ooj80oom<0?ooC0000ooonfX2o`3oD@Go
oo]Z00?o0:OooookJ_oonfX02ooonfX2om`0o`cooo]Z00GoodH0oookJ_oonf[ooo]Zoon9000?oook
JP;o0?og1OoonfX01?nco`3o0?ngonl0ooo_0?l5oookJP;o01Oo00Co0>GooookJ_oonf[o0?oQ0ooo
nfX01Ooo;03ooo]ZoookJ_lBo`3o02go00Oooo]Z00?o0?gooookJ_oonfX01?oonfX00ooo0:7ooo]Z
oookJP05oookJP06o`0goooonf[ooo]ZoookJ_oo@`3oolT02?oonfX01_l0ok?ooo]ZoookJ_l0eOoo
oo]Zo`3o]POooo]Z00?o`03ooookJ_oonfX04?oonfX00oooN`3ooo]ZoookJP07oookJP03ojGo0?oo
nf[ooo]Z00gooo]Z00?o097ooookJ_oonfX03?oonfX2o`000003oooC0?l0003ooo]Z00cooo]Z00?o
00;ooookJ_oonfX01OoonfX00oooc@3oo`2joookJP0=oookJP03on3o0?oonf[ooo]Z00?o0?nH@ooo
nfX3o`3oV17ooo]Z0ooPo`0QoookJP?onP3o2ooonfX00ooo0;Ooool0oooo000@oookJP?o>@3o;Ooo
nfX002_ooo]Z00?oBOl0oookJ_oonfX01?oonfX00oooXP3ood`0oookJP03oookJP03o`3oDOoonf[o
oo]Z00?ooo]Z0_l0Yol<oookJP03om`0oooonf[ooo]Z00[ooo]Z1Ooo:0000ooonf[oohT0oookJP0>
oookJP03o`3omooonf[ooo]Z00Goo`002?oo:006ool000?ooo]Z00Goob`0oookJ_lBo`3ooo]Zo`0]
o`04oookJPgoobP01?oonfX00ol0=ooooo]ZoookJP02oookJP03oom30?oonf[ooo]Z00Kooo]Z1?oo
:0000ol0eOoooo]Zo`3o]P07oookJP03ol00oooonf[ooo]Z00gooo]Z1_oo0007oookJP03o`3o9?nU
o`3ooo]Z00_ooo]Z1?oo00001?oonf[o001oo`00Ool007l8ool000OoobP02ooonfX3oolX00Coo`00
1Ooo:007oookJP_oobP00ol0oiPloookJPGo0?nH4OoonfX3on3o027ooo]Z0ooj0?l;oookJP?oool0
4OoonfX2ocT0oeOooo]Z00?oBOl0oookJ_oonfX01?oonfX00oooXP3ood`0oookJP03oookJP03o`3o
DOoonf[ooo]Z00?ooo]Z0_l0Yol=oookJP03om`0oooonf[ooo]Z00[ooo]Z0_ooAP03oookJP03oon9
0?oonf[ooo]Z00gooo]Z00?o0?ogoookJ_oonfX00ooonfX01?l02?oo/ol0o`3o]oo_0?l6oookJP04
o`0Gool0iOoo0>GooookJP;o0?oQ0ooonfX01Ooo;03ooo]ZoookJ_lBo`3o02go00Kooo]Z0_l0oOl6
oookJP03ool0XOoonf[ooo]Z00Gooo]Z00Ko03OooookJ_oonf[ooo]Zoom30?oob@08oookJP06o`3o
/ooonf[ooo]Zo`3Eoooonf[o0?nf1ooonfX00oo00?oooo]ZoookJP0@oookJP03oomk0?oonf[ooo]Z
00Sooo]Z00?oYOl0oookJ_oonfX03?oonfX00ol0TOoooo]ZoookJP05o`00O`Sooo]Z00Co0000oooC
0?l0003o00003OoonfX00ol00_oooo]ZoookJP05oookJP03ooo=0?oo0;[ooo]Z00kooo]Z0_oPo`03
oookJP;o0?nH??oonfX5o`3oV17ooo]Z0ooPo`0RoookJP;onP3o3?oonfX3oooo013ooo]Z0_li0?l`
oookJP00:_oonfX00om9o`3ooo]ZoookJP03oookJP;ooj8000?ood`0oookJ_oonfX00_oonfX00ol0
oe7ooo]ZoookJP03oookJP03o`2Wool0@Ooooo]Z00_ooo]Z00?og03ooookJ_oonfX02_oonfX4oolX
00;ooo]Z00?oohT0oookJ_oonfX03?oonfX2o`3om`;ooo]Z1ooo0005oolX00Woo`000_oo;002oa;o
0003oookJ_l0;Ooooo]Z00?ooo]Z3ooo:002oookJP03o`0goooonf[ooo]Z00;ooo]Z00?ood<0oook
J_oonfX01_oonfX4oolX0003o`3Eoooonf[o0?nf00Oooo]Z00?o`03ooookJ_oonfX03OoonfX6ool0
00Oooo]Z00?o0?lTojGo0?oonfX02ooonfX4ool00003oookJ_l007oo001o00;o001o1ooo00000ooo
nf[oobP0oolX0006oolX00Wooo]Z00?oo`00oolX0?oo:0001_oo0004oolX00Kooo]Z3Ooo:002oook
JP;o0?nH=?oonfX6o`3oV1;ooo]Z1?oPo`0QoookJP?onP3o3?oonfX2oooo017ooo]Z0oli0?l;oook
JP;oo`3:BooonfX00om9o`3ooo]ZoookJP03oookJP;ooj8000?ood`0oookJ_oonfX00_oonfX00ol0
oe7ooo]ZoookJP03oookJP03o`2Wool0@Ooooo]Z00cooo]Z00?og03ooookJ_oonfX02_oonfX00ooo
AP3ooo]ZoookJP02oookJP03oon90?oonf[ooo]Z00gooo]Z00?o0?ogoookJ_oonfX00ooonfX2ok?o
0003o`3o]oo_0?oooo]Z00Gooo]Z00Go01Ooo`3Uoooonf[ooo]Zo`3oh@03oookJP;oob`000Cooo]Z
oa;o0?lBo`3o02go1_oonfX00ol0oOoo0?n^oookJP05oookJP03ool0XOoonf[ooo]Z00Cooo]Z0_l0
=ol3oookJP03oom30?oob@3ooo]Z00Oooo]Z00Ko0?ncoookJ_oonf[o0=GooookJ_l0okH7oookJP03
ol00oooonf[ooo]Z013ooo]Z00?oog/0oookJ_oonfX02?oonfX00onUo`3ooo]ZoookJP0<oookJP03
o`2Aoooonf[ooo]Z00Oo001o1ooonfX01?l0003oom<0o`000?l0000=oookJP03o`02oooonf[ooo]Z
00Kooo]Z00?oold0oookJ_oonfX03ooonfX00ooPo`3ooo]ZoookJP02oookJP?o0?nH=?oonfX5o`3o
V1;ooo]Z1?oPo`0RoookJP?onP3o3?oonfX2oooo013ooo]Z0oli0?l<oookJP;oo`3:9?oonfX002oo
oo]Z00?ooj80oom<0?oonfX00ooonfX2o`3oD@Gooo]Z00?o0:Ooo`11oooonfX02_oonfX2om`0o`co
oo]Z0ooo:002oookJP;oohT03_oonfX01?l0ooOooo]ZoookJ_oonfX9ool00003oolX0?oo003oo`00
00Woo`0000?oob`0ool00?lBo`000_oonfX00ol0;Ooooo]ZoookJP03oookJQ3oobP000?o03Oooook
J_oonfX00_oonfX00ooo@`3ooo]ZoookJP07oookJP;oobP000Cooo]Zo`3Eoooonf[o0?nf1ooonfX0
0oo00?oooo]ZoookJP0>oookJPCoo`002?oonfX00ol0obCoYOl0oookJP0<oookJP?oo`0000?ooo]Z
o`00Ool007l00_l007l9ool000SoobP00ooonfX5ool00004oookJ_oo003oo`00oolX00Koo`001?oo
:00:oookJP[oobP00ooonfX4o`3oV1Cooo]Z1OooN@0BoookJPGo0?nH5OoonfX3on3o02?ooo]Z0_oj
0?l<oookJP?oool04OoonfX2ocT0o`cooo]Z0_oo0<YBoookJP03oonR0?ooC03ood`000?ooo]Z0_l0
oe45oookJP03o`2Wool0@Ooooo]Z00_ooo]Z0_oL0?l<oookJP04oom60?oonf[ooo]ZoookJP;oohT0
3ooonfX00ol0ooOooo]ZoookJP03oookJP04ok?o0?l0okOok`3oonl0o`Kooo]Z00Go01Ooo`3Uoooo
nf[ooo]Zo`3oh@03oookJP06ool/0?oonf[ooo]Zoa;o0?oonf[o02go1_oonfX00ol0oOoo0?n^oook
JP05oookJP03ool0XOoonf[ooo]Z00Cooo]Z00?o03OooookJ_oonfX00_oonfX00ooo@`3oolT0oook
JP07oookJP06o`3o/ooonf[ooo]Zo`3Eoooonf[o0?nf1ooonfX00oo00?oooo]ZoookJP0@oookJP03
oomk0?oonf[ooo]Z00Sooo]Z00?oYOl0oookJ_oonfX03?oonfX00ol0TOoooo]ZoookJP04o`00O`04
oookJ_l007oo001oo`00O`Oooo]Z00Co0000oooC0?l0003o00003OoonfX00ol00_oooo]ZoookJP07
oookJP03ooo=0?oonf[ooo]Z00oooo]Z0_oPo`05oookJP?o0?nH;?oonfX5o`3oV1Cooo]Z0ooPo`0S
oookJP?onP3o3?oonfX3oooo013ooo]Z0_li0?l=oookJP;oo`3:9_oonfX002gooo]Z0_ooXP000ooo
C03ooo]ZoookJP02oookJP03o`3oDOoonf[ooo]Z00?ooo]Z0_l0Yol<oookJP03om`0oooonf[ooo]Z
00_ooo]Z0_oo:003oookJP03oon90?oonf[ooo]Z00gooo]Z00Co0?ogoookJ_oonf[ooo]Z2?oo0003
oolX00[oo`0000?oob`0oookJ_lBo`000_oonfX00ol0;Ooooo]ZoookJP03oookJPGoobP000?ooo]Z
oolX0?oo:0001ooo:0000ooonf[o03OooookJP02oookJP03ooo90?oo@`3ooo]Z00Sooo]Z00KoobP0
oookJ_oonf[o0=GooookJ_l0okH7oookJP03ol00oooonf[ooo]Z00kooo]Z1?oo0008oookJP03o`3o
9?nUo`3ooo]Z00gooo]Z0_oo0002oookJP?o001o00?ooo]Zool00?oo00001_oo0008oolX00Cooo]Z
2?oo00000ooo:03oo`00ool00003ool000;ooo]Z1?oo:00<oookJP;oo`001_oo:006oookJPGo0?nH
3ooonfX<oomi00Kooo]Z1Ol0oiPGoookJP?oh?l08ooonfX3ooX0o`cooo]Z0_ooo`000ooo0;Oooo]Z
oookJP0>oookJP?o>@3o3OoonfX00ooo0<[ooo]ZoookJP1@oookJP;ooj8000?ood`0oookJ_oonfX0
0_oonfX00ol0oe7ooo]ZoookJP03oookJP;o0:Oo3OoonfX00ooL0?oooo]ZoookJP0;oookJP05oom6
0?oonf[ooo]ZoookJ_ooR@003ooonfX2o`3om`Gooo]Z00?o/ol0o`3o]oo_0?l01_oonfX2o`0Go`04
o`3Uoooonf[ooo]Zo`3oh@?ooo]Z00Koob`0oookJ_oonf[o4_l0oookJ_l0;Ol6oookJP03o`3mool0
ojkooo]Z00Gooo]Z00?oo`2QoookJ_oonfX01?oonfX00ol0=ooooo]ZoookJP02oookJP03oom30?oo
b@3ooo]Z00Oooo]Z00Ko0?ncoookJ_oonf[o0=GooookJ_l0okH7oookJP03ol00oooonf[ooo]Z013o
oo]Z00?oog/0oookJ_oonfX02?oonfX00onUo`3ooo]ZoookJP0=oookJP03o`2Aoooonf[ooo]Z00?o
001o0ooonfX00omn0?oo001oo`00O`06oookJP04o`000?ood`3o0000o`0000gooo]Z00?o00;ooook
J_oonfX01ooonfX00oooc@3ooo]ZoookJP0AoookJP;oh?l01_oonfX5o`3oV2;ooo]Z1Ol0oiPFoook
JP?oh?l09?oonfX2ooX0o`gooo]Z0_ooo`000ooo0;Oooo]ZoookJP0=oookJP?o>@3o3OoonfX2ool0
bRSooo]Z000/oookJP03oonR0?ooC03ood`000Cooo]Z00?o0?mAoookJ_oonfX00ooonfX00ol0Yooo
047ooookJP0;oookJP03om`0oooonf[ooo]Z00[ooo]Z00?oodH0oolX0?oonfX00ooonfX00oooR@3o
oo]ZoookJP0<oookJP;o0?og0ooonfX7ool00003oolX0?oo003oobP000?oobP000?o0>Goool00?oo
00001Ooo00001?oo;03ooo]Zoa;o0?oonfX2o`0]o`Gooo]Z1?oo:003oookJPOoobP00_oonfX01_l0
=ooooo]ZoookJ_oonf[oolT0oom300Sooo]Z00Oo0?ncoolX0?oonf[ooo]Zo`3Eoooonf[o0?nf00Oo
oo]Z00?o`03ooookJ_oonfX03ooonfX3ool000Wooo]Z00?oYOl0oookJ_oonfX03?oonfX2ool000Oo
oo]Z2?oo0007oolX00;o00000ooonfX8ool00003o`02oooo003oo`0000?oo`000ooonfX3oolX00_o
oo]Z1Ooo0003oookJP;oobP000?oh?l0oookJ_oonfX01ooonfX5o`3oV0[ooo]Z4?ooN@02o`3oV1Wo
oo]Z0ooPo`0SoookJP?onP3o3?oonfX3oooo017ooo]Z0_li0?l>oookJP;oo`3:D_oonfX00oooXP3o
od`0oom<0004oookJP03o`3oDOoonf[ooo]Z00?ooo]Z00?o0:Ooo`11oooonfX03?oonfX00ooL0?oo
oo]ZoookJP0:oookJP;oodH00ooonfX00oooR@3ooo]ZoookJP0=oookJP03o`3omooonf[ooo]Z00Co
oo]Z00?o/ol0o`3o]oo_0?l01_oonfX01?l05ooo0?n<o`3UoooonfX2o`3oh@?ooo]Z00Coob`0oook
J_oonf[o4_l00_l0;Ol6oookJP03o`3mool0ojkooo]Z00Gooo]Z00?oo`2QoookJ_oonfX01?oonfX0
0ol0=ooooo]ZoookJP02oookJP03oom30?oonf[ooo]Z00Kooo]Z0_l0ok<2oookJP03o`3Eoooonf[o
0?nf00Sooo]Z00?o`03ooookJ_oonfX03ooonfX00oooN`3ooo]ZoookJP08oookJP03ojGo0?oonf[o
oo]Z00gooo]Z00?o097ooookJ_oonfX01ooonfX00omn0?oo001oo`00O`06oookJP03oooC0?l0003o
000000?o00002ooonfX00ol00_oooo]ZoookJP07oookJP03ooo=0?oonf[ooo]Z01?ooo]Z0_oPo`09
oookJPKo0?nH5OoonfX7o`3oV1Sooo]Z0ooPo`0ToookJP?onP3o3?oonfX3oooo013ooo]Z0_li0?l>
oookJP;oo`3::_oonfX002_ooo]Z00?ooj80oom<0?oonfX00ooonfX2o`3oD@Gooo]Z00?o0:Ooo`11
oooonfX02ooonfX00ooL0?oooo]ZoookJP0:oookJP03oom60?oonf[ooo]Z00?ooo]Z00?oohT0oook
J_oonfX03?oonfX00ol0ooOooo]ZoookJP02oookJPSoo`001?oo:0000ooo003o0>Goool00005ool0
0006oookJ_oo;03ooo]Zoa;o0?oonf[o02go1ooonfX3oolX00?ooo]Z1_oo:003oookJP06o`0goooo
nf[ooo]ZoookJ_oob@3ood<02?oonfX01ol0ok?ooo]ZoookJ_oonf[o0=GooookJ_l0okH01ooonfX0
0oo00?oooo]ZoookJP0?oookJP;oo`002_oonfX00onUo`3ooo]ZoookJP0=oookJP03ool00?oonf[o
oo]Z00Kooo]Z1ooo00000ooonf[oobP0oolX0004oolX0003o`000?oonf[ooo]Z00?ooo]Z2?oo0000
0ol00_ooo`00ool00003ool000?ooo]Z0ooo000;oookJPKoo`001OoonfX2on3o00cooo]Z2_l0oiP>
oomi01Sooo]Z1OoPo`0SoookJP?onP3o3OoonfX2oooo0003ool0]ooonf[ooo]Z00oooo]Z0_li0?l>
oookJP;oo`3:DooonfX00oooXP3ood`0oookJP03oookJP;o0?mA1OoonfX00ol0Yooo047ooookJP0;
oookJP;og03o3?oonfX00oooAP3ooo]ZoookJP02oookJP03oon90?oonf[ooo]Z00gooo]Z00?o0?og
oookJ_oonfX00ooonfX2ok?o0003o`3o]oo_0?ooo`3>00Gooo]Z00Go01Ooo`3Uool0iOoooo]Zo`3o
h@04oookJP05ool/0?oonf[ooo]Zoa;o0?l0;Ol01ooonfX00ol0oOoo0?n^oookJP05oookJP03ool0
XOoonf[ooo]Z00Cooo]Z00?o03OooookJ_oonfX00_oonfX00ooo@`3ooo]ZoookJP06oookJP07o`3o
/ooonf[ooo]ZoookJ_l0eOoooo]Zo`3o]P08oookJP03ol00oooonf[ooo]Z00oooo]Z00?oog/0oook
J_oonfX02?oonfX00onUo`3ooo]ZoookJP0=oookJP03o`2Aoooonf[ooo]Z00Oooo]Z00CoOP3oo`00
Ool007oo001o1_oonfX01?ood`3o0000o`000?l0000=oookJP03o`02oooonf[ooo]Z00Oooo]Z00?o
o`2jooo=0?oonfX05OoonfX3on3o00cooo]Z5Ol0oiPJoookJPGoh?l09?oonfX3ooX0o`gooo]Z0_oo
o`000ooo0;Oooo]ZoookJP0>oookJP;o>@3o3_oonfX2ool0bRcooo]Z000ZoookJP03oonR0?ooC03o
oo]Z00?ooo]Z00?o0?mAoookJ_oonfX00ooonfX2o`2Wo`cooo]Z0_oL0?l<oookJP03oom60?oonf[o
oo]Z00;ooo]Z0_ooR@0>oookJP03o`3omooonf[ooo]Z00?ooo]Z1_oo0003oolX00?oo`0000?o0>Go
ool00?oo00000ooo00001ooonf[oob`0ool/0?oonf[o4_l0oookJ_l0;Ol01ooonfX2oolX00Cooo]Z
0ooo:002ool000Cooo]Z00Ko03OooookJ_oonf[ooo]Zooo90?oo@`06oookJP03oolX0?oonf[o0?nc
00?ooo]Z00?o0=GooookJ_l0okH01ooonfX00oo00?oooo]ZoookJP0@oookJP03ool00?oonf[ooo]Z
00Sooo]Z00?oYOl0oookJ_oonfX02OoonfX2oolX00?ooo]Z00?o097ooookJ_oonfX00ooonfX2o`00
O`03oookJ_oo003oo`0000Coo`000_oonfX6oolX0003o`000?oonf[ooo]Z00?ooo]Z2?oo00000ol0
0_ooo`00ool00009ool000[ooo]Z2?oo0006oookJPCoh?l04ooonfX:oomi00;ooo]Z2OooN@0:oook
JPKoh?l09OoonfX3ooX0o`gooo]Z0oooo`000ooo0;Oooo]ZoookJP0>oookJP?o>@3o3OoonfX3ool0
bUCooo]Z00?ooj80oom<0?oonfX00ooonfX00ol0oe7ooo]ZoookJP03oookJP;o0:Oo3OoonfX00ooL
0?oooo]ZoookJP0;oookJP03oom60?oonf[ooo]Z00;ooo]Z00?oohT0oookJ_oonfX03OoonfX00ol0
ooOooo]ZoookJP03oookJP04ok?o0?l0okOo0?ngonl0o`Gooo]Z0_l05ol01?l0iOoooo]ZoookJ_l0
on44oookJP05ool/0?oonf[ooo]Zoa;o0?l0;Ol01ooonfX00ol0oOoooo]ZoookJP05oookJP04ool0
XOoonf[ooj00oonP00?ooo]Z00?o03OooookJ_oonfX00_oonfX00ooo@`3ooo]ZoookJP06oookJP07
o`3o/ooonf[ooo]ZoookJ_l0eOoooo]Zo`3o]P08oookJP03ol00oooonf[ooo]Z00oooo]Z00?oog/0
oookJ_oonfX02?oonfX00onUo`3ooo]ZoookJP0>oookJP03o`2Aoooonf[ooo]Z00?ooo]Z0_l007l2
oookJP04ogh0oooo2P3o001oo`00O`Kooo]Z00Coom<0o`000?l0003o00003OoonfX00ol00_oooo]Z
oookJP08oookJP03ooo=0?oonf[ooo]Z01Oooo]Z1?oPo`0aoookJPKoh?l09_oonfX3ooX0o`gooo]Z
0oooo`0@oookJP?o>@3o3OoonfX3ool0bRkooo]Z000ZoookJP03oom<0?oonf[ooo]Z00;ooo]Z00?o
0?mAoookJ_oonfX00ooonfX00ol0Yooo047ooookJP0;oookJP03om`0oooonf[ooo]Z00_ooo]Z00?o
odH0oookJ_oonfX00_oonfX00oooR@3ooo]ZoookJP0<oookJP;o0?og1OoonfX5ool000?oobP00_oo
nfX00ooo003o0>Goo`3Uo`06ool00006ool/0?oonf[ooo]Zoa;o0?oonf[o02go0_oonfX01_oo:03o
oo]ZoookJ_oonf[o0?gooolX00?ooo]Z00?oo`00oookJ_oonfX00_oo:0000ooo003ooo]ZoookJP02
oookJP;oogT00ooonfX00ooob@3ood<0oookJP06oookJP04oolX0?l0ok?ooo]ZoookJP;oobP000?o
oo]Zo`3o]_oonfX01_oonfX00oo00?oooo]ZoookJP0@oookJP03ool00?oonf[ooo]Z00Sooo]Z00?o
0?lTojGo0?oonfX02_oonfX3oolX0003oookJ_l0TOoooo]Z00Gooo]Z0_l007l6ool000?ooo]Z1Ooo
:002o`0000Kooo]Z1_oo00000ooonf[o00;oool0000:ool000[ooo]Z2_oo00000ooonf[oobP0oolX
0005oookJPCoh?l03ooonfX7oomi00Gooo]Z4OooN@02on3o02Sooo]Z0ooj0?l>oookJP;oool000?o
o`2goookJ_oonfX03ooonfX2ocT0o`gooo]Z0ooo0<YGoookJP03oom<0?oonf[ooo]Z00;ooo]Z00?o
0?mAoookJ_oonfX00ooonfX00ol0Yooo047ooookJP0<oookJP03om`0oooonf[ooo]Z00[ooo]Z0_oo
AP03oookJP;oohT03_oonfX2o`3om`Gooo]Z00Co/ol0o`3o]oo_0?ooo`3>1OoonfX00ol05ooooo]Z
o`3Uo`02oookJP03o`3ohOoonf[ooo]Z00;ooo]Z00Goob`0oookJ_oonf[o4_l0o`0]o`06oookJP;o
0?go1ooonfX00ooo0:7ooo]ZoonP0003oookJP;o03Oo1?oonfX00ooo@`3ooo]ZoookJP06oookJP03
o`3o/ooonf[ooo]Z00;o0=Go00?ooo]Zo`3o]_oonfX01ooonfX00oo00?oooo]ZoookJP0?oookJP03
oomk0?oonf[ooo]Z00Sooo]Z00?o0?lTojGo0?oonfX03_oonfX00ol0TOoooo]ZoookJP04oookJP?o
001o00CoOP3oo`00Oooo2P3o001o1_oonfX00oood`3o0000o`000002o`0000gooo]Z00?o00;ooook
J_oonfX02?oonfX00oooc@3ooo]ZoookJP0KoookJP?oh?l0:OoonfX5on3o02Sooo]Z1?oj0?l=oook
JP03ool0]oooo`3oool0017ooo]Z0_li0?l=oookJP?oo`3:<OoonfX002gooo]Z0_l0oe45oookJP03
o`2Wool0@Ooooo]Z00_ooo]Z00?og03ooookJ_oonfX02_oonfX2oom600Cooo]Z00?oohT0oookJ_oo
nfX03?oonfX00ol0ooOooo]ZoookJP04oookJP;oo`0000?o0?ngool00?oo:0000_oo:003oookJP03
ool00?l0iOooo`0000Goo`0000?ooo]Zool/0?oonfX00_oo:0000ooonf[o02gooookJP02oookJP05
oolX0?oonf[ooo]Zo`3moooo:0001?oonfX01Ooo003ooo]ZoolX0?oo:03oo`0000Cooo]Z00?oogT0
oookJ_oonfX00_oonfX00ooob@3ood<0oookJP06oookJP05oolX0?l0ok?oobP0oookJ_oo:0000_oo
nfX00ol0okKooo]ZoookJP05oookJP03ol00oooo003oo`00017ooo]Z00?oog/0oookJ_oonfX02?oo
nfX00onUo`3ooo]ZoookJP07oookJP;oo`001_oo:006oookJP;o001o1Ooo0004oookJPCoobP00ol0
0006oookJPKoo`0000?ooo]Zo`02oooo00002_oo00000oooc@3ooo]ZoookJP06oookJPcoo`000ooo
:008oookJP?oh?l03?oonfX4oomi00Sooo]Z3oooN@0YoookJP?onP3o3_oonfX3oooo017ooo]Z0oli
0?l<oookJP?oo`3:GOoonfX2o`3oD@Gooo]Z00?o0:Ooo`11oooonfX03?oonfX00ooL0?oooo]Zoook
JP0:oookJP03oom60?oonf[ooo]Z00;ooo]Z00?oohT0oookJ_oonfX03OoonfX00ol0ooOooo]Zoook
JP04oookJP04ok?o0?l0okOok`3oool0cPGooo]Z00?o01OooookJ_l0iOl00_oonfX01?l0on7ooo]Z
oookJ_oonfX2ool/0004oookJ_lBo`3o4_l0o`0]o`Kooo]Z00?o0?goo`3o[_oonfX01_oonfX00ooo
0:7ooo]ZoonP0003oookJP03o`0goooonf[ooo]Z00?ooo]Z00?ood<0oookJ_oonfX01_oonfX01?l0
ok?ooo]ZoookJ_l0eOl2oookJP03o`3o]_oonf[ooo]Z00Kooo]Z00?o`03ooookJ_oonfX04?oonfX0
0oooN`3ooo]ZoookJP08oookJP03ojGo0?oonf[ooo]Z00gooo]Z00?o097ooookJ_oonfX01OoonfX3
o`00O`03ogh0oooo2P3o001o00Oooo]Z00?oom<0o`000?l000000_l0000=oookJP03o`02oooonf[o
oo]Z00Sooo]Z00?oo`2jooo=0?oonfX07_oonfX3on3o027ooo]Z1OoPo`0ZoookJP?onP3o3_oonfX0
1?oo0;Ooool0oooo0?ooo`0@oookJP?o>@3o3?oonfX3ool0bSCooo]Z000/oookJP03o`3oDOoonf[o
oo]Z00?ooo]Z0_l0Yol=oookJP03om`0oooonf[ooo]Z00[ooo]Z00?oodH0oookJ_oonfX00ooonfX0
0oooR@3ooo]ZoookJP0<oookJP07o`3omooonf[ooo]ZoookJ_oo003ooo]Zok?o0002ool00003o`3o
]ooo:03oobP000Gooo]Z00Coo`00o`3Uoooo003o0?oQ0ooo0002oookJP03ool/0?oonf[oobP000;o
oo]Z00Co02gooookJ_oonf[ooo]Z0ooo:0000ol0oOooobP0oookJP03oookJP?oo`0000Cooo]Zool0
0?ooN@3oogT00_oonfX01OooN@3ooo]ZoookJ_oonf[oolT000;ood<01ooonfX00ooo:03o0?ncoolX
0002oolX00;ooo]Z00?o0?nfoookJ_oonfX01OoonfX00oo00?ooo`00ool00003ool000kooo]Z00?o
og/0oookJ_oonfX02?oonfX00onUo`3ooo]ZoookJP08oookJPGoo`001?oo:005oookJP;o001o1?oo
0005oookJP?oobP01?l00006oookJPKoo`0000?ooo]Zo`02oooo00002_oo00000oooc@3ooo]Zoook
JP09oookJPWoo`001Ooo:009oookJP_oh?l000?ooo]Zoomi0?oonfX02ooonfX;oomi02Wooo]Z0ooj
0?l>oookJP?oool03ooonfX5oolX00gooo]Z0_oo0<YOoookJP03o`3oDOoonf[ooo]Z00?ooo]Z0_l0
Yol=oookJP;og03o3?oonfX00oooAP3ooo]ZoookJP02oookJP03oon90?oonf[ooo]Z00gooo]Z00?o
0?ogoookJ_oonfX00ooonfX2ok?o0003o`3o]oo_0?ooo`3>00Gooo]Z00Co01Ooo`3oS?l0iOoooo]Z
0_l0on43oookJP06ool/0?oonf[ooo]Zoa;o0?oonf[o02go1_oonfX00ol0oOoo0?n^oookJP05oook
JP;oo`2Q00?ooo]ZoonP0?oonfX00_oonfX00ol0=ooooo]ZoookJP02oookJP;ood<02?oonfX01?l0
ok?ooo]ZoookJ_l0eOl2oookJP03o`3o]_oonf[ooo]Z00Kooo]Z00Go`03ooookJ_oonf[ooo]Zool0
X`0>oookJP03oomk0?oonf[ooo]Z00Sooo]Z00?oYOl0oookJ_oonfX03OoonfX00ol0TOoooo]Zoook
JP06oookJP;o001o00?oOP3ooookJ_oo2P001ooonfX00oood`3ooo]Zo`000003o`0000gooo]Z00?o
00;ooookJ_oonfX02OoonfX00oooc@3ooo]ZoookJP0PoookJP_oh?l03ooonfX7on3o02cooo]Z0ooj
0?l>oookJP04ool0]oooo`3oool0oooo017ooo]Z0_li0?l=oookJP;oo`3:=ooonfX002_ooo]Z00?o
0?mAoookJ_oonfX00ooonfX00ol0Yooo047ooookJP0;oookJP;og03o3?oonfX00oooAP3ooo]Zoook
JP02oookJP;oohT03_oonfX00ol0ooOooo]ZoookJP02oookJP06ool00?nco`3oo`00ool00?l0okOo
obP01OoonfX01Ol05oooo`00o`3Uoooo003o0?oQ00;oo`000ooonfX00ooo;03ooo]ZoolX0002oook
JP04o`0]oooonf[ooo]ZoookJP?oobP000?o0?gooolX0?oonfX00ooonfX5ool000GoogT00ooonfX0
0ooob@3ood<0oookJP08oookJP03o`3o/ooo:03oobP000?oobP000?o0?nfoookJ_oonfX01OoonfX0
0oo00?oooo]Zool00004ool000gooo]Z00?oog/0oookJ_oonfX02?oonfX00onUo`3ooo]ZoookJP08
oookJPSoo`000ooo:0001?oonf[oobP0oolX0?oonfX2o`00O`?oo`001OoonfX4oolX00Co00001_oo
nfX5ool000;ooo]Z00?o00;oool00?oo00002Ooo00000oooc@3oo`2joookJP0=oookJPCoo`001ooo
:00CoookJPkoh?l02OooN@0JoookJQ3oogT000?onP3ooookJ_oonfX03?oonfX3oooo00[ooo]Z2ooo
:00<oookJP?oo`3:H?oonfX00ol0oe7ooo]ZoookJP03oookJP03o`2Wool0@Ooooo]Z00cooo]Z00?o
g03ooookJ_oonfX02_oonfX2oom600Cooo]Z00?oohT0oookJ_oonfX03OoonfX00ol0ooOooo]Zoook
JP03oookJP05ok?o0?l02?oo0?ngonl0oooo0<h01?oonfX2o`0Go`;o0>Go00?ooo]Zo`3ohOoonfX0
0ooonfX01_oo;03ooo]ZoookJ_lBo`3ooo]Zo`0]o`Kooo]Z00?o0?goo`3o[_oonfX01OoonfX01?oo
0:7ooo]ZoookJ_ooX003oookJP03o`0goooonf[ooo]Z00;ooo]Z00?ood<0oookJ_oonfX01ooonfX0
1?l0ok?ooo]ZoookJ_l0eOl2oookJP03o`3o]_oonf[ooo]Z00Kooo]Z00?o`03ooookJ_oonfX00_oo
nfX00ooo0:?ooo]ZoookJP0;oookJP03oomk0?oonf[ooo]Z00Sooo]Z00?oYOl0oookJ_oonfX03_oo
nfX00ol0TOoooo]ZoookJP06oookJP;o001o00?oOP3oool:0?oonfX01ooonfX00oood`3ooo]Zo`00
0003o`0000gooo]Z00?o00;ooookJ_oonfX02OoonfX00oooc@3oo`2joookJP0AoookJP;onP3o6?oo
nfX?on3o02oooo]Z1?oj0?l>oookJP04ool0]oooo`3oool0oooo017ooo]Z0oli0?l<oookJP?oo`3:
>OoonfX002[ooo]Z00?o0?mAoookJ_oonfX00ooonfX00ol0Yooo047ooookJP0;oookJP03om`0oooo
nf[ooo]Z00_ooo]Z00?oodH0oookJ_oonfX00_oonfX00oooR@3ooo]ZoookJP0=oookJP03o`3omooo
nf[ooo]Z00;ooo]Z00Koo`00ok?o0?oo003ooo]Zo`3o]ooo0005oookJP09o`0Gool0iOoo0>Goool0
0?l0on7oo`00oookJ_oo:03ooo]Z00;oob`000Gooo]ZoolX0?oonf[ooo]Zo`0]o`04oookJP;oobP0
00Co0?gooolX0?oo:03oobP00ooonfX6ool000CoogT00_oonfX00ooob@3ood<0oookJP08oookJP03
o`3o/ooo:03oobP000?oobP000?o0?nfoolX0?oonfX01OoonfX00oo00?oooo]Zool00006ool000_o
oo]Z00?oog/0oookJ_oonfX02?oonfX00onUo`3ooo]ZoookJP09oookJPWoo`000ooonfX3oolX0004
oookJ_mn0?ooo`00ool000Co001o0_oonfX3oolX0003oookJ_l0003o000000;o00001_oonfX5ool0
0003oookJ_oo:03o00;o00CoobP01ooo00000ooonf[oold0oookJP0@oookJP03ool00?oo:03oobP0
00OoobP07ooonfX7oomi01cooo]Z3_ooN@0=oookJP04ool0]oooo`3oool0oooo00Wooo]Z3_oo:00:
oookJP?oo`3:H_oonfX00ol0oe7ooo]ZoookJP03oookJP03o`2Wool0@Ooooo]Z00cooo]Z00?og03o
oookJ_oonfX02_oonfX00oooAP3ooo]ZoookJP02oookJP;oohT03ooonfX00ol0ooOooo]ZoookJP03
oookJP03ok?o0?l02?oo0?ng00;oo`3>1?oonfX00ol05ooooo]Zo`3Uo`02oookJP03o`3ohOoonf[o
oo]Z00;ooo]Z00Koob`0oookJ_oonf[o4_l0oookJ_l0;Ol6oookJP03o`3mool0ojkooo]Z00Gooo]Z
00Coo`2QoookJ_oonf[ooj000ooonfX00ol0=ooooo]ZoookJP02oookJP03oom30?oonf[ooo]Z00Oo
oo]Z00Co0?ncoookJ_oonf[o0=Go0_oonfX00ol0okKooo]ZoookJP06oookJP03ol00oooonf[ooo]Z
00;ooo]Z00?oo`2SoookJ_oonfX02ooonfX00oooN`3ooo]ZoookJP08oookJP03ojGo0?l0obCooo]Z
00kooo]Z00?o097ooookJ_oonfX02?oonfX00omn0?ooo`X0o`00O`04o`00O`?ooo]Z00?oom<0oook
J_oonfX01?l0000=oookJP04o`02oooonf[ooo]Zo`0Jo`Wooo]Z00?oold0oookJ_oonfX04_oonfX2
ooX0oe7ooo]Z0ooj0?l?oookJP04ool0]oooo`3oool0oooo017ooo]Z0oli0?l<oookJP?oo`3:??oo
nfX002oooo]Z00?o0:Ooo`11oooonfX02ooonfX00ooL0?oooo]ZoookJP0:oookJP;oodH01?oonfX0
0oooR@3ooo]ZoookJP0=oookJP03o`3omooonf[ooo]Z00;ooo]Z00?oo`00ok?o0?oo00000_l0okL0
0ooo003ooo]ZoookJP03oookJP05o`0Gool0iOooo`00ool00?l0on400ooonfX01_oo:03oob`0oook
J_oonf[oobP0oookJP;o02go1?oonfX00ooo:03o0?goo`3mo`05oolX0003oookJ_oo003oo`0000Ko
o`001?ooN@000ooob@3ood<0oookJP08oookJP03o`3o/ooo:03oobP000?oobP000Co0?nfoolX0?oo
:03oobP01?oonfX00oo00?oooo]Zool00008ool000Wooo]Z00?oog/0oookJ_oonfX01?oonfX01_oo
N@3ooo]ZoookJ_oonf[o0?lTojGo00_ooo]Z2ooo00000ooonf[oobP0oolX0002oolX00;oo`001Ol0
07l2oookJP;oobP00_oonfX4o`0000Kooo]Z1?oo0002oookJP03oolX0?l00_ooobP000?oobP01ooo
00000ooonf[oold0oookJP0AoookJP[oobP07ooonfX3oomi01oooo]Z3?ooN@0<oookJP04ool0]ooo
o`3oool0oooo00cooo]Z3?oo:009oookJP?oo`3:J_oonfX00ol0Yooo047ooookJP0;oookJP;og03o
3?oonfX00oooAP3ooo]ZoookJP02oookJP03oon90?oonf[ooo]Z00kooo]Z00?o0?ogoookJ_oonfX0
0ooonfX01?nco`3o0?ngo`3o]ooo0<h5oookJP03o`0Goooonf[o0>Go00;ooo]Z00?o0?oQoookJ_oo
nfX00_oonfX01?oo;03ooo]ZoookJ_lBo`02o`0]o`Kooo]Z00?o0?goo`3o[_oonfX01OoonfX01?oo
0:7ooo]ZoookJ_ooX003oookJP03o`0goooonf[ooo]Z00;ooo]Z00?ood<0oookJ_oonfX01ooonfX0
1?l0ok?ooo]ZoookJ_l0eOl2oookJP03o`3o]_oonf[ooo]Z00Kooo]Z00?o`03ooookJ_oonfX00_oo
nfX00ooo0:?ooo]ZoookJP0;oookJP03oomk0?oonf[ooo]Z00Wooo]Z00?oYOl0oookJ_oonfX03Ooo
nfX00ol0TOoooo]ZoookJP09oookJP03ogh0oooo2P3o001o00Co001o0ooonfX00oood`3ooo]Zoook
JP04o`0000Sooo]Z00?o0?mloookJ_oonfX00_oonfX01?l00_oooo]ZoookJ_l06_l9oookJP03ooo=
0?oo0;[ooo]Z01Cooo]Z0_oj0?m;oookJPConP3o3ooonfX01?oo0;Ooool0oooo0?ooo`0AoookJP?o
>@3o3?oonfX3ool0bSoooo]Z000]oookJP;o0:Oo3OoonfX00ooL0?oooo]ZoookJP0:oookJP03oom6
0?oonf[ooo]Z00;ooo]Z0_ooR@0>oookJP;o0?og1OoonfX01?nco`3oo`00o`3o]oo_0?l2ool000Co
oo]Z00Go01Ooo`3Uoooo003oo`00o`3oh@03oookJP?oobP000Cooo]ZoolX0?oonf[o02go1OoonfX0
0ooo:03o0?gooolX0007oolX00Woo`001?ooN@08oookJP03ool00?l0ok?oobP000;oobP00_oo0000
0ol0okKoobP0oolX0005oookJP03ol00oooonf[ooo]Z00Ooo`002_oonfX00oooN`3ooo]ZoookJP05
oookJP;oogT00_oonfX00onUo`3ooo]ZoookJP09oookJPgoo`001?oo:0000ooo003oobP0oookJP06
oookJP04oolX0?oonf[ooo]ZoookJPCo00001_oonfX4ool000;ooo]Z00?oobP0o`02oooo:0001?oo
:005ool000?ooo]Z00?oold0oookJ_oonfX03_oonfX<oolX01kooo]Z00?oogT0oookJ_oonfX07ooo
nfX;oomi00[ooo]Z00Coo`2goooo0?ooo`3oool04?oonfX:oolX00Sooo]Z0_oo0<Y[oookJP;o0:Oo
3OoonfX00ooL0?oooo]ZoookJP0:oookJP;oodH01?oonfX00oooR@3ooo]ZoookJP0=oookJP;o0?og
1?oonfX2ok?o0003o`3o]oo_0?ooo`3>00Gooo]Z00?o01OooookJ_l0iOl00_oonfX00ol0on7ooo]Z
oookJP02oookJP05ool/0?oonf[o4_l0oa;o0?l0;Ol01ooonfX00ol0oOoooo]ZoookJP05oookJP04
ool0XOoonf[ooj00oonP00;ooo]Z0_l0=ol4oookJP03oom30?oonf[ooo]Z00Oooo]Z00Co0?ncoook
J_oonf[o0=Go0_oo02/00ol0okKooo]ZoookJP06oookJP03ol00oooonf[ooo]Z00;ooo]Z00?oo`2S
oookJ_oonfX02ooonfX00oooN`3ooo]ZoookJP09oookJP03ojGo0?oonf[ooo]Z00kooo]Z00?o097o
oookJ_oonfX02?oonfX00omn0?ooo`X0oookJP07oookJP04oooC0?oonf[ooo]ZoookJPCo00002?oo
nfX00ol0ogcooo]ZoookJP02oookJP04o`02oooonf[ooo]Zo`0Jo`[ooo]Z00?oold0oookJ_oonfX0
5OoonfX3ooX0odGooo]Z0ooj0?l@oookJPCoool04_oonfX2ocT0o`gooo]Z0_oo0<Y2oookJP00;?oo
nfX00ol0Yooo047ooookJP0;oookJP;og03o3?oonfX00oooAP3ooo]ZoookJP02oookJP03oon90?oo
nf[ooo]Z00gooo]Z00?o0?ogoookJ_oonfX01?oonfX01?nco`3oo`00o`3o]oo_0?l4ool000;ooo]Z
00Go01Ooo`3Uoooo003ooo]Zo`3oh@03oookJPGoobP000?ooo]Zo`0]oooonfX01?oonfX00ooo:03o
0?gooolX0006oolX0003ool0XOoo003oo`0000Koo`001?ooN@000ooo@`3ooo]ZoookJP07oookJP08
ool00?oo:03oobP0oolX0?oo003oobP0o`3o]_oo:006oookJP03ol00oooonf[ooo]Z00Ooo`002_oo
nfX00oooN`3ooo]ZoookJP05oookJPCoogT000?oYOl0oookJ_oonfX02_oonfX;ool00003oookJ_oo
:03oobP000?oobP000?oo`X0oolX0?oo:0001_oonfX01?ood`3ooo]ZoookJ_oonfX4o`0000Cooo]Z
0ooo:002ool000Cooo]Z00?o00;ooolX0?oo:0001?oo:004ool000?ooo]Z00?oold0oookJ_oonfX0
3_oonfX>oolX03cooo]Z0_oj0?l9oomi00Wooo]Z1?ooo`0CoookJPSoobP01ooonfX3ool0bQgooo]Z
0_nB0?m=oookJP03o`2Wool0@Ooooo]Z00cooo]Z00?og03ooookJ_oonfX02_oonfX00oooAP3ooo]Z
oookJP03oookJP03oon90?oonf[ooo]Z00gooo]Z00?o0?ogoookJ_oonfX00ooonfX01Onco`3o00So
o`3o]oo_0?ooo`3>00Gooo]Z00?o01Ooo`3oS?l0iOl00_oonfX00ol0on7ooo]ZoookJP02oookJP05
ool/0?oonf[o4_l0oookJ_l0;Ol01_oonfX2o`3mo`Oooo]Z00?oo`2QoookJ_ooX0000ooonfX00ol0
=ooooo]ZoookJP03oookJP03oom30?oonf[ooo]Z00Oooo]Z00Oo0?ncoookJ_oonf[o0=Goool0:ooo
nf[o0?nf00Sooo]Z00?o`03ooookJ_oonfX00_oonfX00ooo0:?ooo]ZoookJP0;oookJP03oomk0?oo
nf[ooo]Z00Wooo]Z00?oYOl0oookJ_oonfX03OoonfX00ol0og[o097ooookJP0:oookJP03ogh0oooo
2P3ooo]Z00Oooo]Z00Coom<0oookJ_oonf[ooo]Z1?l00008oookJP03o`3oO?oonf[ooo]Z00;ooo]Z
00Co00;ooookJ_oonf[o01[o2_oonfX00oooc@3oo`2joookJP0HoookJP;onP3o?_oonfX5ooX0o`oo
oo]Z1?ooo`0CoookJP?o>@3o3?oonfX3ool0bQkooo]Z0_nB0?lToookJP00:ooonfX00ol0Yooo047o
oookJP0;oookJP03om`0oooonf[ooo]Z00[ooo]Z0_ooAP04oookJP03oon90?oonf[ooo]Z00gooo]Z
00?o0?ogoookJ_oonfX00ooonfX2ok?o0003ool00?l0okOoo`0000Koo`000_l0iOl00ooonf[o0?oQ
o`3oh@04oookJPGoobP000?o02gooookJ_oonfX01?oonfX00ol0oOooobP0oolX0004oolX0003oook
J_oo0:7oo`0000Koo`001?ooN@000ooob@3ood<0oookJP08oookJP?oo`0000CoobP0ool00?oo:03o
0?nf2?oonfX00oo00?oooo]ZoookJP05ool000Kooo]Z00?oobP0oookJ_oonfX00_oonfX00oooN`3o
oo]ZoookJP06oookJPGoogT02ooonfX;ool000;ooo]Z1?oo:0001?oo2P3oobP0oolX0?oo:005oook
JP03oooC0?oonf[ooo]Z00;ooo]Z1?l00004oookJPKoobP00ooonfX00ol00_ooobP0oolX0004oolX
00;oo`001Ooo:0000oooc@3ooo]ZoookJP0CoookJP[oobP0=?oonfX7ooX0o`?ooo]Z1_ooN@08oook
JP?oool05?oonfX3oolX0003oookJ_oo:03oobP000CoobP01OoonfX3ool0bQgooo]Z0onB0?m>oook
JP03o`2Wool0@Ooooo]Z00_ooo]Z0_oL0?l<oookJP03oom60?oonf[ooo]Z00?ooo]Z00?oohT0oook
J_oonfX03OoonfX00ol0ooOooo]ZoookJP03oookJP05ok?o0?l02?oo0?ngoookJ_oo0<h01OoonfX0
1?l05ooo0>Goo`3UoooonfX2o`3oh@Cooo]Z00Goob`0oookJ_lBo`3ooo]Zo`0]o`06oookJP03o`3m
ool0ojkooo]Z00Kooo]Z00?oo`2QoookJ_ooX0000_oonfX00on30?oo03OooookJP03oookJP03ooo9
0?oo@`3ooo]Z00Sooo]Z00Oo0?ncoookJ_oonf[o0=Goool0:ooonf[o0?nf00Sooo]Z00?o`03ooook
J_oonfX00_oonfX00ooo0:?ooo]ZoookJP0;oookJP03oomk0?oonf[ooo]Z00Wooo]Z00?oYOl0o`3o
9?oonfX03_oonfX01?l0og[o097ooookJ_oo0<h8oookJP03ogh0oooo2P3ooo]Z00Oooo]Z00?oom<0
oookJ_oonfX00_oonfX4o`0000Oooo]Z00?o0?mloookJ_oonfX00ooonfX01?l00_oooo]ZoookJ_l0
6_l;oookJP03ooo=0?oonf[ooo]Z01Wooo]Z0ooj0?leoookJPKonP3o4OoonfX3oooo0003ool0]ooo
nf[ooo]Z017ooo]Z0oli0?l<oookJP?oo`3:7_oonfX3oi80obKooo]Z000ZoookJP03o`2Woooonf[o
oo]Z00_ooo]Z00?og03ooookJ_oonfX02_oonfX00oooAP3ooo]ZoookJP03oookJP03oon90?oonf[o
oo]Z00gooo]Z00?o0?ogoookJ_oonfX00ooonfX01?nco`3oo`00ool00?l0okL6ool00005o`0Gool0
iOoo0?n<oookJ_l0on401?oonfX00ooo;03oobP0oolX0005oolX00Gooo]Z00?o0?gooolX0?oo:000
0ooo:002oookJP03ool0XOoonf[oo`0000Coo`001?ooN@000ooob@3ooo]Zoom30008oookJP03o`3o
/ooo003oo`0000?oo`0000?oobP0o`3o]_oonfX01ooonfX00oo00?oooo]ZoookJP05ool000Oooo]Z
0_oo:002oookJP03oomk0?oonf[ooo]Z00Kooo]Z1oooN@0:oookJP[oo`000ooonfX7oolX00Kooo]Z
00?oom<0oookJ_oonfX00_oonfX4o`0000Cooo]Z2?oo:0000ooonf[o00;ooolX000<oolX0003oook
J_ooc@3ooo]Z01[ooo]Z1?oo:003ooX0ob[ooo]Z1_oj0?l:oookJPCoogT01_oonfX4oooo01Cooo]Z
0_li0?l00ooo:03ooo]ZoookJP02oookJPGoobP00ooonfX3ool0bQkooo]Z0_nB0?m@oookJP03o`2W
oooonf[ooo]Z00_ooo]Z00?og03ooookJ_oonfX02ooonfX00oooAP3ooo]ZoookJP02oookJP;oohT0
3ooonfX00ol0ooOooo]ZoookJP03oookJP03ok?o0?oonf[o0?ng00;oo`3>1OoonfX01Ol05ooo0>Go
oookJ_oonf[o0?oQ00Cooo]Z0_oo;0001?oonf[o4_l0oookJ_l0;Ol6oookJP03o`3mool0ojkooo]Z
00Gooo]Z0_oo0:401_oonf[ooj00oookJ_oonf[oP`3oo`0go`Cooo]Z00?oolT0oom30?oonfX01ooo
nfX2o`3o/`;ooo]Z00Co0=Goool0:ooonf[o0?nf2?oonfX00oo00?oooo]ZoookJP02oookJP03ool0
Xooonf[ooo]Z00_ooo]Z00?oog/0oookJ_oonfX02_oonfX00onUo`3ooo]ZoookJP0=oookJP05o`3o
N_l0TOoooo]ZoookJ_oo0<h02?oonfX00omn0?ooo`X0oookJP07oookJP03oooC0?oonf[ooo]Z00;o
oo]Z1?l00007oookJP03o`3oO?oonf[ooo]Z00?ooo]Z00Co00;ooookJ_oonf[o01[o1OoonfX00ol0
o`3ooo]ZoookJP03oookJP03ooo=0?oonf[ooo]Z01cooo]Z1?oj0?l[oookJPKonP3o4ooonfX4oooo
0003ool0]ooonf[ooo]Z017ooo]Z0oli0?l<oookJP?oo`3:7_oonfX3oi80obWooo]Z000goookJP03
om`0oooonf[ooo]Z00[ooo]Z00?oodH0oookJ_oonfX00_oonfX2oon900oooo]Z00?o0?ogoookJ_oo
nfX00ooonfX01?nco`3ooo]Zool00?l0okL5ool00006oookJ_l05ooo0>Goo`3oS?oonf[o0?oQ1?oo
nfX00ooo;03oobP0oolX0007oolX00;ooo]Z0_l0oOl4oolX00?ooo]Z00?oo`2Qool00?oo00000ooo
0004oomi0004oookJ_oob@3ooo]Zoom300Sooo]Z00?o0?ncoookJ_oo00001Ooo0008oookJP04ol00
oooonf[ooo]ZoookJP?oo`002?oonfX5oolX00Wooo]Z2?ooN@09oookJPWoo`000ooonfX8oolX00Go
oo]Z00?oom<0oookJ_oonfX00ooonfX4o`0000Cooo]Z2?oo:0000ooonf[o00;ooolX000<oolX0003
oookJ_ooc@3ooo]Z027ooo]Z1ooj0?lNoookJPGonP3o2?oonfXAoolX0003oooo0?oonf[ooo]Z01?o
oo]Z0oli0?l7oookJP?oobP00_oonfX3ool0bQkooo]Z0onB0?l5oookJP;oWol0F?oonfX00ooL0?oo
oo]ZoookJP0:oookJP;oodH01?oonfX00oooR@3ooo]ZoookJP0>oookJP03o`3omooonf[ooo]Z00?o
oo]Z00Co/ol0oookJ_l0okOoo`3>1_oonfX01Ol05ooo0>GooookJ_oonf[o0?oQ00Cooo]Z00Koob`0
oookJ_oonf[o4_l0oookJ_l0;Ol6oookJP03o`3mool0ojkooo]Z00Gooo]Z00Coo`2QoookJ_oonf[o
oj000_oonfX00on30?oo03OooookJP03oookJP03ooo90?oo@`3ooo]Z00Oooo]Z00So0?ncoookJ_oo
nf[ooo]Zo`3Eoooo02_ooo]Zo`3o]PSooo]Z00?o`03ooookJ_oonfX00_oonfX00ooo0:?ooo]Zoook
JP0;oookJP03oomk0?oonf[ooo]Z00[ooo]Z00?oYOl0oookJ_oonfX03OoonfX01Ol0og[o097ooook
J_oonf[oo`3>00Sooo]Z00?oOP3oool:0?oonfX01ooonfX00oood`3ooo]ZoookJP03oookJPCo0000
1ooonfX00ol0ogcooo]ZoookJP03oookJP04o`02oooonf[ooo]Zo`0Jo`Gooo]Z00?o0?l0oookJ_oo
nfX01?oonfX00oooc@3ooo]ZoookJP0OoookJPOonP3o7ooonfX5ooX0oaGooo]Z1?ooo`000ooo0;Oo
oo]ZoookJP0BoookJP?o>@3o3OoonfX2ool0bQoooo]Z0_nB0?l6oookJP;oWol09?oonfX003Gooo]Z
0_oL0?l<oookJP03oom60?oonf[ooo]Z00;ooo]Z00?oohT0oookJ_oonfX03_oonfX00ol0ooOooo]Z
oookJP03oookJP04ok?o0?oonf[o0?ngo`3o]`Coo`000_oonfX01Ol05ooo0>Goo`3oS?oonf[o0?oQ
00Cooo]Z00?oob`0oolX0?oo:0001_oo:003oookJP03o`3moooonf[oobP000;oobP01?oonfX00ooo
0:7ooo]Zool00004ool000?oogT000Cooo]Zooo90?oonf[ood<02?oonfX00ol0ok?ooo]Zool00007
ool000Kooo]Z00Co`03ooookJ_oonf[ooo]Z0ooo0009oookJPGoobP02?oonfX7oomi00[ooo]Z2Ooo
0004oookJPWoobP01?oonfX00oood`3ooo]ZoookJP03oookJPGo00000ooonfX7oolX00;ooo]Z00?o
00;ooolX0?oo:0002ooo:0000ooonf[oold0ool0^P0XoookJPOonP3o4?oonfX7ooX0o`Cooo]Z6?oo
:00DoookJPCo>@3o2ooonfX01?oo:03oo`3:ool0b_oo0<XOoookJP;oTP3o1_oonfX2oioo05Wooo]Z
00?og03ooookJ_oonfX02_oonfX00oooAP3ooo]ZoookJP03oookJP03oon90?oonf[ooo]Z00kooo]Z
00?o0?ogoookJ_oonfX00_oonfX2ok?o00;o0?ng00?oo`3>oookJ_oonfX01?oonfX01Ol05ooo0>Go
oookJ_oonf[o0?oQ00Cooo]Z00Koob`0oookJ_oonf[o4_l0oookJ_l0;Ol6oookJP03o`3mool0ojko
oo]Z00Gooo]Z00Coo`2QoookJ_oonf[ooj000_oonfX00on30?oo03OooookJP03oookJP03ooo90?oo
@`3ooo]Z00Oooo]Z00So0?ncoookJ_oonf[ooo]Zo`3Eoooo02_ooo]Zo`3o]PSooo]Z00?o`03ooook
J_oonfX00_oonfX00ooo0:?ooo]ZoookJP0<oookJP03oomk0?oonf[ooo]Z00Wooo]Z00?oYOl0o`3o
9?oonfX03_oonfX01?l0og[o097ooookJ_oo0<h9oookJP03ool:0?oonf[ooo]Z00Oooo]Z00?oom<0
oookJ_oonfX00ooonfX5o`0000Kooo]Z00?o0?mloookJ_oonfX00ooonfX01?l00_oooo]ZoookJ_l0
6_l5oookJP03o`3o0?oonf[ooo]Z00Cooo]Z00?oold0oookJ_oonfX09_oonfX7ooX0oa3ooo]Z2?oj
0?lEoookJPGoool05OoonfX4ocT0o`gooo]Z0ooo0<XNoookJP?oTP3o1_oonfX2oioo02Kooo]Z000d
oookJP03om`0oooonf[ooo]Z00[ooo]Z0_ooAP04oookJP03oon90?oonf[ooo]Z00kooo]Z00?o0?og
oookJ_oonfX00ooonfX01?nco`3ooo]Zo`3o]oo_0?l3ool000?ooo]Z00Go01Ooo`3Uoooonf[ooo]Z
o`3oh@04oookJP03ool/0?oonf[oobP000GoobP01?oonfX01?l0oOoooo]ZoolX0?oo:005oookJP03
ool0XOoonf[oo`0000;oo`0000Cooo]Zool00?ooN@3oogT00_oonfX00ooob@3ooo]Zoom30008oook
JP03o`3o/ooonf[ooo]Z00Woo`001?oonfX01?o00?oooo]ZoookJ_oonfX3ool000Wooo]Z1ooo:007
oookJPKoogT02ooonfX3ool00004oolX0?oo003oo`00ool000Kooo]Z2?oo:005oookJP03oooC0?oo
nf[ooo]Z00?ooo]Z1?l00004oookJPOoobP00_oonfX00ol00_ooobP0oolX000;oolX00;ooo]Z00?o
old0oookJ_oonfX0;OoonfX;ooX0o`Coo`0000?onP3ooookJ_oonfX02OoonfXFoolX01?ooo]Z0oli
0?l=oookJP?oo`3:7ooonfX3oi80o`Kooo]Z0_nOo`1IoookJP;og03o3?oonfX00oooAP3ooo]Zoook
JP03oookJP03oon90?oonf[ooo]Z00kooo]Z00?o0?ogoookJ_oonfX00_oonfX01Onco`3o00Soo`3o
]oo_0?ooo`3>00Gooo]Z0_l05ol01?l0iOoooo]ZoookJ_l0on44oookJP06ool/0?oonf[o4_l0oa;o
0?oonf[o02go1_oonfX00ol0oOoo0?n^oookJP05oookJP04ool0XOoonf[ooo]ZoonP00;ooo]Z00?o
P`3oo`0goooonfX00ooonfX00ooob@3ood<0oookJP07oookJP06o`3o/ooonf[ooo]ZoookJ_l0eOoo
o`0[0_l0okH8oookJP03ol00oooonf[ooo]Z00;ooo]Z00?oo`2SoookJ_oonfX03?oonfX00oooN`3o
oo]ZoookJP09oookJP03ojGo0?l0obCooo]Z00kooo]Z00Co0?mjo`2Aoooonf[oo`3>2OoonfX00omn
0?ooo`X0oookJP08oookJP03oooC0?oonf[ooo]Z00?ooo]Z1?l00007oookJP03o`3oO?oonf[ooo]Z
00?ooo]Z00Co00;ooookJ_oonf[o01[o1_oonfX00ol0o`3ooo]ZoookJP03oookJP03ooo=0?oonf[o
oo]Z02gooo]Z4?oj0?lHoookJP03ool0]oooo`3oool000;oool05ooonfX3ocT0o`kooo]Z0ooo0<XN
oookJP?oTP3o1ooonfX2oioo02Sooo]Z000coookJP03om`0oooonf[ooo]Z00[ooo]Z00?oodH0oook
J_oonfX00ooonfX00oooR@3ooo]ZoookJP0=oookJP;o0?og1?oonfX01?l02?oo/ol0oookJ_l0okL3
ool000Cooo]Z00?o01Ooo`3UoooonfX00_l0on44oookJP03ool/0?oonf[oobP000CoobP01OoonfX0
0ol0oOoo0?n^oolX0006oookJP03ool0XOoonf[ooj0000?oo`0000?o03Oooomi0?oonfX00_oonfX0
0ooob@3ooo]Zoom30008oookJP03o`3o/ooonf[ooo]Z00Soo`001OoonfX00oo00?oooo]ZoookJP02
oookJP03ool00?oonf[ooo]Z00Sooo]Z2Ooo:005oookJPKoogT02ooonfX3ool00004oolX0?oo003o
o`00ool000Kooo]Z2?oo:005oookJP03oooC0?oonf[ooo]Z00Cooo]Z1?l00004oookJPKoobP00_oo
nfX00ol00_oooo]ZoolX0004oolX0003oookJ_oo:03oobP000GoobP00_oonfX00oooc@3oo`2joook
JP0aoookJQ3oo`001ooonfX8oolX00;oool02_oo:0000ooonf[oo`00ool00007ool000Sooo]Z0oli
0?l8oookJPSoobP06OoonfX9oolX00Oooo]Z0_nOo`1JoookJP03om`0oooonf[ooo]Z00[ooo]Z0_oo
AP05oookJP03oon90?oonf[ooo]Z00gooo]Z0_l0ooL4oookJP05ok?o0?l02?oo0?ngoookJ_oo0<h0
1OoonfX01?l05ooo0?n<o`3UoooonfX2o`3oh@Cooo]Z00Coob`0oookJ_lBo`3ooo]Z0_l0;Ol6oook
JP03o`3mool0ojkooo]Z00Gooo]Z00Coo`2QoookJ_ooX03ooj000_oonfX00on30?oo03OooookJP03
oookJP03ooo90?oo@`3ooo]Z00Oooo]Z00Oo0?ncoookJ_oonf[ooo]Zo`3Eoooo02_o0?nf00Wooo]Z
00?o`03ooookJ_oonfX00_oonfX00ooo0:?ooo]ZoookJP0<oookJP03oomk0?oonf[ooo]Z00Wooo]Z
00?oYOl0o`3o9?oonfX03_oonfX01Ol0og[ooo]Zo`2Aoooonf[oo`3>00Sooo]Z00?oOP3oool:0?oo
nfX02?oonfX00oood`3ooo]ZoookJP04oookJPCo00001ooonfX00ol0ogcooo]ZoookJP03oookJP04
o`02oooonf[ooo]Zo`0Jo`Kooo]Z00?o0?l0oookJ_oonfX01?oonfX00oooc@3ooo]ZoookJP1=oook
JP?oo`2g1Oooo`0HoookJP?o>@3o3_oonfX3ool0bQoooo]Z0_nB0?l8oookJP;oWol0:_oonfX003;o
oo]Z00?og03ooookJ_oonfX02_oonfX00oooAP3ooo]ZoookJP02oookJP;oohT03ooonfX00ol0ooOo
oo]ZoookJP03oookJP;o/ol000Cooo]Zo`3o]ooo003oo`001OoonfX01?l05ooo0>GooookJ_l0on45
oookJP03ool/0?oonf[oobP000?oobP01_oonfX00ol0oOoo0?n^oookJP06oookJP03ool0XOoonf[o
oj0000?oo`0000?o03Ooool00?oo00000_oonfX00ooob@3ooo]Zoom30008oookJP03o`3o/ooonf[o
oo]Z00Ooo`001_oonfX00oo00?oooo]ZoookJP02oookJP03ool00?oonf[ooo]Z00Wooo]Z1ooo:007
oookJPCoogT03OoonfX2ool00004oolX0?oonf[oo`00ool000Oooo]Z1ooo:006oookJP03oooC0?oo
nf[ooo]Z00Cooo]Z1?l00004oookJPKoobP00_oonfX00ol00_oooo]ZoookJP03oolX00;ooo]Z1ooo
:003oookJP03ooo=0?oonf[ooo]Z033ooo]Z5Ooo0002ool0]`?oobP01Oooo`0:oolX00?ooo]Z4?oo
00001?li0?oooo]ZoookJ_oonfX>oolX01?ooo]Z3ooo:007oookJP;oWol0FooonfX00ooL0?oooo]Z
oookJP0:oookJP03oom60?oonf[ooo]Z00?ooo]Z0_ooR@0?oookJP03o`3omooonf[ooo]Z00?ooo]Z
00Go/ol0oookJ_l0okOooo]Zool0cP05oookJP05o`0Gool0iOoo0>GooookJ_l0on401OoonfX01Ooo
;03ooo]Zoa;o0?oonf[o02go00Oooo]Z00?o0?gooookJ_oonfX01OoonfX00ooo0:7ooo]ZoonP0003
oookJP03oh<0ool0=ooooo]Z00?ooo]Z00?oolT0oom30?oonfX01ooonfX01ol0ok?ooo]ZoookJ_oo
nf[o0=Goool0:ol0okH02OoonfX00oo00?oooo]ZoookJP02oookJP03ool0Xooonf[ooo]Z00cooo]Z
00?oog/0oookJ_oonfX02OoonfX00onUo`3o0?lToookJP0?oookJP04o`3oN_l0TOoooo]Zool0cPWo
oo]Z00?oOP3oool:0?oonfX02?oonfX00oood`3ooo]ZoookJP04oookJPCo00001_oonfX00ol0ogco
oo]ZoookJP04oookJP04o`02oooonf[ooo]Zo`0Jo`Kooo]Z00?o0?l0oookJ_oonfX01?oonfX00ooo
c@3ooo]ZoookJP15oookJPGoo`2g1_ooo`0IoookJPCo>@3o3_oonfX3ool0bQoooo]Z0onB0?l7oook
JP?oWol0;?oonfX0033ooo]Z0_oL0?l<oookJP03oom60?oonf[ooo]Z00;ooo]Z00?oohT0oookJ_oo
nfX03_oonfX00ol0ooOooo]ZoookJP03oookJP05ok?o0?oonf[ooo]Zo`3o]ooo00001OoonfX2o`0G
o`03o`3Uoooonf[o0?oQ00Gooo]Z00?oob`0oookJ_oonfX00ooo:005oookJP;o0?go00?o0?n^oook
J_oonfX01OoonfX00ooo0:7ooo]ZoonP0003ool00003o`0goooo003oo`0000;oo`0000?oolT0oook
J_oo@`002?oonfX01?l0ok?ooo]ZoookJ_oonfX5ool000Oooo]Z00?o`03ooookJ_oonfX00_oonfX0
0ooo0:?ooo]ZoookJP09oookJPOoobP01ooonfX4oomi00kooo]Z00Goo`00oookJ_l0TOoooo]Zool0
0008oookJPKoobP01_oonfX00oood`3ooo]ZoookJP05oookJPCo00001?oonfX5oolX00?ooo]Z00?o
00;ooookJ_oonfX00ooo:003oookJPKoobP00ooonfX00oooc@3oo`2joookJP06oookJP;oo`00:?oo
nfXHool000;oool01_oo:0000ooonf[oobP0oolX0004oolX00Gooo]Z3_oo0006oookJPgoobP05?oo
nfX>oolX00Gooo]Z0onOo`1KoookJP;og03o3?oonfX00oooAP3ooo]ZoookJP03oookJP03oon90?oo
nf[ooo]Z00kooo]Z00?o0?ogoookJ_oonfX00_oonfX2ok?o0004oookJ_l0okOoo`3>ool0cPGooo]Z
00Go01Ooo`3Uoooonf[ooo]Zo`3oh@04oookJP;oob`000Cooo]Zoa;o0?oonf[o02go1_oonfX2o`3m
o`Oooo]Z00?oo`2QoookJ_ooX0000ooonfX02?n30?oo03OooookJ_oonf[o00SooookJ_oob@3ood<0
2?oonfX01ol0ok?ooo]ZoookJ_oonf[o0=Goool0:ol0okH02OoonfX00oo00?oooo]ZoookJP02oook
JP03ool0Xooonf[ooo]Z00cooo]Z00?oog/0oookJ_oonfX02_oonfX00onUo`3ooo]ZoookJP0>oook
JP04o`3oN_oonf[o097oool0cPWooo]Z00?oOP3oool:0?oonfX02?oonfX00oood`3ooo]ZoookJP05
oookJPCo00001_oonfX00ol0ogcooo]ZoookJP04oookJP04o`02oooonf[ooo]Zo`0Jo`Kooo]Z00?o
0?l0oookJ_oonfX01?oonfX00oooc@3oo`2joookJP0koookJPOoo`2g2?ooo`0JoookJPGo>@3o3_oo
nfX4ool0bQoooo]Z0onB0?l7oookJP?oWol0;ooonfX002oooo]Z00?og03ooookJ_oonfX02_oonfX2
oom600Cooo]Z00?oohT0oookJ_oonfX03_oonfX00ol0ooOooo]ZoookJP03oookJP04ok?o0?oonf[o
k`3oo`3o]`Kooo]Z00Go01Ooo`3oS?l0iOoooo]Zo`3oh@05oookJP03ool/0?oonf[ooo]Z00;oobP0
00?o02gooookJ_oonfX00ooonfX00ol0oOoooo]Zo`3o[P07oookJP03ool0XOoonf[ooj0000?oo`00
00?o03Ooool00?oo00000_oo00000ooob@3ood<0oom30008oookJP04o`3o/ooonf[ooo]ZoookJPCo
o`002?oonfX00oo00?oooo]ZoookJP02oookJP03ool0Xooonf[ooo]Z00[ooo]Z1Ooo:009oookJP?o
ogT03_oonfX01Ooo003ooo]Zo`2Aoooonf[oo`0000Wooo]Z1Ooo:007oookJP03oooC0?oonf[ooo]Z
00Gooo]Z1?l00004oookJPGoobP00ooonfX00ol00_oooo]ZoookJP03oolX00?ooo]Z1Ooo:005oook
JP03ooo=0?oonf[ooo]Z00Cooo]Z0ooo000YoookJQGoo`000_oonfX6oolX00Cooo]Z0ooo:007oook
JPcoo`002?oonfX;oolX01Oooo]Z2ooo:004oookJP?oWol0GOoonfX00ooL0?oooo]ZoookJP0:oook
JP;oodH01OoonfX00oooR@3ooo]ZoookJP0>oookJP03o`3omooonf[ooo]Z00;ooo]Z00Go/ol0o`08
ooo_0?oo0?ngool0cP06oookJP05o`0Gool0iOoooo]ZoookJ_l0on401?oonfX01_oo;03ooo]Zoook
J_lBo`3ooo]Zo`0]o`Kooo]Z00?o0?goo`3o[_oonfX01_oonfX00ooo0:7ooo]ZoonP0003oookJP06
oh<0ool0=ooooo]ZoookJ_l02?oooo]Z0_oo@`08oookJP07o`3o/ooonf[ooo]ZoookJ_l0eOooo`0[
o`3o]P09oookJP03ol00oooonf[ooo]Z00;ooo]Z00?oo`2SoookJ_oonfX03?oonfX00oooN`3ooo]Z
oookJP0:oookJP03ojGo0?oonf[ooo]Z00kooo]Z00Co0?mjoookJ_l0TOooo`3>2_oonfX00omn0?oo
o`X0oookJP08oookJP03oooC0?oonf[ooo]Z00Gooo]Z1?l00006oookJP03o`3oO?oonf[ooo]Z00Co
oo]Z00Co00;ooookJ_oonf[o01[o1ooonfX00ol0o`3ooo]ZoookJP04oookJP03ooo=0?oonf[ooo]Z
03Gooo]Z1Ooo0;L2oookJPGoool07OoonfX5ocT0oa3ooo]Z0ooo0<XPoookJP?oTP3o1ooonfX3oioo
03;ooo]Z000]oookJP;og03o3?oonfX00oooAP3ooo]ZoookJP03oookJP03oon90?oonf[ooo]Z00ko
oo]Z00?o0?ogoookJ_oonfX00_oonfX00ol02?oo/ol0oookJP02o`3o]`Kooo]Z00Go01Ooo`3Uool0
iOoooo]Zo`3oh@05oookJP06ool/0?oonf[o4_l0oolX0?oonf[o02go1OoonfX00ol0oOoooo]Zo`3o
[P06oookJP;oo`2Q00?ooo]ZoonP0?oo00000_oo00000ol0=oooo`00ool00002ool00003ooo90?oo
@`3ooo]Z00Sooo]Z00Go0?ncoookJ_oonf[ooo]Zo`3Eo`03ool000Sooo]Z00?o`03ooookJ_oonfX0
0_oonfX00ooo0:?ooo]ZoookJP0:oookJPGoobP02OoonfX2oomi013ooo]Z00Go0?mjo`2Aoooonf[o
oo]Zool0cP08oookJPGoobP01ooonfX00oood`3ooo]ZoookJP06oookJPCo00001?oonfX4oolX00Co
oo]Z00?o00;ooookJ_oonfX00ooo:004oookJPCoobP01OoonfX00oooc@3ooo]ZoookJP02oomi0003
oookJ_oo003oo`0000?oo`00:?oonfXBool000Gooo]Z0ooo:007oookJP03oolX0?oonf[ooo]Z00Oo
oo]Z2_oo000:oookJPWoobP06OoonfX9oolX00?ooo]Z0onOo`1NoookJP;og03o3?oonfX00oooAP3o
oo]ZoookJP04oookJP03oon90?oonf[ooo]Z00kooo]Z00?o0?ogoookJ_oonfX00_oonfX01Onco`3o
00Soo`3o]ol0okOoo`3>00Kooo]Z00Go01Ooo`3Uoooonf[ooo]Zo`3oh@04oookJP06ool/0?oonf[o
4_l0oa;o0?oonf[o02go1_oonfX00ol0oOoo0?n^oookJP05oookJP;oo`2Q00?ooo]ZoonP0?oonfX0
0_oonfX01on30?oo03OooookJ_oonf[o00SooookJ_oo@`002OoonfX01ol0ok?ooo]ZoookJ_oonf[o
0=Goool0:ol0okH02OoonfX00oo00?oooo]ZoookJP02oookJP03ool0Xooonf[ooo]Z00gooo]Z00?o
og/0oookJ_oonfX02OoonfX00onUo`3ooo]ZoookJP0?oookJP04o`3oN_l0TOoooo]Zool0cPWooo]Z
00?oOP3oool:0?oonfX02?oonfX00oood`3ooo]ZoookJP06oookJPCo00001_oonfX00ol0ogcooo]Z
oookJP04oookJP04o`02oooonf[ooo]Zo`0Jo`Oooo]Z00?o0?l0oookJ_oonfX01?oonfX00oooc@3o
o`2joookJP1LoookJP;o>@3o4_oonfX3ool0bR3ooo]Z0onB0?l7oookJP?oWol0=OoonfX002cooo]Z
00?og03ooookJ_oonfX02ooonfX00oooAP3ooo]ZoookJP02oookJP;oohT04?oonfX00ol0ooOooo]Z
oookJP02oookJP05o`08oonco`3ooo]Zo`3o]ooo0<h01_oonfX01Ol05ooo0>GooookJ_oonf[o0?oQ
00Cooo]Z0_oo;0001Ooonf[o4_l0oookJ_oonf[o02go00Gooo]Z00?o0?gooookJ_l0ojh01_oonfX0
1Ooo0:7ooo]ZoookJ_ooX03ooo]Z00;oo`0000?o03Ooool00?oo00000_oo00000ooob@3ood<0oook
JP08oookJP05o`3o/ooonf[ooo]ZoookJ_l0eOl00_oo0009oookJP03ol00oooonf[ooo]Z00;ooo]Z
00?oo`2SoookJ_oonfX00ooonfX2ool000Kooo]Z0ooo:00;oookJP03oomi0?oonf[ooo]Z00kooo]Z
00Go0?mjoookJ_l0TOoooo]Zool0cP09oookJPCoobP02?oonfX00oood`3ooo]ZoookJP06oookJPCo
00001?oonfX4oolX00Cooo]Z00Go00;ooookJ_oonf[ooo]ZoolX0005oookJPCoobP01_oonfX4oomi
00Koo`00:?oonfX5ool000;ooo]Z2?oo0008oookJP03oolX0?oonf[ooo]Z01;ooo]Z1ooo0008oook
JP;oo`3:0_oo:0000ooonf[oobP0oolX0005oolX01Wooo]Z2Ooo:0001?oonf[oWol0oioo0?nOo`1P
oookJP03om`0oooonf[ooo]Z00_ooo]Z00?oodH0oookJ_oonfX00ooonfX2oon9013ooo]Z00?o0?og
oookJ_oonfX00_oonfX01Onco`3ooo]Zo`3o]ooonf[oo`3>00Kooo]Z00Go01Ooo`3Uoooonf[ooo]Z
o`3oh@04oookJP03ool/0?oonf[o4_l000;ooo]Z00?o02gooookJ_oonfX01?oonfX00ol0oOoo0?n^
oookJP05oookJP04ool0XOoonf[ooo]ZoonP00?ooo]Z00OoP`3oo`0goooonf[ooo]Zo`08oooonf[o
od<000Wooo]Z00Oo0?ncoookJ_oonf[ooo]Zo`3Eoooo02_o0?nf00Wooo]Z00?o`03ooookJ_oonfX0
0_oonfX00ooo0:?ooo]ZoookJP0=oookJP03oomk0?oonf[ooo]Z00Wooo]Z00?oYOl0oookJ_oonfX0
3ooonfX01?l0og[o097ooookJ_oo0<h9oookJP03ogh0oooo2P3ooo]Z00Wooo]Z00?oom<0oookJ_oo
nfX01_oonfX4o`0000Kooo]Z00?o0?mloookJ_oonfX01?oonfX01?l00_oooo]ZoookJ_l06_l7oook
JP03o`3o0?oonf[ooo]Z00Gooo]Z00?oold0oookJ_oonfX0JooonfX4ool0bR3ooo]Z0onB0?l7oook
JP?oWol0>?oonfX002_ooo]Z00?og03ooookJ_oonfX02ooonfX00oooAP3ooo]ZoookJP02oookJP03
oon90?oonf[ooo]Z00kooo]Z0_ooN@04oookJP05o`08oonco`3ooo]Zo`3o]ooo0<h01_oonfX00ol0
5ooo0>GooookJP02oolX00Cooo]Z00Goob`0oookJ_oonf[o4_l0oookJP02o`0]o`Gooo]Z00?o0?go
o`3o[_l0ojh01_oonfX01Ooo0:7ooo]ZoookJ_ooX03ooo]Z00;oo`0000?o03Ooool00?oo00000_oo
00000ooob@3ood<0oookJP08oookJP07o`3o/ooonf[ooo]ZoookJ_l0eOooo`00o`3o]P09oookJP03
ol00oooonf[ooo]Z00;ooo]Z00?oo`2SoookJ_oonfX01?oonfX3ool000;ooo]Z00?oo`00oookJ_oo
:0000_oo:00;oookJP03oomi0?oonf[ooo]Z00kooo]Z00Go0?mjoookJ_l0TOoooo]Zool0cP0:oook
JP?oobP02?oonfX00oood`3ooo]ZoookJP07oookJPCo00001?oonfX3oolX00Gooo]Z00Go00;ooook
J_oonf[ooo]ZoolX0006ool000?oobP01OoonfX4oomi00Soo`009ooonfX2ool000Gooo]Z1Ooo000P
oookJPGoo`001OoonfX5ool0bPGooo]Z1Ooo:00HoookJP?oobP00_oonfX5oolX00?oWol0H_oonfX0
0ooL0?oooo]ZoookJP0;oookJP03oom60?oonf[ooo]Z00?ooo]Z00?oohT0oookJ_oonfX03_oonfX2
o`3om`Cooo]Z00Go/ol0oookJ_l0okOooo]Zool0cP06oookJP03o`0Gool0iOoooo]Z00;o0?oQ1?oo
nfX00ooo;03ooo]Zoa;o0002oookJP03o`0]oooonf[ooo]Z00Cooo]Z00?o0?goo`3o[_oonfX01Ooo
nfX01?oo0:7ooo]ZoookJ_ooX003oookJP07oh<0ool0=ooooo]ZoookJ_l02?oooo]Zoom30009oook
JP07o`3o/ooonf[ooo]ZoookJ_l0eOooo`0[o`3o]P09oookJP03ol00oooonf[ooo]Z00;ooo]Z00?o
o`2SoookJ_oonfX02OoonfX01Ol:o`3ooo]ZoookJ_oonf[oog/000_ooo]Z00?oYOl0oookJ_oonfX0
3ooonfX01?l0og[o097ooookJ_oo0<h:oookJP03ogh0oooo2P3ooo]Z00Sooo]Z00?oom<0oookJ_oo
nfX01ooonfX4o`0000Gooo]Z00?o0?mloookJ_oonfX01?oonfX01Ol00_oooo]ZoookJ_oonf[o01[o
00Oooo]Z00?o0?l0oookJ_oonfX01OoonfX00oooc@3ooo]ZoookJP1VoookJPGoo`3:8OoonfX3oi80
o`Oooo]Z0onOo`0koookJP00:_oonfX00ooL0?oooo]ZoookJP0;oookJP03oom60?oonf[ooo]Z00;o
oo]Z00?oohT0oookJ_oonfX03_oonfX00oooN@3ooo]ZoookJP03oookJP;oobP000?ooo]Zo`3o]ooo
0<h01_oonfX01?l05ooo0>GooookJ_oo:005oookJP06ool/0?oonf[ooo]Zoa;o0?oonf[o02go1_oo
nfX00ol0oOoo0?n^oookJP06oookJP05ool0XOoonf[ooo]ZoonP0?oonfX00_oo00001ol0=oooo`00
ool00?oonf[oo`00ooo90?oo@`002OoonfX01ol0ok?ooo]ZoookJ_oonf[o0=Goool0:ol0okH02Ooo
nfX00oo00?oooo]ZoookJP02oookJP03ool0Xooonf[ooo]Z00Cooo]Z1Ooo00000ooonf[oo`00oolX
0002oolX00_ooo]Z00?o0?lTojGo0?oonfX03ooonfX01Ol0og[o097ooookJ_oonf[oo`3>00Wooo]Z
00?oOP3ooolX0?oo:0002OoonfX00oood`3ooo]ZoookJP07oookJPCo00001?oonfX3oolX00Gooo]Z
00Go00;ooookJ_oonf[ooo]Zo`0Jo`06ool000?oobP00ooonfX5oomi00Woo`00;_oonfX2ool001Ko
oo]Z2Ooo0004oookJP?oo`000_oonfX5ool0bP_ooo]Z0_oo:00FoookJP;oTP3o0_oo:005oookJP?o
obP00_nOo`0GoookJP;o1ol0BooonfX00ooL0?oooo]ZoookJP0;oookJP03oom60?oonf[ooo]Z00?o
oo]Z00?oohT0oookJ_oonfX03_oonfX00ol0ooOooo]ZoookJP02oookJP;o/ol000Cooo]Zo`3o]ooo
0<koo`3>1_oonfX01?l05ooo0>GooookJ_l0on45oookJP03ool/0?oonf[o4_l000;ooo]Z00?o02go
oookJ_oonfX01?oonfX00ol0oOoo0?n^oookJP05oookJP04ool0XOoonf[ooo]ZoonP00?ooo]Z00Oo
P`3oo`0goooonf[ooo]Zo`08oooonf[ood<000Wooo]Z00Oo0?ncoookJ_oonf[ooo]Zo`3Eoooo02_o
0?nf00Wooo]Z00?o`03ooookJ_oonfX00_oonfX00ooo0:?ooo]ZoookJP0:oookJP04o`[o0?oonf[o
oo]Zoomk00_ooo]Z00?o0?lTojGo0?oonfX03ooonfX01Ol0og[ooo]Zo`2Aoooonf[oo`3>00Wooo]Z
00?oOP3oool:0?oonfX02OoonfX00oood`3ooo]ZoookJP07oookJPCo00001OoonfX00ol0ogcooo]Z
oookJP04oookJP05o`02oooonf[ooo]ZoookJ_l06_l01ooonfX00ol0o`3ooo]ZoookJP06oookJP03
ooo=0?oonf[ooo]Z063ooo]Z1Ooo0<XRoookJPCoTP3o1ooonfX3oioo01Sooo]Z0_l7o`0ToookJP00
=_oonfX2oom600Cooo]Z00?oohT0oookJ_oonfX03_oonfX00oooN@3ooo]ZoookJP03oookJP04oolX
0?oonf[ok`3oo`3o]`Kooo]Z0_oo:0000ol0iOoooo]ZoolX0005oookJP06ool/0?oonf[ooo]Zoa;o
0?oonf[o02go1_oonfX00ol0oOoo0?n^oookJP06oookJP04ool0XOoonf[ooo]ZoonP00;ooo]Z00?o
o`00o`0goooo00000ooo00000ooob@3ood<0oookJP08oookJP07o`3o/ooonf[ooo]ZoookJ_l0eOoo
o`0[o`3o]P09oookJP03ol00oooonf[ooo]Z00;ooo]Z00?oo`2SoookJ_oonfX01OoonfX6ool00003
oookJ_oo:03ooo]Z00cooo]Z00?oYOl0oookJ_oonfX03_oonfX01Ol0og[ooo]Zo`2Aoooonf[oo`3>
00?ooo]Z0_oo0004oookJP03ogh0oooo:03oobP000Wooo]Z00?oom<0oookJ_oonfX02?oonfX4o`00
00Cooo]Z0_oo:006oookJP05o`02oooonf[ooo]ZoookJ_l06_l01ooo0002oolX00;ooo]Z2?ooN@08
ool000[ooo]Z0_oo000ioookJQ7oo`0000?oo`3:oookJ_oonfX03_oonfX00ooo:03ooo]ZoookJP0B
oookJP?oTP3o1ooonfX3oioo0003oolX0?oonf[ooo]Z01Gooo]Z0ol7o`1IoookJP;oodH01OoonfX0
0oooR@3ooo]ZoookJP0>oookJP03o`3omooonf[ooo]Z00;ooo]Z00Go/ol0o`08ooo_0?oo0?ngool0
cP06oookJP05o`0Gool0iOoo0>GooookJ_l0on401?oonfX2ool/0005oookJ_lBo`3ooo]ZoookJ_l0
;Ol01_oonfX00ol0oOoo0?n^oookJP05oookJP04ool0XOoonf[ooo]ZoonP00?ooo]Z00OoP`3oo`0g
oooonf[ooo]Zo`08oooonf[ood<000Wooo]Z00Oo0?ncoookJ_oonf[ooo]Zo`3Eoooo02_o0?nf00[o
oo]Z00Go`03ooookJ_oonf[ooo]Zool0X`0<oookJP04o`[o0?oonf[ooo]Zoomk00cooo]Z00?oYOl0
oookJ_oonfX03_oonfX01Ol0og[ooo]Zo`2Aoooonf[oo`3>00Wooo]Z00?oOP3ooookJ_oo2P002Ooo
nfX00oood`3ooo]ZoookJP08oookJPCo00001OoonfX00ol0ogcooo]ZoookJP04oookJP05o`02oooo
nf[ooo]ZoookJ_l06_l02?oonfX00ol0o`3ooo]ZoookJP05oookJP03ooo=0?oonf[ooo]Z05[ooo]Z
1_oo0<XToookJP?oTP3o1ooonfX4oioo01Sooo]Z0ol7o`0VoookJP00=OoonfX00oooAP3ooo]Zoook
JP03oookJP03oon90?oonf[ooo]Z00kooo]Z00?oogT0oookJ_oonfX00_oonfX2oolX0003oookJ_l0
okOo0?ng00Kooo]Z00GoobP0o`3oS?l0iOoooo]ZoolX0005oookJP06ool/0?oonf[ooo]Zoa;o0?oo
nf[o02go1_oonfX00ol0oOoo0?n^oookJP06oookJP04ool0XOoonf[ooo]ZoonP00;ooo]Z00?oo`00
o`0goooo00000ooo00000ooob@3ood<0oookJP08oookJP07o`3o/ooonf[ooo]ZoookJ_l0eOooo`0[
o`3o]P09oookJP03ol00oooonf[ooo]Z00;ooo]Z00?oo`2SoookJ_oonfX01OoonfX8ool000gooo]Z
00?oYOl0oookJ_oonfX03_oonfX01Ol0og[ooo]Zo`2Aoooonf[oo`3>00Cooo]Z1?oo0002oookJP03
ogh0oooo:03ooo]Z00Wooo]Z00?oom<0oookJ_oonfX02?oonfX4o`0000Cooo]Z0_oo:006oookJP06
o`02oooonf[ooo]ZoookJ_l06_oooo]Z1_oo0002oolX00;ooo]Z2OooN@07ool000[ooo]Z0ooo000h
oookJPooo`009?oonfX4oi80o`Oooo]Z0onOo`0IoookJP;o1ol0FooonfX00oooAP3ooo]ZoookJP04
oookJP03oon90?oonf[ooo]Z00kooo]Z00?o0?ogoookJ_oonfX00_oonfX01Onco`3o00Soo`3o]ol0
okOoo`3>00Kooo]Z00Go01Ooo`3Uoooonf[ooo]Zo`3oh@04oookJP05ool/0?oonf[ooo]Zoa;o0?oo
nfX00_l0;Ol6oookJP03o`3moooonf[ooo]Z00Gooo]Z00Coo`2QoookJ_oonf[ooj000ooonfX01on3
0?oo03OooookJ_oonf[o00SooookJ_oo@`002OoonfX01ol0ok?ooo]ZoookJ_oonf[o0=Goool0:ol0
okH02_oonfX01Oo00?oooo]ZoookJ_oonf[oo`2S00cooo]Z00Co2_l0oookJ_oonf[oog/03?oonfX0
0onUo`3ooo]ZoookJP0?oookJP05o`3oN_l0TOoooo]ZoookJ_oo0<h02OoonfX00omn0?ooo`X0oook
JP09oookJP03oooC0?oonf[ooo]Z00Sooo]Z1?l00004oookJP03o`3oO?oonf[ooo]Z00Gooo]Z00Go
00;ooookJ_oonf[ooo]Zo`0Jo`08oookJP03o`3o0?oonf[ooo]Z00Gooo]Z00?oold0ool0^_oonfX0
DooonfX7ool0bRKooo]Z1?nB0?l7oookJP?oWol06_oonfX2o`Oo02Wooo]Z000doookJP03oom60?oo
nf[ooo]Z00;ooo]Z0_ooR@0?oookJP;oogT01?oonfX2oolX0003oookJ_l0okOoo`3>00Kooo]Z00Go
obP0o`3oS?l0iOoooo]ZoolX0005oookJP06ool/0?oonf[o4_l0oa;o0?oonf[o02go1_oonfX00ol0
oOoo0?n^oookJP06oookJP08ool0XOoonf[ooo]ZoonP0?oonf[oP`3oool00?l0=ol4ool00003ooo9
0?oo@`3oo`0000Sooo]Z00Oo0?ncoookJ_oonf[ooo]Zo`3Eoooo02_o0?nf00Wooo]Z00?o`03ooook
J_oonfX00_oonfX00ooo0:?ooo]ZoookJP06oookJPWoo`002ooonfX00onUo`3ooo]ZoookJP09oook
JP;oobP00ooonfX01Ol0og[oobP0o`2Aoooonf[oo`3>00Cooo]Z1_oo00000omn0?oooo]Zool:0009
oookJP03oooC0?oonf[ooo]Z00Wooo]Z1?l00004oookJP03oolX0?oonf[ooo]Z00Gooo]Z00Ko00;o
oookJ_oonf[ooo]Zo`0JoooonfX6ool00003oookJ_oo:03ooo]Z00;ooo]Z2OooN@07ool000Sooo]Z
1Ooo000goookJPcoo`008ooonfX4oi80o`Sooo]Z0onOo`0IoookJP?o1ol0G?oonfX00oooAP3ooo]Z
oookJP03oookJP;oohT03ooonfX2o`3om`Cooo]Z00Go/ol0oookJ_l0okOooo]Zool0cP06oookJP05
o`0Gool0iOoooo]ZoookJ_l0on401?oonfX01_oo;03ooo]Zoa;o0?lBo`3ooo]Zo`0]o`Oooo]Z00?o
0?gooookJ_oonfX01OoonfX01?oo0:7ooo]ZoookJ_ooX002oookJP;oP`3o00Ko03OooookJ_oonf[o
00Soooo90?oo@`09oookJP07o`3o/ooonf[ooo]ZoookJ_l0eOooo`0[o`3o]P0:oookJP05ol00oooo
nf[ooo]ZoookJ_oo0:<03?oonfX01Ol:o`3ooo]ZoookJ_oonf[oog/000_ooo]Z00?oYOl0oookJ_oo
nfX03ooonfX01Ol0og[o097ooookJ_oonf[oo`3>00Wooo]Z00?oOP3ooookJ_oo2P002OoonfX00ooo
d`3ooo]ZoookJP09oookJPCo00001?oonfX00ol0ogcooo]ZoookJP05oookJP05o`02oooonf[ooo]Z
oookJ_l06_l02?oonfX00ol0o`3ooo]ZoookJP06oookJP03ooo=0?oonf[ooo]Z04oooo]Z0ooo0<XY
oookJPCoTP3o2?oonfX3oioo01[ooo]Z0ol7o`0[oookJP00<ooonfX00oooAP3ooo]ZoookJP02oook
JP03oon90?oonf[ooo]Z00kooo]Z00?oogT0oookJ_oonfX00ooonfX2oolX0003oookJ_l0okOoo`3>
00Kooo]Z00GoobP0o`3oS?l0iOoooo]ZoolX0005oookJP03ool/0?oonf[o4_l000;ooo]Z00?o02go
oookJ_oonfX00ooonfX2o`3mo`03o`3o[_oonf[ooo]Z00Gooo]Z00Soo`2QoookJ_oonf[ooj00oook
J_n30?oooo]Zo`0go`Coo`0000?oolT0oom30?oo00000_oo0006oookJP07o`3o/ooonf[ooo]Zoook
J_l0eOooo`0[o`3o]P09oookJP03ol00oooonf[ooo]Z00;ooo]Z00?oo`2SoookJ_oonfX01_oonfX8
ool000cooo]Z00?oYOl0oookJ_oonfX02_oonfX3oolX00;ooo]Z00Go0?mjoolX0?oo:03ooo]Zool0
cP04oookJPOoo`0000?oo`X0oookJ_oonfX02?oonfX00oood`3ooo]ZoookJP09oookJPCo00001?oo
nfX00ol0ogcooo]ZoookJP05oookJP06o`02oooonf[ooo]ZoookJ_l06_oooo]Z1_oo00000ooonf[o
0?l0oookJP03oookJPSoogT01ooo00000ooonf[oobP0oolX0004oookJPOoo`00=ooonfX9ool002;o
oo]Z0onB0?l9oookJP?oWol06OoonfX3o`Oo05kooo]Z00?oodH0oookJ_oonfX00ooonfX00oooR@3o
oo]ZoookJP0>oookJP03o`3omooonf[ooo]Z00?ooo]Z00Go/ol0oookJ_l0okOooo]Zool0cP06oook
JP05o`0Gool0iOoooo]ZoookJ_l0on401?oonfX00ooo;03ooo]Zoa;o0002oookJP03o`0]oooonf[o
oo]Z00Cooo]Z0_l0oOl7oookJP04ool0XOoonf[ooo]ZoonP00;ooo]Z00?oP`3ooookJ_l0=ol00_oo
nfX00ol02?ooolT0oom30009oookJP07o`3o/ooonf[ooo]ZoookJ_l0eOooo`0[o`3o]P0:oookJP05
ol00oooonf[ooo]ZoookJ_oo0:<03?oonfX01Ol:o`3ooo]ZoookJ_oonf[oog/000_ooo]Z00?o0?lT
ojGo0?oonfX03ooonfX01Ol0og[ooo]Zo`2Aoooonf[oo`3>00Wooo]Z00?oOP3ooookJ_oo2P002_oo
nfX00oood`3ooo]ZoookJP09oookJPCo00001?oonfX00ol0ogcooo]ZoookJP05oookJP05o`02oooo
nf[ooo]ZoookJ_l06_l02?oonfX00ol0o`3ooo]ZoookJP06oookJP03ooo=0?oo0;[ooo]Z07Sooo]Z
0onB0?l9oookJP?oWol06_oonfX3o`Oo02kooo]Z000boookJP03oom60?oonf[ooo]Z00;ooo]Z00?o
ohT0oookJ_oonfX03_oonfX00oooN@3ooo]ZoookJP03oookJP05oolX0?oonf[ooo]Zo`3o]ooo0<h0
1_oonfX2oolX0003o`3Uoooonf[oobP000Gooo]Z00Coob`0oookJ_lBo`3ooo]Z0_l0;Ol5oookJP03
o`3mool0ojkooo]Z00Kooo]Z0_oo0:42oookJP06oonP0?oonf[oP`3ooookJ_l0=ooooo]Z0ooo0000
1?oob@3ood<0ool00?oo0007oookJP07o`3o/ooonf[ooo]ZoookJ_l0eOooo`0[o`3o]P09oookJP03
ol00oooonf[ooo]Z00;ooo]Z00?oo`2SoookJ_oonfX01ooonfX7ool000cooo]Z00?oYOl0oookJ_oo
nfX01_oonfX2ool000;ooo]Z1Ooo:0000ol0og[oobP0oolX0003oolX00Cooo]Z1_oo00000ooo2P3o
o`00ool00008oookJP03oooC0?oonf[ooo]Z00[ooo]Z1Ol00003oookJP03o`3oO?oonf[ooo]Z00Co
oo]Z00?o00;ooookJ_oonfX00_oonfX00ol06_oooo]Zool00005ool00003oookJ_l0o`3ooo]Z00Co
oo]Z1oooN@07ool000?oobP01?oonfX8ool003Kooo]Z1_oo000CoookJQ7oo`0000?oTP3ooookJ_oo
nfX01ooonfX3oioo01Wooo]Z0ol7o`1PoookJP03oom60?oonf[ooo]Z00?ooo]Z00?oohT0oookJ_oo
nfX03_oonfX00ol0ooOooo]ZoookJP02oookJP;o/ol000Cooo]Zo`3o]ooo0<koo`3>1_oonfX01Ol0
5ooo0>GooookJ_oonf[o0?oQ00Cooo]Z00?oob`0oookJ_lBo`000_oonfX00ol0;Ooooo]ZoookJP04
oookJP03o`3mool0ojkooo]Z00Gooo]Z0_oo0:42oookJP06oonP0?oonf[ooo]Zoh<0oooonf[o03Oo
0_oonfX00ol02?ooolT0oom30009oookJP07o`3o/ooonf[ooo]ZoookJ_l0eOooo`0[o`3o]P0:oook
JP05ol00oooonf[ooo]ZoookJ_oo0:<03?oonfX01Ol:o`3ooo]ZoookJ_oonf[oog/000_ooo]Z00?o
0?lTojGo0?oonfX03ooonfX00ol0og[ooo]Zo`2Ao`02oookJP03ool0c_oonf[ooo]Z00Gooo]Z00Co
08cooookJ_mn0?ooo`X02_oonfX00oood`3ooo]ZoookJP0:oookJPGo00000ooonfX00ol0ogcooo]Z
oookJP04oookJP03o`02oooonf[ooo]Z00;ooo]Z00?o01[ooookJ_oonfX01_oonfX00ol0o`3ooo]Z
oookJP07oookJP03ooo=0?oonf[ooo]Z00Kooo]Z00?o0?oCoookJ_oonfX0J_oonfX4oi80o`Wooo]Z
0onOo`0IoookJPCo1ol0<OoonfX0037ooo]Z00?oodH0oookJ_oonfX00_oonfX00oooR@3ooo]Zoook
JP0>oookJP03oomi0?oonf[ooo]Z00?ooo]Z00CoobP0oookJ_oonf[o0?ng1OoonfX01Ooo:03ooo]Z
oolX0?oonf[o0>Go00;oobP01OoonfX01Ooo;03ooo]Zoa;o0?oonf[o02go00Kooo]Z00?o0?goo`3o
[_oonfX01_oonfX02_oo0:7ooo]ZoookJ_oonf[ooj00oookJ_n30?oooo]Zo`0goooonfX3ool00004
ooo90?oo@`3oo`00ool000Oooo]Z00Oo0?ncoookJ_oonf[ooo]Zo`3Eoooo02_o0?nf00Wooo]Z00?o
`03ooookJ_oonfX00_oonfX00ooo0:?ooo]ZoookJP07oookJPKoo`0000?oog/0oookJ_oonfX02_oo
nfX00ol0obCoYOl0oookJP07oookJP?oo`0000?ooo]ZoolX0?oo:0002_oo:002oookJPOoo`0000?o
o`X0oookJ_oonfX02?oonfX00oood`3ooo]ZoookJP0:oookJPCo00000ooonfX00ol0ogcooo]Zoook
JP02oookJPGoogT00ooonfX00ol06_oooo]ZoookJP05ool00003oookJ_l0o`3ooo]Z00Gooo]Z1_oo
N@04ool00003oookJ_oo003oobP000CoobP00_oonfX:ool003Gooo]Z1?oo000EoookJPooo`002Ooo
nfX3oioo01Sooo]Z1?l7o`0>oookJP;o0?n7D_oonfX00oooAP3ooo]ZoookJP03oookJP03oon90?oo
nf[ooo]Z00kooo]Z00?o0?ogoookJ_oonfX00_oonfX01Onco`3o00SooookJ_l0okOoo`3>00Oooo]Z
00?o01Ooo`3UoooonfX00_l0on44oookJP03ool/0?oonf[o4_l000;ooo]Z00?o02gooookJ_oonfX0
1?oonfX00ol0oOoo0?n^oookJP05oookJP05ool0XOoonf[ooo]ZoookJ_ooX0000_oonfX00on30?oo
oo]Zo`0go`02oookJP03o`08oooob@3ood<000Wooo]Z00Oo0?ncoookJ_oonf[ooo]Zo`3Eoooo02_o
0?nf00[ooo]Z00Go`03ooookJ_oonf[ooo]Zool0X`0<oookJP05o`[o0?oonf[ooo]ZoookJ_ooN`00
2ooonfX00ol0obCoYOl0oookJP0?oookJP03o`3oN_oonf[o097o00;ooo]Z00?oo`3>oookJ_oonfX0
1_oonfX01?l0S?ooOP3ooookJ_oo2P0:oookJP03oooC0?oonf[ooo]Z00[ooo]Z1?l00003oookJP03
o`3oO?oonf[ooo]Z00Gooo]Z00?o00;ooookJ_oonfX00_oonfX00ol06_oooo]ZoookJP06oookJP03
o`3o0?oonf[ooo]Z00Oooo]Z00?oold0ool0^_oonfX01_oonfX00ol0om?ooo]ZoookJP1VoookJPCo
TP3o2_oonfX3oioo01Wooo]Z0ol7o`0?oookJP;o0?n79?oonfX002oooo]Z0_ooAP03oookJP;oohT0
3ooonfX2oomi00Gooo]Z00CoobP0oookJ_l0okOo0?ng1_oonfX2oolX00;o0>Go00?oobP0oookJ_oo
nfX00ooonfX2oomi0004oookJ_lBo`3ooo]Zo`0]o`Kooo]Z00?o0?goo`3o[_oonfX01_oonfX02_oo
0:7ooo]ZoookJ_oonf[ooj00oookJ_n30?oooo]Zo`0goooonfX3ool00003ooo90?oo@`3oo`0000So
oo]Z00Oo0?ncoookJ_oonf[ooo]Zo`3Eoooo02_o0?nf00Wooo]Z00?o`03ooookJ_oonfX00_oonfX0
0ooo:03ooo]ZoookJP08oookJPGoo`0000?oog/0oookJ_oonfX02ooonfX00onUo`3ooo]ZoookJP06
oookJPKoo`003?oo:0000ooonf[oo`00ool00004ool00003ool:0?oonf[ooo]Z00Sooo]Z00?oom<0
oookJ_oonfX02ooonfX4o`0000?ooo]Z00?o0?mloookJ_oonfX00_oonfX8oomi0003o`0Joooonf[o
oo]Z00Coo`000ooonfX00ol0o`3ooo]ZoookJP04oookJPKoogT01?oo0007oolX00coo`00=?oonfX0
0ooo003ooo]ZoookJP0FoookJPgoo`001ooonfX4oioo01Sooo]Z0ol7o`0?oookJP?o0?n7D_oonfX2
oom600Cooo]Z0_ooR@0?oookJP;o0?og1?oonfX01Onco`3o00Soo`3o]ol0okOoo`3>00Oooo]Z0_l0
iOl00ooonf[o0?oQoookJP03oookJP;oob`000Gooo]Zoa;o0?oonf[ooo]Zo`0]o`06oookJP03o`3m
ool0ojkooo]Z00Gooo]Z00Goo`2QoookJ_oonf[ooo]ZoonP0002oookJP03oh<0oooonf[o03Oo00;o
oo]Z00?o00Soooo90?oo@`002OoonfX02?l0ok?ooo]ZoookJ_oonf[o0=Goool0:ooonf[o0?nf2Ooo
nfX01Oo00?oooo]ZoookJ_oonf[oo`2S00cooo]Z00Go2_l0oookJ_oonf[ooo]Zoomk000<oookJP03
ojGo0?oonf[ooo]Z00[ooo]Z00?oo`0koookJ_oonfX00_oonfX00ol0og[o097ooookJP02oookJP03
ool0c_oonf[ooo]Z00Gooo]Z00Co08coogh0oooonf[oo`X02_oonfX00oood`3ooo]ZoookJP0;oook
JPCo00000ooonfX00ol0ogcooo]ZoookJP05oookJP03o`02oooonf[ooo]Z00;ooo]Z00?o01[ooook
J_oonfX01ooonfX00ol0o`3ooo]ZoookJP06oookJP03ooo=0?oo0;[ooo]Z00Oooo]Z00?o0?oCoook
J_oonfX0HOoonfX4oi80o`[ooo]Z1?nOo`0HoookJPCo1ol03ooonfX3o`3oQbKooo]Z000^oookJP03
oom60?oonf[ooo]Z00;ooo]Z00?oohT0oookJ_oonfX02OoonfX00oooN@3ooo]ZoookJP02oookJP03
oomi0?oonf[ooo]Z00?ooo]Z0_oo:0000ooonf[o0?ngonl0o`06oookJP?oobP000?ooo]ZoolX0?oo
nfX01?oonfX01_ooN@3ooo]ZoookJ_lBo`3ooo]Zo`0]o`Kooo]Z00?o0?goo`3o[_oonfX01_oonfX0
2Ooo0:7ooo]ZoookJ_oonf[ooj00oookJ_n30?oooo]Zo`0go`02oookJP;oo`0000?oolT0oom30?oo
nfX02?oonfX01ol0ok?ooo]ZoookJ_oonf[o0=Goool0:ol0okH02OoonfX00oo00?oooo]ZoookJP03
oookJP03oolX0?oonf[ooo]Z00Oooo]Z1?oo00001?oonf[oog/0ool00?oo0003oookJP03ool00?oo
nf[ooo]Z00Gooo]Z00?oYOl0oookJ_oonfX01ooonfX7ool000WoobP00ooonfX6ool00003ool:0?oo
nf[ooo]Z00Sooo]Z00?oom<0oookJ_oonfX02ooonfX4o`0000?ooo]Z00?o0?mloookJ_oonfX00_oo
nfX8oomi0003o`0Joooonf[ooo]Z00Coo`000ooonfX00ol0o`3ooo]ZoookJP05oookJPGoogT00ooo
0008oolX00?ooo]Z2_oo0002oookJP;oobP0BOoonfX:ool000Gooo]Z1?nOo`0HoookJPCo1ol03ooo
nfX3o`3oQeCooo]Z00?oodH0oookJ_oonfX00ooonfX00oooR@3ooo]ZoookJP0>oookJP03o`3omooo
nf[ooo]Z00?ooo]Z00Go/ol0oookJ_l0okOok`3oool0cP06oookJP05o`0Gool0iOoooo]ZoookJ_l0
on401?oonfX01?oo;03ooo]ZoookJ_lBo`02oookJP03o`0]oooonf[ooo]Z00Cooo]Z00?o0?goo`3o
[_oonfX01OoonfX01Ooo0:7ooo]ZoookJ_oonf[ooj0000;ooo]Z00?oP`3ooookJ_l0=ol00_oonfX0
0ol02?ooolT0oom30009oookJP08o`3o/ooonf[ooo]ZoookJ_l0eOooo`0[oookJ_l0okH9oookJP03
ol00oooonf[ooo]Z00;ooo]Z00?oo`2SoookJ_oonfX02OoonfX01Ol:o`3ooo]ZoookJ_oonf[oog/0
00Gooo]Z00?ooh`0oookJ_oonfX01?oonfX00ol0obCoYOl0oookJP0;oookJP07ool0>ooonf[ooo]Z
oookJ_l0og[ooo]Zo`2Ao`02oookJP03ool0c_oonf[ooo]Z00Gooo]Z00Go08cooookJ_mn0?oooo]Z
ool:000:oookJP03oooC0?oonf[ooo]Z00_ooo]Z1?l00003oookJP03o`3oO?oonf[ooo]Z00Gooo]Z
00?o00;ooookJ_oonfX00_oonfX00ol06_oooo]ZoookJP02oookJP03oonL0?oonf[ooo]Z00;ooo]Z
00?o0?l0oookJ_oonfX01ooonfX00oooc@3ooo]ZoookJP07oookJP03o`3odooonf[ooo]Z00_ooo]Z
0_l7o`1?oookJPCoTP3o2_oonfX4oioo01Sooo]Z1?l7o`0@oookJP?o0?n7:OoonfX002gooo]Z00?o
odH0oookJ_oonfX00_oonfX00oooR@3ooo]ZoookJP0:oookJP;oogT00_oonfX00oooN@3oobP0oook
JP03oookJP;oobP000Gooo]Zo`3o]ooo0<kooo]ZoolX0004oookJPGoobP01OoonfX01_ooN@3ooo]Z
oookJ_lBo`3ooo]Zo`0]o`Kooo]Z00?o0?goo`3o[_oonfX01_oonfX02Ooo0:7ooo]ZoookJ_oonf[o
oj00oookJ_n30?oooo]Zo`0go`02oookJP;oo`0000?oolT0oom30?oonfX02?oonfX01ol0ok?ooo]Z
oookJ_oonf[o0=Goool0:ol0okH02OoonfX00oo00?oooo]ZoookJP03oookJP03oolX0?oonf[ooo]Z
00Sooo]Z0ooo00000ooonf[oog/0oookJP03ool000;ooo]Z00?oo`00oookJ_oonfX01?oonfX00onU
o`3ooo]ZoookJP07oookJPWoo`001ooo:003oookJPKoo`0000?oo`X0oookJ_oonfX02?oonfX00ooo
d`3ooo]ZoookJP0<oookJPCo00000_oonfX00ol0ogcooo]ZoookJP03oookJPOoogT000?o01[ooook
J_oonfX00_oonfX3ool000;ooo]Z00Coo`00o`3o0?oo003oo`001OoonfX5oomi00;oo`002_oo:006
oookJPOoo`0000Cooo]ZoolX0?oo:03oobP0AooonfX9ool000;ooo]Z1OnOo`0IoookJP?o1ol04?oo
nfX00ol02ooo0?n7o`3oQ`1FoookJP03oom60?oonf[ooo]Z00?ooo]Z00?oohT0oookJ_oonfX03_oo
nfX00ol0ooOooo]ZoookJP03oookJP05ok?o0?oonf[o0?ngoookJ_oo0<h01_oonfX01Ol05ooo0>Go
oookJ_oonf[o0?oQ00Cooo]Z00Coob`0oookJ_oonf[o4_l00_oonfX00ol0;Ooooo]ZoookJP04oook
JP03o`3mool0ojkooo]Z00Gooo]Z00Goo`2QoookJ_oonf[ooo]ZoonP0002oookJP03oh<0oooonf[o
03Oo00;ooo]Z00?o00Soooo90?oo@`002OoonfX02?l0ok?ooo]ZoookJ_oonf[o0=Goool0:ooonf[o
0?nf2OoonfX00oo00?oooo]ZoookJP02oookJP03ool0Xooonf[ooo]Z00Wooo]Z00Go2_l0oookJ_oo
nf[ooo]Zoomk0006oookJP03oon<0?oonf[ooo]Z00?ooo]Z00?o0?lTojGo0?oonfX02ooonfX01ooo
03_ooo]ZoookJ_oonf[o0?mjoookJ_l0TOl00_oonfX00ooo0<kooo]ZoookJP06oookJP04o`2<oomn
0?oooo]Zool:00[ooo]Z00?oom<0oookJ_oonfX03?oonfX4o`0000;ooo]Z00?o0?mloookJ_oonfX0
1_oonfX00ol00_oooo]ZoookJP02oookJP03o`0Joooonf[ooo]Z00;ooo]Z00?ooi`0oookJ_oonfX0
0_oonfX00ol0o`3ooo]ZoookJP07oookJP03ooo=0?oo0;[ooo]Z00;ooo]Z00?oU@3ooookJ_oonfX0
0ooonfX00ol0om?ooo]ZoookJP0<oookJP;o1ol0BooonfX2oi80o`Wooo]Z1OnOo`0IoookJP?o1ol0
4OoonfX3o`3oQbcooo]Z000/oookJP03oom60?oonf[ooo]Z00;ooo]Z00?oohT0oookJ_oonfX02_oo
nfX5oomi0003oookJ_oo:03ooo]Z00;ooo]Z00GoobP0oookJ_oonf[o0?ngool0cP02oookJP03oolX
0?oonf[ooo]Z00;ooo]Z1_oo:003oookJP06oomi0?oonf[o4_l0oa;o0?oonf[o02go1_oonfX00ol0
oOoo0?n^oookJP06oookJP03ool0XOoonf[ooo]Z00;oobP000Cooo]Zoh<0ool0=ooo03Oo0ooonfX0
0ooo003oolT0oom30009oookJP07o`3o/ooonf[ooo]ZoookJ_l0eOooo`0[o`3o]P09oookJP03ol00
oooo:03oobP000?ooo]Z00?oobP0oookJ_oonfX02?oonfX3ool00003oookJ_ooN`3ooo]Z00Koo`00
1_oonfX00onUo`3ooo]ZoookJP08oookJPOoo`002?oo:0001?oo003ooo]ZoookJ_oonfX5ool00003
ool:0?oonf[ooo]Z00Wooo]Z00?oom<0oookJ_oonfX03?oonfX4o`0000;ooo]Z00?o0?mloookJ_oo
nfX00ooonfX7oomi0003o`0Joooonf[ooo]Z00;ooo]Z1_oo00000ol0o`3oo`00ool00006oookJPCo
ogT000?ooo]Zool00?oo00002Ooo:007oookJPOoo`001Ooo:00DoookJP?oo`00;ooonfX6ool000Co
Wol03?oonfXAoomi0003o`Oo0?oonf[ooo]Z00kooo]Z00Co00_oo`3oQol0ohOo0?n7EooonfX00ooo
AP3ooo]ZoookJP03oookJP03oon90?oonf[ooo]Z00kooo]Z00?o0?ogoookJ_oonfX00_oonfX2ok?o
0004oookJ_l0okOoo`3>ool0cPKooo]Z00Go01Ooo`3Uoooonf[ooo]Zo`3oh@04oookJP04ool/0?oo
nf[o4_l0oa;o00;ooo]Z00?o02gooookJ_oonfX01?oonfX00ol0oOoo0?n^oookJP05oookJP03ool0
XOoonf[ooo]Z00;ooj000_oonfX00on30?oo03Ooo`0go`02oookJP03o`08oooob@3ood<000Wooo]Z
00So0?ncoookJ_oonf[ooo]Zo`3Eoooo02_ooo]Zo`3o]PWooo]Z00?o`03ooookJ_oonfX00_oonfX0
0ooo0:?ooo]ZoookJP09oookJP05o`[o0?oonf[ooo]ZoookJ_ooN`001_oonfX00oooS03ooo]Zoook
JP03oookJP03o`3o9?nUo`3ooo]Z00_ooo]Z00Ooo`0koookJ_oonf[ooo]Zo`3oN_oonf[o097o00;o
oo]Z00?oo`3>o`3oh_oonfX01_oonfX01?l0S?ooOP3ooookJ_oo2P0;oookJP03oooC0?oonf[ooo]Z
00cooo]Z1?l00002oookJP03o`3oO?oonf[ooo]Z00Kooo]Z00?o00;ooookJ_oonfX00_oonfX00ol0
6_oooo]ZoookJP02oookJP03oonL0?oonf[ooo]Z00;ooo]Z00?o0?l0oookJ_oonfX02?oonfX01Ooo
c@3ooo]ZoookJ_oonf[oU@3o00Kooo]Z00?o0?oCoookJ_oonfX03OoonfX2o`Oo053ooo]Z1?nOo`0J
oookJPCo1ol04OoonfX3o`3oQboooo]Z000[oookJP03oom60?oonf[ooo]Z00;ooo]Z00?oohT0oook
J_oonfX02_oonfX6oomi00?oobP000Gooo]ZoolX0?oonf[ooo]Zo`3o]`03oookJP?oobP000?ooo]Z
oolX0?oo:0001ooo:0001Ooonf[oogT0oookJ_lBo`3ooo]Z00;o02go1_oonfX00ol0oOoooo]Zoook
JP06oookJP04ool0XOoonf[ooo]ZoolX00;ooo]Z00?oP`3oo`0goooonfX00ooonfX01?oo003oolT0
oom30?oonfX2ool000Kooo]Z00Oo0?ncoookJ_oonf[ooo]Zo`3Eoooo02_o0?nf00Wooo]Z00?o`03o
oolX0?oo:0000_oo:0000ooonf[oobP0oookJP02oookJP03ool00?oonf[ooo]Z00Gooo]Z00Coo`00
oookJ_oonf[oog/00_oonfX6ool000Gooo]Z00?oYOl0oookJ_oonfX02OoonfX6ool000SoobP00ooo
0002oookJP?oo`0000?oOP3ooookJ_oo2P002_oonfX00oood`3ooo]ZoookJP0=oookJPCo00000_oo
nfX00ol0ogcooo]ZoookJP03oookJPKoogT000?ooo]Zo`0JoooonfX00ooonfX6ool00003o`3o0?oo
003oo`0000Oooo]Z0oooN@02oookJPKoobP00_oo0003oolX00Gooo]Z1Ooo0002oookJPSoobP04_oo
nfX6ool001;ooo]Z1Ooo:00EoookJP04oioo0?oo003oo`00ool000;oWol04?oonfX?oomi013ooo]Z
00Co00_oo`3oQol0ohOo0?n7FOoonfX00oooAP3ooo]ZoookJP03oookJP03oon90?oonf[ooo]Z00ko
oo]Z00?o0?ogoookJ_oonfX00_oonfX01Onco`3o00SooookJ_l0okOoo`3>00Oooo]Z00Go01Ooo`3U
oooonf[ooo]Zo`3oh@04oookJP03ool/0?oonf[o4_l000;ooo]Z0_l0;Ol6oookJP03o`3moooonf[o
oo]Z00Gooo]Z00Coo`2QoookJ_oonf[ooj000ooonfX00on30?oo03OooookJP02oookJP03o`08oooo
b@3ood<000;ooo]Z00?o0?;ooookJ_oonfX01?oonfX02?l0ok?ooo]ZoookJ_oonf[o0=Goool0:ooo
nf[o0?nf2OoonfX00oo00?oooo]ZoookJP02oookJP05ool0Xooonf[ooo]ZoookJ_oo08D01ooonfX0
1Ol:o`3ooo]ZoookJ_oonf[oog/000Kooo]Z00?ooh`0oookJ_oonfX00ooonfX00ol0obCoYOl0oook
JP0;oookJP03ool0>ooonf[ooo]Z00;ooo]Z00?o0?mjoookJ_l0TOl00_oonfX00ooo0<ko0?oRoook
JP06oookJP04o`2<oomn0?oooo]Zool:00[ooo]Z00?oom<0oookJ_oonfX03OoonfX4o`0000;ooo]Z
00?o0?mloookJ_oonfX01OoonfX00ol00_oooo]ZoookJP03oookJP03o`0Joooonf[ooo]Z00;ooo]Z
00?ooi`0oookJ_oonfX00_oonfX00ol0o`3ooo]ZoookJP09oookJP05ooo=0?oonf[ooo]ZoookJ_nE
0?l01_oonfX00ol0om?ooo]ZoookJP0>oookJP;o1ol0BOoonfX5oioo01_ooo]Z0ol7o`0BoookJP?o
0?n7<_oonfX002[ooo]Z00CoodH0oookJ_oonf[ooo]Z0_ooR@0<oookJPKoogT01Ooo:0000ooonf[o
0?ngo`3o]`03oookJPkoobP000GoogT0oookJ_lBo`3ooo]Zo`0]o`07oookJP03o`3moooonf[ooo]Z
00Kooo]Z00Coo`2QoookJ_oonf[oobP00_oonfX00on30?oo03OooookJP02oookJP06o`08oooo003o
od<0oom30?oonf[oo`001ooonfX01ol0ok?ooo]ZoookJ_oonf[o0=Goool0:ol0okH02OoonfX00oo0
0?oooo]ZoolX0004oolX00Cooo]Z00?oo`00oookJ_oonfX01?oonfX01?oo003ooo]ZoookJ_ooN`02
oookJPSoo`000ooonfX00oooN@3oYOl0oookJP09oookJPKoo`002?oo:002ool000?ooo]Z0ooo0000
0omn0?oooo]Zool:000:oookJP03oooC0?oonf[ooo]Z00kooo]Z1?l00002oookJP03o`3oO?oonf[o
oo]Z00?ooo]Z1_ooN@000ooonf[o01[ooookJP03oookJPKoo`0000?o0?l0ool00?oo00002?oonfX3
oomi00KoobP00ooo0004oolX00Cooo]Z1_oo00000ooonf[oobP0oolX0007oolX017ooo]Z2Ooo000?
oookJPcoobP01ooonfX7oioo0003oookJ_oo003ooo]Z01?ooo]Z3OooN@0?oookJP04o`0;ool0ohOo
0?n7o`3oQe_ooo]Z00?oodH0oookJ_oonfX00_oonfX2oon900oooo]Z0_l0ooL4oookJP05ok?o0?l0
2?oo0?ngo`3o]ooo0<h01ooonfX00ol05ooo0>GooookJP02o`3oh@Cooo]Z00?oob`0oookJ_lBo`00
0_oonfX00ol0;Ooooo]ZoookJP05oookJP03o`3moooonf[ooo]Z00Gooo]Z00Coo`2QoookJ_oonf[o
oj000_oonfX2oh<0o`03o`0goooonf[ooo]Z00;o00So0_oo@`02oookJP03o`3boooonf[ooo]Z00Co
oo]Z00So0?ncoookJ_oonf[ooo]Zo`3Eoooo02_ooo]Zo`3o]PWooo]Z00?o`03ooookJ_oonfX00_oo
nfX00ooo0:?ooo]ZoookJP02oookJP03ool0QOoonf[ooo]Z00Cooo]Z00Go2_l0oookJ_oonf[ooo]Z
oomk0006oookJP03oon<0?oonf[ooo]Z00?ooo]Z00?o0?lToookJ_nUo`003?oonfX01ooo03_ooo]Z
oookJ_oonf[o0?mjoookJ_l0TOl00_oonfX00ooo0<ko0?oRoookJP06oookJP04o`2<oomn0?oooo]Z
ool:00_ooo]Z00?oom<0oookJ_oonfX03OoonfX4o`0000;ooo]Z00?o0?mloookJ_oonfX01OoonfX0
0ol00_oooo]ZoookJP03oookJP03o`0Joooonf[ooo]Z00;ooo]Z00?ooi`0oookJ_oonfX00_oonfX0
0ol0o`3ooo]ZoookJP09oookJP03ool0^_ooc@3ooo]Z00;ooo]Z00?oU@3ooookJ_oonfX01?oonfX0
0ol0om?ooo]ZoookJP0?oookJP;o1ol0@?oonfX7oioo01cooo]Z1?l7o`0BoookJP?o0?n7=OoonfX0
02gooo]Z00?oohT0oookJ_oonfX03?oonfX5oomi00OoobP000?ok`3ooookJ_oonfX00_oonfX=oolX
0005oomi0?oonf[o4_l0oookJ_l0;Ol01_oonfX2o`3mo`Sooo]Z00Coo`2QoookJ_oonf[oobP00_oo
nfX00on30?oo03OooookJP02oookJP03o`08oooonf[ood<000;ooo]Z00?oo`00oookJ_oonfX01Ooo
nfX01ol0ok?ooo]ZoookJ_oonf[o0=Goool0:ol0okH02OoonfX00oo00?oooo]ZoolX0002oolX0004
ool00?oo:03oobP0oolX00;ooo]Z00?oo`00oookJ_oonfX01OoonfX00ol:o`3ooo]Zoomk0003oook
JPWoo`000_oonfX00onUo`3ooo]ZoookJP09oookJPGoo`000ooo:0001?l0TOooobP0oolX0?oo:003
ool000Cooo]Z0_oo00001?mn0?oooo]ZoookJ_oo2P0:oookJP03oooC0?oonf[ooo]Z00kooo]Z1?l0
00000ooonf[o0?mloookJP05oookJPGoogT00_oonfX00ol06_oooo]ZoolX0008oolX0003ool00?l0
o`3oo`0000Wooo]Z00?oold0oomi0?oo:0001?oo:005ool000?oobP00ooonfX8ool000_oobP03ooo
nfX<ool000cooo]Z4?oo:003oioo01kooo]Z2oooN@0>oolX00?o0?n7H_oonfX00oooR@3ooo]Zoook
JP0>oookJP03o`3omooonf[ooo]Z00?ooo]Z00Go/ol0o`08ool0okOok`3oool0cP07oookJP04o`0G
ool0iOoooo]Zo`3oh@Gooo]Z00?oob`0oookJ_lBo`000_oonfX00ol0;Ooooo]ZoookJP04oookJP;o
0?go1ooonfX01?oo0:7ooo]ZoookJ_ooX002oookJP03oh<0oooonf[o03Oo00;ooo]Z00?o00Sooook
J_oo@`000ooonfX00ol0l_oooo]ZoookJP04oookJP08o`3o/ooonf[ooo]ZoookJ_l0eOooo`0[oook
J_l0okH9oookJP03ol00oooonf[ooo]Z00;ooo]Z00?oo`2SoookJ_oonfX00_oonfX00ooo08Gooo]Z
oookJP05oookJP04o`[o0?oonf[ooo]Zoomk00Kooo]Z00?ooh`0oookJ_oonfX01?oonfX00ol0obCo
YOl0oookJP0;oookJP07ool0>ooonf[ooo]ZoookJ_l0og[ooo]Zo`2Ao`02oookJP03ool0c_l0on;o
oo]Z00Kooo]Z00Go08cooookJ_mn0?oooo]Zool:000:oookJP03oooC0?oonf[ooo]Z00kooo]Z1?l0
00000ooonf[o0?mloookJP07oookJP03o`02oooonf[ooo]Z00?ooo]Z00?o01[ooookJ_oonfX00_oo
nfX00oooW03ooo]ZoookJP03oookJP03o`3o0?oonf[ooo]Z00Sooo]Z00?oo`2jooo=0?oonfX00_oo
nfX00onE0?oooo]ZoookJP05oookJP03o`3odooonf[ooo]Z013ooo]Z0_l7o`0doookJP[oWol07ooo
nfX4o`Oo01;ooo]Z00Co00_oo`3oQol0ohOo0?n7>?oonfX002cooo]Z00?oohT0oookJ_oonfX03?oo
nfX6oomi00SoobP00_oonfX5oolX0003o`3Uoooo:03oobP000GoobP00_ooN@001?oonf[o4_l0oook
J_l0;Ol6oookJP03o`3mool0ojkooo]Z00Kooo]Z0_oo0:42oookJP05oolX0?oonf[ooo]Zoh<0ool0
=ol00ooonfX00ol02?oooo]Zoom30002oookJP03ool00?oonf[ooo]Z00Gooo]Z00Oo0?ncoookJ_oo
nf[ooo]Zo`3Eoooo02_o0?nf00Wooo]Z00?o`03ooookJ_oo:0000ooo:002ool000?oobP000?oo`00
oookJ_oonfX01OoonfX00ol:o`3ooo]Zoomk0003oookJPSoo`000_ooN@000ooonf[oYOl0oookJP0:
oookJPGoo`000ooo:0001?l0TOooobP0oolX0?oo:003ool000Gooo]Z00Goo`00ogh0oooonf[ooo]Z
ool:0009oookJP03ool00?ood`3ooo]Z013ooo]Z1?l000000ooonf[o0?mloookJP05oookJPGoogT0
0_oonfX00ol06_oooo]ZoolX0008oolX0003ool00?l0o`3ooo]Z00Oooo]Z0ooo00000oooc@3oobP0
oolX0002oolX00Koo`001?oo:002oookJPOoo`003_oo:00=oookJPooo`001_oonfX3oioo00koobP0
8OoonfX;oomi0003oookJ_oo:03oobP000[oobP00ol0ohLCoookJP?oomH0C_oonfX00oooR@3ooo]Z
oookJP0>oookJP03o`3omooonf[ooo]Z00?ooo]Z00Go/ol0oookJ_l0okOok`3oool0cP07oookJP;o
0>Go00?ooo]Zo`3ohOoonfX00ooonfX2ool/0005oookJ_lBo`3ooo]ZoookJ_l0;Ol01_oonfX00ol0
oOoo0?n^oookJP05oookJP;oo`2Q0_oonfX01_ooX03ooo]ZoookJ_n30?oooo]Zo`0go`;ooo]Z00?o
00SooookJ_oo@`000ooonfX00ol0l_oooo]ZoookJP04oookJP08o`3o/ooonf[ooo]ZoookJ_l0eOoo
o`0[oookJ_l0okH9oookJP03ol00oooonf[ooo]Z00;ooo]Z00?oo`2SoookJ_oonfX00_oonfX00ooo
08Gooo]ZoookJP05oookJP04o`[o0?oonf[ooo]Zoomk00Kooo]Z00?ooh`0oookJ_oonfX01?oonfX0
0ol0obCoYOl0oookJP0;oookJP03ool0>ooonf[ooo]Z00;ooo]Z00?o0?mjo`2AoooonfX00_oonfX0
0ooo0<kooo]ZoookJP06oookJP04o`2<oomn0?oooo]Zool:00_ooo]Z00?oom<0oookJ_oonfX03_oo
nfX4o`000003oookJ_l0ogcooo]Z00Oooo]Z00?o00;ooookJ_oonfX00ooonfX00ol06_oooo]Zoook
JP02oookJP03oonL0?oonf[ooo]Z00?ooo]Z00?o0?l0oookJ_oonfX02OoonfX00ooo0;[oold0oook
JP02oookJP03oiD0oooonf[ooo]Z00Gooo]Z00?o0?oCoookJ_oonfX04OoonfX3o`Oo01Cooo]Z1_nO
o`0:oookJPgoWol09_oonfX3o`Oo01;ooo]Z0_l02ol3o`3oQaCooo]Z0oooeP0ToookJP00:ooonfX0
0oooR@3ooo]ZoookJP0<oookJPKoogT02_oo:0000ooonf[oobP0oolX0002oolX0004o`3Uoooo:03o
obP0oomi00?oobP000Oooo]Zoomi0?oonf[ooo]Zoa;o0?oonf[o02go00Kooo]Z00?o0?goo`3o[_oo
nfX01_oonfX01Ooo0:7ooo]ZoookJ_oonf[oobP000;ooo]Z00?oP`3oo`0goooonfX00_oonfX00ol0
2?oooo]Zoom30002oookJP03ool00?oonf[ooo]Z00Gooo]Z00Oo0?ncoookJ_oonf[ooo]Zo`3Eoooo
:03o0?nf00Wooo]Z00?o`03ooookJ_oonfX00ooo:004ool00003oookJ_oo003ooo]Z00Kooo]Z00?o
2_l0oookJ_ooN`001?oonfX7ool000?oogT000?oYOl0oookJ_oonfX02_oonfX3ool00003oookJ_oo
:03oobP000;ooo]Z00?o097ooolX0?oo:0000ooo0005oookJP05ool00?oonf[oOP3ooookJ_oo2P00
2_oonfX01?oo003oom<0ool00?oo000?oookJPCo000000?ooo]Zo`3oO?oonfX01OoonfX2oomi00?o
o`000_oonfX00ol06_oooo]ZoolX0008oolX0003ool00?l0o`3ooo]Z00?ooo]Z1ooo00001?oo0;[o
old0oolX0?oo:008ool00004oookJ_oo:03oobP0oookJPSoo`003ooo:00<oookJQ3oo`001OnOo`04
oookJP[oobP07ooonfX3o`Oo00;oogT00_oonfX7oomi00coobP00ol0ohL00ooo:03ooo]ZoookJP0@
oookJP?oomH0D?oonfX00oooR@3ooo]ZoookJP0>oookJP03o`3omooonf[ooo]Z00?ooo]Z00Go/ol0
oookJ_l0okOok`3oool0cP06oookJP05o`0Gool0iOoooo]ZoookJ_l0on401?oonfX01?oo;03ooo]Z
oookJ_lBo`02oookJP03o`0]oooonf[ooo]Z00Cooo]Z00?o0?goo`3o[_oonfX01OoonfX01Ooo0:7o
oo]ZoookJ_oonf[ooj0000;ooo]Z00?oP`3ooookJ_l0=ol00_oonfX00ol02?oooo]Zoom30003oook
JP03o`3boooonf[ooo]Z00Cooo]Z00So0?ncoookJ_oonf[ooo]Zo`3Eoooo02_ooo]Zo`3o]PWooo]Z
00?o`03ooookJ_oonfX00_oonfX00ooo0:?ooo]ZoookJP02oookJP03ool0QOoonf[ooo]Z00Gooo]Z
00Co2_l0oookJ_oonf[oog/01_oonfX00oooS03ooo]ZoookJP04oookJP03o`3o9?nUo`3ooo]Z00_o
oo]Z00?oo`0koookJ_oonfX00_oonfX00ol0og[ooo]Zo`2Ao`02oookJP03ool0c_oonf[ooo]Z00Ko
oo]Z00Co08coogh0oooonf[oo`X02ooonfX00oood`3ooo]ZoookJP0?oookJPCo000000?ooo]Zo`3o
O?oonfX01ooonfX00ol00_oooo]ZoookJP02oookJP03o`0Joooonf[ooo]Z00?ooo]Z00?ooi`0oook
J_oonfX00ooonfX00ol0o`3ooo]ZoookJP09oookJP03ool0^_ooc@3ooo]Z00;ooo]Z00?oU@3ooook
J_oonfX01_oonfX00ol0om?ooo]ZoookJP0CoookJP?o1ol05ooonfX:oioo02kooo]Z1Ol7o`0Aoook
JP?o00_o0ol0ohLDoookJP?oomH09ooonfX002[ooo]Z00?oohT0oookJ_oonfX03?oonfX6oomi00Wo
obP00_oonfX4oolX0006o`3Uoooo:03oobP0oolX0?ooN@3oobP00_oonfX01_ooN@3ooo]Zoa;o0?lB
o`3ooo]Zo`0]o`Kooo]Z00?o0?goo`3o[_oonfX01?oonfX00ooo:03ooo]Zool0X@03oookJP05oolX
0?oonf[ooo]Zoh<0ool0=ol00ooonfX00ol02?oooo]Zoom30002oookJP03ool00?oonf[ooo]Z00Go
oo]Z00Oo0?ncoookJ_oonf[ooo]Zo`3Eoooo:03o0?nf00Wooo]Z00?o`03ooookJ_oonfX01?oo:005
ool000Oooo]Z00Co2_l0oookJ_oonf[oog/00ooonfX6ool000CoogT000?oYOl0oomi0?ooN@002_oo
nfX3ool000;ooo]Z00KoobP0oookJ_oonf[o097oool00?oo:003ool000Kooo]Z00Go08coogh0oooo
nf[ooo]Zool:000:oookJP03oooC0?oo003oo`0000;oo`003_oonfX4o`000003oookJ_l0ogcooo]Z
00Gooo]Z0_ooN@07ool00003oookJ_oo:03oobP000GoobP00_oo00000ol0o`3ooo]ZoookJP09ool0
0003oookJ_ooc@3ooo]Z00Woo`000_oonfX2oolX00?ooo]Z2_oo0003oookJPSoobP00_l7o`09oook
JPgoo`003?oonfX7oolX01gooo]Z1Ol7o`07oookJPGoogT03Ooo:0001?l0ohOoobP0oolX0?oo:00@
oookJP?oomH0D_oonfX00oooR@3ooo]ZoookJP0=oookJP;o0?og1?oonfX2ok?o0003oookJ_l0okOo
k`3o00Oooo]Z00Go01Ooo`3Uoooonf[ooo]Zo`3oh@04oookJP04ool/0?oonf[o4_l0oa;o00;ooo]Z
00?o02gooookJ_oonfX01?oonfX00ol0oOoo0?n^oookJP05oookJP05ool0XOoonf[ooo]ZoookJ_oo
X0000_oonfX00on30?oooo]Zo`0go`02oookJP03o`08oooonf[ood<000?ooo]Z00?o0?;ooookJ_oo
nfX01?oonfX02?l0ok?ooo]ZoookJ_oonf[o0=Goool0:ooonf[o0?nf2OoonfX00oo00?oooo]Zoook
JP02oookJP03ool0Xooonf[ooo]Z00;ooo]Z00?oo`25oookJ_oonfX01OoonfX01Ol:o`3ooo]Zoook
J_oonf[oog/000Gooo]Z00?ooh`0oookJ_oonfX01?oonfX00ol0obCoYOl0oookJP0<oookJP07ool0
>ooonf[ooo]ZoookJ_l0og[ooo]Zo`2Ao`02oookJP03ool0c_oonf[ooo]Z00Oooo]Z00Co08coogh0
oooonf[oo`X02ooonfX00oood`3ooo]ZoookJP0?oookJPCo000000?ooo]Zo`3oO?oonfX01ooonfX0
0ol00_oooo]ZoookJP02oookJP03o`0Joooonf[ooo]Z00?ooo]Z00?ooi`0oookJ_oonfX00ooonfX0
0ol0o`3ooo]ZoookJP0:oookJP03ooo=0?oonf[ooo]Z00;ooo]Z00?oU@3ooookJ_oonfX01_oonfX0
0ol0om?ooo]ZoookJP07oookJP;oomH03?oonfX4o`Oo04Gooo]Z1_l7o`0BoookJP?o00_o1?l0ohLC
oookJPCoomH0:_oonfX002[ooo]Z00?oohT0oookJ_oonfX03?oonfX4oomi0003oookJ_oo:03oobP0
00SoobP000Cooo]ZoolX0?oo:03oobP00_l0iOl3oolX00?oogT000Cooo]Zoomi0?oonf[o4_l00_oo
nfX00ol0;Ooooo]ZoookJP04oookJP03o`3mool0ojkooo]Z00Gooo]Z00?oobP0ool0XOoonfX00_oo
nfX01Ooo:03ooo]ZoookJ_n30?oo03Oo00?ooo]Z00?o00Soool00?oo@`000_oonfX00ooo003ooo]Z
oookJP05oookJP07o`3o/ooonf[ooo]ZoookJ_l0eOooobP0o`3o]P09oookJP04ol00oooonf[ooo]Z
oookJP?oobP01ooo0005oookJP04o`[o0?oonf[ooo]Zoomk00Cooo]Z1Ooo00001Ooonf[oogT0oomi
0?ooN@3oYOl000CoogT02OoonfX2ool000;ooo]Z00KoobP0oookJ_oonf[o097ooookJ_oo:002ool0
00Oooo]Z00Go08coogh0oooonf[ooo]Zool:000:oookJP03oooC0?oo003oo`0000Goo`003?oonfX4
o`000003o`3oO?oonf[ooo]Z00Gooo]Z0_ooN@09ool000KoobP00_oo00000ol0o`3ooo]ZoookJP09
ool000;ooo]Z00?oold0oookJ_oo:0002?oo0003oookJP03oolX0?oonf[ooo]Z00Cooo]Z1ooo0002
oookJP?oobP01ooonfX4o`Oo00Gooo]Z2?oo000AoookJPCoobP06ooonfX5o`Oo00gooo]Z0oooN@0@
oolX00kooo]Z1?ooeP1DoookJP03oon90?oonf[ooo]Z00gooo]Z00?o0?ogoookJ_oonfX00ooonfX0
1Onco`3o00Soo`3o]ol0okOoo`3>00Oooo]Z00Go01Ooo`3Uoooonf[ooo]Zo`3oh@04oookJP03ool/
0?oonf[o4_l000?ooo]Z00?o02gooookJ_oonfX01?oonfX00ol0oOoo0?n^oookJP05oookJP05ool0
XOoonf[ooo]ZoookJ_ooX0000_oonfX00on30?oooo]Zo`0go`02oookJP03o`08oooonf[ood<000?o
oo]Z00?o0?;ooookJ_oonfX01?oonfX02?l0ok?ooo]ZoookJ_oonf[o0=Goool0:ooonf[o0?nf2Ooo
nfX00oo00?oooo]ZoookJP02oookJP03ool0Xooonf[ooo]Z00;ooo]Z00?oo`25oookJ_oonfX01Ooo
nfX01Ol:o`3ooo]ZoookJ_oonf[oog/000Gooo]Z00?ooh`0oookJ_oonfX01?oonfX00ol0obCoYOl0
oookJP0<oookJP07ool0>ooonf[ooo]ZoookJ_l0og[ooo]Zo`2Ao`02oookJP03ool0c_l0on;ooo]Z
00Oooo]Z00Co08coogh0oooonf[oo`X02ooonfX00oood`3ooo]ZoookJP0@oookJPCo000000?o0?ml
oookJ_oonfX01ooonfX00ol00_oooo]ZoookJP02oookJP03o`0Joooonf[ooo]Z00?ooo]Z00?ooi`0
oookJ_oonfX00ooonfX00ol0o`3ooo]ZoookJP0;oookJP03ooo=0?oonf[ooo]Z00;ooo]Z00?oU@3o
oookJ_oonfX01_oonfX00ol0om?ooo]ZoookJP08oookJP;oomH03_oonfX4o`Oo03cooo]Z1Ol7o`0D
oookJP;o00_o1Ol0ohLDoookJP?oomH0;_oonfX003Sooo]Z0oooN@03oookJPSoobP00ooonfX2oolX
0003o`3Uoooo:03oobP000;oobP01OooN@001Ooonf[o4_l0oookJ_oonf[o02go00Kooo]Z00?o0?go
o`3o[_oonfX01OoonfX3oolX00;ooo]Z00GoobP0oookJ_oonf[oP`3oo`0go`03oookJP06o`08oooo
nf[oo`00ool00?oonf[oo`001ooonfX01ol0ok?ooo]ZoookJ_oonf[o0=GooolX0?l0okH02OoonfX0
1?o00?oooo]ZoookJ_oonfX3oolX00Woo`000ooonfX01?l:o`3ooo]ZoookJ_ooN`02oookJP03ool0
0?oonf[oo`0000?oo`000_oonfX3oomi0004ojGo0?ooN@3oogT0oomi00_ooo]Z00_oo`00oookJ_oo
nf[ooo]Zo`3oN_oonf[o097ooookJ_oo003oo`3>ool00008oookJP04o`2<oomn0?oooo]Zool:00_o
oo]Z00?oom<0ool00?oo00001_oo000;oookJPCo000000?o0?mloookJ_oonfX01OoonfX2oomi00Wo
o`001_oo:002ool00004o`3o0?oonf[ooo]ZoookJPSoo`000_oonfX01?ooc@3ooo]ZoookJ_oo:007
ool000?ooo]Z00?o0?oCoookJ_oonfX01ooonfX5ool000KoobP02OoonfX4o`Oo0004oookJ_oo003o
o`00ool001Kooo]Z00?oobP0oookJ_oonfX05_oonfX6o`Oo01;ooo]Z00?oogT0oolX0?oo:0003_oo
:00=oookJP?oomH0IooonfX00ol0ooOooo]ZoookJP03oookJP05ok?o0?l02?oo0?ngonl0oooo0<h0
1ooonfX01Ol05ooo0>GooookJ_oonf[o0?oQ00Cooo]Z00?oob`0oookJ_lBo`000_oonfX2o`0]o`Ko
oo]Z00?o0?gooookJ_oonfX01OoonfX01Ooo0:7ooo]ZoookJ_oonf[ooj0000;ooo]Z00?oP`3ooook
J_l0=ol00_oonfX00ol02?oooo]Zoom30003oookJP03o`3boooonf[ooo]Z00Cooo]Z00So0?ncoook
J_oonf[ooo]Zo`3Eoooo02_ooo]Zo`3o]PWooo]Z00?o`03ooookJ_oonfX00_oonfX00ooo0:?ooo]Z
oookJP02oookJP03ool0QOoonf[ooo]Z00Gooo]Z00Oo2_l0oookJ_oonf[ooo]Zoomk0?oonf[oaOl0
00?ooo]Z00?ooh`0oookJ_oonfX01?oonfX00ol0obCoYOl0oookJP0<oookJP03ool0>ooonf[ooo]Z
00;ooo]Z00?o0?mjoookJ_l0TOl00_oonfX00ooo0<kooo]ZoookJP06oookJP05o`2<oooonf[oOP3o
oookJ_oo2P002ooonfX00oood`3ooo]ZoookJP0@oookJPCo000000?o0?mloookJ_oonfX01_oonfX0
0ol00_oooo]ZoookJP03oookJP03o`0Joooonf[ooo]Z00?ooo]Z00?ooi`0oookJ_oonfX00_oonfX0
0oooIP3o0?l0oookJP0<oookJP03ooo=0?oonf[ooo]Z00?ooo]Z00?oU@3ooookJ_oonfX01OoonfX0
0ol0om?ooo]ZoookJP0:oookJP;oomH04?oonfX4o`Oo03;ooo]Z1_l7o`0EoookJP;o00_o1?l0ohLE
oookJPCoomH0<OoonfX003Oooo]Z0_ooN@04oookJPOoobP01?oonfX2oolX0003o`3Uoooo:03o0?oQ
00?oobP01OooN@001?lBo`3ooo]ZoookJ_l0;Ol6oookJP03o`3mool0ojkooo]Z00Gooo]Z1_oo:002
oookJP03oh<0ool0=ooooo]Z00;ooo]Z00?o00SooookJ_oo00000ooo0007oookJP07o`3o/ooonf[o
oo]ZoookJ_l0eOooobP0o`3o]P09oookJP03ol00oooonf[ooo]Z00;ooo]Z0ooo:007ool000Cooo]Z
00Co2_l0oookJ_oonf[oog/00ooonfX00ooo003ooo]Zool00002ool000?ooo]Z0oooN@000onUo`3o
ogT0oomi000;oookJP05ool00?oonf[ooo]ZoookJ_l0ogX00_oonfX01?l0TOoooo]Zool0c_oo0008
oookJP04o`2<oomn0?oooo]Zool:00_ooo]Z00?oom<0ool00?oo00001_oo000<oookJPCo000000?o
0?mloookJ_oonfX01OoonfX2oomi00Soo`001ooo:002ool00003o`3o0?oonf[ooo]Z00;ooo]Z1ooo
0003oookJP05ooo=0?oonf[ooo]ZoookJ_oo:0001_oo0003oookJP03o`3odooonf[ooo]Z00[ooo]Z
00?oo`00oolX0?oo:0001Ooo:00<oookJPGo1ol09ooonfX7o`Oo01Kooo]Z00?o00_ooolX0?oo:000
3_oo:00<oookJP?oomH0JOoonfX00ol0ooOooo]ZoookJP03oookJP05ok?o0?oonf[o0?ngonl0oooo
0<h01ooonfX00ol05ooo0>GooookJP02o`3oh@Cooo]Z00?oob`0oookJ_lBo`000_oonfX00ol0;Ooo
oo]ZoookJP05oookJP03o`3moooonf[ooo]Z00Gooo]Z00?oo`2QoookJ_oonfX00_ooX002oookJP03
oh<0ool0=ooo03Oo00;ooo]Z00?o00SooookJ_oo@`000ooonfX00ol0l_oooo]ZoookJP04oookJP08
o`3o/ooonf[ooo]ZoookJ_l0eOooo`0[oookJ_l0okH9oookJP03ol00oooonf[ooo]Z00;ooo]Z00?o
o`2SoookJ_oonfX00_oonfX00ooo08Gooo]ZoookJP05oookJP05o`[o0?oonf[ooo]ZoookJ_ooN`00
0_oonfX01?o5o`3ooo]ZoookJ_ooS006oookJP03o`3o9?nUo`3ooo]Z00cooo]Z00?oo`0koookJ_oo
nfX00_oonfX00ol0og[ooo]Zo`2Ao`02oookJP03ool0c_oonf[ooo]Z00Oooo]Z00Co08coogh0oooo
nf[oo`X02ooonfX01?ood`3ooo]ZoookJ_l0oiT@oookJPCo000000?o0?mloookJ_oonfX01_oonfX0
0ol00_oooo]ZoookJP03oookJP03o`0Joooonf[ooo]Z00?ooo]Z00?ooi`0oookJ_oonfX00_oonfX0
0oooIP3ooo]Zo`3o000=oookJP03ooo=0?oonf[ooo]Z00;ooo]Z00?oU@3ooookJ_oonfX01_oonfX0
0ol0om?ooo]ZoookJP0;oookJP;oomH04_oonfX4o`Oo02Oooo]Z1ol7o`0GoookJP03o`0;ool0ohOo
0?n700?o0?n75_oonfX3oooF03Gooo]Z000eoookJP03o`3omoooN@3ooo]Z00Cooo]Z0ooo:0000ol0
okOoobP0oolX0005oookJP;oobP000?o0>GooolX0?l0on400ooo:005oomi0004oa;o0?ooN@3oogT0
o`0]o`Kooo]Z00?o0?goo`3o[_oonfX01_oonfX6oolX0003oookJ_n30?oo03Oo00?ooo]Z00?o00So
oookJ_oo00001Ooo0004oookJP03o`3o/ooo:03ooo]Z00;ooo]Z00?o0=GooolX0?l0okH02OoonfX0
0oo00?oooo]ZoookJP02oookJP?oobP01ooo0004oookJP04o`[o0?oo003ooo]Zoomk00?ooo]Z00?o
o`00oookJ_oo00000_oo0003oookJP?oogT000?oYOl0oomi0?ooN@003?oonfX01?oo03_ooo]Zoook
J_l0ogX2oookJP04o`2Aoooonf[oo`3>ool000Sooo]Z00Go08cooookJ_mn0?oooo]Zool:0003oook
JP;oo`001_oonfX00oood`3oo`00ool00005ool000gooo]Z0ol000000ol0ogcooo]ZoookJP06oook
JP;oogT02?oo00000ooonf[oobP0oolX0003oolX00?oo`0000?o0?l0oookJ_oonfX00_oonfX7ool0
00?ooo]Z00?oold0oookJ_oonfX00_oonfX00ooo:03oo`00ool00003ool000Cooo]Z00?o0?oCoook
J_oonfX02OoonfX:oolX00oooo]Z1ol7o`0FoookJP[o1ol00ooonfX5ool0017ooo]Z0ol0ohL2oolX
00;ooo]Z2?oo:0000ooonf[oogT0oolX0002oolX00coogT000?oomH0oookJ_oonfX0J?oonfX2o`3o
m`Gooo]Z00Go/ol0oookJ_l0okOok`3oool0cP07oookJP04o`0Gool0iOoooo]Zo`3oh@Gooo]Z00?o
ob`0oookJ_lBo`000_oonfX00ol0;Ooooo]ZoookJP05oookJP03o`3moooonf[ooo]Z00Gooo]Z00Co
o`2QoookJ_oonf[ooj000ooonfX00on30?oo03OooookJP02oookJP03o`08oooonf[ood<000?ooo]Z
00?o0?;ooookJ_oonfX00ooonfX2o`3o/`?ooo]Z00Co0=Goool0:ooonf[o0?nf2OoonfX00oo00?oo
oo]ZoookJP02oookJP03ool0Xooonf[ooo]Z00;ooo]Z00?oo`25oookJ_oonfX01OoonfX01Ol:o`3o
oo]ZoookJ_oonf[oog/000;ooo]Z00CoaOl0oookJ_oonf[ooh`01ooonfX00onUo`3ooo]ZoookJP0<
oookJP07ool0>ooonf[ooo]ZoookJ_l0og[ooo]Zo`2Ao`02oookJP03ool0c_oonf[ooo]Z00Oooo]Z
00Co08coogh0oooonf[oo`X03?oonfX01?ood`3ooo]ZoookJ_l0oiT@oookJP?o000000?o0?mloook
J_oonfX01ooonfX00ol00_oooo]ZoookJP03oookJP03o`0Joooonf[ooo]Z00?ooo]Z00?ooi`0oook
J_oonfX00_oonfX00oooIP3ooo]Zo`3o000=oookJP03ooo=0?oonf[ooo]Z00?ooo]Z00CoU@3ooook
J_oonf[oog<01OoonfX00ol0om?ooo]ZoookJP0<oookJP?oomH04ooonfX7o`Oo01Kooo]Z2_l7o`0I
oookJP03o`0;ool0ohOo0?n700?o0?n75ooonfX4oooF03Sooo]Z000doookJP03o`3omooonf[ooo]Z
00?ooo]Z00Ko/ol0oolX0?oo:03oobP0o`3o]ooo:006oookJP;oobP000?o0>GooolX0?l0on400ooo
:005oomi0005oa;o0?ooN@3o02goo`0]ooooN@001OoonfX00ol0oOoooo]ZoookJP05oookJP03ool0
XOoo:03oobP000KoobP000?o03OooookJ_oonfX00_l02?l00oooN@3ood<0ool00006ool000;ooo]Z
00So0?ncoookJ_oo:03oobP0oookJ_l0eOooobP0o`3o]PWooo]Z00?o`03ooookJ_oonfX00_oonfX3
oolX0003oookJ_oo003oo`0000?oo`001OoonfX01?l:o`3ooo]Zool00?oo0003oookJP04ool00?oo
nf[ooo]Zool000Gooo]Z0_ooN@000onUo`3oogT0oookJP0<oookJP04ool0>ooonf[ooo]Zo`3oNP;o
oo]Z00Co097ooookJ_oonf[oo`3>2OoonfX01?l0S?ooOP3ooookJ_oo2P04oookJPCoo`000ooonfX0
0oood`3oo`00ool00005ool000kooo]Z0ol000000ol0ogcooo]ZoookJP06oookJP03oomi0?oonf[o
o`0000Ooo`0000?ooo]ZoolX0?oo:0000ooo:0001?oonf[oo`00ool00?l0o`05oookJPKoo`000ooo
nfX00oooc@3oo`2joookJP03oookJP;oobP01?oo00001Ooonf[oobP0oolX0?oonf[o0?oC00[ooo]Z
2ooo:00EoookJQKo1ol01_oonfX5ool000;ooo]Z3?oo0005oookJPGo0?n71ooonfX6oolX00?ooo]Z
00?oogT0oolX0?ooN@002oooN@1/oookJP03o`3omooonf[ooo]Z00?ooo]Z0_nco`001?oonf[o0?ng
onl0oooo0<h7oookJP;o0>Go00?ooo]Zo`3ohOoonfX00ooonfX2ool/0005oookJ_lBo`3ooo]Zoook
J_l0;Ol01ooonfX00ol0oOoooo]ZoookJP05oookJP04ool0XOoonf[ooo]ZoonP00;ooo]Z0_n30?l0
1ol0=ooooo]ZoookJ_oonf[o00Soooo90?oo@`000ooonfX00ol0l_oooo]ZoookJP03oookJP03o`3o
/ooonf[ooo]Z00;ooo]Z00Co0=Goool0:ooonf[o0?nf2OoonfX00oo00?oooo]ZoookJP02oookJP03
ool0Xooonf[ooo]Z00;ooo]Z00?oo`25oookJ_oonfX01OoonfX01Ol:o`3ooo]ZoookJ_oonf[oog/0
00;ooo]Z00CoaOl0oookJ_oonf[ooh`01ooonfX00onUo`3ooo]ZoookJP0<oookJP07ool0>ooonf[o
oo]ZoookJ_l0og[ooo]Zo`2Ao`02oookJP03ool0c_oonf[ooo]Z00Oooo]Z00Go08cooookJ_mn0?oo
oo]Zool:000;oookJP04oooC0?oonf[ooo]Zo`3oVA7ooo]Z0ol000000ol0ogcooo]ZoookJP07oook
JP03o`02oooonf[ooo]Z00?ooo]Z00?o01[ooookJ_oonfX00ooonfX00oooW03ooo]ZoookJP02oook
JP03oomV0?oonf[o0?l000kooo]Z00?oold0oookJ_oonfX00ooonfX00onE0?oooo]Zoomc0006oook
JP03o`3odooonf[ooo]Z00kooo]Z0_ooeP0HoookJQKo1ol07_oonfX6o`3oQaSooo]Z1?ooeP0loook
JP00<ooonfX00ol0ooOooo]ZoookJP03oookJP06ok?o0?oonf[oobP0oolX0?l0okOok`3o1ooonfX0
1?l05ooo0>GooolX0?l0on43oolX00GoogT000Co4_l0oomi0?l0;OooogT01_oonfX00ol0oOoooo]Z
oookJP05oookJP03ool0XOoonf[oobP000SoobP000Gooo]Zo`08oooonf[oogT0oom30009ool00003
o`3o/ooonf[oobP000CoobP000?o0?nfoookJ_oonfX01ooonfX00oo00?oooo]ZoookJP03oookJP03
oolX0?oonf[ooo]Z00Goo`001OoonfX00ol:o`3ooo]Zool00003ool00005oookJ_oo003ooo]Zoook
J_oo00001OoonfX2oomi0003ojGo0?ooN@3ooo]Z00cooo]Z00Ooo`0koookJ_oonf[ooo]Zo`3oN_oo
nf[o097o00;ooo]Z00?oo`3>o`3oh_oonfX01ooonfX01?l0S?ooOP3ooookJ_oo2P05oookJPGoo`00
0_oonfX00oood`3oo`00ool00004ool000oooo]Z0ol000000ol0ogcooo]ZoookJP06oookJP03o`02
oooonf[oo`0000Koo`000_oonfX5oolX0004oookJ_oo003oo`00o`3o00Kooo]Z1_oo0003oookJP03
ooo=0?oonf[ooo]Z00?ooo]Z00?oobP0oookJ_oo00000_oo0003oolX00;ooo]Z0_l0om<8oookJPco
obP0<?oonfXCool000Go0?n73OoonfX3oolX00Gooo]Z3?ooN@1]oookJP03o`3omooonf[ooo]Z00?o
oo]Z00Go/ol0o`08oooonf[o0?ngonl0o`07oookJP05o`0Gool0iOoooo]ZoookJ_l0on401?oonfX0
1?oo;03ooo]ZoookJ_lBo`02oookJP03o`0]oooonf[ooo]Z00Gooo]Z00?o0?gooookJ_oonfX01Ooo
nfX01?oo0:7ooo]ZoookJ_ooX002oookJP03oh<0oooonf[o03Oo00?ooo]Z00?o00Soooo90?oo@`00
0ooonfX00ol0l_oooo]ZoookJP03oookJP03o`3o/ooonf[ooo]Z00;ooo]Z00Co0=Goool0:ooonf[o
0?nf2OoonfX00oo00?oooo]ZoookJP02oookJP03ool0Xooonf[ooo]Z00;ooo]Z00?oo`25oookJ_oo
nfX01OoonfX01Ol:o`3ooo]ZoookJ_oonf[oog/000;ooo]Z00CoaOl0oookJ_oonf[ooh`01ooonfX0
0onUo`3ooo]ZoookJP0<oookJP03ool0>ooonf[ooo]Z00;ooo]Z00?o0?mjoookJ_l0TOl00_oonfX0
0ooo0<kooo]ZoookJP07oookJP04o`2<oomn0?oooo]Zool:00cooo]Z00Coom<0oookJ_oonf[o0?nI
4OoonfX3o`000003o`3oO?oonf[ooo]Z00Oooo]Z00?o00;ooookJ_oonfX00_oonfX00ol06_oooo]Z
oookJP04oookJP03oonL0?oonf[ooo]Z00;ooo]Z00?oofH0oookJ_l0o`003_oonfX00oooc@3oo`2j
oookJP03oookJP04oiD0oooonf[ooo]Zoomc00Kooo]Z0_l0om<@oookJP;oomH0AOoonfX5o`3oQ`03
o`0;oooonf[ooo]Z01Oooo]Z1?ooeP10oookJP00<_oonfX00ol0ooOooo]ZoookJP03oookJP06ok?o
0?oonf[oobP0oolX0?l0okOok`3o1ooonfX2o`3Uo`04oolX0?l0on7oobP0oolX00;ooo]Z0oooN@02
oa;o0003oomi0?l0;Ooooo]Z00Gooo]Z0_l0oOl7oookJP03ool0XOoonf[oobP000OoobP00_oonfX0
1?l02?oooo]Zoomi0?oo@`08ool00003oookJ_l0ok?ooo]Z00KoobP02OoonfX00oo00?oooo]Zoook
JP03oookJP04oolX0?oonf[ooo]ZoookJP?oo`001_oonfX00ol:o`3ooo]ZoookJP05ool000?ooo]Z
00?ooh`0oookJ_oonfX00ooonfX00oooN@3oYOl0oomi000=oookJP07ool0>ooonf[ooo]ZoookJ_l0
og[ooo]Zo`2Ao`02oookJP03ool0c_l0on;ooo]Z00Sooo]Z00Co08coogh0oooonf[oo`X01?oonfX7
ool00003oooC0?oonf[oo`0000Coo`004?oonfX2o`000003o`3oO?l0003ooo]Z00Oooo]Z00?o00;o
oookJ_oo00001_oo0003oookJP?oobP00_oonfX2ool00003o`3o0?oonf[ooo]Z00Gooo]Z1Ooo0003
oookJP03ooo=0?oonf[ooo]Z00Cooo]Z00?oobP0oookJ_oo00001Ooo:003oookJP03o`3odooonf[o
oo]Z00Cooo]Z3ooo:00^oookJQ7oo`000_l0ohL2ool0013ooo]Z00?oobP0oookJ_oonfX01OoonfX:
oomi06kooo]Z00?o0?ogoookJ_oonfX00ooonfX01Onco`3o00SooookJ_l0okOok`3o00Oooo]Z00Go
01Ooo`3Uoooonf[ooo]Zo`3oh@04oookJP04ool/0?oonf[o4_l0oa;o00;ooo]Z00?o02gooookJ_oo
nfX01?oonfX2o`3mo`Oooo]Z00Coo`2QoookJ_oonf[ooj000_oonfX00on30?oooo]Zo`0go`03oook
JP03o`08oooob@3ood<000?ooo]Z00?o0?;ooookJ_oonfX00ooonfX00ol0ok?ooo]ZoookJP02oook
JP04o`3Eoooo02_o0?nfo`3o]PWooo]Z00?o`03ooookJ_oonfX00_oonfX00ooo0:?ooo]ZoookJP02
oookJP03ool0QOoonf[ooo]Z00Gooo]Z00Go2_l0oookJ_oonf[ooo]Zoomk0002oookJP05olGo0?oo
nf[ooo]ZoookJ_ooS0001_oonfX00onUo`3ooo]ZoookJP0<oookJP03ool0>ooonf[ooo]Z00;ooo]Z
00?o0?mjoookJ_l0TOl00_oonfX00ooo0<kooo]ZoookJP07oookJP05o`2<oomn0?oooo]ZoookJ_oo
2P001ooonfX01Ooo0?cooo]ZoookJ_oonf[oom<000;ooo]Z00?o0?nIoookJ_oonfX04?oonfX2o`00
0003o`3oO?l0003ooo]Z00Sooo]Z00Ko00;ooookJ_oonf[ooo]Zoml0ool06_l6oookJP03oonL0?oo
nf[ooo]Z00;ooo]Z00?oofH0oookJ_l0o`002?oonfX00ooo<@3ooo]ZoookJP04oookJP03ooo=0?oo
nf[ooo]Z00?ooo]Z00CoU@3ooookJ_oonf[oog<01ooonfX00ol0om?ooo]ZoookJP0?oookJP?oomH0
>ooonfX00ol02ooo0?n7o`3oQ`04o`3oQacooo]Z0oooeP14oookJP00<OoonfX00ol0ooOooo]Zoook
JP03oookJP03ok?o0?l02?ooobP000;o0?ng2?oonfX01Ol0iOooobP0oolX0?l0on7oobP000?ooo]Z
0oooN@001?lBo`3oogT0oomi0?l0;Ol6oookJP03o`3mool0ojkooo]Z00Kooo]Z00?oo`2QoookJ_oo
:0001_oo:0001ol0=ooooo]ZoookJ_l02?oooo]Zoomi0?oo@`001ooo0002oookJP03o`3o/ooonf[o
oo]Z00OoobP01ooonfX00oo00?oooo]ZoookJP04oookJP03ool0Xooonf[ooo]Z00?oo`001_oonfX0
0ol:o`3ooo]ZoookJP07ool00003oookJ_ooS03ooo]Z00Cooo]Z00?oogT0ojGo0?oonfX03OoonfX0
1Ooo03_ooo]ZoookJ_oonf[o0?mj00;ooo]Z00Co097ooookJ_oo0<ko0?oR2OoonfX01?l0S?ooOP3o
oookJ_oo2P05oookJPOoo`0000?oom<0ool00?oo00000ooo0005oookJP;oo`002_oonfX2o`000003
o`3oO?l0003ooo]Z00Oooo]Z00?o00;ooookJ_oo00001Ooo0004oookJPOoobP000Co0?l0oolX0?oo
:03oobP01?oonfX5ool000?ooo]Z00?oold0ool0^_oonfX01?oonfX00onE0?oooo]ZoolX0006oolX
00?ooo]Z00?o0?oCoookJ_oonfX02?oonfX;oolX02gooo]Z4_oo000HoookJP_oogT0KooonfX00ol0
ooOooo]ZoookJP03oookJP05ok?o0?l02?oo0?ngo`3o]ooo0<h01ooonfX01Ol05ooo0>GooookJ_oo
nf[o0?oQ00Cooo]Z00?oob`0oookJ_lBo`000ooonfX00ol0;Ooooo]ZoookJP04oookJP03o`3moooo
nf[ooo]Z00Gooo]Z0_oo0:42oookJP06oonP0?oonf[ooo]Zoh<0oooonf[o03Oo0ooonfX00ol02?oo
olT0oom30003oookJP03o`3boooonf[ooo]Z00?ooo]Z00Co0?ncoookJ_oonf[ooo]Z0_l0eOl00ooo
02_o0?nfoookJP09oookJP03ol00oooonf[ooo]Z00?ooo]Z00Goo`2SoookJ_oonf[ooo]Zool0Q@07
oookJP03o`[o0?oonf[ooo]Z00;ooo]Z00?oog/0oookJ_o5o`000ooonfX00oooS03ooo]ZoookJP04
oookJP03ojGo0?oonf[ooo]Z00cooo]Z00?oo`0koookJ_oonfX00_oonfX00ol0og[ooo]Zo`2Ao`02
oookJP03ool0c_oonf[ooo]Z00Oooo]Z00Go08cooookJ_mn0?oooo]Zool:0008oookJP05ool0o?oo
nf[ooo]ZoookJ_ood`000_oonfX00ol0oiWooo]ZoookJP0@oookJP;o000000?o0?mlo`000?oonfX0
1ooonfX00ol00_oooo]ZoookJP02oookJP03oml0ool06_oooo]Z00Gooo]Z00?ooi`0oookJ_oonfX0
0_oonfX00oooIP3ooo]Zo`3o0008oookJP03oola0?oonf[ooo]Z00Cooo]Z00?oold0ool0^_oonfX0
0ooonfX01OnE0?oooo]ZoookJ_oonf[oog<000Oooo]Z00?o0?oCoookJ_oonfX04OoonfX2oooF03?o
oo]Z1ol0ohLNoookJPCoomH0AooonfX0033ooo]Z00?o0?ogoookJ_oonfX00ooonfX01Onco`3o00So
oookJ_l0okOok`3o00Sooo]Z00Co0>GooolX0?oo:03o0?oQ1?oonfX3oomi0004oa;o0?ooN@3ooo]Z
o`0]o`Kooo]Z00?o0?goo`3o[_oonfX01_oonfX00ooo0:7ooo]ZoookJP05oolX0009oookJ_l0=ooo
oo]ZoookJ_l02?oooo]Zoomi0?oo@`3ooo]Z00Koo`000_oonfX00ol0ok?ooo]ZoookJP09oolX00Go
oo]Z00?o`03ooookJ_oonfX01?oonfX00ooo0:?ooo]ZoookJP03ool000Kooo]Z00?o2_l0oookJ_oo
nfX02?oo00000oooS03ooo]ZoookJP04oookJP03oomi0?nUo`3ooo]Z00cooo]Z00Goo`0koookJ_oo
nf[ooo]Zo`3oNP02oookJP04o`2Aoooonf[ooo]Zool0cPWooo]Z00Co08cooookJ_mn0?ooo`X01_oo
nfX6ool00003oooC0?oo003oo`0000?oo`001_oonfX5ool000Oooo]Z0_l000000ol0ogco0000oook
JP07oookJP03o`02oooonf[oo`0000Koo`000ooonfX8oolX0003o`3o0?oo:03oobP000Gooo]Z1?oo
0004oookJP03ooo=0?oonf[ooo]Z00Cooo]Z2?oo:004oookJP03o`3odooonf[ooo]Z00Gooo]Z0_oo
0008oookJPCoobP00_ooeP0[oookJPooo`005OoonfX3oooF00;oogT01?oonfX5oomi06oooo]Z0_l0
ooL5oookJP05ok?o0?oonf[o0?ngonl0oooo0<h01ooonfX00ol05ooo0>GooookJP02o`3oh@Cooo]Z
00?oob`0oookJ_lBo`000_oonfX2o`0]o`Kooo]Z00?o0?gooookJ_oonfX01OoonfX01Ooo0:7ooo]Z
oookJ_oonf[ooj0000;ooo]Z00?oP`3ooookJ_l0=ol00ooonfX00ol02?ooolT0oom30003oookJP03
o`3boooonf[ooo]Z00?ooo]Z00So0?ncoookJ_oonf[ooo]Zo`3Eoooonf[oo`0[o`3o]P[ooo]Z00?o
`03ooookJ_oonfX00ooonfX01Ooo0:?ooo]ZoookJ_oonf[oo`2500Oooo]Z00?o2_l0oookJ_oonfX0
0_oonfX00oooN`3ooo]ZolGo0003oookJP03oon<0?oonf[ooo]Z00Cooo]Z00?o0?lTojGo0?oonfX0
3?oonfX00ooo03_ooo]ZoookJP02oookJP06o`3oN_oonf[ooo]Zo`2Aoooonf[oo`3>2_oonfX01?l0
S?ooOP3ooookJ_oo2P08oookJP05ool0o?oonf[ooo]ZoookJ_ood`000_oonfX00ol0oiWooo]Zoook
JP0AoookJP;o000000?o0?mlo`000?oonfX01ooonfX00ol00_oooo]ZoookJP02oookJP03oml0ool0
6_oooo]Z00Gooo]Z00?ooi`0oookJ_oonfX00_oonfX01?ooIP3ooo]ZoookJ_l0o`08oookJP03oola
0?oonf[ooo]Z00Cooo]Z00?oold0oookJ_oonfX00ooonfX01OnE0?oooo]ZoookJ_oonf[oog<000Oo
oo]Z00?o0?oCoookJ_oonfX04_oonfX3oooF02cooo]Z1?l0ohLPoookJPGoomH0BooonfX002oooo]Z
00?o0?ogoookJ_oonfX00_oonfX01_oo:03o/ol0o`08oooonf[o0?ngonl0o`Sooo]Z00Co0>GooolX
0?oo:03o0?oQ1OoonfX2oomi0004oa;o0?oonf[ooo]Zo`0]o`Kooo]Z00?o0?goo`3o[_oonfX01_oo
nfX00ooo0:7ooo]ZoookJP05oolX0009oookJ_l0=ooooo]ZoookJ_l02?oooo]Zoomi0?oo@`3ooo]Z
00Goo`000ooonfX01?l0ok?ooo]ZoookJ_oonfX7oolX00Kooo]Z00?o`03ooookJ_oonfX01?oonfX0
1Ooo0:?ooo]ZoookJ_oonf[oo`0000Oooo]Z00Co2_l0oookJ_oonf[ooo]Z1ooo00000oooS03ooo]Z
oookJP04oookJP03oomi0?nUo`3ooo]Z00cooo]Z00Goo`0koookJ_oonf[ooo]Zo`3oNP02oookJP05
o`2Aoooonf[ooo]Zool0c_l0on801?oonfX2oolX00?ooo]Z00Co08coogh0oooonf[oo`X01_oonfX5
ool00003oooC0?oo003ooo]Z00?oo`001ooonfX7ool000Gooo]Z00Co0000o`3oO?l0003o00001ooo
nfX00ol00_oooo]ZoookJP0:ool000?oobP01Ooo00000ol0o`3oobP0oolX0006oookJP?oo`001Ooo
nfX00oooc@3ooo]ZoookJP02oookJP[oobP01?oonfX2o`3od`Gooo]Z0ooo000=oookJPCoomH09ooo
nfX=ool0017ooo]Z1_ooeP09oookJP?oogT0L?oonfX00ol0ooOooo]ZoookJP04oookJP05ok?o0?oo
nf[o0?ngonl0oooo0<h01ooonfX01?l05ooo0>GooookJ_l0on45oookJP03ool/0?oonf[o4_l000;o
oo]Z00?o02gooookJ_oonfX01OoonfX00ol0oOoooo]ZoookJP05oookJP05ool0XOoonf[ooo]Zoook
J_ooX0000_oonfX00on30?oooo]Zo`0go`03oookJP03o`08oooob@3ood<000?ooo]Z00?o0?;ooook
J_oonfX00ooonfX02?l0ok?ooo]ZoookJ_oonf[o0=GooookJ_oo02_o0?nf2_oonfX00oo00?oooo]Z
oookJP03oookJP05ool0Xooonf[ooo]ZoookJ_oo08D01ooonfX00ol:o`3ooo]ZoookJP02oookJP03
oomk0?oonf[oaOl000?ooo]Z00?ooh`0oookJ_oonfX01?oonfX00ol0obCoYOl0oookJP0<oookJP03
ool0>ooonf[ooo]Z00;ooo]Z00Oo0?mjoookJ_oonf[o097ooookJ_oo0<ko0?oR00Wooo]Z00Go08co
ogh0oooonf[ooo]Zool:0008oookJP04ool0o?oonf[ooo]ZoooC00?ooo]Z00?o0?nIoookJ_oonfX0
4OoonfX01?l0003o0?mlo`000?l00008oookJP03o`02oooonf[ooo]Z00;ooo]Z00?og`3oo`0Joooo
nfX01OoonfX00oooW03ooo]ZoookJP02oookJP04oomV0?oonf[ooo]Zo`3o00Sooo]Z00?ooc40oook
J_oonfX01OoonfX00oooc@3ooo]ZoookJP03oookJP04oiD0oooonf[ooo]Zoomc00Sooo]Z0_l0om<E
oookJPCoomH0A_oonfX6oooF053ooo]Z000^oookJP03o`3omooonf[ooo]Z00?ooo]Z00Go/ol0o`08
oooonf[o0?ngonl0o`08oookJP04o`3Uoooo:03o0?oQo`3oh@Gooo]Z0_ooN@001?lBo`3ooo]Zoook
J_l0;Ol6oookJP03o`3mool0ojkooo]Z00Gooo]Z0_oo0:43oookJPCoobP000Wooo]Zo`0goooonf[o
oo]Zo`08oooonf[oogT0oom30?oonfX01?oo0004oookJP04o`3o/ooonf[ooo]ZoookJPOoobP01_oo
nfX00oo00?oooo]ZoookJP04oookJP05ool0Xooonf[ooo]ZoookJ_oo00001ooonfX01?oo:03ooo]Z
oookJ_oonfX7ool00003oon<0?oonf[ooo]Z00Gooo]Z00?oYOl0oookJ_oonfX03?oonfX01ooo03_o
oo]ZoookJ_oonf[o0?mjoookJ_l0TOl00_oonfX00ooo0<ko0?oRoookJP04oookJP?oobP000Gooo]Z
oolX0?mn0?oooo]Zool:0006oookJPKoo`0000?oom<0oookJ_oonfX00_oo0007oookJPWoo`001?oo
nfX01?l0003o0?mlo`000?l00007oookJP04o`02oooonf[ooo]ZoookJP[oo`0000?oobP0ool00?oo
00001?oo00000ol0o`3oobP0oookJP06oookJP?oo`000ooo:002oookJP03ooo=0?oonf[ooo]Z00Co
oo]Z2?oo:006oookJP;o0?oC0_oonfX5ool0013ooo]Z1?ooeP0SoookJPGoo`000_oonfX3ool000oo
oo]Z1OooeP0?oookJP03oomi0?oonf[ooo]Z06oooo]Z00?o0?ogoookJ_oonfX01?oonfX01Onco`3o
oo]Zo`3o]oo_0?ooo`3>00Oooo]Z00Co01Ooo`3Uoooonf[o0?oQ1OoonfX00ooo;03ooo]Zoa;o0002
oookJP03o`0]oooonf[ooo]Z00Gooo]Z00?o0?gooookJ_oonfX01OoonfX01Ooo0:7ooo]ZoookJ_oo
nf[ooj0000;ooo]Z00?oP`3ooookJ_l0=ol00ooonfX00ol02?ooolT0oom30003oookJP03o`3boooo
nf[ooo]Z00?ooo]Z00So0?ncoookJ_oonf[ooo]Zo`3Eoooonf[oo`0[o`3o]P[ooo]Z00?o`03ooook
J_oonfX00ooonfX01Ooo0:?ooo]ZoookJ_oonf[oo`2500Oooo]Z00?o2_l0oookJ_oonfX00_oonfX0
1?ooN`3ooo]ZoookJ_o5o`02oookJP03oon<0?oonf[ooo]Z00Gooo]Z00?oYOl0oookJ_oonfX03?oo
nfX00ooo03_ooo]ZoookJP02oookJP03o`3oN_oonf[o097o00;ooo]Z00?oo`3>oookJ_oonfX01ooo
nfX01Ol0S?oooo]Zogh0oooonf[oo`X000Sooo]Z00Goo`3loookJ_oonf[ooo]ZoooC0002oookJP03
o`3oVOoonf[ooo]Z01;ooo]Z00Co0000o`3oO?l0003o00002?oonfX00ol00_oooo]ZoookJP02oook
JP03oml0ool06_oooo]Z00Gooo]Z00?ooi`0oookJ_oonfX00_oonfX01?ooIP3ooo]ZoookJ_l0o`08
oookJP03oola0?oonf[ooo]Z00Gooo]Z00?oold0oookJ_oonfX01?oonfX01?nE0?oooo]ZoookJ_oo
L`09oookJP;o0?oC5ooonfX5oooF03_ooo]Z1_ooeP1FoookJP00;OoonfX00ol0ooOooo]ZoookJP03
oookJP05ok?o0?l02?ooobP0o`3o]oo_0?l01ooonfX2o`3Uo`03oookJ_l0on7ooo]Z00Cooo]Z00Co
ob`0oomi0?oonf[o4_l00_oonfX00ol0;Ooooo]ZoookJP04oookJP03o`3mool0ojkooo]Z00Gooo]Z
00?oo`2QoookJ_oonfX00_oonfX2oolX0004oookJ_oo:03ooo]Zo`0go`;ooo]Z00Co00SooookJ_oo
N@3ood<00_oonfX2ool000Gooo]Z00Co0?ncoookJ_oonf[ooo]Z1_oo:007oookJP03ol00oooonf[o
oo]Z00Cooo]Z00?oo`2SoookJ_oonfX00_oonfX00ooo08Gooo]ZoookJP05oookJP04oolX0?oonf[o
oo]Zoomk00Goo`0000?ooo]Zoon<0?oonfX01_oonfX00onUo`3ooo]ZoookJP0<oookJP05ool0>ooo
nf[ooo]ZoookJ_l0ogX00_oonfX01?l0TOoooo]ZoookJ_oo0<h5oookJPKoobP000?oOP3ooookJ_oo
2P001_oonfX5ool00003oooC0?oonf[ooo]Z00;oo`002?oonfX9ool000Cooo]Z00Co0?mlo`000?l0
003o00001ooonfX01?l00_oooo]ZoookJ_oonfX:ool00003oolX0?oo003oo`0000?oo`0000?oobP0
o`3o0?oo:0001ooonfX6oolX00?ooo]Z00?oold0oookJ_oonfX01OoonfX7oolX00Oooo]Z0_l0om<6
ool001?ooo]Z1OooeP0NoookJP;oo`001OoonfX00ooo003ooo]ZoookJP08oookJPOoomH0=OoonfX2
o`3oGDkooo]Z00?o0?ogoookJ_oonfX01?oonfX01?nco`3ooo]Zo`3o]oo_0?l7oookJP05o`0Gool0
iOoo0>GooookJ_l0on401?oonfX2ool/0005oookJ_lBo`3ooo]ZoookJ_l0;Ol01ooonfX00ol0oOoo
oo]ZoookJP05oookJP05ool0XOoonf[ooo]ZoookJ_ooX0000_oonfX00on30?oooo]Zo`0go`03oook
JP03o`08oooob@3ood<000?ooo]Z00?o0?;ooookJ_oonfX00ooonfX02?l0ok?ooo]ZoookJ_oonf[o
0=GooookJ_oo02_o0?nf2_oonfX00oo00?oooo]ZoookJP03oookJP03ool0Xooonf[ooo]Z00;ooo]Z
00?oo`25oookJ_oonfX01OoonfX01Ol:o`3ooo]ZoookJ_oonf[oog/000;ooo]Z00CoaOl0oookJ_oo
nf[ooh`01ooonfX00onUo`3ooo]ZoookJP0<oookJP03ool0>ooonf[ooo]Z00;ooo]Z00Ko0?mjoook
J_oonf[o097ooookJ_oo0<h:oookJP04o`2<oomn0?oooo]Zool:00Sooo]Z00Goo`3loookJ_oonf[o
oo]ZoooC0003oookJP03o`3oVOoonf[ooo]Z00Sooo]Z00?oodP0oookJ_oonfX01ooonfX01?l0003o
0?mlo`000?l00008oookJP07o`02oooonf[ooo]ZoookJ_oO0?ooE_l0o`0Jo`06oookJP03oonL0?oo
nf[ooo]Z00?ooo]Z00?oofH0oookJ_l0o`002OoonfX00ooo<@3ooo]ZoookJP05oookJP03ooo=0?oo
nf[ooo]Z00Cooo]Z00CoU@3ooookJ_oonf[oog<02_oonfX2o`3oda[ooo]Z1OooeP0_oookJPOoomH0
=_oonfX2o`3oGBCooo]Z000/oookJP03o`3omooonf[ooo]Z00?ooo]Z00Go/ol0o`08oooo:03o0?ng
oolX0007oookJP04o`3Uool0ohcooo]Zo`3oh@Gooo]Z00Coob`0oookJ_oonf[o4_l00_oonfX00ol0
;Ooooo]ZoookJP04oookJP03o`3mool0ojkooo]Z00Gooo]Z00Koo`2QoookJ_oonf[oobP0oonP0?oo
:002oookJP09oolX0?l0=ooo03Oooomi0?oonf[o00SooookJ_ooN@3ood<000;ooo]Z0_oo0005oook
JP05o`3o/ooonf[ooo]ZoookJ_l0eOl01?oo:008oookJP03ol00oooonf[ooo]Z00Cooo]Z00?oo`2S
oookJ_oonfX00_oonfX00ooo08Gooo]ZoookJP05oookJP04oolX0?oonf[ooo]Zoomk00Goo`0000?o
oo]Zoon<0?oonfX01_oonfX00onUo`3ooo]ZoookJP0<oookJP05ool0>ooonf[ooo]ZoookJ_l0ogX0
0_oonfX01?l0TOoooo]ZoookJ_oo0<h6oookJPOoobP000?oo`X0oookJ_oonfX01OoonfX5ool00004
oooC0?oonf[ooo]Zool000Wooo]Z2?oo0005oookJP04o`3oO?l0003o0000o`0000Oooo]Z00Co00;o
oookJ_oonf[ooo]Z2?oo00000ooonf[oo`00oonL0005ool00003oolX0?l0o`3oobP000Gooo]Z2?oo
:003oookJP03ooo=0?oonf[ooo]Z00Gooo]Z00?oU@3ooolX0?oo:0001Ooo:007oookJPSoo`005ooo
nfX8oooF027ooo]Z1oooeP0hoookJPCo0?mMCooonfX00ol0ooOooo]ZoookJP03oookJP;o/ol000?o
oo]Zo`3o]ooo0<h01ooonfX01Ol05ooo0>GooookJ_oonf[o0?oQ00Cooo]Z00Coob`0oookJ_oonf[o
4_l00_oonfX00ol0;Ooooo]ZoookJP05oookJP03o`3moooonf[ooo]Z00Gooo]Z00?oo`2QoookJ_oo
nfX00_ooX002oookJP03oh<0ool0=ooo03Oo00?ooo]Z00?o00Soooo90?oo@`000ooonfX00ol0l_oo
oo]ZoookJP03oookJP08o`3o/ooonf[ooo]ZoookJ_l0eOoooo]Zool0:ol0okH:oookJP03ol00oooo
nf[ooo]Z00?ooo]Z00?oo`2SoookJ_oonfX00_oonfX00ooo08Gooo]ZoookJP05oookJP05o`[o0?oo
nf[ooo]ZoookJ_ooN`000_oonfX01?o5o`3ooo]ZoookJ_ooS007oookJP03ojGo0?oonf[ooo]Z00co
oo]Z00?oo`0koookJ_oonfX00_oonfX01_l0og[ooo]ZoookJ_l0TOoooo]Zool0cP[ooo]Z00Co08co
ogh0oooonf[oo`X02OoonfX01Ooo0?cooo]ZoookJ_oonf[oom<000;ooo]Z00?o0?nIoookJ_oonfX0
2OoonfX00oooB03ooo]ZoookJP07oookJP04o`3oO?l0003o0000o`0000Oooo]Z00?o00;ooookJ_oo
nfX00_oonfX00ooO0?ooE_l0o`0Jo`06oookJP03oonL0?oonf[ooo]Z00?ooo]Z00?oofH0oookJ_l0
o`002OoonfX00ooo<@3ooo]ZoookJP05oookJP03ooo=0?oonf[ooo]Z00Cooo]Z00GoU@3ooookJ_oo
nf[ooo]Zoomc000;oookJP;o0?oC7OoonfX7oooF027ooo]Z1oooeP0ioookJPCo0?mM9_oonfX002_o
oo]Z00?o0?ogoookJ_oonfX00ooonfX01?nco`3o00SooolX0?l0okL3oolX00Gooo]Z00Co0>Goo`3o
S?oonf[o0?oQ1OoonfX01?oo;03ooo]ZoookJ_lBo`02oookJP03o`0]oooonf[ooo]Z00Cooo]Z00?o
0?goo`3o[_oonfX01OoonfX01_oo0:7ooo]ZoookJ_oonf[ooj00oolX00;ooo]Z00?oobP0o`0goooo
nfX00oooN@000ooonf[oogT0oom30002oookJP03ool00?oonf[ooo]Z00Cooo]Z00Go0?ncoookJ_oo
nf[ooo]Zo`3Eo`04oolX00Sooo]Z00?o`03ooookJ_oonfX01?oonfX00ooo0:?ooo]ZoookJP02oook
JP03ool0QOoonf[ooo]Z00Gooo]Z00GoobP0oookJ_oonf[oog/0oookJP03ool000;ooo]Z00?ooh`0
oookJ_oonfX01OoonfX00onUo`3ooo]ZoookJP0<oookJP05ool0>ooonf[ooo]ZoookJ_l0ogX00_oo
nfX01?l0TOoooo]ZoookJ_oo0<h6oookJPOoobP000?oo`X0oolX0?oonfX01OoonfX5ool00005oooC
0?oonf[ooo]ZoookJ_l0oiT02OoonfX7ool000Kooo]Z00Co0?mlo`000?l0003o00001ooonfX01?l0
0_oooo]ZoookJ_oonfX8ool00003oookJ_oo003ooi`000Goo`0000?oobP0o`3o0?oo:0001OoonfX8
oolX00Cooo]Z00?oold0oookJ_oonfX01OoonfX00onE0?oooo]ZoolX0004oolX00Kooo]Z2ooo000M
oookJR7oomH0??oonfX3o`3oGE;ooo]Z00?o0?ogoookJ_oonfX00ooonfX01Onco`3o00SooookJ_l0
okOoo`3>00Oooo]Z00?o01Ooo`3UoooonfX00_l0on44oookJP04ool/0?oonf[ooo]Zoa;o00;ooo]Z
00?o02gooookJ_oonfX01?oonfX00ol0ojko0?gooookJP06oookJP04ool0XOoonf[ooo]ZoonP00?o
oo]Z00?oP`3oo`0goooonfX00ooonfX00ol02?ooolT0oom30002oookJP;o0?;o1OoonfX02?l0ok?o
oo]ZoookJ_oonf[o0=GooookJ_oo02_o0?nf2_oonfX00oo00?oooo]ZoookJP03oookJP03ool0Xooo
nf[ooo]Z00;ooo]Z00?oo`25oookJ_oonfX01OoonfX01Ol:o`3ooo]ZoookJ_oonf[oog/000;ooo]Z
00CoaOl0oookJ_oonf[ooh`01ooonfX00onUo`3ooo]ZoookJP0<oookJP03ool0>ooonf[ooo]Z00;o
oo]Z00Ko0?mjoookJ_oonf[o097ooookJ_oo0<h:oookJP05o`2<oooonf[oOP3ooookJ_oo2P002?oo
nfX01Ooo0?cooo]ZoookJ_oonf[oom<000?ooo]Z00?o0?nIoookJ_oonfX02?oonfX00oooB03ooo]Z
oookJP08oookJP04o`3oO?l0003o0000o`0000Oooo]Z00?o00;ooookJ_oonfX00_oonfX00ooO0?oo
E_l0oookJP06oookJP03oonL0?oonf[ooo]Z00?ooo]Z00?oofH0oookJ_l0o`002OoonfX00ooo<@3o
oo]ZoookJP06oookJP03ooo=0?oonf[ooo]Z00Cooo]Z00CoU@3ooookJ_oonf[ooo]Z0_ooL`0;oook
JP03o`3odooonf[ooo]Z027ooo]Z8OooeP0loookJPCo0?mM:_oonfX002[ooo]Z00?o0?ogoookJ_oo
nfX00ooonfX01?nco`3oobP0oolX0?l0okL5oolX00?ooo]Z00Co0>Goo`3oS?oonf[o0?oQ1OoonfX0
1?oo;03ooo]Zoa;o0?lBo`02oookJP03o`0]oooonf[ooo]Z00Cooo]Z00?o0?gooookJ_oonfX01Ooo
nfX01Ooo0:7ooo]ZoookJ_oonf[ooj0000CoobP000?o03OooookJ_ooN@000oooN@02oom300;ooo]Z
00?o0?;ooookJ_oonfX01?oonfX01_l0ok?ooo]ZoookJ_oonf[o0=GooookJP;oobP02OoonfX00oo0
0?oooo]ZoookJP04oookJP03ool0Xooonf[ooo]Z00;ooo]Z00?oo`25oookJ_oo:0001OoonfX01Ooo
:03ooo]ZoookJ_ooN`3ooo]Z00?oo`000ooonfX00oooS03ooo]ZoookJP04oookJP03ojGo0?oonf[o
oo]Z00cooo]Z00?oo`0koookJ_oonfX00_oonfX00ol0og[ooo]Zo`2Ao`03oookJP03ool0c_oonf[o
oo]Z00Cooo]Z1ooo:0000ooo2P3ooo]ZoookJP05oookJPCoo`0000Gooo]ZoooC0?oonf[ooo]Zo`3o
V@0:oookJPKoo`001_oonfX00ol0ogco0000o`000002o`0000Oooo]Z00Co00;ooookJ_oonf[ooo]Z
1ooo0002oookJP03ool00?ooW03oo`0000?oo`000ooo:0000ol0o`3ooo]ZoookJP04oookJPOoobP0
1?oonfX00oooc@3ooo]ZoookJP06oookJP03oiD0oooonf[ooo]Z00CoobP01OoonfX<ool007Gooo]Z
1?l0oeeDoookJP03o`3omooonf[ooo]Z00?ooo]Z00Go/ol0oookJ_oonf[o0?ngool0cP07oookJP04
o`0Gool0iOoooo]Zo`3oh@Gooo]Z00Coob`0oookJ_lBo`3o4_l00_oonfX00ol0;Ooooo]ZoookJP04
oookJP03o`3o[_l0oOoooo]Z00Kooo]Z00Coo`2QoookJ_oonf[ooj000ooonfX00on30?oo03Oooook
JP02oookJP;o00So0_oo@`02oookJP03o`3boooonf[ooo]Z00Cooo]Z00So0?ncoookJ_oonf[ooo]Z
o`3Eoooonf[oo`0[o`3o]P[ooo]Z00?o`03ooookJ_oonfX00ooonfX00ooo0:?ooo]ZoookJP02oook
JP03ool0QOoonf[ooo]Z00Gooo]Z00Go2_l0oookJ_oonf[ooo]Zoomk0002oookJP05olGo0?oonf[o
oo]ZoookJ_ooS0001_oonfX00onUo`3ooo]ZoookJP0<oookJP03ool0>ooonf[ooo]Z00?ooo]Z00?o
0?mjoookJ_l0TOl00_oonfX00ooo0<kooo]ZoookJP08oookJP04o`2<oomn0?oooo]Zool:00Wooo]Z
00Goo`3loookJ_oonf[ooo]ZoooC0002oookJP03o`3oVOoonf[ooo]Z00Wooo]Z00?oodP0oookJ_oo
nfX02?oonfX01?l0ogco0000o`000?l00007oookJP03o`02oooonf[ooo]Z00;ooo]Z00Cog`3oo`0J
oooonf[omOl01OoonfX00oooW03ooo]ZoookJP03oookJP03oomV0?oonf[o0?l000[ooo]Z00?ooc40
oookJ_oonfX01OoonfX00oooc@3ooo]ZoookJP05oookJP03oiD0oooonf[ooo]Z00;ooo]Z00?oog<0
oookJ_oonfX02OoonfX2o`3od`03oookJ_l02?oo00So07Sooo]Z0ol0oed^oookJP00;ooonfX01?nc
o`3oobP0o`3o]ol0okL7oolX0005oookJ_l0iOoo0?n<oookJ_l0on401OoonfX00ooo;03ooo]Zoa;o
0002oookJP;o02go1_oonfX00ol0oOoooo]ZoookJP05oookJP05ool0XOoonf[ooo]ZoookJ_ooX000
1?oo:0000ol0=ooooo]ZoookJP03oomi0005oom30?ooN@3oogT0oookJ_l0l_l01_oonfX02?l0ok?o
oo]ZoookJ_oonf[o0=GooookJ_oo:03o0?nf2OoonfX00oooN@3ooo]ZoookJP04oookJP03ool0Xooo
nf[ooo]Z00;ooo]Z00?oo`25oookJ_oonfX00_oo:003oookJP05oolX0?oonf[ooo]ZoookJ_ooN`00
0ooo0003oookJP03oon<0?oonf[ooo]Z00Cooo]Z00?oYOl0oookJ_oonfX03?oonfX00ooo:03ooo]Z
oookJP02oookJP03o`3oN_oonf[o097o00?ooo]Z00?oo`3>oookJ_oonfX01OoonfX6oolX0003ool:
0?oonf[ooo]Z00Kooo]Z0ooo00000ooonf[oom<0oookJP02oookJP03o`3oVOoonf[ooo]Z00Oooo]Z
1_oo0007oookJP03o`3oO?l0003o000000;o00001_oonfX00ol00_oooo]ZoookJP02oookJP03ool0
0?oO0?ooo`0000Coo`000_oonfX00ooo003ooi`0ool00003ool000?oobP000?o0?l0oookJ_oonfX0
1OoonfX6oolX00Gooo]Z00?oold0oookJ_oonfX01_oonfX01?nE0?oooo]ZoookJ_oonfX2oolX00Co
oo]Z3_oo001aoookJP?o0?mM2ooonfX2o`3oIe3ooo]Z00Go/ol0oookJ_l0okOo0?ngool0cP07oook
JP04o`0Gool0iOoooo]Zo`3oh@Gooo]Z00?oob`0oookJ_lBo`000_oonfX2o`0]o`Kooo]Z00?o0?n^
o`3moooonfX01_oonfX01?oo0:7ooo]ZoookJ_ooX003oookJP03oh<0ool0=ooooo]Z00;ooo]Z00?o
00SooookJ_oo@`000ooonfX00ol0l_oooo]ZoookJP04oookJP08o`3o/ooonf[ooo]ZoookJ_l0eOoo
oo]Zool0:ol0okH:oookJP03ol00oooonf[ooo]Z00?ooo]Z00?oo`2SoookJ_oonfX00_oonfX00ooo
08Gooo]ZoookJP05oookJP05o`[o0?oonf[ooo]ZoookJ_ooN`000_oonfX01Oo5o`3ooo]ZoookJ_oo
nf[ooh`000Kooo]Z00?oYOl0oookJ_oonfX03?oonfX00ooo03_ooo]ZoookJP03oookJP03o`3oN_oo
nf[o097o00;ooo]Z00?oo`3>oookJ_oonfX02?oonfX01?l0S?ooOP3ooookJ_oo2P09oookJP05ool0
o?oonf[ooo]ZoookJ_ood`000ooonfX00ol0oiWooo]ZoookJP08oookJP03oom80?oonf[ooo]Z00So
oo]Z00?o0?mlo`000?l000000_l00007oookJP03o`02oooonf[ooo]Z00;ooo]Z00Cog`3oo`0Joooo
nf[omOl01OoonfX00oooW03ooo]ZoookJP03oookJP03oomV0?oonf[o0?l000[ooo]Z00?ooc40oook
J_oonfX01_oonfX00oooc@3ooo]ZoookJP05oookJP03oiD0oooonf[ooo]Z00;ooo]Z00?oog<0oook
J_oonfX02_oonfX00ol0om?ooo]ZoookJP02o`08og;ooo]Z1?l0oed:oookJP?o0?mW9?oonfX002ko
oo]Z00Co/ol0oolX0?l0okOok`3o1_oo:002oookJP04o`3Uool0ohcooo]Zo`3oh@Gooo]Z00?oob`0
oookJ_lBo`000_oonfX00ol0;Ooooo]ZoookJP05oookJP03o`3moooonf[ooo]Z00Gooo]Z00Goo`2Q
oookJ_oonf[ooo]ZoonP0004oolX0003o`0goooo:03oobP000?oogT000Good<0oomi0?ooN@3oogT0
o`3bo`06oookJP08o`3o/ooonf[ooo]ZoookJ_l0eOooo`0[oolX0?l0okH:oookJP03oomi0?oonf[o
oo]Z00?ooo]Z00?oo`2SoookJ_oonfX00_oonfX00ooo08Gooo]ZoookJP04oolX0003oookJ_oo:03o
oo]Z00;ooo]Z00?oog/0oookJ_oo00001?oonfX00oooS03ooo]ZoookJP04oookJP03o`3o9?nUo`3o
oo]Z00gooo]Z00GoobP0oookJ_oonf[ooo]Zo`3oNP02oookJP04o`2Aoooonf[ooo]Zool0cPOooo]Z
1_oo:0000ooonf[oo`X0oookJP07oookJP;oo`000_oonfX01?ood`3ooo]ZoookJ_l0oiT:oookJPGo
o`001ooonfX00ol0ogcooo]Zo`000004o`0000Gooo]Z00Co00;ooolX0?oo:03oobP00_oo00000ooO
0?ooo`00ool00003ool000;ooo]Z00?ooi`0ool00?oo00000ooo0003oolX0003o`3o0?oonf[ooo]Z
00Gooo]Z1_oo:005oookJP03ooo=0?oo0;[ooo]Z00Oooo]Z00CoU@3ooookJ_oonf[ooo]Z0_oo:002
oookJQ3oo`001?oonfX2oolX06Kooo]Z1?l0oed;oookJP?o0?mWDOoonfX01Onco`3ooo]Zo`3o]oo_
0?ooo`3>00Oooo]Z00Co01Ooo`3Uoooonf[o0?oQ1OoonfX00ooo;03ooo]Zoa;o0002oookJP03o`0]
oooonf[ooo]Z00Gooo]Z00?o0?n^o`3moooonfX01_oonfX01?oo0:7ooo]ZoookJ_ooX003oookJP03
oh<0ool0=ooooo]Z00;ooo]Z00?o00SooookJ_oo@`000ooonfX00ol0l_oooo]ZoookJP04oookJP08
o`3o/ooonf[ooo]ZoookJ_l0eOoooo]Zool0:ol0okH:oookJP03ol00oooonf[ooo]Z00?ooo]Z00?o
o`2SoookJ_oonfX00_oonfX00ooo08Gooo]ZoookJP05oookJP05o`[o0?oonf[ooo]ZoookJ_ooN`00
0_oonfX01Oo5o`3ooo]ZoookJ_oonf[ooh`000Kooo]Z00?o0?lTojGo0?oonfX03OoonfX00ooo03_o
oo]ZoookJP02oookJP06o`3oN_oonf[ooo]Zo`2Aoooonf[oo`3>2_oonfX01Ol0S?oooo]Zogh0oooo
nf[oo`X000Sooo]Z00Goo`3loookJ_oonf[ooo]ZoooC0003oookJP03o`3oVOoonf[ooo]Z00Wooo]Z
00?oodP0oookJ_oonfX02?oonfX00ol0ogco0000o`000003o`0000Gooo]Z00?o00;ooookJ_oonfX0
0ooonfX01?oO0?oo01[ooookJ_oeo`05oookJP03oonL0?oonf[oF`3o00?ooo]Z00?oofH0oookJ_l0
o`002_oonfX00ooo<@3ooo]ZoookJP06oookJP03ooo=0?oo0;[ooo]Z00Kooo]Z00?oU@3ooookJ_oo
nfX00_oonfX00oooL`3ooo]ZoookJP09oookJP03o`19ool0om?o0?oC00;ooo]Z00?o00SooookJ_oo
nfX0JooonfX4o`3oG@_ooo]Z0ol0ofLWoookJP00;OoonfX01?nco`3ooo]Zo`3o]oo_0?l5oolX00;o
oo]Z00?o01Ooo`3Uool0oh`00_l0on44oookJP;oob`000Gooo]Zoa;o0?oonf[ooo]Zo`0]o`06oook
JP;o0?go1_oonfX2ool0X@?ooo]Z00?ooj00oolX0?oo:0000_oo:0000ol0=oooobP0oolX0003oomi
0005oom30?ooN@3oogT0oomi0?l0l_l00_ooN@04oookJP08o`3o/ooonf[ooo]ZoookJ_l0eOooo`0[
oookJ_l0okH:oookJP03oomi0?oonf[ooo]Z00?ooo]Z00?oo`2SoookJ_oonfX00_oonfX01?oo08Go
oo]ZoookJ_oonfX5oolX00?ooo]Z00?oog/0oookJ_oo00001?oonfX00oooS03ooo]ZoookJP04oook
JP03o`3o9?nUo`3ooo]Z00Sooo]Z00?oobP0oookJ_oonfX00_oonfX01Ooo:03ooo]ZoookJ_oonf[o
0?mj00;ooo]Z00Co097ooookJ_oonf[oo`3>2?oonfX5oolX0003oookJ_oo2P3ooo]Z00Oooo]Z0_oo
0002oookJP04oooC0?oonf[ooo]Zo`3oV@_ooo]Z1Ooo0007oookJP03o`3oO?oonf[o000000?o0000
1_oonfX00ol00_ooobP0oolX0004oolX00Goo`000_oonfX00oooW03oo`00ool00002ool000CoobP0
00?o0?l0oookJ_oonfX01_oonfX5oolX00Kooo]Z00?oold0ool0^_oonfX01ooonfX00onE0?oooo]Z
oookJP02oookJP03oolX0?oonf[ooo]Z00;ooo]Z3_oo0003oookJPCoobP0HOoonfX3o`3oG@_ooo]Z
1?l0ofL3oookJP;oogT0C_oonfX01?nco`3ooo]Zo`3o]oo_0?l7oookJP;o01Oo00?o0>GooookJ_l0
on401OoonfX00ooo;03ooo]Zoa;o0002oookJP03o`0]oooonf[ooo]Z00Gooo]Z0_l0oOl6oookJP;o
o`2Q0_oonfX01_ooX03ooo]ZoookJ_oonf[oP`3oo`0go`?ooo]Z00?o00SooookJ_oo@`000ooonfX0
0ol0l_oooo]ZoookJP04oookJP08o`3o/ooonf[ooo]ZoookJ_l0eOoooo]Zool0:ol0okH:oookJP03
ol00oooonf[ooo]Z00?ooo]Z00?oo`2SoookJ_oonfX00_oonfX00ooo08Gooo]ZoookJP05oookJP05
o`[o0?oonf[ooo]ZoookJ_ooN`000_oonfX01Oo5o`3ooo]ZoookJ_oonf[ooh`000Kooo]Z00?o0?lT
ojGo0?oonfX03OoonfX00ooo03_ooo]ZoookJP02oookJP06o`3oN_oonf[ooo]Zo`2Aoooonf[oo`3>
2_oonfX01Ol0S?oooo]Zogh0oooonf[oo`X000Wooo]Z00Goo`3loookJ_oonf[ooo]ZoooC0002oook
JP03o`3oVOoonf[ooo]Z00Wooo]Z00?oodP0oookJ_oonfX02OoonfX00ol0ogco0000o`000002o`00
00Kooo]Z00?o00;ooookJ_oonfX00_oonfX01OoO0?ooE_l0o`0Joooonf[omOl000Gooo]Z00?ooi`0
oookJ_mK0?l00ooonfX00oooIP3ooo]Zo`3o000;oookJP03oola0?oonf[ooo]Z00Kooo]Z00?oold0
oookJ_oonfX01_oonfX00onE0?oooo]ZoookJP02oookJP03oomc0?oonf[ooo]Z00[ooo]Z00Co04Wo
o`3odol0om?ooo]Z0_l02?mXoookJP?o0?mM2ooonfX4o`3oI`Cooo]Z0_l02?lToookJP00;?oonfX0
0onco`3ooo]Zo`3o]`05oolX00?ooo]Z00Co01Ooo`3Uoooonf[o0?oQ1OoonfX01?oo;03ooo]Zoook
J_lBo`02oookJP03o`0]oooonf[ooo]Z00Cooo]Z00?o0?goo`3o[_oonfX01OoonfX00ooo0:7ooo]Z
oookJP02oookJP03oonP0?oo:03oobP000;oobP000?o03OooolX0?oo:0000oooN@001_oo@`3oogT0
oomi0?ooN@3o0?;ooomi00Gooo]Z00So0?ncoookJ_oonf[ooo]Zo`3Eoooo02_ooo]Zo`3o]P[ooo]Z
00?oogT0oookJ_oonfX00ooonfX00ooo0:?ooo]ZoookJP02oookJP04ool0QOoonf[ooo]ZoookJPOo
obP000Gooo]Zoomk0?oonf[ooo]ZolGo0003oookJP03oon<0?oonf[ooo]Z00Gooo]Z00?oYOl0oook
J_oonfX02?oonfX2oolX00;ooo]Z00?oobP0oookJ_oonfX00_oonfX00ol0og[oobP0oolX0002oook
JP03ool0c_oo:03ooo]Z00Kooo]Z1Ooo:0000ooonf[oo`X0oookJP08oookJP04ool00?oonf[ooo]Z
oooC00?ooo]Z00?o0?nIoookJ_oonfX02OoonfX4ool000Sooo]Z00?o0?mloookJ_l000000ol00005
oookJP03o`02oooonf[oobP000GoobP01Ooo0002oookJP03oonL0?oo003oo`0000;oo`0000Gooo]Z
oolX0?oo:03oobP0o`3o0008oookJPKoobP01OoonfX00oooc@3ooo]Zool0^P08oookJP03oiD0oooo
nf[ooo]Z00;ooo]Z00?oog<0oookJ_oonfX01OoonfX7ool00005o`3odooonf[oo`00ool00?l02?l0
1ooo:00?oookJP;oo`00BOoonfX5o`3oG@[ooo]Z1?l0ofL2oookJP03oomi0?oonf[oogT000;oogT0
CooonfX01?nco`3ooo]Zo`3o]ooo0<h7oookJP05o`0Gool0iOoo0>GooookJ_l0on401OoonfX00ooo
;03ooo]Zoa;o0002oookJP03o`0]oooonf[ooo]Z00Gooo]Z00?o0?gooookJ_oonfX01OoonfX01Ooo
0:7ooo]ZoookJ_oonf[ooj0000?ooo]Z00?oP`3oo`0goooonfX00_oonfX00ol02?oooo]Zoom30003
oookJP03o`3boooonf[ooo]Z00Cooo]Z00So0?ncoookJ_oonf[ooo]Zo`3Eoooonf[oo`0[o`3o]P[o
oo]Z00?o`03ooookJ_oonfX00ooonfX00ooo0:?ooo]ZoookJP02oookJP03ool0QOoonf[ooo]Z00Go
oo]Z00Go2_l0oookJ_oonf[ooo]Zoomk0003oookJP04olGo0?oonf[ooo]Zoon<00Oooo]Z00?oYOl0
oookJ_oonfX03?oonfX00ooo03_ooo]ZoookJP02oookJP07o`3oN_oonf[ooo]Zo`2Aoooonf[oo`3>
o`3ohP0:oookJP04o`2<oomn0?oooo]Zool:00Wooo]Z00Goo`3loookJ_oonf[ooo]ZoooC0003oook
JP03o`3oVOoonf[ooo]Z00Wooo]Z00?oodP0oookJ_oonfX02?oonfX00ol0ogcooo]Zo`000003o`00
00Kooo]Z00?o00;ooookJ_oonfX00_oonfX01OoO0?ooE_l0o`0Joooonf[omOl000Gooo]Z00?ooi`0
oookJ_mK0?l00ooonfX00oooIP3ooo]Zo`3o000;oookJP03oola0?oonf[ooo]Z00Kooo]Z00?oold0
ool0^_oonfX01ooonfX00onE0?oooo]ZoookJP02oookJP03oomc0?oonf[ooo]Z00_ooo]Z00Co04Wo
o`3odooonf[ooo]Z0_l02?mQoookJPGo0?mM2_oonfX4o`3oI`Gooo]Z0ol02?lVoookJP00:ooonfX0
0onco`3ooo]Zo`3o]`04oolX00Cooo]Z00Co01Ooo`3Uoooonf[o0?oQ1OoonfX01?oo;03ooo]Zoook
J_lBo`02oookJP03o`0]oooonf[ooo]Z00Cooo]Z00?o0?goo`3o[_oonfX01OoonfX00ooo0:7ooo]Z
oookJP02oookJP03oonP0?oo:03oobP000;oobP000Co03OooolX0?oo:03oobP00_ooN@001Ooo@`3o
ogT0oomi0?ooN@3o0?;o00Kooo]Z00So0?ncoookJ_oonf[ooo]Zo`3Eoooo02_ooo]Zo`3o]P[ooo]Z
00?oogT0oookJ_oonfX00ooonfX00ooo0:?ooo]ZoookJP02oookJP04ool0QOoonf[ooo]ZoookJPWo
obP00_oonfX01Oo5o`3ooo]ZoookJ_oonf[ooh`000Oooo]Z00?oYOl0oookJ_oonfX02?oonfX5oolX
00Cooo]Z00?o0?mjoookJ_oo:0000_oo:0000ooonf[oo`3>oookJP07oookJP?oobP000CoOP3ooook
J_oonf[oo`X02OoonfX01?oo0?cooo]ZoookJ_ood`02oookJP03o`3oVOoonf[ooo]Z00[ooo]Z0ooo
0008oookJP03o`3oO?oonf[ooo]Z00Co00001OoonfX00ol00_oooo]ZoolX0005oolX00Coo`000ooo
nfX00oooW03oo`00ool00003ool000?oobP000?o0?l0ool00?oo00001ooonfX5oolX00Kooo]Z00?o
old0ool0^_oonfX01ooonfX00ooo003oU@3ooookJP03oookJP03oomc0?oonf[ooo]Z00Oooo]Z1Ooo
0002o`3od`;ooo]Z2Ooo:00=oookJPGoo`00?ooonfX7o`3oG@[ooo]Z1Ol0ofL3oookJP?o00So0_oo
N@1AoookJP04ok?o0?oonf[o0?ngool0cPOooo]Z00?o01Ooo`3UoooonfX00_l0on44oookJP;oob`0
00Gooo]Zoa;o0?oonf[ooo]Zo`0]o`07oookJP03o`3moooonf[ooo]Z00Gooo]Z00Goo`2QoookJ_oo
nf[ooo]ZoonP0003oookJP03oh<0ool0=ooooo]Z00;ooo]Z00?o00SooookJ_oo@`000ooonfX00ol0
l_oooo]ZoookJP04oookJP08o`3o/ooonf[ooo]ZoookJ_l0eOoooo]Zool0:ol0okH:oookJP03ol00
oooonf[ooo]Z00?ooo]Z00?oo`2SoookJ_oonfX00_oonfX00ooo08Gooo]ZoookJP05oookJP05o`[o
0?oonf[ooo]ZoookJ_ooN`000ooonfX01?o5o`3ooo]ZoookJ_ooS007oookJP03ojGo0?oonf[ooo]Z
00cooo]Z00?oo`0koookJ_oonfX00ooonfX00ol0og[ooo]Zo`2Ao`02oookJP03ool0c_oonf[ooo]Z
00Sooo]Z00Go08coogh0oooonf[ooo]Zool:0009oookJP04ool0o?oonf[ooo]ZoooC00?ooo]Z00?o
0?nIoookJ_oonfX02_oonfX00oooB03ooo]ZoookJP08oookJP03o`3oO?oonf[o000000?o00001_oo
nfX00ol00_oooo]ZoookJP02oookJP04oml0oomFo`3ooo]ZooGo00Kooo]Z00?ooi`0oookJ_mK0?l0
0ooonfX00oooIP3ooo]Zo`3o000;oookJP03oola0?oonf[ooo]Z00Oooo]Z00?oold0oookJ_oonfX0
1ooonfX00onE0?oooo]ZoookJP02oookJP03oomc0?oonf[ooo]Z00_ooo]Z00?o04Woo`3odol0om<0
0_oonfX3o`08oeOooo]Z1ol0oed:oookJPGo0?mW1?oonfX5o`08obWooo]Z000ZoookJP03ok?o0?oo
nf[o0?ng00?oobP01OoonfX01?l05ooo0>GooookJ_l0on45oookJP04ool/0?oonf[ooo]Zoa;o00;o
oo]Z00?o02gooookJ_oonfX01?oonfX00ol0oOoo0?n^oookJP05oookJP03ool0XOoonf[ooo]Z00;o
oo]Z00?ooj00oookJ_oo:0000_oo:0001?l0=oooobP0oolX0?oo:002oomi0005oom30?ooN@3oogT0
oomi0?l0l_l01_oonfX02?l0ok?ooo]ZoookJ_oonf[o0=Goool0:ooonf[o0?nf2_oonfX00oooN@3o
oo]ZoookJP03oookJP03ool0Xooonf[ooo]Z00;ooo]Z00?oo`25oookJ_oonfX00_oonfX7oolX0004
oomk0?oonf[ooo]ZolGo00?ooo]Z00?ooh`0oookJ_oonfX01OoonfX00onUo`3ooo]ZoookJP09oook
JPGoobP00ooonfX00ol0og[ooo]ZoolX0003oolX0003ool0c_oonf[ooo]Z00Kooo]Z0ooo:0001?mn
0?oooo]ZoookJ_oo2P09oookJP04ool0o?oonf[ooo]ZoooC00?ooo]Z00?o0?nIoookJ_oonfX02Ooo
nfX3ool000Wooo]Z00?o0?mloookJ_oonfX01?l00005oookJP03o`02oooonf[oobP000KoobP00ooo
0003oookJP03oonL0?oo003oo`0000?oo`000_oo:0001?oo003o0?l0ool00?oo0008oookJPCoobP0
1ooonfX00oooc@3oo`2joookJP05oookJP;oo`0000?ooo]ZoiD0oooonfX00ooonfX00oooL`3ooo]Z
oookJP0:oookJP?oo`000_l0om<:oolX00cooo]Z1ooo000DoookJPCoobP07?oonfX5oolX00Co0?mM
3OoonfX4o`3oI`?ooo]Z1Ol02?l5oookJPGoogT0BooonfX01?nco`3ooo]Zo`3o]ooo0<h7oookJP04
o`0Gool0iOoooo]Zo`3oh@Gooo]Z00Coob`0oookJ_oonf[o4_l00_oonfX00ol0;Ooooo]ZoookJP05
oookJP03o`3moooonf[ooo]Z00Gooo]Z00Goo`2QoookJ_oonf[ooo]ZoonP0003oookJP03oh<0ool0
=ooooo]Z00;ooo]Z00?o00SooookJ_oo@`000ooonfX00ol0l_oooo]ZoookJP04oookJP08o`3o/ooo
nf[ooo]ZoookJ_l0eOoooo]Zool0:ol0okH:oookJP03ol00oooonf[ooo]Z00?ooo]Z00?oo`2Soook
J_oonfX00_oonfX00ooo08Gooo]ZoookJP06oookJP04o`[o0?oonf[ooo]Zoomk00?ooo]Z00CoaOl0
oookJ_oonf[ooh`01ooonfX00onUo`3ooo]ZoookJP0=oookJP03ool0>ooonf[ooo]Z00;ooo]Z00Ko
0?mjoookJ_oonf[o097ooookJ_oo0<h:oookJP05o`2<oooonf[oOP3ooookJ_oo2P002OoonfX01Ooo
0?cooo]ZoookJ_oonf[oom<000?ooo]Z00?o0?nIoookJ_oonfX02OoonfX00oooB03ooo]ZoookJP09
oookJP03o`3oO?oonf[o000000?o00001_oonfX00ol00_oooo]ZoookJP02oookJP04oml0ool06_oo
oo]ZooGo00Kooo]Z00?ooi`0oookJ_mK0?l00ooonfX00oooIP3ooo]Zo`3o000;oookJP03oola0?oo
nf[ooo]Z00Oooo]Z00?oold0ool0^_oonfX02?oonfX00onE0?oooo]ZoookJP02oookJP03oomc0?oo
nf[ooo]Z00cooo]Z00?o04Woo`3odol0om<00ooonfX3o`08odkooo]Z1_l0oed=oookJPCo0?mW1?oo
nfX5o`08obkooo]Z000[oookJP03o`3o]ooo:03oobP000Kooo]Z0_l0iOl00ooonf[o0?oQoookJP04
oookJP04ool/0?oonf[o4_l0oa;o00;ooo]Z00?o02gooookJ_oonfX01?oonfX00ol0oOoo0?n^oook
JP05oookJP03ool0XOoonf[ooo]Z00;ooo]Z00?ooj00oookJ_oo:0000_oo:0001?l0=oooobP0oook
J_oo:002oomi0005oom30?ooN@3oogT0oookJ_l0l_l01_oonfX02?l0ok?ooo]ZoookJ_oonf[o0=Go
ool0:ooonf[o0?nf2_oonfX00oooN@3ooo]ZoookJP03oookJP03ool0Xooonf[ooo]Z00;ooo]Z00?o
o`25oookJ_oonfX00_oonfX7oolX0004oomk0?oonf[ooo]ZolGo00?ooo]Z00?oobP0oookJ_oonfX0
1OoonfX00onUo`3ooo]ZoookJP09oookJPOoobP000Cooo]Zo`3oN_oonf[ooo]Z0ooo:0000ooo0<ko
obP0oolX0007oookJP;oobP000CoOP3ooookJ_oonf[oo`X02OoonfX01Ooo0?cooo]ZoookJ_oonf[o
om<000;ooo]Z00?o0?nIoookJ_oonfX02_oonfX2ool000Wooo]Z00Co0?mloookJ_oonf[ooo]Z1?l0
0004oookJP03o`02oooonf[ooo]Z00OoobP00_oo0004oookJP03oonL0?oo003oo`0000Coo`0000?o
obP0ool00?l0o`000_oo0008oookJPCoobP01ooonfX00oooc@3oo`2joookJP04oookJPCoo`0000?o
oo]ZoiD0oooonfX00ooonfX00oooL`3ooo]ZoookJP0=oookJPgoobP02_oonfX:ool0017ooo]Z2Ooo
:00CoookJPCo0?mM3Ooo:005oookJPCo0?mW0_oonfX5o`08o`[ooo]Z0_ooN@03o`3oddcooo]Z00?o
0?ngool0c_oonfX01_oonfX01?l05ooo0>GooookJ_l0on45oookJP04ool/0?oonf[o4_l0oa;o00;o
oo]Z00?o02gooookJ_oonfX01OoonfX00ol0oOoooo]ZoookJP05oookJP05ool0XOoonf[ooo]Zoook
J_ooX0000ooonfX00on30?oo03OooookJP02oookJP03o`08oooonf[ood<000?ooo]Z00?o0?;ooook
J_oonfX01?oonfX02?l0ok?ooo]ZoookJ_oonf[o0=GooookJ_oo02_o0?nf2_oonfX00oo00?oooo]Z
oookJP03oookJP03ool0Xooonf[ooo]Z00;ooo]Z00?oo`25oookJ_oonfX01_oonfX01?l:o`3ooo]Z
oookJ_ooN`03oookJP04olGo0?oonf[ooo]Zoon<00Oooo]Z00?oYOl0oookJ_oonfX03OoonfX00ooo
03_ooo]ZoookJP02oookJP06o`3oN_oonf[ooo]Zo`2Aoooonf[oo`3>2ooonfX01?l0S?ooOP3ooook
J_oo2P09oookJP05ool0o?oonf[ooo]ZoookJ_ood`000ooonfX00ol0oiWooo]ZoookJP0:oookJP03
oom80?oonf[ooo]Z00Sooo]Z00?o0?mloookJ_oonfX01?l00005oookJP03o`02oooonf[ooo]Z00;o
oo]Z00Gog`3ooeKo0?l06_oooo]ZooGo0006oookJP03oonL0?oonf[oF`3o00?ooo]Z00?oofH0oook
J_l0o`003?oonfX00ooo<@3ooo]ZoookJP07oookJP03ooo=0?oonf[ooo]Z00Sooo]Z00?oU@3ooook
J_oonfX00_oonfX00oooL`3ooo]ZoookJP0=oookJP04o`19ool0om?o0?oCo`3od`?ooo]Z0ol02?m4
oookJPOo0?mM3ooonfX4o`3oI`?ooo]Z1Ol02?l<oookJP?o0?oC9?oonfX002[ooo]Z00?o0?ngoolX
0?oonfX01_oonfX01?l0iOoo0?n<oookJ_l0on45oookJP03ool/0?oonf[o4_l000?ooo]Z00?o02go
oookJ_oonfX01?oonfX00ol0oOoo0?n^oookJP05oookJP03ool0XOoonf[ooo]Z00;ooo]Z00?ooj00
oookJ_oo:0000_oo:0002?l0=ooooo]ZoookJ_oo:03ooo]Zoomi0?oo@`3oogT00_oonfX00ol0l_oo
oo]ZoookJP04oookJP08o`3o/ooonf[ooo]ZoookJ_l0eOooo`0[oookJ_l0okH4oookJP;oogT01?oo
nfX00oooN@3ooo]ZoookJP03oookJP03ool0Xooonf[ooo]Z00;ooo]Z00?oo`25oookJ_oonfX00ooo
nfX5oolX0005oookJ_ooN`3ooo]ZoookJ_o5o`001?oonfX00ooo:03ooo]ZoookJP04oookJP03ojGo
0?oonf[ooo]Z00Gooo]Z00?oo`00oookJ_oonfX00_oonfX8oolX0003o`3oN_oonf[oobP000;oobP0
00?oo`3>oolX0?oo:0000_oo:006oookJP05oolX0?oonf[oOP3ooookJ_oo2P002_oonfX01?oo0?co
oo]ZoolX0?ood`02oookJP03o`3oVOoonf[ooo]Z00_ooo]Z00?oo`00oookJ_oonfX02?oonfX01?l0
ogcooo]ZoookJ_oonfX4o`0000Cooo]Z00?o00;ooookJ_oonfX01ooo:002ool000Cooo]Z00?ooi`0
oookJ_oo00001?oo00001?oo:03oo`00ool00?l0o`0:oookJP?oobP02?oonfX00oooc@3oo`2joook
JP02oookJPGoo`000_oonfX00onE0?oooo]ZoookJP02oookJP;oog<03?oonfX@oolX00Sooo]Z3?oo
000?oookJPkoobP01OoonfX9o`3oG@Cooo]Z4Ooo:0000ol0ofOooo]Zo`08o`04o`08o`kooo]Z0ol0
om<3oomi04_ooo]Z00?o0?ngool0c_oonfX01_oonfX01?l05ooo0>GooookJ_l0on45oookJP03ool/
0?oonf[o4_l000?ooo]Z00?o02gooookJ_oonfX01OoonfX00ol0oOoooo]ZoookJP05oookJP05ool0
XOoonf[ooo]ZoookJ_ooX0000ooonfX00on30?oo03OooookJP02oookJP03o`08oooonf[ood<000?o
oo]Z00?o0?;ooookJ_oonfX01?oonfX02?l0ok?ooo]ZoookJ_oonf[o0=GooookJ_oo02_o0?nf2_oo
nfX00oo00?oooo]ZoookJP03oookJP03ool0Xooonf[ooo]Z00;ooo]Z00?oo`25oookJ_oonfX01_oo
nfX01?l:o`3ooo]ZoookJ_ooN`03oookJP05olGo0?oonf[ooo]ZoookJ_ooS0001_oonfX00onUo`3o
oo]ZoookJP05oookJP03okoo0?oonf[ooo]Z00Gooo]Z00?oo`0koookJ_oonfX00_oonfX01ol0og[o
oo]ZoookJ_l0TOoooo]Zool0c_l0on802_oonfX01Ol0S?ooOP3ooookJ_oonf[oo`X000Wooo]Z00Co
o`3loookJ_oonf[oom<00ooonfX00ol0oiWooo]ZoookJP0:oookJP03oom80?oonf[ooo]Z00Wooo]Z
00?o0?mloookJ_oonfX01?l00005oookJP03o`02oooonf[ooo]Z00;ooo]Z00Gog`3ooeKo0?l06_oo
02goooGo0006oookJP03oonL0?oonf[oF`3o00?ooo]Z00CoofH0oookJ_oonf[o0?l02ooonfX00ooo
<@3ooo]ZoookJP07oookJP03ooo=0?oo0;[ooo]Z00Wooo]Z00?oU@3ooookJ_oonfX00_oonfX2oomc
013ooo]Z00Co04Woo`3odol0om?o0?oC0ooonfX5o`08o`cooo]Z1?l0oedWoookJPSo0?mM4OoonfX5
o`3oI`;ooo]Z1Ol02?l=oookJPCo0?oC9ooonfX002[ooo]Z00?oo`3>oookJ_oonfX01?oonfX01Ol0
5ooo0>Goo`3oS?oonf[o0?oQ00Cooo]Z0_oo;0001?oonf[o4_l0oookJ_oonfX2o`0]o`Kooo]Z00?o
0?goo`3o[_oonfX01OoonfX01?oo0:7ooo]ZoookJ_oonfX2oonP00;ooo]Z00?oobP0o`0gool0=ol0
0_oonfX01?oo:03ooo]Zoomi0?oo@`03oookJP03o`3boooonf[ooo]Z00Cooo]Z00So0?ncoookJ_oo
nf[ooo]Zo`3Eoooo02_ooo]Zo`3o]PGooo]Z0oooN@02oookJP03oomi0?oonf[ooo]Z00?ooo]Z00?o
o`2SoookJ_oonfX00_oonfX00ooo08Gooo]ZoookJP03oookJPGoobP000Gooo]Zoomk0?oonf[ooo]Z
olGo0004oookJP03oolX0?oonf[ooo]Z00Cooo]Z00?oYOl0oookJ_oonfX01_oonfX01?oo003ooo]Z
oookJ_oonfX7oolX0004oookJ_l0og[ooo]Zo`2Ao`?oobP000?oo`3>oolX0?oo:0000ooo:004oook
JP03oolX0?oonf[oOP3o00;ooo]Z00?oo`X0oookJ_oonfX01ooonfX01?oo0?cooo]ZoookJ_ood`02
oolX0003oookJ_l0oiWooo]Z00cooo]Z00?oodP0oookJ_oonfX02?oonfX01?l0ogcooo]ZoookJ_oo
nfX4o`0000Cooo]Z00?o00;ooookJ_oonfX01ooo:002ool000Cooo]Z00Cooi`0oookJ_oo003ooo]Z
0ooo00001?ooIP3oo`00ool00?l0o`0:oookJP?oobP02OoonfX00oooc@3ooo]ZoookJP07ool000;o
oo]Z00?oU@3ooookJ_oonfX00ooonfX00oooL`3ooo]ZoookJP09oookJQ7oobP00_l02?l4oookJQ3o
o`002_oonfX4ool000koobP00ol0oed=oookJPooobP01?l02?l?oookJPCo0?oC0_oonfX4oomi04_o
oo]Z00?oo`3>oookJ_oonfX01?oonfX2o`0Go`03o`3Uoooonf[o0?oQ00Gooo]Z00?oob`0oookJ_lB
o`000_oonfX2o`0]o`Oooo]Z00?o0?gooookJ_oonfX01OoonfX01Ooo0:7ooo]ZoookJ_oonf[ooj00
00?ooo]Z00?oP`3oo`0goooonfX00_oonfX00ol02?oooo]Zoom30003oookJP03o`3boooonf[ooo]Z
00Cooo]Z00So0?ncoookJ_oonf[ooo]Zo`3Eoooonf[oo`0[o`3o]P[ooo]Z00?o`03ooookJ_oonfX0
0ooonfX00ooo0:?ooo]ZoookJP02oookJP03ool0QOoonf[ooo]Z00Kooo]Z00Co2_l0oookJ_oonf[o
og/00ooonfX01Oo5o`3ooo]ZoookJ_oonf[ooh`000Kooo]Z00?oYOl0oookJ_oonfX01_oonfX00ono
o`3ooo]ZoookJP04oookJP03ool0>ooonf[ooo]Z00;ooo]Z00Co0?mjoookJ_oonf[o097o0_oonfX0
0ooo0<kooo]ZoookJP08oookJP05o`2<oooonf[oOP3ooookJ_oo2P002OoonfX01Ooo0?cooo]Zoook
J_oonf[oom<000?ooo]Z00?o0?nIoookJ_oonfX02_oonfX00oooB03ooo]ZoookJP09oookJP03o`3o
O?oonf[ooo]Z00Co00001OoonfX00ol00_oooo]ZoookJP02oookJP05oml0oomFo`3o01[oo`0]oooe
o`001_oonfX00oooW03ooo]Zoe/0o`03oookJP04oomV0?oonf[ooo]Zo`3o00_ooo]Z00?ooc40oook
J_oonfX02?oonfX00oooc@3ooo]ZoookJP09oookJP03oiD0oooonf[ooo]Z00?ooo]Z00?oog<0oook
J_oonfX03ooonfX2o`19o`?o0?oC1OoonfX4o`08o`cooo]Z1Ol0oedGoookJP_o0?mM4ooonfX6o`3o
I`03oookJ_l02?oo00So00Co00So3_oonfX4o`3od`Cooo]Z0ol0BOlToookJP00<?oonfX01Ol05ooo
0>Goo`3oS?oonf[o0?oQ00Cooo]Z00Coob`0oookJ_oonf[o4_l00_oonfX00ol0;Ooooo]ZoookJP05
oookJP03o`3mool0ojkooo]Z00Gooo]Z00Goo`2QoookJ_oonf[ooo]ZoonP0003oookJP03oolX0?l0
=oooobP000;ooo]Z00CoobP0ooo90?ooN@3ood<00ooonfX00ol0l_oooo]ZoookJP04oookJP08o`3o
/ooonf[ooo]ZoookJ_l0eOooo`0[oookJ_l0okH5oookJPKoogT01?oonfX2ool0X`Cooo]Z00?oo`25
oookJ_oonfX01?oonfX3oolX00;ooo]Z00Coog/0oookJ_oonf[oaOl01?oonfX00ooo:03ooo]Zoook
JP04oookJP03o`3o9?nUo`3ooo]Z00Kooo]Z00?oo`00oookJ_oonfX00_oonfX6oolX0005oookJ_l0
og[ooo]Zo`2AoooonfX00_oo:0000ooo0<koobP0oolX0002oolX00Kooo]Z00Go08coogh0oooonf[o
oo]Zool:0009oookJP05ool0o?oonf[ooo]ZoookJ_ood`001?oo:00<oookJP03oom80?oonf[ooo]Z
00Sooo]Z00?o0?mloookJ_oonfX00_oonfX4o`0000Cooo]Z00?o00;ooookJ_oonfX01_oo:0000ooo
003omOl0oookJP03oookJP03ool00?ooW03oo`0000Goo`0000CoofH0ool00?oo003o0?l02ooonfX2
oolX00Wooo]Z00?oold0ool0^_oo00001ooo0003oookJP03oiD0oooonf[ooo]Z00?ooo]Z0_ooL`09
oookJP[oobP00_l0om<7oomi00?o00So00?ooo]Zool00?oo00003ooo0009o`3oG@Woo`001ooo:00B
oookJPcoobP000?o00SooookJ_oonfX03ooonfX4o`3od`?ooo]Z1oooN@1AoookJP05o`0Gool0iOoo
0>GooookJ_l0on401OoonfX00ooo;03ooo]Zoa;o0002oookJP03o`0]oooonf[ooo]Z00Kooo]Z00?o
0?gooookJ_oonfX01OoonfX01Ooo0:7ooo]ZoookJ_oonf[ooj0000?ooo]Z00?oP`3oo`0goooonfX0
0_oonfX00ol02?ooolT0oom30003oookJP03o`3boooonf[ooo]Z00Cooo]Z00So0?ncoookJ_oonf[o
oo]Zo`3Eoooonf[oo`0[o`3o]P[ooo]Z00?o`03ooookJ_oonfX00ooonfX00ooo0:?ooo]ZoookJP02
oookJP03ool0QOoonf[ooo]Z00Kooo]Z00Co2_l0oookJ_oonf[oog/00ooonfX01Oo5o`3ooo]Zoook
J_oonf[ooh`000Kooo]Z00?o0?lTojGo0?oonfX01_oonfX00onoo`3ooo]ZoookJP05oookJP03ool0
>ooonf[ooo]Z00;ooo]Z00?o0?mjoookJ_l0TOl00_oonfX00ooo0<kooo]ZoookJP09oookJP04o`2<
oomn0?oooo]Zool:00[ooo]Z00Coo`3loookJ_oonf[oom<00ooonfX00ol0oiWooo]ZoookJP0:oook
JP03oom80?oonf[ooo]Z00Wooo]Z00Co0?mloookJ_oonf[ooo]Z1?l00004oookJP03o`02oooonf[o
oo]Z00?ooo]Z00Gog`3ooeKo0?oonf[o02goooGo0005oookJP04oonL0?oonf[ooo]Zoe/0o`?ooo]Z
00CoofH0oookJ_oonf[o0?l03?oonfX00ooo<@3ooo]ZoookJP07oookJP03ooo=0?oo0;[ooo]Z00[o
oo]Z00?oU@3ooookJ_oonfX00ooonfX2oomc01;ooo]Z0_l0BOl3o`3od`Kooo]Z0ol02?l>oookJQOo
0?mM6?oonfX6o`3oI`Oo00So4?oonfX4o`3od`Cooo]Z1?l0BOlWoookJP00;ooonfX00ol05ooo0>Go
oookJP02o`3oh@Cooo]Z00Coob`0oookJ_oonf[o4_l00_oonfX00ol0;Ooooo]ZoookJP05oookJP03
o`3mool0ojkooo]Z00Gooo]Z00Goo`2QoookJ_oonf[ooo]ZoonP0002oookJP03oh<0oooo:03o03Oo
00CoobP000?oolT0oookJ_oo@`000ooonfX00ol0l_oooo]ZoookJP04oookJP08o`3o/ooonf[ooo]Z
oookJ_l0eOooo`0[oookJ_l0okH6oookJPKoogT00ooonfX00ooo0:?ooo]ZoookJP03oookJP03ool0
QOoonf[ooo]Z00Cooo]Z0ooo:002oookJP04oomk0?oonf[ooo]ZolGo00Cooo]Z00?oobP0oookJ_oo
nfX01?oonfX00ol0obCoYOl0oookJP06oookJP03ool00?oonf[ooo]Z00;ooo]Z1_oo:002oookJP03
o`3oN_oonf[o097o00;oobP000?oo`3>oolX0?oo:0000_oo:006oookJP05o`2<oomn0?oooo]Zoook
J_oo2P002OoonfX01Ooo0?cooo]ZoookJ_oonf[oom<000KoobP02ooonfX00oooB03ooo]ZoookJP08
oookJP03o`3oO?oonf[ooo]Z00;ooo]Z1?l00003oookJP04o`02oooonf[ooo]ZoookJPKoobP000?o
o`00ooGo0?oonfX00ooonfX00ooo003ooi`0ool00005ool00004oomV0?oo003oo`00o`3o00cooo]Z
00?oobP0oookJ_oonfX02?oonfX00oooc@3ooo]ZoookJP07ool000?ooo]Z00?oU@3ooookJ_oonfX0
1?oonfX00oooL`3ooo]ZoookJP05oookJPgoobP02_ooN@03o`08o`[oo`003_oonfX>ool000Wooo]Z
2?l0ofL3oolX0003oookJ_oo:03oobP000OoobP03ooonfX5o`3od`;ooo]Z1OooN@03oookJPCoogT0
D?oonfX00ol05ooo0>GooookJP02o`3oh@Gooo]Z00?oob`0oookJ_lBo`000_oonfX00ol0;Ooooo]Z
oookJP05oookJP03o`3o[_l0oOoooo]Z00Kooo]Z00Goo`2QoookJ_oonf[ooo]ZoonP0002oookJP;o
P`3o00?o03OooookJ_oonfX00_l02?l00ooob@3ood<0oookJP02oookJP03o`3boooonf[ooo]Z00Co
oo]Z00So0?ncoookJ_oonf[ooo]Zo`3Eoooonf[oo`0[o`3o]P[ooo]Z00?o`03ooookJ_oonfX00ooo
nfX00ooo0:?ooo]ZoookJP02oookJP03ool0QOoonf[ooo]Z00Kooo]Z00Co2_l0oookJ_oonf[oog/0
0ooonfX01Oo5o`3ooo]ZoookJ_oonf[ooh`000Kooo]Z00?o0?lTojGo0?oonfX01_oonfX00onoo`3o
oo]ZoookJP05oookJP03ool0>ooonf[ooo]Z00;ooo]Z00Ko0?mjoookJ_oonf[o097ooookJ_oo0<h;
oookJP04o`2<oomn0?oooo]Zool:00[ooo]Z00Coo`3loookJ_oonf[oom<01?oonfX00ol0oiWooo]Z
oookJP0:oookJP03oom80?oonf[ooo]Z00Wooo]Z00Co0?mloookJ_oonf[ooo]Z1?l00004oookJP03
o`02oooonf[ooo]Z00;ooo]Z00Kog`3ooeKo0?l06_oo02gooookJ_oeo`05oookJP04oonL0?oonf[o
oo]Zoe/0o`?ooo]Z00CoofH0oookJ_oonf[o0?l03?oonfX00ooo<@3ooo]ZoookJP08oookJP03ooo=
0?oonf[ooo]Z00[ooo]Z00?oU@3ooookJ_oonfX01?oonfX00oooL`3ooo]ZoookJP0BoookJP;o04Wo
0ol0om<6oookJP?o00So;ooonfX;o`3oI`Ko00So4_oonfX5o`3od`Cooo]Z1?l0BOl[oookJP00;_oo
nfX01?l05ooo0>GooookJ_l0on45oookJP04ool/0?oonf[ooo]Zoa;o00;ooo]Z00?o02gooookJ_oo
nfX01OoonfX00ol0oOoooo]ZoookJP05oookJP05ool0XOoonf[ooo]ZoookJ_ooX0000_oonfX00on3
0?oooo]Zo`0go`04oolX0003ooo90?oonf[ood<000?ooo]Z00?o0?;ooookJ_oonfX01?oonfX00ol0
ok?ooo]ZoookJP02o`3Eo`03ool0:ooonf[o0?nf00Kooo]Z2?ooN@000ooonf[oo`2SoookJP04oook
JP03ool0QOoonf[ooo]Z00Cooo]Z0ooo:002oookJP04oomk0?oonf[oobP0oolX00Cooo]Z00?oobP0
oookJ_oonfX01OoonfX00onUo`3ooo]ZoookJP02ool000?ooo]Z00?oo`00oookJ_oonfX00ooonfX4
oolX00?ooo]Z00Ko0?mjoookJ_l0TOoooo]ZoolX0?oo0<h4oolX00Kooo]Z00Go08cooookJ_mn0?oo
oo]Zool:000:oookJP05ool0o?oonf[ooo]ZoookJ_ood`001ooo:005oookJP?o001o00?ooo]Zoom8
0?oonfX00_oonfX5o`00O`;ooo]Z00?o0?mloookJ_oonfX00ooonfX4o`0000?ooo]Z00Co00;ooook
J_oonf[ooo]Z1Ooo:0000ooo003omOl0oookJP04oookJP03ool00?ooW03oo`0000Goo`0000CoofH0
ool00?oo003o0?l03?oonfX00ooo<@3ooo]ZoookJP08oookJP04ooo=0?oo0;[ooo]ZoookJPKoo`00
1?oonfX00onE0?oooo]ZoookJP04oookJP;oog<03_oonfX3oolX00googT000?oo`00o`08ool02?l0
1_l02?l@oookJQ3oo`001ol0ofL5oookJPOo00So1_oo:00>oookJPCo0?oC0ooonfX3o`19o`;oogT0
2?oonfX3oomi04oooo]Z00Co01Ooo`3Uoooonf[o0?oQ1_oonfX00ooo;03ooo]Zoa;o0002oookJP03
o`0]oooonf[ooo]Z00Gooo]Z00?o0?n^o`3moooonfX01_oonfX01Ooo0:7ooo]ZoookJ_oonf[ooj00
00;ooo]Z00?oP`3ooookJ_l0=ol00_oonfX01?l02?oooo]Zooo90?oo@`03oookJP03o`3boooonf[o
oo]Z00Cooo]Z00So0?ncoookJ_oonf[ooo]Zo`3Eoooonf[oo`0[o`3o]P[ooo]Z00?o`03ooookJ_oo
nfX00ooonfX00ooo0:?ooo]ZoookJP02oookJP03ool0QOoonf[ooo]Z00Kooo]Z00Co2_l0oookJ_oo
nf[oog/00ooonfX01Oo5o`3ooo]ZoookJ_oonf[ooh`000Oooo]Z00?oYOl0oookJ_oonfX01OoonfX0
0onoo`3ooo]ZoookJP05oookJP03ool0>ooonf[ooo]Z00;ooo]Z00Oo0?mjoookJ_oonf[o097ooook
J_oo0<ko0?oR00[ooo]Z00Go08cooookJ_mn0?oooo]Zool:0009oookJP05ool0o?oonf[ooo]Zoook
J_ood`000ooonfX00ol0oiWooo]ZoookJP06oookJP?o001o00?ooo]Zoom80?oonfX00_oonfX5o`00
O`?ooo]Z00?o0?mloookJ_oonfX00_oonfX4o`0000Cooo]Z00?o00;ooookJ_oonfX00_oonfX01OoO
0?ooE_l0o`0Jool0;OoomOl000Kooo]Z00Cooi`0oookJ_oonf[oF`3o0ooonfX01?ooIP3ooo]Zoook
J_l0o`0<oookJP03oola0?oonf[ooo]Z00Wooo]Z00?oold0oookJ_oonfX02_oonfX00onE0?oooo]Z
oookJP04oookJP;oog<05OoonfX2o`19o`?o0?oC1_oonfX8o`08oa3ooo]Z5ol0ofL4oookJPOo00So
5?oonfX4o`3od`Cooo]Z1Ol0BOl_oookJP00;OoonfX01?l05ooo0>GooookJ_l0on45oookJP04ool/
0?oonf[ooo]Zoa;o00;ooo]Z00?o02gooookJ_oonfX01OoonfX00ol0oOoooo]ZoookJP05oookJP05
ool0XOoonf[ooo]ZoookJ_ooX0000_oonfX00on30?oooo]Zo`0go`04oolX0003ooo90?oo:03ood<0
00?ooo]Z00?o0?;ooookJ_oonfX01?oonfX02?l0ok?ooo]ZoookJ_l0eOoooo]Zool0:ooonf[o0?nf
1ooonfX9oomi00Gooo]Z00?oo`25oookJ_oonfX01OoonfX01Ooo:03ooo]ZoookJ_oonf[oog/000;o
oo]Z0ooo:002oookJP03oolX0?oonf[ooo]Z00Gooo]Z00CoYOl0oookJ_oonf[ooo]Z0ooo00000ooo
nf[oo`00oookJP04oookJPCoobP00ooonfX01_l0og[ooo]Zo`2Aoooonf[oobP0ool0cP?oobP02?oo
nfX01?l0S?ooOP3ooookJ_oo2P0:oookJP05ool0o?oonf[ooo]ZoookJ_ood`002?oo:005oookJP?o
001o00Cooo]Zoom80?oonf[ooo]Z1ol007l00ooonf[o0?mloookJP04oookJPCo00000ooonfX01?l0
0_oooo]ZoookJ_oonfX7oolX00Gooo]Z00?oobP0oonL0?oo00001?oo0009oomi00Sooo]Z00?ooc40
oookJ_oonfX02OoonfX00oooc@3oo`2joookJP02ooo900Goo`001?oonfX00onE0?oooo]ZoookJP05
oookJP03oomc0?oonf[ooo]Z00kooo]Z3oooN@07oookJPco00So1?oonfX=ool000Kooo]Z2Ol02?l7
oookJPCoobP03?oonfX4o`3od`Oo04Wo3OoonfX00oooN@3ooo]ZoookJP1>oookJP04o`0Gool0iOoo
oo]Zo`3oh@Gooo]Z0_oo;0001Ooonf[o4_l0oookJ_oonf[o02go00Oooo]Z00?o0?n^o`3moooonfX0
1_oonfX01Ooo0:7ooo]ZoookJ_oonf[ooj0000;ooo]Z00?oP`3ooookJ_l0=ol00_oonfX01?l02?oo
oo]Zooo90?oo@`03oookJP03o`3boooonf[ooo]Z00Cooo]Z00So0?ncoookJ_oonf[ooo]Zo`3Eoooo
nf[oo`0[o`3o]P[ooo]Z00?o`03ooookJ_oonfX00ooonfX00ooo0:?ooo]ZoookJP02oookJP03ool0
QOoonf[ooo]Z00Kooo]Z00Co2_l0oookJ_oonf[oog/00ooonfX01Oo5o`3ooo]ZoookJ_oonf[ooh`0
00Oooo]Z00?oYOl0oookJ_oonfX01OoonfX00onoo`3ooo]ZoookJP05oookJP03ool0>ooonf[ooo]Z
00;ooo]Z00Oo0?mjoookJ_oonf[o097ooookJ_oo0<ko0?oR00[ooo]Z00Go08cooookJ_mn0?oooo]Z
ool:000:oookJP04ool0o?oonf[ooo]ZoooC00?ooo]Z00?o0?nIoookJ_oonfX01ooonfX3o`00O`04
oookJ_ooB03ooo]ZoookJPOo001o0_oonfX00ol0ogcooo]ZoookJP02oookJPCo00000ooonfX00ol0
0_oooo]ZoookJP03oookJP05oml0oomFo`3o01[oo`0]oooeo`001_oonfX01?ooW03ooo]ZoookJ_mK
0?l3oookJP04oomV0?oonf[ooo]Zo`3o00cooo]Z00?ooc40oookJ_oonfX02OoonfX00oooc@3oo`2j
oookJP05oookJP03o`2goooonf[ooo]Z00?ooo]Z00?oU@3ooookJ_oonfX01OoonfX00oooL`3ooo]Z
oookJP0EoookJP;o04Wo1Ol0om<9oookJPco00So5ooonfX8o`08oaOooo]Z1?l0om<00ooonf[o04Wo
o`19o`05o`19ocCooo]Z000/oookJP04o`0Gool0iOoooo]Zo`3oh@Gooo]Z00Coob`0oookJ_oonf[o
4_l00_oonfX00ol0;Ooooo]ZoookJP05oookJP03o`3moooonf[ooo]Z00Gooo]Z00Goo`2QoookJ_oo
nf[ooo]ZoonP0002oookJP03oh<0oooonf[o03Oo00CoobP000?oolT0oolX0?oo@`000_oo:0000ooo
nf[o0?;ooookJP05oookJP08o`3o/ooonf[ooo]Zo`3Eoooonf[oo`0[oookJ_l0okH7oookJPSoogT0
00?oo`2SoookJ_oonfX00ooonfX00ooo:03ooo]ZoookJP05oookJP05oolX0?oonf[ooo]ZoookJ_oo
N`000_oonfX6oolX00Oooo]Z00CoYOl0oookJ_oonf[ooo]Z1Ooo0006oookJP?oobP00ooonfX00ol0
og[ooo]Zo`2Ao`02oookJP04oolX0?oo0<koobP0oolX00Sooo]Z00Go08coogh0oooonf[ooo]Zool:
0009oookJP06ool0o?oonf[ooo]ZoookJ_ood`3ooo]Z1ooo:006oookJP?o001o00CoodP0oookJ_oo
nf[ooo]Z0ol007l01_oonf[o001oo`00Ool007oooo]Zo`3oO0Gooo]Z1?l00003oookJP04o`02oooo
nf[ooo]ZoookJP_oobP000?ooo]ZoolX0?ooW0001Ooo0009oomi00Wooo]Z00?ooc40oookJ_oonfX0
2?oonfX00oooc@3oo`2jooo90004ooo900?oo`001OoonfX00onE0?oooo]ZoookJP05oookJP03oomc
0?oonf[ooo]Z00gooo]Z4?ooN@03o`3od`oooo]Z1?l02?l9ool000[o00So4?oonfX00ooo:03ooo]Z
oookJP07oookJPKo0?oC1?l0BOmToookJP04o`0Gool0iOoooo]Zo`3oh@Gooo]Z00Coob`0oookJ_oo
nf[o4_l00_oonfX00ol0;Ooooo]ZoookJP05oookJP03o`3o[_l0oOoooo]Z00Kooo]Z00Goo`2Qoook
J_oonf[ooo]ZoonP0002oookJP03oh<0oooonf[o03Oo00;ooo]Z00Co00SooookJ_oob@3ood<00ooo
nfX00ol0l_oooo]ZoookJP04oookJP08o`3o/ooonf[ooo]ZoookJ_l0eOoooo]Zool0:ol0okH:oook
JP03ol00oooonf[ooo]Z00?ooo]Z00?oo`2SoookJ_oonfX00_oonfX00ooo08Gooo]ZoookJP06oook
JP04o`[o0?oonf[ooo]Zoomk00?ooo]Z00GoaOl0oookJ_oonf[ooo]Zoon<0007oookJP03ojGo0?oo
nf[ooo]Z00Gooo]Z00?o_ol0oookJ_oonfX01_oonfX01Ooo03_ooo]ZoookJ_oonf[o0?mj00;ooo]Z
00Co097ooookJ_oonf[oo`3>2ooonfX01?l0S?ooOP3ooookJ_oo2P0:oookJP04ool0o?oonf[ooo]Z
oooC00Cooo]Z00?o0?nIoookJ_oonfX01ooonfX3o`00O`04oom80?oonf[ooo]ZoookJP?o001o00Co
oo]Zo`00Ool007oo001o0_oonfX00ol0ogcooo]ZoookJP02oookJPCo00000ooonfX00ol00_oooo]Z
oookJP03oookJP05oml0oomFo`3ooo]Zo`0]oooeo`001_oonfX01?ooW03ooo]ZoookJ_mK0?l3oook
JP04oomV0?oonf[ooo]Zo`3o00gooo]Z00?ooc40oookJ_oonfX02OoonfX00oooc@3ooo]ZoookJP04
oookJP03o`2goooonf[ooo]Z00Cooo]Z00?oU@3ooookJ_oonfX01OoonfX2oomc01Sooo]Z0ol0BOl0
0ooonf[o0?oCo`3od`03o`3oda3ooo]Z5ol02?lIoookJPKo0?oC1Ol0BOlkoookJP00:ooonfX01?l0
5ooo0>GooookJ_l0on44oookJP;oob`00_oonfX01?lBo`3ooo]ZoookJ_l0;Ol6oookJP;o0?go1ooo
nfX01Ooo0:7ooo]ZoookJ_oonf[ooj0000;ooo]Z00CoP`3ooookJ_l0=ooooo]Z0ooo:0001?oob@3o
obP0oom30?oo:002oookJP03o`3boooonf[ooo]Z00Cooo]Z00So0?ncoookJ_oonf[o0=GooookJ_oo
02_ooo]Zo`3o]POooo]Z2?ooN@000ooo0:?ooo]ZoookJP03oookJP03oolX0?oonf[ooo]Z00Kooo]Z
00Co2_l0oookJ_oonf[oog/00ooonfX6oolX00Kooo]Z00?oYOl0oookJ_oonfX00_oonfX6ool000Co
oo]Z0_oo:005oookJP06o`3oN_l0TOoooo]ZoookJ_oo:03oo`3>0_oo:008oookJP05o`2<oomn0?oo
oo]ZoookJ_oo2P002_oonfX01Ooo0?cooo]ZoookJ_oonf[oom<000OoobP01ooonfX3o`00O`03oom8
0?oonf[ooo]Z00?o001o0ooonfX2o`00O`03o`3oO?oonf[ooo]Z00Cooo]Z1?l00003oookJP04o`02
oooonf[ooo]ZoookJP_oobP000?ooo]ZoolX0?ooW0001Ooo0009oomi00Wooo]Z00?ooc40oookJ_oo
nfX02?oonfX7ooo900Coo`001OoonfX00onE0?oooo]ZoookJP05oookJP03oomc0?oonf[ooo]Z00co
oo]Z2?ooN@05oookJPCo04Wo0_oonfX5o`3od`kooo]Z1_oo000NoookJPWo0?oC0ol0BOmZoookJP04
o`0Gool0iOoooo]Zo`3oh@Gooo]Z00Coob`0oookJ_oonf[o4_l00_oonfX00ol0;Ooooo]ZoookJP05
oookJP;o0?go1_oonfX2ool0X@?ooo]Z00Kooj00oookJ_oonf[oP`3ooookJ_l0=ol2oookJP04o`08
oooonf[oolT0oom300?ooo]Z00?o0?;ooookJ_oonfX01?oonfX02?l0ok?ooo]ZoookJ_oonf[o0=Go
oookJ_oo02_o0?nf2_oonfX00oo00?oooo]ZoookJP03oookJP03ool0Xooonf[ooo]Z00?ooo]Z00?o
o`25oookJ_oonfX01_oonfX00ol:o`3ooo]Zoomk0003oookJP05olGo0?oonf[ooo]ZoookJ_ooS000
1ooonfX00onUo`3ooo]ZoookJP06oookJP03okoo0?oonf[ooo]Z00Gooo]Z00?oo`0koookJ_oonfX0
0_oonfX00ol0og[ooo]Zo`2Ao`02oookJP03ool0c_l0on;ooo]Z00Wooo]Z00Go08coogh0oooonf[o
oo]Zool:000:oookJP04ool0o?oonf[ooo]ZoooC00?ooo]Z00?o0?nIoookJ_oonfX02?oonfX3o`00
O`03oom80?oonf[ooo]Z00?o001o0ooonfX3o`00O`03o`3oO?oonf[ooo]Z00?ooo]Z1?l00003oook
JP03o`02oooonf[ooo]Z00?ooo]Z00Gog`3oo`0Joooonf[o02goooGo0006oookJP03oonL0?oonf[o
F`3o00Cooo]Z00CoofH0oookJ_oonf[o0?l03OoonfX00ooo<@3ooo]ZoookJP0:oookJP03ooo=0?oo
nf[ooo]Z00Cooo]Z00?o0;OooookJ_oonfX01?oonfX00onE0?oooo]ZoookJP06oookJP03oomc0?oo
nf[ooo]Z01Sooo]Z1Ol0BOl00ooonf[o0?oCo`3od`03o`3odc;ooo]Z2Ol0om<4o`19od;ooo]Z000Z
oookJP04o`0Gool0iOoooo]Zo`3oh@Cooo]Z00Goob`0oookJ_oonf[ooo]Zoa;o0002oookJP03o`0]
oooonf[ooo]Z00Cooo]Z00?o0?goo`3o[_oonfX01_oonfX01Ooo0:7ooo]ZoookJ_oonf[ooj0000;o
oo]Z00CoP`3ooookJ_l0=ooooo]Z0ooo:0001?oob@3oobP0oom30?oo:002oookJP03o`3boooonf[o
oo]Z00Cooo]Z00So0?ncoookJ_oonf[o0=GooookJ_oo02_ooo]Zo`3o]PSooo]Z1_ooN@000ooonf[o
o`2SoookJP04oookJP03oolX0?oonf[ooo]Z00Kooo]Z00Co2_l0oookJ_oonf[oog/00ooonfX8oolX
00Cooo]Z00?oYOl0oookJ_oonfX00_oonfX8ool000?ooo]Z00?oobP0oookJ_oonfX00ooonfX00ol0
og[ooo]Zo`2Ao`02oookJP03ool0c_oo:03ooo]Z00Wooo]Z00Co08coogh0oooonf[oo`X02_oonfX0
1_oo0?cooo]ZoookJ_oonf[oom<0oookJPKoobP02?oonfX2o`00O`04oom80?oonf[ooo]ZoookJP?o
001o0ooonfX2o`00O`03o`3oO?oonf[ooo]Z00Cooo]Z1_l000001Ol00_oooo]ZoookJ_oonf[oogT0
00[oobP00_oonfX00ooo:03ooi`0ool00005ool000OoogT02_oonfX00ooo<@3ooo]ZoookJP07oook
JPWoolT00ooo0006oookJP03oiD0oooonf[ooo]Z00Gooo]Z00?oog<0oookJ_oonfX07?oonfX5o`19
o`;ooo]Z2_l0om<4oookJP;oo`005OoonfX=o`3od`Ko04WoKooonfX01?l05ooo0>GooookJ_l0on45
oookJP04ool/0?oonf[ooo]Zoa;o00;ooo]Z00?o02gooookJ_oonfX01OoonfX00ol0oOoooo]Zoook
JP05oookJP03ool0XOoonf[ooo]Z00;ooo]Z00Kooj00oookJ_oonf[oP`3ooookJ_l0=ol2oookJP04
o`08oooonf[oolT0oom300?ooo]Z00?o0?;ooookJ_oonfX01?oonfX02?l0ok?ooo]ZoookJ_oonf[o
0=GooookJ_oo02_o0?nf2_oonfX00oo00?oooo]ZoookJP03oookJP03ool0Xooonf[ooo]Z00?ooo]Z
00?oo`25oookJ_oonfX01_oonfX00ol:o`3ooo]Zoomk0003oookJP05olGo0?oonf[ooo]ZoookJ_oo
S0001ooonfX00ol0obCoYOl0oookJP06oookJP03okoo0?oonf[ooo]Z00Gooo]Z00?oo`0koookJ_oo
nfX00_oonfX01ol0og[ooo]ZoookJ_l0TOoooo]Zool0c_l0on802_oonfX01Ol0S?oooo]Zogh0oooo
nf[oo`X000[ooo]Z00Coo`3loookJ_oonf[oom<01?oonfX00ol0oiWooo]ZoookJP08oookJP;o001o
00CoodP0oookJ_oonf[ooo]Z0ol007l3oookJP?o001o00?o0?mloookJ_oonfX00ooonfX6o`000003
o`02oooonf[ooo]Z00?ooo]Z00Kog`3ooeKo0?l06_oo02gooookJ_oeo`06oookJP04oonL0?oonf[o
F`3oo`2Io`?ooo]Z00CoofH0oookJ_oonf[o0?l03OoonfX00ooo<@3ooo]ZoookJP0:oookJP03ooo=
0?oo0;[ooo]Z00Gooo]Z00?o0;OooookJ_oonfX01?oonfX00onE0?oooo]ZoookJP06oookJP03oomc
0?oonf[ooo]Z01cooo]Z1Ol0BOl00ooonf[o0?oCo`3od`08o`3oda_ooo]Z3Ol0om<00ooonf[o04Wo
o`19o`04o`19odSooo]Z000ZoookJP03o`3Uoooonf[o0?oQ00Cooo]Z00?oob`0oookJ_oonfX00_lB
o`02oookJP03o`0]oooonf[ooo]Z00Cooo]Z00?o0?goo`3o[_oonfX01_oonfX01Ooo0:7ooo]Zoook
J_oonf[ooj0000;ooo]Z00CoP`3ooookJ_l0=ooooo]Z0ooo:0000ooob@3oobP0oom30003oookJP03
o`3boooonf[ooo]Z00Cooo]Z00So0?ncoookJ_oonf[o0=GooookJ_oo02_ooo]Zo`3o]PSooo]Z1Ooo
N@02oookJP03ool0Xooonf[ooo]Z00?ooo]Z00?oobP0oookJ_oonfX01_oonfX01?l:o`3ooo]Zoook
J_ooN`03oookJP03olGo0?oo:03oobP000OoobP00_oonfX00onUo`3ooo]ZoookJP03oookJPWoo`00
00?ooo]ZoolX0?oonfX01?oonfX00ol0og[ooo]Zo`2Ao`02oookJP03ool0c_oo:03ooo]Z00Wooo]Z
00Co08coogh0oooonf[oo`X01_oonfX2oolX00;ooo]Z00GoobP0oookJ_oonf[ooo]ZoooC0002oook
JPGoobP02OoonfX2o`00O`04oom80?oonf[ooo]ZoookJP?o001o0ooonfX00ol007oo0?mlo`00O`06
oookJPCo00000_oonfX01Ol00_oooo]ZoookJ_oonf[oogT000[oobP00_oonfX00ooo:03ooi`0ool0
0003ool00003oolX0?oo003oogT000KoogT02ooonfX00ooo<@3ooo]ZoookJP05oookJP[oolT00_oo
nfX2ool000?ooo]Z00?oobP0oookJ_oonfX00_nE0?l6oookJP;oog<08OoonfX9o`19o`?ooo]Z6ol0
om<8oookJPGo04WoMOoonfX00ol0iOoooo]Zo`3oh@05oookJP04ool/0?oonf[o4_l0oa;o00;ooo]Z
00?o02gooookJ_oonfX01OoonfX00ol0oOoooo]ZoookJP05oookJP03ool0XOoonf[ooo]Z00;ooo]Z
00Kooj00oookJ_oonf[oP`3ooookJ_l0=ol2oookJP04o`08oooonf[oolT0oom300?ooo]Z00?o0?;o
oookJ_oonfX01?oonfX02?l0ok?ooo]ZoookJ_oonf[o0=GooookJ_oo02_o0?nf2_oonfX00oo00?oo
oo]ZoookJP03oookJP03ool0Xooonf[ooo]Z00?ooo]Z00?oo`25oookJ_oonfX01_oonfX00ol:o`3o
oo]Zoomk0003oookJP03olGo0?oonf[ooo]Z00;ooo]Z00?ooh`0oookJ_oonfX01?oonfX00ol0obCo
YOl0oookJP06oookJP03okoo0?oonf[ooo]Z00Gooo]Z00?oo`0koookJ_oonfX00_oonfX01?l0og[o
oo]ZoookJ_l0TOl2oookJP03ool0c_oonf[ooo]Z00Sooo]Z00Go08cooookJ_mn0?oooo]Zool:000:
oookJP05ool0o?oonf[ooo]ZoookJ_ood`000ooonfX00ol0oiWooo]ZoookJP09oookJP;o001o00Co
odP0oookJ_oonf[ooo]Z0ol007l3oookJP;o001o00?o0?mloookJ_oonfX01?oonfX4o`0000;ooo]Z
00?o00;ooookJ_oonfX00ooonfX01OoO0?ooE_l0o`0Jool0;OoomOl000Oooo]Z00Cooi`0oookJ_mK
0?oo09Wo0ooonfX01?ooIP3ooo]ZoookJ_l0o`0>oookJP03oola0?oonf[ooo]Z00[ooo]Z00?oold0
oookJ_oonfX01OoonfX00ol0]ooooo]ZoookJP04oookJP;oU@3o1ooonfX2oomc027ooo]Z2Ol0BOl2
oookJQ_o0?oC2?oonfX6o`19odkooo]Z000[oookJP03o`3ohOoonf[ooo]Z00;ooo]Z00Coob`0oook
J_oonf[o4_l00_oonfX2o`0]o`Kooo]Z00?o0?goo`3o[_oonfX01_oonfX01Ooo0:7ooo]ZoookJ_oo
nf[ooj0000;ooo]Z00?oP`3ooookJ_l0=ol00_oonfX2oolX0003ooo90?oo:03ood<000?ooo]Z00?o
0?;ooookJ_oonfX01?oonfX02?l0ok?ooo]ZoookJ_l0eOoooo]Zool0:ooonf[o0?nf2OoonfX4oomi
00;ooo]Z00?oo`2SoookJ_oonfX00ooonfX00ooo:03ooo]ZoookJP06oookJP05o`[o0?oonf[ooo]Z
oookJ_ooN`000_oonfX00oo5o`3oobP0oolX0006oolX00?ooo]Z00?oYOl0oookJ_oonfX00ooonfX8
ool000?ooo]Z00?oo`0koookJ_oonfX00_oonfX00ol0og[ooo]Zo`2Ao`03oookJP03ool0c_oonf[o
oo]Z00Sooo]Z00Go08coogh0oooonf[ooo]Zool:0006oookJP?oobP000Gooo]ZoolX0?oonf[ooo]Z
oooC0002oookJPGoobP01ooonfX2oolX0004oookJ_l007ooodP0o`00O`?ooo]Z0ol007l3oookJP03
o`00Ool0ogco001o00Kooo]Z1?l00002oookJP05o`02oooonf[ooo]ZoookJ_ooN@002Ooo:003oook
JP03oonL0?oo:03oo`0000?oo`0000?oobP0ool00?ooN@001_ooN@0;oookJP03oola0?oonf[ooo]Z
00Oooo]Z2?oob@03oookJP05ool00?oonf[ooo]ZoookJ_oo:0001?oonfX00onE0?oooo]ZoookJP05
oookJP;oog<0:?oonfXVo`19og_ooo]Z00?o0?oQoookJ_oonfX00ooonfX00ooo;03ooo]Zoa;o0002
oookJP;o02go1ooonfX00ol0oOoooo]ZoookJP05oookJP03ool0XOoonf[ooo]Z00;ooo]Z00Kooj00
oookJ_oonf[oP`3ooookJ_l0=ol2oookJP04o`08oooonf[oolT0oom300?ooo]Z00?o0?;ooookJ_oo
nfX01?oonfX02?l0ok?ooo]ZoookJ_oonf[o0=GooookJ_oo02_o0?nf2_oonfX00oo00?oooo]Zoook
JP03oookJP03ool0Xooonf[ooo]Z00?ooo]Z00?oo`25oookJ_oonfX01_oonfX01?l:o`3ooo]Zoook
J_ooN`02oookJP03olGo0?oonf[ooo]Z00;ooo]Z00?ooh`0oookJ_oonfX01?oonfX00ol0obCoYOl0
oookJP06oookJP03okoo0?oonf[ooo]Z00Kooo]Z00Goo`0koookJ_oonf[ooo]Zo`3oNP02oookJP04
o`2Aoooonf[ooo]Zool0cP_ooo]Z00Go08coogh0oooonf[ooo]Zool:000:oookJP04ool0o?oonf[o
oo]ZoooC00?ooo]Z00?o0?nIoookJ_oonfX02_oonfX00ol007ooodP0o`00O`03oookJP?o001o0ooo
nfX2o`00O`03o`3oO?oonf[ooo]Z00Cooo]Z1?l00002oookJP03o`02oooonf[ooo]Z00?ooo]Z00Go
g`3ooeKo0?l06_oo02goooGo0006oookJP05oonL0?oonf[ooo]Zoe/0ool0VOl00ooonfX01?ooIP3o
oo]ZoookJ_l0o`0>oookJP03oola0?oonf[ooo]Z00_ooo]Z00?oold0oookJ_oonfX01OoonfX00ol0
]ooooo]ZoookJP05oookJP03oiD0oooonf[ooo]Z00Kooo]Z0_ooL`0XoookJRGo04WoE?oonfX002[o
oo]Z00?o0?oQoookJ_oonfX00_oonfX01?oo;03ooo]ZoookJ_lBo`02oookJP03o`0]oooonf[ooo]Z
00Gooo]Z00?o0?goo`3o[_oonfX01_oonfX01Ooo0:7ooo]ZoookJ_oonf[ooj0000;ooo]Z00?oP`3o
oookJ_l0=ol00_oonfX2oolX0003ooo90?oo:03ood<000?ooo]Z00?o0?;ooookJ_oonfX01?oonfX0
2?l0ok?ooo]ZoookJ_l0eOoooo]Zool0:ooonf[o0?nf2OoonfX3oomi00?ooo]Z00?oo`2SoookJ_oo
nfX00ooonfX00ooo:03ooo]ZoookJP06oookJP05o`[o0?oonf[ooo]ZoookJ_ooN`000_oonfX00oo5
o`3oobP0oolX0006oolX00?ooo]Z00?o0?lTojGo0?oonfX01?oonfX7ool000?ooo]Z00?oo`0koook
J_oonfX00_oonfX00ol0og[ooo]Zo`2Ao`03oookJP03ool0c_l0on;ooo]Z00Wooo]Z00Co08cooook
J_oonf[oo`X01_oonfX6oolX00;ooo]Z00?oom<0oookJ_oonfX01?oo:008oookJP?oobP000?o001o
oom80?l007l00ooonfX3o`00O`?ooo]Z00?o001oo`3oO?l007l01_oonfX4o`000003oookJ_l00_oo
oo]Z00?ooo]Z00?oogT0oolX0?oO0?l01ooo:003oookJP03oonL0?oo:03oo`0000?oo`000_oonfX7
oomi00_ooo]Z00?ooc40oookJ_oonfX01ooonfX9ooo900?ooo]Z00?oo`00oookJ_oo:0000_oo:004
oookJP03oiD0oooonf[ooo]Z00Kooo]Z0_ooL`36oookJP03o`3ohOoonf[ooo]Z00?ooo]Z00?oob`0
oookJ_lBo`000_oonfX00ol0;Ooooo]ZoookJP06oookJP03o`3moooonf[ooo]Z00Gooo]Z00?oo`2Q
oookJ_oonfX00_oonfX01_ooX03ooo]ZoookJ_n30?oooo]Zo`0go`;ooo]Z00Co00SooookJ_oob@3o
od<00ooonfX00ol0l_oooo]ZoookJP04oookJP08o`3o/ooonf[ooo]ZoookJ_l0eOoooo]Zool0:ol0
okH:oookJP03ol00oooonf[ooo]Z00?ooo]Z00?oo`2SoookJ_oonfX00ooonfX00ooo08Gooo]Zoook
JP06oookJP04o`[o0?oonf[ooo]Zoomk00;ooo]Z00?oaOl0oookJ_oonfX00_oonfX00oooS03ooo]Z
oookJP04oookJP03o`3o9?nUo`3ooo]Z00Kooo]Z00?o_ol0oookJ_oonfX01_oonfX01Ooo03_ooo]Z
oookJ_oonf[o0?mj00;ooo]Z00Go097ooookJ_oonf[oo`3>o`3ohP0:oookJP05o`2<oomn0?oooo]Z
oookJ_oo2P002_oonfX01?oo0?cooo]ZoookJ_ood`04oookJP03o`3oVOoonf[ooo]Z00[ooo]Z00?o
001ooom80?l007l00ooonfX3o`00O`?ooo]Z00?o001oo`3oO?l007l01_oonfX4o`0000;ooo]Z00?o
00;ooookJ_oonfX00ooonfX01OoO0?ooE_l0oookJ_l0;OoomOl000Kooo]Z00Gooi`0oookJ_oonf[o
F`3oo`2Io`03oookJP04oomV0?oonf[ooo]Zo`3o00kooo]Z00?ooc40oookJ_oonfX02ooonfX00ooo
c@3oo`2joookJP06oookJP03o`2goooonf[ooo]Z00Gooo]Z0_nE0?l8oookJP03oomc0?oonf[ooo]Z
09kooo]Z000^oookJP04ool/0?oonf[ooo]Zoa;o00;ooo]Z00?o02gooookJ_oonfX01OoonfX00ol0
oOoo0?n^oookJP06oookJP05ool0XOoonf[ooo]ZoookJ_ooX0000_oonfX00on30?oo03Ooo`0go`03
oookJP04oolX0?oob@3ooo]Zoom300?ooo]Z00?o0?;ooookJ_oonfX01?oonfX02?l0ok?ooo]Zoook
J_l0eOoooo]Zool0:ooonf[o0?nf2_oonfX00oooN@3ooo]ZoookJP02oookJP03ool0Xooonf[ooo]Z
00?ooo]Z00?oobP0oookJ_oonfX01_oonfX01Ol:o`3ooo]ZoookJ_oonf[oog/000;ooo]Z00?oaOl0
oookJ_oo:0001Ooo:004oookJP03o`3o9?nUo`3ooo]Z00Cooo]Z1_oo0004oookJP03ool0>ooonf[o
oo]Z00;ooo]Z00?o0?mjoookJ_l0TOl00ooonfX00ooo0<ko0?oRoookJP09oookJP04o`2<oomn0?oo
oo]Zool:00Oooo]Z1ooo:0001?ood`3ooo]ZoookJ_oonfX3oolX00Wooo]Z1Ooo:0001?l007oooo]Z
oookJ_oonfX3o`00O`?ooo]Z00?o0?mlo`00Ool007l01_oonfX4o`000003oookJ_l00_oooo]Z00?o
oo]Z00?oogT0oolX0?oO0?l01_oo:004oookJP03oonL0?oo:03oo`0000;oo`0000CoobP0oookJ_oo
nf[oofH01OooN@0<oookJP03oola0?oonf[ooo]Z00Wooo]Z1ooob@04oookJPGoobP01?oonfX00onE
0?oooo]ZoookJP07oookJP;oog<0bOoonfX00ooo;03ooo]Zoa;o0002oookJP03o`0]oooonf[ooo]Z
00Kooo]Z00?o0?gooookJ_oonfX01OoonfX00ooo0:7ooo]ZoookJP02oookJP04oonP0?oonf[ooo]Z
oh<0o`;o03Oo0_oonfX01?l02?oooo]Zooo90?oo@`03oookJP03o`3boooonf[ooo]Z00Cooo]Z00So
0?ncoookJ_oonf[ooo]Zo`3Eoooonf[oo`0[o`3o]P[ooo]Z00?o`03ooookJ_oonfX00ooonfX00ooo
0:?ooo]ZoookJP03oookJP03ool0QOoonf[ooo]Z00Kooo]Z00Co2_l0oookJ_oonf[oog/00_oonfX0
0oo5o`3ooo]ZoookJP02oookJP03oon<0?oonf[ooo]Z00Cooo]Z00?o0?lTojGo0?oonfX01_oonfX0
0onoo`3ooo]ZoookJP06oookJP05ool0>ooonf[ooo]ZoookJ_l0ogX00_oonfX01Ol0TOoooo]Zoook
J_oo0<ko0?oR00[ooo]Z00Go08cooookJ_mn0?oooo]Zool:000:oookJP05ool0o?oonf[ooo]Zoook
J_ood`000ooonfX00ol0oiWooo]ZoookJP0;oookJP03oom80?l007oo001o00?ooo]Z0ol007l3oook
JP03o`00Ool0ogco001o00Kooo]Z1?l000000ooonf[o00;ooookJP05oookJP05oml0ool06_oooo]Z
o`0]oooeo`001_oonfX01OooW03ooo]ZoookJ_mK0?oo09Wo00?ooo]Z00CoofH0oookJ_oonf[o0?l0
3ooonfX00ooo<@3ooo]ZoookJP0;oookJP03ooo=0?oonf[ooo]Z00Gooo]Z00?o0;OooookJ_oonfX0
1ooonfX00onE0?oooo]ZoookJP06oookJP;oog<0W_oonfX002gooo]Z00Coob`0oookJ_oonf[o4_l0
0_oonfX00ol0;Ooooo]ZoookJP05oookJP03o`3mool0ojkooo]Z00Kooo]Z00?oo`2QoookJ_oonfX0
0_ooX002oookJP03oh<0ool0=ooooo]Z00?ooo]Z00CoobP0ooo90?oonf[ood<00_oonfX2oolX00Ko
oo]Z00So0?ncoookJ_oonf[o0=GooookJ_oo02_ooo]Zo`3o]P[ooo]Z00?oogT0oookJ_oonfX00_oo
nfX00ooo0:?ooo]ZoookJP03oookJP03oolX0?oonf[ooo]Z00Kooo]Z00Go2_l0oookJ_oonf[ooo]Z
oomk0002oookJP03oolX0?oonf[oobP000CoobP01_oonfX00onUo`3ooo]ZoookJP04oookJPGoo`00
1?oonfX00ooo03_ooo]ZoookJP03oookJP03o`3oN_l0TOoooo]Z00;ooo]Z00?oo`3>o`3oh_oonfX0
2OoonfX01Ol0S?ooOP3ooookJ_oonf[oo`X000Oooo]Z1_oo:0000oood`3oobP0oookJP02oookJP;o
obP02OoonfX7oolX00?ooo]Z0ol007l3oookJP03o`3oO?l007oo001o00Kooo]Z1?l000000ooonf[o
00;ooookJP03oookJP04oomi0?oO0?ooobP0oomi00GoobP01?oonfX00oooW03oobP0ool00002ool0
0004oolX0?oonf[ooo]ZoomV00GoogT03OoonfX00ooo<@3ooo]ZoookJP09oookJPKoolT00ooonfX6
oolX00Gooo]Z00?oU@3ooookJ_oonfX00_oonfX00oooN@3ooo]ZoookJP03oookJP;oog<0a_oonfX0
0ooo;03ooo]Zoa;o0002oookJP03o`0]oooonf[ooo]Z00Kooo]Z00?o0?gooookJ_oonfX01OoonfX0
1?oo0:7ooo]ZoookJ_oonfX2oonP00;ooo]Z00?oP`3oo`0goooonfX00_oonfX01?l02?oooo]Zooo9
0?oo@`02oookJP;o0?;o1_oonfX02?l0ok?ooo]ZoookJ_oonf[o0=GooookJ_oo02_o0?nf2_oonfX0
0oo00?oooo]ZoookJP03oookJP03ool0Xooonf[ooo]Z00?ooo]Z00?oo`25oookJ_oonfX01_oonfX0
1?l:o`3ooo]ZoookJ_ooN`02oookJP03olGo0?oonf[ooo]Z00;ooo]Z00?ooh`0oookJ_oonfX01Ooo
nfX00onUo`3ooo]ZoookJP06oookJP03okoo0?oonf[ooo]Z00Gooo]Z00?oo`0koookJ_oonfX00_oo
nfX00ol0og[ooo]Zo`2Ao`03oookJP03ool0c_oonf[ooo]Z00Wooo]Z00Go08coogh0oooonf[ooo]Z
ool:000:oookJP04ool0o?oonf[ooo]ZoooC00Cooo]Z00?o0?nIoookJ_oonfX02?oonfX3o`00O`03
oom80?l007oo001o00?ooo]Z0ol007l3oookJP03o`3oO?l007oo001o00Kooo]Z1?l000000ooonf[o
00;ooookJP04oookJP05oml0oomFo`3o01[oo`0]oooeo`001ooonfX01?ooW03ooo]ZoookJ_l0VOl4
oookJP04oomV0?oonf[ooo]Zo`3o00oooo]Z00?ooc40oookJ_oonfX03?oonfX00oooc@3ooo]Zoook
JP05oookJP03o`2goooonf[ooo]Z00Oooo]Z00?oU@3ooookJ_oonfX01ooonfX2oomc09cooo]Z000]
oookJP03ool/0?oonf[o4_l000;ooo]Z00?o02gooookJ_oonfX01OoonfX00ol0oOoo0?n^oookJP06
oookJP04ool0XOoonf[ooo]ZoonP00?ooo]Z00?oP`3oo`0goooonfX00_oonfX00ol02?ooobP0ooo9
0002oomi00;ooo]Z00?oobP0oookJ_oonfX01OoonfX02?l0ok?ooo]ZoookJ_l0eOoooo]Zool0:ooo
nf[o0?nf2_oonfX00oo00?oooo]ZoookJP02oookJP03ool0Xooo:03ooo]Z00?ooo]Z00?oobP0oook
J_oonfX01_oonfX01Ol:o`3ooo]ZoookJ_oonf[oog/000?ooo]Z00?oobP0oookJ_oo:0000ooo:006
oookJP03ojGo0?oonf[ooo]Z00Cooo]Z1?oo0005oookJP03ool0>ooonf[ooo]Z00?ooo]Z00?o0?mj
oookJ_l0TOl00_oonfX00ooo0<ko0?oRoookJP0:oookJP04o`2<oooonf[ooo]Zool:00Oooo]Z1ooo
:0001?ood`3ooo]ZoookJ_oonfX2oolX00[ooo]Z2?oo:003oookJP?o001o00Cooo]Zo`3oO?l007oo
001o1ooonfX4o`000003o`02oooonf[ooo]Z00?ooo]Z00CoogT0oml0ooooN@3oogT01?oo:005oook
JP03oonL0?oo:03oo`0000;oo`000ooonfX00oooIP3oogT0oomi0003oomi00gooo]Z00?ooc40oook
J_oonfX02_oonfX6ooo90003oookJ_oo:03oobP000KoobP01OoonfX2oiD0o`;ooo]Z0_ooN@06oook
JP;oog<0`ooonfX00ooo;03ooo]Zoa;o0002oookJP03o`0]oooonf[ooo]Z00Kooo]Z00?o0?gooook
J_oonfX01OoonfX01Ooo0:7ooo]ZoookJ_oonf[ooj0000?ooo]Z00CoP`3oo`0goooonf[ooo]Z0_l0
2?l00ooonf[ood<0oom30002oookJP03o`3boooonf[ooo]Z00Gooo]Z00So0?ncoookJ_oonf[ooo]Z
o`3Eoooonf[oo`0[o`3o]P[ooo]Z00?o`03ooookJ_oonfX00ooonfX00ooo0:?ooo]ZoookJP03oook
JP03ool0QOoonf[ooo]Z00Kooo]Z00Co2_l0oookJ_oonf[oog/00ooonfX01Oo5o`3ooo]ZoookJ_oo
nf[ooh`000Oooo]Z00?o0?lTojGo0?oonfX01_oonfX00onoo`3ooo]ZoookJP05oookJP03ool0>ooo
nf[ooo]Z00;ooo]Z00Co0?mjoookJ_oonf[o097o0_oonfX00ooo0<kooo]ZoookJP09oookJP05o`2<
oomn0?oooo]ZoookJ_oo2P002_oonfX01Ooo0?cooo]ZoookJ_oonf[oom<000?ooo]Z00?o0?nIoook
J_oonfX02OoonfX2o`00O`04oom80?l007oo001oo`00O`Cooo]Z0ol007l01?oonf[o001oo`3oO?l0
07l7oookJPCo000000?ooo]Zo`02oooonfX01?oonfX01OoO0?ooE_l0o`0Jool0;OoomOl000Oooo]Z
00Cooi`0oookJ_oonf[o09Wo1?oonfX01?ooIP3ooo]ZoookJ_l0o`0@oookJP03oola0?oonf[ooo]Z
00_ooo]Z00?oold0ool0^_oonfX01_oonfX00ol0]ooooo]ZoookJP07oookJP;oU@3o2OoonfX2oomc
09[ooo]Z000/oookJP03ool/0?oonf[o4_l000;ooo]Z00?o02gooookJ_oonfX01OoonfX00ol0oOoo
0?n^oookJP06oookJP04ool0XOoonf[ooo]ZoonP00;ooo]Z0_n30?l02?l0=ooooo]ZoookJ_oonf[o
00SooookJ_oob@3oogT00ooonfX00ooo:03ooo]ZoookJP05oookJP04o`3o/ooonf[ooo]Zo`3Eo`;o
o`0[00?ooo]Zo`3o]_oonfX02OoonfX00oo00?oooo]ZoookJP02oookJP04ool0Xooonf[oobP0oolX
00;ooo]Z00?oobP0oookJ_oonfX01_oonfX01Ol:o`3ooo]ZoookJ_oonf[oog/000?ooo]Z00?oobP0
oookJ_oo:0000_oo:007oookJP03ojGo0?oonf[ooo]Z00Gooo]Z0ooo0005oookJP03ool0>ooonf[o
oo]Z00?ooo]Z00?o0?mjoookJ_l0TOl00ooonfX00ooo0<kooo]ZoookJP09oookJP04o`2<oomn0?oo
oo]Zool:00Sooo]Z1_oo:0000oood`3ooo]ZoookJP02oookJP03oolX0?oonf[ooo]Z00Wooo]Z2?oo
:003oookJPCo001o00?o0?mlo`00Ool007l01ooonfX4o`000003o`02oooonf[ooo]Z00?ooo]Z00Co
obP0oml0oooo:03oogT01?oo:005oookJP03oonL0?oo:03oobP000;oo`000ooonfX00oooIP3ooo]Z
oomi0002oomi00kooo]Z00?ooc40oookJ_oonfX02ooonfX5ooo900WoobP01ooonfX00onE0?ooogT0
oomi0002oomi00Oooo]Z0_ooL`30oookJP03ool/0?oonf[o4_l000;ooo]Z00?o02gooookJ_oonfX0
1OoonfX00ol0ojko0?gooookJP06oookJP05ool0XOoonf[ooo]ZoookJ_ooX0000_oonfX2oh<0o`04
o`0goooonf[ooo]Zo`08o`;ooo]Z00Good<0oookJ_oonf[ooo]Zo`3bo`07oookJP05o`3o/ooonf[o
oo]ZoookJ_l0eOl00_oo02/00ol0okKooo]ZoookJP08oookJP03ol00oooonf[ooo]Z00?ooo]Z00?o
o`2SoookJ_oonfX00ooonfX00ooo08Gooo]ZoookJP06oookJP04o`[o0?oonf[ooo]Zoomk00?ooo]Z
00GoaOl0oookJ_oonf[ooo]Zoon<0007oookJP03o`3o9?nUo`3ooo]Z00Kooo]Z00?o_ol0oookJ_oo
nfX01OoonfX00ooo03_ooo]ZoookJP02oookJP04o`3oN_oonf[ooo]Zo`2Ao`;ooo]Z00?oo`3>o`3o
h_oonfX02OoonfX01Ol0S?oooo]Zogh0oooonf[oo`X000[ooo]Z00Goo`3loookJ_oonf[ooo]ZoooC
0003oookJP03o`3oVOoonf[ooo]Z00cooo]Z00CoodP0o`00Ool007oo001o1?oonfX4o`00O`03o`3o
O?l007oo001o00Oooo]Z1?l000000ol00_oooo]ZoookJP04oookJP05oml0oomFo`3o01[oo`0]oooe
o`001ooonfX01?ooW03ooo]ZoookJ_l0VOl4oookJP04oomV0?oonf[ooo]Zo`3o013ooo]Z00?ooc40
oookJ_oonfX03?oonfX00oooc@3ooo]ZoookJP06oookJP03o`2goooonf[ooo]Z00Sooo]Z00?oU@3o
oookJ_oonfX02?oonfX2oomc09Sooo]Z000[oookJP03ool/0?oonf[o4_l000;ooo]Z00?o02gooook
J_oonfX01OoonfX00ol0oOoooo]ZoookJP06oookJP04ool0XOoonf[ooo]ZoonP00;ooo]Z00?oP`3o
oookJ_l0=ol00ooonfX01?l02?oooo]Zooo90?ooN@03oookJP03oolX0?oonf[ooo]Z00Gooo]Z00Go
0?ncoookJ_oonf[o0=Goool0:`02oookJP03o`3o]_oonf[ooo]Z00Sooo]Z00?o`03ooookJ_oonfX0
0_oonfX00ooo0:?ooo]ZoolX0004oolX00Sooo]Z00Go2_l0oookJ_oonf[ooo]Zoomk0003oookJP04
oolX0?oonf[ooo]ZoolX00Sooo]Z00?oYOl0oookJ_oonfX01OoonfX3ool000Kooo]Z00?oo`0koook
J_oonfX00_oonfX00ol0og[ooo]Zo`2Ao`03oookJP03ool0c_l0on;ooo]Z00Wooo]Z00Go08coogh0
oooonf[ooo]Zool:0007oookJPKoobP000?oogT0oookJ_oonfX00ooonfX00ol0oiWooo]ZoookJP09
oookJPOoobP01OoonfX2o`00O`03o`3oO?l007oo001o00Sooo]Z1?l000000ol00_oooo]ZoookJP03
oookJP03oml0oooo:03oobP000CoobP01_oonfX01?ooW03oobP0oolX0?oo0004oolX0003oomV0?oo
:03oogT000;oogT03ooonfX00ooo<@3ooo]ZoookJP0;oookJPCoolT00_oonfX8oolX00Kooo]Z1_oo
N@08oookJP;oog<0_OoonfX00ooo;03ooo]Zoa;o0002oookJP03o`0]oooonf[ooo]Z00Gooo]Z00?o
0?n^o`3moooonfX01_oonfX01Ooo0:7ooo]ZoookJ_oonf[ooj0000;ooo]Z00?oP`3ooookJ_l0=ol0
0_oonfX01?l02?oooo]ZoookJ_oo@`03oookJP03o`3boooonf[ooo]Z00Gooo]Z00So0?ncoookJ_oo
nf[ooo]Zo`3Eoooo02_ooo]Zo`3o]P[ooo]Z00?o`03ooookJ_oonfX00ooonfX00ooo0:?ooo]Zoook
JP03oookJP03ool0QOoonf[ooo]Z00Kooo]Z00Co2_l0oookJ_oonf[oog/00ooonfX01Oo5o`3ooo]Z
oookJ_oonf[ooh`000Oooo]Z00?o0?lTojGo0?oonfX01_oonfX00onoo`3ooo]ZoookJP06oookJP05
ool0>ooonf[ooo]ZoookJ_l0ogX00_oonfX01Ol0TOoooo]ZoookJ_oonf[oo`3>00[ooo]Z00?o08co
oookJ_mn0?l00_oonfX00ooo2P3ooo]ZoookJP08oookJP04ool0o?oonf[ooo]ZoooC00Cooo]Z00?o
0?nIoookJ_oonfX02ooonfX00oooB03ooo]Zo`00O`02o`00O`Gooo]Z0ol007l00ol0ogco001ooook
JP07oookJPCo000000?o00;ooookJ_oonfX01?oonfX01OoO0?ooE_l0oookJ_l0;OoomOl000Oooo]Z
00Cooi`0oookJ_mK0?oo09Wo1?oonfX01OooIP3ooo]ZoookJ_oonf[o0?l000oooo]Z00?ooc40oook
J_oonfX03OoonfX00oooc@3ooo]ZoookJP06oookJP03o`2goooonf[ooo]Z00Sooo]Z00?oU@3ooook
J_oonfX02OoonfX2oomc09Kooo]Z000ZoookJP03ool/0?oonf[o4_l000;ooo]Z00?o02gooookJ_oo
nfX01OoonfX00ol0oOoooo]ZoookJP06oookJP04ool0XOoonf[ooo]ZoonP00;ooo]Z00?oP`3ooook
J_l0=ol00ooonfX01?l02?oooo]Zooo90?ooN@03oookJP03oolX0?oonf[ooo]Z00Gooo]Z00Go0?nc
oookJ_oonf[o0=Goool0:`02oookJP03o`3o]_oonf[ooo]Z00Sooo]Z00?o`03ooookJ_oonfX00_oo
nfX00ooo0:?ooo]ZoolX0005oolX00Oooo]Z00Go2_l0oookJ_oonf[ooo]Zoomk0003oookJP04oolX
0?oonf[ooo]ZoolX00Sooo]Z00?oYOl0oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP05oookJP03
ool0>ooonf[ooo]Z00;ooo]Z00?o0?mjoookJ_l0TOl00ooonfX00ooo0<ko0?oRoookJP0:oookJP04
o`2<oooonf[ooo]Zool:00Sooo]Z00?oobP0oomi0?ooN@000_oo:0000ooonf[oogT0oookJP03oook
JP03o`3oVOoonf[ooo]Z00Wooo]Z1ooo:008oookJP03o`3oO?oonf[ooo]Z00Sooo]Z0ol000000ol0
0_oooo]ZoookJP04oookJP03oml0oooo:03oobP000GoobP01OoonfX01?ooW03ooo]ZoolX0?oo0004
oolX0003oomV0?oo:03oogT000;oogT03ooonfX00ooo<@3ooo]ZoookJP0<oookJPCoolT00ooonfX7
oolX00Gooo]Z1oooN@09oookJP;oog<0^_oonfX00ooo;03ooo]Zoa;o0002oookJP03o`0]oooonf[o
oo]Z00Gooo]Z00?o0?n^o`3moooonfX01_oonfX01Ooo0:7ooo]ZoookJ_oonf[ooj0000;ooo]Z00?o
P`3ooookJ_l0=ol00_oonfX01?l02?oooo]ZoookJ_oo@`03oookJP03o`3boooonf[ooo]Z00Gooo]Z
00So0?ncoookJ_oonf[ooo]Zo`3Eoooo02_ooo]Zo`3o]P[ooo]Z00?o`03ooookJ_oonfX00ooonfX0
0ooo0:?ooo]ZoookJP03oookJP03ool0QOoonf[ooo]Z00Kooo]Z00Co2_l0oookJ_oonf[oog/00ooo
nfX01Oo5o`3ooo]ZoookJ_oonf[ooh`000Oooo]Z00?o0?lTojGo0?oonfX01_oonfX00onoo`3ooo]Z
oookJP06oookJP05ool0>ooonf[ooo]ZoookJ_l0ogX00_oonfX01Ol0TOoooo]ZoookJ_oonf[oo`3>
00_ooo]Z00Go08coogh0oooonf[ooo]Zool:000:oookJP05ool0o?oonf[ooo]ZoookJ_ood`000ooo
nfX00ol0oiWooo]ZoookJP0<oookJP03oom80?oonf[ooo]Z00Wooo]Z00?o0?mloookJ_oonfX02?oo
nfX4o`000003o`02oooonf[ooo]Z00Cooo]Z00Gog`3oo`0Joooonf[o02goooGo0007oookJP04oonL
0?oonf[oF`3oo`2Io`Cooo]Z00GoofH0oookJ_oonf[ooo]Zo`3o000@oookJP03oola0?oonf[ooo]Z
00cooo]Z00?oold0ool0^_oonfX01ooonfX2o`2go`Wooo]Z00?oU@3ooookJ_oonfX02_oonfX2oomc
09Cooo]Z000[oookJP04oa;o0?oonf[ooo]Zo`0]o`Oooo]Z00?o0?gooookJ_oonfX01_oonfX01?oo
0:7ooo]ZoookJ_ooX002oookJP03oh<0oooonf[o03Oo00?ooo]Z00Co00SooookJ_oob@3oogT00ooo
nfX00ooo:03ooo]ZoookJP05oookJP05o`3o/ooonf[ooo]Zo`3Eoooo02/00_oonfX00ol0okKooo]Z
oookJP08oookJP03ol00oooonf[ooo]Z00;ooo]Z00?oo`2SoookJ_oonfX01ooo:005oookJP05o`[o
0?oonf[ooo]ZoookJ_ooN`000ooonfX01Ooo:03ooo]ZoookJ_oonf[ooh`000Oooo]Z00?oYOl0oook
J_oonfX01_oonfX00ooo003ooo]ZoookJP05oookJP03ool0>ooonf[ooo]Z00?ooo]Z00?o0?mjo`2A
oooonfX00_oonfX00ooo0<ko0?oRoookJP0:oookJP04o`2<oooonf[ooo]Zool:00Wooo]Z00KoobP0
oomi0?ooN@3oogT0oookJ_ooN@04oookJP03o`3oVOoonf[ooo]Z00[ooo]Z1_oo:009oookJP03o`3o
O?oonf[ooo]Z00Sooo]Z0ol000000ol00_oooo]ZoookJP04oookJP03oml0oooo:03oobP000GoobP0
1OoonfX01?ooW03ooo]ZoolX0?l0VOl4oolX0003oomV0?oo:03oogT000;oogT03ooonfX00ooo<@3o
oo]ZoookJP0=oookJP?oolT01OoonfX5oolX00Cooo]Z2OooN@0:oookJP;oog<0^OoonfX01?lBo`3o
oo]ZoookJ_l0;Ol7oookJP03o`3o[_l0oOoooo]Z00Kooo]Z00Goo`2QoookJ_oonf[ooo]ZoonP0002
oookJP03oh<0oooonf[o03Oo00;ooo]Z00Co00SooookJ_oonf[ood<00ooonfX00ol0l_oooo]Zoook
JP05oookJP08o`3o/ooonf[ooo]ZoookJ_l0eOooo`0[oookJ_l0okH:oookJP03ol00oooonf[ooo]Z
00?ooo]Z00?oo`2SoookJ_oonfX00ooonfX00ooo08Gooo]ZoookJP06oookJP04o`[o0?oonf[ooo]Z
oomk00?ooo]Z00?oaOl0oookJ_oonfX00_oonfX00oooS03ooo]ZoookJP04oookJP03o`3o9?nUo`3o
oo]Z00Kooo]Z00?o_ol0oookJ_oonfX01_oonfX00ooo03_ooo]ZoookJP02oookJP03o`3oN_oonf[o
097o00?ooo]Z00?oo`3>o`3oh_oonfX02OoonfX01Ol0S?ooOP3ooookJ_oonf[oo`X000[ooo]Z00Go
o`3loookJ_oonf[ooo]ZoooC0003oookJP03o`3oVOoonf[ooo]Z00cooo]Z00?oodP0oookJ_oonfX0
2_oonfX00ol0ogcooo]ZoookJP08oookJPCo000000?o00;ooookJ_oonfX00ooonfX01OoO0?ooE_l0
o`0Jool0;OoomOl000Sooo]Z00Cooi`0oookJ_mK0?oo09Wo1?oonfX01OooIP3ooo]ZoookJ_oonf[o
0?l0013ooo]Z00?ooc40oookJ_oonfX03OoonfX00oooc@3oo`2joookJP08oookJP03o`2goooonf[o
oo]Z00Oooo]Z00?oU@3ooookJ_oonfX02ooonfX2oomc09;ooo]Z000ZoookJP04oa;o0?oonf[ooo]Z
o`0]o`Oooo]Z00?o0?gooookJ_oonfX01OoonfX2ool0X@;ooo]Z00Kooj00oookJ_oonf[oP`3ooook
J_l0=ol3oookJP04o`08oooonf[oolT0oomi00?ooo]Z00?oobP0oookJ_oonfX01OoonfX01Ol0ok?o
oo]ZoookJ_l0eOooo`0[00;ooo]Z00?o0?nfoookJ_oonfX02?oonfX00oo00?oooo]ZoookJP02oook
JP03ool0Xooonf[ooo]Z00WoobP00ooonfX01Ol:o`3ooo]ZoookJ_oonf[oog/000?ooo]Z00GoobP0
oookJ_oonf[ooo]Zoon<0007oookJP03ojGo0?oonf[ooo]Z00Oooo]Z00?o_ol0oookJ_oonfX01?oo
nfX00ooo03_ooo]ZoookJP03oookJP03o`3oN_oonf[o097o00?ooo]Z00?oo`3>oookJ_oonfX02Ooo
nfX01?l0S?ooOP3ooookJ_oo2P09oookJP03oolX0?ooN@3oogT000CoogT01?oonfX00ol0oiWooo]Z
oookJP0:oookJPGoobP02OoonfX00ol0ogcooo]ZoookJP09oookJP?o000000?o00;ooookJ_oonfX0
0ooonfX00ooO0?ooobP0oolX0005oolX00Kooo]Z00Gooi`0oookJ_oo:03o09WooookJP03oolX0004
oomV0?oo:03oobP0oomi017ooo]Z00?ooc40oookJ_oonfX03OoonfX2ooo900Oooo]Z1?oo:002oook
JP_oogT02ooonfX3oomc0;Gooo]Z00Co4_l0oookJ_oonf[o02go1ooonfX00ol0ojko0?gooookJP05
oookJP;oo`2Q0ooonfX01_ooX03ooo]ZoookJ_n30?oooo]Zo`0go`;ooo]Z00Co00SooookJ_oonf[o
od<00ooonfX00ol0l_oooo]ZoookJP05oookJP08o`3o/ooonf[ooo]ZoookJ_l0eOooo`0[oookJ_l0
okH:oookJP03ol00oooonf[ooo]Z00?ooo]Z00?oo`2SoookJ_oonfX00ooonfX00ooo08Gooo]Zoook
JP06oookJP04o`[o0?oonf[ooo]Zoomk00?ooo]Z00?oaOl0oookJ_oonfX00_oonfX00oooS03ooo]Z
oookJP04oookJP03o`3o9?nUo`3ooo]Z00Oooo]Z00?o_ol0oookJ_oonfX01OoonfX00ooo03_ooo]Z
oookJP02oookJP04o`3oN_oonf[ooo]Zo`2Ao`;ooo]Z00?oo`3>o`3oh_oonfX02OoonfX01Ol0S?oo
oo]Zogh0oooonf[oo`X000_ooo]Z00Coo`3loookJ_oonf[oom<01?oonfX00ol0oiWooo]ZoookJP0;
oookJP03oom80?oonf[ooo]Z00[ooo]Z00?o0?mloookJ_oonfX02OoonfX3o`000003o`02oooonf[o
oo]Z00Cooo]Z00Gog`3ooeKo0?l06_oo02goooGo0008oookJP04oonL0?oonf[oF`3oo`2Io`Cooo]Z
00GoofH0oookJ_oonf[ooo]Zo`3o000@oookJP03oola0?oonf[ooo]Z00kooo]Z00?oold0oookJ_oo
nfX02?oonfX00ol0]ooooo]ZoookJP07oookJP;oU@3o3OoonfX3oomc08oooo]Z000/oookJP03o`0]
oooonf[ooo]Z00Gooo]Z00?o0?gooookJ_oonfX01OoonfX01Ooo0:7ooo]ZoookJ_oonf[ooj0000;o
oo]Z00?oP`3ooookJ_l0=ol00ooonfX01?l02?oooo]Zooo90?ooN@03oookJP03oolX0?oonf[ooo]Z
00Gooo]Z00Go0?ncoookJ_oonf[o0=Goool0:`02oookJP03o`3o]_oonf[ooo]Z00Sooo]Z00?o`03o
oookJ_oonfX00_oonfX01?oo0:?ooo]ZoookJ_oonfX7oolX00Cooo]Z00Go2_l0oookJ_oo:03oobP0
oomk0003oookJP05oolX0?oonf[ooo]ZoookJ_ooS0001ooonfX00ol0obCoYOl0oookJP07oookJP03
okoo0?oonf[ooo]Z00Cooo]Z00?oo`0koookJ_oonfX00ooonfX00ol0og[ooo]Zo`2Ao`03oookJP03
ool0c_l0on;ooo]Z00Wooo]Z00Go08coogh0oooonf[ooo]Zool:0009oookJP03oolX0?ooN@3oogT0
00GoogT00_oonfX00ol0oiWooo]ZoookJP0:oookJPGoobP02_oonfX00ol0ogcooo]ZoookJP09oook
JP;o000000?o00;oo`000?oonfX01?oonfX00ooO0?ooobP0oolX0005oolX00Gooo]Z00Kooi`0oook
J_oonf[oobP0o`2IoooonfX3oolX0004oomV0?oo:03oobP0oomi017ooo]Z00?ooc40oookJ_oonfX0
3_oonfX00oooc@3oolT0oookJP06oookJP?oobP01OoonfX9oomi00gooo]Z0_ooL`08oookJP;oogT0
ZooonfX00ol0;Ooooo]ZoookJP05oookJP;o0?go1_oonfX00ooo0:7ooo]ZoookJP02oookJP06oonP
0?oonf[ooo]Zoh<0oooonf[o03Oo0_oonfX01?l02?oooo]ZoookJ_oo@`03oookJP03o`3boooonf[o
oo]Z00Gooo]Z00So0?ncoookJ_oonf[ooo]Zo`3Eoooo02_ooo]Zo`3o]P[ooo]Z00?o`03ooookJ_oo
nfX00ooonfX00ooo0:?ooo]ZoookJP03oookJP03ool0QOoonf[ooo]Z00Kooo]Z00Co2_l0oookJ_oo
nf[oog/00ooonfX00oo5o`3ooo]ZoookJP02oookJP03oon<0?oonf[ooo]Z00Cooo]Z00?o0?lToook
J_nUo`001ooonfX00onoo`3ooo]ZoookJP05oookJP03ool0>ooonf[ooo]Z00;ooo]Z00Co0?mjoook
J_oonf[o097o0ooonfX00ooo0<kooo]ZoookJP08oookJP03o`2<oooonf[oOP3o00;ooo]Z00?oo`X0
oookJ_oonfX02?oonfX01Ooo0?cooo]ZoookJ_oonf[oom<000?ooo]Z00?o0?nIoookJ_oonfX03?oo
nfX00oooB03ooo]ZoookJP0:oookJP03o`3oO?oonf[ooo]Z00Wooo]Z0ol000000ol00_oooo]Zoook
JP04oookJP05oml0oooonf[o01[oo`0]oooeo`001ooonfX01OooW03ooo]ZoookJ_mK0?oo09Wo00Co
oo]Z00GoofH0oookJ_oonf[ooo]Zo`3o000AoookJP03oola0?oonf[ooo]Z00gooo]Z00?oold0ool0
^_oonfX02OoonfX00ol0]ooooo]ZoookJP08oookJP03oiD0oooonf[ooo]Z00gooo]Z0_ooL`2=oook
JP00:ooonfX00ol0;Ooooo]ZoookJP05oookJP03o`3moooonf[ooo]Z00Gooo]Z00Goo`2QoookJ_oo
nf[ooo]ZoonP0002oookJP03oh<0oooonf[o03Oo00?ooo]Z00Co00SooookJ_oob@3oogT00ooonfX0
0ooo:03ooo]ZoookJP05oookJP05o`3o/ooonf[ooo]Zo`3Eoooo02/00_oonfX00ol0okKooo]Zoook
JP08oookJP03ol00oooonf[ooo]Z00;ooo]Z00Coo`2SoookJ_oonf[ooo]Z1ooo:004oookJP03o`[o
0?oonf[ooo]Z00?oobP00_oonfX01Ooo:03ooo]ZoookJ_oonf[ooh`000Oooo]Z00?o0?lTojGo0?oo
nfX01ooonfX00onoo`3ooo]ZoookJP04oookJP03ool0>ooonf[ooo]Z00?ooo]Z00?o0?mjoookJ_l0
TOl00ooonfX00ooo0<ko0?oRoookJP0:oookJP04o`2<oooonf[ooo]Zool:00Wooo]Z0_oo:008oomi
0003o`3oVOoonf[ooo]Z00_ooo]Z1?oo:00:oookJP03o`3oO?oonf[ooo]Z00[ooo]Z0_l000000ol0
0_oo0000oookJP04oookJP03oml0oooo:03oobP000;oobP000?omOl0oolX0?oonfX01OoonfX01_oo
W03ooo]ZoookJ_mK0?oo09WooookJP?oobP000CoofH0oolX0?oo:03o0?l04OoonfX00ooo<@3ooo]Z
oookJP0?oookJP03ooo=0?oonf[ooo]Z00Oooo]Z0_oo:007oookJPOoogT03_oonfX3oomc00Gooo]Z
1?ooN@2XoookJP03o`0]oooonf[ooo]Z00Gooo]Z00?o0?gooookJ_oonfX01OoonfX00ooo0:7ooo]Z
oookJP02oookJP06oonP0?oonf[ooo]Zoh<0oooonf[o03Oo0_oonfX01?l02?oooo]ZoookJ_oo@`03
oookJP03o`3boooonf[ooo]Z00Gooo]Z00So0?ncoookJ_oonf[ooo]Zo`3Eoooo02_ooo]Zo`3o]P[o
oo]Z00?o`03ooookJ_oonfX00ooonfX00ooo0:?ooo]ZoookJP03oookJP03ool0QOoonf[ooo]Z00Ko
oo]Z00Go2_l0oookJ_oonf[ooo]Zoomk0002oookJP03olGo0?oonf[ooo]Z00;ooo]Z00?ooh`0oook
J_oonfX01?oonfX00ol0obCooo]ZojGo0007oookJP03okoo0?oonf[ooo]Z00Gooo]Z00?oo`0koook
J_oonfX00_oonfX01?l0og[ooo]ZoookJ_l0TOl3oookJP03ool0c_oonf[ooo]Z00Wooo]Z00Go08co
ogh0oooonf[ooo]Zool:000:oookJP05ool0o?oonf[ooo]ZoookJ_ood`001?oonfX00ol0oiWooo]Z
oookJP0;oookJP03oom80?oonf[ooo]Z00[ooo]Z00?o0?mloookJ_oonfX02_oonfX3o`000003o`02
oooonf[ooo]Z00Cooo]Z00Gog`3oo`0Joooonf[o02goooGo0007oookJP05oonL0?oonf[ooo]Zoe/0
ool0VOl01?oonfX01OooIP3ooo]ZoookJ_oonf[o0?l0017ooo]Z00?ooc40oookJ_oonfX03_oonfX0
0oooc@3oo`2joookJP09oookJP03o`2goooonf[ooo]Z00Sooo]Z0_nE0?l?oookJP?oog<0R_oonfX0
02[ooo]Z00?o02gooookJ_oonfX01OoonfX00ol0oOoooo]ZoookJP05oookJP05ool0XOoonf[ooo]Z
oookJ_ooX0000_oonfX00on30?oooo]Zo`0go`03oookJP04o`08oooonf[oolT0oomi00?ooo]Z00?o
obP0oookJ_oonfX01OoonfX01Ol0ok?ooo]ZoookJ_l0eOooo`0[00;ooo]Z00?o0?nfoookJ_oonfX0
2?oonfX00oo00?oooo]ZoookJP02oookJP04ool0Xooonf[ooo]ZoookJPKoobP01OoonfX00ol:o`3o
oo]ZoookJP06oolX00?ooo]Z00?ooh`0oookJ_oonfX01_oonfX00onUo`3ooo]ZoookJP06oookJP03
okoo0?oonf[ooo]Z00Gooo]Z00?oo`0koookJ_oonfX00_oonfX00ol0og[ooo]Zo`2Ao`03oookJP03
ool0c_l0on;ooo]Z00[ooo]Z00Co08coogh0oooonf[oo`X02_oonfX00ooo:03oogT0oomi0006oomi
0003oookJ_l0oiWooo]Z00cooo]Z0ooo:00;oookJP03o`3oO?oonf[ooo]Z00[ooo]Z00?o0000o`02
ool000000_l00004oookJP03oml0oooo:03oobP000;oobP000?omOl0oolX0?oonfX01?oonfX00ooo
:03ooi`0oolX0002oolX0003o`2Ioooonf[oobP000;oobP000CoofH0oolX0?oo:03o0?l04_oonfX0
0ooo<@3ooo]ZoookJP0>oookJP03ooo=0?oonf[ooo]Z00Wooo]Z00?oobP0o`2goooonfX01ooonfX5
oomi013ooo]Z0oooL`02oookJPKoogT0YOoonfX00ol0;Ooooo]ZoookJP05oookJP03o`3moooonf[o
oo]Z00Gooo]Z00Coo`2QoookJ_oonf[ooo]Z0_ooX002oookJP03oh<0oooonf[o03Oo00;ooo]Z00Co
00SooookJ_oonf[ood<00ooonfX00ol0l_oooo]ZoookJP05oookJP08o`3o/ooonf[ooo]ZoookJ_l0
eOooo`0[oookJ_l0okH:oookJP03ol00oooonf[ooo]Z00?ooo]Z00?oo`2SoookJ_oonfX00ooonfX0
0ooo08Gooo]ZoookJP06oookJP05o`[o0?oonf[ooo]ZoookJ_ooN`000_oonfX00oo5o`3ooo]Zoook
JP02oookJP03oon<0?oonf[ooo]Z00Gooo]Z00?o0?lTojGo0?oonfX01_oonfX00onoo`3ooo]Zoook
JP06oookJP05ool0>ooonf[ooo]ZoookJ_l0ogX00_oonfX01_l0TOoooo]ZoookJ_oonf[oo`3>o`3o
hP[ooo]Z00Go08coogh0oooonf[ooo]Zool:000;oookJP05ool0o?oonf[ooo]ZoookJ_ood`000ooo
nfX00ol0oiWooo]ZoookJP0<oookJP03oom80?oonf[ooo]Z00[ooo]Z00?o0?mloookJ_oonfX02_oo
nfX2o`000003o`02ool0003o000000Gooo]Z00Gog`3oo`0Joooonf[o02goooGo0007oookJP05oonL
0?oonf[ooo]Zoe/0ool0VOl01?oonfX01OooIP3ooo]ZoookJ_oonf[o0?l0017ooo]Z00?ooc40oook
J_oonfX03ooonfX00oooc@3ooo]ZoookJP09oookJP03o`2goooonf[ooo]Z00Wooo]Z0_nE0?l@oook
JP?oog<0QooonfX0037ooo]Z00?o0?gooookJ_oonfX01OoonfX01Ooo0:7ooo]ZoookJ_oonf[ooj00
00;ooo]Z00?oP`3ooookJ_l0=ol00ooonfX01?l02?oooo]Zooo90?ooN@03oookJP03oolX0?oonf[o
oo]Z00Cooo]Z0_l0ok<2oookJP05o`3Eoooo02_ooo]ZoookJ_l0okH02_oonfX00oo00?oooo]Zoook
JP03oookJP04ool0Xooonf[ooo]ZoookJPCoobP01_oonfX01?l:o`3ooo]ZoookJ_oonfX6oolX00;o
oo]Z00?ooh`0oookJ_oonfX01_oonfX00onUo`3ooo]ZoookJP06oookJP03okoo0?oonf[ooo]Z00Go
oo]Z00?oo`0koookJ_oonfX00_oonfX00ol0og[ooo]Zo`2Ao`04oookJP03ool0c_oonf[ooo]Z00Wo
oo]Z00Go08coogh0oooonf[ooo]Zool:000:oookJP03oolX0?ooN@3oogT000GoogT000?ooo]Zo`3o
VOoonfX03OoonfX2oolX00_ooo]Z00?o0?mloookJ_oonfX02ooonfX01?l0003o00;oo`000?l00004
oookJP03oml0oomFo`3oobP000;oobP000?omOl0oolX0?oonfX01OoonfX00ooo:03ooi`0oolX0007
oolX0004oomV0?oo:03oobP0o`3o01;ooo]Z00?ooc40oookJ_oonfX03ooonfX00oooc@3ooo]Zoook
JP0:oookJP03o`2goooonf[ooo]Z00Sooo]Z0oooN@0BoookJP03oomc0?ooN@3oogT000OoogT0Z_oo
nfX00ol0oOoooo]ZoookJP05oookJP05ool0XOoonf[ooo]ZoookJ_ooX0000ooonfX00on30?oooo]Z
o`0go`02oookJP04o`08oooonf[ooo]Zoom300?ooo]Z00?o0?;ooookJ_oonfX01?oonfX2o`3o/`?o
oo]Z00Co0=Goool0:ooonf[o0?nf2_oonfX00oo00?oooo]ZoookJP04oookJP03ool0Xooonf[ooo]Z
00;ooo]Z00?oo`25oookJ_oonfX01_oonfX01Ol:o`3ooo]ZoookJ_oonf[oog/000;ooo]Z00?oaOl0
oookJ_oonfX00_oonfX00oooS03ooo]ZoookJP05oookJP03o`3o9?nUo`3ooo]Z00Kooo]Z00?o_ol0
oookJ_oonfX01_oonfX01Ooo03_ooo]ZoookJ_oonf[o0?mj00;ooo]Z00?o097ooookJ_oonfX00_oo
nfX00ooo0<kooo]ZoookJP08oookJP03o`2<oooonf[oOP3o00;ooo]Z00?oo`X0oookJ_oonfX02?oo
nfX01Ooo0?cooo]ZoookJ_oonf[oom<000?ooo]Z00?o0?nIoookJ_oonfX03?oonfX00oooB03ooo]Z
oookJP0:oookJP03o`3oO?oonf[ooo]Z00_ooo]Z0_l000000ol00_oo0000oookJP04oookJP06oml0
oomFo`3o01[oo`0]oooonf[omOl01ooonfX01?ooW03ooo]ZoookJ_l0VOl5oookJP05oomV0?oonf[o
oo]ZoookJ_l0o`004OoonfX00ooo<@3ooo]ZoookJP0@oookJP03ooo=0?oonf[ooo]Z00Wooo]Z00?o
0;OooookJ_oonfX02_oonfX00onE0?oooo]ZoookJP0@oookJP?oog<0Q?oonfX0033ooo]Z00?o0?go
oookJ_oonfX01OoonfX01Ooo0:7ooo]ZoookJ_oonf[ooj0000;ooo]Z00?oP`3ooookJ_l0=ol00ooo
nfX01?l02?oooo]Zooo90?ooN@03oookJP03oolX0?oonf[ooo]Z00Cooo]Z00Ko0?ncoookJ_oonf[o
oo]Zo`3Eoooo02/2oookJP03o`3o]_oonf[ooo]Z00Sooo]Z00?o`03ooookJ_oonfX00ooonfX01?oo
0:?ooo]ZoookJ_oonfX4oolX00Kooo]Z00Co2_l0oookJ_oonf[ooo]Z2?oo:0000oooS03ooo]Zoook
JP06oookJP03ojGo0?oonf[ooo]Z00Kooo]Z00?o_ol0oookJ_oonfX01OoonfX00ooo03_ooo]Zoook
JP03oookJP03o`3oN_oonf[o097o00?ooo]Z00?oo`3>oookJ_oonfX02OoonfX01Ol0S?ooOP3ooook
J_oonf[oo`X000[ooo]Z00?oobP0oookJ_ooN@001OooN@000ooonf[o0?nIoookJP0=oookJP;oobP0
3?oonfX00ol0ogcooo]ZoookJP0;oookJP04o`000?l00_oo0000o`0000Cooo]Z00?og`3ooeKo0?oo
:0000_oo:0000ooeo`3oobP0oookJP05oookJP03oolX0?ooW03oobP000OoobP000CoofH0oolX0?oo
:03o0?l04_oonfX00ooo<@3ooo]ZoookJP0@oookJP03ooo=0?oonf[ooo]Z00[ooo]Z00?o0;Oooook
J_oonfX02_oonfX00oooN@3oU@3ooookJP0@oookJP_oogT0YooonfX00ol0oOoooo]ZoookJP05oook
JP05ool0XOoonf[ooo]ZoookJ_ooX0000ooonfX00on30?oooo]Zo`0go`02oookJP04o`08oooonf[o
oo]Zoom300?ooo]Z00?o0?;ooookJ_oonfX01?oonfX00ol0ok?ooo]ZoookJP02oookJP04o`3Eoooo
02_ooo]Zo`3o]P[ooo]Z00?o`03ooookJ_oonfX01?oonfX00ooo0:?ooo]ZoookJP02oookJP03ool0
QOoonf[ooo]Z00Kooo]Z00Go2_l0oookJ_oonf[ooo]Zoomk0002oookJP03olGo0?oonf[ooo]Z00;o
oo]Z00?ooh`0oookJ_oonfX01OoonfX00ol0obCoYOl0oookJP06oookJP03okoo0?oonf[ooo]Z00Ko
oo]Z00?oo`0koookJ_oonfX00_oonfX01?l0og[ooo]ZoookJ_l0TOl3oookJP03ool0c_oonf[ooo]Z
00Sooo]Z00?o08cooookJ_mn0?l00_oonfX00ooo2P3ooo]ZoookJP08oookJP05ool0o?oonf[ooo]Z
oookJ_ood`001?oonfX00ol0oiWooo]ZoookJP0<oookJP03oom80?oonf[ooo]Z00[ooo]Z00?o0?ml
oookJ_oonfX02ooonfX2o`000003o`02ool0003ooo]Z00Cooo]Z00Gog`3ooookJ_l06_oo02goooGo
0008oookJP04oonL0?oonf[ooo]Zo`2Io`Gooo]Z00GoofH0oookJ_oonf[ooo]Zo`3o000BoookJP03
oola0?oonf[ooo]Z00oooo]Z00?oold0ool0^_oonfX02_oonfX00ol0]ooooo]ZoookJP0:oookJP;o
U@3o4ooonfX4oomc083ooo]Z000_oookJP03o`3moooonf[ooo]Z00Gooo]Z00Goo`2QoookJ_oonf[o
oo]ZoonP0002oookJP03oh<0oooonf[o03Oo00?ooo]Z00Co00SooookJ_oo:03oogT00_oonfX2oolX
00Kooo]Z00Ko0?ncoookJ_oonf[ooo]Zo`3Eoooo02/2oookJP03o`3o]_oonf[ooo]Z00Sooo]Z00?o
`03ooookJ_oonfX00ooonfX00ooo0:?ooo]ZoookJP02oookJP;oobP01ooonfX00ol:o`3ooo]Zoook
JP02oookJPSoobP000?ooh`0oookJ_oonfX01OoonfX00onUo`3ooo]ZoookJP06oookJP03okoo0?oo
nf[ooo]Z00Gooo]Z00?oo`0koookJ_oonfX00ooonfX00ol0og[ooo]Zo`2Ao`03oookJP03ool0c_l0
on;ooo]Z00Wooo]Z00Go08coogh0oooonf[ooo]Zool:000;oookJP03ool0o?ooN@3oogT000CoogT0
0_oonfX00ol0oiWooo]ZoookJP0<oookJP03oolX0?oonf[ooo]Z00[ooo]Z00?o0?mloookJ_oonfX0
3?oonfX01?l00_oo0000o`000?l00004oookJP03oml0oomFo`3oobP000;oobP000?omOl0oookJ_oo
nfX01OoonfX00ooo:03ooi`0oolX0007oolX0005oomV0?oo:03oobP0oookJ_l0o`004_oonfX00ooo
<@3ooo]ZoookJP0?oookJP03ooo=0?oo0;[ooo]Z00_ooo]Z00?o0;OooookJ_oonfX02ooonfX2oiD0
o`oooo]Z3OooN@1@oookJPCoog<0D?oonfX00ol0oOoooo]ZoookJP05oookJP05ool0XOoonf[ooo]Z
oookJ_ooX0000ooonfX00on30?oo03Ooo`0go`02oookJP04o`08oooonf[ooo]Zoom300?ooo]Z00?o
0?;ooookJ_oonfX01?oonfX00ol0ok?ooo]ZoookJP02oookJP04o`3Eoooo02_ooo]Zo`3o]P[ooo]Z
00?o`03ooookJ_oonfX01?oonfX00ooo0:?ooo]ZoookJP02oookJP03ool0QOoonf[ooo]Z00Kooo]Z
00Go2_l0oookJ_oonf[ooo]Zoomk0003oookJP05olGo0?oonf[ooo]ZoookJ_ooS0001ooonfX00ol0
obCoYOl0oookJP06oookJP03okoo0?oonf[ooo]Z00Kooo]Z00?oo`0koookJ_oonfX00_oonfX01?l0
og[ooo]ZoookJ_l0TOl3oookJP03ool0c_l0on;ooo]Z00Sooo]Z00?o08cooookJ_mn0?l00_oonfX0
0ooo2P3ooo]ZoookJP09oookJP05ool0o?oonf[ooo]ZoookJ_ood`000ooonfX00ol0oiWooo]Zoook
JP0<oookJP03oom80?oonf[ooo]Z00[ooo]Z00?o0?mloookJ_oonfX03?oonfX01?l0003o00;oo`00
0?l00005oookJP05oml0oooonf[o01[oo`0]oooeo`002?oonfX01?ooW03ooo]ZoookJ_l0VOl5oook
JP05oomV0?oonf[ooo]ZoookJ_l0o`004_oonfX00ooo<@3ooo]ZoookJP0@oookJP03ooo=0?oo0;[o
oo]Z00[ooo]Z00?o0;OooookJ_oonfX02ooonfX2oiD0oaGooo]Z1?ooL`1DoookJPCoog<09?oonfX0
02kooo]Z00?o0?gooookJ_oonfX01OoonfX00ooo0:7ooo]ZoookJP02oonP00;ooo]Z00?oP`3ooook
J_l0=ol00ooonfX00ol02?oooo]Zooo90002oolX0003oookJ_oo:03ooo]Z00Kooo]Z00Oo0?ncoook
J_oonf[ooo]Zo`3Eoooo02_ooo]Z00;o0?nf2_oonfX00oo00?oooo]ZoookJP03oookJP03ool0Xooo
nf[ooo]Z00;ooo]Z00?oobP0oookJ_oonfX01_oonfX00ol:o`3ooo]ZoookJP02oookJPSoobP000?o
oh`0oookJ_oonfX01OoonfX00onUo`3ooo]ZoookJP06oookJP03okoo0?oonf[ooo]Z00Gooo]Z00?o
o`0koookJ_oonfX00ooonfX00ol0og[ooo]Zo`2Ao`03oookJP03ool0c_l0on;ooo]Z00[ooo]Z00Go
08coogh0oooonf[ooo]Zool:000:oookJP03ool0o?oonf[oogT000CoogT00_oonfX00ol0oiWooo]Z
oookJP0=oookJP03oom80?oonf[ooo]Z00[ooo]Z00?o0?mloookJ_oonfX03?oonfX01?l00_oo0000
o`000?l00004oookJP06oml0oomFo`3oobP0oolX0?oeo`3oobP01ooonfX00ooo:03ooi`0oolX0005
oolX0004oookJ_oo:03oofH0oolX00;ooo]Z00?o0?l0oookJ_oonfX04?oonfX00ooo<@3ooo]Zoook
JP0@oookJP03ooo=0?oo0;[ooo]Z00_ooo]Z00?o0;OooookJ_oonfX03?oonfX2oiD0o`cooo]Z4?oo
N@18oookJPKoog<0DooonfX00ol0oOoooo]ZoookJP05oookJP05ool0XOoonf[ooo]ZoookJ_ooX000
0ooonfX00on30?oo03OooookJP02oookJP04o`08oooonf[oolT0oom300?ooo]Z00?o0?;ooookJ_oo
nfX01?oonfX00ol0ok?ooo]ZoookJP02oookJP04o`3Eoooo02_ooo]Zo`3o]P[ooo]Z00?o`03ooook
J_oonfX01?oonfX00ooo0:?ooo]ZoookJP02oookJP03ool0QOoonf[ooo]Z00Kooo]Z00Go2_l0oook
J_oonf[ooo]Zoomk0003oookJP05olGo0?oonf[ooo]ZoookJ_ooS0001ooonfX00ol0obCoYOl0oook
JP06oookJP03okoo0?oonf[ooo]Z00Kooo]Z00?oo`0koookJ_oonfX00_oonfX01?l0og[ooo]Zoook
J_l0TOl3oookJP03ool0c_l0on;ooo]Z00Wooo]Z00?o08coogh0oooonfX00_oonfX00ooo2P3ooo]Z
oookJP08oookJP05ool0o?oonf[ooo]ZoookJ_ood`001?oonfX00ol0oiWooo]ZoookJP0<oookJP03
oom80?oonf[ooo]Z00[ooo]Z00?o0?mloookJ_oonfX03?oonfX01?l0003o00;oo`000?l00005oook
JP05oml0ool06_oo02gooookJ_oeo`002?oonfX01?ooW03ooo]Zoe/0ool0VOl5oookJP05oomV0?oo
nf[ooo]ZoookJ_l0o`004_oonfX00ooo<@3ooo]ZoookJP0AoookJP03ooo=0?oo0;[ooo]Z00[ooo]Z
00?o0;OooookJ_oonfX03?oonfX3oiD0oaKooo]Z1?ooL`19oookJPOoog<0:?oonfX002gooo]Z00?o
0?gooookJ_oonfX01OoonfX01?oo0:7ooo]ZoookJ_ooX003oookJP05oh<0oooonf[o03OooookJ_oo
N@000_l02?l00ooonf[oolT0oolX0003oolX00Oooo]Z00So0?ncoookJ_oonf[ooo]Zo`3Eoooo02_o
oo]Zo`3o]P_ooo]Z00?o`03ooookJ_oonfX00ooonfX00ooo0:?ooo]ZoookJP02oookJP03oolX0?oo
nf[ooo]Z00Oooo]Z00Go2_l0oookJ_oonf[ooo]Zoomk0007oolX0003oon<0?oonf[ooo]Z00Gooo]Z
00?o0?lTojGo0?oonfX01_oonfX00onoo`3ooo]ZoookJP05oookJP03ool0>ooonf[ooo]Z00?ooo]Z
00?o0?mjoookJ_l0TOl00ooonfX00ooo0<ko0?oRoookJP0:oookJP05o`2<oomn0?oooo]ZoookJ_oo
2P002_oonfX00ooo0?cooo]ZoookJP04oomi00;ooo]Z00?o0?nIoookJ_oonfX03OoonfX00oooB03o
oo]ZoookJP0;oookJP03o`3oO?oonf[ooo]Z00cooo]Z00Co00;oo`000?l0003o00000ooonfX00ooO
0?ooE_l0oookJP02oolX0003ooGo0?oonf[ooo]Z00Oooo]Z00?ooi`0oolX0?oo:0001?oo:0001?oo
nf[oobP0oomV0?oo:002oookJP03o`3o0?oonf[ooo]Z013ooo]Z00?ooc40oookJ_oonfX04?oonfX0
0oooc@3ooo]Zool0^P0<oookJP03o`2goooonf[ooo]Z00gooo]Z0_nE0?l:oookJQ7oogT01oooL`0j
oookJPKoog<0F?oonfX00ol0oOoooo]ZoookJP05oookJP05ool0XOoonf[ooo]ZoookJ_ooX0000_oo
nfX2oh<0o`08o`0goooonf[ooo]ZoookJ_l02?oooo]Zooo90?oo@`03oookJP03o`3boooonf[ooo]Z
00Cooo]Z00Co0?ncoookJ_oonf[ooo]Z0_l0eOl00ooo02_ooo]Zo`3o]P0:oookJP03ol00oooonf[o
oo]Z00Cooo]Z00?oo`2SoookJ_oonfX00_oonfX00ooo08Gooo]ZoookJP07oookJP04o`[o0?oonf[o
oo]Zoomk00?ooo]Z00GoaOl0oookJ_oonf[ooo]Zoon<0007oookJP03o`3o9?nUo`3ooo]Z00Kooo]Z
00?o_ol0oookJ_oonfX01_oonfX00ooo03_ooo]ZoookJP02oookJP04o`3oN_oonf[ooo]Zo`2Ao`?o
oo]Z00?oo`3>o`3oh_oonfX02OoonfX00ol0S?ooOP3ooookJP02oookJP03ool:0?oonf[ooo]Z00So
oo]Z00Goo`3loookJ_oonf[ooo]ZoooC0004oookJP03o`3oVOoonf[ooo]Z00cooo]Z00?oodP0oook
J_oonfX02ooonfX00ol0ogcooo]ZoookJP0<oookJP04o`02ool0003o0000o`0000Cooo]Z00Kog`3o
oookJ_l06_oo02gooookJ_oeo`08oookJP04oonL0?oonf[oF`3oo`2Io`Gooo]Z00GoofH0oookJ_oo
nf[ooo]Zo`3o000CoookJP03oola0?oonf[ooo]Z013ooo]Z00?oold0oookJ_oo0;X02ooonfX00ol0
]ooooo]ZoookJP0>oookJP;oU@3o6?oonfX9oomc03[ooo]Z1_ooL`0_oookJP00;?oonfX00ol0oOoo
oo]ZoookJP05oookJP04ool0XOoonf[ooo]ZoonP00?ooo]Z00?oP`3ooookJ_l0=ol00_oonfX2oomi
0003oookJ_oob@3oobP000GoobP01OoonfX02?l0ok?ooo]ZoookJ_oonf[o0=Goool0:ooonf[o0?nf
2ooonfX00oo00?oooo]ZoookJP03oookJP03ool0Xooonf[ooo]Z00?ooo]Z00?oo`25oookJ_oonfX0
1_oonfX01Ol:o`3ooo]ZoookJ_oonf[oog/000KoobP000?ooo]Zoon<0?oonfX01_oonfX00ol0obCo
YOl0oookJP06oookJP03okoo0?oonf[ooo]Z00Kooo]Z00?oo`0koookJ_oonfX00_oonfX00ol0og[o
oo]Zo`2Ao`03oookJP03ool0c_l0on;ooo]Z00[ooo]Z00Go08coogh0oooonf[ooo]Zool:000;oook
JP03ool0o?oonf[oogT000?oogT00ooonfX00ol0oiWooo]ZoookJP0<oookJP03oom80?oonf[ooo]Z
00_ooo]Z00?o0?mloookJ_oonfX03?oonfX00ol00_oo0000o`000002o`0000?ooo]Z00?og`3ooeKo
0?l06_l00_oo:0000ooeo`3ooo]ZoookJP06oookJP03oonL0?oo:03oobP000CoobP00_oonfX00ooo
:03oofH0oolX0002oookJP03o`3o0?oonf[ooo]Z017ooo]Z00?ooc40oookJ_oonfX04?oonfX00ooo
c@3oo`2joookJP0<oookJP;o0;Oo3ooonfX2oiD0ob3ooo]Z3OooL`0QoookJPcoog<0GOoonfX00ol0
oOoooo]ZoookJP05oookJP05ool0XOoonf[ooo]ZoookJ_ooX0000_oonfX00on30?oooo]Zo`0go`03
oookJP04o`08oooonf[oolT0oom300?ooo]Z00?o0?;ooookJ_oonfX01?oonfX02Ol0ok?ooo]Zoook
J_oonf[o0=GooookJ_oo02_ooo]Zo`3o]P0:oookJP03ol00oooonf[ooo]Z00Cooo]Z00?oo`2Soook
J_oonfX00_oonfX00ooo08Gooo]ZoookJP07oookJP04o`[o0?oonf[ooo]Zoomk00?ooo]Z00GoaOl0
oookJ_oonf[ooo]Zoon<0007oookJP03o`3o9?nUo`3ooo]Z00Kooo]Z00?o_ol0oookJ_oonfX01ooo
nfX01Ooo03_ooo]ZoookJ_oonf[o0?mj00;ooo]Z00Ko097ooookJ_oonf[ooo]Zool0c_l0on8:oook
JP03o`2<oooonf[oOP3o00;ooo]Z00?oo`X0oookJ_oonfX02?oonfX00ooo0?cooo]ZoookJP02oook
JP05oooC0?oonf[ooo]ZoookJ_l0oiT03ooonfX00oooB03ooo]ZoookJP0:oookJP03o`3oO?oonf[o
oo]Z00gooo]Z00Co00;oo`000?l0003o00001?oonfX01_oO0?oooo]Zo`0Jool0;Ooooo]ZooGo00Oo
oo]Z00Gooi`0oookJ_oonf[oF`3oo`2Io`05oookJP05oomV0?oonf[ooo]ZoookJ_l0o`004ooonfX0
0ooo<@3ooo]ZoookJP0AoookJP03ooo=0?oo0;[ooo]Z00_ooo]Z0_l0]ol@oookJP;oU@3o7ooonfX>
oomc023ooo]Z3?ooL`0eoookJP00:ooonfX00ol0oOoooo]ZoookJP05oookJP04ool0XOoonf[ooo]Z
oonP00?ooo]Z00?oP`3ooookJ_l0=ol00_oonfX5oomi00OoobP00ooonfX02?l0ok?ooo]ZoookJ_oo
nf[o0=Goool0:ooonf[o0?nf2ooonfX00oo00?oooo]ZoookJP03oookJP03ool0Xooonf[ooo]Z00?o
oo]Z00?oo`25oookJ_oonfX01_oonfX01_l:o`3ooo]ZoookJ_oonf[oog/0oookJPGoobP000?ooo]Z
oon<0?oonfX01ooonfX00onUo`3ooo]ZoookJP06oookJP03okoo0?oonf[ooo]Z00Gooo]Z00?oo`0k
oookJ_oonfX00ooonfX00ol0og[ooo]Zo`2Ao`03oookJP03ool0c_l0on;ooo]Z00Wooo]Z00Go08co
oookJ_mn0?oooo]Zool:000;oookJP03ool0o?oonf[ooo]Z00?oogT00ooonfX00ol0oiWooo]Zoook
JP0=oookJP03oom80?oonf[ooo]Z00_ooo]Z00?o0?mloookJ_oonfX03?oonfX00ol00_oo0000o`00
0002o`0000?ooo]Z00?og`3ooeKo0?l06_l00_oo:0000ooeo`3ooo]ZoookJP06oookJP03oonL0?oo
:03oobP000CoobP00_oonfX00ooo:03oofH0oolX0002oookJP03o`3o0?oonf[ooo]Z017ooo]Z00?o
oc40oookJ_oonfX04OoonfX00oooc@3oo`2joookJP0=oookJP03o`2goooonf[ooo]Z00kooo]Z0onE
0?lZoookJR7oog<0J?oonfX00ol0oOoooo]ZoookJP05oookJP05ool0XOoonf[ooo]ZoookJ_ooX000
0_oonfX00on30?oooo]Zo`0go`03oookJP04o`08oooonf[oolT0oom300?ooo]Z00?o0?;ooookJ_oo
nfX01?oonfX02Ol0ok?ooo]ZoookJ_oonf[o0=GooookJ_oo02_ooo]Zo`3o]P0:oookJP03ol00oooo
nf[ooo]Z00Cooo]Z00?oo`2SoookJ_oonfX00_oonfX00ooo08Gooo]ZoookJP07oookJP04o`[o0?oo
nf[ooo]Zoomk00?ooo]Z00?oaOl0oookJ_oonfX00_oonfX00oooS03ooo]ZoookJP05oookJP03ojGo
0?oonf[ooo]Z00Kooo]Z00?o_ol0oookJ_oonfX01_oonfX00ooo03_ooo]ZoookJP02oookJP04o`3o
N_oonf[ooo]Zo`2Ao`?ooo]Z00?oo`3>o`3oh_oonfX02?oonfX00ol0S?oooo]Zogh0o`02oookJP03
ool:0?oonf[ooo]Z00Wooo]Z00Goo`3loookJ_oonf[ooo]ZoooC0004oookJP03o`3oVOoonf[ooo]Z
00cooo]Z00?oodP0oookJ_oonfX02ooonfX00ol0ogcooo]ZoookJP0<oookJP03o`02ool0003o0000
00;o00001?oonfX01OoO0?oooo]Zo`0Jool0;OoomOl000Sooo]Z00Gooi`0oookJ_oonf[oF`3oo`2I
o`05oookJP05oomV0?oonf[ooo]ZoookJ_l0o`004ooonfX00ooo<@3ooo]ZoookJP0BoookJP03ooo=
0?oo0;[ooo]Z00cooo]Z00?o0;OooookJ_oonfX03ooonfX2oiD0ob_ooo]Z8?ooL`11oookJP00:_oo
nfX00ol0oOoooo]ZoookJP05oookJP04ool0XOoonf[ooo]ZoonP00?ooo]Z00?oP`3ooookJ_l0=ol0
0_oonfX5oomi00WoobP000?ooo]Zo`3o/ooonfX00_oonfX01?l0eOooo`0[oookJ_l0okH;oookJP03
ol00oooonf[ooo]Z00?ooo]Z00?oo`2SoookJ_oonfX00ooonfX00ooo08Gooo]ZoookJP06oookJP06
o`[o0?oonf[ooo]ZoookJ_ooN`3ooo]Z1?oo:002oookJP03oon<0?oonf[ooo]Z00Kooo]Z00?oYOl0
oookJ_oonfX01_oonfX00onoo`3ooo]ZoookJP05oookJP03ool0>ooonf[ooo]Z00?ooo]Z00?o0?mj
oookJ_l0TOl00ooonfX00ooo0<ko0?oRoookJP0:oookJP05o`2<oomn0?oooo]ZoookJ_oo2P002_oo
nfX01?oo0?cooo]ZoookJ_oonfX2oomi00?ooo]Z00?o0?nIoookJ_oonfX03OoonfX00oooB03ooo]Z
oookJP0;oookJP03o`3oO?oonf[ooo]Z00gooo]Z00?o00;oo`000?l000000_l00003oookJP05oml0
oooonf[o01[ooolX0?oeo`002OoonfX00oooW03oobP0oolX0003oolX00Cooo]Z00GoofH0oookJ_oo
nf[ooo]Zo`3o000CoookJP03oola0?oonf[ooo]Z01;ooo]Z00?oold0ool0^_oonfX03OoonfX2o`2g
oa7ooo]Z0_nE0?n`oookJP03o`3moooonf[ooo]Z00Gooo]Z00?oo`2QoookJ_oonfX00_ooX002oook
JP03oh<0oooonf[o03Oo00?ooo]Z00Co00SooookJ_oob@3ood<00ooonfX00ol0l_oooo]ZoookJP04
oookJP09o`3o/ooonf[ooo]ZoookJ_l0eOoooo]Zool0:ooonf[o0?nf00[ooo]Z00?o`03ooookJ_oo
nfX01?oonfX00ooo0:?ooo]ZoookJP02oookJP03ool0QOoonf[ooo]Z00Oooo]Z00Co2_l0oookJ_oo
nf[oog/00ooonfX00oo5o`3ooo]ZoookJP02oookJP03oon<0?oonf[ooo]Z00Gooo]Z00?oYOl0oook
J_oonfX01_oonfX00onoo`3ooo]ZoookJP06oookJP03ool0>ooonf[ooo]Z00;ooo]Z00Co0?mjoook
J_oonf[o097o0ooonfX00ooo0<ko0?oRoookJP09oookJP05o`2<oomn0?oooo]ZoookJ_oo2P002ooo
nfX00ooo0?cooo]ZoookJP02oookJP05oooC0?oonf[ooo]ZoookJ_l0oiT03ooonfX00oooB03ooo]Z
oookJP0:oookJP03o`3oO?oonf[ooo]Z00gooo]Z00?o00;oo`000?l000000_l00003oookJP06oeKo
0?oO0?oo01[oo`0]oooonf[omOl02?oonfX01OooW03ooo]ZoookJ_mK0?oo09Wo00Gooo]Z00GoofH0
oookJ_oonf[ooo]Zo`3o000DoookJP03oola0?oonf[ooo]Z01;ooo]Z00?oold0ool0^_oonfX03?oo
nfX2o`2goa7ooo]Z0onE0?n9oookJP00<OoonfX01?oo0:7ooo]ZoookJ_ooX003oookJP03oh<0oooo
nf[o03Oo00;ooo]Z00?o00Sooomi0?ooN@000_ooN@08oolX00;ooo]Z00So0?ncoookJ_oonf[ooo]Z
o`3Eoooo02_ooo]Zo`3o]P_ooo]Z00?o`03ooookJ_oonfX00ooonfX00ooo0:?ooo]ZoookJP03oook
JP03ool0QOoonf[ooo]Z00Kooo]Z00?o2_l0oookJ_oonfX00_oonfX00oooN`3ooo]ZoolX0002oolX
00;ooo]Z00?ooh`0oookJ_oonfX01_oonfX00onUo`3ooo]ZoookJP06oookJP03okoo0?oonf[ooo]Z
00Gooo]Z00?oo`0koookJ_oonfX00ooonfX00ol0og[ooo]Zo`2Ao`03oookJP03ool0c_l0on;ooo]Z
00[ooo]Z00Go08coogh0oooonf[ooo]Zool:000;oookJP03ool0o?oonf[ooo]Z00;oogT01?oonfX0
0ol0oiWooo]ZoookJP0=oookJP03oom80?oonf[ooo]Z00_ooo]Z00?o0?mloookJ_oonfX03?oonfX0
0ol00_oooo]Zo`000003o`0000;ooo]Z00Kog`3ooeKo0?l06_oooo]ZoolX0?oeo`09oookJP03oonL
0?oo:03oobP000?oobP01?oonfX01OooIP3ooo]ZoookJ_oonf[o0?l001?ooo]Z00?ooc40oookJ_oo
nfX04ooonfX00oooc@3oo`2joookJP0>oookJP03o`2goooonf[ooo]Z013ooo]Z0onE0?ndoookJP04
ool0XOoonf[ooo]ZoonP00?ooo]Z00?oP`3ooookJ_l0=ol00ooonfX01?l02?oooo]Zooo90?oo@`03
oookJP03o`3boooonf[ooo]Z00Cooo]Z00Wo0?ncoookJ_oonf[ooo]Zo`3Eoooonf[oo`0[oookJ_l0
okH02_oonfX00oo00?oooo]ZoookJP04oookJP03ool0Xooonf[ooo]Z00;ooo]Z00?oo`25oookJ_oo
nfX01ooonfX01Ol:o`3ooo]ZoookJ_oonf[oog/000;ooo]Z00?oaOl0oookJ_oonfX00_oonfX00ooo
S03ooo]ZoookJP05oookJP03o`3o9?nUo`3ooo]Z00Kooo]Z00?o_ol0oookJ_oonfX01_oonfX00ooo
03_ooo]ZoookJP02oookJP04o`3oN_oonf[ooo]Zo`2Ao`?ooo]Z00?oo`3>o`3oh_oonfX02OoonfX0
0ol0S?ooOP3ooookJP02oookJP03ool:0?oonf[ooo]Z00Sooo]Z00?oo`3loookJ_oonfX00_oonfX0
0oood`3ooo]ZoookJP02oookJP03o`3oVOoonf[ooo]Z00cooo]Z00?oodP0oookJ_oonfX02ooonfX0
0ol0ogcooo]ZoookJP0=oookJP03o`02ool0003o000000;o00000ooonfX01_oO0?oooo]Zo`0Jool0
;Ooooo]ZooGo00Sooo]Z00Gooi`0oookJ_oonf[oF`3oo`2Io`05oookJP05oomV0?oonf[ooo]Zoook
J_l0o`005?oonfX00ooo<@3ooo]ZoookJP0CoookJP03ooo=0?oo0;[ooo]Z00gooo]Z00?o0;Oooook
J_oonfX04OoonfX2oiD0ohOooo]Z000`oookJP04ool0XOoonf[ooo]ZoonP00?ooo]Z00?oP`3ooook
J_l0=ol00_oonfX00ol02?ooogT0oomi0002oomi00OoobP00ooonfX02?l0ok?ooo]ZoookJ_oonf[o
0=Goool0:ooonf[o0?nf2ooonfX00oo00?oooo]ZoookJP03oookJP03ool0Xooonf[ooo]Z00?ooo]Z
00?oo`25oookJ_oonfX01_oonfX00ol:o`3ooo]ZoookJP02oookJP03oomk0?oonf[oobP000;oobP0
0_oonfX00oooS03ooo]ZoookJP06oookJP03ojGo0?oonf[ooo]Z00Kooo]Z00?o_ol0oookJ_oonfX0
1OoonfX00ooo03_ooo]ZoookJP03oookJP03o`3oN_oonf[o097o00?ooo]Z00?oo`3>o`3oh_oonfX0
2_oonfX01Ol0S?ooOP3ooookJ_oonf[oo`X000_ooo]Z00Goo`3loookJ_oonf[ooo]Zoomi0004oook
JP03o`3oVOoonf[ooo]Z00gooo]Z00?oodP0oookJ_oonfX01ooonfX2oomi00;ooo]Z00?oogT0oook
J_oonfX03OoonfX00ol00_oooo]Zo`000003o`0000;ooo]Z00Kog`3ooeKo0?l06_oooo]Zo`0]oooe
o`09oookJP03oonL0?oo:03oobP000?oobP00ooonfX00oooIP3oY03ooookJP02oookJP03o`3o0?oo
nf[ooo]Z01;ooo]Z00?ooc40oookJ_oonfX04ooonfX00oooc@3oo`2joookJP0>oookJP03o`2goooo
nf[ooo]Z01;ooo]Z0_nE0?naoookJP04ool0XOoonf[ooo]ZoonP00?ooo]Z00?oP`3ooookJ_l0=ol0
0ooonfX01?l02?oooo]Zooo90?oo@`03oookJP03o`3boooonf[ooo]Z00Cooo]Z00Wo0?ncoookJ_oo
nf[ooo]Zo`3Eoooonf[oo`0[oookJ_l0okH02_oonfX00oo00?oooo]ZoookJP04oookJP03ool0Xooo
nf[ooo]Z00;ooo]Z00?oo`25oookJ_oonfX01ooonfX01Ol:o`3ooo]ZoookJ_oonf[oog/000;ooo]Z
00?oaOl0oookJ_oonfX00_oonfX00oooS03ooo]ZoookJP05oookJP03o`3o9?nUo`3ooo]Z00Kooo]Z
00?o_ol0oookJ_oonfX01_oonfX00ooo03_ooo]ZoookJP02oookJP04o`3oN_oonf[ooo]Zo`2Ao`?o
oo]Z00?oo`3>o`3oh_oonfX02OoonfX00ol0S?oooo]Zogh0o`02oookJP03ool:0?oonf[ooo]Z00So
oo]Z00?oo`3loookJ_oonfX00_oonfX00oood`3ooo]ZoookJP02oookJP03o`3oVOoonf[ooo]Z00go
oo]Z00?oodP0oookJ_oonfX02_oonfX00ol0ogcooo]ZoookJP0=oookJP03o`02oooonf[o000000?o
00000ooonfX01_oO0?oooo]Zo`0Jool0;Ooooo]ZooGo00Sooo]Z00Gooi`0oookJ_oonf[oF`3oo`2I
o`04oookJP03oomV0?nT0?oooo]Z00;ooo]Z00?o0?l0oookJ_oonfX04_oonfX00ooo<@3ooo]Zoook
JP0DoookJP03ooo=0?oonf[ooo]Z00gooo]Z00?o0;OooookJ_oonfX04_oonfX2oiD0ohGooo]Z000_
oookJP04ool0XOoonf[ooo]ZoonP00?ooo]Z00?oP`3ooookJ_l0=ol00_oonfX00ol02?oooo]Zoomi
0003oomi00KoobP00ooonfX02?l0ok?ooo]ZoookJ_oonf[o0=Goool0:ooonf[o0?nf2ooonfX00oo0
0?oooo]ZoookJP03oookJP03ool0Xooonf[ooo]Z00?ooo]Z00?oo`25oookJ_oonfX01_oonfX00ol:
o`3ooo]ZoookJP02oookJP04oomk0?oonf[ooo]ZoolX00Cooo]Z00?ooh`0oookJ_oonfX01OoonfX0
0onUo`3ooo]ZoookJP06oookJP03okoo0?oonf[ooo]Z00Kooo]Z00?oo`0koookJ_oonfX00_oonfX0
1?l0og[ooo]ZoookJ_l0TOl2oookJP03ool0c_l0on;ooo]Z00[ooo]Z00?o08cooookJ_mn0?l00_oo
nfX00ooo2P3ooo]ZoookJP08oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Goom<0oookJ_oonf[ooo]Z
o`3oV@0?oookJP03oom80?oonf[ooo]Z00Sooo]Z1OooN@0?oookJP03o`02oooonf[o000000?o0000
0_oonfX01_oO0?oooo]Zo`0Joooonf[o02goooGo00Sooo]Z00?ooi`0oookJ_oo:0000ooo:004oook
JP03oomV0?nT0?oooo]Z00;ooo]Z00?o0?l0oookJ_oonfX04_oonfX00ooo<@3ooo]ZoookJP0Coook
JP03ooo=0?oonf[oo`2j00oooo]Z0_l0]olDoookJP?oU@3o[OoonfX01?oo0:7ooo]ZoookJ_ooX003
oookJP03oh<0oooonf[o03Oo00?ooo]Z00Co00SooookJ_oob@3ood<00ooonfX00ol0l_oooo]Zoook
JP04oookJP09o`3o/ooonf[ooo]ZoookJ_l0eOoooo]Zool0:ooonf[o0?nf00[ooo]Z00?o`03ooook
J_oonfX01?oonfX00ooo0:?ooo]ZoookJP02oookJP03ool0QOoonf[ooo]Z00Oooo]Z00Go2_l0oook
J_oonf[ooo]Zoomk0002oookJP03olGo0?oonf[ooo]Z00;ooo]Z00?ooh`0oookJ_oonfX01OoonfX0
0ol0obCoYOl0oookJP06oookJP03okoo0?oonf[ooo]Z00Kooo]Z00?oo`0koookJ_oonfX00_oonfX0
1Ol0og[ooo]ZoookJ_oonf[o097o00;ooo]Z00?oo`3>o`3oh_oonfX02OoonfX00ol0S?oooo]Zogh0
o`02oookJP03ool:0?oonf[ooo]Z00Wooo]Z00?oo`3loookJ_oonfX00_oonfX01Oood`3ooo]Zoook
J_oonf[o0?nI00oooo]Z00?oodP0oookJ_oonfX02ooonfX00ol0ogcooo]ZoookJP0=oookJP03o`02
oooonf[o000000?o00000_oonfX01omFo`3og`3ooookJ_l06_oo02gooookJ_oeo`001ooonfX01Ooo
W03ooo]ZoookJ_oonf[o09Wo00Gooo]Z00?oofH0oj@0oooonfX00_oonfX00ol0o`3ooo]ZoookJP0C
oookJP03oola0?oonf[ooo]Z01?ooo]Z00?oold0ool0^_oonfX03_oonfX2o`2goaCooo]Z0onE0?n2
oookJP00;_oonfX01?oo0:7ooo]ZoookJ_ooX003oookJP03oh<0oooonf[o03Oo00;ooo]Z00?o00So
oookJ_ooN@000oooN@05oolX00Cooo]Z00So0?ncoookJ_oonf[ooo]Zo`3Eoooo02_ooo]Zo`3o]P_o
oo]Z00?o`03ooookJ_oonfX00ooonfX00ooo0:?ooo]ZoookJP03oookJP03ool0QOoonf[ooo]Z00Ko
oo]Z00?o2_l0oookJ_oonfX00_oonfX01?ooN`3ooo]ZoookJ_oo:004oookJP03oon<0?oonf[ooo]Z
00Gooo]Z00?o0?lTojGo0?oonfX01_oonfX00onoo`3ooo]ZoookJP06oookJP03ool0>ooonf[ooo]Z
00?ooo]Z00?o0?mjoookJ_l0TOl00_oonfX00ooo0<kooo]Zo`3ohP0;oookJP05o`2<oomn0?oooo]Z
oookJ_oo2P002_oonfX00ooo0?cooo]ZoookJP02oookJP03oooC0?oonf[ooo]Z00;ooo]Z00?o0?nI
oookJ_oonfX03OoonfX00oooB03ooo]ZoookJP08oookJPOoogT03?oonfX00ol00_oooo]ZoookJP04
o`000007oookJ_oO0?ooE_l0o`0Joooonf[o02goooGo0009oookJP03oonL0?oonf[oobP000?oobP0
1?oonfX00oooIP3oY03ooookJP02oookJP03o`3o0?oonf[ooo]Z01;ooo]Z00?ooc40oookJ_oonfX0
5?oonfX00oooc@3ooo]Zool0^P0@oookJP03o`2goooonf[ooo]Z01Cooo]Z0_nE0?nZoookJP04ool0
XOoonf[ooo]ZoonP00?ooo]Z00?oP`3ooookJ_l0=ol00ooonfX01?l02?oooo]Zooo90?oo@`03oook
JP03o`3boooonf[ooo]Z00Cooo]Z00Wo0?ncoookJ_oonf[ooo]Zo`3Eoooonf[oo`0[oookJ_l0okH0
2_oonfX00oo00?oooo]ZoookJP04oookJP03ool0Xooonf[ooo]Z00;ooo]Z00?oo`25oookJ_oonfX0
1ooonfX01Ol:o`3ooo]ZoookJ_oonf[oog/000;ooo]Z00?oaOl0oookJ_oonfX00_oonfX00oooS03o
oo]ZoookJP05oookJP03o`3o9?nUo`3ooo]Z00Kooo]Z00?o_ol0oookJ_oonfX01_oonfX00ooo03_o
oo]ZoookJP03oookJP04o`3oN_oonf[ooo]Zo`2Ao`;ooo]Z00?oo`3>o`3oh_oonfX02_oonfX01Ol0
S?ooOP3ooookJ_oonf[oo`X000_ooo]Z00?oo`3loookJ_oonfX00_oonfX00oood`3ooo]ZoookJP02
oookJP03o`3oVOoonf[ooo]Z00cooo]Z00?oodP0oookJ_oonfX02ooonfX00ol0ogcooo]ZoookJP0=
oookJP03o`02oooonf[ooo]Z00Co00000_oonfX01_oO0?oooo]Zo`0Jool0;Ooooo]ZooGo00Sooo]Z
00Gooi`0oookJ_oonf[ooo]Zo`2Io`05oookJP03oomV0?nT0?oooo]Z00;ooo]Z00?o0?l0oookJ_oo
nfX04ooonfX00ooo<@3ooo]ZoookJP0DoookJP03ooo=0?oo0;[ooo]Z00oooo]Z00?o0;OooookJ_oo
nfX05?oonfX3oiD0ogoooo]Z000]oookJP04ool0XOoonf[ooo]ZoonP00?ooo]Z00?oP`3ooookJ_l0
=ol00_oonfX00ol02?oooo]Zoomi0003oomi00CoobP01OoonfX02?l0ok?ooo]ZoookJ_oonf[o0=Go
ool0:ooonf[o0?nf2ooonfX00oo00?oooo]ZoookJP03oookJP03ool0Xooonf[ooo]Z00?ooo]Z00?o
o`25oookJ_oonfX01_oonfX00ol:o`3ooo]ZoookJP02oookJP05oomk0?oonf[ooo]ZoookJ_o5o`00
0ooonfX00oooS03ooo]ZoookJP05oookJP03o`3o9?nUo`3ooo]Z00Kooo]Z00?o_ol0oookJ_oonfX0
1_oonfX00ooo03_ooo]ZoookJP03oookJP03o`3oN_oonf[o097o00?ooo]Z00?oo`3>o`3oh_oonfX0
2_oonfX01Ol0S?ooOP3ooookJ_oonf[oo`X000_ooo]Z00Goo`3loookJ_oonf[ooo]ZoooC0004oook
JP03o`3oVOoonf[ooo]Z00gooo]Z00?oodP0oookJ_oonfX02?oonfX9oomi00_ooo]Z00?o00;ooook
J_oonfX01?l000001ooonf[og`3ooeKo0?l06_oooo]Zo`0]oooeo`002OoonfX00oooW03ooo]Zoook
JP02oolX00Gooo]Z00GoofH0oj@0oooonf[ooo]Zo`3o000FoookJP03oola0?oonf[ooo]Z01Cooo]Z
00?oold0oookJ_oo0;X04?oonfX00ol0]ooooo]ZoookJP0EoookJP?oU@3oY_oonfX01?oo0:7ooo]Z
oookJ_ooX003oookJP03oh<0oooonf[o03Oo00?ooo]Z00Co00SooookJ_oob@3ood<00ooonfX00ol0
l_oooo]ZoookJP04oookJP09o`3o/ooonf[ooo]ZoookJ_l0eOoooo]Zool0:ooonf[o0?nf00[ooo]Z
00?o`03ooookJ_oonfX01?oonfX00ooo0:?ooo]ZoookJP02oookJP03ool0QOoonf[ooo]Z00Oooo]Z
00Go2_l0oookJ_oonf[ooo]Zoomk0003oookJP05olGo0?oonf[ooo]ZoookJ_ooS0001ooonfX00ol0
obCoYOl0oookJP06oookJP03okoo0?oonf[ooo]Z00Oooo]Z00?oo`0koookJ_oonfX00_oonfX01?l0
og[ooo]ZoookJ_l0TOl3oookJP03ool0c_l0on;ooo]Z00Wooo]Z00?o08coogh0oooonfX00_oonfX0
0ooo2P3ooo]ZoookJP08oookJP03ool0o?oonf[ooo]Z00;ooo]Z00?oom<0oookJ_oonfX00_oonfX0
0ol0oiWooo]ZoookJP0=oookJP03oom80?oonf[ooo]Z00_ooo]Z00?o0?mloookJ_oonfX03OoonfX0
0ol00_oooo]ZoookJP04o`0000;ooo]Z00Kog`3ooookJ_l06_oo02gooookJ_oeo`08oookJP05oonL
0?oonf[ooo]ZoookJ_l0VOl01OoonfX00oooIP3oY03ooookJP02oookJP03o`3o0?oonf[ooo]Z01Co
oo]Z00?ooc40oookJ_oonfX05?oonfX00oooc@3oo`2joookJP0?oookJP;o0;Oo5ooonfX3oiD0ogco
oo]Z000/oookJP04ool0XOoonf[ooo]ZoonP00?ooo]Z00?oP`3ooookJ_l0=ol00_oonfX00ol02?oo
oo]ZoookJP04oomi00;oobP01_oonfX02?l0ok?ooo]ZoookJ_oonf[o0=Goool0:ooonf[o0?nf2ooo
nfX00oo00?oooo]ZoookJP04oookJP03ool0Xooonf[ooo]Z00;ooo]Z00?oo`25oookJ_oonfX01_oo
nfX00ol:o`3ooo]ZoookJP02oookJP05oomk0?oonf[ooo]ZoookJ_o5o`000ooonfX00oooS03ooo]Z
oookJP05oookJP03o`3o9?nUo`3ooo]Z00Kooo]Z00?o_ol0oookJ_oonfX01_oonfX00ooo03_ooo]Z
oookJP03oookJP03o`3oN_oonf[o097o00?ooo]Z00?oo`3>o`3oh_oonfX02_oonfX01Ol0S?oooo]Z
ogh0oooonf[oo`X000_ooo]Z00?oo`3loookJ_oonfX00_oonfX01Oood`3ooo]ZoookJ_oonf[o0?nI
013ooo]Z00?oodP0oookJ_oonfX02?oonfX9oomi00_ooo]Z00?o00;ooookJ_oonfX01Ol000001_oO
0?oooo]Zo`0Joooonf[o02goooGo00Wooo]Z00?ooi`0oookJ_oonfX00_oo:005oookJP05oomV0?nT
0?oooo]ZoookJ_l0o`005_oonfX00ooo<@3ooo]ZoookJP0EoookJP03ooo=0?oonf[oo`2j013ooo]Z
0_l0]olHoookJP?oU@3oX_oonfX01?oo0:7ooo]ZoookJ_ooX003oookJP03oh<0oooonf[o03Oo00?o
oo]Z00Co00SooookJ_oob@3ood<00ooonfX00ol0l_oooo]ZoookJP04oookJP09o`3o/ooonf[ooo]Z
oookJ_l0eOoooo]Zool0:ooonf[o0?nf00[ooo]Z00?o`03ooookJ_oonfX01?oonfX00ooo0:?ooo]Z
oookJP02oookJP03ool0QOoonf[ooo]Z00Oooo]Z00Go2_l0oookJ_oonf[ooo]Zoomk0003oookJP05
olGo0?oonf[ooo]ZoookJ_ooS0001ooonfX00ol0obCoYOl0oookJP06oookJP03okoo0?oonf[ooo]Z
00Oooo]Z00?oo`0koookJ_oonfX00_oonfX01?l0og[ooo]ZoookJ_l0TOl3oookJP03ool0c_l0on;o
oo]Z00Wooo]Z00?o08cooookJ_mn0?l00_oonfX00ooo2P3ooo]ZoookJP08oookJP03ool0o?oonf[o
oo]Z00?ooo]Z00Goom<0oookJ_oonf[ooo]Zo`3oV@0?oookJP03oom80?oonf[ooo]Z00_ooo]Z00?o
0?mloookJ_oonfX03_oonfX00ol00_oooo]ZoookJP05o`000007oeKo0?oO0?oooo]Zo`0Jool0;Ooo
oo]ZooGo0008oookJP05oonL0?oonf[ooo]ZoookJ_l0VOl01OoonfX00oooIP3oY03ooookJP02oook
JP03o`3o0?oonf[ooo]Z01Cooo]Z00?ooc40oookJ_oonfX05OoonfX00oooc@3oo`2joookJP0@oook
JP03o`2goooonf[ooo]Z01Oooo]Z0onE0?mioookJP00:ooonfX01?oo0:7ooo]ZoookJ_ooX003oook
JP03oh<0oooonf[o03Oo00;ooo]Z00?o00SooookJ_oonfX01?ooN@02oolX00Kooo]Z00So0?ncoook
J_oonf[ooo]Zo`3Eoooo02_ooo]Zo`3o]P_ooo]Z00?o`03ooookJ_oonfX01?oonfX00ooo0:?ooo]Z
oookJP02oookJP03ool0QOoonf[ooo]Z00Kooo]Z00?o2_l0oookJ_oonfX00_oonfX01OooN`3ooo]Z
oookJ_oonf[oaOl000?ooo]Z00?ooh`0oookJ_oonfX01_oonfX00onUo`3ooo]ZoookJP05oookJP03
oolX0?oonf[ooo]Z00Kooo]Z00?oo`0koookJ_oonfX00ooonfX00ol0og[ooo]Zo`2Ao`03oookJP03
ool0c_l0on;ooo]Z00[ooo]Z00?o08cooookJ_mn0?l00_oonfX00ooo2P3ooo]ZoookJP08oookJP03
ool0o?oonf[ooo]Z00;ooo]Z00?oom<0oookJ_oonfX00_oonfX00ol0oiWooo]ZoookJP0=oookJP03
oom80?oonf[ooo]Z00Wooo]Z2?ooN@0;oookJP04o`02oooonf[ooo]ZoookJPCo000000Oog`3ooeKo
0?oonf[o01[ooookJ_l0;OoomOl000Wooo]Z00?ooi`0oookJ_oonfX00_oo:005oookJP05oomV0?oo
nf[ooo]ZoookJ_l0o`005_oonfX00ooo<@3ooo]ZoookJP0FoookJP03ooo=0?oonf[oo`2j017ooo]Z
00?o0;OooookJ_oonfX06?oonfX5oiD0oicooo]Z00Coo`2QoookJ_oonf[ooj000ooonfX00on30?oo
oo]Zo`0go`03oookJP04o`08oooonf[oolT0oom300?ooo]Z00?o0?;ooookJ_oonfX01?oonfX02Ol0
ok?ooo]ZoookJ_oonf[o0=GooookJ_oo02_ooo]Zo`3o]P0;oookJP03ol00oooonf[ooo]Z00?ooo]Z
00?oo`2SoookJ_oonfX00_oonfX00ooo08Gooo]ZoookJP07oookJP05o`[o0?oonf[ooo]ZoookJ_oo
N`000ooonfX01Oo5o`3ooo]ZoookJ_oonf[ooh`000Sooo]Z00?oYOl0oookJ_oonfX01OoonfX00ono
o`3ooo]ZoookJP07oookJP03ool0>ooonf[ooo]Z00;ooo]Z00Co0?mjoookJ_oonf[o097o0ooonfX0
0ooo0<ko0?oRoookJP09oookJP03o`2<oooonf[oOP3o00;ooo]Z00?oo`X0oookJ_oonfX02OoonfX0
0ooo0?cooo]ZoookJP02oookJP05oooC0?oonf[ooo]ZoookJ_l0oiT04?oonfX00oooB03ooo]Zoook
JP0;oookJP03o`3oO?oonf[ooo]Z00gooo]Z00Co00;ooookJ_oonf[ooo]Z1?l000002?oonf[og`3o
oookJ_oonf[o01[oo`0]oooonf[omOl02?oonfX01OooW03ooo]ZoookJ_mK0?oo09Wo00Gooo]Z00?o
ofH0oookJ_oonfX00_oonfX00ol0o`3ooo]ZoookJP0DoookJP03oola0?oonf[ooo]Z01Kooo]Z00?o
old0ool0^_oonfX04?oonfX2o`2goa[ooo]Z1?nE0?meoookJP00:_oonfX01?oo0:7ooo]ZoookJ_oo
X003oookJP03oh<0ool0=ooo03Oo00;ooo]Z00Co00SooookJ_oonf[oolT00_ooN@000ooonf[oobP0
oookJP06oookJP08o`3o/ooonf[ooo]ZoookJ_l0eOooo`0[oookJ_l0okH;oookJP03ol00oooonf[o
oo]Z00Cooo]Z00?oo`2SoookJ_oonfX00_oonfX00ooo08Gooo]ZoookJP06oookJP03o`[o0?oonf[o
oo]Z00;ooo]Z00Goog/0oookJ_oonf[ooo]ZolGo0003oookJP03oon<0?oonf[ooo]Z00Kooo]Z00?o
YOl0oookJ_oonfX01_oonfX00ooo:03ooo]ZoookJP05oookJP03ool0>ooonf[ooo]Z00?ooo]Z00Co
0?mjoookJ_oonf[o097o0_oonfX00ooo0<ko0?oRoookJP0:oookJP03o`2<oooonf[oOP3o00;ooo]Z
00?oo`X0oookJ_oonfX02OoonfX01Ooo0?cooo]ZoookJ_oonf[oom<000Cooo]Z00?o0?nIoookJ_oo
nfX03OoonfX00oooB03ooo]ZoookJP0:oookJPOoogT03?oonfX01?l00_oooo]ZoookJ_oonfX4o`00
0006oml0oomFo`3o01[ooookJ_l0;OoomOl02_oonfX01?ooW03ooo]ZoookJ_oo:006oookJP05oomV
0?oonf[ooo]ZoookJ_l0o`005ooonfX00ooo<@3ooo]ZoookJP0FoookJP03ooo=0?oonf[oo`2j017o
oo]Z00?o0;OooookJ_oonfX07?oonfX4oiD0oc?ooo]Z1?oob@1PoookJP04ool0XOoonf[ooo]ZoonP
00?ooo]Z00?oP`3oo`0gool0=ol00ooonfX01?l02?oooo]Zooo90?oo@`02oookJP;o0?;o1_oonfX0
2Ol0ok?ooo]ZoookJ_oonf[o0=GooookJ_oo02_ooo]Zo`3o]P0;oookJP03ol00oooonf[ooo]Z00?o
oo]Z00?oo`2SoookJ_oonfX00_oonfX00ooo08Gooo]ZoookJP07oookJP05o`[o0?oonf[ooo]Zoook
J_ooN`000ooonfX01Oo5o`3ooo]ZoookJ_oonf[ooh`000Sooo]Z00?oYOl0oookJ_oonfX01_oonfX0
0onoo`3ooo]ZoookJP06oookJP03ool0>ooonf[ooo]Z00;ooo]Z00Go0?mjoookJ_oonf[ooo]Zo`2A
o`02oookJP03ool0c_l0on;ooo]Z00[ooo]Z00Go08coogh0oooonf[ooo]Zool:000;oookJP03ool0
o?oonf[ooo]Z00;ooo]Z00?oom<0oookJ_oonfX00_oonfX00ol0oiWooo]ZoookJP0=oookJP03oom8
0?oonf[ooo]Z00_ooo]Z00?o0?mloookJ_oonfX03_oonfX01?l00_oooo]ZoookJ_oonfX4o`000007
oookJ_oO0?oooo]Zo`0Jool0;Ooooo]ZooGo0009oookJP05oonL0?oonf[ooo]Zoe/0ool0VOl01Ooo
nfX00oooIP3ooo]ZoookJP02oookJP03o`3o0?oonf[ooo]Z01Gooo]Z00?ooc40oookJ_oonfX05_oo
nfX00oooc@3oo`2joookJP0AoookJP03o`2goooonf[ooo]Z01_ooo]Z1?nE0?maoookJP00;?oonfX0
1_ooX03ooo]ZoookJ_oonf[oP`3oo`0go`?ooo]Z00Go00SooookJ_oonf[oolT0oomi0002oookJP03
o`3boooonf[ooo]Z00Gooo]Z00So0?ncoookJ_oonf[ooo]Zo`3Eoooo02_ooo]Zo`3o]P_ooo]Z00?o
`03ooookJ_oonfX01?oonfX00ooo0:?ooo]ZoookJP02oookJP03ool0QOoonf[ooo]Z00Oooo]Z00Go
2_l0oookJ_oonf[ooo]Zoomk0003oookJP05olGo0?oonf[ooo]ZoookJ_ooS0002?oonfX00onUo`3o
oo]ZoookJP06oookJP03oolX0?oonf[ooo]Z00Kooo]Z00?oo`0koookJ_oonfX00ooonfX00ol0og[o
oo]Zo`2Ao`02oookJP03ool0c_oonf[o0?oR00_ooo]Z00Go08coogh0oooonf[ooo]Zool:000;oook
JP05ool0o?oonf[ooo]ZoookJ_ood`001?oonfX00ol0oiWooo]ZoookJP0>oookJP03oom80?oonf[o
oo]Z00[ooo]Z1_ooN@0=oookJP04o`02oooonf[ooo]ZoookJPCo000000Kog`3ooookJ_l06_oooo]Z
o`0]oooeo`09oookJP05oonL0?oonf[ooo]ZoookJ_l0VOl01_oonfX01OooIP3ooo]ZoookJ_oonf[o
0?l001Oooo]Z00?ooc40oookJ_oonfX05ooonfX00oooc@3ooo]Zool0^P0AoookJP;o0;Oo8?oonfX5
oiD0obkooo]Z2Ooob@1MoookJP06oonP0?oonf[ooo]ZoookJ_n30?oo03Oo1?oonfX01?l02?oooo]Z
ooo90?oo@`02oookJP03o`3boooonf[ooo]Z00Gooo]Z00Wo0?ncoookJ_oonf[ooo]Zo`3Eoooonf[o
o`0[oookJ_l0okH02ooonfX00oo00?oooo]ZoookJP03oookJP03ool0Xooonf[ooo]Z00;ooo]Z00?o
o`25oookJ_oonfX02?oonfX01?l:o`3ooo]ZoookJ_ooN`03oookJP05olGo0?oonf[ooo]ZoookJ_oo
S0002?oonfX00onUo`3ooo]ZoookJP06oookJP03okoo0?oonf[ooo]Z00Kooo]Z00?oo`0koookJ_oo
nfX00ooonfX01?l0og[ooo]ZoookJ_l0TOl2oookJP03ool0c_l0on;ooo]Z00[ooo]Z00Go08coogh0
oooonf[ooo]Zool:000;oookJP03ool0o?oonf[ooo]Z00;ooo]Z00?oom<0oookJ_oonfX00_oonfX0
0ol0oiWooo]ZoookJP0>oookJP03oom80?oonf[ooo]Z00_ooo]Z00?o0?mloookJ_oonfX03_oonfX0
1?l00_oooo]ZoookJ_oonfX4o`000007oeKo0?oO0?oooo]Zo`0Jool0;Ooooo]ZooGo0008oookJP06
oonL0?oonf[ooo]ZoookJ_mK0?oo09Wo1OoonfX00oooIP3ooo]ZoookJP02oookJP03o`3o0?oonf[o
oo]Z01Gooo]Z00?ooc40oookJ_oonfX05ooonfX00oooc@3oo`2joookJP0AoookJP;o0;Oo7ooonfX5
oiD0ofcooo]Z000[oookJP06oonP0?oonf[ooo]ZoookJ_n30?oo03Oo0ooonfX01Ol02?oooo]Zoook
J_oo@`3oogT000;ooo]Z00?o0?;ooookJ_oonfX01OoonfX02?l0ok?ooo]ZoookJ_oonf[o0=Gooook
J_oo02_o0?nf2ooonfX00oo00?oooo]ZoookJP04oookJP03ool0Xooonf[ooo]Z00;ooo]Z00?oo`25
oookJ_oonfX01ooonfX01Ol:o`3ooo]ZoookJ_oonf[oog/000?ooo]Z00?oaOl0oookJ_oonfX00_oo
nfX00oooS03ooo]ZoookJP05oookJP03ojGo0?oonf[ooo]Z00Kooo]Z00?oobP0oookJ_oonfX01_oo
nfX00ooo03_ooo]ZoookJP03oookJP03o`3oN_oonf[o097o00;ooo]Z00?oo`3>oookJ_l0on802ooo
nfX00ol0S?oooo]Zogh0o`02oookJP03ool:0?oonf[ooo]Z00Sooo]Z00?oo`3loookJ_oonfX00_oo
nfX00oood`3ooo]ZoookJP02oookJP03o`3oVOoonf[ooo]Z00gooo]Z00?oodP0oookJ_oonfX02_oo
nfX6oomi00gooo]Z00?o00;ooookJ_oonfX00_oonfX3o`000007oml0oomFo`3ooo]Zo`0Joooonf[o
02goooGo0009oookJP05oonL0?oonf[ooo]Zoe/0ool0VOl01_oonfX01OooIP3ooo]ZoookJ_oonf[o
0?l001Oooo]Z00?ooc40oookJ_oonfX05ooonfX01?ooc@3ooo]ZoookJ_oo0;XBoookJP;o0;Oo8ooo
nfX7oiD0obOooo]Z3_oob@06oookJPGoU@3oC?oonfX01_ooX03ooo]ZoookJ_oonf[oP`3oo`0go`?o
oo]Z0_l02?l00ooonf[ood<0oom30002oookJP03o`3boooonf[ooo]Z00Gooo]Z00Wo0?ncoookJ_oo
nf[ooo]Zo`3Eoooonf[oo`0[oookJ_l0okH02ooonfX00oo00?oooo]ZoookJP03oookJP03ool0Xooo
nf[ooo]Z00;ooo]Z00?oo`25oookJ_oonfX02?oonfX01?l:o`3ooo]ZoookJ_ooN`03oookJP03olGo
0?oonf[ooo]Z00;ooo]Z00?ooh`0oookJ_oonfX01OoonfX00onUo`3ooo]ZoookJP06oookJP03okoo
0?oonf[ooo]Z00Kooo]Z00?oo`0koookJ_oonfX00ooonfX01?l0og[ooo]ZoookJ_l0TOl2oookJP03
ool0c_l0on;ooo]Z00[ooo]Z00?o08cooookJ_mn0?l00_oonfX00ooo2P3ooo]ZoookJP08oookJP03
ool0o?oonf[ooo]Z00?ooo]Z00Goom<0oookJ_oonf[ooo]Zo`3oV@0@oookJP03oom80?oonf[ooo]Z
00_ooo]Z00?o0?mloookJ_oonfX03_oonfX00ol00_oooo]ZoookJP02oookJPCo000000Oog`3ooook
J_oonf[o01[oo`0]oooonf[omOl000Sooo]Z00Kooi`0oookJ_oonf[ooo]Zoe/0ool0VOl5oookJP03
oomV0?oonf[ooo]Z00;ooo]Z00?o0?l0oookJ_oonfX05OoonfX00ooo<@3ooo]ZoookJP0GoookJP03
ooo=0?oonf[oo`2j01?ooo]Z00?o0;OooookJ_oonfX08OoonfX7oiD0occooo]Z1OnE0?lToookJP00
:_oonfX01_ooX03ooo]ZoookJ_oonf[oP`3oo`0go`?ooo]Z00Co00SooookJ_oonf[ood<00ooonfX0
0ol0l_oooo]ZoookJP05oookJP08o`3o/ooonf[ooo]ZoookJ_l0eOoooo]Zool0:ol0okH;oookJP03
ol00oooonf[ooo]Z00Cooo]Z00?oo`2SoookJ_oonfX00_oonfX00ooo08Gooo]ZoookJP07oookJP05
o`[o0?oonf[ooo]ZoookJ_ooN`000ooonfX00oo5o`3ooo]ZoookJP02oookJP03oon<0?oonf[ooo]Z
00Gooo]Z00?o0?lTojGo0?oonfX01_oonfX00ooo:03ooo]ZoookJP06oookJP03ool0>ooonf[ooo]Z
00?ooo]Z00?o0?mjoookJ_l0TOl00ooonfX00ooo0<ko0?oRoookJP0:oookJP03o`2<oooonf[oOP3o
00;ooo]Z00?oo`X0oookJ_oonfX02OoonfX01Ooo0?cooo]ZoookJ_oonf[oom<000Cooo]Z00?o0?nI
oookJ_oonfX03_oonfX00oooB03ooo]ZoookJP0:oookJPGoogT03_oonfX00ol00_oooo]ZoookJP02
oookJP?o000000?og`3ooeKo0?l06_l00_oonfX00ol0;OoomOl0oookJP08oookJP05oonL0?oonf[o
oo]Zoe/0ool0VOl01_oonfX01OooIP3ooo]ZoookJ_oonf[o0?l001Sooo]Z00?ooc40oookJ_oonfX0
5ooonfX00oooc@3ooo]Zool0^P0DoookJP;o0;Oo:?oonfX;oiD0oacooo]Z4?oob@04oiD0oe3ooo]Z
00Kooj00oookJ_oonf[ooo]Zoh<0ool0=ol3oookJP04o`08oooonf[ooo]Zoom300?ooo]Z00?o0?;o
oookJ_oonfX01OoonfX02Ol0ok?ooo]ZoookJ_oonf[o0=GooookJ_oo02_ooo]Zo`3o]P0;oookJP03
ol00oooonf[ooo]Z00?ooo]Z00?oo`2SoookJ_oonfX00_oonfX00ooo08Gooo]ZoookJP08oookJP04
o`[o0?oonf[ooo]Zoomk00?ooo]Z00?oaOl0oookJ_oonfX00_oonfX00oooS03ooo]ZoookJP05oook
JP03o`3o9?nUo`3ooo]Z00Kooo]Z00?o_ol0oookJ_oonfX01_oonfX00ooo03_ooo]ZoookJP03oook
JP04o`3oN_oonf[ooo]Zo`2Ao`?ooo]Z00?oo`3>oookJ_oonfX02OoonfX00ol0S?oooo]Zogh0o`02
oookJP03ool:0?oonf[ooo]Z00Wooo]Z00?oo`3loookJ_oonfX00_oonfX00oood`3ooo]ZoookJP02
oookJP03o`3oVOoonf[ooo]Z00kooo]Z00?oodP0oookJ_oonfX02ooonfX00ol0ogcooo]ZoookJP0>
oookJP03o`02oooonf[ooo]Z00;ooo]Z1?l000001ooO0?oooo]Zo`0Joooonf[o02gooookJ_oeo`00
2?oonfX01_ooW03ooo]ZoookJ_oonf[oF`3oo`2Io`Gooo]Z00?oofH0oookJ_oonfX00_oonfX00ol0
o`3ooo]ZoookJP0FoookJP03oola0?oonf[ooo]Z01Oooo]Z00?oold0oookJ_oo0;X04ooonfX2o`2g
obSooo]Z2onE0?lRoookJPooU@3o:OoonfX002gooo]Z00?oP`3oo`0goooonfX00_oonfX01?l02?oo
oo]ZoookJ_oo@`03oookJP03o`3boooonf[ooo]Z00Gooo]Z00So0?ncoookJ_oonf[ooo]Zo`3Eoooo
nf[oo`0[o`3o]P_ooo]Z00?o`03ooookJ_oonfX01?oonfX00ooo0:?ooo]ZoookJP02oookJP03ool0
QOoonf[ooo]Z00Oooo]Z00Go2_l0oookJ_oonf[ooo]Zoomk0003oookJP03olGo0?oonf[ooo]Z00;o
oo]Z00?ooh`0oookJ_oonfX01OoonfX00ol0obCoYOl0oookJP06oookJP03oolX0?oonf[ooo]Z00Ko
oo]Z00?oo`0koookJ_oonfX00ooonfX00ol0og[ooo]Zo`2Ao`03oookJP03ool0c_l0on;ooo]Z00[o
oo]Z00?o08cooookJ_mn0?l00_oonfX00ooo2P3ooo]ZoookJP09oookJP05ool0o?oonf[ooo]Zoook
J_ood`001OoonfX00ol0oiWooo]ZoookJP0=oookJP03oom80?oonf[ooo]Z00_ooo]Z1OooN@0>oook
JP03o`02oooonf[ooo]Z00;ooo]Z0ol000001ooO0?oooo]Zo`0Joooonf[o02gooookJ_oeo`002Ooo
nfX01?ooW03ooo]ZoookJ_l0VOl6oookJP03oomV0?nT0?oooo]Z00;ooo]Z00?o0?l0oookJ_oonfX0
5_oonfX00ooo<@3ooo]ZoookJP0HoookJP03ooo=0?oonf[oo`2j01Gooo]Z00?o0;OooookJ_oonfX0
<?oonfXHoiD0oa;oolT0FOoonfX00on30?oo03OooookJP02oookJP04o`08oooonf[ooo]Zoom300?o
oo]Z00?o0?;ooookJ_oonfX01OoonfX02Ol0ok?ooo]ZoookJ_oonf[o0=GooookJ_oo02_ooo]Zo`3o
]P0;oookJP03ol00oooonf[ooo]Z00?ooo]Z00?oo`2SoookJ_oonfX00_oonfX00ooo08Gooo]Zoook
JP08oookJP04o`[o0?oonf[ooo]Zoomk00?ooo]Z00?oaOl0oookJ_oonfX00_oonfX00oooS03ooo]Z
oookJP05oookJP03o`3o9?nUo`3ooo]Z00Kooo]Z00?o_ol0oookJ_oonfX01ooonfX00ooo03_ooo]Z
oookJP02oookJP04o`3oN_oonf[ooo]Zo`2Ao`?ooo]Z00?oo`3>o`3oh_oonfX02_oonfX01Ol0S?oo
OP3ooookJ_oonf[oo`X000_ooo]Z00?oo`3loookJ_oonfX00_oonfX00oood`3ooo]ZoookJP02oook
JP03o`3oVOoonf[ooo]Z00kooo]Z00?oodP0oookJ_oonfX03?oonfX00ol0ogcooo]ZoookJP0>oook
JP03o`02oooonf[ooo]Z00;ooo]Z0ol000001OmFo`3og`3ooookJ_l06_oo02go00;ooo]Z00?omOl0
oookJ_oonfX01_oonfX01OooW03ooo]ZoookJ_oonf[o09Wo00Gooo]Z00?oofH0oj@0oooonfX00ooo
nfX00ol0o`3ooo]ZoookJP0FoookJP03oola0?oonf[ooo]Z01Sooo]Z00?oold0oookJ_oo0;X05?oo
nfX2o`2goc7ooo]Z8_nE0?lhoookJP00;?oonfX00on30?oo03OooookJP02oookJP04o`08oooonf[o
oo]Zoom300?ooo]Z00?o0?;ooookJ_oonfX01OoonfX02?l0ok?ooo]ZoookJ_oonf[o0=GooookJ_oo
02_o0?nf2ooonfX00oo00?oooo]ZoookJP04oookJP03ool0Xooonf[ooo]Z00;ooo]Z00?oo`25oook
J_oonfX01ooonfX01Ol:o`3ooo]ZoookJ_oonf[oog/000?ooo]Z00?oaOl0oookJ_oonfX00_oonfX0
0oooS03ooo]ZoookJP05oookJP03o`3o9?nUo`3ooo]Z00Kooo]Z00?oobP0oookJ_oonfX01_oonfX0
0ooo03_ooo]ZoookJP03oookJP04o`3oN_oonf[ooo]Zo`2Ao`;ooo]Z00?oo`3>oookJ_l0on802_oo
nfX00ol0S?oooo]Zogh0o`02oookJP03ool:0?oonf[ooo]Z00Wooo]Z00?oo`3loookJ_oonfX00_oo
nfX00oood`3ooo]ZoookJP02oookJP03o`3oVOoonf[ooo]Z00kooo]Z00?oodP0oookJ_oonfX02ooo
nfX4oomi00kooo]Z00?o00;ooookJ_oonfX00ooonfX2o`000007oml0oomFo`3ooo]Zo`0Joooonf[o
02goooGo000:oookJP04oonL0?oonf[ooo]Zo`2Io`Kooo]Z00?oofH0oj@0oooonfX00_oonfX00ol0
o`3ooo]ZoookJP0FoookJP03oola0?oonf[ooo]Z01Wooo]Z00?oold0oookJ_oo0;X05OoonfX2o`2g
odgooo]Z2_oob@1KoookJP03oh<0ool0=ooooo]Z00;ooo]Z00Co00SooookJ_oonf[ood<00ooonfX0
0ol0l_oooo]ZoookJP05oookJP09o`3o/ooonf[ooo]ZoookJ_l0eOoooo]Zool0:ooonf[o0?nf00_o
oo]Z00?o`03ooookJ_oonfX00ooonfX00ooo0:?ooo]ZoookJP02oookJP03ool0QOoonf[ooo]Z00So
oo]Z00Go2_l0oookJ_oonf[ooo]Zoomk0002oookJP03olGo0?oonf[ooo]Z00;ooo]Z00?ooh`0oook
J_oonfX01OoonfX00ol0obCoYOl0oookJP06oookJP03okoo0?oonf[ooo]Z00Oooo]Z00?oo`0koook
J_oonfX00_oonfX01?l0og[ooo]ZoookJ_l0TOl3oookJP03ool0c_l0on;ooo]Z00[ooo]Z00Go08co
ogh0oooonf[ooo]Zool:000;oookJP03ool0o?oonf[ooo]Z00?ooo]Z00Goom<0oookJ_oonf[ooo]Z
o`3oV@0AoookJP03oom80?oonf[ooo]Z00_ooo]Z00?o0?mloookJ_oonfX03_oonfX00ol00_oooo]Z
oookJP03oookJP?o000000Oog`3ooookJ_oonf[o01[oo`0]oooonf[omOl000Wooo]Z00Gooi`0oook
J_oonf[ooo]Zo`2Io`05oookJP03oomV0?nT0?oooo]Z00?ooo]Z00?o0?l0oookJ_oonfX05_oonfX0
0ooo<@3ooo]ZoookJP0IoookJP03ooo=0?oonf[oo`2j01Gooo]Z00?o0;OooookJ_oonfX0R?oonfX0
02_ooo]Z00?oP`3oo`0goooonfX00_oonfX01?l02?oooo]ZoookJ_oo@`03oookJP03o`3boooonf[o
oo]Z00Gooo]Z00So0?ncoookJ_oonf[ooo]Zo`3Eoooonf[oo`0[o`3o]P_ooo]Z00?o`03ooookJ_oo
nfX01?oonfX00ooo0:?ooo]ZoookJP02oookJP03ool0QOoonf[ooo]Z00Oooo]Z00Go2_l0oookJ_oo
nf[ooo]Zoomk0003oookJP03olGo0?oonf[ooo]Z00;ooo]Z00?ooh`0oookJ_oonfX01_oonfX00onU
o`3ooo]ZoookJP05oookJP03oolX0?oonf[ooo]Z00Oooo]Z00?oo`0koookJ_oonfX00ooonfX00ol0
og[ooo]Zo`2Ao`02oookJP03ool0c_oonf[o0?oR00_ooo]Z00?o08cooookJ_mn0?l00_oonfX00ooo
2P3ooo]ZoookJP08oookJP03ool0o?oonf[ooo]Z00;ooo]Z00?oom<0oookJ_oonfX00_oonfX00ol0
oiWooo]ZoookJP0>oookJP03oom80?oonf[ooo]Z00cooo]Z0oooN@0?oookJP03o`02oooonf[ooo]Z
00?ooo]Z0_l000000ooO0?ooE_l0o`0Jo`02oookJP03o`0]oooeo`3ooo]Z00Sooo]Z00Gooi`0oook
J_oonf[ooo]Zo`2Io`06oookJP03oomV0?nT0?oooo]Z00;ooo]Z00?o0?l0oookJ_oonfX05ooonfX0
0ooo<@3ooo]ZoookJP0IoookJP03ooo=0?oonf[oo`2j01Kooo]Z0_l0]om;oookJPOoolT0GOoonfX0
0on30?oo03OooookJP02oookJP04o`08oooonf[ooo]Zoom300?ooo]Z00?o0?;ooookJ_oonfX01Ooo
nfX02Ol0ok?ooo]ZoookJ_oonf[o0=GooookJ_oo02_ooo]Zo`3o]P0;oookJP03ol00oooonf[ooo]Z
00?ooo]Z00?oo`2SoookJ_oonfX00_oonfX00ooo08Gooo]ZoookJP08oookJP05o`[o0?oonf[ooo]Z
oookJ_ooN`000_oonfX00oo5o`3ooo]ZoookJP02oookJP03oon<0?oonf[ooo]Z00Kooo]Z00?oYOl0
oookJ_oonfX01OoonfX00onoo`3ooo]ZoookJP07oookJP03ool0>ooonf[ooo]Z00?ooo]Z00?o0?mj
oookJ_l0TOl00ooonfX00ooo0<ko0?oRoookJP0:oookJP03o`2<oooonf[oOP3o00;ooo]Z00?oo`X0
oookJ_oonfX02OoonfX00ooo0?cooo]ZoookJP02oookJP05oooC0?oonf[ooo]ZoookJ_l0oiT04Ooo
nfX00oooB03ooo]ZoookJP0<oookJP03o`3oO?oonf[ooo]Z00kooo]Z00?o00;ooookJ_oonfX00ooo
nfX3o`000007oml0oooonf[o01[ooookJ_l0;Ooooo]ZooGo0008oookJP03oonL0?oonf[ooo]Z00;o
oo]Z00?o09WooookJ_oonfX00ooonfX00oooIP3oY03ooookJP03oookJP03o`3o0?oonf[ooo]Z01Ko
oo]Z00?ooc40oookJ_oonfX06_oonfX00oooc@3ooo]Zool0^P0EoookJP;o0;OoR?oonfX002[ooo]Z
00?oP`3oo`0goooonfX00_oonfX01?l02?oooo]ZoookJ_oo@`03oookJP03o`3boooonf[ooo]Z00Go
oo]Z00So0?ncoookJ_oonf[ooo]Zo`3Eoooonf[oo`0[o`3o]P_ooo]Z00?o`03ooookJ_oonfX01?oo
nfX00ooo0:?ooo]ZoookJP02oookJP03ool0QOoonf[ooo]Z00Oooo]Z00Go2_l0oookJ_oonf[ooo]Z
oomk0003oookJP03olGo0?oonf[ooo]Z00;ooo]Z00?ooh`0oookJ_oonfX01_oonfX00onUo`3ooo]Z
oookJP05oookJP03oolX0?oonf[ooo]Z00Oooo]Z00?oo`0koookJ_oonfX00ooonfX00ol0og[ooo]Z
o`2Ao`03oookJP03ool0c_l0on;ooo]Z00[ooo]Z00?o08cooookJ_mn0?l00_oonfX00ooo2P3ooo]Z
oookJP09oookJP05ool0o?oonf[ooo]ZoookJ_ood`001OoonfX00ol0oiWooo]ZoookJP0=oookJP03
oom80?oonf[ooo]Z00cooo]Z0oooN@0@oookJP03o`02oooonf[ooo]Z00?ooo]Z0_l000001ooO0?oo
0000o`0Joooonf[o02gooookJ_oeo`002OoonfX01OooW03ooo]ZoookJ_oonf[o09Wo00Kooo]Z00?o
ofH0oj@0oooonfX00_oonfX00ol0o`3ooo]ZoookJP0GoookJP03oola0?oonf[ooo]Z01[ooo]Z00?o
old0oookJ_oo0;X05ooonfX3o`2godSooo]Z1?oob@1OoookJP03oh<0ool0=ooooo]Z00;ooo]Z00Co
00SooookJ_oonf[ood<00ooonfX00ol0l_oooo]ZoookJP05oookJP09o`3o/ooonf[ooo]ZoookJ_l0
eOoooo]Zool0:ooonf[o0?nf00_ooo]Z00?o`03ooookJ_oonfX00ooonfX00ooo0:?ooo]ZoookJP02
oookJP03ool0QOoonf[ooo]Z00Sooo]Z00Go2_l0oookJ_oonf[ooo]Zoomk0002oookJP03olGo0?oo
nf[ooo]Z00;ooo]Z00?ooh`0oookJ_oonfX01_oonfX00onUo`3ooo]ZoookJP05oookJP03okoo0?oo
nf[ooo]Z00Oooo]Z00?oo`0koookJ_oonfX00ooonfX01?l0og[ooo]ZoookJ_l0TOl2oookJP03ool0
c_l0on;ooo]Z00_ooo]Z00Go08coogh0oooonf[ooo]Zool:000;oookJP03ool0o?oonf[ooo]Z00;o
oo]Z00?oom<0oookJ_oonfX00_oonfX00ol0oiWooo]ZoookJP0>oookJP03oom80?oonf[ooo]Z00co
oo]Z00?o0?mloookJ_oonfX03ooonfX00ol00_oooo]ZoookJP03oookJP;o000000SoE_l0oml0oooo
nf[o01[ooookJ_l0;Ooooo]ZooGo00Sooo]Z00?ooi`0oookJ_oonfX00_oonfX00ol0VOoooo]Zoook
JP03oookJP03oomV0?nT0?oooo]Z00;ooo]Z00?o0?l0oookJ_oonfX06?oonfX00ooo<@3ooo]Zoook
JP0JoookJP03ooo=0?oonf[oo`2j01Kooo]Z0ol0]on5oookJP00:_oonfX01Ol0=ooooo]ZoookJ_oo
nf[o00So00;ooo]Z00Good<0oookJ_oonf[ooo]Zo`3bo`07oookJP08o`3o/ooonf[ooo]ZoookJ_l0
eOoooo]Zool0:ol0okH;oookJP03ol00oooonf[ooo]Z00Cooo]Z00?oo`2SoookJ_oonfX00_oonfX0
0ooo08Gooo]ZoookJP07oookJP05o`[o0?oonf[ooo]ZoookJ_ooN`000ooonfX00oo5o`3ooo]Zoook
JP02oookJP03oon<0?oonf[ooo]Z00Kooo]Z00?oYOl0oookJ_oonfX00_oo:004oookJP03oolX0?oo
nf[ooo]Z00Kooo]Z00?oo`0koookJ_oonfX00ooonfX00ol0og[ooo]Zo`2Ao`03oookJP03ool0c_l0
on;ooo]Z00[ooo]Z00?o08cooookJ_mn0?l00_oonfX00ooo2P3ooo]ZoookJP09oookJP05ool0o?oo
nf[ooo]ZoookJ_ood`001OoonfX00ol0oiWooo]ZoookJP0>oookJP03oom80?oonf[ooo]Z00cooo]Z
0_ooN@0@oookJP03o`02oooonf[ooo]Z00Cooo]Z00Wo0000oml0oomFo`3o0000o`0Joooonf[o02go
oookJ_oeo`002OoonfX01OooW03ooo]ZoookJ_mK0?oo09Wo00Kooo]Z00?oofH0oj@0oooonfX00_oo
nfX00ol0o`3ooo]ZoookJP0GoookJP03oola0?oonf[ooo]Z01_ooo]Z0_ooc@000ooo0;[ooo]Zoook
JP0GoookJP;o0;OoA_oonfX00ooob@3ooo]ZoookJP1PoookJP05o`0goooonf[ooo]ZoookJ_l02?l0
0_oonfX01Ooo@`3ooo]ZoookJ_oonf[o0?;o00Oooo]Z00Wo0?ncoookJ_oonf[ooo]Zo`3Eoooonf[o
o`0[oookJ_l0okH02ooonfX00oo00?oooo]ZoookJP03oookJP03ool0Xooonf[ooo]Z00;ooo]Z00?o
o`25oookJ_oonfX02?oonfX01Ol:o`3ooo]ZoookJ_oonf[oog/000;ooo]Z00?oaOl0oookJ_oonfX0
0_oonfX00oooS03ooo]ZoookJP06oookJP03ojGo0?oonf[ooo]Z00Kooo]Z00?o_ol0oookJ_oonfX0
1_oonfX00ooo03_ooo]ZoookJP03oookJP04o`3oN_oonf[ooo]Zo`2Ao`;ooo]Z00?oo`3>o`3oh_oo
nfX02ooonfX01Ol0S?ooOP3ooookJ_oonf[oo`X000_ooo]Z00?oo`3loookJ_oonfX00_oonfX00ooo
d`3ooo]ZoookJP02oookJP03o`3oVOoonf[ooo]Z00oooo]Z00?oodP0oookJ_oonfX03?oonfX00ol0
ogcooo]ZoookJP0>oookJP03o`02oooonf[ooo]Z00Cooo]Z0_l000001ooO0?oo0000oookJ_l06_oo
02gooookJ_oeo`002OoonfX01_ooW03ooo]ZoookJ_oonf[oF`3oo`2Io`Gooo]Z00?oofH0oj@0oooo
nfX00_oonfX00ol0o`3ooo]ZoookJP0HoookJP03oola0?oonf[ooo]Z01_ooo]Z0_ooc@000ooo0;[o
oo]ZoookJP0FoookJP?o0;OoP_oonfX002gooo]Z00Co00SooookJ_oonf[ood<00ooonfX00ol0l_oo
oo]ZoookJP05oookJP08o`3o/ooonf[ooo]ZoookJ_l0eOoooo]Zool0:ol0okH;oookJP03ol00oooo
nf[ooo]Z00Cooo]Z00?oo`2SoookJ_oonfX00_oonfX00ooo08Gooo]ZoookJP07oookJP05o`[o0?oo
nf[ooo]ZoookJ_ooN`000ooonfX00oo5o`3ooo]ZoookJP02oookJP03oon<0?oonf[ooo]Z00Kooo]Z
00CoYOl0oookJ_oonf[ooo]Z0ooo:002oookJP03oolX0?oonf[ooo]Z00Kooo]Z00?oo`0koookJ_oo
nfX00ooonfX00ol0og[ooo]Zo`2Ao`03oookJP03ool0c_l0on;ooo]Z00[ooo]Z00?o08cooookJ_mn
0?l00_oonfX00ooo2P3ooo]ZoookJP09oookJP03ool0o?oonf[ooo]Z00;ooo]Z00?oom<0oookJ_oo
nfX00_oonfX00ol0oiWooo]ZoookJP0>oookJP03oom80?oonf[ooo]Z00gooo]Z00?oogT0oookJ_oo
nfX03ooonfX00ol00_oooo]ZoookJP04oookJP04o`000?oO0?ooE_l0o`0Jo`;ooo]Z00?o02goooGo
0?oonfX02OoonfX01?ooW03ooo]ZoookJ_l0VOl7oookJP03oomV0?nT0?oooo]Z00;ooo]Z00?o0?l0
oookJ_oonfX06?oonfX00ooo<@3ooo]ZoookJP0LoookJP03ooo=0?oo0;[oo`2j01Wooo]Z0ol0]onY
oookJP04o`08oooonf[ooo]Zoom300?ooo]Z00?o0?;ooookJ_oonfX01OoonfX02Ol0ok?ooo]Zoook
J_oonf[o0=GooookJ_oo02_ooo]Zo`3o]P0;oookJP03ol00oooonf[ooo]Z00?ooo]Z00?oo`2Soook
J_oonfX00_oonfX00ooo08Gooo]ZoookJP08oookJP05o`[o0?oonf[ooo]ZoookJ_ooN`000ooonfX0
1Oo5o`3ooo]ZoookJ_oonf[ooh`000Sooo]Z00?oYOl0oookJ_oonfX01_oonfX00onoo`3ooo]Zoook
JP06oookJP03ool0>ooonf[ooo]Z00?ooo]Z00Co0?mjoookJ_oonf[o097o0ooonfX00ooo0<kooo]Z
oookJP0:oookJP05o`2<oomn0?oooo]ZoookJ_oo2P003?oonfX00ooo0?cooo]ZoookJP02oookJP05
oooC0?oonf[ooo]ZoookJ_l0oiT04OoonfX00oooB03ooo]ZoookJP0<oookJP03o`3oO?oonf[ooo]Z
00oooo]Z00?o00;ooookJ_oonfX01?oonfX2o`000007oml0ool0003o01[ooookJ_l0;Ooooo]ZooGo
0009oookJP05oonL0?oonf[ooo]ZoookJ_l0VOl01_oonfX00oooIP3oY03ooookJP02oookJP03o`3o
0?oonf[ooo]Z01Sooo]Z00?ooc40oookJ_oonfX07OoonfX00oooc@3oo`2jool0^P0IoookJP?o0;Oo
OooonfX002cooo]Z00Co00SooookJ_oonf[ood<00ooonfX00ol0l_oooo]ZoookJP05oookJP08o`3o
/ooonf[ooo]ZoookJ_l0eOoooo]Zool0:ol0okH;oookJP03ol00oooonf[ooo]Z00Cooo]Z00?oo`2S
oookJ_oonfX00_oonfX00ooo08Gooo]ZoookJP07oookJP05o`[o0?oonf[ooo]ZoookJ_ooN`000ooo
nfX00oo5o`3ooo]ZoookJP02oookJP03oon<0?oonf[ooo]Z00Kooo]Z00CoYOl0oookJ_oonf[ooo]Z
1_oo:008oookJP03ool0>ooonf[ooo]Z00?ooo]Z00?o0?mjoookJ_l0TOl00ooonfX00ooo0<kooo]Z
o`3ohP0;oookJP05o`2<oooonf[oOP3ooookJ_oo2P002ooonfX00ooo0?cooo]ZoookJP02oookJP03
oooC0?oonf[ooo]Z00?ooo]Z00?o0?nIoookJ_oonfX03_oonfX00oooB03ooo]ZoookJP0=oookJP03
o`3oO?oonf[ooo]Z00kooo]Z00?o00;ooookJ_oonfX01OoonfX02?l0003og`3oo`000?l06_oooo]Z
o`0]oooonf[omOl02_oonfX01?ooW03ooo]ZoookJ_l0VOl7oookJP03oomV0?oonf[ooo]Z00;ooo]Z
00?o0?l0oookJ_oonfX06?oonfX00ooo<@3ooo]ZoookJP0MoookJP03ooo=0?oonf[oo`2j01_ooo]Z
0_l0]onVoookJP04o`08oooonf[ooo]Zoom300?ooo]Z00?o0?;ooookJ_oonfX01OoonfX02Ol0ok?o
oo]ZoookJ_oonf[o0=GooookJ_oo02_ooo]Zo`3o]P0;oookJP03ol00oooonf[ooo]Z00Cooo]Z00Go
o`2SoookJ_oonf[ooo]Zool0Q@0:oookJP05o`[o0?oonf[ooo]ZoookJ_ooN`000ooonfX01Oo5o`3o
oo]ZoookJ_oonf[ooh`000Sooo]Z00?oYOl0oookJ_oonfX01_oonfX00onoo`3ooo]ZoookJP06oook
JP03ool0>ooonf[ooo]Z00?ooo]Z00Co0?mjoookJ_oonf[o097o0ooonfX00ooo0<ko0?oRoookJP0:
oookJP03o`2<oooonf[oOP3o00;ooo]Z00?oo`X0oookJ_oonfX02OoonfX00ooo0?cooo]ZoookJP02
oookJP03oooC0?oonf[ooo]Z00;ooo]Z00?o0?nIoookJ_oonfX03ooonfX00oooB03ooo]ZoookJP0<
oookJP03o`3oO?oonf[ooo]Z00kooo]Z00?o00;ooookJ_oonfX01OoonfX02Ol0003oE_l0oml0ool0
003o01[ooookJ_l0;Ooooo]ZooGo0009oookJP05oonL0?oonf[ooo]ZoookJ_l0VOl01_oonfX00ooo
IP3ooo]ZoookJP02oookJP03o`3o0?oonf[ooo]Z01Sooo]Z00?ooc40oookJ_oonfX07_oonfX00ooo
c@3ooo]Zool0^P0KoookJP;o0;OoOOoonfX002_ooo]Z00Co00SooookJ_oonf[ood<00ooonfX00ol0
l_oooo]ZoookJP05oookJP08o`3o/ooonf[ooo]ZoookJ_l0eOoooo]Zool0:ol0okH;oookJP03ol00
oooonf[ooo]Z00Cooo]Z00?oo`2SoookJ_oonfX00_oonfX00ooo08Gooo]ZoookJP07oookJP05o`[o
0?oonf[ooo]ZoookJ_ooN`000ooonfX00oo5o`3ooo]ZoookJP02oookJP03oon<0?oonf[ooo]Z00Ko
oo]Z00?oYOl0oookJ_oonfX00_oonfX6oolX00Sooo]Z00?oo`0koookJ_oonfX00_oonfX01?l0og[o
oo]ZoookJ_l0TOl2oookJP03ool0c_oonf[o0?oR00_ooo]Z00?o08cooookJ_mn0?l00_oonfX00ooo
2P3ooo]ZoookJP09oookJP05ool0o?oonf[ooo]ZoookJ_ood`001OoonfX00ol0oiWooo]ZoookJP0>
oookJP03oom80?oonf[ooo]Z00gooo]Z00?o0?mloookJ_oonfX03ooonfX00ol00_oooo]ZoookJP05
oookJP08oml0oomFo`3o0000o`0Joooonf[o02gooookJ_oeo`09oookJP05oonL0?oonf[ooo]Zoook
J_l0VOl01ooonfX00oooIP3ooo]ZoookJP02oookJP03o`3o0?oonf[ooo]Z01Sooo]Z00?ooc40oook
J_oonfX07_oonfX00oooc@3ooo]Zool0^P0LoookJP;o0;OoXooonfX01?l02?oooo]ZoookJ_oo@`03
oookJP03o`3boooonf[ooo]Z00Gooo]Z00Wo0?ncoookJ_oonf[ooo]Zo`3Eoooonf[oo`0[oookJ_l0
okH02ooonfX00oo00?oooo]ZoookJP04oookJP05ool0Xooonf[ooo]ZoookJ_oo08D02_oonfX01Ol:
o`3ooo]ZoookJ_oonf[oog/000?ooo]Z00GoaOl0oookJ_oonf[ooo]Zoon<0008oookJP03ojGo0?oo
nf[ooo]Z00Kooo]Z00?o_ol0oookJ_oonfX01ooonfX00ooo03_ooo]ZoookJP02oookJP04o`3oN_oo
nf[ooo]Zo`2Ao`?ooo]Z00?oo`3>o`3oh_oonfX02ooonfX01Ol0S?ooOP3ooookJ_oonf[oo`X000_o
oo]Z00?oo`3loookJ_oonfX00_oonfX00oood`3ooo]ZoookJP02oookJP03o`3oVOoonf[ooo]Z00oo
oo]Z00?oodP0oookJ_oonfX03?oonfX00ol0ogcooo]ZoookJP0?oookJP03o`02oooonf[ooo]Z00Go
oo]Z00So0000oml0ool0003o0000o`0Jool0;Ooooo]ZooGo00Wooo]Z00?ooi`0oookJ_oonfX00_oo
nfX00ol0VOoooo]ZoookJP04oookJP03oomV0?oonf[ooo]Z00;ooo]Z00?o0?l0oookJ_oonfX06?oo
nfX00ooo<@3ooo]ZoookJP0OoookJP03ooo=0?oonf[oo`2j01cooo]Z0_l0]omkoookJP00:_oonfX0
1?l02?oooo]ZoookJ_oo@`03oookJP03o`3boooonf[ooo]Z00Gooo]Z00So0?ncoookJ_oonf[ooo]Z
o`3Eoooonf[oo`0[o`3o]P_ooo]Z00?o`03ooookJ_oonfX01?oonfX00ooo0:?ooo]ZoookJP02oook
JP03ool0QOoonf[ooo]Z00Oooo]Z00Go2_l0oookJ_oonf[ooo]Zoomk0003oookJP03olGo0?oonf[o
oo]Z00;ooo]Z00?ooh`0oookJ_oonfX01_oonfX00onUo`3ooo]ZoookJP02oookJPSoobP01_oonfX0
0ooo03_ooo]ZoookJP02oookJP04o`3oN_oonf[ooo]Zo`2Ao`?ooo]Z00?oo`3>o`3oh_oonfX02_oo
nfX00ol0S?oooo]Zogh0o`02oookJP03ool:0?oonf[ooo]Z00Wooo]Z00?oo`3loookJ_oonfX00_oo
nfX00oood`3ooo]ZoookJP02oookJP03o`3oVOoonf[ooo]Z00kooo]Z00?oodP0oookJ_oonfX03_oo
nfX00ol0ogcooo]ZoookJP0?oookJP03o`02oooonf[ooo]Z00Gooo]Z00Oog`3ooeKo0?l0003o01[o
o`0]oooonf[omOl000[ooo]Z00Gooi`0oookJ_oonf[ooo]Zo`2Io`07oookJP03oomV0?oonf[ooo]Z
00;ooo]Z00?o0?l0oookJ_oonfX06OoonfX00ooo<@3ooo]ZoookJP0NoookJP04ooo=0?oonf[oo`2j
ool0^Qcooo]Z0ol0]onOoookJP04o`08oooonf[ooo]Zoom300?ooo]Z00?o0?;ooookJ_oonfX01Ooo
nfX02Ol0ok?ooo]ZoookJ_oonf[o0=GooookJ_oo02_ooo]Zo`3o]P0;oookJP03ol00oooonf[ooo]Z
00Cooo]Z00Goo`2SoookJ_oonf[ooo]Zool0Q@0:oookJP05o`[o0?oonf[ooo]ZoookJ_ooN`000ooo
nfX01Oo5o`3ooo]ZoookJ_oonf[ooh`000Sooo]Z00?oYOl0oookJ_oonfX01_oonfX00onoo`3ooo]Z
oookJP07oookJP03ool0>ooonf[ooo]Z00?ooo]Z00?o0?mjoookJ_l0TOl00ooonfX00ooo0<ko0?oR
oookJP0;oookJP05o`2<oomn0?oooo]ZoookJ_oo2P002ooonfX00ooo0?cooo]ZoookJP03oookJP05
oooC0?oonf[ooo]ZoookJ_l0oiT04OoonfX00oooB03ooo]ZoookJP0=oookJP03o`3oO?oonf[ooo]Z
00oooo]Z00?o00;ooookJ_oonfX01OoonfX02?l0003og`3oo`000?l06_oo0000o`0]oooonf[omOl0
2OoonfX00oooW03ooo]ZoookJP02oookJP03o`2Ioooonf[ooo]Z00Cooo]Z00?oofH0oookJ_oonfX0
0_oonfX00ol0o`3ooo]ZoookJP0IoookJP03oola0?oonf[ooo]Z01oooo]Z00?oold0oookJ_oo0;X0
7OoonfX3o`2gogSooo]Z000/oookJP05oom30?oonf[ooo]ZoookJ_l0l_l01ooonfX02?l0ok?ooo]Z
oookJ_oonf[o0=GooookJ_oo02_o0?nf2ooonfX00oo00?oooo]ZoookJP04oookJP03ool0Xooonf[o
oo]Z00;ooo]Z00?oo`25oookJ_oonfX02?oonfX01?l:o`3ooo]ZoookJ_ooN`03oookJP03olGo0?oo
nf[ooo]Z00;ooo]Z00?ooh`0oookJ_oonfX01_oonfX00onUo`3ooo]ZoookJP03oookJPWoobP01?oo
nfX00ooo03_ooo]ZoookJP03oookJP03o`3oN_oonf[o097o00?ooo]Z00?oo`3>o`3oh_oonfX02_oo
nfX00ol0S?oooo]Zogh0o`02oookJP03ool:0?oonf[ooo]Z00Wooo]Z00?oo`3loookJ_oonfX00_oo
nfX00oood`3ooo]ZoookJP03oookJP03o`3oVOoonf[ooo]Z00kooo]Z00?oodP0oookJ_oonfX03Ooo
nfX00ol0ogcooo]ZoookJP0?oookJP03o`02oooonf[ooo]Z00Kooo]Z00Oog`3oo`000?l06_oo0000
o`0]oooonf[omOl000[ooo]Z00Gooi`0oookJ_oonf[ooo]Zo`2Io`07oookJP03oomV0?oonf[ooo]Z
00;ooo]Z00?o0?l0oookJ_oonfX06OoonfX00ooo<@3ooo]ZoookJP0OoookJP04ooo=0?oonf[ooo]Z
ool0^Qkooo]Z0_l0]onOoookJP05oom30?oonf[ooo]ZoookJ_l0l_l01ooonfX02Ol0ok?ooo]Zoook
J_oonf[o0=GooookJ_oo02_ooo]Zo`3o]P0;oookJP03ol00oooonf[ooo]Z00Cooo]Z00Goo`2Soook
J_oonf[ooo]Zool0Q@0;oookJP04o`[o0?oonf[ooo]Zoomk00?ooo]Z00GoaOl0oookJ_oonf[ooo]Z
oon<0008oookJP03ojGo0?oonf[ooo]Z00Kooo]Z00?o_ol0oookJ_oonfX01ooonfX00ooo03_ooo]Z
oookJP03oookJP03o`3oN_oonf[o097o00?ooo]Z00?oo`3>o`3oh_oonfX02ooonfX01Ol0S?ooOP3o
oookJ_oonf[oo`X000cooo]Z00?oo`3loookJ_oonfX00_oonfX00oood`3ooo]ZoookJP02oookJP03
o`3oVOoonf[ooo]Z00oooo]Z00?oodP0oookJ_oonfX03?oonfX00ol0ogcooo]ZoookJP0?oookJP03
o`02oooonf[ooo]Z00Kooo]Z00OoE_l0oml0ool0003o01[ooookJ_l0;OoomOl000[ooo]Z00?ooi`0
oookJ_oonfX00_oonfX00ol0VOoooo]ZoookJP04oookJP03oomV0?oonf[ooo]Z00;ooo]Z00?o0?l0
oookJ_oonfX06OoonfX00ooo<@3ooo]ZoookJP0PoookJP03ooo=0?oonf[oo`2j01oooo]Z0_l0]omf
oookJP00:ooonfX01Ooo@`3ooo]ZoookJ_oonf[o0?;o00Oooo]Z00Oo0?ncoookJ_oonf[ooo]Zo`3E
oooonf[oo`0[00;oiOl02_oonfX00oo00?oooo]ZoookJP04oookJP03ool0Xooonf[ooo]Z00?ooo]Z
00?oo`25oookJ_oonfX01ooonfX01?l:o`3ooo]ZoookJ_ooN`03oookJP03olGo0?oonf[ooo]Z00;o
oo]Z00?ooh`0oookJ_oonfX01_oonfX00onUo`3ooo]ZoookJP03oookJPSoobP01OoonfX00ooo03_o
oo]ZoookJP03oookJP03o`3oN_oonf[o097o00?ooo]Z00?oo`3>o`3oh_oonfX02_oonfX01_l0S?oo
oo]ZoookJ_mn0?oooo]Zool:00cooo]Z00Goo`3loookJ_oonf[ooo]ZoooC0005oookJP03o`3oVOoo
nf[ooo]Z00kooo]Z00?oodP0oookJ_oonfX03OoonfX00ol0ogcooo]ZoookJP0@oookJP03o`02oooo
nf[ooo]Z00Gooo]Z00Sog`3ooeKo0?l0003o01[oo`000?l0;Ooooo]ZooGo00[ooo]Z00Gooi`0oook
J_oonf[oF`3oo`2Io`07oookJP03oomV0?oonf[ooo]Z00;ooo]Z00?o0?l0oookJ_oonfX06OoonfX0
0ooo<@3ooo]ZoookJP0PoookJP;oold000?ooo]Zool0^_oonfX07_oonfX2o`2go`gooo]Z0_ooN@2=
oookJP05oom30?oonf[ooo]ZoookJ_l0l_l01ooonfX01ol0ok?ooo]ZoookJ_oonf[o0=GooookJ_oo
02/00_l0okH;oookJP03ol00oooonf[ooo]Z00Cooo]Z00?oo`2SoookJ_oonfX00_oonfX00ooo08Go
oo]ZoookJP08oookJP04o`[o0?oonf[ooo]Zoomk00?ooo]Z00?oaOl0oookJ_oonfX00_oonfX00ooo
S03ooo]ZoookJP05oookJP03ojGo0?l0obCooo]Z00Kooo]Z00?o_ol0oookJ_oonfX01ooonfX00ooo
03_ooo]ZoookJP03oookJP04o`3oN_oonf[ooo]Zo`2Ao`?ooo]Z00?oo`3>oookJ_oonfX02_oonfX0
0ol0S?oooo]Zogh0o`02oookJP03ool:0?oonf[ooo]Z00Wooo]Z00?oo`3loookJ_oonfX00_oonfX0
0oood`3ooo]ZoookJP02oookJP03o`3oVOoonf[ooo]Z00oooo]Z00?oodP0oookJ_oonfX03OoonfX0
0ol0ogcooo]ZoookJP0?oookJP03o`02oooonf[ooo]Z00Kooo]Z00Oog`3oo`000?l0003o01[oo`0]
oooonf[omOl000[ooo]Z00Gooi`0oookJ_oonf[ooo]Zo`2Io`07oookJP03oomV0?oonf[ooo]Z00;o
oo]Z00?o0?l0oookJ_oonfX06OoonfX00ooo<@3ooo]ZoookJP0QoookJP03ooo=0?oonf[oo`2j023o
oo]Z0_l0]omdoookJP00:_oonfX01Ooo@`3ooo]ZoookJ_oonf[o0?;o00Oooo]Z00So0?ncoookJ_oo
nf[ooo]Zo`3Eoooonf[oo`0[onGo00_ooo]Z00?o`03ooookJ_oonfX01?oonfX00ooo0:?ooo]Zoook
JP03oookJP03ool0QOoonf[ooo]Z00Oooo]Z00Co2_l0oookJ_oonf[oog/00ooonfX00oo5o`3ooo]Z
oookJP02oookJP03oon<0?oonf[ooo]Z00Kooo]Z00?oYOl0oookJ_oonfX01?oonfX7oolX00Gooo]Z
00?oo`0koookJ_oonfX00ooonfX00ol0og[ooo]Zo`2Ao`03oookJP03ool0c_l0on;ooo]Z00_ooo]Z
00Go08cooookJ_mn0?oooo]Zool:000<oookJP03ool0o?oonf[ooo]Z00;ooo]Z00?oom<0oookJ_oo
nfX00_oonfX00ol0oiWooo]ZoookJP0?oookJP03oom80?oonf[ooo]Z00gooo]Z00?o0?mloookJ_oo
nfX03ooonfX00ol00_oooo]ZoookJP06oookJP07oml0oomFo`3o0000o`0Jool0;Ooooo]ZooGo000:
oookJP05oonL0?oonf[ooo]ZoookJ_l0VOl02?oonfX00oooIP3ooo]ZoookJP02oookJP03o`3o0?oo
nf[ooo]Z01[ooo]Z00?ooc40oookJ_oonfX08OoonfX01?ooc@3ooo]Zool0^_oo0;XOoookJP?o0;Oo
2_oonfX4oomi08[ooo]Z00Good<0oookJ_oonf[ooo]Zo`3bo`07oookJP08o`3o/ooonf[ooo]Zoook
J_l0eOoooo]Zool0:ol0okH<oookJP03ol00oooonf[ooo]Z00Cooo]Z00?oo`2SoookJ_oonfX00_oo
nfX00ooo08Gooo]ZoookJP08oookJP04o`[o0?oonf[ooo]Zoomk00?ooo]Z00?oaOl0oookJ_oonfX0
0_oonfX00oooS03ooo]ZoookJP06oookJP03ojGo0?oonf[ooo]Z00Kooo]Z00?o_ol0oookJ_oonfX0
1_oonfX00ooo03_ooo]ZoookJP03oookJP04o`3oN_oonf[ooo]Zo`2Ao`?ooo]Z00?oo`3>o`3oh_oo
nfX02ooonfX01Ol0S?ooOP3ooookJ_oonf[oo`X000_ooo]Z00?oo`3loookJ_oonfX00ooonfX01Ooo
d`3ooo]ZoookJ_oonf[o0?nI01;ooo]Z00?oodP0oookJ_oonfX03?oonfX00ol0ogcooo]ZoookJP0?
oookJP03o`02oooonf[ooo]Z00Oooo]Z00Oog`3oo`000?l06_oo0000o`0]oooonf[omOl000Wooo]Z
00?ooi`0oookJ_oonfX00_oonfX00ol0VOoooo]ZoookJP05oookJP03oomV0?oonf[ooo]Z00;ooo]Z
00?o0?l0oookJ_oonfX06_oonfX00ooo<@3ooo]ZoookJP0QoookJP04ooo=0?oonf[oo`2jool0^R3o
oo]Z0ol0]omaoookJP00;OoonfX00ol0l_oooo]ZoookJP05oookJP08o`3o/ooonf[ooo]ZoookJ_l0
eOoooo]Zool0:ooUo`0;oookJP03ol00oooonf[ooo]Z00Cooo]Z00?oo`2SoookJ_oonfX00ooonfX0
0ooo08Gooo]ZoookJP07oookJP04o`[o0?oonf[ooo]Zoomk00?ooo]Z00?oaOl0oookJ_oonfX00_oo
nfX00oooS03ooo]ZoookJP06oookJP03ojGo0?oonf[ooo]Z00Cooo]Z1_oo:006oookJP03ool0>ooo
nf[ooo]Z00?ooo]Z00Co0?mjoookJ_oonf[o097o0ooonfX00ooo0<ko0?oRoookJP0:oookJP03o`2<
oooonf[oOP3o00;ooo]Z00?oo`X0oookJ_oonfX02OoonfX00ooo0?cooo]ZoookJP02oookJP03oooC
0?oonf[ooo]Z00?ooo]Z00?o0?nIoookJ_oonfX03_oonfX00oooB03ooo]ZoookJP0=oookJP03o`3o
O?oonf[ooo]Z013ooo]Z00?o00;ooookJ_oonfX01_oonfX01ooO0?oo0000o`0Jool0003o02gooook
J_oeo`002_oonfX01OooW03ooo]ZoookJ_oonf[o09Wo00Oooo]Z00?oofH0oj@0oooonfX00ooonfX0
0ol0o`3ooo]ZoookJP0JoookJP03oola0?oonf[ooo]Z02;ooo]Z00Coold0oookJ_oonf[oo`2j8Ooo
nfX5o`2go`Gooo]Z1_ooN@2;oookJP03o`3boooonf[ooo]Z00Gooo]Z00So0?ncoookJ_oonf[ooo]Z
o`3Eoooonf[oo`0[o`3o]Pcooo]Z00?o`03ooookJ_oonfX01?oonfX00ooo0:?ooo]ZoookJP02oook
JP03ool0QOoonf[ooo]Z00Sooo]Z00Co2_l0oookJ_oonf[oog/00ooonfX00oo5o`3ooo]ZoookJP02
oookJP03oon<0?oonf[ooo]Z00Kooo]Z00?oYOl0oookJ_oonfX01_oonfX00onoo`3ooo]ZoookJP06
oookJP03ool0>ooonf[ooo]Z00?ooo]Z00Co0?mjoookJ_oonf[o097o0ooonfX00ooo0<ko0?oRoook
JP0;oookJP05o`2<oomn0?oooo]ZoookJ_oo2P003?oonfX00ooo0?cooo]ZoookJP02oookJP03oooC
0?oonf[ooo]Z00;ooo]Z00?o0?nIoookJ_oonfX03ooonfX00oooB03ooo]ZoookJP0=oookJP03o`3o
O?oonf[ooo]Z00oooo]Z00?o00;ooookJ_oonfX01_oonfX01omFo`3og`3oo`000?l06_oo0000o`0]
oooeo`002_oonfX00oooW03ooo]ZoookJP02oookJP03o`2Ioooonf[ooo]Z00Cooo]Z00?oofH0oj@0
oooonfX00ooonfX00ol0o`3ooo]ZoookJP0JoookJP03oola0?oonf[ooo]Z02;ooo]Z00Coold0oook
J_oonf[oo`2j8_oonfX4o`2gofgooo]Z000/oookJP03o`3boooonf[ooo]Z00Gooo]Z00So0?ncoook
J_oonf[ooo]Zo`3Eoooonf[oo`0[onGo00_ooo]Z00?o`03ooookJ_oonfX01?oonfX00ooo0:?ooo]Z
oookJP03oookJP03ool0QOoonf[ooo]Z00Oooo]Z00Go2_l0oookJ_oonf[ooo]Zoomk0002oookJP03
olGo0?oonf[ooo]Z00;ooo]Z00?ooh`0oookJ_oonfX01_oonfX00onUo`3ooo]ZoookJP05oookJPGo
obP01_oonfX00ooo03_ooo]ZoookJP03oookJP04o`3oN_oonf[ooo]Zo`2Ao`?ooo]Z00?oo`3>o`3o
h_oonfX02_oonfX00ol0S?oooo]Zoomi0002oookJP03ool:0?oonf[ooo]Z00Wooo]Z00?oo`3loook
J_oonfX00_oonfX00oood`3ooo]ZoookJP03oookJP03o`3oVOoonf[ooo]Z00kooo]Z00?oodP0oook
J_oonfX03_oonfX00ol0ogcooo]ZoookJP0@oookJP03o`02oooonf[ooo]Z00Gooo]Z00Sog`3ooeKo
0?l0003o01[oo`000?l0;Ooooo]ZooGo00[ooo]Z00Gooi`0oookJ_oonf[ooo]Zo`2Io`07oookJP03
oomV0?nT0?oooo]Z00?ooo]Z00?o0?l0oookJ_oonfX06_oonfX00ooo<@3ooo]Zoomi0002oomi027o
oo]Z00Coold0oookJ_oonf[oo`2j9OoonfX4o`2go`03oookJ_ooN@3oogT000KoogT0R?oonfX00ol0
l_oooo]ZoookJP05oookJP08o`3o/ooonf[ooo]ZoookJ_l0eOoooo]Zool0:ol0okH<oookJP03ol00
oooonf[ooo]Z00Cooo]Z00?oo`2SoookJ_oonfX00_oonfX00ooo08Gooo]ZoookJP08oookJP05o`[o
0?oonf[ooo]ZoookJ_ooN`000_oonfX00oo5o`3ooo]ZoookJP02oookJP03oon<0?oonf[ooo]Z00Ko
oo]Z00?oYOl0oookJ_oonfX01_oonfX00onoo`3ooo]ZoookJP06oookJP03ool0>ooonf[ooo]Z00Co
oo]Z00?o0?mjoookJ_l0TOl00ooonfX00ooo0<ko0?oRoookJP0;oookJP05o`2<oomn0?oooo]Zoook
J_oo2P003?oonfX00ooo0?cooo]ZoookJP02oookJP03oooC0?oonf[ooo]Z00;ooo]Z00?o0?nIoook
J_oonfX03ooonfX00oooB03ooo]ZoookJP0=oookJP03o`3oO?oonf[ooo]Z013ooo]Z00?o00;ooook
J_oonfX01_oonfX01ooO0?oo0000o`000?l06_oo02gooookJ_oeo`002_oonfX00oooW03ooo]Zoook
JP02oookJP03o`2Ioooonf[ooo]Z00Cooo]Z00?oofH0oj@0oooonfX00ooonfX00ol0o`3ooo]Zoook
JP0JoookJP03oola0?oonf[ooo]Z02?ooo]Z00Coold0oookJ_oonf[oo`2j9OoonfX4o`2gofWooo]Z
000[oookJP03o`3boooonf[ooo]Z00Gooo]Z00So0?ncoookJ_oonf[ooo]Zo`3Eoooonf[oo`0[onGo
00_ooo]Z00?o`03ooookJ_oonfX01?oonfX00ooo0:?ooo]ZoookJP03oookJP03ool0QOoonf[ooo]Z
00Oooo]Z00Go2_l0oookJ_oonf[ooo]Zoomk0002oookJP03olGo0?oonf[ooo]Z00;ooo]Z00?ooh`0
oookJ_oonfX01_oonfX00onUo`3o0?lToookJP05oookJPCoobP01ooonfX00ooo03_ooo]ZoookJP03
oookJP04o`3oN_oonf[ooo]Zo`2Ao`?ooo]Z00?oo`3>o`3oh_oonfX02_oonfX01_l0S?oooo]Zoook
J_ooN@3ooo]Zool:00cooo]Z00Goo`3loookJ_oonf[ooo]ZoooC0005oookJP03o`3oVOoonf[ooo]Z
00oooo]Z00?oodP0oookJ_oonfX03OoonfX00ol0ogcooo]ZoookJP0@oookJP03o`02oooonf[ooo]Z
00Kooo]Z00Oog`3ooeKo0?l0003o01[oo`0]ool0003omOl000_ooo]Z00Gooi`0oookJ_oonf[ooo]Z
o`2Io`07oookJP03oomV0?nT0?oooo]Z00?ooo]Z00?o0?l0oookJ_oonfX06OoonfX6oomi02;ooo]Z
00Coold0oookJ_oonf[oo`2j:?oonfX00ol0]oooogT0oomi0008oomi08Gooo]Z00?o0?;ooookJ_oo
nfX01OoonfX02?l0ok?ooo]ZoookJ_oonf[o0=GooookJ_oo02_o0?nf3?oonfX00oo00?oooo]Zoook
JP04oookJP03ool0Xooonf[ooo]Z00;ooo]Z00?oo`25oookJ_oonfX02?oonfX01Ol:o`3ooo]Zoook
J_oonf[oog/000;ooo]Z00?oaOl0oookJ_oonfX00_oonfX00oooS03ooo]ZoookJP06oookJP03ojGo
0?oonf[ooo]Z00Kooo]Z00?o_ol0oookJ_oonfX01_oonfX00ooo03_ooo]ZoookJP04oookJP03o`3o
N_oonf[o097o00?ooo]Z00?oo`3>o`3oh_oonfX02ooonfX00ol0S?oooo]Zogh0o`02oookJP03ool:
0?oonf[ooo]Z00Wooo]Z00?oo`3loookJ_oonfX00_oonfX00oood`3ooo]ZoookJP02oookJP03o`3o
VOoonf[ooo]Z013ooo]Z00?oodP0oookJ_oonfX03OoonfX00ol0ogcooo]ZoookJP0?oookJP03o`02
oooonf[ooo]Z00Oooo]Z00Oog`3oo`000?l06_oo0000o`0]oooonf[omOl000[ooo]Z00Kooi`0oook
J_oonf[ooo]Zo`2IoomK0?l6oookJP03oomV0?nT0?oooo]Z00?ooo]Z00?o0?l0oookJ_oonfX06ooo
nfX00ooo<@3ooo]ZoookJP0SoookJP04ooo=0?oonf[ooo]Zool0^RSooo]Z1Ol0]omToookJP00:_oo
nfX00ol0l_oooo]ZoookJP05oookJP08o`3o/ooonf[ooo]ZoookJ_l0eOoooo]Zool0:ooUo`0;oook
JP03ol00oooonf[ooo]Z00Cooo]Z00?oo`2SoookJ_oonfX00ooonfX00ooo08Gooo]ZoookJP07oook
JP05o`[o0?oonf[ooo]ZoookJ_ooN`000_oonfX00oo5o`3ooo]ZoookJP02oookJP03oon<0?oonf[o
oo]Z00Kooo]Z00?oYOl0o`3o9?oonfX01_oonfX3oolX00Sooo]Z00?oo`0koookJ_oonfX00_oonfX0
1?l0og[ooo]ZoookJ_l0TOl3oookJP03ool0c_l0on;ooo]Z00_ooo]Z00Go08cooookJ_ooN@3ooo]Z
ool:000<oookJP03ool0o?oonf[ooo]Z00;ooo]Z00?oom<0oookJ_oonfX00_oonfX00ol0oiWooo]Z
oookJP0?oookJP03oom80?oonf[ooo]Z00kooo]Z00?o0?mloookJ_oonfX04?oonfX00ol00_oooo]Z
oookJP06oookJP07oml0oooonf[o0000o`0Jool0;Ooo0000ooGo000;oookJP05oonL0?oonf[ooo]Z
oookJ_l0VOl01ooonfX00oooIP3ooo]ZoookJP02oookJP03o`3o0?oonf[ooo]Z01Sooo]Z2?ooN@0S
oookJP04ooo=0?oonf[ooo]Zool0^ROooo]Z3OooN@22oookJP03o`3boooonf[ooo]Z00Gooo]Z00So
0?ncoookJ_oonf[ooo]Zo`3Eoooonf[oo`0[o`3o]Pcooo]Z00?o`03ooookJ_oonfX01?oonfX00ooo
0:?ooo]ZoookJP02oookJP03ool0QOoonf[ooo]Z00Sooo]Z00Go2_l0oookJ_oonf[ooo]Zoomk0002
oookJP03olGo0?oonf[ooo]Z00;ooo]Z00?ooh`0oookJ_oonfX01_oonfX00onUo`3ooo]ZoookJP06
oookJP03okoo0?oonf[ooo]Z00Oooo]Z00?oo`0koookJ_oonfX00ooonfX00ol0og[ooo]Zo`2Ao`03
oookJP03ool0c_oonf[o0?oR00_ooo]Z00?o08cooookJ_mn0?l00_oonfX00ooo2P3ooo]ZoookJP0:
oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Goom<0oookJ_oonf[ooo]Zo`3oV@0BoookJP03oom80?oo
nf[ooo]Z00gooo]Z00?o0?mloookJ_oonfX04?oonfX00ol00_oooo]ZoookJP06oookJP07oeKo0?oO
0?oo0000o`0Jool0003o02goooGo000;oookJP05oonL0?oonf[ooo]ZoookJ_l0VOl01ooonfX00ooo
IP3oY03ooookJP03oookJP03o`3o0?oonf[ooo]Z01_ooo]Z00?ooc40oookJ_oonfX09?oonfX01?oo
c@3ooo]ZoookJ_oo0;X/oookJPGo0;OoGooonfX0037ooo]Z00So0?ncoookJ_oonf[ooo]Zo`3Eoooo
nf[oo`0[onGo00_ooo]Z00?o`03ooookJ_oonfX01?oonfX00ooo0:?ooo]ZoookJP03oookJP03ool0
QOoonf[ooo]Z00Oooo]Z00Go2_l0oookJ_oonf[ooo]Zoomk0002oookJP03olGo0?oonf[ooo]Z00;o
oo]Z00?ooh`0oookJ_oonfX01_oonfX00onUo`3o0?lToookJP06oookJP?oobP02?oonfX00ooo03_o
oo]ZoookJP02oookJP04o`3oN_oonf[ooo]Zoomi00?ooo]Z00?oo`3>o`3oh_oonfX02ooonfX01Ol0
S?oooo]Zoomi0?oonf[oo`X000cooo]Z00?oo`3loookJ_oonfX00_oonfX00oood`3ooo]ZoookJP03
oookJP03o`3oVOoonf[ooo]Z00oooo]Z00?oodP0oookJ_oonfX03OoonfX00ol0ogcooo]ZoookJP0@
oookJP03o`02oooonf[ooo]Z00Kooo]Z00Gog`3ooeKo0?oonf[o01[oo`0]o`02o`000003ooGo0?oo
nf[ooo]Z00Cooo]Z0oooN@000ooonf[ooi`0oookJP02oookJP03oe/0ool0VOoooo]Z00Kooo]Z00?o
ofH0oookJ_oonfX00_oonfX00ol0o`3ooo]ZoookJP0HoookJPSoogT09?oonfX01?ooc@3ooo]Zoook
J_oo0;XVoookJPooogT0QooonfX02?l0ok?ooo]ZoookJ_oonf[o0=GooookJ_oo02_o0?nf3?oonfX0
0oo00?oooo]ZoookJP04oookJP03ool0Xooonf[ooo]Z00;ooo]Z00?oo`25oookJ_oonfX02?oonfX0
1Ol:o`3ooo]ZoookJ_oonf[oog/000;ooo]Z00?oaOl0oookJ_oonfX00_oonfX00oooS03ooo]Zoook
JP06oookJP03ojGo0?oonf[ooo]Z00Kooo]Z00?o_ol0oookJ_oonfX01ooonfX00ooo03_ooo]Zoook
JP03oookJP03o`3oN_oonf[o097o00Cooo]Z00?oo`3>o`3oh_oonfX02ooonfX01Ol0S?ooOP3ooook
J_oonf[oo`X000cooo]Z00?oo`3loookJ_oonfX00_oonfX00oood`3ooo]ZoookJP02oookJP03o`3o
VOoonf[ooo]Z013ooo]Z00?oodP0oookJ_oonfX03OoonfX00ol0ogcooo]ZoookJP0?oookJP03o`02
oooonf[ooo]Z00Oooo]Z00Oog`3ooookJ_l0003o01[oo`0]ool0003omOl000[ooo]Z00?ooi`0oook
J_oonfX00_oonfX00ol0VOoooo]ZoookJP05oookJP03oomV0?nT0?oooo]Z00?ooo]Z00?o0?l0oook
J_oonfX06ooonfX00ooo<@3ooo]ZoookJP0UoookJP04ooo=0?oonf[ooo]Zool0^S3ooo]Z1Ol0]omJ
oookJP00<?oonfX02?l0ok?ooo]ZoookJ_oonf[o0=GooookJ_oo02_oiOl02ooonfX00oo00?oooo]Z
oookJP04oookJP03ool0Xooonf[ooo]Z00?ooo]Z00?oo`25oookJ_oonfX01ooonfX01Ol:o`3ooo]Z
oookJ_oonf[oog/000?ooo]Z00GoaOl0oookJ_oonf[ooo]Zoon<0008oookJP03ojGo0?l0obCooo]Z
00Oooo]Z00?oobP0oookJ_oonfX01ooonfX00ooo03_ooo]ZoookJP03oookJP04o`3oN_oonf[ooo]Z
oomi00?ooo]Z00?oo`3>oookJ_oonfX02_oonfX00ol0S?oooo]Zoomi0002oookJP03ool:0?oonf[o
oo]Z00Wooo]Z00?oo`3loookJ_oonfX00_oonfX00oood`3ooo]ZoookJP03oookJP03o`3oVOoonf[o
oo]Z00oooo]Z00?oodP0oookJ_oonfX03_oonfX00ol0ogcooo]ZoookJP0@oookJP03o`02oooonf[o
oo]Z00Kooo]Z00Oog`3ooeKo0?oonf[o01[oo`0]ool0003omOl000Oooo]Z1oooN@000ooonf[oF`3o
o`2Io`07oookJP03oomV0?oonf[ooo]Z00;ooo]Z00?o0?l0oookJ_oonfX06OoonfX7oomi02Gooo]Z
0_ooc@000ooonf[oo`2joookJP0ToookJQ3oogT01?l0]on1oookJP08o`3o/ooonf[ooo]ZoookJ_l0
eOoooo]Zool0:ol0okH<oookJP03ol00oooonf[ooo]Z00Cooo]Z00?oo`2SoookJ_oonfX00_oonfX0
0ooo08Gooo]ZoookJP08oookJP05o`[o0?oonf[ooo]ZoookJ_ooN`000ooonfX01Oo5o`3ooo]Zoook
J_oonf[ooh`000Sooo]Z00?oYOl0oookJ_oonfX01_oonfX00onoo`3ooo]ZoookJP07oookJP03ool0
>ooonf[ooo]Z00?ooo]Z00Co0?mjoookJ_oonf[o097o0ooonfX00ooo0<ko0?oRoookJP0;oookJP05
o`2<oomn0?oooo]ZoookJ_oo2P003?oonfX00ooo0?cooo]ZoookJP02oookJP03oooC0?oonf[ooo]Z
00;ooo]Z00?o0?nIoookJ_oonfX04?oonfX00oooB03ooo]ZoookJP0=oookJP03o`3oO?oonf[ooo]Z
013ooo]Z00?o00;ooookJ_oonfX01ooonfX01ooO0?oooo]Zo`0Jool0003o02goo`000?oeo`002_oo
nfX00oooW03ooo]ZoookJP02oookJP03o`2Ioooonf[ooo]Z00Gooo]Z00?oofH0oj@0oooonfX00ooo
nfX00ol0o`3ooo]ZoookJP0LoookJP03oola0?oonf[ooo]Z02Gooo]Z0_ooc@000ooonf[oo`2joook
JP0coookJPKo0;OoE?oonfX002oooo]Z00So0?ncoookJ_oonf[ooo]Zo`3Eoooonf[oo`0[onGo00_o
oo]Z00?o`03ooookJ_oonfX01?oonfX00ooo0:?ooo]ZoookJP03oookJP03ool0QOoonf[ooo]Z00Oo
oo]Z00Go2_l0oookJ_oonf[ooo]Zoomk0003oookJP05olGo0?oonf[ooo]ZoookJ_ooS0002?oonfX0
0onUo`3o0?lToookJP07oookJP03oolX0?oonf[ooo]Z00Oooo]Z00?oo`0koookJ_oonfX00ooonfX0
1?l0og[ooo]ZoookJ_ooN@03oookJP03ool0c_l0on;ooo]Z00[ooo]Z00?o08cooookJ_ooN@000_oo
nfX00ooo2P3ooo]ZoookJP0:oookJP03ool0o?oonf[ooo]Z00;ooo]Z00?oom<0oookJ_oonfX00_oo
nfX00ol0oiWooo]ZoookJP0@oookJP03oom80?oonf[ooo]Z00gooo]Z00?o0?mloookJ_oonfX04Ooo
nfX00ol00_oooo]ZoookJP05oookJP08oml0oomFo`3ooo]ZoookJ_l06_oo02goo`000?oeo`07oook
JPWoogT02?oonfX00oooIP3ooo]ZoookJP02oookJP03o`3o0?oonf[ooo]Z01[ooo]Z1_ooN@0Woook
JP04ooo=0?oonf[oo`2jool0^R?ooo]Z2?ooN@0<oookJPSo0;OoN?oonfX02?l0ok?ooo]ZoookJ_oo
nf[o0=GooookJ_oo02_o0?nf3?oonfX00oo00?oooo]ZoookJP04oookJP03ool0Xooonf[ooo]Z00;o
oo]Z00?oo`25oookJ_oonfX02?oonfX01Ol:o`3ooo]ZoookJ_oonf[oog/000?ooo]Z00GoaOl0oook
J_oonf[ooo]Zoon<0008oookJP03ojGo0?l0obCooo]Z00Kooo]Z00?o_ol0oookJ_oonfX01ooonfX0
0ooo03_ooo]ZoookJP03oookJP04o`3oN_oonf[ooo]Zo`2Ao`?ooo]Z00?oo`3>o`3oh_oonfX02ooo
nfX00ol0S?oooo]Zogh0o`02oookJP03ool:0?oonf[ooo]Z00[ooo]Z00?oo`3loookJ_oonfX00_oo
nfX01Oood`3ooo]ZoookJ_oonf[o0?nI01;ooo]Z00?oodP0oookJ_oonfX03_oonfX00ol0ogcooo]Z
oookJP0@oookJP03o`02oooonf[ooo]Z00Kooo]Z00Oog`3ooookJ_oonf[o01[oo`000?l0;OoomOl0
00_ooo]Z00?ooi`0oookJ_oonfX00_oonfX00ol0VOoooo]ZoookJP05oookJP03oomV0?oonf[ooo]Z
00?ooo]Z00?o0?l0oookJ_oonfX07?oonfX00ooo<@3ooo]ZoookJP0WoookJP04ooo=0?oonf[oo`2j
ool0^SSooo]Z2?l0]om<oookJP00;_oonfX02?l0ok?ooo]ZoookJ_oonf[o0=GooookJ_oo02_oiOl0
2ooonfX00oo00?oooo]ZoookJP04oookJP03ool0Xooonf[ooo]Z00?ooo]Z00?oo`25oookJ_oonfX0
1ooonfX01Ol:o`3ooo]ZoookJ_oonf[oog/000?ooo]Z00GoaOl0oookJ_oonf[ooo]Zoon<0008oook
JP03ojGo0?l0obCooo]Z00Sooo]Z00?o_ol0oookJ_oonfX01_oonfX00ooo03_ooo]ZoookJP03oook
JP04o`3oN_oonf[ooo]Zoomi00?ooo]Z00?oo`3>o`3oh_oonfX02ooonfX01Ol0S?ooogT0oookJ_oo
nf[oo`X000cooo]Z00?oo`3loookJ_oonfX00_oonfX00oood`3ooo]ZoookJP03oookJP03o`3oVOoo
nf[ooo]Z00oooo]Z00?oodP0oookJ_oonfX03OoonfX00ol0ogcooo]ZoookJP0AoookJP03ooo90?oo
nf[ooo]Z00Kooo]Z00Gog`3ooeKo0?oonf[o01[oo`0]o`02o`000003ooGo0?oonf[ooo]Z00Gooo]Z
2OooN@08oookJP03oomV0?oonf[ooo]Z00;ooo]Z00?o0?l0oookJ_oonfX06_oonfX6oomi02Sooo]Z
00Koold0oookJ_oonf[oo`2joookJ_oUo`03oookJP03onGo0?oonf[ooo]Z03Kooo]Z3_l0]olAoook
JPWo0;OoCooonfX02?l0ok?ooo]ZoookJ_oonf[o0=GooookJ_oo02_o0?nf3?oonfX00oo00?oooo]Z
oookJP04oookJP03ool0Xooonf[ooo]Z00;ooo]Z00?oo`25oookJ_oonfX02?oonfX01Ol:o`3ooo]Z
oookJ_oonf[oog/000?ooo]Z00GoaOl0oookJ_oonf[ooo]Zoon<0008oookJP03ojGo0?l0obCooo]Z
00Oooo]Z00?o_ol0oookJ_oonfX01_oonfX00ooo03_ooo]ZoookJP04oookJP03o`3oN_oonf[o097o
00?ooo]Z00?oo`3>o`3oh_oonfX02ooonfX00ol0S?oooo]Zogh0o`02oookJP03ool:0?oonf[ooo]Z
00[ooo]Z00?oo`3loookJ_oonfX00_oonfX00oood`3ooo]ZoookJP02oookJP03o`3oVOoonf[ooo]Z
013ooo]Z00?oodP0oookJ_oonfX03OoonfX00ol0ogcooo]ZoookJP0@oookJP03o`02oooonf[ooo]Z
00Oooo]Z00Oog`3ooookJ_oonf[o01[oo`0]ool0003omOl000_ooo]Z00Gooi`0oookJ_oonf[ooo]Z
o`2Io`08oookJP03oomV0?oonf[ooo]Z00?ooo]Z00?o0?l0oookJ_oonfX07?oonfX00ooo<@3ooo]Z
oookJP0XoookJP04ooo=0?oonf[ooo]Zool0^Soooo]Z3Ol0]olAoookJP[o0;Oo9?oonfX002gooo]Z
00So0?ncoookJ_oonf[ooo]Zo`3Eoooonf[oo`0[onGo00_ooo]Z00?o`03ooookJ_oonfX01?oonfX0
0ooo0:?ooo]ZoookJP03oookJP03ool0QOoonf[ooo]Z00Oooo]Z00Go2_l0oookJ_oonf[ooo]Zoomk
0003oookJP05olGo0?oonf[ooo]ZoookJ_ooS0002?oonfX00onUo`3o0?lToookJP08oookJP03okoo
0?oonf[ooo]Z00Kooo]Z00?oo`0koookJ_oonfX00ooonfX01?l0og[ooo]ZoookJ_ooN@03oookJP03
ool0c_l0on;ooo]Z00_ooo]Z00Go08cooookJ_ooN@3ooo]Zool:000<oookJP03ool0o?oonf[ooo]Z
00;ooo]Z00?oom<0oookJ_oonfX00ooonfX00ol0oiWooo]ZoookJP0?oookJP03oom80?oonf[ooo]Z
00kooo]Z00?o0?mloookJ_oonfX03?oonfX2ooo900?ooo]Z00?oolT0oookJ_oonfX01_oonfX02?oO
0?ooE_l0oookJ_l06_oo02goo`000?oeo`3o00001ooonfX8oomi0003o`2Ioooonf[ooo]Z00Kooo]Z
00?oofH0oookJ_oonfX00_oonfX00ol0o`3ooo]ZoookJP0KoookJPGoogT0:OoonfX2ooo=0003oook
J_oo0;[oiOl000?ooo]Z0_oUo`15oookJQ7o0;OoEooonfX02?l0ok?ooo]ZoookJ_oonf[o0=Gooook
J_oo02_o0?nf3?oonfX00oo00?oooo]ZoookJP04oookJP03ool0Xooonf[ooo]Z00;ooo]Z00?oo`25
oookJ_oonfX02?oonfX01Ol:o`3ooo]ZoookJ_oonf[oog/000?ooo]Z00GoaOl0oookJ_oonf[ooo]Z
oon<0008oookJP03ojGo0?l0obCooo]Z00Oooo]Z00?o_ol0oookJ_oonfX01_oonfX00ooo03_ooo]Z
oookJP04oookJP03o`3oN_oonf[o097o00?ooo]Z00?oo`3>oookJ_l0on803?oonfX01Ol0S?ooOP3o
oookJ_oonf[oo`X000cooo]Z00?oo`3loookJ_oonfX00_oonfX00oood`3ooo]ZoookJP02oookJP03
o`3oVOoonf[ooo]Z013ooo]Z00?oodP0oookJ_oonfX03_oonfX00ol0ogcooo]ZoookJP0@oookJP03
o`02oooonf[ooo]Z00Oooo]Z00Oog`3ooookJ_l06_oo0000o`0]ool0003omOl000[ooo]Z00?ooi`0
oookJ_oonfX00_oonfX00ol0VOoooo]ZoookJP06oookJP03oomV0?oonf[ooo]Z00?ooo]Z00?o0?l0
oookJ_oonfX07OoonfX00ooo<@3ooo]ZoookJP0XoookJP;oold000?ooo]Zool0^_oo0;X0B_oonfXA
o`2gobkooo]Z000/oookJP08o`3o/ooonf[ooo]ZoookJ_l0eOoooo]Zool0:ooUo`0;oookJP03ol00
oooonf[ooo]Z00Cooo]Z00?oo`2SoookJ_oonfX00ooonfX00ooo08Gooo]ZoookJP07oookJP05o`[o
0?oonf[ooo]ZoookJ_ooN`000ooonfX01Oo5o`3ooo]ZoookJ_oonf[ooh`000Sooo]Z00?oYOl0o`3o
9?oonfX02?oonfX00onoo`3ooo]ZoookJP06oookJP03ool0>ooonf[ooo]Z00?ooo]Z00Co0?mjoook
J_oonf[oogT01?oonfX00ooo0<kooo]ZoookJP07oookJP;oogT000Gooo]Zo`2<oooonf[oogT0oook
JP02oomi00cooo]Z00?oo`3loookJ_oonfX00_oonfX00oood`3ooo]ZoookJP02oookJP03o`3oVOoo
nf[ooo]Z013ooo]Z00?oodP0oookJ_oonfX03OoonfX00ol0ogcooo]ZoookJP0=oookJPGoolT02?oo
nfX02OoO0?ooE_l0oookJ_oonf[o01[oo`0]ool0003omOl0o`000007oookJPOoogT000?ooo]Zo`2I
oooonfX01_oonfX00oooIP3oY03ooookJP03oookJP03o`3o0?oonf[ooo]Z01_ooo]Z1_ooN@0Zoook
JP05ooo=0?oUo`3oiOl0onGo0?oonfX01?oUo`2[oookJP08o`3o/ooonf[ooo]ZoookJ_l0eOoooo]Z
ool0:ol0okH<oookJP03ol00oooonf[ooo]Z00Cooo]Z00?oo`2SoookJ_oonfX00_oonfX00ooo08Go
oo]ZoookJP08oookJP05o`[o0?oonf[ooo]ZoookJ_ooN`000ooonfX01Oo5o`3ooo]ZoookJ_oonf[o
oh`000Sooo]Z00?oYOl0o`3o9?oonfX01ooonfX00onoo`3ooo]ZoookJP06oookJP03ool0>ooonf[o
oo]Z00Cooo]Z00?o0?mjoookJ_l0TOl01?oonfX00ooo0<ko0?oRoookJP0;oookJP05o`2<oomn0?oo
oo]ZoookJ_oo2P003OoonfX00ooo0?cooo]ZoookJP02oookJP05oooC0?oonf[ooo]ZoookJ_l0oiT0
4ooonfX00oooB03ooo]ZoookJP0=oookJP03o`3oO?oonf[ooo]Z013ooo]Z00?o00;ooookJ_oonfX0
1ooonfX02?oO0?oooo]ZoookJ_l06_oo0000o`0]ool0003omOl02_oonfX00oooW03ooo]ZoookJP02
oookJP03o`2Ioooonf[ooo]Z00Gooo]Z00?oofH0oj@0oooonfX01?oonfX00ol0o`3ooo]ZoookJP0M
oookJP03oola0?oonf[ooo]Z02[ooo]Z00Coold0oookJ_oonf[oo`2jR?oonfX002_ooo]Z00So0?nc
oookJ_oonf[ooo]Zo`3Eoooonf[oo`0[onGo00cooo]Z00?o`03ooookJ_oonfX00ooonfX00ooo0:?o
oo]ZoookJP03oookJP03ool0QOoonf[ooo]Z00Oooo]Z00Go2_l0oookJ_oonf[ooo]Zoomk0003oook
JP03olGo0?oonf[ooo]Z00;ooo]Z00?ooh`0oookJ_oonfX01_oonfX00onUo`3ooo]ZoookJP07oook
JP03okoo0?oonf[ooo]Z00Oooo]Z00?oo`0koookJ_oonfX00_oonfX01Ol0og[ooo]ZoookJ_oonf[o
ogT000?ooo]Z00?oo`3>oookJ_oonfX02?oonfX2oomi0003o`2<oooonf[oogT000;ooo]Z00?oogT0
oookJ_oonfX02_oonfX00ooo0?cooo]ZoookJP02oookJP03oooC0?oonf[ooo]Z00?ooo]Z00?o0?nI
oookJ_oonfX03ooonfX00oooB03ooo]ZoookJP0>oookJP03o`3oO?oonf[ooo]Z00gooo]Z1ooob@06
oookJP05oml0oomFo`3ooo]Zo`0Jool0;Ol00_l000000ooeo`3o0000o`000006oookJPOoogT000?o
oo]Zo`2IoooonfX01_oonfX00oooIP3ooo]ZoookJP03oookJP03o`3o0?oonf[ooo]Z01cooo]Z1Ooo
N@0ZoookJP[oiOl0ZOoonfX02?l0ok?ooo]ZoookJ_oonf[o0=GooookJ_oo02_o0?nf3?oonfX00oo0
0?oooo]ZoookJP04oookJP03ool0Xooonf[ooo]Z00;ooo]Z00?oo`25oookJ_oonfX02?oonfX01Ol:
o`3ooo]ZoookJ_oonf[oog/000?ooo]Z00?oaOl0oookJ_oonfX00_oonfX00oooS03ooo]ZoookJP06
oookJP03ojGo0?oonf[ooo]Z00Kooo]Z00?o_ol0oookJ_oonfX01ooonfX00ooo03_ooo]ZoookJP03
oookJP04o`3oN_oonf[ooo]Zo`2Ao`?ooo]Z00?oo`3>o`3oh_oonfX02ooonfX00ol0S?ooOP3ooook
JP02oookJP03ool:0?oonf[ooo]Z00[ooo]Z00?oo`3loookJ_oonfX00_oonfX00oood`3ooo]Zoook
JP02oookJP03o`3oVOoonf[ooo]Z013ooo]Z00?oodP0oookJ_oonfX03_oonfX00ol0ogcooo]Zoook
JP0@oookJP03o`02oooonf[ooo]Z00Oooo]Z00Oog`3ooookJ_l06_oooo]Zo`0]ool0003omOl000;o
00002OoonfX00oooW03ooo]ZoookJP02oookJP03o`2Ioooonf[ooo]Z00Gooo]Z00?oofH0oj@0oooo
nfX01?oonfX00ol0o`3ooo]ZoookJP0MoookJP03oola0?oonf[ooo]Z02_ooo]Z00?oold0oookJ_oo
nfX00_oo0;Z6oookJP00:_oonfX02?l0ok?ooo]ZoookJ_oonf[o0=GooookJ_oo02_oiOl03?oonfX0
0oo00?oooo]ZoookJP03oookJP03ool0Xooonf[ooo]Z00?ooo]Z00?oo`25oookJ_oonfX01ooonfX0
1Ol:o`3ooo]ZoookJ_oonf[oog/000?ooo]Z00?oaOl0oookJ_oonfX00_oonfX00oooS03ooo]Zoook
JP06oookJP03ojGo0?oonf[ooo]Z00Oooo]Z00?o_ol0oookJ_oonfX01ooonfX00ooo03_ooo]Zoook
JP02oookJP05o`3oN_oonf[ooo]ZoookJ_ooN@000ooonfX00ooo0<ko0?oRoookJP08oookJP?oogT0
00Go08cooomi0?oonf[ooo]Zoomi000<oookJP03ool0o?oonf[ooo]Z00;ooo]Z00?oom<0oookJ_oo
nfX00ooonfX00ol0oiWooo]ZoookJP0@oookJP03oom80?oonf[ooo]Z00gooo]Z00?o0?mloookJ_oo
nfX03OoonfX9ooo900Gooo]Z00Oog`3ooeKo0?oonf[o01[oo`0]ool0003omOl000;o00001ooonfX6
oomi0003oookJ_l0VOoooo]Z00Oooo]Z00?oofH0oookJ_oonfX00ooonfX00ol0o`3ooo]ZoookJP0M
oookJPCoogT0:OoonfX<onGo0:Oooo]Z00So0?ncoookJ_oonf[ooo]Zo`3Eoooonf[oo`0[o`3o]Pco
oo]Z00?o`03ooookJ_oonfX01?oonfX00ooo0:?ooo]ZoookJP02oookJP03ool0QOoonf[ooo]Z00So
oo]Z00Go2_l0oookJ_oonf[ooo]Zoomk0003oookJP03olGo0?oonf[ooo]Z00;ooo]Z00?ooh`0oook
J_oonfX01_oonfX00onUo`3ooo]ZoookJP06oookJP03okoo0?oonf[ooo]Z00Oooo]Z00?oo`0koook
J_oonfX00ooonfX01?l0og[ooo]ZoookJ_l0TOl3oookJP03ool0c_l0on;ooo]Z00_ooo]Z00?o08co
oookJ_mn0?l00_oonfX00ooo2P3ooo]ZoookJP0:oookJP03ool0o?oonf[ooo]Z00;ooo]Z00?oom<0
oookJ_oonfX00_oonfX00ol0oiWooo]ZoookJP0@oookJP03oom80?oonf[ooo]Z00kooo]Z00?o0?ml
oookJ_oonfX04?oonfX00ol00_oooo]ZoookJP08oookJP08oml0oooonf[o01[ooookJ_l0;Ooo0000
ooGo0?l0000:oookJP06oonL0?oonf[ooo]ZoookJ_l0VOooF`3o1ooonfX00oooIP3oY03ooookJP04
oookJP03o`3o0?oonf[ooo]Z01kooo]Z00?ooc40oookJ_oonfX0:ooonfX01Oooc@3ooo]ZoookJ_oo
nf[oo`2j08Gooo]Z000]oookJP04o`3Eoooonf[oo`0[onGo00cooo]Z00?o`03ooookJ_oonfX00ooo
nfX00ooo0:?ooo]ZoookJP03oookJP03ool0QOoonf[ooo]Z00Oooo]Z00Go2_l0oookJ_oonf[ooo]Z
oomk0003oookJP03olGo0?oonf[ooo]Z00;ooo]Z00?ooh`0oookJ_oonfX01_oonfX00onUo`3ooo]Z
oookJP07oookJP03okoo0?oonf[ooo]Z00Oooo]Z00?oo`0koookJ_oonfX00ooonfX01?l0og[ooo]Z
oookJ_ooN@03oookJP03ool0c_l0on;ooo]Z00Wooo]Z0_ooN@000ol0S?ooogT0oomi0002oomi00co
oo]Z00?oo`3loookJ_oonfX00_oonfX00oood`3ooo]ZoookJP03oookJP03o`3oVOoonf[ooo]Z013o
oo]Z00?oodP0oookJ_oonfX03_oonfX00ol0ogcooo]ZoookJP0=oookJPWoolT01?oonfX02?oO0?oo
E_l0oookJ_oonf[o01[oo`0]ool0003omOl00_l00007oookJPKoogT000?ooo]Zo`2IoooonfX01ooo
nfX00oooIP3ooo]ZoookJP03oookJP03o`3o0?oonf[ooo]Z01gooo]Z1?ooN@0XoookJPkoiOl0ZOoo
nfX01?l0eOoooo]Zool0:ol0okH<oookJP03ol00oooonf[ooo]Z00Cooo]Z00?oo`2SoookJ_oonfX0
0ooonfX00ooo08Gooo]ZoookJP07oookJP05o`[o0?oonf[ooo]ZoookJ_ooN`000ooonfX00oo5o`3o
oo]ZoookJP02oookJP03oon<0?oonf[ooo]Z00Kooo]Z00?oYOl0oookJ_oonfX01_oonfX00onoo`3o
oo]ZoookJP07oookJP03ool0>ooonf[ooo]Z00Cooo]Z00?o0?mjoookJ_l0TOl00ooonfX00ooo0<ko
oo]Zo`3ohP0;oookJP03o`2<oooonf[oOP3o00;ooo]Z00?oo`X0oookJ_oonfX02_oonfX00ooo0?co
oo]ZoookJP02oookJP03oooC0?oonf[ooo]Z00;ooo]Z00?o0?nIoookJ_oonfX04OoonfX00oooB03o
oo]ZoookJP0>oookJP03o`3oO?oonf[ooo]Z013ooo]Z00?o00;ooookJ_oonfX01ooonfX02OoO0?oo
oo]ZoookJ_l06_oooo]Zo`0]ool0003omOl0o`00000:oookJP05oonL0?oonf[ooo]ZoookJ_l0VOl0
2?oonfX00oooIP3oY03ooookJP03oookJP03o`3o0?oonf[ooo]Z01oooo]Z00?ooc40oookJ_oonfX0
;?oonfX2ooo=00;ooo]Z0_oo0;Z3oookJP00;?oonfX01?l0eOoooo]Zool0:ooUo`0<oookJP03ol00
oooonf[ooo]Z00?ooo]Z00?oo`2SoookJ_oonfX00ooonfX00ooo08Gooo]ZoookJP07oookJP05o`[o
0?oonf[ooo]ZoookJ_ooN`000ooonfX00oo5o`3ooo]ZoookJP02oookJP03oon<0?oonf[ooo]Z00Ko
oo]Z00?oYOl0oookJ_oonfX02?oonfX00onoo`3ooo]ZoookJP06oookJP03ool0>ooonf[ooo]Z00?o
oo]Z00Co0?mjoookJ_oonf[oogT00ooonfX00ooo0<ko0?oRoookJP09oookJP;oogT000?o08cooomi
0?ooN@000oooN@0<oookJP03ool0o?oonf[ooo]Z00;ooo]Z00?oom<0oookJ_oonfX00ooonfX00ol0
oiWooo]ZoookJP0?oookJP03oom80?oonf[ooo]Z00kooo]Z00?o0?mloookJ_oonfX03_oonfX8ooo9
00Gooo]Z00Sog`3ooeKo0?oonf[o01[oo`0]oooonf[o0000ooGo00;o00001ooonfX5oomi00;ooo]Z
00?o09WooookJ_oonfX01_oonfX00oooIP3ooo]ZoookJP03oookJP03o`3o0?oonf[ooo]Z01kooo]Z
0oooN@0WoookJQ3oiOl0YooonfX01?l0eOoooo]Zool0:ol0okH<oookJP03ol00oooonf[ooo]Z00Co
oo]Z00?oo`2SoookJ_oonfX00ooonfX00ooo08Gooo]ZoookJP07oookJP05o`[o0?oonf[ooo]Zoook
J_ooN`000ooonfX00oo5o`3ooo]ZoookJP02oookJP03oon<0?oonf[ooo]Z00Kooo]Z00?oYOl0oook
J_oonfX01ooonfX00onoo`3ooo]ZoookJP06oookJP03ool0>ooonf[ooo]Z00Cooo]Z00?o0?mjoook
J_l0TOl01?oonfX00ooo0<ko0?oRoookJP0;oookJP05o`2<oomn0?oooo]ZoookJ_oo2P003OoonfX0
0ooo0?cooo]ZoookJP02oookJP03oooC0?oonf[ooo]Z00;ooo]Z00?o0?nIoookJ_oonfX04?oonfX0
0oooB03ooo]ZoookJP0>oookJP03o`3oO?oonf[ooo]Z017ooo]Z00?o00;ooookJ_oonfX01ooonfX0
1ooO0?oooo]Zo`0Joooonf[o02goo`000?oeo`000_l00009oookJP03oonL0?oonf[ooo]Z00;ooo]Z
00?o09WooookJ_oonfX01_oonfX00oooIP3oY03ooookJP03oookJP03o`3o0?oonf[ooo]Z023ooo]Z
00?ooc40oookJ_oonfX0;OoonfX01?ooc@3ooo]ZoookJ_oonfX2ool0^X7ooo]Z000[oookJP04o`3E
oooonf[oo`0[onGo00cooo]Z00?o`03ooookJ_oonfX00ooonfX00ooo0:?ooo]ZoookJP03oookJP03
ool0QOoonf[ooo]Z00Oooo]Z00?o2_l0oookJ_oonfX00_oonfX01?ooN`3ooo]ZoookJ_o5o`04oook
JP03oon<0?oonf[ooo]Z00Kooo]Z00?oYOl0o`3o9?oonfX02?oonfX00onoo`3ooo]ZoookJP06oook
JP03ool0>ooonf[ooo]Z00?ooo]Z00Co0?mjoookJ_oonf[oogT00ooonfX00ooo0<ko0?oRoookJP0:
oookJP;oogT000?o08cooomi0?ooN@001?ooN@0:oookJP03ool0o?oonf[ooo]Z00;ooo]Z00?oom<0
oookJ_oonfX00ooonfX00ol0oiWooo]ZoookJP0@oookJP03oom80?oonf[ooo]Z00kooo]Z00?o0?ml
oookJ_oonfX03_oonfX7ooo900Gooo]Z00Sog`3ooookJ_mFo`3ooo]Zo`0Jool0;Ooooo]ZooGo00?o
00001ooonfX4oomi00?ooo]Z00?o09WooookJ_oonfX01_oonfX00oooIP3ooo]ZoookJP03oookJP03
o`3o0?oonf[ooo]Z01kooo]Z0oooN@0ZoookJPkoiOl0YOoonfX01?l0eOoooo]Zool0:ol0okH<oook
JP03ol00oooonf[ooo]Z00Cooo]Z00?oo`2SoookJ_oonfX00ooonfX00ooo08Gooo]ZoookJP07oook
JP03o`[o0?oonf[ooo]Z00;ooo]Z00Coog/0oookJ_oonf[oaOl01?oonfX00oooS03ooo]ZoookJP06
oookJP03ojGo0?l0obCooo]Z00Oooo]Z00?o_ol0oookJ_oonfX01_oonfX00ooo03_ooo]ZoookJP04
oookJP03o`3oN_oonf[o097o00Cooo]Z00?oo`3>o`3oh_oonfX02ooonfX00ol0S?ooOP3ooookJP02
oookJP03ool:0?oonf[ooo]Z00[ooo]Z00?oo`3loookJ_oonfX00_oonfX00oood`3ooo]ZoookJP02
oookJP03o`3oVOoonf[ooo]Z013ooo]Z00?oodP0oookJ_oonfX03_oonfX00ol0ogcooo]ZoookJP0A
oookJP03o`02oooonf[ooo]Z00Oooo]Z00Sog`3ooeKo0?oonf[o01[ooookJ_l0;Ooo0000ooGo00;o
00002OoonfX00oooW03ooo]ZoookJP02oookJP03o`2Ioooonf[ooo]Z00Kooo]Z00?oofH0oj@0oooo
nfX00ooonfX00ol0o`3ooo]ZoookJP0PoookJP03oola0?oonf[ooo]Z02kooo]Z0_ooc@03oookJP03
ool0^_oonf[ooo]Z07kooo]Z000ZoookJP04o`3Eoooonf[oo`0[onGo00cooo]Z00?o`03ooookJ_oo
nfX00ooonfX00ooo0:?ooo]ZoookJP03oookJP03ool0QOoonf[ooo]Z00Oooo]Z00?o2_l0oookJ_oo
nfX00_oonfX01?ooN`3ooo]ZoookJ_o5o`04oookJP03oon<0?oonf[ooo]Z00Oooo]Z00?oYOl0oook
J_oonfX01ooonfX00onoo`3ooo]ZoookJP06oookJP04ool0>ooonf[ooo]ZoookJP;oogT000Co0?mj
oookJ_oonf[oogT01?oonfX00ooo0<kooo]ZoookJP09oookJP;oogT000?o08cooomi0?ooN@000ooo
N@0;oookJP03ool0o?oonf[ooo]Z00;ooo]Z00?oom<0oookJ_oonfX00ooonfX00ol0oiWooo]Zoook
JP0@oookJP03oom80?oonf[ooo]Z00kooo]Z00?o0?mloookJ_oonfX03ooonfX6ooo900Kooo]Z00So
g`3ooeKo0?oonf[o01[ooookJ_l0;Ooooo]ZooGo00?o00001ooonfX4oomi00?ooo]Z00?o09Wooook
J_oonfX01_oonfX00oooIP3ooo]ZoookJP02oookJP03o`3o0?oonf[ooo]Z023ooo]Z0_ooN@0]oook
JPcoiOl0XooonfX01?l0eOoooo]Zool0:ol0okH<oookJP03ol00oooonf[ooo]Z00Cooo]Z00?oo`2S
oookJ_oonfX00ooonfX00ooo08Gooo]ZoookJP07oookJP03o`[o0?oonf[ooo]Z00;ooo]Z00Coog/0
oookJ_oonf[oaOl01?oonfX00oooS03ooo]ZoookJP06oookJP03ojGo0?l0obCooo]Z00Oooo]Z00?o
_ol0oookJ_oonfX01_oonfX00ooo03_ooo]ZoookJP04oookJP03o`3oN_oonf[o097o00Cooo]Z00?o
o`3>o`3oh_oonfX02ooonfX00ol0S?oooo]Zogh0o`02oookJP03ool:0?oonf[ooo]Z00[ooo]Z00?o
o`3loookJ_oonfX00_oonfX00oood`3ooo]ZoookJP02oookJP03o`3oVOoonf[ooo]Z017ooo]Z00?o
odP0oookJ_oonfX03_oonfX00ol0ogcooo]ZoookJP0AoookJP03o`02oooonf[ooo]Z00Oooo]Z00?o
g`3ooookJ_l06_l00_oonfX00ol0;Ooo0000ooGo0002o`0000Wooo]Z00?ooi`0oookJ_oonfX00_oo
nfX00ol0VOoooo]ZoookJP06oookJP03oomV0?nT0?oooo]Z00?ooo]Z00?o0?l0oookJ_oonfX08?oo
nfX00ooo<@3ooo]ZoookJP0`oookJP04ooo=0?oonf[ooo]ZoookJP;oo`2jO_oonfX002_ooo]Z00?o
o`0[onGo0?oonfX02ooonfX00oo00?oooo]ZoookJP03oookJP03ool0Xooonf[ooo]Z00?ooo]Z00?o
o`25oookJ_oonfX01ooonfX00ol:o`3ooo]ZoookJP02oookJP05oomk0?oonf[ooo]ZoookJ_o5o`00
0ooonfX00oooS03ooo]ZoookJP07oookJP03ojGo0?oonf[ooo]Z00Oooo]Z00?o_ol0oookJ_oonfX0
1_oonfX00ooo03_ooo]ZoookJP02oookJP03oomi0?l0og[oogT000;ooo]Z00GoogT0oookJ_oonf[o
oo]Zool0cP0<oookJP03oomi0?l0S?ooogT000CoogT03?oonfX00ooo0?cooo]ZoookJP02oookJP03
oooC0?oonf[ooo]Z00?ooo]Z00?o0?nIoookJ_oonfX04?oonfX00oooB03ooo]ZoookJP0>oookJP03
o`3oO?oonf[ooo]Z00kooo]Z1_oob@07oookJP05oml0oomFo`3ooo]Zo`0Jool0;Ol00_oonfX01?oe
o`3o0000o`000?l00007oookJP?oogT00ooonfX00ol0VOoooo]ZoookJP06oookJP03oomV0?oonf[o
oo]Z00?ooo]Z00?o0?l0oookJ_oonfX08OoonfX00oooN@3ooo]ZoookJP0^oookJP[oiOl0XooonfX0
0ooo02_o0?nfoookJP0;oookJP03ol00oooonf[ooo]Z00Cooo]Z00?oo`2SoookJ_oonfX00ooonfX0
0ooo08Gooo]ZoookJP07oookJP03o`[o0?oonf[ooo]Z00;ooo]Z00Coog/0oookJ_oonf[oaOl01?oo
nfX00oooS03ooo]ZoookJP06oookJP03ojGo0?l0obCooo]Z00Oooo]Z00?o_ol0oookJ_oonfX01_oo
nfX00ooo03_ooo]ZoookJP04oookJP04o`3oN_oonf[ooo]Zo`2Ao`?ooo]Z00?oo`3>o`3oh_oonfX0
2ooonfX00ol0S?oooo]Zogh0o`02oookJP03ool:0?oonf[ooo]Z00_ooo]Z00?oo`3loookJ_oonfX0
0_oonfX00oood`3ooo]ZoookJP02oookJP03o`3oVOoonf[ooo]Z013ooo]Z00?oodP0oookJ_oonfX0
3_oonfX00ol0ogcooo]ZoookJP0AoookJP03o`02oooonf[ooo]Z00Sooo]Z00Sog`3ooookJ_l06_oo
oo]Zo`0]oooonf[o0000ooGo00;o00002OoonfX01OooW03ooo]ZoookJ_oonf[o09Wo00Sooo]Z00?o
ofH0oj@0oooonfX01?oonfX00ol0o`3ooo]ZoookJP0QoookJP03oola0?oonf[ooo]Z033ooo]Z0_oo
c@03oookJP;oo`2jO?oonfX002[ooo]Z00?oo`0[onGo0?oonfX02ooonfX00oo00?oooo]ZoookJP03
oookJP03ool0Xooonf[ooo]Z00?ooo]Z00?oo`25oookJ_oonfX01ooonfX00ol:o`3ooo]ZoookJP02
oookJP05oomk0?oonf[ooo]ZoookJ_o5o`000ooonfX00oooS03ooo]ZoookJP07oookJP03ojGo0?oo
nf[ooo]Z00Oooo]Z00?o_ol0oookJ_oonfX01_oonfX00ooo03_ooo]ZoookJP02oookJP;oogT000Co
0?mjoomi0?ooN@3oogT00ooonfX00ooo0<ko0?oRoookJP0:oookJP03oomi0?l0S?ooogT000CoogT0
3?oonfX00ooo0?cooo]ZoookJP02oookJP03oooC0?oonf[ooo]Z00?ooo]Z00?o0?nIoookJ_oonfX0
4?oonfX00oooB03ooo]ZoookJP0>oookJP03o`3oO?oonf[ooo]Z00oooo]Z1Ooob@07oookJP08oml0
oomFo`3ooo]ZoookJ_l06_oo02gooookJ_oeo`04o`0000Oooo]Z0oooN@03oookJP03o`2Ioooonf[o
oo]Z00;ooo]Z1OooN@05oookJP03o`3o0?oonf[ooo]Z027ooo]Z00?ooc40oookJ_oonfX0<OoonfX8
onGo0:7ooo]Z00?oo`0[o`3o]_oonfX02ooonfX00oo00?oooo]ZoookJP04oookJP03ool0Xooonf[o
oo]Z00?ooo]Z00?oo`25oookJ_oonfX01ooonfX00ol:o`3ooo]ZoookJP02oookJP04oomk0?oonf[o
oo]ZolGo00Cooo]Z00?ooh`0oookJ_oonfX01_oonfX00onUo`3o0?lToookJP07oookJP03okoo0?oo
nf[ooo]Z00Kooo]Z00?oo`0koookJ_oonfX01?oonfX01?l0og[ooo]ZoookJ_l0TOl3oookJP03ool0
c_oonf[o0?oR00cooo]Z00Go08coogh0oooonf[ooo]Zool:000=oookJP03ool0o?oonf[ooo]Z00;o
oo]Z00?oom<0oookJ_oonfX00_oonfX00ol0oiWooo]ZoookJP0@oookJP03oom80?oonf[ooo]Z00oo
oo]Z00?o0?mloookJ_oonfX04OoonfX00ol00_oooo]ZoookJP07oookJP08oml0oooonf[ooo]Zo`0J
oooonf[o02gooookJ_oeo`03o`0000Wooo]Z00Gooi`0oookJ_oonf[ooo]Zo`2Io`08oookJP03oomV
0?nT0?oooo]Z00Cooo]Z00?o0?l0oookJ_oonfX08OoonfX00ooo<@3ooo]ZoookJP0boookJP03ooo=
0?oonf[ooo]Z00;ooo]Z00?oo`2joookJ_oonfX0NOoonfX002[ooo]Z00?oiOl0oookJ_oonfX02_oo
nfX00oo00?oooo]ZoookJP03oookJP03ool0Xooonf[ooo]Z00?ooo]Z00?oo`25oookJ_oonfX01ooo
nfX00ol:o`3ooo]ZoookJP02oookJP05oomk0?oonf[ooo]ZoookJ_o5o`001?oonfX00oooS03ooo]Z
oookJP06oookJP03ojGo0?oonf[ooo]Z00Oooo]Z00?o_ol0oookJ_oonfX01ooonfX00ooo03_ooo]Z
oookJP02oookJP03oomi0?l0og[oogT000CoogT000?ooo]Zool0c_l0on803?oonfX00oooN@3o08co
oomi0003oomi00cooo]Z00?oo`3loookJ_oonfX00_oonfX00oood`3ooo]ZoookJP03oookJP03o`3o
VOoonf[ooo]Z017ooo]Z00?oodP0oookJ_oonfX03_oonfX00ol0ogcooo]ZoookJP0?oookJPGoolT0
1ooonfX02?oO0?ooE_l0oookJ_l06_oooo]Zo`0]oooonf[omOl01?l00007oookJP;oogT01?oonfX0
0ol0VOoooo]ZoookJP02oookJPWoogT000?ooo]Zo`3o0?oonfX08ooonfX00ooo<@3ooo]ZoookJP0c
oookJP04onGo0?ooc@3ooo]ZoookJP;oiOl000?oo`2joookJ_oonfX0WOoonfX00ol0okKooo]Zoook
JP0:oookJP03ol00oooonf[ooo]Z00Cooo]Z00?oo`2SoookJ_oonfX00ooonfX00ooo08Gooo]Zoook
JP07oookJP03o`[o0?oonf[ooo]Z00;ooo]Z00Coog/0oookJ_oonf[oaOl01OoonfX00oooS03ooo]Z
oookJP06oookJP03ojGo0?oonf[ooo]Z00Kooo]Z00?o_ol0oookJ_oonfX01ooonfX00ooo03_ooo]Z
oookJP03oookJP04o`3oN_oonf[ooo]Zo`2Ao`Cooo]Z00?oo`3>o`3oh_oonfX02ooonfX00ol0S?oo
OP3ooookJP02oookJP03ool:0?oonf[ooo]Z00[ooo]Z00?oo`3loookJ_oonfX00_oonfX00oood`3o
oo]ZoookJP03oookJP03o`3oVOoonf[ooo]Z013ooo]Z00?oodP0oookJ_oonfX03_oonfX00ol0ogco
oo]ZoookJP0AoookJP03o`02oooonf[ooo]Z00Sooo]Z00?og`3ooookJ_l06_l00_oonfX00ol0;Ooo
oo]ZooGo0003o`0000Sooo]Z00?ooi`0oookJ_oonfX00_oonfX00ol0VOoooo]ZoookJP06oookJP03
oomV0?nT0?oooo]Z00Cooo]Z00?o0?l0oookJ_oonfX08OoonfX00ooo<@3ooo]ZoookJP0coookJP;o
old00ooonfX2ool0^WWooo]Z000ZoookJP;oiOl02_oonfX00oo00?oooo]ZoookJP03oookJP03ool0
Xooonf[ooo]Z00?ooo]Z00?oo`25oookJ_oonfX01ooonfX00ol:o`3ooo]ZoookJP02oookJP05oomk
0?oonf[ooo]ZoookJ_o5o`001?oonfX00oooS03ooo]ZoookJP06oookJP03ojGo0?oonf[ooo]Z00Oo
oo]Z00?o_ol0oookJ_oonfX01ooonfX00ooo03_ooo]ZoookJP02oookJP03oomi0?l0og[oogT000Go
ogT000?oo`3>o`3oh_oonfX02ooonfX4oomi0003oookJ_ooN@3ooo]Z00cooo]Z00?oo`3loookJ_oo
nfX00_oonfX00oood`3ooo]ZoookJP02oookJP03o`3oVOoonf[ooo]Z017ooo]Z00?oodP0oookJ_oo
nfX03_oonfX00ol0ogcooo]ZoookJP0@oookJPCoolT02?oonfX02?oO0?ooE_l0oookJ_l06_oooo]Z
o`0]oooonf[omOl01?l00007oookJP03oomi0?oonf[ooo]Z00?ooo]Z00?o09WooookJ_oonfX00_oo
nfX9oomi0003oookJ_l0o`3ooo]Z02?ooo]Z00?ooc40oookJ_oonfX0=OoonfX2ooo=00?ooo]Z0_oo
0;ZYoookJP03ol00oooonf[ooo]Z00Cooo]Z00?oo`2SoookJ_oonfX00ooonfX00ooo08Gooo]Zoook
JP07oookJP03o`[o0?oonf[ooo]Z00;ooo]Z00Coog/0oookJ_oonf[oaOl01OoonfX00oooS03ooo]Z
oookJP06oookJP03ojGo0?oonf[ooo]Z00Kooo]Z00?o_ol0oookJ_oonfX01ooonfX00ooo03_ooo]Z
oookJP04oookJP03o`3oN_oonf[o097o00Cooo]Z00?oo`3>o`3oh_oonfX02ooonfX00ol0S?ooOP3o
oookJP02oookJP03ool:0?oonf[ooo]Z00_ooo]Z00?oo`3loookJ_oonfX00_oonfX00oood`3ooo]Z
oookJP02oookJP03o`3oVOoonf[ooo]Z013ooo]Z00?oodP0oookJ_oonfX03ooonfX00ol0ogcooo]Z
oookJP0AoookJP03o`02oooonf[ooo]Z00Sooo]Z00Gog`3ooookJ_l06_oooo]Zo`0]o`02oookJP04
ooGo0?l0003o0000o`0000Sooo]Z00?ooi`0oookJ_oonfX00_oonfX00ol0VOoooo]ZoookJP06oook
JP03oomV0?nT0?oooo]Z00?ooo]Z00?o0?l0oookJ_oonfX08ooonfX00ooo<@3ooo]ZoookJP0doook
JP;oold00ooonfX2ool0^WOooo]Z000ZoookJP?oiOl02?oonfX00oo00?oooo]ZoookJP03oookJP03
ool0Xooonf[ooo]Z00?ooo]Z00?oo`25oookJ_oonfX01ooonfX00ol:o`3ooo]ZoookJP02oookJP05
oomk0?oonf[ooo]ZoookJ_o5o`001?oonfX00oooS03ooo]ZoookJP06oookJP03ojGo0?l0obCooo]Z
00Sooo]Z00?o_ol0oookJ_oonfX01_oonfX00ooo03_ooo]ZoookJP03oookJP03o`3oN_ooN@3oogT0
00CoogT000?ooo]Zool0c_oonfX03?oonfX01_l0S?ooogT0oomi0?ooN@3ooo]Zoomi00cooo]Z00?o
o`3loookJ_oonfX00_oonfX00oood`3ooo]ZoookJP03oookJP03o`3oVOoonf[ooo]Z013ooo]Z00?o
odP0oookJ_oonfX03ooonfX00ol0ogcooo]ZoookJP0@oookJP?oolT02?oonfX01_oO0?ooE_l0oook
J_l06_oooo]Zo`0]o`;ooo]Z00?omOl0o`000?l000000_l00007oookJP03oonL0?oonf[ooo]Z00;o
oo]Z00?oF`3oo`2IoooonfX00ooonfX8oomi00;ooo]Z00?o0?l0oookJ_oonfX08_oonfX00ooo<@3o
oo]ZoookJP0goookJP;oold00ooonfX2ool0^ZKooo]Z00?o`03ooookJ_oonfX01?oonfX00ooo0:?o
oo]ZoookJP03oookJP03ool0QOoonf[ooo]Z00Oooo]Z00?o2_l0oookJ_oonfX00_oonfX01?ooN`3o
oo]ZoookJ_o5o`05oookJP03oon<0?oonf[ooo]Z00Kooo]Z00?oYOl0oookJ_oonfX01ooonfX00ono
o`3ooo]ZoookJP06oookJP03ool0>ooonf[ooo]Z00Cooo]Z00?o0?mjoookJ_l0TOl01?oonfX00ooo
0<ko0?oRoookJP0;oookJP03o`2<oooonf[oOP3o00;ooo]Z00?oo`X0oookJ_oonfX02ooonfX00ooo
0?cooo]ZoookJP02oookJP03oooC0?oonf[ooo]Z00;ooo]Z00?o0?nIoookJ_oonfX04OoonfX00ooo
B03ooo]ZoookJP0>oookJP03o`3oO?oonf[ooo]Z01;ooo]Z00?o00;ooookJ_oonfX01ooonfX00ooO
0?oooo]Zo`0Jo`02oookJP03o`0]oooonf[omOl000Co00002?oonfX01_ooW03ooo]ZoookJ_oonf[o
F`3oo`2Io`Sooo]Z00?oofH0oj@0oooonfX00ooonfX00ol0o`3ooo]ZoookJP0SoookJP03oola0?oo
nf[ooo]Z03Kooo]Z0_ooc@03oookJP;oo`2jMOoonfX002[ooo]Z1?oUo`06oookJP03ol00oooonf[o
oo]Z00?ooo]Z00?oo`2SoookJ_oonfX00ooonfX00ooo08Gooo]ZoookJP07oookJP03o`[o0?oonf[o
oo]Z00;ooo]Z00Goog/0oookJ_oonf[ooo]ZolGo0004oookJP03oon<0?oonf[ooo]Z00Oooo]Z00?o
YOl0oookJ_oonfX01ooonfX00onoo`3ooo]ZoookJP06oookJP03ool0>ooonf[ooo]Z00?ooo]Z00?o
ogT0o`3oN_ooN@001?ooN@000ooonf[oo`3>oookJP0<oookJP03o`2<ooooN@3oogT000?oogT03?oo
nfX00ooo0?cooo]ZoookJP03oookJP03oooC0?oonf[ooo]Z00;ooo]Z00?o0?nIoookJ_oonfX04Ooo
nfX00oooB03ooo]ZoookJP0>oookJP03o`3oO?oonf[ooo]Z013ooo]Z0ooob@05oookJPCo001o00Wo
g`3ooeKo0?oonf[o01[ooookJ_l0;Ooooo]ZooGo0?oonfX01?l00007oookJP03oonL0?oonf[ooo]Z
00;ooo]Z00?o09WooookJ_oonfX00ooonfX8oomi00;ooo]Z00?o0?l0oookJ_oonfX08ooonfX00ooo
<@3ooo]ZoookJP0hoookJP03ooo=0?oonf[ooo]Z00;ooo]Z00?oo`2joookJ_oonfX0X_oonfX00oo0
0?oooo]ZoookJP04oookJP03ool0Xooonf[ooo]Z00?ooo]Z00?oo`25oookJ_oonfX01ooonfX00ol:
o`3ooo]ZoookJP02oookJP04oomk0?oonf[ooo]ZolGo00Gooo]Z00?ooh`0oookJ_oonfX01_oonfX0
0onUo`3ooo]ZoookJP07oookJP03okoo0?oonf[ooo]Z00Kooo]Z00?oo`0koookJ_oonfX01?oonfX0
1?l0og[ooo]ZoookJ_l0TOl3oookJP03ool0c_l0on;ooo]Z00_ooo]Z00?o08cooookJ_mn0?l00_oo
nfX00ooo2P3ooo]ZoookJP0;oookJP03ool0o?oonf[ooo]Z00;ooo]Z00?oom<0oookJ_oonfX00ooo
nfX00ol0oiWooo]ZoookJP0@oookJP03oom80?oonf[ooo]Z00oooo]Z00?o0?mloookJ_oonfX03ooo
nfX2o`00O`03o`02oooonf[ooo]Z00?ooo]Z1Ol007l00ooO0?oooo]Zo`0Jo`02oookJP03o`0]oooo
nf[omOl000Co00001ooonfX00oooW03ooo]ZoookJP02oookJP03o`2Ioooonf[ooo]Z00Oooo]Z00?o
ofH0oj@0oooonfX00ooonfX00ol0o`3ooo]ZoookJP0SoookJP03oola0?oonf[ooo]Z03Sooo]Z00?o
old0oookJ_oonfX00_oonfX00ooo0;[ooo]ZoookJP1boookJP00:_oonfX2onGo00Oooo]Z00?o`03o
oookJ_oonfX00ooonfX00ooo0:?ooo]ZoookJP03oookJP03ool0QOoonf[ooo]Z00Oooo]Z00?o2_l0
oookJ_oonfX00_oonfX01OooN`3ooo]ZoookJ_oonf[oaOl000Cooo]Z00?ooh`0oookJ_oonfX01ooo
nfX00onUo`3ooo]ZoookJP07oookJP03okoo0?oonf[ooo]Z00Oooo]Z00?oo`0koookJ_oonfX00_oo
nfX00oooN@3o0?mjoomi0003oomi00;ooo]Z00?oo`3>o`3oh_oonfX03?oonfX00ol0S?ooogT0oomi
0004oomi00[ooo]Z00?oo`3loookJ_oonfX00ooonfX00oood`3ooo]ZoookJP02oookJP03o`3oVOoo
nf[ooo]Z017ooo]Z00?oodP0oookJ_oonfX03ooonfX00ol0ogcooo]ZoookJP0@oookJP;oolT000?o
001ooookJ_oonfX00_oonfX4o`00O`0:oml0oomFo`3o001ooookJ_l06_oooo]Zo`0]oooonf[omOl0
oookJPCo00001ooonfX00oooW03ooo]ZoookJP02oookJP03o`2Ioooonf[ooo]Z00?ooo]Z1oooN@03
oookJP03o`3o0?oonf[ooo]Z02?ooo]Z00?ooc40oookJ_oonfX0>OoonfX2ooo=00?ooo]Z0_oo0;ZQ
oookJP03ol00oooonf[ooo]Z00Cooo]Z00?oo`2SoookJ_oonfX00ooonfX00ooo08Gooo]ZoookJP07
oookJP03o`[o0?oonf[ooo]Z00;ooo]Z00Coog/0oookJ_oonf[oaOl01OoonfX00oooS03ooo]Zoook
JP06oookJP03ojGo0?oonf[ooo]Z00Oooo]Z00?o_ol0oookJ_oonfX01ooonfX00ooo03_ooo]Zoook
JP03oookJP04o`3oN_oonf[ooo]Zo`2Ao`Cooo]Z00?oo`3>oookJ_oonfX02ooonfX00ol0S?ooOP3o
oookJP02oookJP03ool:0?oonf[ooo]Z00[ooo]Z00?oo`3loookJ_oonfX00_oonfX00oood`3ooo]Z
oookJP03oookJP03o`3oVOoonf[ooo]Z013ooo]Z00?oodP0oookJ_oonfX03ooonfX00ol0ogcooo]Z
oookJP0@oookJP;o001o00?o00;ooookJ_oonfX00_oonfX5o`00O`09oml0ool007oooo]Zo`0Joooo
nf[o02gooookJ_oeo`3ooo]Z00Co00001ooonfX00oooW03ooo]ZoookJP02oookJP03o`2Ioooonf[o
oo]Z00Kooo]Z00?oofH0oookJ_nT0?l01?oonfX00ol0o`3ooo]ZoookJP0SoookJP03oola0?oonf[o
oo]Z03Wooo]Z0_ooc@03oookJP;oo`2jL_oonfX003;ooo]Z00?o`03ooookJ_oonfX00ooonfX00ooo
0:?ooo]ZoookJP03oookJP03ool0QOoonf[ooo]Z00Oooo]Z00?o2_l0oookJ_oonfX00_oonfX01Ooo
N`3ooo]ZoookJ_oonf[oaOl000Cooo]Z00?ooh`0oookJ_oonfX01ooonfX00onUo`3ooo]ZoookJP07
oookJP03okoo0?oonf[ooo]Z00Oooo]Z00?oo`0koookJ_oonfX00ooonfX00ol0og[oogT0oomi0002
oomi00;ooo]Z00?oo`3>o`3oh_oonfX03?oonfX00ol0S?ooogT0oomi0006oomi00Wooo]Z00?oo`3l
oookJ_oonfX00_oonfX00oood`3ooo]ZoookJP03oookJP03o`3oVOoonf[ooo]Z017ooo]Z00?oodP0
oookJ_oonfX03_oonfX00ol0ogcooo]ZoookJP0AoookJP03ooo90?l007oo001o00?ooo]Z1?l007l0
1Ooonf[og`3ooeKo0?l007oo01[o00;ooo]Z00Co02gooookJ_oeo`3ooo]Z1?l00006oookJP03oonL
0?oonf[ooo]Z00?ooo]Z00?o09WooookJ_oonfX00ooonfX7oomi00?ooo]Z00?o0?l0oookJ_oonfX0
8ooonfX00ooo<@3ooo]ZoookJP0koookJP;oold00ooonfX2ool0^Ykooo]Z00?o`03ooookJ_oonfX0
1?oonfX00ooo0:?ooo]ZoookJP03oookJP03ool0QOoonf[ooo]Z00Oooo]Z00?o2_l0oookJ_oonfX0
0_oonfX01?ooN`3ooo]ZoookJ_o5o`05oookJP03oon<0?oonf[ooo]Z00Kooo]Z00?oYOl0oookJ_oo
nfX01ooonfX00onoo`3ooo]ZoookJP07oookJP03ool0>ooonf[ooo]Z00?ooo]Z00Co0?mjoookJ_oo
nf[o097o1?oonfX00ooo0<kooo]ZoookJP0;oookJP03o`2<oomn0?oooo]Z00;ooo]Z00?oo`X0oook
J_oonfX02ooonfX00ooo0?cooo]ZoookJP02oookJP03oooC0?oonf[ooo]Z00?ooo]Z00?o0?nIoook
J_oonfX04?oonfX00oooB03ooo]ZoookJP0>oookJP03o`3oO?oonf[ooo]Z017ooo]Z00?o001oo`02
ool007l00ooonfX4o`00O`05oookJ_l007oog`3oo`00Ool06_l00_oonfX01?l0;Ooooo]ZooGo0?oo
nfX4o`0000Oooo]Z00?ooi`0oookJ_oonfX00_oonfX00ol0VOoooo]ZoookJP06oookJP03oomV0?nT
0?oooo]Z00Cooo]Z00?o0?l0oookJ_oonfX08ooonfX00ooo<@3ooo]ZoookJP0koookJP;oold00ooo
nfX2ool0^W3ooo]Z000aoookJP03ol00oooonf[ooo]Z00?ooo]Z00?oo`2SoookJ_oonfX00ooonfX0
0ooo08Gooo]ZoookJP08oookJP05o`[o0?oonf[ooo]ZoookJ_ooN`000ooonfX00oo5o`3ooo]Zoook
JP02oookJP03oon<0?oonf[ooo]Z00Oooo]Z00?oYOl0oookJ_oonfX01ooonfX00onoo`3ooo]Zoook
JP07oookJP03ool0>ooonf[ooo]Z00?ooo]Z00Co0?mjoomi0?ooN@3oogT00ooonfX00ooo0<ko0?oR
oookJP0<oookJP03o`2<oomn0?ooogT000GoogT02_oonfX00ooo0?cooo]ZoookJP03oookJP03oooC
0?oonf[ooo]Z00;ooo]Z00?o0?nIoookJ_oonfX04OoonfX00oooB03ooo]ZoookJP0?oookJP03o`3o
O?oonf[ooo]Z017ooo]Z00?o00;oo`00Ool007l00ooonfX3o`00O`;ooo]Z00Sog`3ooeKo0?l007oo
01[ooookJ_l0;Ooooo]ZooGo00;ooo]Z1?l00006oookJP03oonL0?oonf[ooo]Z00;ooo]Z00?o09Wo
oookJ_oonfX01?oonfX6oomi00Cooo]Z00?o0?l0oookJ_oonfX09?oonfX00ooo<@3ooo]ZoookJP0l
oookJP03ooo=0?oonf[ooo]Z00;ooo]Z00?oo`2joookJ_oonfX0V_oonfX00oo00?oooo]ZoookJP04
oookJP03ool0Xooonf[ooo]Z00?ooo]Z00?oo`25oookJ_oonfX01ooonfX00ol:o`3ooo]ZoookJP02
oookJP04oomk0?oonf[ooo]ZolGo00Gooo]Z00?ooh`0oookJ_oonfX01_oonfX00onUo`3ooo]Zoook
JP07oookJP03okoo0?oonf[ooo]Z00Oooo]Z00?oo`0koookJ_oonfX00ooonfX01?l0og[ooo]Zoook
J_l0TOl4oookJP03ool0c_oonf[ooo]Z00_ooo]Z00?o08cooookJ_mn0?l00_oonfX00ooo2P3ooo]Z
oookJP0;oookJP03ool0o?oonf[ooo]Z00;ooo]Z00?oom<0oookJ_oonfX00ooonfX00ol0oiWooo]Z
oookJP0@oookJP03oom80?oonf[ooo]Z00oooo]Z00?o0?mloookJ_oonfX04OoonfX00ol007oo00;o
o`00O`03oookJP?o001o0ooonfX00ooO0?oo001oo`0Jo`02oookJP04o`0]oooonf[omOl0oookJPCo
00001_oonfX00oooW03ooo]ZoookJP02oookJP03oe/0ool0VOoooo]Z00Oooo]Z00?oofH0oj@0oooo
nfX01?oonfX00ol0o`3ooo]ZoookJP0ToookJP03oola0?oonf[ooo]Z03cooo]Z00?oold0oookJ_oo
nfX00_oonfX00ooo0;[ooo]ZoookJP1]oookJP00<?oonfX00oo00?oooo]ZoookJP03oookJP03ool0
Xooonf[ooo]Z00?ooo]Z00?oo`25oookJ_oonfX02?oonfX01Ol:o`3ooo]ZoookJ_oonf[oog/000?o
oo]Z00?oaOl0oookJ_oonfX00_oonfX00oooS03ooo]ZoookJP07oookJP03ojGo0?oonf[ooo]Z00Oo
oo]Z00?o_ol0oookJ_oonfX01ooonfX00ooo03_ooo]ZoookJP03oookJP04o`3oN_ooN@3oogT0oomi
00?ooo]Z00?oo`3>o`3oh_oonfX03?oonfX00ol0S?oooo]Zoomi0005oomi00[ooo]Z00?oo`3loook
J_oonfX00ooonfX00oood`3ooo]ZoookJP02oookJP03o`3oVOoonf[ooo]Z017ooo]Z00?oodP0oook
J_oonfX03ooonfX00ol0ogcooo]ZoookJP0BoookJP03o`02ool007oo001o00Oooo]Z00Wog`3ooeKo
0?l007oo01[oo`00Oooonf[o02gooookJ_oeo`000_oonfX6o`0000Cooo]Z00?ooi`0oookJ_oonfX0
0_oonfX00ol0VOoooo]ZoookJP05oookJPGoogT01?oonfX00ol0o`3ooo]ZoookJP0ToookJP03oola
0?oonf[ooo]Z03cooo]Z00?oold0oookJ_oonfX00ooonfX00ooo0;[ooo]ZoookJP2HoookJP03ol00
oooonf[ooo]Z00Cooo]Z00?oo`2SoookJ_oonfX00ooonfX00ooo08Gooo]ZoookJP07oookJP03o`[o
0?oonf[ooo]Z00;ooo]Z00Coog/0oookJ_oonf[oaOl01OoonfX00oooS03ooo]ZoookJP06oookJP03
ojGo0?oonf[ooo]Z00Oooo]Z00?o_ol0oookJ_oonfX01ooonfX00ooo03_ooo]ZoookJP03oookJP04
o`3oN_oonf[ooo]Zo`2Ao`Cooo]Z00?oo`3>oookJ_oonfX02ooonfX00ol0S?oooo]Zogh0o`02oook
JP03ool:0?oonf[ooo]Z00_ooo]Z00?oo`3loookJ_oonfX00_oonfX00oood`3ooo]ZoookJP03oook
JP03o`3oVOoonf[ooo]Z013ooo]Z00?oodP0oookJ_oonfX03ooonfX00ol0ogcooo]ZoookJP0Boook
JP03o`02ool007oo001o00Sooo]Z00Sog`3oo`00Ool007oo01[ooookJ_l0;Ooooo]ZooGo00;ooo]Z
1_l00004oookJP03oonL0?oonf[ooo]Z00;ooo]Z00?oF`3oo`2IoooonfX01ooonfX00oooIP3oY03o
oookJP04oookJP03o`3o0?oonf[ooo]Z02Cooo]Z00?ooc40oookJ_oonfX0?OoonfX00oooc@3ooo]Z
oookJP02oookJP03ool0^_oonf[ooo]Z06cooo]Z003VoookJP?o001o2OoonfX3o`00O`Kooo]Z1?l0
003ooookJ][ooo]Z0ol007l9oookJP?o001o1_oonfX4o`000?Oooo]Z003VoookJP?o001o1?oonfX2
o`00O`;ooo]Z1?l007l6oookJPCo0000oooonf[JoookJP?o001o1?oonfX2o`00O`;ooo]Z1?l007l6
oookJPCo0000mooonfX00>Kooo]Z0ol007l4oookJPOo001ooooonf[UoookJP?o001o1?oonfX7o`00
Oooooo]Z0ooonfX00>Kooo]Z0ol007l4oookJPKo001ooooonf[VoookJP?o001o1?oonfX6o`00Oooo
oo]Z1?oonfX00>?ooo]Z1_l007l4oookJP;o001ooooonf[WoookJPKo001o1?oonfX2o`00Oooooo]Z
2?oonfX00>?ooo]Z1_l007l4oookJP;o001ooooonf[WoookJPKo001o1?oonfX2o`00Oooooo]Z2?oo
nfX00>Gooo]Z1?l007l5oookJPOo001ooooonf[SoookJPCo001o1OoonfX7o`00Oooooo]Z0_oonfX0
0>Kooo]Z0ol007l5oookJPOo001ooooonf[ToookJP?o001o1OoonfX7o`00Oooooo]Z0_oonfX00?oo
oo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]Zjooo
nfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oo
oo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[o
oookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00
oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[
oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Z
oooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooook
J_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z
003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooook
J^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooo
nf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00001
\
\>"],
  ImageRangeCache->{{{0, 999}, {999, 0}} -> {-0.0500105, -0.0500105, \
0.00210213, 0.00210213}, {{23.75, 476.812}, {975.188, 522.125}} -> {-71.9892, \
-71.0885, 0.283964, 0.283964}, {{522.125, 975.188}, {975.188, 522.125}} -> \
{-213.51, -71.0885, 0.283964, 0.283964}, {{23.75, 476.812}, {476.812, 23.75}} -> \
{-17.9973, -53.1523, 0.070991, 0.070991}, {{522.125, 975.188}, {476.812, \
23.75}} -> {-53.3774, -53.1523, 0.070991, 0.070991}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
In this next example, the eigenvalues are real and of opposite \
sign, and the system of equations has an unstable saddle point. The \
eigenvectors are real and correspond to directions along which the system \
will evolve along a straight trajectory.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CritPointPlotPointsMany[1.25, 0.25, 0.75, \(-1.75\), \ 200]\)], "Input",\

  CellTags->"mmtag:25:fixed_point__saddle_node_visualization"],

Cell[BoxData[
    \("Unstable"\)], "Print"],

Cell[BoxData[
    \("Saddle"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Eigenvalues = \
"\[InvisibleSpace]\(-1.8112494995995996`\)\[InvisibleSpace]" and "\
\[InvisibleSpace]1.3112494995995991`\),
      SequenceForm[ 
      "Eigenvalues = ", -1.8112494995995996, " and ", 1.3112494995995991],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Stable \
(\[Lambda]="\[InvisibleSpace]\(-1.8112494995995996`\)\[InvisibleSpace]") \
direction is \[Theta] = "\[InvisibleSpace]94.6687563267693`\),
      SequenceForm[ 
      "Stable (\[Lambda]=", -1.8112494995995996, ") direction is \[Theta] = ",
         94.668756326769298],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Unstable \
(\[Lambda]="\[InvisibleSpace]1.3112494995995991`\[InvisibleSpace]") direction \
is \[Theta] = "\[InvisibleSpace]13.766192496152701`\),
      SequenceForm[ 
      "Unstable (\[Lambda]=", 1.3112494995995991, 
        ") direction is \[Theta] = ", 13.766192496152701],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{\(-1.8112494995995996`\), 
        1.3112494995995991`}, {{\(-0.0813950251558419`\), 
          0.9966819201128714`}, {0.9712748580499135`, 
          0.23796039611691722`}}}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 1000 1000 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto fill
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto
-15. 3.75 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00833333 0.5 0.00833333 [
[0 .4875 -18.4688 -20 ]
[0 .4875 18.4688 0 ]
[.16667 .4875 -18.4688 -20 ]
[.16667 .4875 18.4688 0 ]
[.33333 .4875 -18.4688 -20 ]
[.33333 .4875 18.4688 0 ]
[.66667 .4875 -12 -20 ]
[.66667 .4875 12 0 ]
[.83333 .4875 -12 -20 ]
[.83333 .4875 12 0 ]
[1 .4875 -12 -20 ]
[1 .4875 12 0 ]
[.4875 0 -36.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .16667 -36.9375 -10 ]
[.4875 .16667 0 10 ]
[.4875 .33333 -36.9375 -10 ]
[.4875 .33333 0 10 ]
[.4875 .66667 -24 -10 ]
[.4875 .66667 0 10 ]
[.4875 .83333 -24 -10 ]
[.4875 .83333 0 10 ]
[.4875 1 -24 -10 ]
[.4875 1 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.16667 .5 m
.16667 .50625 L
s
gsave
.16667 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.33333 .5 m
.33333 .50625 L
s
gsave
.33333 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.66667 .5 m
.66667 .50625 L
s
gsave
.66667 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.83333 .5 m
.83333 .50625 L
s
gsave
.83333 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 .5 m
.04167 .50375 L
s
.08333 .5 m
.08333 .50375 L
s
.125 .5 m
.125 .50375 L
s
.20833 .5 m
.20833 .50375 L
s
.25 .5 m
.25 .50375 L
s
.29167 .5 m
.29167 .50375 L
s
.375 .5 m
.375 .50375 L
s
.41667 .5 m
.41667 .50375 L
s
.45833 .5 m
.45833 .50375 L
s
.54167 .5 m
.54167 .50375 L
s
.58333 .5 m
.58333 .50375 L
s
.625 .5 m
.625 .50375 L
s
.70833 .5 m
.70833 .50375 L
s
.75 .5 m
.75 .50375 L
s
.79167 .5 m
.79167 .50375 L
s
.875 .5 m
.875 .50375 L
s
.91667 .5 m
.91667 .50375 L
s
.95833 .5 m
.95833 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.5 .16667 m
.50625 .16667 L
s
gsave
.4875 .16667 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.5 .33333 m
.50625 .33333 L
s
gsave
.4875 .33333 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.5 .66667 m
.50625 .66667 L
s
gsave
.4875 .66667 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.5 .83333 m
.50625 .83333 L
s
gsave
.4875 .83333 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .04167 m
.50375 .04167 L
s
.5 .08333 m
.50375 .08333 L
s
.5 .125 m
.50375 .125 L
s
.5 .20833 m
.50375 .20833 L
s
.5 .25 m
.50375 .25 L
s
.5 .29167 m
.50375 .29167 L
s
.5 .375 m
.50375 .375 L
s
.5 .41667 m
.50375 .41667 L
s
.5 .45833 m
.50375 .45833 L
s
.5 .54167 m
.50375 .54167 L
s
.5 .58333 m
.50375 .58333 L
s
.5 .625 m
.50375 .625 L
s
.5 .70833 m
.50375 .70833 L
s
.5 .75 m
.50375 .75 L
s
.5 .79167 m
.50375 .79167 L
s
.5 .875 m
.50375 .875 L
s
.5 .91667 m
.50375 .91667 L
s
.5 .95833 m
.50375 .95833 L
s
.01 w
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .581 0 r
.5 Mabswid
.43922 .56504 m
.43266 .55019 L
.42486 .53723 L
.41569 .52577 L
.40502 .51546 L
.39266 .50602 L
.37841 .49717 L
.36203 .48869 L
.34325 .48037 L
.32175 .47199 L
.29716 .46337 L
.26906 .45432 L
.23696 .44465 L
.20033 .43417 L
.15853 .42267 L
.11084 .40994 L
.05645 .39574 L
s
.05645 .39574 m
0 .38124 L
s
1 0 0 r
.43922 .56504 m
.43266 .55019 L
s
% Start of user PostScript
-7.293702 7.8048668 -8.0807984 6.0229653 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42486 .53723 m
.41569 .52577 L
s
% Start of user PostScript
-9.0170783 4.4677727 -10.116999 3.0921333 MAarrowhead1
% End of user PostScript
1 .473 0 r
.29716 .46337 m
.26906 .45432 L
s
% Start of user PostScript
-24.341298 -4.3957901 -27.71338 -5.4816758 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-69.160516 -16.576065 -78.841599 -19.008898 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-197.36179 -48.266806 -225.01208 -55.055392 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-563.40907 -138.0138 -642.34795 -157.35703 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1608.4124 -394.05306 -1833.7673 -449.26535 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4591.6848 -1124.9525 -5235.0267 -1282.5701 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-13108.313 -3211.5101 -14944.921 -3661.4756 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-37421.529 -9168.1997 -42664.668 -10452.758 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-106830.75 -26173.319 -121798.83 -29840.469 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-304979.75 -74719.429 -347710.53 -85188.385 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-870654.29 -213308.56 -992641.86 -243195.27 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2485538.4 -608951.94 -2833787.8 -694272.34 MAarrowhead1
% End of user PostScript
1 .049 0 r
.46282 .48066 m
.45736 .48102 L
.45118 .48092 L
.44417 .48038 L
.4362 .47941 L
.42714 .47801 L
.41683 .47617 L
.40509 .47387 L
.39172 .47107 L
.37649 .46774 L
.35914 .46382 L
.33936 .45925 L
.31682 .45396 L
.29113 .44786 L
.26184 .44084 L
.22845 .43279 L
.19039 .42358 L
.14699 .41304 L
.09752 .401 L
.04112 .38725 L
s
.04112 .38725 m
0 .37721 L
s
1 0 0 r
.46282 .48066 m
.45736 .48102 L
s
% Start of user PostScript
-4.4611492 -2.320897 -5.1162638 -2.2779699 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45118 .48092 m
.44417 .48038 L
s
% Start of user PostScript
-5.8581863 -2.2900124 -6.6999045 -2.3546231 MAarrowhead1
% End of user PostScript
1 .473 0 r
.35914 .46382 m
.33936 .45925 L
s
% Start of user PostScript
-16.903216 -4.341958 -19.276443 -4.8901435 MAarrowhead1
% End of user PostScript
1 .788 0 r
.09752 .401 m
.04112 .38725 L
s
% Start of user PostScript
-48.297296 -11.879867 -55.065395 -13.53023 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-137.8887 -33.793522 -157.20859 -38.525023 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-393.64613 -96.445113 -448.80005 -109.95728 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1123.7791 -275.32423 -1281.232 -313.89979 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3208.1576 -785.99233 -3657.6533 -896.11785 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-9158.6283 -2243.8456 -10441.846 -2558.2313 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-26145.995 -6405.7164 -29809.316 -7303.2228 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-74641.422 -18286.999 -85099.449 -20849.195 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-213085.87 -52205.611 -242941.38 -59520.151 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-608316.2 -149036.25 -693547.52 -169917.75 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1736617.3 -425467.76 -1979935.1 -485080.14 MAarrowhead1
% End of user PostScript
1 0 .147 r
.54265 .58041 m
.55034 .5707 L
.55882 .56311 L
.56826 .55735 L
.57881 .55321 L
.59069 .5505 L
.60408 .5491 L
.61925 .5489 L
.63643 .54985 L
.65595 .55191 L
.67814 .55508 L
.70338 .55937 L
.73211 .56483 L
.76482 .57152 L
.80209 .57955 L
.84455 .58904 L
.89294 .60013 L
.94809 .613 L
s
.94809 .613 m
1 .62528 L
s
1 0 0 r
.54265 .58041 m
.55034 .5707 L
s
% Start of user PostScript
5.1181345 9.6486924 6.0407574 8.4839825 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55882 .56311 m
.56826 .55735 L
s
% Start of user PostScript
7.0586009 7.5730057 8.1906472 6.8822416 MAarrowhead1
% End of user PostScript
1 .473 0 r
.67814 .55508 m
.70338 .55937 L
s
% Start of user PostScript
21.376657 6.6093598 24.405338 7.1240626 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
61.313773 15.343933 69.912348 17.397191 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
175.10576 42.97621 199.64172 48.974939 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
499.9067 122.4939 569.94917 139.65123 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1427.1342 349.6492 1627.0905 398.63738 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4074.1748 998.16565 4645.0084 1138.0186 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
11630.929 2849.5545 13260.541 3248.8062 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
33203.903 8134.8899 37856.11 9274.6712 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
94790.296 23223.433 108071.39 26477.273 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
270606.74 66298.111 308521.52 75587.154 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
772526.44 189267.43 880765.3 215785.74 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2205403.7 540319.48 2514403.3 616023.77 MAarrowhead1
% End of user PostScript
0 .48 1 r
.54302 .46218 m
.54786 .47138 L
.55358 .47946 L
.56026 .48668 L
.56801 .49323 L
.57697 .49931 L
.58728 .50507 L
.59911 .51067 L
.61266 .51625 L
.62816 .52193 L
.64589 .52784 L
.66614 .53411 L
.68925 .54086 L
.71563 .54824 L
.74573 .55637 L
.78007 .56542 L
.81923 .57555 L
.8639 .58693 L
.91483 .59978 L
.9729 .61431 L
s
.9729 .61431 m
1 .62106 L
s
1 0 0 r
.54302 .46218 m
.54786 .47138 L
s
% Start of user PostScript
5.1619022 -4.538154 5.7430735 -3.4344231 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55358 .47946 m
.56026 .48668 L
s
% Start of user PostScript
6.4292085 -2.4642413 7.2311145 -1.5985756 MAarrowhead1
% End of user PostScript
1 .473 0 r
.64589 .52784 m
.66614 .53411 L
s
% Start of user PostScript
17.506735 3.340647 19.936387 4.0930386 MAarrowhead1
% End of user PostScript
1 .788 0 r
.91483 .59978 m
.9729 .61431 L
s
% Start of user PostScript
49.77916 11.973089 56.748277 13.717404 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
142.06252 34.75274 161.96565 39.637631 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
405.54822 99.346224 462.36937 113.26933 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1157.7539 283.64452 1319.967 323.38688 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3305.1481 809.754 3768.2332 923.20902 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
9435.5161 2311.6824 10757.528 2635.5728 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
26936.452 6599.3769 30710.525 7524.0171 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
76898.016 18839.86 87672.215 21479.517 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
219527.98 53783.915 250286.09 61319.591 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
626707.09 153541.98 714515.17 175054.79 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1789119.5 438330.7 2039793.4 499745.31 MAarrowhead1
% End of user PostScript
1 .633 0 r
.52758 .53851 m
.53223 .53438 L
.53739 .53126 L
.54317 .52901 L
.54967 .52755 L
.557 .5268 L
.5653 .52671 L
.57472 .52724 L
.5854 .52838 L
.59755 .53012 L
.61137 .53248 L
.6271 .53547 L
.64502 .53914 L
.66543 .54354 L
.68868 .54874 L
.71518 .55482 L
.74538 .56187 L
.7798 .57001 L
.81904 .57938 L
.86377 .59014 L
.91476 .60246 L
.97289 .61657 L
s
.97289 .61657 m
1 .62316 L
s
1 0 0 r
.52758 .53851 m
.53223 .53438 L
s
% Start of user PostScript
3.3100021 4.6206614 3.8670364 4.125982 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53739 .53126 m
.54317 .52901 L
s
% Start of user PostScript
4.4866652 3.7512003 5.1802183 3.4817695 MAarrowhead1
% End of user PostScript
1 .473 0 r
.61137 .53248 m
.6271 .53547 L
s
% Start of user PostScript
13.364801 3.8970469 15.252591 4.2563901 MAarrowhead1
% End of user PostScript
1 .788 0 r
.81904 .57938 m
.86377 .59014 L
s
% Start of user PostScript
38.284371 9.5258068 43.651983 10.816638 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
109.32465 26.818653 124.643 30.565929 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
312.10654 76.473539 355.83606 87.185847 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
891.00149 218.29548 1015.84 248.88034 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2543.6259 623.1837 2900.0139 710.49797 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
7261.5274 1779.0598 8278.9417 2028.3242 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
20730.163 5078.8485 23634.671 5790.4471 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
59180.34 14499.065 67472.111 16530.532 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
168947.67 41391.84 192618.96 47191.26 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
482310.74 118165.17 549887.41 134721.31 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1376897.7 337337.18 1569815.1 384601.57 MAarrowhead1
% End of user PostScript
0 .479 1 r
.41773 .57722 m
.40859 .55885 L
.39777 .54274 L
.38511 .5284 L
.37039 .51543 L
.35339 .50345 L
.33381 .49213 L
.31133 .48118 L
.28557 .47033 L
.25608 .45932 L
.22237 .4479 L
.18386 .43583 L
.13989 .42285 L
.08971 .40872 L
.03245 .39316 L
s
.03245 .39316 m
0 .38458 L
s
1 0 0 r
.41773 .57722 m
.40859 .55885 L
s
% Start of user PostScript
-9.872273 9.2662423 -10.96941 7.0616166 MAarrowhead1
% End of user PostScript
1 .158 0 r
.39777 .54274 m
.38511 .5284 L
s
% Start of user PostScript
-12.26766 5.1284253 -13.787349 3.4085574 MAarrowhead1
% End of user PostScript
1 .473 0 r
.22237 .4479 m
.18386 .43583 L
s
% Start of user PostScript
-33.315399 -6.2523068 -37.936469 -7.7008706 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-94.707958 -22.754806 -107.96653 -26.077425 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-270.27762 -66.112175 -308.1437 -75.406734 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-771.56476 -189.0071 -879.66827 -215.49634 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2202.6531 -539.63979 -2511.2672 -615.25058 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6288.119 -1540.5752 -7169.1488 -1756.426 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-17951.283 -4398.028 -20466.441 -5014.2368 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-51247.209 -12555.464 -58427.467 -14314.613 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-146300.21 -35843.259 -166798.37 -40865.267 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-417656.93 -102325.11 -476174.94 -116661.91 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1192324.4 -292117.09 -1359381.2 -333045.68 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3403840.3 -833934.05 -3880753.1 -950776.74 MAarrowhead1
% End of user PostScript
.899 1 0 r
.56939 .56752 m
.58035 .56184 L
.59264 .55786 L
.60648 .55543 L
.62212 .5544 L
.63983 .55468 L
.65992 .55622 L
.68274 .55899 L
.70869 .56299 L
.73822 .56826 L
.77184 .57486 L
.81013 .58287 L
.85375 .59242 L
.90346 .60364 L
.9601 .61673 L
s
.9601 .61673 m
1 .62609 L
s
1 0 0 r
.56939 .56752 m
.58035 .56184 L
s
% Start of user PostScript
8.3267645 8.1025174 9.6418504 7.420347 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59264 .55786 m
.60648 .55543 L
s
% Start of user PostScript
11.116605 6.9436869 12.777472 6.6514499 MAarrowhead1
% End of user PostScript
1 .473 0 r
.77184 .57486 m
.81013 .58287 L
s
% Start of user PostScript
32.62086 8.9829558 37.215635 9.9445036 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
93.333687 23.099237 106.41639 26.265926 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
266.49723 65.345921 303.83756 74.485175 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
760.80609 186.4088 867.40312 212.52273 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2171.9472 532.12572 2476.2593 606.68108 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6200.4619 1519.1014 7069.21 1731.9429 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
17701.04 4336.7195 20181.137 4944.3382 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
50532.818 12380.439 57612.983 14115.066 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
144260.77 35343.601 164473.18 40295.601 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
411834.76 100898.69 469537.02 115035.63 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1175703.3 288044.95 1340431.3 328403. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3356390.4 822308.93 3826655. 937522.82 MAarrowhead1
% End of user PostScript
.436 1 0 r
.5472 .55504 m
.55487 .54972 L
.56345 .54581 L
.57308 .54315 L
.58394 .54163 L
.59621 .54115 L
.61012 .54164 L
.62591 .54308 L
.64385 .54545 L
.66426 .54876 L
.68748 .55304 L
.71392 .55834 L
.74404 .56474 L
.77836 .57232 L
.81746 .58122 L
.86202 .59157 L
.91281 .60354 L
.97071 .61732 L
s
.97071 .61732 m
1 .62435 L
s
1 0 0 r
.5472 .55504 m
.55487 .54972 L
s
% Start of user PostScript
5.6634772 6.6045811 6.5847115 5.9659803 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56345 .54581 m
.57308 .54315 L
s
% Start of user PostScript
7.6138604 5.4970062 8.7695493 5.1785003 MAarrowhead1
% End of user PostScript
1 .473 0 r
.68748 .55304 m
.71392 .55834 L
s
% Start of user PostScript
22.497796 6.3646392 25.670844 7.0007596 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
64.405441 15.979428 73.434205 18.158286 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
183.90625 45.103677 209.67455 51.40907 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
525.02428 128.64094 598.58582 146.66154 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1498.8384 367.21499 1708.841 418.66479 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4278.8749 1048.3164 4878.3891 1195.1961 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
12215.306 2992.7255 13926.795 3412.037 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
34872.178 8543.6138 39758.127 9740.6615 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
99552.876 24390.255 113501.25 27807.58 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
284202.93 69629.148 324022.66 79384.904 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
811340.74 198776.86 925017.88 226627.53 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2316210.5 567466.93 2640735.3 646974.85 MAarrowhead1
% End of user PostScript
1 .635 0 r
.42762 .44516 m
.41657 .4486 L
.40412 .45068 L
.39005 .45151 L
.37412 .45118 L
.35604 .44973 L
.3355 .44718 L
.31215 .44353 L
.28558 .43875 L
.25532 .43278 L
.22086 .42555 L
.1816 .41693 L
.13686 .40681 L
.08588 .39502 L
.02777 .38137 L
s
.02777 .38137 m
0 .37477 L
s
1 0 0 r
.42762 .44516 m
.41657 .4486 L
s
% Start of user PostScript
-8.6860417 -6.581073 -10.012063 -6.1682203 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40412 .45068 m
.39005 .45151 L
s
% Start of user PostScript
-11.505813 -5.9186789 -13.193784 -5.8186916 MAarrowhead1
% End of user PostScript
1 .473 0 r
.22086 .42555 m
.1816 .41693 L
s
% Start of user PostScript
-33.496954 -8.9345302 -38.208039 -9.9681556 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-95.779573 -23.636705 -109.20345 -26.897216 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-273.46678 -67.038941 -311.78325 -76.419753 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-780.69966 -191.27928 -890.0839 -218.07663 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2228.7385 -546.03868 -2541.0076 -622.54362 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6362.5892 -1558.8221 -7254.053 -1777.2289 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-18163.88 -4450.1143 -20708.825 -5073.6209 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-51854.131 -12704.158 -59119.425 -14484.141 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-148032.85 -36267.752 -168773.77 -41349.235 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-422603.25 -103536.95 -481814.29 -118043.54 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1206445.1 -295576.64 -1375480.4 -336989.95 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3444152. -843810.35 -3926712.9 -962036.81 MAarrowhead1
% End of user PostScript
1 0 .455 r
.49115 .56311 m
.49151 .55238 L
.49165 .54339 L
.4916 .53585 L
.49135 .52951 L
.49091 .52416 L
.49028 .51964 L
.48946 .51579 L
.48843 .51249 L
.48718 .50965 L
.4857 .50717 L
.48396 .50497 L
.48193 .503 L
.47958 .50119 L
.47687 .4995 L
.47375 .49788 L
.47018 .49629 L
.46609 .4947 L
.46142 .49305 L
.45607 .49133 L
.44997 .48949 L
.443 .48749 L
.43505 .4853 L
.42598 .48288 L
.41563 .48018 L
.40383 .47714 L
.39038 .47373 L
.37503 .46987 L
.35754 .46551 L
.33759 .46055 L
.31484 .45492 L
.2889 .44852 L
.25933 .44124 L
.22562 .43294 L
.18718 .4235 L
.14335 .41274 L
.09338 .40048 L
.03641 .3865 L
s
.03641 .3865 m
0 .37757 L
s
1 0 0 r
.49115 .56311 m
.49151 .55238 L
s
% Start of user PostScript
-1.0619257 7.5728311 -1.0189454 6.2856766 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49165 .54339 m
.4916 .53585 L
s
% Start of user PostScript
-1.0017129 5.2071999 -1.0085726 4.3021901 MAarrowhead1
% End of user PostScript
1 .473 0 r
.4857 .50717 m
.48396 .50497 L
s
% Start of user PostScript
-1.7159048 0.85990901 -1.9249763 0.59658064 MAarrowhead1
% End of user PostScript
1 .788 0 r
.46142 .49305 m
.45607 .49133 L
s
% Start of user PostScript
-4.6299891 -0.83371659 -5.2713381 -1.0406494 MAarrowhead1
% End of user PostScript
.897 1 0 r
.39038 .47373 m
.37503 .46987 L
s
% Start of user PostScript
-13.154603 -3.1522641 -14.99597 -3.6150893 MAarrowhead1
% End of user PostScript
.581 1 0 r
.18718 .4235 m
.14335 .41274 L
s
% Start of user PostScript
-37.538873 -9.1803744 -42.798047 -10.471607 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-107.16226 -26.250648 -122.1767 -29.929799 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-305.92534 -74.950182 -348.78859 -85.451743 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-873.35356 -213.96966 -995.71932 -243.94906 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-2493.2442 -610.8398 -2842.5733 -696.42472 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-7117.6981 -1743.8218 -8114.9604 -1988.149 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-20319.56 -4978.2515 -23166.538 -5675.7555 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-58008.153 -14211.881 -66135.688 -16203.111 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-165601.31 -40571.99 -188803.75 -46256.541 MAarrowhead1
% End of user PostScript
0 .906 1 r
.51827 .54962 m
.52193 .54304 L
.52593 .53777 L
.53033 .53365 L
.53522 .5305 L
.54069 .52822 L
.54684 .5267 L
.55377 .52588 L
.56162 .5257 L
.57051 .52612 L
.58061 .52713 L
.59208 .52872 L
.60514 .53089 L
.61999 .53368 L
.63691 .53712 L
.65618 .54125 L
.67813 .54613 L
.70315 .55185 L
.73167 .55849 L
.76417 .56617 L
.80122 .575 L
.84345 .58515 L
.8916 .59678 L
.94649 .61009 L
s
.94649 .61009 m
1 .6231 L
s
1 0 0 r
.51827 .54962 m
.52193 .54304 L
s
% Start of user PostScript
2.1921351 5.953894 2.6318899 5.1642336 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52593 .53777 m
.53033 .53365 L
s
% Start of user PostScript
3.1112888 4.5329571 3.6395262 4.0376869 MAarrowhead1
% End of user PostScript
1 .473 0 r
.58061 .52713 m
.59208 .52872 L
s
% Start of user PostScript
9.6730558 3.2552582 11.050026 3.4459333 MAarrowhead1
% End of user PostScript
1 .788 0 r
.73167 .55849 m
.76417 .56617 L
s
% Start of user PostScript
27.800302 7.0189099 31.700499 7.9400091 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
79.407739 19.503551 90.53477 22.221564 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
226.70296 55.553232 258.46664 63.333372 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
647.19259 158.56358 737.87095 180.77915 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1847.6019 452.6594 2106.4699 516.08143 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
5274.5225 1292.2476 6013.5371 1473.3047 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
15057.674 3689.1 17167.408 4205.9807 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
42986.554 10531.62 49009.41 12007.207 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
122717.74 30065.602 139911.76 34278.1 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
350333.85 85831.092 399419.21 97856.906 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1000130.9 245030.07 1140259.5 279361.29 MAarrowhead1
% End of user PostScript
0 .211 1 r
.44611 .5348 m
.43974 .52528 L
.43227 .51682 L
.4236 .50916 L
.41358 .50209 L
.40204 .49541 L
.38879 .48894 L
.37361 .48254 L
.35623 .47605 L
.33636 .46931 L
.31366 .46219 L
.28775 .45454 L
.25817 .44621 L
.22442 .43704 L
.18592 .42685 L
.142 .41546 L
.09192 .40267 L
.03481 .38824 L
s
.03481 .38824 m
0 .37951 L
s
1 0 0 r
.44611 .5348 m
.43974 .52528 L
s
% Start of user PostScript
-6.4666449 4.1756621 -7.2316727 3.0339828 MAarrowhead1
% End of user PostScript
1 .158 0 r
.43227 .51682 m
.4236 .50916 L
s
% Start of user PostScript
-8.1272506 2.0184083 -9.1677995 1.0992151 MAarrowhead1
% End of user PostScript
1 .473 0 r
.31366 .46219 m
.28775 .45454 L
s
% Start of user PostScript
-22.360549 -4.5368228 -25.470442 -5.4547121 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-63.637267 -15.369942 -72.548087 -17.589698 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-181.6249 -44.445831 -207.07114 -50.688707 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-518.49075 -127.01701 -591.1363 -144.81704 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1480.1816 -362.63866 -1687.5701 -413.44891 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4225.6125 -1035.2659 -4817.6641 -1180.3175 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-12063.252 -2955.4725 -13753.437 -3369.5644 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-34438.097 -8437.2647 -39263.226 -9619.4118 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-98313.664 -24086.651 -112088.41 -27461.437 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-280665.23 -68762.42 -319989.3 -78396.739 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-801241.35 -196302.53 -913503.46 -223806.52 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2287378.8 -560403.23 -2607864. -638921.45 MAarrowhead1
% End of user PostScript
1 0 .388 r
.5201 .43203 m
.52113 .44436 L
.5226 .4548 L
.52453 .46367 L
.52693 .47128 L
.52983 .47784 L
.53329 .48357 L
.53736 .48864 L
.54209 .4932 L
.54756 .49737 L
.55388 .50129 L
.56114 .50504 L
.56946 .50872 L
.57899 .51243 L
.58989 .51625 L
.60234 .52026 L
.61656 .52454 L
.63279 .52918 L
.65132 .53427 L
.67245 .53992 L
.69655 .54621 L
.72404 .55327 L
.7554 .56122 L
.79115 .5702 L
.83191 .58037 L
.87839 .59192 L
.93139 .60503 L
.99182 .61995 L
s
.99182 .61995 m
1 .62196 L
s
1 0 0 r
.5201 .43203 m
.52113 .44436 L
s
% Start of user PostScript
2.4118366 -8.1561744 2.5356144 -6.6767317 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5226 .4548 m
.52453 .46367 L
s
% Start of user PostScript
2.7122121 -5.424422 2.9431525 -4.3590993 MAarrowhead1
% End of user PostScript
1 .473 0 r
.55388 .50129 m
.56114 .50504 L
s
% Start of user PostScript
6.4655541 0.15434124 7.3364424 0.60456504 MAarrowhead1
% End of user PostScript
1 .788 0 r
.65132 .53427 m
.67245 .53992 L
s
% Start of user PostScript
18.157918 4.1129513 20.69381 4.7898551 MAarrowhead1
% End of user PostScript
.897 1 0 r
.93139 .60503 m
.99182 .61995 L
s
% Start of user PostScript
51.766692 12.603911 59.017806 14.393478 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
147.7667 36.184036 168.46987 41.259338 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
421.83956 103.3455 480.94349 117.82657 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1204.264 295.04125 1372.9937 336.37986 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
3437.9252 842.28455 3919.6137 960.2973 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
9814.5673 2404.5493 11189.689 2741.4513 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
28018.565 6864.4924 31944.253 7826.278 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
79987.225 19596.71 91194.254 22342.41 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
228347.03 55944.566 260340.79 63782.971 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
651883.68 159710.2 743219.25 182087.23 MAarrowhead1
% End of user PostScript
.908 1 0 r
.49686 .56486 m
.49803 .55427 L
.49909 .54546 L
.50008 .53813 L
.50102 .53205 L
.50195 .52701 L
.50287 .52284 L
.50381 .5194 L
.5048 .51658 L
.50585 .51429 L
.50698 .51244 L
.50822 .51096 L
.50959 .50982 L
.51112 .50895 L
.51283 .50834 L
.51476 .50795 L
.51693 .50777 L
.51939 .50777 L
.52218 .50795 L
.52535 .50831 L
.52896 .50885 L
.53306 .50956 L
.53772 .51046 L
.54304 .51156 L
.54909 .51288 L
.55599 .51443 L
.56386 .51624 L
.57282 .51833 L
.58303 .52075 L
.59468 .52354 L
.60795 .52673 L
.62308 .53039 L
.64033 .53458 L
.66 .53937 L
.68242 .54483 L
.70798 .55107 L
.73713 .55819 L
.77035 .56632 L
.80823 .57558 L
.85142 .58615 L
.90066 .59821 L
.9568 .61195 L
s
.9568 .61195 m
1 .62253 L
s
1 0 0 r
.49686 .56486 m
.49803 .55427 L
s
% Start of user PostScript
-0.37694864 7.7827429 -0.23696554 6.5123803 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49909 .54546 m
.50008 .53813 L
s
% Start of user PostScript
-0.10930992 5.4551387 0.0095825783 4.5760836 MAarrowhead1
% End of user PostScript
1 .473 0 r
.50698 .51244 m
.50822 .51096 L
s
% Start of user PostScript
0.83786839 1.4924585 0.98677503 1.3156943 MAarrowhead1
% End of user PostScript
1 .788 0 r
.52218 .50795 m
.52535 .50831 L
s
% Start of user PostScript
2.6619498 0.95440935 3.0423156 0.99752693 MAarrowhead1
% End of user PostScript
.897 1 0 r
.56386 .51624 m
.57282 .51833 L
s
% Start of user PostScript
7.662717 1.9483171 8.7380795 2.2000218 MAarrowhead1
% End of user PostScript
.581 1 0 r
.68242 .54483 m
.70798 .55107 L
s
% Start of user PostScript
21.890363 5.3797585 24.957835 6.1285224 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
62.495968 15.3153 71.252388 17.459957 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
178.41392 43.711972 203.41156 49.836191 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
509.33513 124.7863 580.6982 142.27008 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
1454.0468 356.23861 1657.7736 406.15126 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
4151.0037 1016.9876 4732.6018 1159.478 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
11850.26 2903.2899 13510.602 3310.0705 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
33830.047 8288.2938 38569.983 9449.5685 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
96577.806 23661.369 110109.35 26976.569 MAarrowhead1
% End of user PostScript
.477 0 1 r
.56827 .54143 m
.57844 .53983 L
.58993 .53923 L
.60295 .53957 L
.61773 .54082 L
.63451 .54294 L
.65361 .54597 L
.67533 .54991 L
.70007 .55482 L
.72824 .56076 L
.76034 .56782 L
.79691 .57611 L
.8386 .58577 L
.88611 .59694 L
.94026 .60982 L
s
.94026 .60982 m
1 .62414 L
s
1 0 0 r
.56827 .54143 m
.57844 .53983 L
s
% Start of user PostScript
8.1918675 4.9719691 9.4122203 4.7797484 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58993 .53923 m
.60295 .53957 L
s
% Start of user PostScript
10.791531 4.7078496 12.354065 4.7487355 MAarrowhead1
% End of user PostScript
1 .473 0 r
.76034 .56782 m
.79691 .57611 L
s
% Start of user PostScript
31.240544 8.1384958 35.629528 9.1335009 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
89.286969 21.988921 101.79977 25.035681 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
254.91975 62.481548 290.63727 71.227842 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
727.74891 178.3033 829.71413 203.28354 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2077.5744 509.00304 2368.6638 580.31913 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5931.0466 1453.0949 6762.047 1656.6883 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
16931.915 4148.2854 19304.249 4729.5025 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
48337.125 11842.499 55109.651 13501.754 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
137992.52 33807.892 157326.69 38544.723 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
393940.19 96514.558 449135.24 110037.24 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1124618. 275529.16 1282188.5 314133.61 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3210552.4 786578.92 3660383.7 896786.67 MAarrowhead1
% End of user PostScript
.323 1 0 r
.45805 .5317 m
.4532 .52356 L
.4475 .51636 L
.44086 .50989 L
.43317 .50397 L
.4243 .49843 L
.41411 .49312 L
.40243 .48791 L
.38904 .48267 L
.37374 .47729 L
.35625 .47164 L
.33628 .46561 L
.31348 .45908 L
.28746 .45191 L
.25778 .44398 L
.22392 .43514 L
.18531 .42522 L
.14128 .41404 L
.09106 .40142 L
.0338 .38713 L
s
.0338 .38713 m
0 .37873 L
s
1 0 0 r
.45805 .5317 m
.4532 .52356 L
s
% Start of user PostScript
-5.0341752 3.8043963 -5.6161806 2.8272062 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4475 .51636 m
.44086 .50989 L
s
% Start of user PostScript
-6.3001635 1.963299 -7.097027 1.1870969 MAarrowhead1
% End of user PostScript
1 .473 0 r
.35625 .47164 m
.33628 .46561 L
s
% Start of user PostScript
-17.250051 -3.4028074 -19.646801 -4.1264214 MAarrowhead1
% End of user PostScript
1 .788 0 r
.09106 .40142 m
.0338 .38713 L
s
% Start of user PostScript
-49.072612 -11.829348 -55.943453 -13.544722 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-140.05163 -34.266971 -159.67318 -39.081733 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-399.80899 -97.941743 -455.82606 -111.66758 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1141.37 -279.63086 -1301.2875 -318.81075 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3258.3753 -798.29485 -3714.907 -910.1443 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-9301.9894 -2278.9687 -10605.293 -2598.2755 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-26555.261 -6505.9858 -30275.925 -7417.541 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-75809.794 -18573.248 -86431.522 -21175.55 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-216421.33 -53022.792 -246744.17 -60451.827 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-617838.25 -151369.13 -704403.71 -172577.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1763800.8 -432127.66 -2010927.3 -492673.17 MAarrowhead1
% End of user PostScript
0 .269 1 r
.45847 .44568 m
.45157 .45131 L
.44389 .45552 L
.43527 .4585 L
.42558 .46038 L
.41463 .46124 L
.40223 .46116 L
.38816 .46018 L
.37219 .45832 L
.35403 .45559 L
.33336 .45196 L
.30984 .44739 L
.28305 .44182 L
.25253 .43518 L
.21775 .42735 L
.17812 .41822 L
.13295 .40764 L
.08147 .39543 L
.02277 .38139 L
s
.02277 .38139 m
0 .3759 L
s
1 0 0 r
.45847 .44568 m
.45157 .45131 L
s
% Start of user PostScript
-4.9832376 -6.518144 -5.8111273 -5.843384 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44389 .45552 m
.43527 .4585 L
s
% Start of user PostScript
-6.7335277 -5.3371684 -7.7672401 -4.9795272 MAarrowhead1
% End of user PostScript
1 .473 0 r
.33336 .45196 m
.30984 .44739 L
s
% Start of user PostScript
-19.996342 -5.7648998 -22.819231 -6.3130599 MAarrowhead1
% End of user PostScript
1 .788 0 r
.02277 .38139 m
0 0 rlineto s
.02277 .38139 m
0 .3759 L
s
% Start of user PostScript
-57.267055 -14.233617 -65.295733 -16.166946 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-163.52828 -40.111837 -186.44143 -45.717605 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-466.84952 -114.38841 -532.26019 -130.41203 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1332.7614 -326.52652 -1519.495 -372.27543 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3804.7596 -932.1591 -4337.8453 -1062.7639 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-10861.804 -2661.1204 -12383.654 -3033.9705 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-31008.21 -7596.9495 -35352.778 -8661.3598 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-88522.045 -21687.724 -100924.89 -24726.396 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-252712.18 -61913.979 -288119.74 -70588.76 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-721441.16 -176751.64 -822522.44 -201516.35 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2059565.7 -504589.47 -2348131.9 -575287.62 MAarrowhead1
% End of user PostScript
0 1 .458 r
.54613 .56115 m
.55382 .55478 L
.56237 .54998 L
.57196 .54658 L
.58275 .54443 L
.59494 .54341 L
.60874 .54346 L
.62438 .5445 L
.64215 .54653 L
.66236 .54954 L
.68534 .55356 L
.71151 .55862 L
.74131 .56479 L
.77526 .57217 L
.81394 .58086 L
.85803 .59101 L
.90827 .60277 L
.96554 .61635 L
s
.96554 .61635 m
1 .62459 L
s
1 0 0 r
.54613 .56115 m
.55382 .55478 L
s
% Start of user PostScript
5.5357503 7.3383388 6.4578186 6.5731973 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56237 .54998 m
.57196 .54658 L
s
% Start of user PostScript
7.4848154 5.9979486 8.6354619 5.5899789 MAarrowhead1
% End of user PostScript
1 .473 0 r
.68534 .55356 m
.71151 .55862 L
s
% Start of user PostScript
22.241113 6.4267995 25.381258 7.0341425 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
63.698893 15.835687 72.629381 17.985603 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
181.89536 44.617908 207.38208 50.853172 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
519.28505 127.23646 592.04251 145.05979 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1482.4544 363.20133 1690.1615 414.08866 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4232.1021 1036.8572 4825.0629 1182.1313 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
12081.779 2960.0118 13774.56 3374.7397 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
34490.987 8450.2228 39323.527 9634.1854 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
98464.654 24123.643 112260.56 27503.612 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
281096.28 68868.025 320480.74 78517.14 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
802471.9 196604.01 914906.42 224150.24 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2290891.8 561263.9 2611869.1 639902.71 MAarrowhead1
% End of user PostScript
.376 0 1 r
.44156 .46097 m
.43277 .46291 L
.42284 .46389 L
.41161 .46399 L
.39887 .46325 L
.38441 .46169 L
.36797 .45932 L
.34927 .45612 L
.32798 .45205 L
.30374 .44708 L
.27612 .44111 L
.24466 .43407 L
.2088 .42584 L
.16793 .4163 L
.12134 .40527 L
.06824 .39259 L
.00771 .37803 L
s
.00771 .37803 m
0 .37616 L
s
1 0 0 r
.44156 .46097 m
.43277 .46291 L
s
% Start of user PostScript
-7.0128061 -4.6835904 -8.0679723 -4.4508184 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42284 .46389 m
.41161 .46399 L
s
% Start of user PostScript
-9.2589505 -4.3327108 -10.606762 -4.3209338 MAarrowhead1
% End of user PostScript
1 .473 0 r
.27612 .44111 m
.24466 .43407 L
s
% Start of user PostScript
-26.865413 -7.0666774 -30.641399 -7.9114858 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-76.796889 -18.928895 -87.559705 -21.546909 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-219.26315 -53.745757 -249.98482 -61.268076 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-625.95668 -153.36441 -713.65977 -174.85045 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1786.9785 -437.80764 -2037.3526 -499.14853 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5101.4555 -1249.8467 -5816.2216 -1424.9629 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-14563.603 -3568.0537 -16604.113 -4067.9745 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-41576.084 -10186.057 -47401.318 -11613.228 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-118691.14 -29079.093 -135320.99 -33153.371 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-338838.74 -83014.812 -386313.51 -94646.037 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-967314.71 -236990.17 -1102845.4 -270194.91 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2761484. -676558.05 -3148396.1 -771350.75 MAarrowhead1
% End of user PostScript
0 1 .143 r
.52729 .42474 m
.52911 .43876 L
.53151 .45067 L
.53453 .46086 L
.5382 .46965 L
.54258 .4773 L
.54773 .48405 L
.55375 .4901 L
.56071 .49563 L
.56875 .50079 L
.57799 .50571 L
.58859 .51053 L
.60072 .51535 L
.61461 .5203 L
.63047 .52548 L
.6486 .53099 L
.66928 .53696 L
.69289 .54349 L
.71983 .55071 L
.75055 .55876 L
.78559 .56778 L
.82555 .57793 L
.87112 .5894 L
.92308 .60238 L
.98232 .61711 L
s
.98232 .61711 m
1 .62148 L
s
1 0 0 r
.52729 .42474 m
.52911 .43876 L
s
% Start of user PostScript
3.2745971 -9.03175 3.4926459 -7.3491373 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53151 .45067 m
.53453 .46086 L
s
% Start of user PostScript
3.7811314 -5.919174 4.1433145 -4.6963462 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57799 .50571 m
.58859 .51053 L
s
% Start of user PostScript
9.3583812 0.68541631 10.630235 1.2633088 MAarrowhead1
% End of user PostScript
1 .788 0 r
.71983 .55071 m
.75055 .55876 L
s
% Start of user PostScript
26.379075 6.0854024 30.065814 7.0511724 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
75.22765 18.342004 85.765643 20.938473 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
214.74083 52.590266 244.82771 59.964939 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
613.03643 150.18781 698.92898 171.23213 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1750.0915 428.76778 1995.2972 488.84287 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
4996.1502 1224.0465 5696.1619 1395.548 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
14262.978 3494.401 16261.367 3984.0024 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
40717.861 9975.7944 46422.85 11373.505 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
116241.1 28478.836 132527.66 32469.012 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
331844.35 81301.202 378339.14 92692.332 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
947347.19 232098.16 1080080.2 264617.49 MAarrowhead1
% End of user PostScript
.02 0 1 r
.50732 .52112 m
.50882 .51829 L
.51045 .51602 L
.51224 .51423 L
.51423 .51285 L
.51645 .51185 L
.51895 .51116 L
.52176 .51077 L
.52495 .51065 L
.52855 .51078 L
.53265 .51116 L
.5373 .51177 L
.54259 .51263 L
.54861 .51374 L
.55547 .51512 L
.56327 .51678 L
.57217 .51875 L
.58231 .52105 L
.59386 .52374 L
.60703 .52684 L
.62204 .53042 L
.63916 .53452 L
.65866 .53923 L
.6809 .54462 L
.70626 .55078 L
.73516 .55782 L
.76811 .56586 L
.80568 .57504 L
.84852 .58551 L
.89735 .59745 L
.95303 .61107 L
s
.95303 .61107 m
1 .62257 L
s
1 0 0 r
.50732 .52112 m
.50882 .51829 L
s
% Start of user PostScript
0.87817673 2.534967 1.0580118 2.194705 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51045 .51602 m
.51224 .51423 L
s
% Start of user PostScript
1.2536347 1.921981 1.4688162 1.7071708 MAarrowhead1
% End of user PostScript
1 .473 0 r
.53265 .51116 m
.5373 .51177 L
s
% Start of user PostScript
3.9176093 1.3389798 4.4757893 1.4129155 MAarrowhead1
% End of user PostScript
1 .788 0 r
.59386 .52374 m
.60703 .52684 L
s
% Start of user PostScript
11.263505 2.8485679 12.843816 3.2209913 MAarrowhead1
% End of user PostScript
.897 1 0 r
.76811 .56586 m
.80568 .57504 L
s
% Start of user PostScript
32.173659 7.9033871 36.682029 9.0044655 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
91.853545 22.508843 104.72329 25.661091 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
262.22395 64.245497 298.96424 73.246602 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
748.59555 183.40468 853.48145 209.10147 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
2137.086 523.58184 2436.5136 596.941 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
6100.9396 1494.718 6955.7437 1704.1433 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
17416.924 4267.1116 19857.214 4864.9776 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
49721.727 12181.724 56688.249 13888.508 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
141945.28 34776.308 161833.26 39648.825 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
405224.49 99279.188 462000.58 113189.22 MAarrowhead1
% End of user PostScript
0 .573 1 r
.53829 .55502 m
.54478 .54905 L
.55198 .54451 L
.56004 .54122 L
.56911 .53905 L
.57933 .53789 L
.5909 .53766 L
.60401 .53833 L
.6189 .53985 L
.63582 .54222 L
.65506 .54545 L
.67697 .54958 L
.70192 .55466 L
.73034 .56077 L
.76272 .56798 L
.79962 .57642 L
.84167 .58622 L
.8896 .59755 L
.94424 .61059 L
s
.94424 .61059 m
1 .62399 L
s
1 0 0 r
.53829 .55502 m
.54478 .54905 L
s
% Start of user PostScript
4.5952807 6.6028311 5.373214 5.8860552 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55198 .54451 m
.56004 .54122 L
s
% Start of user PostScript
6.2379295 5.3408634 7.2052666 4.9462326 MAarrowhead1
% End of user PostScript
1 .473 0 r
.65506 .54545 m
.67697 .54958 L
s
% Start of user PostScript
18.607756 5.4540769 21.23681 5.9498807 MAarrowhead1
% End of user PostScript
1 .788 0 r
.94424 .61059 m
0 0 rlineto s
.94424 .61059 m
1 .62399 L
s
% Start of user PostScript
53.309093 13.270822 60.783388 15.067185 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
152.23056 37.345538 173.56082 42.563234 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
434.5972 106.48703 495.48899 121.40348 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1240.6878 303.96875 1414.5209 346.55706 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3541.9083 867.76109 4038.1659 989.34311 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
10111.418 2477.2773 11528.131 2824.3692 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
28866.013 7072.1154 32910.436 8062.9911 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
82406.513 20189.431 93952.508 23018.177 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
235253.6 57636.661 268215.03 65712.146 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
671600.5 164540.78 765698.6 187594.63 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1917280.9 469729.99 2185911.6 535543.96 MAarrowhead1
% End of user PostScript
0 1 .552 r
.4185 .46575 m
.40673 .46523 L
.39337 .46393 L
.37818 .46186 L
.36091 .459 L
.34126 .45533 L
.31887 .45081 L
.29338 .44536 L
.26433 .43891 L
.23123 .43135 L
.1935 .42257 L
.1505 .41243 L
.10149 .40074 L
.04561 .38732 L
s
.04561 .38732 m
0 .37631 L
s
1 0 0 r
.4185 .46575 m
.40673 .46523 L
s
% Start of user PostScript
-9.7802985 -4.1100684 -11.192578 -4.1721318 MAarrowhead1
% End of user PostScript
1 .158 0 r
.39337 .46393 m
.37818 .46186 L
s
% Start of user PostScript
-12.795781 -4.3280114 -14.61781 -4.57675 MAarrowhead1
% End of user PostScript
1 .473 0 r
.1935 .42257 m
.1505 .41243 L
s
% Start of user PostScript
-36.779584 -9.2910634 -41.939638 -10.508856 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-105.05689 -25.804506 -119.77805 -29.400262 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-299.92955 -73.497585 -341.95313 -83.790718 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-856.24025 -209.78077 -976.20836 -239.17212 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2444.3901 -598.87153 -2786.8742 -682.7793 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6978.2297 -1709.6525 -7955.9511 -1949.1923 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-19921.407 -4880.7048 -22712.599 -5564.5414 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-56871.507 -13933.405 -64839.787 -15885.618 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-162356.42 -39776.999 -185104.22 -45350.163 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-463494.1 -113555.13 -528434.37 -129465.36 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1323180.1 -324176.47 -1508571.1 -369596.91 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3777406.2 -925456.96 -4306659.4 -1055122.9 MAarrowhead1
% End of user PostScript
.332 0 1 r
.46741 .44673 m
.46174 .45284 L
.45545 .45756 L
.44844 .46106 L
.44057 .46349 L
.43171 .46496 L
.42169 .46554 L
.41035 .46529 L
.39747 .46425 L
.38285 .46243 L
.36622 .45982 L
.34729 .45641 L
.32574 .45215 L
.3012 .447 L
.27324 .44086 L
.24139 .43365 L
.20508 .42525 L
.16369 .41552 L
.11652 .40431 L
.06275 .39142 L
.00145 .37665 L
s
.00145 .37665 m
0 .3763 L
s
1 0 0 r
.46741 .44673 m
.46174 .45284 L
s
% Start of user PostScript
-3.9103037 -6.3929192 -4.5912341 -5.6593515 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45545 .45756 m
.44844 .46106 L
s
% Start of user PostScript
-5.3455265 -5.0929246 -6.1871114 -4.6723392 MAarrowhead1
% End of user PostScript
1 .473 0 r
.36622 .45982 m
.34729 .45641 L
s
% Start of user PostScript
-16.053983 -4.8215274 -18.325058 -5.230767 MAarrowhead1
% End of user PostScript
1 .788 0 r
.11652 .40431 m
.06275 .39142 L
s
% Start of user PostScript
-46.017154 -11.482696 -52.469734 -13.029009 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-131.41324 -32.244957 -149.82678 -36.748123 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-375.16796 -91.9269 -427.73311 -104.80335 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1071.0296 -262.4028 -1221.0918 -299.16731 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3057.5691 -749.09894 -3485.9658 -854.05517 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8728.7293 -2138.5213 -9951.7135 -2438.15 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-24918.722 -6105.037 -28410.09 -6960.4151 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-71137.811 -17428.621 -81104.946 -19870.549 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-203083.78 -49755.119 -231537.89 -56726.321 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-579762.3 -142040.6 -660992.93 -161941.95 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1655101.8 -405496.63 -1886998.5 -462310.85 MAarrowhead1
% End of user PostScript
1 .053 0 r
.46483 .52607 m
.46076 .51932 L
.45597 .51336 L
.45039 .50799 L
.44393 .50307 L
.43648 .49846 L
.42793 .49404 L
.41812 .4897 L
.40688 .48533 L
.39404 .48083 L
.37935 .47611 L
.36259 .47106 L
.34345 .46559 L
.32162 .45959 L
.2967 .45294 L
.26829 .44552 L
.23588 .4372 L
.19892 .42783 L
.15677 .41724 L
.10872 .40525 L
.05392 .39164 L
s
.05392 .39164 m
0 .3783 L
s
1 0 0 r
.46483 .52607 m
.46076 .51932 L
s
% Start of user PostScript
-4.219969 3.1281435 -4.7093354 2.3187312 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45597 .51336 m
.45039 .50799 L
s
% Start of user PostScript
-5.2841478 1.6026166 -5.9535814 0.9586271 MAarrowhead1
% End of user PostScript
1 .473 0 r
.37935 .47611 m
.36259 .47106 L
s
% Start of user PostScript
-14.477411 -2.8666541 -16.489189 -3.4722375 MAarrowhead1
% End of user PostScript
1 .788 0 r
.15677 .41724 m
.10872 .40525 L
s
% Start of user PostScript
-41.18732 -9.9310773 -46.954175 -11.370408 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-117.5478 -28.761469 -134.01653 -32.802489 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-335.56685 -82.2044 -382.58298 -93.724718 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-957.97231 -234.69923 -1092.194 -267.58361 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2734.8129 -670.02321 -3117.9882 -763.90046 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7807.3267 -1912.7793 -8901.2131 -2180.7793 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-22288.308 -5460.5907 -25411.127 -6225.6753 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-63628.521 -15588.86 -72543.528 -17773.019 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-181646.3 -44502.981 -207096.81 -50738.304 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-518562.74 -127046.83 -591218.68 -144847.39 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1480389.7 -362692.5 -1687807.4 -413509.43 MAarrowhead1
% End of user PostScript
0 .528 1 r
.54452 .55018 m
.55172 .54544 L
.55977 .54198 L
.56882 .53967 L
.57902 .53839 L
.59055 .53806 L
.60363 .53864 L
.61847 .54008 L
.63534 .54238 L
.65453 .54555 L
.67637 .54963 L
.70124 .55466 L
.72957 .56071 L
.76184 .56788 L
.79862 .57627 L
.84053 .58603 L
.88831 .5973 L
.94277 .61028 L
s
.94277 .61028 m
1 .62403 L
s
1 0 0 r
.54452 .55018 m
.55172 .54544 L
s
% Start of user PostScript
5.3427735 6.0216534 6.2067263 5.4525748 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55977 .54198 m
.56882 .53967 L
s
% Start of user PostScript
7.1726135 5.0378152 8.257884 4.760221 MAarrowhead1
% End of user PostScript
1 .473 0 r
.67637 .54963 m
.70124 .55466 L
s
% Start of user PostScript
21.164481 5.9555428 24.148699 6.5590576 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
60.581809 15.023289 69.074368 17.073985 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
172.98651 42.423817 197.22473 48.355097 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
493.84972 121.00216 563.04336 137.95282 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1409.8412 345.41061 1607.3744 393.80547 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4024.8063 986.07003 4588.7228 1124.2284 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
11489.992 2815.0252 13099.857 3209.4389 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
32801.557 8036.3159 37397.391 9162.286 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
93641.681 22942.024 106761.84 26156.437 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
267327.69 65494.748 304783.03 74671.232 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
763165.41 186974. 870092.69 213170.97 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2178679.8 533772.2 2483935.2 608559.14 MAarrowhead1
% End of user PostScript
.752 1 0 r
.47354 .48758 m
.46969 .48762 L
.46532 .48737 L
.46036 .48684 L
.45472 .48603 L
.44831 .48494 L
.44101 .48354 L
.43269 .48184 L
.42322 .4798 L
.41243 .47738 L
.40013 .47456 L
.38611 .47129 L
.37014 .46751 L
.35192 .46316 L
.33116 .45817 L
.3075 .45244 L
.28051 .4459 L
.24975 .43842 L
.21469 .42987 L
.17471 .42011 L
.12912 .40898 L
.07716 .39627 L
.01791 .38178 L
s
.01791 .38178 m
0 .3774 L
s
1 0 0 r
.47354 .48758 m
.46969 .48762 L
s
% Start of user PostScript
-3.1751051 -1.4901131 -3.6374063 -1.4853834 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46532 .48737 m
.46036 .48684 L
s
% Start of user PostScript
-4.161592 -1.5153631 -4.7568112 -1.5790551 MAarrowhead1
% End of user PostScript
1 .473 0 r
.40013 .47456 m
.38611 .47129 L
s
% Start of user PostScript
-11.984485 -3.0525869 -13.666484 -3.4453874 MAarrowhead1
% End of user PostScript
1 .788 0 r
.21469 .42987 m
.17471 .42011 L
s
% Start of user PostScript
-34.237653 -8.4154906 -39.035368 -9.5863927 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-97.747172 -23.95428 -111.44271 -27.308595 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-279.04936 -68.368042 -318.14707 -77.946652 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-796.62869 -195.17279 -908.24453 -222.51839 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2274.2107 -557.17715 -2592.8509 -635.24334 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6492.4025 -1590.6256 -7402.0545 -1813.4885 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-18534.47 -4540.9081 -21131.339 -5177.1357 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-52912.089 -12963.356 -60325.614 -14779.655 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-151053.1 -37007.708 -172217.19 -42192.866 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-431225.45 -105649.37 -491644.55 -120451.93 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1231059.7 -301607.17 -1403543.8 -343865.42 MAarrowhead1
% End of user PostScript
.044 0 1 r
.50475 .44612 m
.50407 .45507 L
.50351 .46254 L
.50307 .46878 L
.50271 .47399 L
.50244 .47834 L
.50224 .48198 L
.5021 .48502 L
.50201 .48757 L
.50198 .4897 L
.50199 .49149 L
.50205 .49299 L
.50215 .49426 L
.5023 .49534 L
.50249 .49625 L
.50274 .49703 L
.50303 .49771 L
.50338 .4983 L
.50379 .49882 L
.50427 .49928 L
.50483 .49971 L
.50547 .50011 L
.5062 .5005 L
.50705 .50087 L
.50802 .50125 L
.50912 .50164 L
.51038 .50205 L
.51183 .50248 L
.51347 .50296 L
.51535 .50347 L
.5175 .50405 L
.51994 .50469 L
.52273 .5054 L
.52591 .50621 L
.52954 .50712 L
.53368 .50815 L
.53839 .50933 L
.54377 .51066 L
.5499 .51217 L
.55689 .51389 L
.56486 .51585 L
.57395 .51808 L
.58431 .52063 L
.59612 .52353 L
.60959 .52683 L
.62494 .5306 L
.64245 .53489 L
.66241 .53978 L
.68516 .54536 L
.7111 .55171 L
Mistroke
.74068 .55896 L
.7744 .56722 L
.81285 .57664 L
.85668 .58738 L
.90666 .59963 L
.96364 .61359 L
Mfstroke
.96364 .61359 m
1 .6225 L
s
1 0 0 r
.50475 .44612 m
.50407 .45507 L
s
% Start of user PostScript
0.56992547 -6.4660575 0.4880579 -5.3917578 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50351 .46254 m
.50307 .46878 L
s
% Start of user PostScript
0.42151182 -4.4950054 0.36799533 -3.7463257 MAarrowhead1
% End of user PostScript
1 .473 0 r
.50199 .49149 m
.50205 .49299 L
s
% Start of user PostScript
0.2387631 -1.0212018 0.24578316 -0.84060946 MAarrowhead1
% End of user PostScript
1 .788 0 r
.50379 .49882 m
.50427 .49928 L
s
% Start of user PostScript
0.45513436 -0.14201162 0.51269671 -0.085908807 MAarrowhead1
% End of user PostScript
.897 1 0 r
.51038 .50205 m
.51183 .50248 L
s
% Start of user PostScript
1.2461349 0.24577309 1.4192738 0.29805362 MAarrowhead1
% End of user PostScript
.581 1 0 r
.52954 .50712 m
.53368 .50815 L
s
% Start of user PostScript
3.5449712 0.85453349 4.0413157 0.97845252 MAarrowhead1
% End of user PostScript
.266 1 0 r
.58431 .52063 m
.59612 .52353 L
s
% Start of user PostScript
10.11723 2.475419 11.534677 2.8232344 MAarrowhead1
% End of user PostScript
0 1 .049 r
.74068 .55896 m
.7744 .56722 L
s
% Start of user PostScript
28.881915 7.0752408 32.928548 8.0667855 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
82.45175 20.200333 94.004079 23.03066 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
235.3827 57.668248 268.36223 65.748173 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
671.96906 164.63106 766.1188 187.69756 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1918.3331 469.98776 2187.1112 535.83785 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
5476.4453 1341.7181 6243.7513 1529.7066 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
15634.122 3830.3285 17824.622 4366.9967 MAarrowhead1
% End of user PostScript
1 .002 0 r
.56642 .43195 m
.57366 .4477 L
.58226 .46146 L
.59235 .47365 L
.60409 .48464 L
.61767 .49474 L
.63333 .50422 L
.65131 .51334 L
.67193 .52232 L
.69553 .53139 L
.72253 .54074 L
.75337 .55058 L
.78858 .56111 L
.82878 .57255 L
.87465 .58511 L
.92698 .59904 L
.98667 .61458 L
s
.98667 .61458 m
1 .618 L
s
1 0 0 r
.56642 .43195 m
.57366 .4477 L
s
% Start of user PostScript
7.9704315 -8.1654465 8.8394578 -6.276268 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58226 .46146 m
.59235 .47365 L
s
% Start of user PostScript
9.8712819 -4.62491 11.081915 -3.1614427 MAarrowhead1
% End of user PostScript
1 .473 0 r
.72253 .54074 m
.75337 .55058 L
s
% Start of user PostScript
26.703011 4.8883689 30.403887 6.0690619 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
75.884672 18.203269 86.507384 20.870145 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
216.55363 52.964026 246.89278 60.412162 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
618.19683 151.43558 704.812 172.65967 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1764.8199 432.37233 2012.0891 492.95362 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5038.1959 1234.3467 5744.0987 1407.2917 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
14383.01 3523.8084 16398.217 4017.53 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
41060.527 10059.747 46813.527 11469.22 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
117219.34 28718.503 133642.96 32742.259 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
334637.03 81985.402 381523.1 93472.395 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
955319.69 234051.41 1089169.8 266844.41 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2727240.7 668168.51 3109355. 761785.75 MAarrowhead1
% End of user PostScript
0 1 .024 r
.56449 .44692 m
.57184 .46013 L
.5805 .47177 L
.5906 .48219 L
.60232 .49169 L
.61584 .50053 L
.63138 .50895 L
.64922 .51717 L
.66966 .52539 L
.69303 .5338 L
.71975 .54258 L
.75026 .55192 L
.78509 .56201 L
.82485 .57305 L
.8702 .58524 L
.92194 .59882 L
.98094 .61403 L
s
.98094 .61403 m
1 .61888 L
s
1 0 0 r
.56449 .44692 m
.57184 .46013 L
s
% Start of user PostScript
7.7388468 -6.3700888 8.6207686 -4.7845856 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5805 .47177 m
.5906 .48219 L
s
% Start of user PostScript
9.6597831 -3.3874676 10.872346 -2.1371175 MAarrowhead1
% End of user PostScript
1 .473 0 r
.71975 .54258 m
.75026 .55192 L
s
% Start of user PostScript
26.369669 5.1094255 30.031252 6.2303397 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
74.996553 18.056762 85.49657 20.681803 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
214.03314 52.363201 244.01955 59.722152 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
611.00485 149.67748 696.61246 170.65406 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1744.2892 427.34325 1988.6818 487.21964 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4979.585 1219.9874 5677.2757 1390.9204 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
14215.688 3482.8148 16207.451 3970.7929 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
40582.857 9942.7186 46268.93 11335.795 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
115855.69 28384.411 132088.25 32361.358 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
330744.09 81031.64 377084.72 92385.001 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
944206.16 231328.62 1076499.1 263740.12 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2695513.8 660395.5 3073182.9 752923.66 MAarrowhead1
% End of user PostScript
.007 1 0 r
.48242 .47682 m
.4795 .47923 L
.47624 .48104 L
.47259 .48232 L
.46848 .48313 L
.46384 .48351 L
.45859 .48349 L
.45263 .48308 L
.44587 .48231 L
.43817 .48116 L
.42942 .47962 L
.41946 .47769 L
.40811 .47534 L
.39518 .47253 L
.38045 .46922 L
.36367 .46535 L
.34453 .46087 L
.32273 .4557 L
.29787 .44975 L
.26953 .44293 L
.23722 .43512 L
.20039 .42618 L
.1584 .41596 L
.11053 .40429 L
.05596 .39097 L
s
.05596 .39097 m
0 .37729 L
s
1 0 0 r
.48242 .47682 m
.4795 .47923 L
s
% Start of user PostScript
-2.1090171 -2.7814425 -2.4599572 -2.4922256 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47624 .48104 m
.47259 .48232 L
s
% Start of user PostScript
-2.8508819 -2.2749632 -3.2889155 -2.121103 MAarrowhead1
% End of user PostScript
1 .473 0 r
.42942 .47962 m
.41946 .47769 L
s
% Start of user PostScript
-8.4693781 -2.4451515 -9.6650871 -2.6767721 MAarrowhead1
% End of user PostScript
1 .788 0 r
.29787 .44975 m
.26953 .44293 L
s
% Start of user PostScript
-24.255977 -6.0295839 -27.656616 -6.8483339 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-69.264045 -16.989961 -78.969146 -19.36431 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-197.73884 -48.450413 -225.4442 -55.237375 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-564.50462 -138.30363 -643.59752 -157.68104 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1611.5445 -394.82544 -1837.3384 -450.14445 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-4600.6272 -1127.1445 -5245.2222 -1285.069 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-13133.842 -3217.765 -14974.028 -3668.6068 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-37494.41 -9186.0554 -42747.76 -10473.116 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-107038.81 -26224.293 -122036.04 -29898.585 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-305573.72 -74864.949 -348387.72 -85354.294 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-872349.94 -213723.99 -994575.09 -243668.91 MAarrowhead1
% End of user PostScript
0 1 .225 r
.42767 .54695 m
.41912 .53415 L
.40911 .52275 L
.39748 .51244 L
.38403 .50293 L
.36855 .49394 L
.35078 .48526 L
.3304 .47665 L
.30709 .46792 L
.28043 .45888 L
.24997 .44932 L
.2152 .43904 L
.17552 .42786 L
.13023 .41555 L
.07857 .40187 L
.01965 .38659 L
s
.01965 .38659 m
0 .38157 L
s
1 0 0 r
.42767 .54695 m
.41912 .53415 L
s
% Start of user PostScript
-8.6793164 5.6345811 -9.7053733 4.0974435 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40911 .52275 m
.39748 .51244 L
s
% Start of user PostScript
-10.906669 2.7303825 -12.302541 1.4933712 MAarrowhead1
% End of user PostScript
1 .473 0 r
.24997 .44932 m
.2152 .43904 L
s
% Start of user PostScript
-30.003026 -6.0821481 -34.1757 -7.3146015 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-85.386353 -20.621628 -97.342563 -23.600221 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-243.69795 -59.635571 -277.84081 -68.012091 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-695.69271 -170.4269 -793.16597 -194.31037 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1986.0557 -486.57583 -2264.3224 -554.75123 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5669.7787 -1389.0835 -6464.1727 -1583.7086 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-16186.049 -3965.5493 -18453.88 -4521.1634 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-46207.831 -11320.826 -52682.02 -12906.99 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-131913.83 -32318.623 -150396.3 -36846.793 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-376586.77 -92263.004 -429350.43 -105190. MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1075077.6 -263391.85 -1225706.9 -300295.74 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3069124.7 -751929.4 -3499140.4 -857282.4 MAarrowhead1
% End of user PostScript
.976 0 1 r
.49451 .52796 m
.49446 .52309 L
.49428 .519 L
.49398 .51554 L
.49356 .51262 L
.493 .51013 L
.49231 .508 L
.49147 .50616 L
.49048 .50455 L
.48932 .50312 L
.48796 .50184 L
.48639 .50066 L
.48458 .49956 L
.4825 .49849 L
.48012 .49745 L
.47739 .4964 L
.47427 .49531 L
.4707 .49417 L
.46663 .49295 L
.46199 .49162 L
.45668 .49017 L
.45063 .48856 L
.44373 .48676 L
.43586 .48474 L
.42689 .48247 L
.41665 .4799 L
.40498 .47698 L
.39167 .47368 L
.3765 .46993 L
.3592 .46566 L
.33948 .4608 L
.31699 .45527 L
.29135 .44897 L
.26212 .44179 L
.22879 .43362 L
.1908 .4243 L
.14748 .41368 L
.09808 .40157 L
.04177 .38777 L
s
.04177 .38777 m
0 .37753 L
s
1 0 0 r
.49451 .52796 m
.49446 .52309 L
s
% Start of user PostScript
-0.65847524 3.3549646 -0.66464882 2.7709122 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49428 .519 m
.49398 .51554 L
s
% Start of user PostScript
-0.68594908 2.2796626 -0.7221327 1.8652868 MAarrowhead1
% End of user PostScript
1 .473 0 r
.48796 .50184 m
.48639 .50066 L
s
% Start of user PostScript
-1.4447926 0.22076548 -1.6331521 0.079401757 MAarrowhead1
% End of user PostScript
1 .788 0 r
.46663 .49295 m
.46199 .49162 L
s
% Start of user PostScript
-4.004024 -0.84602677 -4.5617249 -1.0050196 MAarrowhead1
% End of user PostScript
.897 1 0 r
.40498 .47698 m
.39167 .47368 L
s
% Start of user PostScript
-11.402355 -2.7618668 -12.999165 -3.1583319 MAarrowhead1
% End of user PostScript
.581 1 0 r
.22879 .43362 m
.1908 .4243 L
s
% Start of user PostScript
-32.544724 -7.9659518 -37.10439 -9.0842936 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-92.906913 -22.760261 -105.92408 -25.94973 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-265.22971 -64.980337 -302.39109 -74.08487 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-757.17603 -185.50651 -863.26413 -211.4979 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-2161.5814 -529.58309 -2464.441 -603.7831 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-6170.869 -1511.8505 -7035.4709 -1723.6763 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-17616.558 -4316.0215 -20084.818 -4920.7403 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-50291.64 -12321.351 -57338.014 -14047.699 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-143572.26 -35174.917 -163688.2 -40103.282 MAarrowhead1
% End of user PostScript
.453 1 0 r
.51245 .47504 m
.51351 .47994 L
.51483 .48413 L
.51643 .48776 L
.51834 .49092 L
.52058 .49371 L
.52318 .49623 L
.5262 .49853 L
.52968 .50069 L
.53367 .50276 L
.53826 .50479 L
.5435 .50684 L
.54951 .50894 L
.55636 .51115 L
.5642 .51351 L
.57314 .51607 L
.58334 .51887 L
.59498 .52198 L
.60825 .52545 L
.62339 .52933 L
.64066 .53371 L
.66035 .53866 L
.6828 .54426 L
.7084 .55062 L
.73759 .55785 L
.77087 .56606 L
.80881 .57541 L
.85207 .58605 L
.90139 .59816 L
.95763 .61197 L
s
.95763 .61197 m
1 .62237 L
s
1 0 0 r
.51245 .47504 m
.51351 .47994 L
s
% Start of user PostScript
1.4944156 -2.9957502 1.6214932 -2.4076577 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51483 .48413 m
.51643 .48776 L
s
% Start of user PostScript
1.7800111 -1.9041331 1.9721155 -1.4693642 MAarrowhead1
% End of user PostScript
1 .473 0 r
.53826 .50479 m
.5435 .50684 L
s
% Start of user PostScript
4.5906612 0.57520442 5.220407 0.82052568 MAarrowhead1
% End of user PostScript
1 .788 0 r
.60825 .52545 m
.62339 .52933 L
s
% Start of user PostScript
12.990124 3.0535295 14.807015 3.5200394 MAarrowhead1
% End of user PostScript
.897 1 0 r
.80881 .57541 m
.85207 .58605 L
s
% Start of user PostScript
37.057061 9.04861 42.248392 10.325495 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
105.78391 25.909733 120.60514 29.542084 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
301.98975 73.985215 344.30157 84.351801 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
862.11811 211.21682 982.90967 240.81057 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
2461.1693 602.98147 2806.0043 687.46536 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
7026.1308 1721.388 8010.5636 1962.572 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
20058.154 4914.2076 22868.507 5602.7384 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
57261.893 14029.049 65284.87 15994.663 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
163470.9 40050.042 186374.84 45661.463 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
466675.69 114334.61 532061.73 130354.06 MAarrowhead1
% End of user PostScript
.617 1 0 r
.463 .47699 m
.45748 .47794 L
.45123 .47834 L
.44416 .47822 L
.43614 .4776 L
.42703 .47648 L
.41667 .47488 L
.40488 .47277 L
.39145 .47013 L
.37617 .46693 L
.35875 .46311 L
.3389 .45863 L
.31628 .4534 L
.2905 .44735 L
.26112 .44037 L
.22762 .43235 L
.18944 .42314 L
.1459 .41261 L
.09628 .40055 L
.0397 .38678 L
s
.0397 .38678 m
0 .3771 L
s
1 0 0 r
.463 .47699 m
.45748 .47794 L
s
% Start of user PostScript
-4.4396705 -2.7617881 -5.1026984 -2.646886 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45123 .47834 m
.44416 .47822 L
s
% Start of user PostScript
-5.8518334 -2.599027 -6.7002649 -2.6138305 MAarrowhead1
% End of user PostScript
1 .473 0 r
.35875 .46311 m
.3389 .45863 L
s
% Start of user PostScript
-16.950227 -4.4263994 -19.331826 -4.9645548 MAarrowhead1
% End of user PostScript
1 .788 0 r
.09628 .40055 m
.0397 .38678 L
s
% Start of user PostScript
-48.446801 -11.933618 -55.236266 -13.58638 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-138.3191 -33.902989 -157.69939 -38.648622 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-394.87567 -96.747292 -450.20188 -110.30152 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1127.2893 -276.18447 -1285.2341 -314.88048 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3218.1788 -788.44755 -3669.0785 -898.91706 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-9187.2367 -2250.8546 -10474.462 -2566.2224 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-26227.666 -6425.7256 -29902.43 -7326.0355 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-74874.577 -18344.121 -85365.271 -20914.32 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-213751.47 -52368.683 -243700.24 -59706.071 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-610216.37 -149501.79 -695713.93 -170448.52 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1742041.9 -426796.77 -1986119.8 -486595.37 MAarrowhead1
% End of user PostScript
0 .112 1 r
.49378 .52012 m
.49343 .51645 L
.49296 .51334 L
.49234 .51069 L
.49157 .50842 L
.49065 .50646 L
.48955 .50474 L
.48827 .50322 L
.48677 .50184 L
.48504 .50058 L
.48305 .49939 L
.48076 .49824 L
.47814 .49711 L
.47514 .49596 L
.4717 .49478 L
.46778 .49354 L
.4633 .4922 L
.45819 .49075 L
.45235 .48916 L
.4457 .48739 L
.43811 .48542 L
.42945 .4832 L
.41958 .4807 L
.40832 .47787 L
.39548 .47467 L
.38085 .47104 L
.36416 .46691 L
.34513 .46222 L
.32343 .45688 L
.2987 .45079 L
.2705 .44387 L
.23834 .43597 L
.20169 .42698 L
.15989 .41673 L
.11224 .40504 L
.05791 .39173 L
s
.05791 .39173 m
0 .37753 L
s
1 0 0 r
.49378 .52012 m
.49343 .51645 L
s
% Start of user PostScript
-0.74692283 2.4145726 -0.78798092 1.9741773 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49296 .51334 m
.49234 .51069 L
s
% Start of user PostScript
-0.84532712 1.6010848 -0.91949817 1.2833525 MAarrowhead1
% End of user PostScript
1 .473 0 r
.48305 .49939 m
.48076 .49824 L
s
% Start of user PostScript
-2.0339364 -0.073738566 -2.3085173 -0.21134869 MAarrowhead1
% End of user PostScript
1 .788 0 r
.45235 .48916 m
.4457 .48739 L
s
% Start of user PostScript
-5.7174078 -1.3010618 -6.5160344 -1.5132396 MAarrowhead1
% End of user PostScript
.897 1 0 r
.36416 .46691 m
.34513 .46222 L
s
% Start of user PostScript
-16.301108 -3.9703307 -18.584487 -4.533632 MAarrowhead1
% End of user PostScript
.581 1 0 r
.11224 .40504 m
.05791 .39173 L
s
% Start of user PostScript
-46.531391 -11.394601 -53.05078 -12.992749 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-132.83637 -32.543354 -151.44807 -37.103398 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-379.22017 -92.90788 -432.35279 -105.92531 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-1082.5953 -265.23361 -1234.278 -302.39558 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-3090.5863 -757.18744 -3523.6091 -863.27716 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-8822.9865 -2161.614 -10059.177 -2464.4783 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-25187.807 -6170.9622 -28716.876 -7035.5772 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-71905.993 -17616.824 -81980.759 -20085.122 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-205276.78 -50292.4 -234038.16 -57338.88 MAarrowhead1
% End of user PostScript
.119 0 1 r
.42537 .54485 m
.41646 .53221 L
.40605 .52093 L
.39396 .51069 L
.38 .50119 L
.36394 .49219 L
.3455 .48344 L
.32437 .47474 L
.3002 .46587 L
.27257 .45665 L
.24101 .44687 L
.20497 .43633 L
.16385 .42483 L
.11692 .41214 L
.0634 .39803 L
.00235 .38225 L
s
.00235 .38225 m
0 .38165 L
s
1 0 0 r
.42537 .54485 m
.41646 .53221 L
s
% Start of user PostScript
-8.9551361 5.3817434 -10.024374 3.8647189 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40605 .52093 m
.39396 .51069 L
s
% Start of user PostScript
-11.274149 2.511388 -12.724666 1.2823539 MAarrowhead1
% End of user PostScript
1 .473 0 r
.24101 .44687 m
.20497 .43633 L
s
% Start of user PostScript
-31.079157 -6.3760792 -35.40335 -7.6406377 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-88.464839 -21.382961 -100.85255 -24.466093 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-252.48788 -61.790756 -287.86234 -70.468739 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-720.7865 -176.57522 -821.77567 -201.32002 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2057.6934 -504.12701 -2345.9972 -574.76149 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5874.2896 -1439.1883 -6697.3376 -1640.8336 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-16769.885 -4108.588 -19119.517 -4684.2433 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-47874.563 -11729.172 -54582.279 -13372.549 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-136672. -33484.367 -155821.15 -38175.869 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-390170.38 -95590.962 -444837.24 -108984.23 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1113856. -272892.48 -1269918.6 -311127.51 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3179829. -779051.75 -3625355.6 -888204.87 MAarrowhead1
% End of user PostScript
.633 1 0 r
.54356 .47927 m
.54889 .48578 L
.5551 .49164 L
.56229 .49702 L
.57057 .50207 L
.58008 .50692 L
.59099 .5117 L
.60348 .51652 L
.61777 .52148 L
.63409 .5267 L
.65272 .53228 L
.67399 .53835 L
.69827 .545 L
.72596 .55238 L
.75755 .56061 L
.79357 .56985 L
.83465 .58026 L
.8815 .59202 L
.93491 .60535 L
.99582 .62047 L
s
.99582 .62047 m
1 .6215 L
s
1 0 0 r
.54356 .47927 m
.54889 .48578 L
s
% Start of user PostScript
5.227152 -2.4877109 5.867273 -1.7065837 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5551 .49164 m
.56229 .49702 L
s
% Start of user PostScript
6.6123654 -1.0031656 7.4746049 -0.35733901 MAarrowhead1
% End of user PostScript
1 .473 0 r
.65272 .53228 m
.67399 .53835 L
s
% Start of user PostScript
18.326683 3.8740641 20.879359 4.6015062 MAarrowhead1
% End of user PostScript
1 .788 0 r
.93491 .60535 m
.99582 .62047 L
s
% Start of user PostScript
52.189696 12.641746 59.498465 14.45634 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
148.96048 36.461061 169.83054 41.579809 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
425.24432 104.17603 484.82521 118.77455 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1213.9832 297.42157 1384.0746 339.09394 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3465.6712 849.08206 3951.2471 968.04727 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
9893.7763 2423.9553 11279.996 2763.5763 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
28244.691 6919.8927 32202.061 7889.4404 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
80632.767 19754.866 91930.242 22522.725 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
230189.92 56396.069 262441.88 64297.736 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
657144.74 160999.15 749217.44 183556.77 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1876012.7 459619.36 2138861.3 524016.73 MAarrowhead1
% End of user PostScript
1 0 .101 r
.50955 .52771 m
.5115 .52398 L
.51363 .521 L
.51598 .51865 L
.51858 .51684 L
.52148 .51552 L
.52474 .51462 L
.52842 .5141 L
.53257 .51394 L
.53728 .5141 L
.54263 .51459 L
.5487 .51539 L
.55561 .51651 L
.56347 .51796 L
.57243 .51975 L
.58262 .52192 L
.59424 .52449 L
.60748 .5275 L
.62257 .531 L
.63976 .53505 L
.65936 .53972 L
.68171 .54508 L
.70718 .55123 L
.73622 .55827 L
.76933 .56631 L
.80707 .57551 L
.8501 .586 L
.89916 .59798 L
.95509 .61166 L
s
.95509 .61166 m
1 .62264 L
s
1 0 0 r
.50955 .52771 m
.5115 .52398 L
s
% Start of user PostScript
1.1455366 3.3246666 1.3805613 2.877949 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51363 .521 m
.51598 .51865 L
s
% Start of user PostScript
1.6361691 2.5198207 1.9172894 2.2376485 MAarrowhead1
% End of user PostScript
1 .473 0 r
.54263 .51459 m
.5487 .51539 L
s
% Start of user PostScript
5.1154138 1.7508093 5.8443164 1.8469616 MAarrowhead1
% End of user PostScript
1 .788 0 r
.62257 .531 m
.63976 .53505 L
s
% Start of user PostScript
14.707819 3.720212 16.771396 4.2064296 MAarrowhead1
% End of user PostScript
.897 1 0 r
.8501 .586 m
.89916 .59798 L
s
% Start of user PostScript
42.012297 10.32036 47.899321 11.758125 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
119.9422 29.392039 136.74748 33.508234 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
342.41159 83.891666 390.38699 95.645293 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
977.51478 239.48952 1114.4746 273.04434 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
2790.6032 683.69227 3181.5952 779.48453 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
7966.5965 1951.8002 9082.7982 2225.2674 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
22742.99 5571.987 25929.515 6352.6794 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
64926.545 15906.874 74023.419 18135.589 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
185351.9 45410.844 211321.59 51773.367 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
529141.44 129638.59 603279.56 147802.29 MAarrowhead1
% End of user PostScript
1 .465 0 r
.47641 .41747 m
.47122 .42891 L
.46562 .43815 L
.4595 .4455 L
.45273 .45123 L
.4452 .45554 L
.43676 .45862 L
.42727 .46058 L
.41655 .46153 L
.40441 .46155 L
.39065 .46067 L
.37503 .45891 L
.35726 .4563 L
.33705 .45279 L
.31404 .44836 L
.28783 .44295 L
.25798 .43647 L
.22397 .42884 L
.18521 .41993 L
.14103 .4096 L
.09068 .39767 L
.03328 .38394 L
s
.03328 .38394 m
0 .37593 L
s
1 0 0 r
.47641 .41747 m
.47122 .42891 L
s
% Start of user PostScript
-2.8310787 -9.9040313 -3.4532306 -8.5305767 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46562 .43815 m
.4595 .4455 L
s
% Start of user PostScript
-4.1251959 -7.4221172 -4.8601427 -6.5399995 MAarrowhead1
% End of user PostScript
1 .473 0 r
.39065 .46067 m
.37503 .45891 L
s
% Start of user PostScript
-13.121494 -4.7201814 -14.996806 -4.9302242 MAarrowhead1
% End of user PostScript
1 .788 0 r
.18521 .41993 m
.14103 .4096 L
s
% Start of user PostScript
-37.774952 -9.608273 -43.076264 -10.848522 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-107.91385 -26.521677 -123.03571 -30.212753 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-308.08919 -75.500723 -351.25611 -86.073305 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-879.53518 -215.48893 -1002.7672 -245.67977 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2510.8925 -615.16471 -2862.6942 -701.35526 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7168.0804 -1756.1656 -8172.4018 -2002.2223 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-20463.391 -5013.49 -23330.522 -5715.9312 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-58418.762 -14312.48 -66603.828 -16317.804 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-166773.52 -40859.177 -190140.19 -46583.966 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-476103.99 -116644.52 -542811.03 -132987.62 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1359178.7 -332996.06 -1549613.5 -379652.21 MAarrowhead1
% End of user PostScript
1 .289 0 r
.49934 .46153 m
.49831 .46763 L
.49729 .47267 L
.49626 .47684 L
.49519 .48026 L
.49406 .48306 L
.49284 .48533 L
.49153 .48714 L
.49007 .48857 L
.48846 .48967 L
.48666 .49047 L
.48464 .49101 L
.48236 .49132 L
.47978 .49141 L
.47686 .4913 L
.47355 .49099 L
.46978 .49048 L
.46549 .48978 L
.46062 .48888 L
.45506 .48776 L
.44873 .48642 L
.44153 .48482 L
.43331 .48295 L
.42395 .48077 L
.41328 .47826 L
.40112 .47536 L
.38726 .47203 L
.37145 .46822 L
.35343 .46385 L
.33289 .45886 L
.30947 .45315 L
.28278 .44664 L
.25234 .43921 L
.21763 .43072 L
.17807 .42105 L
.13296 .41001 L
.08153 .39742 L
.0229 .38306 L
s
.0229 .38306 m
0 .37746 L
s
1 0 0 r
.49934 .46153 m
.49831 .46763 L
s
% Start of user PostScript
-0.079448626 -4.6159961 -0.20311212 -3.8847911 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49729 .47267 m
.49626 .47684 L
s
% Start of user PostScript
-0.32545909 -3.2794208 -0.44939366 -2.7796964 MAarrowhead1
% End of user PostScript
1 .473 0 r
.48666 .49047 m
.48464 .49101 L
s
% Start of user PostScript
-1.6003066 -1.1433739 -1.8429193 -1.0783462 MAarrowhead1
% End of user PostScript
1 .788 0 r
.46062 .48888 m
.45506 .48776 L
s
% Start of user PostScript
-4.7261437 -1.3343053 -5.3926436 -1.4683708 MAarrowhead1
% End of user PostScript
.897 1 0 r
.38726 .47203 m
.37145 .46822 L
s
% Start of user PostScript
-13.52917 -3.3560415 -15.42576 -3.8138398 MAarrowhead1
% End of user PostScript
.581 1 0 r
.17807 .42105 m
.13296 .41001 L
s
% Start of user PostScript
-38.63168 -9.4744104 -44.044612 -10.798956 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-110.28752 -27.022505 -125.73998 -30.80795 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-314.8486 -77.137813 -358.96212 -87.945449 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-898.82793 -220.21117 -1024.7629 -251.06497 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-2565.9684 -628.65715 -2925.4868 -716.73844 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-7325.3105 -1794.6864 -8351.6615 -2046.1403 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-20912.251 -5123.4596 -23842.271 -5841.3087 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-59700.163 -14626.42 -68064.766 -16675.731 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-170431.65 -41755.413 -194310.87 -47605.774 MAarrowhead1
% End of user PostScript
1 .968 0 r
.44652 .51671 m
.43975 .51011 L
.43192 .50407 L
.42289 .49842 L
.41251 .49301 L
.4006 .4877 L
.38697 .48236 L
.37138 .47688 L
.35357 .47112 L
.33322 .46498 L
.30999 .45832 L
.28349 .45102 L
.25326 .44294 L
.21877 .43393 L
.17943 .42382 L
.13458 .41244 L
.08343 .39958 L
.0251 .38502 L
s
.0251 .38502 m
0 .37879 L
s
1 0 0 r
.44652 .51671 m
.43975 .51011 L
s
% Start of user PostScript
-6.4181632 2.0046699 -7.229839 1.2131956 MAarrowhead1
% End of user PostScript
1 .158 0 r
.43192 .50407 m
.42289 .49842 L
s
% Start of user PostScript
-8.1697473 0.48848246 -9.2534512 -0.18954735 MAarrowhead1
% End of user PostScript
1 .473 0 r
.30999 .45832 m
.28349 .45102 L
s
% Start of user PostScript
-22.800613 -5.0014271 -25.980898 -5.8774534 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-64.9684 -15.779843 -74.067777 -18.031916 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-185.44259 -45.400827 -211.4242 -51.771611 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-529.39357 -129.6928 -603.56684 -147.86635 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1511.3079 -370.26563 -1723.0575 -422.14416 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4314.4719 -1057.0366 -4918.9735 -1205.1383 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-12316.927 -3017.6224 -14042.655 -3440.4222 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-35162.287 -8614.69 -40088.883 -9821.6961 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-100381.08 -24593.163 -114445.49 -28038.917 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-286567.27 -70208.408 -326718.28 -80045.325 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-818090.46 -200430.53 -932713.3 -228512.89 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2335479.5 -572187.81 -2662704.1 -652357.18 MAarrowhead1
% End of user PostScript
.176 0 1 r
.42875 .4678 m
.41841 .46771 L
.40668 .46687 L
.39335 .46531 L
.3782 .46302 L
.36096 .45998 L
.34133 .45615 L
.31898 .4515 L
.29352 .44595 L
.2645 .43942 L
.23143 .43179 L
.19375 .42296 L
.15079 .41277 L
.10182 .40105 L
.046 .3876 L
s
.046 .3876 m
0 .37647 L
s
1 0 0 r
.42875 .4678 m
.41841 .46771 L
s
% Start of user PostScript
-8.5494581 -3.8635929 -9.790633 -3.8746112 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40668 .46687 m
.39335 .46531 L
s
% Start of user PostScript
-11.198534 -3.9750292 -12.797711 -4.1628178 MAarrowhead1
% End of user PostScript
1 .473 0 r
.23143 .43179 m
.19375 .42296 L
s
% Start of user PostScript
-32.227815 -8.1848917 -36.75034 -9.2449995 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-92.064417 -22.62349 -104.96525 -25.77292 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-262.83917 -64.411011 -299.66601 -73.430873 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-750.35495 -183.8392 -855.48745 -209.59583 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2142.1094 -524.8134 -2442.2409 -598.34486 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6115.2807 -1498.2317 -6972.0941 -1708.1493 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-17457.865 -4277.1421 -19903.891 -4876.4134 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-49838.605 -12210.358 -56821.503 -13921.155 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-142278.94 -34858.055 -162213.67 -39742.025 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-406177.02 -99512.557 -463086.58 -113455.28 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1159551.6 -284087.83 -1322016.7 -323891.44 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3310280.7 -811012.15 -3774084.9 -924643.25 MAarrowhead1
% End of user PostScript
0 1 .189 r
.50145 .51141 m
.50192 .5097 L
.50242 .50829 L
.50294 .50714 L
.50351 .50622 L
.50414 .50548 L
.50483 .50491 L
.50559 .50448 L
.50645 .50418 L
.50742 .50398 L
.50851 .50389 L
.50975 .5039 L
.51115 .50399 L
.51275 .50417 L
.51456 .50444 L
.51662 .5048 L
.51897 .50526 L
.52164 .50581 L
.52468 .50647 L
.52815 .50725 L
.5321 .50816 L
.53661 .50922 L
.54175 .51043 L
.5476 .51183 L
.55427 .51344 L
.56188 .51528 L
.57055 .51739 L
.58044 .51979 L
.59171 .52254 L
.60457 .52568 L
.61922 .52926 L
.63592 .53334 L
.65497 .538 L
.67668 .54331 L
.70144 .54938 L
.72966 .55629 L
.76184 .56417 L
.79853 .57315 L
.84036 .5834 L
.88804 .59508 L
.94241 .6084 L
s
.94241 .6084 m
1 .62251 L
s
1 0 0 r
.50145 .51141 m
.50192 .5097 L
s
% Start of user PostScript
0.17373191 1.3696687 0.23056361 1.1637324 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50242 .50829 m
.50294 .50714 L
s
% Start of user PostScript
0.28997541 0.99485212 0.35322055 0.85730068 MAarrowhead1
% End of user PostScript
1 .473 0 r
.50851 .50389 m
.50975 .5039 L
s
% Start of user PostScript
1.0216046 0.46720604 1.1700523 0.46763938 MAarrowhead1
% End of user PostScript
1 .788 0 r
.52468 .50647 m
.52815 .50725 L
s
% Start of user PostScript
2.9619719 0.77660992 3.3782214 0.87015224 MAarrowhead1
% End of user PostScript
.897 1 0 r
.57055 .51739 m
.58044 .51979 L
s
% Start of user PostScript
8.4665029 2.0862355 9.6530393 2.3749533 MAarrowhead1
% End of user PostScript
.581 1 0 r
.70144 .54938 m
.72966 .55629 L
s
% Start of user PostScript
24.172628 5.9250536 27.559529 6.7543724 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
69.008457 16.907593 78.677264 19.276322 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
197.00505 48.265998 224.60748 55.028511 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
562.40882 137.78907 641.20805 157.09472 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
1605.5612 393.35929 1830.5167 448.47294 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
4583.546 1122.9596 5225.7477 1280.2977 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
13085.079 3205.8181 14918.432 3654.986 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
37355.201 9151.9494 42589.046 10434.231 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
106641.39 26126.928 121582.94 29787.578 MAarrowhead1
% End of user PostScript
0 1 .033 r
.55182 .53236 m
.55957 .531 L
.56831 .53042 L
.57822 .53058 L
.58946 .53145 L
.60223 .533 L
.61674 .53523 L
.63326 .53818 L
.65207 .54187 L
.67349 .54636 L
.69789 .5517 L
.7257 .55798 L
.75738 .5653 L
.7935 .57377 L
.83467 .58355 L
.8816 .59479 L
.9351 .60768 L
.99608 .62244 L
s
.99608 .62244 m
1 .6234 L
s
1 0 0 r
.55182 .53236 m
.55957 .531 L
s
% Start of user PostScript
6.2188047 3.8832474 7.1478917 3.7199508 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56831 .53042 m
.57822 .53058 L
s
% Start of user PostScript
8.1975828 3.6509654 9.3863613 3.6700903 MAarrowhead1
% End of user PostScript
1 .473 0 r
.69789 .5517 m
.7257 .55798 L
s
% Start of user PostScript
23.746966 6.2036438 27.083601 6.9572168 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
67.873594 16.719455 77.385596 19.034874 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
193.78411 47.497983 220.93576 54.146561 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
553.21812 135.54233 630.72976 154.53169 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1579.3247 386.93256 1800.6043 441.14542 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4508.6465 1104.6096 5140.354 1259.3767 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
12871.256 3153.432 14674.65 3595.2601 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
36744.781 9002.3978 41893.101 10263.726 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
104898.77 25699.989 119596.16 29300.82 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
299464.36 73368.168 341422.38 83647.799 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
854908.97 209450.99 974690.46 238797.21 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2440588.8 597939.37 2782540.2 681716.79 MAarrowhead1
% End of user PostScript
1 .045 0 r
.56466 .46175 m
.57239 .47261 L
.58143 .4823 L
.59192 .49111 L
.60402 .49928 L
.61796 .50703 L
.63395 .51457 L
.65227 .52208 L
.67323 .52974 L
.69719 .53772 L
.72456 .54618 L
.75581 .5553 L
.79147 .56526 L
.83216 .57624 L
.87857 .58847 L
.93151 .60214 L
.99188 .61753 L
s
.99188 .61753 m
1 .61958 L
s
1 0 0 r
.56466 .46175 m
.57239 .47261 L
s
% Start of user PostScript
7.7586616 -4.5896772 8.6868287 -3.2869985 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58143 .4823 m
.59192 .49111 L
s
% Start of user PostScript
9.7713664 -2.1241498 11.029823 -1.0673194 MAarrowhead1
% End of user PostScript
1 .473 0 r
.72456 .54618 m
.75581 .5553 L
s
% Start of user PostScript
26.947485 5.5412035 30.697131 6.6356134 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
76.706974 18.543956 87.448307 21.216829 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
218.93034 53.579005 249.60328 61.103505 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
624.98869 153.10724 712.55566 174.56325 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1784.2109 437.12488 2034.197 498.37151 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5093.5535 1247.9097 5807.2124 1422.7548 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
14541.045 3562.5266 16578.394 4061.6731 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
41511.683 10170.279 47327.895 11595.239 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
118507.29 29034.05 135111.38 33102.017 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
338313.88 82886.224 385715.12 94499.432 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
965816.36 236623.07 1101137.1 269776.39 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2757206.5 675510.07 3143519.3 770155.95 MAarrowhead1
% End of user PostScript
.696 0 1 r
.5457 .48453 m
.55146 .49036 L
.55812 .49568 L
.56581 .50063 L
.57465 .50537 L
.58479 .50999 L
.59641 .51462 L
.6097 .51937 L
.62488 .52433 L
.64223 .52962 L
.66203 .53534 L
.68462 .5416 L
.7104 .54851 L
.7398 .55622 L
.77334 .56486 L
.81159 .57458 L
.8552 .58555 L
.90493 .59798 L
.96164 .61208 L
s
.96164 .61208 m
1 .62158 L
s
1 0 0 r
.5457 .48453 m
.55146 .49036 L
s
% Start of user PostScript
5.4845344 -1.8564685 6.1746275 -1.1572287 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55812 .49568 m
.56581 .50063 L
s
% Start of user PostScript
6.9743893 -0.5189527 7.897035 0.076148326 MAarrowhead1
% End of user PostScript
1 .473 0 r
.66203 .53534 m
.68462 .5416 L
s
% Start of user PostScript
19.443153 4.2404666 22.154531 4.9914049 MAarrowhead1
% End of user PostScript
1 .788 0 r
.96164 .61208 m
0 0 rlineto s
.96164 .61208 m
1 .62158 L
s
% Start of user PostScript
55.396468 13.449205 63.155073 15.370395 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
158.11973 38.710178 180.27321 44.142516 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
451.39316 110.58365 514.6378 126.07958 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1288.633 315.71091 1469.1836 359.94571 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3678.781 901.29361 4194.2158 1027.5742 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
10502.161 2573.0083 11973.621 2933.5131 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
29981.503 7345.4083 34182.219 8374.5751 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
85591.008 20969.626 97583.184 23907.685 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
244344.68 59863.957 278579.86 68251.509 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
697553.66 170899.25 795288.06 194843.98 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1991371.8 487882.11 2270383.4 556239.38 MAarrowhead1
% End of user PostScript
1 0 .287 r
.46645 .54248 m
.46299 .53323 L
.45884 .52521 L
.45394 .51816 L
.44821 .51188 L
.44155 .50618 L
.43386 .5009 L
.42502 .4959 L
.41486 .49105 L
.40322 .48622 L
.3899 .48131 L
.37468 .47621 L
.35729 .47081 L
.33744 .46499 L
.31478 .45864 L
.28893 .45164 L
.25944 .44386 L
.2258 .43515 L
.18744 .42537 L
.14369 .41433 L
.09381 .40184 L
.03693 .38768 L
s
.03693 .38768 m
0 .37852 L
s
1 0 0 r
.46645 .54248 m
.46299 .53323 L
s
% Start of user PostScript
-4.0259252 5.0977165 -4.441049 3.9880725 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45884 .52521 m
.45394 .51816 L
s
% Start of user PostScript
-4.9390122 3.0251172 -5.5273333 2.1793445 MAarrowhead1
% End of user PostScript
1 .473 0 r
.3899 .48131 m
.37468 .47621 L
s
% Start of user PostScript
-13.211463 -2.2423438 -15.038179 -2.8546329 MAarrowhead1
% End of user PostScript
1 .788 0 r
.18744 .42537 m
.14369 .41433 L
s
% Start of user PostScript
-37.507402 -8.9557393 -42.756857 -10.280529 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-107.02692 -26.166554 -122.02114 -29.849192 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-305.52827 -74.840942 -348.3356 -85.330783 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-872.21751 -213.68852 -994.42403 -243.62937 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2490.0005 -610.04442 -2838.875 -695.5181 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7108.4376 -1741.5528 -8104.4024 -1985.5622 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-20293.123 -4971.7745 -23136.397 -5668.371 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-57932.681 -14193.391 -66049.643 -16182.03 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-165385.86 -40519.204 -188558.11 -46196.359 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-472142.51 -115673.97 -538294.51 -131881.08 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1347869.5 -330225.33 -1536719.8 -376493.27 MAarrowhead1
% End of user PostScript
1 0 .051 r
.50084 .56619 m
.50257 .55568 L
.50428 .54698 L
.506 .53979 L
.50778 .53388 L
.50966 .52904 L
.51166 .52512 L
.51384 .52196 L
.51624 .51947 L
.51889 .51756 L
.52185 .51614 L
.52518 .51517 L
.52893 .5146 L
.53317 .51439 L
.53797 .51453 L
.54341 .515 L
.5496 .51579 L
.55664 .51691 L
.56465 .51837 L
.57377 .52019 L
.58416 .52238 L
.59599 .52499 L
.60948 .52805 L
.62485 .53161 L
.64237 .53573 L
.66234 .54048 L
.6851 .54594 L
.71105 .5522 L
.74063 .55937 L
.77435 .56756 L
.8128 .57692 L
.85663 .58761 L
.90661 .59982 L
.96358 .61374 L
s
.96358 .61374 m
1 .62265 L
s
1 0 0 r
.50084 .56619 m
.50257 .55568 L
s
% Start of user PostScript
0.10067271 7.9429232 0.30863218 6.6820637 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50428 .54698 m
.506 .53979 L
s
% Start of user PostScript
0.5136133 5.6378004 0.72051931 4.7753306 MAarrowhead1
% End of user PostScript
1 .473 0 r
.52185 .51614 m
.52518 .51517 L
s
% Start of user PostScript
2.6224885 1.936742 3.0216114 1.8201114 MAarrowhead1
% End of user PostScript
1 .788 0 r
.56465 .51837 m
.57377 .52019 L
s
% Start of user PostScript
7.7581521 2.2046253 8.8525885 2.4224143 MAarrowhead1
% End of user PostScript
.897 1 0 r
.6851 .54594 m
.71105 .5522 L
s
% Start of user PostScript
22.211671 5.5131707 25.3255 6.2642312 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
63.424708 15.555681 72.311568 17.730168 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
181.06797 44.365225 206.43755 50.580068 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
516.91255 126.64346 589.3373 144.38723 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
1475.6789 361.53859 1682.4366 412.19378 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
4212.7589 1032.1176 4803.0096 1176.7278 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
12026.558 2946.4826 13711.602 3359.315 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
34333.342 8411.6002 39143.795 9590.1514 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
98014.612 24013.384 111747.46 27377.904 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
279811.5 68553.258 319015.95 78158.27 MAarrowhead1
% End of user PostScript
.552 0 1 r
.51618 .52153 m
.51888 .51928 L
.52188 .51759 L
.52525 .51639 L
.52904 .51563 L
.53331 .51526 L
.53815 .51527 L
.54364 .51564 L
.54988 .51635 L
.55697 .5174 L
.56504 .5188 L
.57422 .52058 L
.58467 .52274 L
.59659 .52533 L
.61016 .52838 L
.62563 .53194 L
.64326 .53607 L
.66336 .54083 L
.68626 .54631 L
.71238 .55259 L
.74215 .5598 L
.77609 .56803 L
.81478 .57745 L
.85889 .5882 L
.90918 .60048 L
.96652 .61449 L
s
.96652 .61449 m
1 .62267 L
s
1 0 0 r
.51618 .52153 m
.51888 .51928 L
s
% Start of user PostScript
1.9417693 2.5836796 2.2654378 2.313756 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52188 .51759 m
.52525 .51639 L
s
% Start of user PostScript
2.6259058 2.1107034 3.0297459 1.9665472 MAarrowhead1
% End of user PostScript
1 .473 0 r
.56504 .5188 m
.57422 .52058 L
s
% Start of user PostScript
7.8042235 2.2565631 8.9061102 2.4694429 MAarrowhead1
% End of user PostScript
1 .788 0 r
.68626 .54631 m
.71238 .55259 L
s
% Start of user PostScript
22.351722 5.5570279 25.485408 6.3113719 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
63.826528 15.656367 72.769743 17.84429 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
182.21556 44.646907 207.74593 50.901059 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
520.18877 127.44626 593.07257 145.30247 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1485.0319 363.83008 1693.1 414.80633 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
4239.4598 1038.6592 4833.4515 1184.186 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
12102.783 2965.1577 13798.507 3380.6066 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
34550.95 8464.9136 39391.892 9650.9346 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
98635.837 24165.583 112455.73 27551.428 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
281584.97 68987.754 321037.9 78653.644 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
803867.01 196945.81 916497.01 224539.93 MAarrowhead1
% End of user PostScript
1 .746 0 r
.57313 .51716 m
.58335 .51979 L
.59502 .52275 L
.60832 .5261 L
.62348 .52989 L
.64077 .53418 L
.66049 .53906 L
.68297 .54461 L
.7086 .55093 L
.73782 .55812 L
.77114 .56631 L
.80913 .57563 L
.85243 .58626 L
.90181 .59837 L
.95811 .61218 L
s
.95811 .61218 m
1 .62245 L
s
1 0 0 r
.57313 .51716 m
.58335 .51979 L
s
% Start of user PostScript
8.7750148 2.0593373 10.002268 2.3750088 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59502 .52275 m
.60832 .5261 L
s
% Start of user PostScript
11.401839 2.7304134 12.99781 3.1318627 MAarrowhead1
% End of user PostScript
1 .473 0 r
.77114 .56631 m
.80913 .57563 L
s
% Start of user PostScript
32.53668 7.9566254 37.09504 9.0758656 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
92.882407 22.75253 105.8961 25.941433 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
265.15939 64.962704 302.31091 74.064887 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
756.97519 185.45722 863.03516 211.44173 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2161.008 529.44259 2463.7873 603.62293 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6169.2322 1511.4495 7033.6047 1723.2191 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
17611.885 4314.8767 20079.491 4919.435 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
50278.3 12318.083 57322.805 14043.972 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
143534.18 35165.586 163644.78 40092.645 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
409760.47 100390.5 467172.11 114456.23 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1169781.6 286594.16 1333680. 326748.93 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3339485.3 818167.22 3807381.4 932800.82 MAarrowhead1
% End of user PostScript
.18 0 1 r
.55344 .51591 m
.561 .51729 L
.5696 .51901 L
.5794 .52109 L
.59057 .52355 L
.60329 .52644 L
.61779 .52981 L
.63431 .5337 L
.65315 .53818 L
.67463 .54333 L
.69911 .54924 L
.72702 .556 L
.75883 .56373 L
.79511 .57257 L
.83646 .58265 L
.88361 .59417 L
.93736 .60731 L
.99864 .6223 L
s
.99864 .6223 m
1 .62263 L
s
1 0 0 r
.55344 .51591 m
.561 .51729 L
s
% Start of user PostScript
6.4129155 1.9087012 7.3196944 2.0749387 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5696 .51901 m
.5794 .52109 L
s
% Start of user PostScript
8.3521533 2.281232 9.5281279 2.530416 MAarrowhead1
% End of user PostScript
1 .473 0 r
.69911 .54924 m
.72702 .556 L
s
% Start of user PostScript
23.892964 5.9089008 27.241964 6.7202586 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
68.221058 16.726977 77.779843 19.066714 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
194.75977 47.718795 222.04768 54.403775 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
555.99961 136.2195 633.90086 155.30504 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1587.2644 388.87676 1809.6563 443.36232 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4531.3124 1110.1625 5166.1956 1265.7076 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
12935.962 3169.2849 14748.423 3613.3341 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
36929.504 9047.6547 42103.706 10315.324 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
105426.12 25829.188 120197.4 29448.121 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
300969.82 73737.005 343138.78 84068.313 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
859206.77 210503.94 979590.43 239997.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2452858.1 600945.33 2796528.6 685143.92 MAarrowhead1
% End of user PostScript
.974 0 1 r
.51275 .42294 m
.51257 .43618 L
.5127 .44729 L
.51311 .45664 L
.51381 .46453 L
.51479 .4712 L
.51607 .47689 L
.51766 .48176 L
.51958 .48597 L
.52186 .48965 L
.52454 .49291 L
.52766 .49584 L
.53126 .49854 L
.53542 .50107 L
.5402 .5035 L
.54567 .50589 L
.55194 .5083 L
.55911 .51079 L
.5673 .51341 L
.57666 .51621 L
.58733 .51925 L
.59952 .52259 L
.61342 .5263 L
.62927 .53043 L
.64735 .53506 L
.66797 .54029 L
.69149 .54619 L
.7183 .55288 L
.74887 .56047 L
.78373 .56909 L
.82347 .5789 L
.86878 .59006 L
.92045 .60276 L
.97935 .61724 L
s
.97935 .61724 m
1 .62231 L
s
1 0 0 r
.51275 .42294 m
.51257 .43618 L
s
% Start of user PostScript
1.5299905 -9.2475968 1.508782 -7.6586536 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5127 .44729 m
.51311 .45664 L
s
% Start of user PostScript
1.5236295 -6.324976 1.5731192 -5.2031574 MAarrowhead1
% End of user PostScript
1 .473 0 r
.52454 .49291 m
.52766 .49584 L
s
% Start of user PostScript
2.9445738 -0.85137124 3.3186338 -0.49916556 MAarrowhead1
% End of user PostScript
1 .788 0 r
.5673 .51341 m
.57666 .51621 L
s
% Start of user PostScript
8.0762322 1.6093626 9.1987539 1.9455594 MAarrowhead1
% End of user PostScript
.897 1 0 r
.69149 .54619 m
.7183 .55288 L
s
% Start of user PostScript
22.978511 5.5429761 26.195912 6.3455987 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
65.58072 16.046784 74.768751 18.301207 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
187.21516 45.862558 213.4458 52.289805 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
534.45966 130.94042 609.3429 149.28685 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
1525.7719 373.81079 1739.5481 426.18558 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
4355.7639 1067.1534 4966.051 1216.6725 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
12434.808 3046.503 14177.051 3473.3492 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
35498.811 8697.1376 40472.558 9915.6956 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
101341.78 24828.534 115540.8 28307.266 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
289309.89 70880.344 329845.17 80811.406 MAarrowhead1
% End of user PostScript
1 0 .477 r
.4716 .57804 m
.4697 .56349 L
.46719 .55113 L
.46404 .54056 L
.46021 .53144 L
.45565 .5235 L
.45028 .51649 L
.44401 .5102 L
.43675 .50446 L
.42838 .4991 L
.41875 .49399 L
.40771 .48898 L
.39506 .48396 L
.38059 .47881 L
.36406 .47343 L
.34518 .46769 L
.32363 .46147 L
.29903 .45467 L
.27097 .44715 L
.23896 .43877 L
.20245 .42937 L
.16081 .41879 L
.11334 .40685 L
.0592 .39332 L
s
.0592 .39332 m
0 .37861 L
s
1 0 0 r
.4716 .57804 m
.4697 .56349 L
s
% Start of user PostScript
-3.4081049 9.3649988 -3.6359002 7.6193704 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46719 .55113 m
.46404 .54056 L
s
% Start of user PostScript
-3.936982 6.1357373 -4.3147646 4.8668841 MAarrowhead1
% End of user PostScript
1 .473 0 r
.41875 .49399 m
.40771 .48898 L
s
% Start of user PostScript
-9.7498651 -0.72151334 -11.075105 -1.322395 MAarrowhead1
% End of user PostScript
1 .788 0 r
.27097 .44715 m
.23896 .43877 L
s
% Start of user PostScript
-27.484134 -6.3420945 -31.325358 -7.3480401 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-78.379418 -19.110883 -89.358925 -21.816068 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-223.73779 -54.793728 -255.08521 -62.47736 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-638.72072 -156.48023 -728.2119 -178.40623 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1823.4149 -446.7318 -2078.8939 -509.32385 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-5205.4731 -1275.3302 -5934.8131 -1454.0171 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-14860.552 -3640.8054 -16942.667 -4150.9195 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-42423.811 -10393.749 -48367.821 -11850.019 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-121111.23 -29672.009 -138080.15 -33829.361 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-345747.58 -84707.466 -394190.36 -96575.848 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-987038.04 -241822.34 -1125332.2 -275704.13 MAarrowhead1
% End of user PostScript
1 0 .611 r
.53974 .48122 m
.5446 .48714 L
.55027 .49247 L
.55683 .49736 L
.56439 .50196 L
.57307 .50638 L
.58303 .51072 L
.59442 .51511 L
.60746 .51963 L
.62235 .52439 L
.63935 .52948 L
.65876 .53501 L
.68091 .54108 L
.70618 .54781 L
.735 .55532 L
.76787 .56374 L
.80536 .57324 L
.84811 .58397 L
.89685 .59613 L
.95242 .60993 L
s
.95242 .60993 m
1 .6217 L
s
1 0 0 r
.53974 .48122 m
.5446 .48714 L
s
% Start of user PostScript
4.7682628 -2.2531597 5.3525834 -1.543187 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55027 .49247 m
.55683 .49736 L
s
% Start of user PostScript
6.0326499 -0.90366039 6.8195786 -0.31629952 MAarrowhead1
% End of user PostScript
1 .473 0 r
.63935 .52948 m
.65876 .53501 L
s
% Start of user PostScript
16.72238 3.5377268 19.051666 4.201043 MAarrowhead1
% End of user PostScript
1 .788 0 r
.89685 .59613 m
.95242 .60993 L
s
% Start of user PostScript
47.62164 11.535898 54.290705 13.191559 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
135.92242 33.269888 154.96578 37.940583 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
388.024 95.057864 442.38996 108.37861 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1107.727 271.38919 1262.9308 309.4141 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3162.3317 774.76454 3605.4067 883.31709 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
9027.8047 2211.794 10292.692 2521.689 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
25772.52 6314.2159 29383.514 7198.9021 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
73575.23 18025.784 83883.872 20551.381 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
210042.11 51459.896 239471.16 58669.954 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
599626.9 146907.39 683640.76 167490.62 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1711811.1 419390.3 1951653.4 478151.17 MAarrowhead1
% End of user PostScript
.336 1 0 r
.47987 .53367 m
.478 .52682 L
.47571 .52092 L
.47296 .5158 L
.46972 .51129 L
.46594 .50726 L
.46154 .5036 L
.45648 .5002 L
.45064 .49697 L
.44395 .49383 L
.43628 .4907 L
.42751 .4875 L
.41748 .48418 L
.40603 .48064 L
.39295 .47683 L
.37803 .47267 L
.361 .46807 L
.34157 .46296 L
.31942 .45724 L
.29416 .4508 L
.26535 .44354 L
.23249 .43532 L
.19503 .426 L
.15232 .41542 L
.10362 .40339 L
.0481 .3897 L
s
.0481 .3897 m
0 .37787 L
s
1 0 0 r
.47987 .53367 m
.478 .52682 L
s
% Start of user PostScript
-2.4150703 4.0406541 -2.6400377 3.2181026 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47571 .52092 m
.47296 .5158 L
s
% Start of user PostScript
-2.9153137 2.5103658 -3.2448342 1.895416 MAarrowhead1
% End of user PostScript
1 .473 0 r
.43628 .4907 m
.42751 .4875 L
s
% Start of user PostScript
-7.6462022 -1.116149 -8.6989767 -1.4995137 MAarrowhead1
% End of user PostScript
1 .788 0 r
.31942 .45724 m
.29416 .4508 L
s
% Start of user PostScript
-21.669504 -5.1312012 -24.701271 -5.9034313 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-61.824671 -15.105176 -70.485918 -17.23408 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-176.48793 -43.229388 -201.21545 -49.289205 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-503.83458 -123.43616 -574.4269 -140.73152 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1438.3433 -352.3907 -1639.8699 -401.7644 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-4106.1734 -1006.0041 -4681.4903 -1146.9557 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-11722.278 -2871.9347 -13364.689 -3274.3221 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-33464.687 -8198.7813 -38153.432 -9347.5144 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-95534.779 -23405.83 -108920.18 -26685.226 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-272732.09 -66818.816 -310944.65 -76180.816 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-778593.87 -190753.94 -887682.83 -217480.52 MAarrowhead1
% End of user PostScript
1 0 .857 r
.57721 .5355 m
.58844 .5355 L
.60117 .53633 L
.61563 .53796 L
.63206 .54039 L
.65076 .54364 L
.67205 .54775 L
.69629 .55276 L
.72391 .55875 L
.75538 .56582 L
.79124 .57406 L
.83211 .58363 L
.8787 .59467 L
.9318 .60737 L
.99234 .62194 L
s
.99234 .62194 m
1 .62379 L
s
1 0 0 r
.57721 .5355 m
.58844 .5355 L
s
% Start of user PostScript
9.2657297 4.2602841 10.612677 4.2605695 MAarrowhead1
% End of user PostScript
1 .158 0 r
.60117 .53633 m
.61563 .53796 L
s
% Start of user PostScript
12.140274 4.3597369 13.875167 4.5552656 MAarrowhead1
% End of user PostScript
1 .473 0 r
.79124 .57406 m
.83211 .58363 L
s
% Start of user PostScript
34.948587 8.8876315 39.853206 10.035362 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
99.839245 24.536797 113.82961 27.951755 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
285.03648 69.851301 324.97344 79.632806 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
813.72411 199.36499 927.73529 227.2968 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2323.0154 569.13511 2648.4936 648.87647 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6631.73 1624.7608 7560.9033 1852.4064 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
18932.222 4638.3564 21584.819 5288.2376 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
54047.588 13241.551 61620.208 15096.828 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
154294.72 37801.897 175912.98 43098.329 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
440479.59 107916.62 502195.29 123036.84 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1257478.4 308079.69 1433664. 351244.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3589841.4 879503.97 4092814.9 1002731.5 MAarrowhead1
% End of user PostScript
1 0 .181 r
.48513 .49739 m
.48307 .49672 L
.48072 .496 L
.47804 .49522 L
.47497 .49437 L
.47148 .49343 L
.46749 .49239 L
.46295 .49121 L
.45776 .4899 L
.45185 .48841 L
.44511 .48672 L
.43742 .48481 L
.42866 .48264 L
.41867 .48017 L
.40727 .47736 L
.39428 .47417 L
.37947 .47053 L
.36259 .46638 L
.34333 .46166 L
.32138 .45627 L
.29636 .45014 L
.26783 .44314 L
.2353 .43517 L
.19821 .42608 L
.15593 .41572 L
.10772 .4039 L
.05276 .39044 L
s
.05276 .39044 m
0 .37751 L
s
1 0 0 r
.48513 .49739 m
.48307 .49672 L
s
% Start of user PostScript
-1.7845868 -0.31260627 -2.0315749 -0.39376251 MAarrowhead1
% End of user PostScript
1 .158 0 r
.48072 .496 m
.47804 .49522 L
s
% Start of user PostScript
-2.3136739 -0.48010068 -2.6357196 -0.57337215 MAarrowhead1
% End of user PostScript
1 .473 0 r
.44511 .48672 m
.43742 .48481 L
s
% Start of user PostScript
-6.5868656 -1.5934008 -7.5092542 -1.8227585 MAarrowhead1
% End of user PostScript
1 .788 0 r
.34333 .46166 m
.32138 .45627 L
s
% Start of user PostScript
-18.79987 -4.601148 -21.433807 -5.2472497 MAarrowhead1
% End of user PostScript
.897 1 0 r
.05276 .39044 m
0 0 rlineto s
.05276 .39044 m
0 .37751 L
s
% Start of user PostScript
-53.668749 -13.147613 -61.188262 -14.990065 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-153.21297 -37.536608 -174.67967 -42.79595 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-437.39138 -107.15995 -498.67439 -122.17418 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1248.6622 -305.91972 -1423.6125 -348.78221 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-3564.673 -873.33774 -4064.1201 -995.70129 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-10176.406 -2493.1991 -11602.225 -2842.5218 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-29051.541 -7117.5693 -33121.959 -8114.8136 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-82936.157 -20319.192 -94556.361 -23166.119 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-236765.62 -58007.104 -269938.91 -66134.492 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-675917.02 -165598.32 -770619.91 -188800.34 MAarrowhead1
% End of user PostScript
.517 0 1 r
.53847 .49833 m
.54359 .50142 L
.54947 .50439 L
.55621 .50733 L
.56393 .51028 L
.57275 .51334 L
.58283 .51655 L
.59435 .51999 L
.60749 .52373 L
.62249 .52784 L
.6396 .53239 L
.65911 .53747 L
.68137 .54317 L
.70675 .5496 L
.73569 .55686 L
.76869 .56509 L
.80632 .57443 L
.84922 .58505 L
.89813 .59712 L
.95391 .61085 L
s
.95391 .61085 m
1 .62219 L
s
1 0 0 r
.53847 .49833 m
.54359 .50142 L
s
% Start of user PostScript
4.6161383 -0.20060834 5.2303075 0.1704588 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54947 .50439 m
.55621 .50733 L
s
% Start of user PostScript
5.9359287 0.52738546 6.7449206 0.87914622 MAarrowhead1
% End of user PostScript
1 .473 0 r
.6396 .53239 m
.65911 .53747 L
s
% Start of user PostScript
16.751418 3.8864219 19.093135 4.4961943 MAarrowhead1
% End of user PostScript
1 .788 0 r
.89813 .59712 m
.95391 .61085 L
s
% Start of user PostScript
47.77619 11.653967 54.468872 13.302127 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
136.38045 33.400937 155.48845 38.084348 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
389.33553 95.383609 443.88536 108.74867 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1111.4721 272.30777 1267.2006 310.46107 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3173.0234 777.38422 3617.5964 886.30374 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
9058.3272 2219.272 10327.492 2530.2147 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
25859.656 6335.5639 29482.858 7223.2413 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
73823.984 18086.728 84167.48 20620.864 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
210752.25 51633.879 240280.79 58868.314 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
601654.2 147404.08 685952.11 168056.89 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1717598.7 420808.23 1958251.8 479767.77 MAarrowhead1
% End of user PostScript
0 1 .577 r
.4664 .56238 m
.46342 .54995 L
.45974 .53929 L
.4553 .53006 L
.45004 .52198 L
.44388 .5148 L
.43671 .50831 L
.42843 .50234 L
.41888 .49671 L
.40793 .49128 L
.39536 .48591 L
.38099 .48047 L
.36455 .47485 L
.34576 .46892 L
.32432 .46255 L
.29984 .45563 L
.27191 .44801 L
.24005 .43956 L
.20371 .43012 L
.16226 .41951 L
.11499 .40756 L
.06109 .39404 L
s
.06109 .39404 m
0 .37882 L
s
1 0 0 r
.4664 .56238 m
.46342 .54995 L
s
% Start of user PostScript
-4.0323055 7.4859631 -4.3898161 5.994517 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45974 .53929 m
.4553 .53006 L
s
% Start of user PostScript
-4.8317867 4.7149538 -5.3643572 3.6072387 MAarrowhead1
% End of user PostScript
1 .473 0 r
.39536 .48591 m
.38099 .48047 L
s
% Start of user PostScript
-12.556395 -1.6912396 -14.281766 -2.343412 MAarrowhead1
% End of user PostScript
1 .788 0 r
.20371 .43012 m
.16226 .41951 L
s
% Start of user PostScript
-35.555381 -8.3857799 -40.529092 -9.6582075 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-101.43506 -24.775024 -115.64528 -28.26915 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-289.56016 -70.923729 -330.13006 -80.866244 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-826.63077 -202.51867 -942.45009 -230.89487 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2359.8595 -578.15986 -2690.4999 -659.16626 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6736.9118 -1650.5297 -7680.8221 -1881.7858 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-19232.494 -4711.9224 -21927.163 -5372.111 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-54904.803 -13451.567 -62597.528 -15336.269 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-156741.89 -38401.449 -178703.03 -43781.885 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-447465.77 -109628.22 -510160.3 -124988.25 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1277422.5 -312965.95 -1456402.4 -356815.68 MAarrowhead1
% End of user PostScript
0 1 .17 r
.48895 .5343 m
.48831 .52801 L
.48743 .52268 L
.4863 .51814 L
.48491 .51424 L
.48323 .51085 L
.48125 .50789 L
.47892 .50525 L
.47623 .50287 L
.47311 .50066 L
.46952 .49858 L
.46539 .49657 L
.46067 .49458 L
.45526 .49255 L
.44908 .49046 L
.44202 .48824 L
.43395 .48586 L
.42475 .48327 L
.41425 .48041 L
.40227 .47724 L
.3886 .4737 L
.37302 .46972 L
.35525 .46522 L
.33498 .46015 L
.31188 .45439 L
.28553 .44786 L
.25549 .44043 L
.22124 .43198 L
.18219 .42237 L
.13767 .41142 L
.08691 .39896 L
.02904 .38475 L
s
.02904 .38475 m
0 .37763 L
s
1 0 0 r
.48895 .5343 m
.48831 .52801 L
s
% Start of user PostScript
-1.3256579 4.1164142 -1.4026671 3.3617787 MAarrowhead1
% End of user PostScript
1 .158 0 r
.48743 .52268 m
.4863 .51814 L
s
% Start of user PostScript
-1.5084791 2.7219806 -1.6441452 2.1765682 MAarrowhead1
% End of user PostScript
1 .473 0 r
.46952 .49858 m
.46539 .49657 L
s
% Start of user PostScript
-3.6578905 -0.17026308 -4.1526267 -0.41173361 MAarrowhead1
% End of user PostScript
1 .788 0 r
.41425 .48041 m
.40227 .47724 L
s
% Start of user PostScript
-10.290251 -2.3506428 -11.727847 -2.731089 MAarrowhead1
% End of user PostScript
.897 1 0 r
.25549 .44043 m
.22124 .43198 L
s
% Start of user PostScript
-29.340789 -7.1484124 -33.450753 -8.161976 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-83.753505 -20.510044 -95.487997 -23.386528 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-239.09701 -58.576082 -272.59689 -66.783852 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-682.57219 -167.2283 -778.20752 -190.65885 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-1948.6027 -477.40364 -2221.6219 -544.29281 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-5562.8588 -1362.8892 -6342.2722 -1553.844 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-15880.815 -3890.7678 -18105.879 -4435.9042 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-45336.45 -11107.34 -51688.551 -12663.591 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-129426.22 -31709.164 -147560.15 -36151.942 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-369485.15 -90523.122 -421253.8 -103206.34 MAarrowhead1
% End of user PostScript
1 0 .398 r
.45393 .57771 m
.44965 .56192 L
.44441 .54833 L
.43814 .53653 L
.43074 .52616 L
.42209 .51689 L
.41206 .50847 L
.40047 .50066 L
.38714 .49325 L
.37184 .48603 L
.35431 .47885 L
.33425 .47153 L
.31132 .4639 L
.28513 .45581 L
.25524 .44708 L
.22111 .43755 L
.18218 .42704 L
.13777 .41535 L
.08712 .40226 L
.02936 .38754 L
s
.02936 .38754 m
0 .38014 L
s
1 0 0 r
.45393 .57771 m
.44965 .56192 L
s
% Start of user PostScript
-5.5288539 9.3250216 -6.0420462 7.4300163 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44441 .54833 m
.43814 .53653 L
s
% Start of user PostScript
-6.6704573 5.7998963 -7.4230544 4.3839049 MAarrowhead1
% End of user PostScript
1 .473 0 r
.35431 .47885 m
.33425 .47153 L
s
% Start of user PostScript
-17.483342 -2.5378088 -19.890202 -3.4166721 MAarrowhead1
% End of user PostScript
1 .788 0 r
.08712 .40226 m
.02936 .38754 L
s
% Start of user PostScript
-49.54517 -11.728598 -56.476921 -13.494765 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-141.35527 -34.535518 -161.15823 -39.403148 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-403.51994 -98.83898 -460.05666 -112.69411 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1151.9615 -282.22295 -1313.3629 -321.76686 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3288.6113 -805.70194 -3749.3793 -918.58939 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-9388.3067 -2300.1161 -10703.704 -2622.3859 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-26801.679 -6566.3577 -30556.869 -7486.3716 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-76513.266 -18745.597 -87233.558 -21372.047 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-218429.59 -53514.814 -249033.82 -61012.786 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-623571.44 -152773.76 -710940.18 -174178.92 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1780167.9 -436137.56 -2029587.6 -497244.9 MAarrowhead1
% End of user PostScript
.276 0 1 r
.52296 .48911 m
.52577 .49253 L
.52904 .49562 L
.53283 .49845 L
.5372 .50111 L
.54221 .50366 L
.54796 .50618 L
.55455 .50872 L
.56208 .51133 L
.57068 .51408 L
.5805 .51702 L
.59172 .52022 L
.60451 .52373 L
.61911 .52761 L
.63576 .53195 L
.65475 .53682 L
.6764 .54231 L
.70109 .54851 L
.72925 .55553 L
.76136 .5635 L
.79796 .57256 L
.8397 .58286 L
.88729 .59458 L
.94154 .60792 L
s
.94154 .60792 m
1 .62228 L
s
1 0 0 r
.52296 .48911 m
.52577 .49253 L
s
% Start of user PostScript
2.7549758 -1.3069341 3.0924554 -0.89591349 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52904 .49562 m
.53283 .49845 L
s
% Start of user PostScript
3.4852577 -0.52573443 3.9398023 -0.18581251 MAarrowhead1
% End of user PostScript
1 .473 0 r
.5805 .51702 m
.59172 .52022 L
s
% Start of user PostScript
9.6602942 2.042812 11.00587 2.4261422 MAarrowhead1
% End of user PostScript
1 .788 0 r
.72925 .55553 m
.76136 .5635 L
s
% Start of user PostScript
27.510195 6.6638799 31.362793 7.6203598 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
78.519978 19.219378 89.520993 21.917563 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
224.1546 54.913234 255.56085 62.608397 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
639.91427 156.77673 729.57278 178.74305 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1826.823 447.56776 2082.7796 510.27665 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
5215.203 1277.7142 5945.9062 1456.7351 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
14888.329 3647.6107 16974.336 4158.6783 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
42503.108 10413.176 48458.228 11872.169 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
121337.61 29727.471 138338.25 33892.594 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
346393.84 84865.798 394927.16 96756.365 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
988882.98 242274.35 1127435.6 276219.47 MAarrowhead1
% End of user PostScript
.276 1 0 r
.50149 .4788 m
.50117 .4823 L
.5009 .48521 L
.50065 .48764 L
.50044 .48966 L
.50025 .49134 L
.50007 .49274 L
.4999 .49391 L
.49973 .49487 L
.49957 .49567 L
.49941 .49633 L
.49924 .49687 L
.49906 .49732 L
.49887 .49768 L
.49866 .49796 L
.49843 .49819 L
.49818 .49837 L
.4979 .49849 L
.49758 .49858 L
.49722 .49863 L
.49681 .49864 L
.49635 .49863 L
.49583 .49858 L
.49523 .4985 L
.49456 .49839 L
.49379 .49824 L
.49291 .49807 L
.49191 .49786 L
.49078 .4976 L
.48948 .49731 L
.488 .49697 L
.48632 .49657 L
.4844 .49611 L
.48221 .49559 L
.47972 .49499 L
.47688 .4943 L
.47364 .49351 L
.46994 .49261 L
.46573 .49158 L
.46093 .49041 L
.45546 .48907 L
.44922 .48755 L
.4421 .4858 L
.43399 .48382 L
.42474 .48155 L
.41419 .47897 L
.40217 .47603 L
.38846 .47267 L
.37284 .46884 L
.35502 .46448 L
Mistroke
.3347 .4595 L
.31154 .45383 L
.28514 .44736 L
.25504 .43998 L
.22071 .43157 L
.18158 .42199 L
.13697 .41106 L
.08611 .3986 L
.02812 .38439 L
Mfstroke
.02812 .38439 m
0 .3775 L
s
1 0 0 r
.50149 .4788 m
.50117 .4823 L
s
% Start of user PostScript
0.17897962 -2.5437024 0.14070824 -2.1244019 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5009 .48521 m
.50065 .48764 L
s
% Start of user PostScript
0.10756949 -1.7748624 0.07854383 -1.483568 MAarrowhead1
% End of user PostScript
1 .473 0 r
.49941 .49633 m
.49924 .49687 L
s
% Start of user PostScript
-0.070747059 -0.44026769 -0.091013703 -0.37516584 MAarrowhead1
% End of user PostScript
1 .788 0 r
.49758 .49858 m
.49722 .49863 L
s
% Start of user PostScript
-0.29068602 -0.17052473 -0.33384533 -0.16464655 MAarrowhead1
% End of user PostScript
.897 1 0 r
.49291 .49807 m
.49191 .49786 L
s
% Start of user PostScript
-0.85068 -0.23173274 -0.97043984 -0.25721062 MAarrowhead1
% End of user PostScript
.581 1 0 r
.47972 .49499 m
.47688 .4943 L
s
% Start of user PostScript
-2.4334073 -0.60165506 -2.7744866 -0.68431174 MAarrowhead1
% End of user PostScript
.266 1 0 r
.4421 .4858 m
.43399 .48382 L
s
% Start of user PostScript
-6.9480244 -1.7035377 -7.9215452 -1.9418353 MAarrowhead1
% End of user PostScript
0 1 .049 r
.3347 .4595 m
.31154 .45383 L
s
% Start of user PostScript
-19.835446 -4.8599465 -22.614603 -5.5407842 MAarrowhead1
% End of user PostScript
0 1 .364 r
.02812 .38439 m
0 0 rlineto s
.02812 .38439 m
0 .3775 L
s
% Start of user PostScript
-56.626171 -13.87337 -64.560079 -15.817149 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-161.65606 -39.605427 -184.30572 -45.154547 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-461.4947 -113.06528 -526.15483 -128.90688 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1317.4722 -322.77805 -1502.0635 -368.00256 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3761.1114 -921.46476 -4288.0816 -1050.5714 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-10737.197 -2630.5918 -12241.588 -2999.1647 MAarrowhead1
% End of user PostScript
.256 1 0 r
.44365 .47495 m
.43548 .47481 L
.42621 .4741 L
.41568 .47281 L
.40371 .47096 L
.39008 .46853 L
.37457 .46548 L
.35691 .46178 L
.33678 .45737 L
.31385 .45219 L
.28771 .44615 L
.25792 .43916 L
.22397 .43109 L
.18526 .42182 L
.14114 .41119 L
.09084 .39901 L
.03349 .38509 L
s
.03349 .38509 m
0 .37693 L
s
1 0 0 r
.44365 .47495 m
.43548 .47481 L
s
% Start of user PostScript
-6.7617277 -3.0055629 -7.7421399 -3.0222824 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42621 .4741 m
.41568 .47281 L
s
% Start of user PostScript
-8.8544467 -3.1083393 -10.118034 -3.2623497 MAarrowhead1
% End of user PostScript
1 .473 0 r
.28771 .44615 m
.25792 .43916 L
s
% Start of user PostScript
-25.474594 -6.4617106 -29.049243 -7.3009648 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-72.770962 -17.880511 -82.968186 -20.370234 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-207.75695 -50.912193 -236.86612 -58.041868 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-593.10579 -145.31259 -676.20605 -165.67151 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1693.1953 -414.83013 -1930.4293 -472.95187 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4833.7235 -1184.2527 -5510.9776 -1350.1786 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-13799.284 -3380.7969 -15732.705 -3854.4811 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-39394.109 -9651.4778 -44913.627 -11003.749 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-112462.06 -27552.979 -128219.14 -31413.433 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-321055.97 -78658.071 -366039.2 -89678.872 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-916548.59 -224552.57 -1044966.4 -256014.68 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2616557.2 -641051.27 -2983163.6 -730869.12 MAarrowhead1
% End of user PostScript
1 0 .923 r
.42494 .53896 m
.41583 .52723 L
.40521 .5167 L
.3929 .50707 L
.37871 .49808 L
.3624 .48948 L
.34369 .48105 L
.32226 .4726 L
.29776 .46392 L
.26975 .45482 L
.23776 .44513 L
.20125 .43463 L
.15958 .42312 L
.11205 .4104 L
.05783 .39621 L
s
.05783 .39621 m
0 .38134 L
s
1 0 0 r
.42494 .53896 m
.41583 .52723 L
s
% Start of user PostScript
-9.0069654 4.6756553 -10.10044 3.2675658 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40521 .5167 m
.3929 .50707 L
s
% Start of user PostScript
-11.375036 2.0039961 -12.851506 0.84856798 MAarrowhead1
% End of user PostScript
1 .473 0 r
.23776 .44513 m
.20125 .43463 L
s
% Start of user PostScript
-31.468419 -6.5847822 -35.849927 -7.8446065 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-89.599876 -21.687654 -102.14727 -24.805499 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-255.73376 -62.592239 -291.56316 -71.380644 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-730.05413 -178.84724 -832.34182 -203.90993 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2084.1509 -510.60938 -2376.1617 -582.152 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5949.8203 -1457.6933 -6783.4509 -1661.9312 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-16985.51 -4161.4157 -19365.353 -4744.4726 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-48490.127 -11879.984 -55284.089 -13544.491 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-138429.31 -33914.904 -157824.67 -38666.729 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-395187.13 -96820.056 -450556.89 -110385.54 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1128177.8 -276401.29 -1286247. -315127.94 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3220714.8 -789068.68 -3671969.9 -899625.27 MAarrowhead1
% End of user PostScript
1 .52 0 r
.45415 .47095 m
.44728 .47222 L
.43953 .47278 L
.43076 .47269 L
.4208 .47196 L
.4095 .47062 L
.39664 .46867 L
.38201 .46608 L
.36536 .46283 L
.34639 .45887 L
.32478 .45416 L
.30016 .44861 L
.2721 .44214 L
.24012 .43464 L
.20367 .42599 L
.16211 .41604 L
.11474 .40463 L
.06074 .39156 L
s
.06074 .39156 m
0 .37682 L
s
1 0 0 r
.45415 .47095 m
.44728 .47222 L
s
% Start of user PostScript
-5.5025331 -3.4865561 -6.3258475 -3.3339924 MAarrowhead1
% End of user PostScript
1 .158 0 r
.43953 .47278 m
.43076 .47269 L
s
% Start of user PostScript
-7.2558434 -3.2662577 -8.3089049 -3.2776425 MAarrowhead1
% End of user PostScript
1 .473 0 r
.32478 .45416 m
.30016 .44861 L
s
% Start of user PostScript
-21.026194 -5.500904 -23.980736 -6.1668548 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-60.098766 -14.806148 -68.521227 -16.856038 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-171.5868 -42.057693 -195.62833 -47.944629 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-489.84896 -120.01654 -558.48192 -136.83073 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1398.4187 -342.61084 -1594.3515 -390.61381 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3992.1972 -978.08057 -4551.5449 -1115.1196 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-11396.9 -2792.2177 -12993.722 -3183.4359 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-32535.798 -7971.2054 -37094.396 -9088.0528 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-92882.993 -22756.147 -105896.85 -25944.516 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-265161.79 -64964.107 -302313.67 -74066.243 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-756982.21 -185459.13 -863043.16 -211443.85 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2161028.1 -529447.56 -2463810.2 -603628.58 MAarrowhead1
% End of user PostScript
0 .476 1 r
.42192 .54706 m
.4126 .53381 L
.40171 .52199 L
.38906 .51126 L
.37446 .50131 L
.35766 .49188 L
.33837 .48273 L
.31627 .47361 L
.29098 .46433 L
.26208 .45468 L
.22906 .44444 L
.19136 .43341 L
.14834 .42137 L
.09926 .4081 L
.04326 .39334 L
s
.04326 .39334 m
0 .38215 L
s
1 0 0 r
.42192 .54706 m
.4126 .53381 L
s
% Start of user PostScript
-9.3695165 5.6467396 -10.48784 4.0569684 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40171 .52199 m
.38906 .51126 L
s
% Start of user PostScript
-11.795065 2.6389012 -13.312322 1.3512479 MAarrowhead1
% End of user PostScript
1 .473 0 r
.22906 .44444 m
.19136 .43341 L
s
% Start of user PostScript
-32.512746 -6.6673982 -37.036332 -7.9907326 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-92.544872 -22.368494 -105.50389 -25.593926 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-264.13258 -64.640382 -301.13851 -73.718617 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-754.02903 -184.7188 -859.6758 -210.60483 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2152.5938 -527.37724 -2454.1942 -601.26937 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6145.2106 -1505.5634 -7006.2175 -1716.5085 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-17543.309 -4298.0753 -20001.306 -4900.2797 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-50082.528 -12270.119 -57099.603 -13989.288 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-142975.29 -35028.66 -163007.59 -39936.533 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-408164.96 -99999.598 -465353.05 -114010.57 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1165226.8 -285478.23 -1328487. -325476.65 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3326482.1 -814981.46 -3792556.3 -929168.7 MAarrowhead1
% End of user PostScript
0 .084 1 r
.54459 .54616 m
.5517 .54206 L
.55966 .53914 L
.56862 .53728 L
.57873 .53636 L
.59018 .53634 L
.60317 .53716 L
.61791 .5388 L
.63468 .54127 L
.65375 .54457 L
.67546 .54875 L
.70019 .55385 L
.72835 .55995 L
.76044 .56715 L
.79702 .57556 L
.8387 .58531 L
.88621 .59656 L
.94037 .60951 L
s
.94037 .60951 m
1 .62386 L
s
1 0 0 r
.54459 .54616 m
.5517 .54206 L
s
% Start of user PostScript
5.3504085 5.5391075 6.2035717 5.0476383 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55966 .53914 m
.56862 .53728 L
s
% Start of user PostScript
7.1591222 4.6973035 8.2342469 4.4730882 MAarrowhead1
% End of user PostScript
1 .473 0 r
.67546 .54875 m
.70019 .55385 L
s
% Start of user PostScript
21.055231 5.8495991 24.022204 6.4620062 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
60.253315 14.924218 68.699394 16.966606 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
172.04483 42.188742 196.151 48.088393 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
491.16049 120.34228 559.97732 137.20079 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1402.1638 343.52942 1598.6213 391.66078 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4002.8888 980.70025 4563.7345 1118.1062 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
11427.422 2799.6957 13028.521 3191.9616 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
32622.933 7992.5534 37193.74 9112.3919 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
93131.747 22817.092 106180.46 26013.999 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
265871.93 65138.09 303123.31 74264.603 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
759009.52 185955.81 865354.52 212010.12 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2166815.6 530865.49 2470408.7 605245.18 MAarrowhead1
% End of user PostScript
.506 0 1 r
.5646 .48165 m
.57282 .48933 L
.58232 .49638 L
.59327 .503 L
.60586 .50938 L
.62028 .51565 L
.6368 .52199 L
.65568 .52852 L
.67726 .5354 L
.7019 .54277 L
.73002 .55077 L
.76211 .55956 L
.79872 .5693 L
.84048 .58017 L
.88811 .59238 L
.94242 .60613 L
s
.94242 .60613 m
1 .62059 L
s
1 0 0 r
.5646 .48165 m
.57282 .48933 L
s
% Start of user PostScript
7.7522813 -2.2014306 8.7380616 -1.280554 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58232 .49638 m
.59327 .503 L
s
% Start of user PostScript
9.8785919 -0.43431317 11.192799 0.36057478 MAarrowhead1
% End of user PostScript
1 .473 0 r
.73002 .55077 m
.76211 .55956 L
s
% Start of user PostScript
27.602552 6.0923076 31.453543 7.1468343 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
78.658995 19.113915 89.676072 21.83915 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
224.52219 54.970534 255.97915 62.683547 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
640.95681 157.02446 730.7612 179.02779 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1829.7977 448.29473 2086.171 511.10602 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5223.6945 1279.7942 5955.5875 1459.1066 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
14912.57 3653.5498 17001.974 4165.4495 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
42572.313 10430.131 48537.129 11891.499 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
121535.17 29775.874 138563.49 33947.778 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
346957.85 85003.979 395570.19 96913.906 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
990493.1 242668.83 1129271.3 276669.21 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2827653.5 692769.45 3223836.7 789833.54 MAarrowhead1
% End of user PostScript
0 1 .05 r
.53382 .45264 m
.53719 .46269 L
.54127 .47138 L
.5461 .47898 L
.55177 .48572 L
.55837 .4918 L
.56599 .4974 L
.57478 .50266 L
.58487 .50773 L
.59644 .51273 L
.60969 .51778 L
.62484 .523 L
.64214 .52849 L
.6619 .53438 L
.68446 .54078 L
.71019 .54782 L
.73955 .55562 L
.77304 .56433 L
.81123 .57412 L
.85479 .58514 L
.90445 .5976 L
.96109 .61172 L
s
.96109 .61172 m
1 .62138 L
s
1 0 0 r
.53382 .45264 m
.53719 .46269 L
s
% Start of user PostScript
4.0582038 -5.6829775 4.4633282 -4.4775136 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54127 .47138 m
.5461 .47898 L
s
% Start of user PostScript
4.9522969 -3.4347725 5.5323705 -2.5226141 MAarrowhead1
% End of user PostScript
1 .473 0 r
.60969 .51778 m
.62484 .523 L
s
% Start of user PostScript
13.162774 2.1334615 14.980293 2.7595599 MAarrowhead1
% End of user PostScript
1 .788 0 r
.81123 .57412 m
.85479 .58514 L
s
% Start of user PostScript
37.348066 8.893937 42.574638 10.216892 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
106.56727 26.048595 121.49696 29.716309 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
304.21495 74.517925 346.83823 84.962884 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
868.46798 212.7696 990.14914 242.58179 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2479.2963 607.42184 2826.671 692.52809 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
7077.8793 1734.0661 8069.5626 1977.0265 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
20205.886 4950.4015 23036.937 5644.0034 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
57683.636 14132.375 65765.703 16112.466 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
164674.88 40345.017 187747.52 45997.766 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
470112.83 115176.7 535980.44 131314.14 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1342075.2 328805.73 1530113.6 374874.78 MAarrowhead1
% End of user PostScript
.467 0 1 r
.57086 .43199 m
.5787 .44806 L
.58798 .46213 L
.59886 .47464 L
.61149 .48595 L
.6261 .49638 L
.64292 .50622 L
.66225 .51572 L
.68439 .52513 L
.70973 .53466 L
.73871 .54453 L
.77181 .55495 L
.80961 .56614 L
.85275 .57832 L
.90198 .59172 L
.95814 .6066 L
s
.95814 .6066 m
1 .61747 L
s
1 0 0 r
.57086 .43199 m
.5787 .44806 L
s
% Start of user PostScript
8.5034516 -8.1609415 9.4440728 -6.2333343 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58798 .46213 m
.59886 .47464 L
s
% Start of user PostScript
10.558034 -4.5444251 11.862739 -3.0433698 MAarrowhead1
% End of user PostScript
1 .473 0 r
.73871 .54453 m
.77181 .55495 L
s
% Start of user PostScript
28.645136 5.3435773 32.61762 6.5942277 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
81.424717 19.555729 92.823527 22.41355 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
232.3683 56.837452 264.92322 64.828635 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
663.34421 162.49633 756.28498 185.27022 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1893.7063 463.94917 2159.0339 528.95473 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5406.14 1324.4923 6163.5955 1510.0676 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
15433.414 3781.1554 17595.794 4310.934 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
44059.215 10794.419 50232.362 12306.828 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
125779.97 30815.841 143403.03 35133.456 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
359075.88 87972.871 409386.08 100298.77 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1025087.6 251144.4 1168712.8 286332.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2926413.6 716965.47 3336434.1 817419.67 MAarrowhead1
% End of user PostScript
1 0 .975 r
.45067 .53814 m
.44499 .52843 L
.43831 .51985 L
.43052 .51215 L
.4215 .5051 L
.4111 .49852 L
.39914 .49223 L
.38542 .48606 L
.36971 .47987 L
.35175 .47352 L
.33122 .46686 L
.30777 .45975 L
.281 .45206 L
.25046 .44363 L
.21561 .4343 L
.17587 .42391 L
.13053 .41225 L
.07884 .39913 L
.01988 .3843 L
s
.01988 .3843 m
0 .37933 L
s
1 0 0 r
.45067 .53814 m
.44499 .52843 L
s
% Start of user PostScript
-5.9193663 4.5766517 -6.6011803 3.4111413 MAarrowhead1
% End of user PostScript
1 .158 0 r
.43831 .51985 m
.43052 .51215 L
s
% Start of user PostScript
-7.4029679 2.3816526 -8.3374888 1.4576554 MAarrowhead1
% End of user PostScript
1 .473 0 r
.33122 .46686 m
.30777 .45975 L
s
% Start of user PostScript
-20.253897 -3.9770714 -23.067559 -4.829612 MAarrowhead1
% End of user PostScript
1 .788 0 r
.01988 .3843 m
0 0 rlineto s
.01988 .3843 m
0 .37933 L
s
% Start of user PostScript
-57.61406 -13.884025 -65.680716 -15.898659 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-164.42774 -40.230155 -187.46442 -45.883093 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-469.39589 -114.9883 -535.16274 -131.10316 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1340.0258 -328.30064 -1527.777 -374.29981 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3825.4966 -937.2383 -4361.4878 -1068.5552 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-10921.004 -2675.6238 -12451.148 -3050.5062 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-31177.213 -7638.3547 -35545.459 -8708.5663 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-89004.512 -21805.927 -101474.95 -24861.161 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-254089.53 -62251.425 -289690.07 -70973.486 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-725373.19 -177714.98 -827005.39 -202614.67 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2070790.8 -507339.61 -2360929.8 -578423.08 MAarrowhead1
% End of user PostScript
1 .971 0 r
.46423 .48443 m
.45905 .48429 L
.45318 .48379 L
.4465 .48294 L
.43891 .48173 L
.43027 .48016 L
.42043 .47821 L
.40923 .47584 L
.39646 .47303 L
.38192 .46974 L
.36534 .46589 L
.34644 .46145 L
.32491 .45633 L
.30035 .45044 L
.27237 .44369 L
.24046 .43596 L
.20408 .42713 L
.16261 .41703 L
.11533 .4055 L
.06143 .39233 L
s
.06143 .39233 m
0 .37732 L
s
1 0 0 r
.46423 .48443 m
.45905 .48429 L
s
% Start of user PostScript
-4.2921665 -1.8687239 -4.9135484 -1.8855846 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45318 .48379 m
.4465 .48294 L
s
% Start of user PostScript
-5.618678 -1.945391 -6.4198382 -2.0474369 MAarrowhead1
% End of user PostScript
1 .473 0 r
.36534 .46589 m
.34644 .46145 L
s
% Start of user PostScript
-16.159488 -4.0926054 -18.426867 -4.6259815 MAarrowhead1
% End of user PostScript
1 .788 0 r
.11533 .4055 m
.06143 .39233 L
s
% Start of user PostScript
-46.160022 -11.340474 -52.628281 -12.919989 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-131.78392 -32.29416 -150.24838 -36.816695 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-376.21746 -92.174253 -428.92941 -105.08829 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1074.0236 -263.13404 -1224.5053 -300.00169 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3066.116 -751.19237 -3495.7102 -856.44208 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8753.1287 -2144.499 -9979.5316 -2444.9653 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-24988.377 -6122.1024 -28489.504 -6979.8716 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-71336.663 -17477.34 -81331.659 -19926.094 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-203651.46 -49894.2 -232185.11 -56884.888 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-581382.92 -142437.65 -662840.61 -162394.62 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1659728.3 -406630.12 -1892273.2 -463603.15 MAarrowhead1
% End of user PostScript
.643 0 1 r
.50403 .56918 m
.50626 .55843 L
.50853 .54956 L
.51089 .54227 L
.51338 .53632 L
.51607 .53151 L
.51899 .52766 L
.52222 .52463 L
.5258 .52233 L
.52981 .52066 L
.53431 .51955 L
.53939 .51895 L
.54514 .51882 L
.55165 .51913 L
.55905 .51987 L
.56746 .52103 L
.57702 .52263 L
.5879 .52467 L
.60029 .52719 L
.61441 .53021 L
.63049 .53379 L
.64882 .53798 L
.66971 .54285 L
.69352 .54847 L
.72066 .55494 L
.7516 .56238 L
.78687 .5709 L
.82707 .58065 L
.87291 .59179 L
.92517 .60452 L
.98475 .61906 L
s
.98475 .61906 m
1 .62279 L
s
1 0 0 r
.50403 .56918 m
.50626 .55843 L
s
% Start of user PostScript
0.48329649 8.3013712 0.75134599 7.0113801 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50853 .54956 m
.51089 .54227 L
s
% Start of user PostScript
1.0237627 5.9470501 1.306657 5.0726704 MAarrowhead1
% End of user PostScript
1 .473 0 r
.53431 .51955 m
.53939 .51895 L
s
% Start of user PostScript
4.1175124 2.346286 4.7271627 2.2740664 MAarrowhead1
% End of user PostScript
1 .788 0 r
.60029 .52719 m
.61441 .53021 L
s
% Start of user PostScript
12.035213 3.2626557 13.729158 3.6256401 MAarrowhead1
% End of user PostScript
.897 1 0 r
.78687 .5709 m
.82707 .58065 L
s
% Start of user PostScript
34.423928 8.5075347 39.248878 9.6774211 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
98.288684 24.097846 112.06036 27.46901 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
280.59755 68.749904 319.91224 78.38125 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
801.04899 196.25635 913.28418 223.75359 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
2286.8299 560.26896 2607.2381 638.76831 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
6528.4277 1599.4518 7443.1271 1823.5513 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
18637.314 4566.1048 21248.593 5205.8627 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
53205.689 13035.287 60660.35 14861.664 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
151891.27 37213.057 173172.79 42426.987 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
433618.24 106235.6 494372.6 121120.3 MAarrowhead1
% End of user PostScript
0 .517 1 r
.50678 .47683 m
.50713 .48103 L
.50762 .48458 L
.50826 .4876 L
.50907 .49019 L
.51004 .49242 L
.5112 .49437 L
.51257 .49609 L
.51416 .49764 L
.516 .49905 L
.51812 .50038 L
.52056 .50165 L
.52336 .5029 L
.52656 .50415 L
.53022 .50544 L
.53441 .50679 L
.53919 .50823 L
.54465 .5098 L
.55088 .51151 L
.55798 .51341 L
.56609 .51553 L
.57533 .5179 L
.58587 .52058 L
.59789 .5236 L
.6116 .52702 L
.62723 .5309 L
.64505 .53531 L
.66536 .54033 L
.68853 .54603 L
.71494 .55253 L
.74505 .55993 L
.77938 .56836 L
.81852 .57796 L
.86315 .58891 L
.91403 .60138 L
.97204 .6156 L
s
.97204 .6156 m
1 .62246 L
s
1 0 0 r
.50678 .47683 m
.50713 .48103 L
s
% Start of user PostScript
0.81405499 -2.7806423 0.85515423 -2.2768658 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50762 .48458 m
.50826 .4876 L
s
% Start of user PostScript
0.9140988 -1.8505092 0.99138658 -1.4879001 MAarrowhead1
% End of user PostScript
1 .473 0 r
.51812 .50038 m
.52056 .50165 L
s
% Start of user PostScript
2.17441 0.045632004 2.4671421 0.19804712 MAarrowhead1
% End of user PostScript
1 .788 0 r
.55088 .51151 m
.55798 .51341 L
s
% Start of user PostScript
6.1053159 1.381418 6.957933 1.6092554 MAarrowhead1
% End of user PostScript
.897 1 0 r
.64505 .53531 m
.66536 .54033 L
s
% Start of user PostScript
17.405426 4.2374394 19.843447 4.8391987 MAarrowhead1
% End of user PostScript
.581 1 0 r
.91403 .60138 m
.97204 .6156 L
s
% Start of user PostScript
49.683268 12.165996 56.644248 13.872466 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
141.83416 34.747605 161.70654 39.616544 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
404.90697 99.201049 461.63857 113.10023 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
1155.9258 283.19943 1317.8828 322.87859 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
3299.9297 808.47616 3762.2837 921.75195 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
9420.6188 2308.0328 10740.544 2631.4117 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
26893.924 6588.9575 30662.038 7512.1378 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
76776.606 18810.115 87533.793 21445.604 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
219181.37 53698.998 249890.93 61222.777 MAarrowhead1
% End of user PostScript
1 .168 0 r
.42716 .57933 m
.41933 .56131 L
.41002 .5456 L
.39906 .53171 L
.3863 .51923 L
.37153 .50781 L
.35449 .49713 L
.3349 .4869 L
.31244 .47686 L
.28672 .46678 L
.2573 .45642 L
.22369 .44556 L
.1853 .43395 L
.14147 .42139 L
.09147 .40761 L
.03442 .39235 L
s
.03442 .39235 m
0 .38336 L
s
1 0 0 r
.42716 .57933 m
.41933 .56131 L
s
% Start of user PostScript
-8.7408053 9.5190068 -9.6800104 7.3571235 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41002 .5456 m
.39906 .53171 L
s
% Start of user PostScript
-10.798101 5.4714493 -12.112307 3.8047433 MAarrowhead1
% End of user PostScript
1 .473 0 r
.2573 .45642 m
.22369 .44556 L
s
% Start of user PostScript
-29.123682 -5.2293398 -33.157547 -6.5333778 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-82.742309 -19.824184 -94.324397 -22.735912 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-236.11835 -57.743445 -269.19838 -65.865393 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-674.04716 -165.11553 -768.48746 -188.2573 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1924.2604 -471.43416 -2193.8689 -537.48865 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5493.3655 -1345.8622 -6263.0421 -1534.4317 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-15682.425 -3842.1625 -17879.693 -4380.4888 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-44770.089 -10968.582 -51042.837 -12505.393 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-127809.37 -31313.04 -145716.77 -35700.317 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-364869.39 -89392.271 -415991.33 -101917.04 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1041626.9 -255196.5 -1187569.4 -290952.14 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2973629.9 -728533.37 -3390265.8 -830608.34 MAarrowhead1
% End of user PostScript
1 .296 0 r
.58031 .42476 m
.58924 .44267 L
.59981 .45838 L
.61217 .47236 L
.62654 .48501 L
.64314 .4967 L
.66226 .50774 L
.68421 .51842 L
.70936 .52901 L
.73815 .53975 L
.77106 .5509 L
.80866 .56268 L
.85159 .57534 L
.90059 .58913 L
.9565 .60432 L
s
.9565 .60432 m
1 .61583 L
s
1 0 0 r
.58031 .42476 m
.58924 .44267 L
s
% Start of user PostScript
9.6374489 -9.0289157 10.708903 -6.879431 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59981 .45838 m
.61217 .47236 L
s
% Start of user PostScript
11.976676 -4.9944626 13.460621 -3.3173561 MAarrowhead1
% End of user PostScript
1 .473 0 r
.77106 .5509 m
.80866 .56268 L
s
% Start of user PostScript
32.527756 6.1075304 37.039649 7.5213618 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
92.46951 22.217707 105.41473 25.461681 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
263.88968 64.549802 300.86081 73.624659 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
753.32908 184.54002 858.87761 210.40319 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2150.5941 526.88559 2451.9142 600.70935 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6139.5014 1504.1642 6999.7084 1714.9134 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
17527.01 4294.0821 19982.723 4895.727 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
50035.999 12258.719 57046.554 13976.291 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
142842.46 34996.116 162856.15 39899.43 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
407785.75 99906.693 464920.71 113904.64 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1164144.2 285213. 1327252.7 325174.26 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3323391.6 814224.3 3789032.8 928305.45 MAarrowhead1
% End of user PostScript
1 0 .872 r
.50711 .49188 m
.50786 .4937 L
.50876 .49528 L
.50982 .49668 L
.51106 .49793 L
.51249 .49907 L
.51414 .50014 L
.51604 .50116 L
.51822 .50215 L
.52072 .50314 L
.52358 .50416 L
.52684 .50523 L
.53057 .50637 L
.53482 .5076 L
.53968 .50894 L
.54522 .51043 L
.55154 .51208 L
.55874 .51394 L
.56696 .51603 L
.57634 .51839 L
.58703 .52106 L
.59921 .52409 L
.61311 .52753 L
.62895 .53144 L
.64701 .53589 L
.66761 .54096 L
.69109 .54673 L
.71786 .5533 L
.74838 .56079 L
.78318 .56933 L
.82286 .57906 L
.86809 .59015 L
.91967 .60279 L
.97847 .6172 L
s
.97847 .6172 m
1 .62248 L
s
1 0 0 r
.50711 .49188 m
.50786 .4937 L
s
% Start of user PostScript
0.85294162 -0.97433633 0.94347787 -0.75611824 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50876 .49528 m
.50982 .49668 L
s
% Start of user PostScript
1.0514985 -0.56609372 1.1786583 -0.39847692 MAarrowhead1
% End of user PostScript
1 .473 0 r
.52358 .50416 m
.52684 .50523 L
s
% Start of user PostScript
2.8290246 0.49969437 3.2206648 0.62768762 MAarrowhead1
% End of user PostScript
1 .788 0 r
.56696 .51603 m
.57634 .51839 L
s
% Start of user PostScript
8.0357105 1.9233191 9.1604839 2.20641 MAarrowhead1
% End of user PostScript
.897 1 0 r
.69109 .54673 m
.71786 .5533 L
s
% Start of user PostScript
22.93077 5.6073293 26.143344 6.3961701 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
65.460381 16.035159 74.631989 18.282599 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
186.87536 45.783502 213.0585 52.198415 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
533.49049 130.70396 608.23797 149.01697 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
1523.0053 373.13322 1736.3939 425.41301 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
4347.866 1065.2185 4957.0465 1214.4665 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
12412.261 3040.979 14151.345 3467.0513 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
35434.444 8681.3679 40399.172 9897.7164 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
101158.03 24783.515 115331.31 28255.939 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
288785.31 70751.824 329247.09 80664.878 MAarrowhead1
% End of user PostScript
1 .914 0 r
.55935 .51793 m
.56775 .51943 L
.57731 .5213 L
.5882 .52358 L
.6006 .52629 L
.61474 .52948 L
.63085 .5332 L
.64921 .53751 L
.67014 .54248 L
.694 .54819 L
.72119 .55475 L
.7522 .56225 L
.78755 .57083 L
.82784 .58064 L
.87378 .59185 L
.92616 .60463 L
.98588 .61923 L
s
.98588 .61923 m
1 .62268 L
s
1 0 0 r
.55935 .51793 m
.56775 .51943 L
s
% Start of user PostScript
7.1217978 2.1518297 8.1295987 2.3313111 MAarrowhead1
% End of user PostScript
1 .158 0 r
.57731 .5213 m
.5882 .52358 L
s
% Start of user PostScript
9.2769521 2.5561533 10.583684 2.8293629 MAarrowhead1
% End of user PostScript
1 .473 0 r
.72119 .55475 m
.7522 .56225 L
s
% Start of user PostScript
26.543216 6.5695594 30.26382 7.470079 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
75.789361 18.583862 86.408608 21.182969 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
216.36627 53.012971 246.68149 60.439531 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
617.68185 151.33168 704.22542 172.53454 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1763.3545 432.01852 2010.4185 492.54867 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5034.0134 1233.3232 5739.3301 1406.1244 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
14371.07 3520.8834 16384.604 4014.1951 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
41026.441 10051.396 46774.665 11459.699 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
117122.03 28694.662 133532.02 32715.078 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
334359.23 81917.342 381206.38 93394.799 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
954526.64 233857.12 1088265.6 266622.89 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2724976.7 667613.83 3106773.8 761153.36 MAarrowhead1
% End of user PostScript
0 .973 1 r
.57256 .48982 m
.58205 .49677 L
.59297 .50331 L
.60552 .50961 L
.61991 .51583 L
.63638 .52211 L
.65521 .52859 L
.67672 .53543 L
.70129 .54275 L
.72933 .55071 L
.76133 .55946 L
.79784 .56916 L
.83947 .57999 L
.88696 .59215 L
.94111 .60586 L
s
.94111 .60586 m
1 .62063 L
s
1 0 0 r
.57256 .48982 m
.58205 .49677 L
s
% Start of user PostScript
8.7077952 -1.222085 9.8456979 -0.38740292 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59297 .50331 m
.60552 .50961 L
s
% Start of user PostScript
11.156642 0.39757891 12.662617 1.1535053 MAarrowhead1
% End of user PostScript
1 .473 0 r
.76133 .55946 m
.79784 .56916 L
s
% Start of user PostScript
31.359943 7.1346711 35.740364 8.2987271 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
89.411121 21.776766 101.93538 24.86652 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
255.2233 62.498959 290.98195 71.264767 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
728.60353 178.49931 830.68816 203.51101 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2080.0113 509.59694 2371.4421 580.99719 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5938.003 1454.7984 6769.9779 1658.6307 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
16951.774 4153.1505 19326.891 4735.0494 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
48393.817 11856.388 55174.286 13517.59 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
138154.37 33847.544 157511.21 38589.931 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
394402.23 96627.756 449662.01 110166.29 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1125937. 275852.31 1283692.3 314502.04 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3214317.9 787501.46 3664676.8 897838.47 MAarrowhead1
% End of user PostScript
1 0 .218 r
.42293 .53367 m
.41341 .52263 L
.40236 .51266 L
.38957 .50347 L
.37485 .4948 L
.35793 .48644 L
.33855 .47817 L
.31636 .4698 L
.29099 .46113 L
.26201 .45199 L
.22892 .44218 L
.19115 .4315 L
.14805 .41975 L
.09889 .40672 L
.04281 .39215 L
s
.04281 .39215 m
0 .3812 L
s
1 0 0 r
.42293 .53367 m
.41341 .52263 L
s
% Start of user PostScript
-9.2488296 4.0404891 -10.390292 2.7160533 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40236 .51266 m
.38957 .50347 L
s
% Start of user PostScript
-11.717262 1.5192557 -13.251496 0.41609145 MAarrowhead1
% End of user PostScript
1 .473 0 r
.22892 .44218 m
.19115 .4315 L
s
% Start of user PostScript
-32.529498 -6.9388768 -37.061978 -8.2200943 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-92.648784 -22.456733 -105.6239 -25.675708 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-264.4424 -64.731028 -301.49209 -73.817544 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-754.91659 -184.93971 -860.6878 -210.85565 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2155.1284 -527.999 -2457.0838 -601.978 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6152.4463 -1507.3363 -7014.467 -1718.5298 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-17563.965 -4303.1361 -20024.856 -4906.0496 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-50141.498 -12284.567 -57166.835 -14005.76 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-143143.64 -35069.904 -163199.52 -39983.556 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-408645.56 -100117.34 -465900.98 -114144.81 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1166598.8 -285814.37 -1330051.2 -325859.88 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3330398.9 -815941.07 -3797021.9 -930262.76 MAarrowhead1
% End of user PostScript
1 0 .241 r
.50019 .50216 m
.50026 .50183 L
.50035 .50156 L
.50043 .50134 L
.50052 .50115 L
.50062 .50101 L
.50073 .50089 L
.50084 .5008 L
.50098 .50074 L
.50113 .50069 L
.5013 .50066 L
.50149 .50065 L
.5017 .50066 L
.50194 .50068 L
.50222 .50071 L
.50254 .50076 L
.5029 .50083 L
.5033 .50091 L
.50377 .501 L
.5043 .50112 L
.5049 .50126 L
.50559 .50142 L
.50638 .5016 L
.50727 .50181 L
.50829 .50206 L
.50945 .50234 L
.51078 .50266 L
.51229 .50303 L
.51401 .50345 L
.51598 .50393 L
.51821 .50447 L
.52077 .5051 L
.52368 .50581 L
.52699 .50662 L
.53078 .50754 L
.53509 .5086 L
.54 .5098 L
.54561 .51118 L
.552 .51274 L
.55929 .51453 L
.56759 .51656 L
.57706 .51888 L
.58786 .52153 L
.60017 .52454 L
.61421 .52798 L
.63021 .5319 L
.64845 .53637 L
.66925 .54147 L
.69296 .54728 L
.72 .5539 L
Mistroke
.75082 .56145 L
.78597 .57006 L
.82603 .57988 L
.87172 .59107 L
.9238 .60383 L
.98318 .61838 L
Mfstroke
.98318 .61838 m
1 .6225 L
s
1 0 0 r
.50019 .50216 m
.50026 .50183 L
s
% Start of user PostScript
0.022429925 0.25962922 0.031794275 0.21982138 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50035 .50156 m
.50043 .50134 L
s
% Start of user PostScript
0.041439925 0.18705746 0.051577051 0.16023342 MAarrowhead1
% End of user PostScript
1 .473 0 r
.5013 .50066 m
.50149 .50065 L
s
% Start of user PostScript
0.15541122 0.079613572 0.17820285 0.0783159 MAarrowhead1
% End of user PostScript
1 .788 0 r
.50377 .501 m
.5043 .50112 L
s
% Start of user PostScript
0.4523803 0.12058563 0.51600219 0.13455704 MAarrowhead1
% End of user PostScript
.897 1 0 r
.51078 .50266 m
.51229 .50303 L
s
% Start of user PostScript
1.2934984 0.31919465 1.4747868 0.36323055 MAarrowhead1
% End of user PostScript
.581 1 0 r
.53078 .50754 m
.53509 .5086 L
s
% Start of user PostScript
3.6931515 0.90535246 4.210613 1.0320404 MAarrowhead1
% End of user PostScript
.266 1 0 r
.58786 .52153 m
.60017 .52454 L
s
% Start of user PostScript
10.543299 2.5832133 12.020526 2.9451101 MAarrowhead1
% End of user PostScript
0 1 .049 r
.75082 .56145 m
.78597 .57006 L
s
% Start of user PostScript
30.098969 7.3742169 34.316144 8.4074113 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
85.926356 21.051792 97.965518 24.001362 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
245.30203 60.098507 279.67135 68.518922 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
700.28669 171.56884 798.40402 195.60739 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1999.1741 489.79365 2279.2788 558.41875 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
5707.2297 1398.2598 6506.8709 1594.1704 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
16292.964 3991.7435 18575.774 4551.0276 MAarrowhead1
% End of user PostScript
1 0 .853 r
.4767 .4691 m
.47282 .47232 L
.4685 .47475 L
.46366 .47647 L
.45821 .47755 L
.45205 .47807 L
.44509 .47805 L
.43718 .47752 L
.42821 .4765 L
.418 .47498 L
.4064 .47295 L
.39318 .47039 L
.37813 .46728 L
.36098 .46355 L
.34145 .45916 L
.31918 .45404 L
.29381 .44809 L
.26489 .44124 L
.23191 .43335 L
.19433 .4243 L
.15148 .41394 L
.10263 .40208 L
.04695 .38853 L
s
.04695 .38853 m
0 .37709 L
s
1 0 0 r
.4767 .4691 m
.47282 .47232 L
s
% Start of user PostScript
-2.7956182 -3.7077824 -3.2613183 -3.3210839 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4685 .47475 m
.46366 .47647 L
s
% Start of user PostScript
-3.7800074 -3.0303336 -4.361141 -2.8241031 MAarrowhead1
% End of user PostScript
1 .473 0 r
.4064 .47295 m
.39318 .47039 L
s
% Start of user PostScript
-11.232542 -3.2460363 -12.818432 -3.5527215 MAarrowhead1
% End of user PostScript
1 .788 0 r
.23191 .43335 m
.19433 .4243 L
s
% Start of user PostScript
-32.170232 -7.9976565 -36.680451 -9.0834312 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-91.863714 -22.533667 -104.73543 -25.682698 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-262.25767 -64.259001 -299.00281 -73.260427 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-748.69291 -183.42977 -853.59248 -209.1297 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2137.3641 -523.65029 -2436.8307 -597.01895 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6101.7339 -1494.9127 -6956.6492 -1704.3652 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-17419.192 -4267.6671 -19859.799 -4865.611 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-49728.2 -12183.309 -56695.629 -13890.316 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-141963.75 -34780.836 -161854.33 -39653.986 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-405277.24 -99292.112 -462060.73 -113203.95 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1156982.9 -283458.5 -1319088.1 -323173.94 MAarrowhead1
% End of user PostScript
1 0 .426 r
.47002 .44771 m
.46472 .45385 L
.45886 .45863 L
.45233 .46222 L
.44501 .46475 L
.43677 .46634 L
.42747 .46707 L
.41694 .467 L
.40499 .46617 L
.39142 .46459 L
.37599 .46227 L
.35844 .45919 L
.33845 .45531 L
.31569 .45058 L
.28977 .44493 L
.26022 .43828 L
.22655 .43053 L
.18818 .42154 L
.14444 .41116 L
.09458 .39923 L
.03774 .38555 L
s
.03774 .38555 m
0 .37642 L
s
1 0 0 r
.47002 .44771 m
.46472 .45385 L
s
% Start of user PostScript
-3.5973372 -6.2752805 -4.233415 -5.5375102 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45886 .45863 m
.45233 .46222 L
s
% Start of user PostScript
-4.9367365 -4.9642575 -5.7203477 -4.5341926 MAarrowhead1
% End of user PostScript
1 .473 0 r
.37599 .46227 m
.35844 .45919 L
s
% Start of user PostScript
-14.880991 -4.5274512 -16.987554 -4.897495 MAarrowhead1
% End of user PostScript
1 .788 0 r
.14444 .41116 m
.09458 .39923 L
s
% Start of user PostScript
-42.667098 -10.660367 -48.650263 -12.091935 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-121.84919 -29.901415 -138.9227 -34.076338 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-347.8645 -85.237519 -396.60415 -97.176746 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-993.08379 -243.30622 -1132.2251 -277.39511 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2835.05 -694.5822 -3232.2695 -791.90008 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8093.4831 -1982.8873 -9227.4629 -2260.7101 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-23105.225 -5660.7339 -26342.503 -6453.8606 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-65960.652 -16160.228 -75202.414 -18424.441 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-188304.06 -46134.117 -214687.38 -52597.979 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-537569.25 -131703.39 -612888.2 -150156.38 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1534649.3 -375986.01 -1749669.4 -428665.5 MAarrowhead1
% End of user PostScript
1 0 .525 r
.45922 .57573 m
.4556 .56065 L
.45113 .5477 L
.44575 .5365 L
.43937 .52668 L
.43189 .51797 L
.42319 .5101 L
.41314 .50284 L
.40156 .49601 L
.38826 .48942 L
.37302 .4829 L
.35557 .4763 L
.33562 .46948 L
.31282 .46228 L
.2868 .45456 L
.25709 .44615 L
.2232 .43691 L
.18453 .42665 L
.14042 .41519 L
.09012 .40233 L
.03276 .38782 L
s
.03276 .38782 m
0 .3796 L
s
1 0 0 r
.45922 .57573 m
.4556 .56065 L
s
% Start of user PostScript
-4.8937785 9.0880816 -5.3276002 7.2775524 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45113 .5477 m
.44575 .5365 L
s
% Start of user PostScript
-5.8639279 5.7242495 -6.5102116 4.3795729 MAarrowhead1
% End of user PostScript
1 .473 0 r
.37302 .4829 m
.35557 .4763 L
s
% Start of user PostScript
-15.238185 -2.0519091 -17.332046 -2.8434591 MAarrowhead1
% End of user PostScript
1 .788 0 r
.14042 .41519 m
.09012 .40233 L
s
% Start of user PostScript
-43.149168 -10.176655 -49.185143 -11.720863 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-123.09916 -30.066345 -140.34434 -34.306738 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-351.40327 -86.07133 -400.63792 -98.137329 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1003.1793 -245.7718 -1143.7348 -280.20848 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2863.8689 -701.64094 -3265.1262 -799.94837 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8175.7547 -2003.0433 -9321.2616 -2283.6902 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-23340.093 -5718.2761 -26610.279 -6519.4651 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-66631.153 -16324.499 -75966.859 -18611.728 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-190218.2 -46603.078 -216869.71 -53132.646 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-543033.73 -133042.18 -619118.31 -151682.75 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1550249.3 -379807.97 -1767455.1 -433022.95 MAarrowhead1
% End of user PostScript
0 1 .244 r
.50647 .42681 m
.50554 .43897 L
.50479 .44913 L
.50419 .4576 L
.50371 .46468 L
.50334 .47059 L
.50307 .47553 L
.50289 .47966 L
.50277 .48312 L
.50273 .48602 L
.50276 .48845 L
.50284 .4905 L
.50299 .49223 L
.5032 .49369 L
.50348 .49493 L
.50382 .496 L
.50424 .49692 L
.50473 .49772 L
.50531 .49843 L
.50598 .49907 L
.50676 .49966 L
.50766 .50021 L
.50869 .50074 L
.50988 .50126 L
.51123 .50178 L
.51278 .50232 L
.51455 .50289 L
.51657 .5035 L
.51888 .50416 L
.52152 .50488 L
.52452 .50568 L
.52795 .50658 L
.53186 .50758 L
.53632 .50871 L
.5414 .50999 L
.5472 .51143 L
.55381 .51307 L
.56134 .51494 L
.56994 .51706 L
.57973 .51947 L
.5909 .52222 L
.60364 .52535 L
.61816 .52891 L
.63471 .53297 L
.65359 .5376 L
.67511 .54288 L
.69964 .54889 L
.72761 .55575 L
.7595 .56356 L
.79586 .57247 L
Mistroke
.83731 .58263 L
.88457 .59421 L
.93845 .60741 L
.99989 .62247 L
Mfstroke
.99989 .62247 m
1 .62249 L
s
1 0 0 r
.50647 .42681 m
.50554 .43897 L
s
% Start of user PostScript
0.77589817 -8.7823644 0.66494642 -7.3230901 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50479 .44913 m
.50419 .4576 L
s
% Start of user PostScript
0.57484051 -6.1049684 0.50247227 -5.0879632 MAarrowhead1
% End of user PostScript
1 .473 0 r
.50276 .48845 m
.50284 .4905 L
s
% Start of user PostScript
0.33088786 -1.3854794 0.34134476 -1.1399564 MAarrowhead1
% End of user PostScript
1 .788 0 r
.50531 .49843 m
.50598 .49907 L
s
% Start of user PostScript
0.63698363 -0.18829278 0.71780114 -0.11144415 MAarrowhead1
% End of user PostScript
.897 1 0 r
.51455 .50289 m
.51657 .5035 L
s
% Start of user PostScript
1.7462231 0.34696545 1.9889073 0.41981788 MAarrowhead1
% End of user PostScript
.581 1 0 r
.5414 .50999 m
.5472 .51143 L
s
% Start of user PostScript
4.9681459 1.1982005 5.6637692 1.3717721 MAarrowhead1
% End of user PostScript
.266 1 0 r
.61816 .52891 m
.63471 .53297 L
s
% Start of user PostScript
14.17905 3.4693809 16.16557 3.956813 MAarrowhead1
% End of user PostScript
0 1 .049 r
.83731 .58263 m
.88457 .59421 L
s
% Start of user PostScript
40.477327 9.9158173 46.148589 11.305439 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
115.5542 28.310302 131.74452 32.276939 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
329.88336 80.820705 376.10339 92.144529 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
941.74894 230.72659 1073.6976 263.05375 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
2688.499 658.67686 3065.1852 750.96423 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
7675.1101 1880.3866 8750.4715 2143.848 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
21910.856 5368.1159 24980.791 6120.2439 MAarrowhead1
% End of user PostScript
.2 1 0 r
.49019 .53126 m
.48965 .52555 L
.48888 .52071 L
.4879 .51659 L
.48668 .51305 L
.48521 .50999 L
.48348 .50731 L
.48144 .50493 L
.47907 .50278 L
.47633 .5008 L
.47318 .49893 L
.46955 .49713 L
.4654 .49535 L
.46065 .49355 L
.45521 .49169 L
.449 .48973 L
.44191 .48762 L
.43382 .48533 L
.42458 .48281 L
.41405 .48002 L
.40203 .4769 L
.38832 .47339 L
.3727 .46944 L
.35487 .46497 L
.33455 .4599 L
.31138 .45415 L
.28496 .44762 L
.25484 .44019 L
.2205 .43173 L
.18135 .42211 L
.1367 .41114 L
.0858 .39865 L
.02777 .38441 L
s
.02777 .38441 m
0 .3776 L
s
1 0 0 r
.49019 .53126 m
.48965 .52555 L
s
% Start of user PostScript
-1.1766061 3.7517266 -1.2425538 3.0662684 MAarrowhead1
% End of user PostScript
1 .158 0 r
.48888 .52071 m
.4879 .51659 L
s
% Start of user PostScript
-1.3341273 2.4854143 -1.4522024 1.99058 MAarrowhead1
% End of user PostScript
1 .473 0 r
.47318 .49893 m
.46955 .49713 L
s
% Start of user PostScript
-3.2187364 -0.12824806 -3.653548 -0.34417315 MAarrowhead1
% End of user PostScript
1 .788 0 r
.42458 .48281 m
.41405 .48002 L
s
% Start of user PostScript
-9.0503119 -2.0622581 -10.314557 -2.3976827 MAarrowhead1
% End of user PostScript
.897 1 0 r
.28496 .44762 m
.25484 .44019 L
s
% Start of user PostScript
-25.804249 -6.2855829 -29.418797 -7.1771714 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-73.658173 -18.037557 -83.978228 -20.567365 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-210.2771 -51.515461 -239.73902 -58.733906 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-600.29733 -147.07117 -684.40511 -167.67749 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-1713.725 -419.85908 -1953.8354 -478.68566 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-4892.3313 -1198.6114 -5577.797 -1366.5491 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-13966.597 -3421.7883 -15923.46 -3901.2158 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-39871.753 -9768.4998 -45458.194 -11137.167 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-113825.63 -27887.052 -129773.77 -31794.313 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-324948.7 -79611.782 -370477.34 -90766.207 MAarrowhead1
% End of user PostScript
0 1 .172 r
.49661 .49589 m
.49606 .4963 L
.49544 .4966 L
.49475 .49681 L
.49396 .49693 L
.49308 .49698 L
.49208 .49695 L
.49094 .49686 L
.48965 .49669 L
.48818 .49646 L
.48651 .49616 L
.4846 .49578 L
.48243 .49532 L
.47996 .49478 L
.47715 .49414 L
.47394 .4934 L
.47028 .49254 L
.46611 .49155 L
.46136 .49041 L
.45595 .4891 L
.44977 .48761 L
.44273 .4859 L
.43471 .48394 L
.42556 .48171 L
.41512 .47916 L
.40323 .47626 L
.38967 .47294 L
.37421 .46916 L
.35659 .46484 L
.33649 .45992 L
.31359 .45431 L
.28747 .44792 L
.25769 .44062 L
.22374 .43231 L
.18503 .42283 L
.1409 .41202 L
.09058 .39969 L
.03322 .38564 L
s
.03322 .38564 m
0 .3775 L
s
1 0 0 r
.49661 .49589 m
.49606 .4963 L
s
% Start of user PostScript
-0.40625305 -0.49334314 -0.47281453 -0.44440817 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49544 .4966 m
.49475 .49681 L
s
% Start of user PostScript
-0.54710469 -0.40817536 -0.63047103 -0.38318417 MAarrowhead1
% End of user PostScript
1 .473 0 r
.48651 .49616 m
.4846 .49578 L
s
% Start of user PostScript
-1.6193757 -0.46111228 -1.8478427 -0.50642238 MAarrowhead1
% End of user PostScript
1 .788 0 r
.46136 .49041 m
.45595 .4891 L
s
% Start of user PostScript
-4.636486 -1.1510438 -5.2864751 -1.3077859 MAarrowhead1
% End of user PostScript
.897 1 0 r
.38967 .47294 m
.37421 .46916 L
s
% Start of user PostScript
-13.239382 -3.2471709 -15.094441 -3.7010688 MAarrowhead1
% End of user PostScript
.581 1 0 r
.18503 .42283 m
.1409 .41202 L
s
% Start of user PostScript
-37.796449 -9.2608875 -43.092138 -10.558183 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-107.90124 -26.435784 -123.01931 -30.139649 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-308.03583 -75.468207 -351.1948 -86.042061 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-879.37877 -215.44605 -1002.5887 -245.63224 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-2510.445 -615.054 -2862.184 -701.22936 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-7166.8027 -1755.8523 -8170.9451 -2001.8652 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-20459.744 -5012.5962 -23326.363 -5714.9122 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-58408.348 -14309.928 -66591.955 -16314.896 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-166743.79 -40851.894 -190106.3 -46575.663 MAarrowhead1
% End of user PostScript
1 0 .571 r
.56237 .50984 m
.57097 .51285 L
.58081 .51601 L
.59204 .51939 L
.60486 .52305 L
.61948 .52707 L
.63617 .53153 L
.6552 .53649 L
.67691 .54207 L
.70167 .54834 L
.7299 .55543 L
.76209 .56347 L
.79879 .57258 L
.84064 .58294 L
.88835 .59471 L
.94275 .60811 L
s
.94275 .60811 m
1 .62219 L
s
1 0 0 r
.56237 .50984 m
.57097 .51285 L
s
% Start of user PostScript
7.4843488 1.1807454 8.5169983 1.5419086 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58081 .51601 m
.59204 .51939 L
s
% Start of user PostScript
9.6969806 1.9212482 11.0445 2.326683 MAarrowhead1
% End of user PostScript
1 .473 0 r
.7299 .55543 m
.76209 .56347 L
s
% Start of user PostScript
27.587542 6.6521754 31.450226 7.6162051 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
78.734357 19.264702 89.765233 21.971396 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
224.7651 55.061115 256.25684 62.777504 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
641.65676 157.20324 731.5594 179.22944 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1831.7974 448.78637 2088.451 511.66603 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5229.4037 1281.1934 5962.0967 1460.7017 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
14928.869 3657.543 17020.556 4170.0022 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
42618.842 10441.531 48590.178 11904.496 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
121668. 29808.417 138714.94 33984.882 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
347337.06 85096.884 396002.53 97019.828 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
991575.66 242934.05 1130505.6 276971.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2830744. 693526.62 3227360.2 790696.79 MAarrowhead1
% End of user PostScript
.47 1 0 r
.48212 .58127 m
.48172 .56698 L
.4809 .55494 L
.47969 .54477 L
.47806 .53613 L
.476 .52875 L
.47349 .52239 L
.47048 .51687 L
.46693 .51201 L
.46279 .50766 L
.45799 .50371 L
.45245 .50003 L
.44607 .49653 L
.43875 .49313 L
.43037 .48972 L
.42078 .48625 L
.40982 .48263 L
.3973 .47878 L
.38301 .47462 L
.3667 .47008 L
.34809 .46507 L
.32686 .45949 L
.30265 .45324 L
.27503 .44621 L
.24354 .43828 L
.20764 .4293 L
.1667 .41911 L
.12002 .40755 L
.0668 .3944 L
.00611 .37945 L
s
.00611 .37945 m
0 .37794 L
s
1 0 0 r
.48212 .58127 m
.48172 .56698 L
s
% Start of user PostScript
-2.1451464 9.7522513 -2.1940828 8.0375489 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4809 .55494 m
.47969 .54477 L
s
% Start of user PostScript
-2.2915615 6.5930403 -2.4374775 5.3720183 MAarrowhead1
% End of user PostScript
1 .473 0 r
.45799 .50371 m
.45245 .50003 L
s
% Start of user PostScript
-5.0411642 0.44483029 -5.7063555 0.0035516634 MAarrowhead1
% End of user PostScript
1 .788 0 r
.38301 .47462 m
.3667 .47008 L
s
% Start of user PostScript
-14.039095 -3.0450999 -15.996459 -3.5899983 MAarrowhead1
% End of user PostScript
.897 1 0 r
.1667 .41911 m
.12002 .40755 L
s
% Start of user PostScript
-39.995979 -9.7063158 -45.597557 -11.094035 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-114.16084 -27.94743 -130.15541 -31.869671 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-325.9011 -79.84001 -371.56305 -91.027943 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-930.37934 -227.93988 -1060.735 -259.87695 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2656.0409 -650.72442 -3028.1794 -741.89765 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-7582.4489 -1857.6847 -8644.8275 -2117.9654 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-21646.328 -5303.3069 -24679.2 -6046.3545 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-61795.801 -15139.848 -70454.025 -17261.095 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-176414.27 -43221.142 -201131.71 -49276.866 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-503626.35 -123387.45 -574189.55 -140675.29 MAarrowhead1
% End of user PostScript
1 .943 0 r
.44691 .43241 m
.43814 .4393 L
.42835 .44445 L
.41739 .44806 L
.40503 .45028 L
.39108 .45125 L
.37528 .45103 L
.35735 .44969 L
.33699 .44725 L
.31384 .4437 L
.28749 .43901 L
.2575 .43314 L
.22334 .42601 L
.18443 .4175 L
.14009 .4075 L
.08955 .39583 L
.03196 .38232 L
s
.03196 .38232 m
0 .37473 L
s
1 0 0 r
.44691 .43241 m
.43814 .4393 L
s
% Start of user PostScript
-6.3706274 -8.1113406 -7.4235875 -7.2840914 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42835 .44445 m
.41739 .44806 L
s
% Start of user PostScript
-8.5975098 -6.6662653 -9.9137438 -6.2333076 MAarrowhead1
% End of user PostScript
1 .473 0 r
.28749 .43901 m
.2575 .43314 L
s
% Start of user PostScript
-25.500632 -7.3182897 -29.099744 -8.0226856 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-73.02364 -18.142048 -83.261153 -20.608569 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-208.52017 -51.146054 -237.73742 -58.294443 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-595.29445 -145.85981 -678.70163 -166.29211 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1699.4458 -416.36407 -1937.5556 -474.69996 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4851.5679 -1188.6252 -5531.3222 -1355.1635 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-13850.226 -3393.2778 -15790.784 -3868.7107 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-39539.538 -9687.1078 -45079.432 -11044.371 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-112877.23 -27654.695 -128692.48 -31529.4 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-322241.2 -78948.45 -367390.49 -90009.935 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-919932.17 -225381.54 -1048824.1 -256959.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2626216.6 -643417.81 -2994176.4 -733567.23 MAarrowhead1
% End of user PostScript
.892 1 0 r
.51096 .42901 m
.51069 .44115 L
.51068 .45133 L
.51092 .45989 L
.5114 .4671 L
.51213 .47319 L
.5131 .47836 L
.51432 .48278 L
.51582 .48658 L
.51761 .48988 L
.51973 .49279 L
.5222 .49539 L
.52506 .49776 L
.52837 .49996 L
.53217 .50205 L
.53654 .50408 L
.54154 .50612 L
.54726 .50819 L
.5538 .51035 L
.56127 .51265 L
.56979 .51513 L
.57952 .51784 L
.59063 .52083 L
.60329 .52416 L
.61773 .52789 L
.63421 .53208 L
.65299 .53682 L
.67441 .54218 L
.69883 .54825 L
.72668 .55515 L
.75843 .56299 L
.79463 .57192 L
.8359 .58207 L
.88296 .59364 L
.93661 .60681 L
.99778 .62183 L
s
.99778 .62183 m
1 .62237 L
s
1 0 0 r
.51096 .42901 m
.51069 .44115 L
s
% Start of user PostScript
1.3146347 -8.5182857 1.2823992 -7.0616092 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51068 .45133 m
.51092 .45989 L
s
% Start of user PostScript
1.2815028 -5.8398891 1.3103963 -4.8133079 MAarrowhead1
% End of user PostScript
1 .473 0 r
.51973 .49279 m
.5222 .49539 L
s
% Start of user PostScript
2.3675508 -0.86491109 2.6638936 -0.55292338 MAarrowhead1
% End of user PostScript
1 .788 0 r
.5538 .51035 m
.56127 .51265 L
s
% Start of user PostScript
6.4557651 1.2423665 7.3519775 1.5181454 MAarrowhead1
% End of user PostScript
.897 1 0 r
.65299 .53682 m
.67441 .54218 L
s
% Start of user PostScript
18.358707 4.4181812 20.929 5.0610958 MAarrowhead1
% End of user PostScript
.581 1 0 r
.93661 .60681 m
.99778 .62183 L
s
% Start of user PostScript
52.393612 12.817624 59.734035 14.619112 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
149.56903 36.639722 170.52508 41.774638 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
426.98782 104.61013 486.81316 119.26739 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
1218.9619 298.64299 1389.751 340.48601 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
3479.8849 852.56478 3967.4524 972.01784 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
9934.3536 2433.8967 11326.258 2774.9106 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
28360.531 6948.2733 32334.131 7921.7974 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
80963.466 19835.887 92307.276 22615.098 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
231134. 56627.367 263518.23 64561.44 MAarrowhead1
% End of user PostScript
0 1 .465 r
.47044 .51876 m
.46694 .5136 L
.46284 .509 L
.45807 .50483 L
.45257 .50098 L
.44623 .49734 L
.43896 .49382 L
.43062 .49032 L
.42108 .48677 L
.41017 .48309 L
.39771 .47919 L
.38348 .475 L
.36724 .47043 L
.34871 .4654 L
.32757 .45982 L
.30347 .45357 L
.27597 .44655 L
.24462 .43863 L
.20887 .42967 L
.1681 .41952 L
.12162 .40799 L
.06862 .39489 L
.00819 .37999 L
s
.00819 .37999 m
0 .37798 L
s
1 0 0 r
.47044 .51876 m
.46694 .5136 L
s
% Start of user PostScript
-3.5467885 2.2517284 -3.9673295 1.6316964 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46284 .509 m
.45807 .50483 L
s
% Start of user PostScript
-4.4594498 1.0797784 -5.0310814 0.57984152 MAarrowhead1
% End of user PostScript
1 .473 0 r
.39771 .47919 m
.38348 .475 L
s
% Start of user PostScript
-12.275125 -2.4973059 -13.982508 -3.0001149 MAarrowhead1
% End of user PostScript
1 .788 0 r
.20887 .42967 m
.1681 .41952 L
s
% Start of user PostScript
-34.935954 -8.4394706 -39.827906 -9.657831 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-99.70982 -24.400584 -113.6795 -27.827786 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-284.64507 -69.73087 -324.5266 -79.502857 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-812.60159 -199.08421 -926.45534 -226.97841 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2319.8096 -568.34835 -2644.8387 -647.97987 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6622.5779 -1622.5182 -7550.4688 -1849.8497 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-18906.094 -4631.9552 -21555.031 -5280.9395 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-53972.999 -13223.277 -61535.168 -15075.993 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-154081.78 -37749.728 -175670.21 -43038.851 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-439871.7 -107767.69 -501502.23 -122867.04 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1255743. -307654.52 -1431685.4 -350760.07 MAarrowhead1
% End of user PostScript
0 1 .593 r
.55317 .52888 m
.56101 .52817 L
.56988 .52815 L
.57994 .52879 L
.59136 .53006 L
.60435 .53197 L
.61913 .53453 L
.63595 .53777 L
.65511 .54172 L
.67693 .54645 L
.7018 .55203 L
.73014 .55854 L
.76244 .5661 L
.79925 .57482 L
.84121 .58485 L
.88905 .59636 L
.94359 .60955 L
s
.94359 .60955 m
1 .62324 L
s
1 0 0 r
.55317 .52888 m
.56101 .52817 L
s
% Start of user PostScript
6.3802329 3.4650902 7.320732 3.3804174 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56988 .52815 m
.57994 .52879 L
s
% Start of user PostScript
8.3852907 3.37834 9.5925688 3.4547816 MAarrowhead1
% End of user PostScript
1 .473 0 r
.7018 .55203 m
.73014 .55854 L
s
% Start of user PostScript
24.215999 6.2437439 27.616519 7.0253625 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
69.196893 17.026095 78.893872 19.389742 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
197.55817 48.418495 225.23851 55.197284 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
563.99142 138.18079 643.01249 157.54013 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1610.08 394.46733 1835.6687 449.73595 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4596.4466 1126.1204 5240.4558 1283.9014 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
13121.907 3214.841 14960.42 3665.2731 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
37460.338 9177.7079 42708.915 10463.599 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
106941.54 26200.463 121925.14 29871.416 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
305296.04 74796.919 348071.14 85276.732 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
871557.23 213529.78 993671.31 243447.48 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2488116.1 609583.47 2836726.6 694992.35 MAarrowhead1
% End of user PostScript
1 0 .984 r
.56585 .5233 m
.57525 .52442 L
.58594 .52604 L
.5981 .5282 L
.61195 .5309 L
.62772 .53419 L
.64569 .53811 L
.66616 .54273 L
.68949 .54811 L
.71608 .55434 L
.74639 .56154 L
.78094 .56981 L
.82032 .57929 L
.86522 .59016 L
.91641 .60259 L
.97477 .61679 L
s
.97477 .61679 m
1 .62294 L
s
1 0 0 r
.56585 .5233 m
.57525 .52442 L
s
% Start of user PostScript
7.9018397 2.7958641 9.030021 2.9298027 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58594 .52604 m
.5981 .5282 L
s
% Start of user PostScript
10.312784 3.1252154 11.772366 3.3836399 MAarrowhead1
% End of user PostScript
1 .473 0 r
.74639 .56154 m
.78094 .56981 L
s
% Start of user PostScript
29.566439 7.3842737 33.712441 8.3767501 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
84.43557 20.719549 96.266665 23.612676 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
241.05306 59.065267 274.82725 67.338592 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
688.1584 168.59925 784.57647 192.22118 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1964.5507 481.31141 2239.8043 548.74793 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5608.3871 1374.0437 6394.1795 1566.5613 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
16010.788 3922.6111 18254.064 4472.2091 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
45707.499 11198.246 52111.587 12767.234 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
130485.48 31968.682 148767.83 36447.821 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
372509.14 91263.993 424701.48 104051.01 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1063436.8 260539.88 1212435.1 297044.18 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3035892.6 743787.61 3461252.2 847999.87 MAarrowhead1
% End of user PostScript
.856 1 0 r
.45311 .56244 m
.44835 .54903 L
.44262 .53741 L
.43584 .52722 L
.42791 .51816 L
.41868 .50997 L
.40802 .5024 L
.39575 .49526 L
.38165 .48836 L
.36549 .48153 L
.347 .4746 L
.32586 .46742 L
.3017 .45983 L
.27413 .45168 L
.24265 .44281 L
.20674 .43304 L
.16577 .42219 L
.11904 .41007 L
.06575 .39645 L
.00497 .38109 L
s
.00497 .38109 m
0 .37984 L
s
1 0 0 r
.45311 .56244 m
.44835 .54903 L
s
% Start of user PostScript
-5.6267646 7.4929162 -6.1979414 5.8832536 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44262 .53741 m
.43584 .52722 L
s
% Start of user PostScript
-6.8851277 4.4886568 -7.6986164 3.2662655 MAarrowhead1
% End of user PostScript
1 .473 0 r
.347 .4746 m
.32586 .46742 L
s
% Start of user PostScript
-18.360204 -3.0481746 -20.897156 -3.9099492 MAarrowhead1
% End of user PostScript
1 .788 0 r
.06575 .39645 m
.00497 .38109 L
s
% Start of user PostScript
-52.110424 -12.426473 -59.403292 -14.269618 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-148.69309 -36.349565 -169.52456 -41.466477 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-424.47134 -103.97586 -483.94366 -118.54957 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1211.7742 -296.87785 -1381.5561 -338.47479 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3459.3645 -847.53634 -3944.0568 -966.28517 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-9875.772 -2419.5441 -11259.469 -2758.5471 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-28193.292 -6907.3001 -32143.461 -7875.0835 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-80486.034 -19718.917 -91762.951 -22481.739 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-229771.03 -56293.442 -261964.3 -64180.729 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-655948.89 -160706.17 -747854.04 -183222.74 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1872598.8 -458782.96 -2134969. -523063.14 MAarrowhead1
% End of user PostScript
1 0 .675 r
.44764 .53886 m
.44157 .52881 L
.43444 .51992 L
.42614 .51193 L
.41652 .5046 L
.40544 .49773 L
.3927 .49115 L
.3781 .48468 L
.36137 .47817 L
.34225 .47148 L
.32039 .46445 L
.29544 .45693 L
.26695 .44878 L
.23444 .43985 L
.19735 .42995 L
.15505 .4189 L
.1068 .40652 L
.05178 .39256 L
s
.05178 .39256 m
0 .37955 L
s
1 0 0 r
.44764 .53886 m
.44157 .52881 L
s
% Start of user PostScript
-6.2828276 4.663645 -7.0112565 3.4575496 MAarrowhead1
% End of user PostScript
1 .158 0 r
.43444 .51992 m
.42614 .51193 L
s
% Start of user PostScript
-7.8669041 2.3905325 -8.8634271 1.4310432 MAarrowhead1
% End of user PostScript
1 .473 0 r
.32039 .46445 m
.29544 .45693 L
s
% Start of user PostScript
-21.552634 -4.2664855 -24.547557 -5.1682018 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-61.315649 -14.78415 -69.900771 -16.926927 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-174.9936 -42.817183 -199.51062 -48.833065 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-499.5589 -122.3778 -569.55189 -139.52812 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1426.1349 -349.39711 -1625.9509 -398.35214 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4071.3203 -997.46459 -4641.7539 -1137.2198 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-11622.779 -2847.5575 -13251.25 -3246.5295 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-33180.638 -8129.1899 -37829.585 -9268.1726 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-94723.879 -23207.161 -107995.66 -26458.721 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-270417.14 -66251.657 -308305.34 -75534.192 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-771985.15 -189134.82 -880148.17 -215634.54 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2203858.4 -539940.9 -2512641.5 -615592.14 MAarrowhead1
% End of user PostScript
1 .484 0 r
.57348 .48574 m
.58299 .49342 L
.59396 .50056 L
.60657 .50737 L
.62104 .51402 L
.63762 .52067 L
.65658 .52748 L
.67826 .53459 L
.70301 .54216 L
.73127 .55034 L
.76352 .55929 L
.80031 .56918 L
.84228 .58019 L
.89014 .59252 L
.94473 .6064 L
s
.94473 .6064 m
1 .62032 L
s
1 0 0 r
.57348 .48574 m
.58299 .49342 L
s
% Start of user PostScript
8.8178488 -1.7109788 9.9585419 -0.79015158 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59396 .50056 m
.60657 .50737 L
s
% Start of user PostScript
11.274759 0.067425394 12.788493 0.88474292 MAarrowhead1
% End of user PostScript
1 .473 0 r
.76352 .55929 m
.80031 .56918 L
s
% Start of user PostScript
31.621819 7.1145136 36.036867 8.3010218 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
90.141036 21.935796 102.76708 25.053766 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
257.3029 63.003809 293.35281 71.841745 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
734.5394 179.95249 837.45568 205.16813 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2096.9568 513.74828 2390.7618 585.73025 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5986.3786 1466.6503 6825.1315 1672.1432 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
17089.876 4186.9854 19484.343 4773.6249 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
48788.072 11952.98 55623.78 13627.715 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
139279.88 34123.293 158794.42 38904.315 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
397615.34 97414.962 453325.32 111063.8 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1135109.8 278099.63 1294150.3 317064.23 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3240504.3 793917.08 3694532.1 905152.98 MAarrowhead1
% End of user PostScript
0 .57 1 r
.48884 .56191 m
.48886 .5512 L
.48862 .54221 L
.48813 .53463 L
.48738 .52823 L
.48638 .5228 L
.48511 .51816 L
.48356 .51416 L
.4817 .5107 L
.47951 .50764 L
.47695 .50492 L
.47398 .50244 L
.47055 .50014 L
.46661 .49795 L
.46208 .49583 L
.45689 .49371 L
.45095 .49155 L
.44417 .48929 L
.43642 .4869 L
.42757 .48432 L
.41747 .48151 L
.40595 .4784 L
.39281 .47494 L
.37782 .47107 L
.36073 .46672 L
.34123 .4618 L
.31901 .45624 L
.29366 .44993 L
.26476 .44277 L
.23182 .43463 L
.19425 .42537 L
.15142 .41483 L
.10258 .40283 L
.0469 .38916 L
s
.0469 .38916 m
0 .37764 L
s
1 0 0 r
.48884 .56191 m
.48886 .5512 L
s
% Start of user PostScript
-1.3390451 7.4290188 -1.3367507 6.1444737 MAarrowhead1
% End of user PostScript
1 .158 0 r
.48862 .54221 m
.48813 .53463 L
s
% Start of user PostScript
-1.3655967 5.0652015 -1.424734 4.1561391 MAarrowhead1
% End of user PostScript
1 .473 0 r
.47695 .50492 m
.47398 .50244 L
s
% Start of user PostScript
-2.7658036 0.59027702 -3.1222805 0.2928904 MAarrowhead1
% End of user PostScript
1 .788 0 r
.43642 .4869 m
.42757 .48432 L
s
% Start of user PostScript
-7.6298367 -1.5715869 -8.6915664 -1.8810295 MAarrowhead1
% End of user PostScript
.897 1 0 r
.31901 .45624 m
.29366 .44993 L
s
% Start of user PostScript
-21.719161 -5.2512476 -24.760526 -6.0079568 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-61.989061 -15.170782 -70.673961 -17.301285 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-176.96254 -43.351615 -201.75671 -49.426775 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-505.19075 -123.76982 -575.97312 -141.11151 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-1442.2152 -353.33963 -1644.2843 -402.84619 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-4117.2269 -1008.7123 -4694.0925 -1150.0432 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-11753.834 -2879.6657 -13400.666 -3283.1363 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-33554.771 -8220.8517 -38256.138 -9372.6771 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-95791.95 -23468.836 -109213.38 -26757.06 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-273466.26 -66998.687 -311781.68 -76385.888 MAarrowhead1
% End of user PostScript
0 1 .859 r
.56884 .50205 m
.57813 .50678 L
.58877 .51143 L
.60095 .51613 L
.61489 .52097 L
.63081 .52606 L
.64899 .5315 L
.66974 .53742 L
.69342 .54391 L
.72044 .5511 L
.75125 .55913 L
.7864 .56815 L
.82647 .5783 L
.87217 .58978 L
.92429 .60278 L
.9837 .61753 L
s
.9837 .61753 m
1 .62156 L
s
1 0 0 r
.56884 .50205 m
.57813 .50678 L
s
% Start of user PostScript
8.2611067 0.24559442 9.3750345 0.81312349 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58877 .51143 m
.60095 .51613 L
s
% Start of user PostScript
10.652248 1.371848 12.11443 1.9351664 MAarrowhead1
% End of user PostScript
1 .473 0 r
.75125 .55913 m
.7864 .56815 L
s
% Start of user PostScript
30.150294 7.096089 34.367542 8.1774618 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
86.011897 21.004491 98.061372 23.967896 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
245.53191 60.1388 279.93305 68.569666 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
700.9396 171.72504 799.14831 195.7866 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2001.0372 490.24922 2281.4029 558.93842 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5712.5483 1399.5627 6512.9347 1595.6558 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
16308.147 3995.4634 18593.085 4555.2687 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
46556.396 11406.224 53079.424 13004.353 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
132908.91 32562.417 151530.81 37124.745 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
379427.53 92958.984 432589.2 105983.49 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1083187.3 265378.73 1234953. 302561. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3092276.4 757601.53 3525536. 863749.26 MAarrowhead1
% End of user PostScript
1 0 .514 r
.46788 .5059 m
.46371 .5026 L
.45891 .49952 L
.45339 .49658 L
.44705 .4937 L
.43979 .49082 L
.4315 .48786 L
.42201 .48477 L
.41118 .48147 L
.39881 .47791 L
.3847 .474 L
.3686 .46969 L
.35024 .46488 L
.32929 .45948 L
.30541 .45342 L
.27817 .44656 L
.24711 .4388 L
.2117 .43 L
.17132 .42 L
.12528 .40864 L
.07279 .3957 L
.01294 .38098 L
s
.01294 .38098 m
0 .3778 L
s
1 0 0 r
.46788 .5059 m
.46371 .5026 L
s
% Start of user PostScript
-3.8549762 0.70791394 -4.3546445 0.311749 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45891 .49952 m
.45339 .49658 L
s
% Start of user PostScript
-4.9310233 -0.057858457 -5.5937502 -0.41078295 MAarrowhead1
% End of user PostScript
1 .473 0 r
.3847 .474 m
.3686 .46969 L
s
% Start of user PostScript
-13.835774 -3.1196565 -15.767695 -3.6377172 MAarrowhead1
% End of user PostScript
1 .788 0 r
.17132 .42 m
.12528 .40864 L
s
% Start of user PostScript
-39.441626 -9.5997033 -44.966249 -10.963731 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-112.58441 -27.568064 -128.35827 -31.435095 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-321.40213 -78.739383 -366.43378 -89.772624 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-917.53607 -224.79368 -1046.0922 -256.28982 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2619.3761 -641.7417 -2986.3775 -731.65634 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7477.7784 -1832.0407 -8525.4917 -2088.7284 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-21347.515 -5230.0985 -24338.52 -5962.8888 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-60942.753 -14930.852 -69481.456 -17022.818 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-173978.99 -42624.504 -198355.23 -48596.633 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-496674.13 -121684.17 -566263.26 -138733.37 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1417902.2 -347383.2 -1616564.8 -396055.14 MAarrowhead1
% End of user PostScript
1 .632 0 r
.4455 .43108 m
.4365 .43808 L
.42647 .4433 L
.41522 .44696 L
.40255 .4492 L
.38824 .45015 L
.37203 .4499 L
.35364 .4485 L
.33275 .44598 L
.309 .44232 L
.28197 .4375 L
.2512 .43147 L
.21616 .42414 L
.17623 .4154 L
.13074 .40513 L
.0789 .39316 L
.0198 .37929 L
s
.0198 .37929 m
0 .37459 L
s
1 0 0 r
.4455 .43108 m
.4365 .43808 L
s
% Start of user PostScript
-6.5402189 -8.270537 -7.6198208 -7.4303246 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42647 .4433 m
.41522 .44696 L
s
% Start of user PostScript
-8.8236404 -6.8035617 -10.173563 -6.3652902 MAarrowhead1
% End of user PostScript
1 .473 0 r
.28197 .4375 m
.2512 .43147 L
s
% Start of user PostScript
-26.163367 -7.4998878 -29.855806 -8.2239629 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-74.919646 -18.611081 -85.42292 -21.141964 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-213.93382 -52.473448 -243.90961 -59.807501 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-610.74954 -149.64652 -696.32214 -170.6093 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1743.5669 -427.17372 -1987.8586 -487.02413 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4977.5246 -1219.4844 -5674.9268 -1390.3463 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-14209.806 -3481.3743 -16200.746 -3969.1504 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-40566.067 -9938.6052 -46249.787 -11331.105 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-115807.75 -28372.668 -132033.6 -32347.969 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-330607.25 -80998.115 -376928.71 -92346.779 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-943815.51 -231232.91 -1076053.7 -263631.01 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2694398.6 -660122.27 -3071911.4 -752612.16 MAarrowhead1
% End of user PostScript
.233 0 1 r
.4402 .50303 m
.43225 .49815 L
.42312 .49347 L
.41265 .48887 L
.40066 .48423 L
.38696 .47945 L
.37129 .47443 L
.35341 .46906 L
.33299 .46323 L
.30969 .45684 L
.28311 .44975 L
.25279 .44184 L
.21821 .43297 L
.17878 .42298 L
.13382 .41169 L
.08255 .39889 L
.02408 .38438 L
s
.02408 .38438 m
0 .37842 L
s
1 0 0 r
.4402 .50303 m
.43225 .49815 L
s
% Start of user PostScript
-7.1761611 0.36306905 -8.1296833 -0.22196119 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42312 .49347 m
.41265 .48887 L
s
% Start of user PostScript
-9.2254071 -0.78361131 -10.481831 -1.3360585 MAarrowhead1
% End of user PostScript
1 .473 0 r
.28311 .44975 m
.25279 .44184 L
s
% Start of user PostScript
-26.026894 -6.0298249 -29.66504 -6.9786027 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-74.228685 -18.10447 -84.62689 -20.665496 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-211.89051 -51.893635 -241.57807 -59.170195 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-604.89969 -148.19473 -689.65222 -168.95967 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1726.8629 -423.07691 -1968.8141 -482.35462 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4929.8373 -1207.8 -5620.5579 -1377.0252 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-14073.669 -3448.0206 -16045.533 -3931.1235 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-40177.421 -9843.3877 -45806.689 -11222.547 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-114698.25 -28100.842 -130768.65 -32038.057 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-327439.85 -80222.108 -373317.52 -91462.046 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-934773.24 -229017.57 -1065744.5 -261105.28 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2668584.8 -653797.93 -3042480.8 -745401.71 MAarrowhead1
% End of user PostScript
0 1 .547 r
.45888 .51653 m
.45377 .51087 L
.44784 .50574 L
.44098 .50099 L
.43309 .4965 L
.42403 .49214 L
.41365 .48782 L
.40177 .48342 L
.38819 .47885 L
.37268 .47402 L
.35497 .46882 L
.33475 .46314 L
.31169 .45689 L
.28538 .44994 L
.25537 .44217 L
.22115 .43344 L
.18212 .42359 L
.13762 .41244 L
.08687 .39981 L
.02901 .38546 L
s
.02901 .38546 m
0 .37829 L
s
1 0 0 r
.45888 .51653 m
.45377 .51087 L
s
% Start of user PostScript
-4.9344018 1.983376 -5.5476085 1.3042777 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44784 .50574 m
.44098 .50099 L
s
% Start of user PostScript
-6.2596793 0.68857413 -7.0823211 0.11888193 MAarrowhead1
% End of user PostScript
1 .473 0 r
.35497 .46882 m
.33475 .46314 L
s
% Start of user PostScript
-17.403953 -3.7421537 -19.82965 -4.4228875 MAarrowhead1
% End of user PostScript
1 .788 0 r
.08687 .39981 m
.02901 .38546 L
s
% Start of user PostScript
-49.575243 -12.023319 -56.518242 -13.744637 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-141.50139 -34.638791 -161.32648 -39.500664 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-403.95126 -98.960496 -460.5488 -112.8279 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1153.1961 -282.52916 -1314.7707 -322.11486 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3292.1368 -806.56654 -3753.3988 -919.57488 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-9398.3714 -2302.5821 -10715.179 -2625.1974 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-26830.412 -6573.3972 -30589.627 -7494.3974 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-76595.292 -18765.693 -87327.076 -21394.959 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-218663.76 -53572.184 -249300.79 -61078.195 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-624239.94 -152937.54 -711702.34 -174365.65 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1782076.3 -436605.12 -2031763.4 -497777.97 MAarrowhead1
% End of user PostScript
1 0 .307 r
.51207 .4212 m
.51176 .43467 L
.51174 .44596 L
.51199 .45545 L
.51251 .46345 L
.51329 .4702 L
.51434 .47594 L
.51568 .48083 L
.51731 .48504 L
.51927 .4887 L
.52158 .49192 L
.52427 .4948 L
.5274 .49741 L
.53101 .49984 L
.53517 .50214 L
.53994 .50438 L
.5454 .50661 L
.55165 .50889 L
.55879 .51127 L
.56695 .51379 L
.57627 .5165 L
.5869 .51947 L
.59903 .52274 L
.61287 .52639 L
.62866 .53046 L
.64666 .53505 L
.66718 .54022 L
.69059 .54608 L
.71728 .55272 L
.74771 .56026 L
.7824 .56883 L
.82196 .57858 L
.86707 .58968 L
.91849 .60232 L
.97712 .61672 L
s
.97712 .61672 m
1 .62234 L
s
1 0 0 r
.51207 .4212 m
.51176 .43467 L
s
% Start of user PostScript
1.4486282 -9.4558644 1.4114092 -7.8396426 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51174 .44596 m
.51199 .45545 L
s
% Start of user PostScript
1.4087668 -6.484218 1.4389535 -5.3454093 MAarrowhead1
% End of user PostScript
1 .473 0 r
.52158 .49192 m
.52427 .4948 L
s
% Start of user PostScript
2.589164 -0.96922908 2.9126739 -0.62430828 MAarrowhead1
% End of user PostScript
1 .788 0 r
.55879 .51127 m
.56695 .51379 L
s
% Start of user PostScript
7.0551532 1.3519723 8.0344343 1.6542728 MAarrowhead1
% End of user PostScript
.897 1 0 r
.66718 .54022 m
.69059 .54608 L
s
% Start of user PostScript
20.062025 4.8267456 22.870755 5.5295258 MAarrowhead1
% End of user PostScript
.581 1 0 r
.97712 .61672 m
0 0 rlineto s
.97712 .61672 m
1 .62234 L
s
% Start of user PostScript
57.254397 14.006454 65.275816 15.975124 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
163.44514 40.038858 186.34536 45.650173 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
466.60114 114.3152 531.97671 130.33227 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
1332.0498 326.34926 1518.6836 372.07421 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
3802.7274 931.66053 4335.5284 1062.1957 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
10856.002 2659.6988 12377.039 3032.3498 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
30991.648 7592.8916 35333.894 8656.7334 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
88474.762 21676.14 100870.98 24713.188 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
252577.2 61880.908 287965.85 70551.056 MAarrowhead1
% End of user PostScript
0 1 .484 r
.48328 .45023 m
.47981 .45695 L
.47605 .46234 L
.47192 .4666 L
.46733 .46987 L
.46222 .47228 L
.45647 .47393 L
.44999 .4749 L
.44267 .47523 L
.43438 .47498 L
.42497 .47415 L
.41427 .47277 L
.40211 .47082 L
.38826 .46829 L
.3725 .46515 L
.35455 .46135 L
.3341 .45684 L
.31079 .45154 L
.28423 .44538 L
.25395 .43826 L
.21944 .43004 L
.1801 .42061 L
.13526 .40979 L
.08413 .3974 L
.02585 .38324 L
s
.02585 .38324 m
0 .37695 L
s
1 0 0 r
.48328 .45023 m
.47981 .45695 L
s
% Start of user PostScript
-2.0069975 -5.9721741 -2.4223706 -5.1659973 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47605 .46234 m
.47192 .4666 L
s
% Start of user PostScript
-2.8737137 -4.5190509 -3.3697488 -4.0085522 MAarrowhead1
% End of user PostScript
1 .473 0 r
.42497 .47415 m
.41427 .47277 L
s
% Start of user PostScript
-9.0041201 -3.101772 -10.28762 -3.2678239 MAarrowhead1
% End of user PostScript
1 .788 0 r
.28423 .44538 m
.25395 .43826 L
s
% Start of user PostScript
-25.892811 -6.5540207 -29.525808 -7.4092519 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-73.962756 -18.170115 -84.326904 -20.701128 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-211.15877 -51.745074 -240.74456 -58.991611 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-602.81718 -147.69173 -687.2781 -168.38403 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1720.9193 -421.62242 -1962.0377 -480.69585 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-4912.8698 -1203.6434 -5601.2131 -1372.2861 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-14025.23 -3436.1533 -15990.308 -3917.5935 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-40039.139 -9809.5089 -45649.032 -11183.921 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-114303.48 -28004.125 -130318.57 -31927.789 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-326312.87 -79946.001 -372032.64 -91147.253 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-931555.95 -228229.34 -1062076.5 -260206.61 MAarrowhead1
% End of user PostScript
0 1 .654 r
.46513 .43223 m
.45879 .44049 L
.45181 .44697 L
.44405 .45189 L
.43537 .45547 L
.42561 .45783 L
.4146 .4591 L
.40214 .45936 L
.38802 .45866 L
.37199 .45704 L
.35378 .45449 L
.33305 .45102 L
.30946 .44658 L
.2826 .44112 L
.252 .43455 L
.21714 .42679 L
.17741 .4177 L
.13214 .40715 L
.08053 .39496 L
.0217 .38092 L
s
.0217 .38092 m
0 .37571 L
s
1 0 0 r
.46513 .43223 m
.45879 .44049 L
s
% Start of user PostScript
-4.1846673 -8.1322191 -4.9449746 -7.1410867 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45181 .44697 m
.44405 .45189 L
s
% Start of user PostScript
-5.7829836 -6.3640506 -6.7143565 -5.7726327 MAarrowhead1
% End of user PostScript
1 .473 0 r
.35378 .45449 m
.33305 .45102 L
s
% Start of user PostScript
-17.546991 -5.4606127 -20.033943 -5.8774641 MAarrowhead1
% End of user PostScript
1 .788 0 r
.08053 .39496 m
.0217 .38092 L
s
% Start of user PostScript
-50.336713 -12.605152 -57.396079 -14.289495 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-143.75815 -35.284504 -163.90171 -40.209024 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-410.4133 -100.56548 -467.91677 -114.65122 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1171.6485 -287.05507 -1335.8085 -327.27336 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3344.8155 -819.47394 -3813.4584 -934.29037 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-9548.7587 -2339.427 -10886.637 -2667.2045 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-27259.737 -6678.5809 -31079.105 -7614.3184 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-77820.926 -19065.971 -88724.433 -21737.309 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-222162.69 -54429.415 -253289.96 -62055.533 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-634228.67 -155384.75 -723090.59 -177155.75 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1810592. -443591.42 -2064274.5 -505743.12 MAarrowhead1
% End of user PostScript
0 1 .598 r
.53704 .50663 m
.54217 .5083 L
.54803 .51007 L
.55471 .51199 L
.56235 .51409 L
.57105 .51642 L
.58098 .51902 L
.59231 .52193 L
.60523 .52521 L
.61995 .52891 L
.63675 .5331 L
.6559 .53786 L
.67773 .54327 L
.70263 .54941 L
.73102 .55641 L
.76338 .56437 L
.80028 .57343 L
.84234 .58376 L
.89031 .59553 L
.94499 .60894 L
s
.94499 .60894 m
1 .62243 L
s
1 0 0 r
.53704 .50663 m
.54217 .5083 L
s
% Start of user PostScript
4.4446134 0.79610509 5.0601805 0.99542835 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54803 .51007 m
.55471 .51199 L
s
% Start of user PostScript
5.7631825 1.2081363 6.5656731 1.4385135 MAarrowhead1
% End of user PostScript
1 .473 0 r
.63675 .5331 m
.6559 .53786 L
s
% Start of user PostScript
16.40994 3.9725417 18.707969 4.5434832 MAarrowhead1
% End of user PostScript
1 .788 0 r
.89031 .59553 m
.94499 .60894 L
s
% Start of user PostScript
46.836955 11.463722 53.399016 13.073276 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
133.70749 32.755428 152.44121 37.34559 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
381.70675 93.51677 435.18775 106.61961 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1089.6939 266.97268 1242.3712 304.37833 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3110.8513 762.15232 3546.7134 868.93767 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
8880.839 2175.7878 10125.135 2480.6379 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
25352.964 6211.4253 28905.173 7081.7096 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
72377.482 17732.338 82518.308 20216.82 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
206622.78 50622.169 235572.75 57714.852 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
589865.43 144515.85 672511.61 164764. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1683944.2 412562.95 1919882. 470367.24 MAarrowhead1
% End of user PostScript
1 0 .046 r
.45786 .43971 m
.45074 .44624 L
.44282 .45121 L
.43395 .4548 L
.42399 .45717 L
.41274 .45842 L
.40002 .45865 L
.3856 .45791 L
.36923 .45623 L
.35062 .45361 L
.32945 .45005 L
.30536 .4455 L
.27792 .43991 L
.24667 .43319 L
.21105 .42525 L
.17047 .41596 L
.12422 .40518 L
.0715 .39272 L
.01141 .37838 L
s
.01141 .37838 m
0 .37564 L
s
1 0 0 r
.45786 .43971 m
.45074 .44624 L
s
% Start of user PostScript
-5.0562175 -7.2346261 -5.9114355 -6.4508248 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44282 .45121 m
.43395 .4548 L
s
% Start of user PostScript
-6.8621598 -5.8549859 -7.9258005 -5.4241118 MAarrowhead1
% End of user PostScript
1 .473 0 r
.32945 .45005 m
.30536 .4455 L
s
% Start of user PostScript
-20.46557 -5.9940462 -23.356999 -6.5400811 MAarrowhead1
% End of user PostScript
1 .788 0 r
.01141 .37838 m
0 0 rlineto s
.01141 .37838 m
0 .37564 L
s
% Start of user PostScript
-58.630558 -14.594484 -66.850933 -16.570336 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-167.42642 -41.07317 -190.8859 -46.811743 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-477.97923 -117.11664 -544.94933 -133.52208 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1364.5348 -334.31127 -1555.7201 -381.15081 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3895.466 -954.38208 -4441.2607 -1088.1006 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-11120.752 -2724.5622 -12678.883 -3106.3012 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-31747.454 -7778.0627 -36195.597 -8867.8489 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-90632.433 -22204.765 -103330.96 -25315.879 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-258736.9 -63390.024 -294988.59 -72271.615 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-738640.5 -180965.44 -842131.59 -206320.55 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2108666.3 -516619.02 -2404112. -589002.63 MAarrowhead1
% End of user PostScript
1 0 .714 r
.57869 .43297 m
.58761 .44945 L
.59812 .46396 L
.61039 .47692 L
.62464 .48871 L
.64107 .49967 L
.65999 .51008 L
.68169 .52022 L
.70655 .53034 L
.73499 .54066 L
.7675 .55143 L
.80464 .56287 L
.84703 .5752 L
.89542 .58868 L
.95062 .60356 L
s
.95062 .60356 m
1 .61655 L
s
1 0 0 r
.57869 .43297 m
.58761 .44945 L
s
% Start of user PostScript
9.4432579 -8.0434268 10.512795 -6.0655585 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59812 .46396 m
.61039 .47692 L
s
% Start of user PostScript
11.774193 -4.3249451 13.247373 -2.7696126 MAarrowhead1
% End of user PostScript
1 .473 0 r
.7675 .55143 m
.80464 .56287 L
s
% Start of user PostScript
32.100557 6.1717219 36.556729 7.5439278 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
91.285366 21.967242 104.06565 25.164237 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
260.51751 63.732937 297.0164 72.690552 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
743.70419 182.18412 847.90422 207.71655 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2123.1175 520.15439 2420.5878 593.03488 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6061.0614 1484.9467 6910.2781 1693.0033 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
17303.08 4239.2197 19727.419 4833.1778 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
49396.725 12102.099 56317.711 13797.726 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
141017.46 34548.996 160775.45 39389.664 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
402575.77 98630.257 458980.75 112449.37 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1149270.8 281569.04 1310295.4 321019.75 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3280931.1 803821.54 3740623.1 916445.16 MAarrowhead1
% End of user PostScript
1 0 .857 r
.56237 .52732 m
.5714 .52754 L
.58165 .52839 L
.5933 .52985 L
.60654 .53194 L
.62161 .53466 L
.63877 .53806 L
.65831 .54217 L
.68057 .54707 L
.70594 .55281 L
.73485 .55951 L
.76781 .56725 L
.80537 .57619 L
.84819 .58645 L
.897 .59822 L
.95265 .61169 L
s
.95265 .61169 m
1 .6232 L
s
1 0 0 r
.56237 .52732 m
.5714 .52754 L
s
% Start of user PostScript
7.4840688 3.2788951 8.5680475 3.3050242 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58165 .52839 m
.5933 .52985 L
s
% Start of user PostScript
9.7980406 3.406595 11.195477 3.5822856 MAarrowhead1
% End of user PostScript
1 .473 0 r
.73485 .55951 m
.76781 .56725 L
s
% Start of user PostScript
28.18243 7.1408752 32.136861 8.0705657 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
80.504581 19.778931 91.785454 22.533532 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
229.83561 56.322289 262.03825 64.209713 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
656.136 160.75506 748.06744 183.27758 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1873.1336 458.9147 2135.5788 523.21313 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5347.4102 1310.105 6096.6371 1493.664 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
15265.753 3740.079 17404.642 4264.1024 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
43580.577 10677.154 49686.662 12173.133 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
124413.56 30481.073 141845.17 34751.783 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
355175.05 87017.177 404938.71 99209.173 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1013951.5 248416.09 1156016.5 283221.73 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2894622.5 709176.71 3300188.7 808539.62 MAarrowhead1
% End of user PostScript
.936 0 1 r
.45999 .51237 m
.45493 .50745 L
.44906 .50295 L
.4423 .49874 L
.43454 .4947 L
.42563 .49074 L
.41543 .48676 L
.40376 .48266 L
.39043 .47836 L
.3752 .47377 L
.35782 .46879 L
.33799 .46333 L
.31537 .45729 L
.28956 .45055 L
.26013 .44299 L
.22656 .43447 L
.18828 .42485 L
.14464 .41396 L
.09487 .4016 L
.03813 .38755 L
s
.03813 .38755 m
0 .37814 L
s
1 0 0 r
.45999 .51237 m
.45493 .50745 L
s
% Start of user PostScript
-4.8013256 1.4838685 -5.408914 0.8943009 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44906 .50295 m
.4423 .49874 L
s
% Start of user PostScript
-6.1124212 0.35424524 -6.9234989 -0.1512489 MAarrowhead1
% End of user PostScript
1 .473 0 r
.35782 .46879 m
.33799 .46333 L
s
% Start of user PostScript
-17.06126 -3.7451682 -19.441073 -4.4002513 MAarrowhead1
% End of user PostScript
1 .788 0 r
.09487 .4016 m
.03813 .38755 L
s
% Start of user PostScript
-48.615172 -11.808525 -55.424155 -13.493626 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-138.76487 -33.973143 -158.20666 -38.740315 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-396.14006 -97.047893 -451.6432 -110.64698 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1130.897 -277.06618 -1289.3472 -315.88638 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3228.4774 -790.97019 -3680.8201 -901.79329 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-9216.637 -2258.0575 -10507.982 -2574.4345 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-26311.598 -6446.2888 -29998.122 -7349.4798 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-75114.185 -18402.825 -85638.45 -20981.249 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-214435.51 -52536.27 -244480.11 -59897.138 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-612169.14 -149980.21 -697940.3 -170993.98 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1747616.6 -428162.58 -1992475.6 -488152.54 MAarrowhead1
% End of user PostScript
0 .964 1 r
.55566 .58046 m
.56509 .5717 L
.57558 .56503 L
.5873 .5602 L
.60049 .557 L
.61536 .55528 L
.63218 .55492 L
.65125 .55586 L
.67291 .55805 L
.69752 .56148 L
.72551 .56617 L
.75737 .57217 L
.79366 .57955 L
.83499 .58842 L
.88208 .5989 L
.93574 .61117 L
.9969 .62542 L
s
.9969 .62542 m
1 .62616 L
s
1 0 0 r
.55566 .58046 m
.56509 .5717 L
s
% Start of user PostScript
6.6788151 9.6551551 7.8109025 8.6040388 MAarrowhead1
% End of user PostScript
1 .158 0 r
.57558 .56503 m
.5873 .5602 L
s
% Start of user PostScript
9.0690833 7.8039021 10.476413 7.223932 MAarrowhead1
% End of user PostScript
1 .473 0 r
.72551 .56617 m
.75737 .57217 L
s
% Start of user PostScript
27.06128 7.9406402 30.884931 8.6602879 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
77.529312 19.302281 88.399496 21.914469 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
221.39475 54.313533 252.41619 61.901752 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
632.05151 154.86832 720.60881 176.56187 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1804.3803 442.07354 2057.1925 504.01137 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5151.1344 1262.0185 5872.861 1438.84 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
14705.426 3602.8002 16765.807 4107.5894 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
41980.959 10285.251 47862.921 11726.32 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
119846.98 29362.27 136638.77 33476.225 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
342138.41 83823.226 390075.5 95567.717 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
976734.6 239298.02 1113585.1 272826.12 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2788375.8 683146.5 3179055.8 778862.31 MAarrowhead1
% End of user PostScript
.937 1 0 r
.43005 .50212 m
.42072 .49664 L
.41 .49135 L
.39772 .48612 L
.38367 .48083 L
.3676 .47535 L
.34923 .46956 L
.32827 .46335 L
.30434 .45659 L
.27704 .44915 L
.24589 .44089 L
.21037 .43167 L
.16985 .4213 L
.12365 .40962 L
.07096 .39641 L
.01088 .38144 L
s
.01088 .38144 m
0 .37874 L
s
1 0 0 r
.43005 .50212 m
.42072 .49664 L
s
% Start of user PostScript
-8.3941829 0.25391301 -9.513729 -0.40314673 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41 .49135 m
.39772 .48612 L
s
% Start of user PostScript
-10.799506 -1.0375191 -12.273252 -1.6650356 MAarrowhead1
% End of user PostScript
1 .473 0 r
.24589 .44089 m
.21037 .43167 L
s
% Start of user PostScript
-30.492986 -7.0930746 -34.75612 -8.200098 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-86.971968 -21.219285 -99.15546 -24.218906 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-248.26843 -60.804448 -283.05287 -69.330015 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-708.7508 -173.63764 -808.05392 -197.96751 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2023.3363 -495.7122 -2306.8264 -565.1669 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5776.2077 -1415.159 -6585.5134 -1613.4374 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-16489.881 -4039.9879 -18800.283 -4606.0315 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-47075.211 -11533.332 -53670.929 -13149.27 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-134390.02 -32925.285 -153219.43 -37538.454 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-383655.78 -93994.899 -437409.88 -107164.55 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1095258.1 -268336.05 -1248715. -305932.67 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3126736.1 -766044.08 -3564823.8 -873374.69 MAarrowhead1
% End of user PostScript
.073 0 1 r
.48854 .50151 m
.48704 .50043 L
.48531 .49941 L
.48333 .49842 L
.48105 .49745 L
.47845 .49647 L
.47547 .49545 L
.47207 .49437 L
.46819 .49322 L
.46376 .49197 L
.4587 .49059 L
.45293 .48906 L
.44635 .48735 L
.43885 .48543 L
.43029 .48326 L
.42053 .48081 L
.4094 .47804 L
.39671 .47489 L
.38224 .47132 L
.36575 .46725 L
.34694 .46262 L
.3255 .45734 L
.30105 .45134 L
.27318 .4445 L
.2414 .4367 L
.20517 .42781 L
.16387 .41769 L
.11677 .40614 L
.06308 .39298 L
.00186 .37798 L
s
.00186 .37798 m
0 .37752 L
s
1 0 0 r
.48854 .50151 m
.48704 .50043 L
s
% Start of user PostScript
-1.3752107 0.18106658 -1.5552103 0.051152113 MAarrowhead1
% End of user PostScript
1 .158 0 r
.48531 .49941 m
.48333 .49842 L
s
% Start of user PostScript
-1.7625307 -0.071239011 -2.0006517 -0.18931464 MAarrowhead1
% End of user PostScript
1 .473 0 r
.4587 .49059 m
.45293 .48906 L
s
% Start of user PostScript
-4.9560244 -1.1295506 -5.6483414 -1.3131933 MAarrowhead1
% End of user PostScript
1 .788 0 r
.38224 .47132 m
.36575 .46725 L
s
% Start of user PostScript
-14.130668 -3.4421054 -16.110032 -3.9303392 MAarrowhead1
% End of user PostScript
.897 1 0 r
.16387 .41769 m
.11677 .40614 L
s
% Start of user PostScript
-40.335972 -9.8775644 -45.987339 -11.262912 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-115.1499 -28.210399 -131.28355 -32.163293 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-328.72899 -80.537686 -374.78727 -91.821917 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-938.4534 -229.91914 -1069.9403 -262.13319 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2679.0909 -656.37189 -3054.4589 -748.33631 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-7648.2519 -1873.8064 -8719.8503 -2136.3459 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-21834.182 -5349.3309 -24893.374 -6098.8268 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-62332.086 -15271.236 -71065.449 -17410.893 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-177945.25 -43596.23 -202877.2 -49704.508 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-507996.99 -124458.25 -579172.56 -141896.12 MAarrowhead1
% End of user PostScript
1 .035 0 r
.44106 .51704 m
.43357 .50999 L
.42491 .50351 L
.41493 .49744 L
.40345 .4916 L
.3903 .48585 L
.37524 .48005 L
.35802 .47407 L
.33835 .46779 L
.31588 .46106 L
.29023 .45375 L
.26097 .44573 L
.22758 .43684 L
.1895 .42692 L
.14607 .41578 L
.09654 .40323 L
.04006 .38905 L
s
.04006 .38905 m
0 .37906 L
s
1 0 0 r
.44106 .51704 m
.43357 .50999 L
s
% Start of user PostScript
-7.0725956 2.0444499 -7.971065 1.1985586 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42491 .50351 m
.41493 .49744 L
s
% Start of user PostScript
-9.0107391 0.42174267 -10.208864 -0.30739803 MAarrowhead1
% End of user PostScript
1 .473 0 r
.29023 .45375 m
.26097 .44573 L
s
% Start of user PostScript
-25.17225 -5.5497647 -28.684024 -6.5124242 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-71.732074 -17.429249 -81.778922 -19.914723 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-204.74987 -50.129269 -233.43658 -57.163096 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-584.5115 -143.19616 -666.40735 -163.2618 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1668.6581 -408.81602 -1902.4541 -466.09589 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4763.6743 -1167.0902 -5431.1138 -1330.6116 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-13599.308 -3331.803 -15504.71 -3798.6228 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-38823.218 -9511.6108 -44262.749 -10844.285 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-110832.28 -27153.687 -126361.02 -30958.196 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-316403.31 -77518.176 -360734.64 -88379.266 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-903266.18 -221298.41 -1029823. -252304.58 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2578638.6 -631761.31 -2939932.3 -720277.53 MAarrowhead1
% End of user PostScript
0 1 .86 r
.53639 .4277 m
.5395 .44191 L
.54337 .45409 L
.54807 .46461 L
.55365 .47379 L
.5602 .48191 L
.56783 .48922 L
.57666 .49593 L
.58685 .50221 L
.59855 .50823 L
.61197 .51416 L
.62733 .52012 L
.6449 .52626 L
.66497 .53271 L
.6879 .5396 L
.71407 .54708 L
.74393 .55528 L
.778 .56437 L
.81686 .57451 L
.86117 .58589 L
.91171 .5987 L
.96935 .61318 L
s
.96935 .61318 m
1 .62083 L
s
1 0 0 r
.53639 .4277 m
.5395 .44191 L
s
% Start of user PostScript
4.3667045 -8.6763547 4.7399191 -6.9702776 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54337 .45409 m
.54807 .46461 L
s
% Start of user PostScript
5.2049543 -5.5092003 5.7681264 -4.2472596 MAarrowhead1
% End of user PostScript
1 .473 0 r
.61197 .51416 m
.62733 .52012 L
s
% Start of user PostScript
13.435927 1.6987629 15.279438 2.4143319 MAarrowhead1
% End of user PostScript
1 .788 0 r
.81686 .57451 m
.86117 .58589 L
s
% Start of user PostScript
38.022639 8.9414232 43.340843 10.30634 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
108.46833 26.486696 123.6637 30.224082 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
309.63629 75.839648 353.019 86.471741 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
883.94342 216.55953 1007.7928 246.90318 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2523.4751 618.24522 2877.0398 704.86804 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
7204.0008 1764.9655 8213.355 2012.2553 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
20565.936 5038.6132 23447.434 5744.5745 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
58711.507 14384.202 66937.589 16399.575 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
167609.24 41063.929 191093.01 46817.405 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
478489.82 117229.05 545531.14 133654.04 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1365989.7 334664.75 1557378.9 381554.71 MAarrowhead1
% End of user PostScript
0 .109 1 r
.47043 .47307 m
.46581 .4752 L
.46061 .47665 L
.45476 .47748 L
.44814 .47775 L
.44064 .4775 L
.43213 .47673 L
.42245 .47546 L
.41145 .47368 L
.39894 .47138 L
.38468 .46853 L
.36844 .46508 L
.34995 .461 L
.32887 .4562 L
.30484 .45063 L
.27746 .44418 L
.24625 .43675 L
.21067 .42821 L
.17011 .41842 L
.12387 .40722 L
.07116 .39441 L
.01106 .37977 L
s
.01106 .37977 m
0 .37707 L
s
1 0 0 r
.47043 .47307 m
.46581 .4752 L
s
% Start of user PostScript
-3.5483891 -3.2317208 -4.1033902 -2.9763233 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46061 .47665 m
.45476 .47748 L
s
% Start of user PostScript
-4.726571 -2.8024678 -5.4290717 -2.702142 MAarrowhead1
% End of user PostScript
1 .473 0 r
.38468 .46853 m
.36844 .46508 L
s
% Start of user PostScript
-13.83834 -3.776495 -15.786687 -4.1898663 MAarrowhead1
% End of user PostScript
1 .788 0 r
.17011 .41842 m
.12387 .40722 L
s
% Start of user PostScript
-39.586605 -9.789304 -45.135313 -11.133706 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-113.03061 -27.713562 -128.86788 -31.590134 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-322.68355 -79.061822 -367.89493 -90.137693 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-921.19602 -225.69235 -1050.265 -257.31381 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2629.8249 -644.30211 -2998.2903 -734.57534 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7507.6077 -1839.3489 -8559.5004 -2097.0605 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-21432.672 -5250.9617 -24435.608 -5986.6751 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-61185.857 -14990.413 -69758.622 -17090.723 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-174673. -42794.536 -199146.48 -48790.488 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-498655.4 -122169.57 -568522.12 -139286.78 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1423558.3 -348768.94 -1623013.4 -397635.03 MAarrowhead1
% End of user PostScript
.414 0 1 r
.57607 .42415 m
.58442 .44185 L
.59431 .45733 L
.60592 .47107 L
.61941 .48347 L
.63502 .49488 L
.65301 .50561 L
.67366 .51595 L
.69734 .52616 L
.72445 .53648 L
.75545 .54714 L
.79086 .55837 L
.8313 .57042 L
.87745 .5835 L
.93011 .59789 L
.99019 .61385 L
s
.99019 .61385 m
1 .6164 L
s
1 0 0 r
.57607 .42415 m
.58442 .44185 L
s
% Start of user PostScript
9.1284498 -9.102407 10.129842 -6.9785717 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59431 .45733 m
.60592 .47107 L
s
% Start of user PostScript
11.317529 -5.120303 12.709992 -3.4715151 MAarrowhead1
% End of user PostScript
1 .473 0 r
.75545 .54714 m
.79086 .55837 L
s
% Start of user PostScript
30.653503 5.6567129 34.902999 7.0048708 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
87.120661 20.909215 99.316503 23.969267 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
248.62023 60.809279 283.45197 69.359913 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
709.73806 173.86041 809.17903 198.22723 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2026.1507 496.39724 2310.0351 565.94926 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5784.2413 1417.1262 6594.6726 1615.6805 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
16512.816 4045.6065 18826.43 4612.4374 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
47140.683 11549.373 53745.575 13167.558 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
134576.93 32971.078 153432.53 37590.663 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
384189.37 94125.627 438018.23 107313.59 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1096781.4 268709.25 1250451.7 306358.17 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3131084.7 767109.49 3569781.7 874589.38 MAarrowhead1
% End of user PostScript
.285 1 0 r
.45832 .50967 m
.45297 .50507 L
.44679 .5008 L
.43967 .49677 L
.4315 .49285 L
.42214 .48896 L
.41142 .48501 L
.39918 .48089 L
.38519 .47654 L
.36922 .47185 L
.35099 .46674 L
.33019 .46111 L
.30646 .45485 L
.2794 .44784 L
.24854 .43997 L
.21335 .43108 L
.17322 .42103 L
.12746 .40964 L
.07528 .39671 L
.01579 .38201 L
s
.01579 .38201 m
0 .37811 L
s
1 0 0 r
.45832 .50967 m
.45297 .50507 L
s
% Start of user PostScript
-5.0013555 1.1604681 -5.6436878 0.60784673 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44679 .5008 m
.43967 .49677 L
s
% Start of user PostScript
-6.385694 0.096286305 -7.2397363 -0.38809003 MAarrowhead1
% End of user PostScript
1 .473 0 r
.35099 .46674 m
.33019 .46111 L
s
% Start of user PostScript
-17.881465 -3.9909663 -20.377294 -4.6670432 MAarrowhead1
% End of user PostScript
1 .788 0 r
.07528 .39671 m
.01579 .38201 L
s
% Start of user PostScript
-50.966094 -12.395027 -58.104724 -14.159146 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-145.47848 -35.620437 -165.86098 -40.61767 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-415.30655 -101.74422 -473.49512 -116.00114 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1185.6135 -290.47174 -1351.73 -331.17016 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3384.6817 -829.23997 -3858.9102 -945.42505 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-9662.5681 -2367.3098 -11016.393 -2698.9941 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-27584.639 -6758.1814 -31449.529 -7705.0717 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-78748.456 -19293.214 -89781.92 -21996.391 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-224810.6 -55078.147 -256308.86 -62795.158 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-641787.89 -157236.75 -731708.94 -179267.23 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1832172.1 -448878.49 -2088878.1 -511770.96 MAarrowhead1
% End of user PostScript
1 .161 0 r
.52117 .50428 m
.52411 .50515 L
.52747 .5061 L
.53131 .50714 L
.53568 .5083 L
.54067 .5096 L
.54636 .51105 L
.55285 .51269 L
.56024 .51455 L
.56868 .51665 L
.5783 .51903 L
.58926 .52175 L
.60177 .52483 L
.61602 .52834 L
.63228 .53234 L
.65081 .53689 L
.67194 .54207 L
.69603 .54798 L
.72349 .55472 L
.7548 .5624 L
.7905 .57115 L
.8312 .58112 L
.87761 .5925 L
.93051 .60546 L
.99083 .62024 L
s
.99083 .62024 m
1 .62249 L
s
1 0 0 r
.52117 .50428 m
.52411 .50515 L
s
% Start of user PostScript
2.5402863 0.51352123 2.8935417 0.61810013 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52747 .5061 m
.53131 .50714 L
s
% Start of user PostScript
3.2967332 0.73192594 3.7567844 0.8571898 MAarrowhead1
% End of user PostScript
1 .473 0 r
.5783 .51903 m
.58926 .52175 L
s
% Start of user PostScript
9.3956 2.2841127 10.711584 2.6094735 MAarrowhead1
% End of user PostScript
1 .788 0 r
.72349 .55472 m
.7548 .5624 L
s
% Start of user PostScript
26.818768 6.5663673 30.57625 7.4876348 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
76.561176 18.756354 87.288156 21.384605 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
218.56616 53.548042 249.18951 61.050739 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
623.96126 152.86921 711.38462 174.28776 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1781.2807 436.41019 2030.8564 497.55573 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
5085.189 1245.8611 5797.676 1420.419 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
14517.166 3556.6766 16551.169 4055.0033 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
41443.514 10153.578 47250.175 11576.198 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
118312.69 28986.371 134889.5 33047.658 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
337758.32 82750.112 385081.71 94344.249 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
964230.33 236234.5 1099328.9 269333.37 MAarrowhead1
% End of user PostScript
1 .148 0 r
.46463 .49606 m
.45979 .49409 L
.45425 .49208 L
.44792 .48999 L
.44069 .48776 L
.43244 .48536 L
.42302 .48273 L
.41227 .47984 L
.40001 .47661 L
.38603 .473 L
.37009 .46894 L
.3519 .46436 L
.33117 .45917 L
.30753 .45329 L
.28057 .44661 L
.24983 .43902 L
.21479 .43038 L
.17484 .42055 L
.12928 .40936 L
.07735 .3966 L
.01813 .38207 L
s
.01813 .38207 m
0 .37762 L
s
1 0 0 r
.46463 .49606 m
.45979 .49409 L
s
% Start of user PostScript
-4.2445835 -0.47270463 -4.8254067 -0.70897418 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45425 .49208 m
.44792 .48999 L
s
% Start of user PostScript
-5.4899097 -0.95017736 -6.2494357 -1.2016724 MAarrowhead1
% End of user PostScript
1 .473 0 r
.37009 .46894 m
.3519 .46436 L
s
% Start of user PostScript
-15.589735 -3.7267437 -17.771747 -4.2766914 MAarrowhead1
% End of user PostScript
1 .788 0 r
.12928 .40936 m
.07735 .3966 L
s
% Start of user PostScript
-44.486032 -10.87722 -50.718447 -12.407756 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-126.99388 -31.108135 -144.7869 -35.468235 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-362.54026 -88.820438 -413.33583 -101.26545 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1034.9774 -253.56712 -1179.9883 -289.09455 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2954.647 -723.88254 -3368.6233 -825.30591 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8434.9078 -2066.5355 -9616.7247 -2356.0783 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-24079.922 -5899.5327 -27453.766 -6726.1176 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-68743.211 -16841.949 -78374.839 -19201.679 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-196247.69 -48080.291 -223744. -54816.832 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-560246.68 -137259.32 -638742.97 -156490.75 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1599388.7 -391847.04 -1823479.4 -446748.81 MAarrowhead1
% End of user PostScript
1 .803 0 r
.57662 .4698 m
.58616 .48025 L
.59723 .48973 L
.61002 .49851 L
.62474 .50683 L
.64163 .5149 L
.66099 .52293 L
.68315 .53109 L
.70847 .53958 L
.7374 .54857 L
.77042 .55825 L
.80812 .56881 L
.85112 .58045 L
.90018 .5934 L
.95614 .60787 L
s
.95614 .60787 m
1 .61906 L
s
1 0 0 r
.57662 .4698 m
.58616 .48025 L
s
% Start of user PostScript
9.1947463 -3.62374 10.339158 -2.369819 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59723 .48973 m
.61002 .49851 L
s
% Start of user PostScript
11.667747 -1.2320605 13.202372 -0.17838965 MAarrowhead1
% End of user PostScript
1 .473 0 r
.77042 .55825 m
.80812 .56881 L
s
% Start of user PostScript
32.450932 6.9899115 36.974125 8.2572099 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
92.439237 22.421897 105.3854 25.631044 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
263.84765 64.58919 300.8141 73.654671 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
753.21951 184.52484 858.75296 210.38238 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2150.2837 526.81229 2451.5604 600.62496 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6138.6159 1503.9479 6998.6988 1714.6666 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
17524.482 4293.4629 19979.842 4895.021 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
50028.783 12256.952 57038.327 13974.276 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
142821.86 34991.069 162832.66 39893.675 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
407726.94 99892.285 464853.66 113888.22 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1163976.3 285171.87 1327061.3 325127.37 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3322912.3 814106.87 3788486.4 928171.57 MAarrowhead1
% End of user PostScript
1 0 .312 r
.55339 .57308 m
.56234 .56534 L
.5723 .55948 L
.58346 .5553 L
.596 .5526 L
.61017 .55125 L
.62619 .55116 L
.64437 .55226 L
.66501 .55452 L
.68848 .55793 L
.71517 .56252 L
.74556 .56834 L
.78017 .57547 L
.81959 .58399 L
.8645 .59406 L
.91569 .60581 L
.97403 .61944 L
s
.97403 .61944 m
1 .62559 L
s
1 0 0 r
.55339 .57308 m
.56234 .56534 L
s
% Start of user PostScript
6.4071427 8.7700445 7.4811263 7.8403013 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5723 .55948 m
.58346 .5553 L
s
% Start of user PostScript
8.6763823 7.1378906 10.01474 6.635421 MAarrowhead1
% End of user PostScript
1 .473 0 r
.71517 .56252 m
.74556 .56834 L
s
% Start of user PostScript
25.820675 7.5029023 29.467228 8.2013267 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
73.959574 18.396287 84.328832 20.890954 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
211.1973 51.807801 240.78979 59.047152 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
602.93833 147.73392 687.41653 168.42839 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1721.2678 421.71074 1962.4351 480.79565 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4913.8653 1203.888 5602.3481 1372.5648 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
14028.072 3436.8498 15993.548 3918.3875 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
40047.252 9811.4967 45658.282 11186.188 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
114326.65 28009.799 130344.98 31934.259 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
326378.99 79962.2 372108.03 91165.723 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
931744.71 228275.59 1062291.7 260259.34 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2659939. 651679.73 3032623.7 742986.72 MAarrowhead1
% End of user PostScript
1 .207 0 r
.51622 .50438 m
.5185 .50487 L
.5211 .50545 L
.52406 .50613 L
.52744 .50692 L
.53129 .50783 L
.53568 .50888 L
.54068 .51008 L
.54638 .51146 L
.55288 .51304 L
.56029 .51484 L
.56874 .5169 L
.57837 .51925 L
.58936 .52193 L
.60188 .52499 L
.61615 .52848 L
.63243 .53247 L
.65098 .53701 L
.67214 .54219 L
.69626 .5481 L
.72375 .55483 L
.7551 .56251 L
.79085 .57126 L
.8316 .58125 L
.87806 .59263 L
.93103 .60561 L
.99142 .6204 L
s
.99142 .6204 m
1 .6225 L
s
1 0 0 r
.51622 .50438 m
.5185 .50487 L
s
% Start of user PostScript
1.9459743 0.52591147 2.2198285 0.5848623 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5211 .50545 m
.52406 .50613 L
s
% Start of user PostScript
2.5318531 0.65451384 2.8874293 0.73596095 MAarrowhead1
% End of user PostScript
1 .473 0 r
.56029 .51484 m
.56874 .5169 L
s
% Start of user PostScript
7.2350957 1.7806178 8.2490033 2.0276922 MAarrowhead1
% End of user PostScript
1 .788 0 r
.67214 .54219 m
.69626 .5481 L
s
% Start of user PostScript
20.656391 5.0626609 23.550609 5.7714259 MAarrowhead1
% End of user PostScript
.897 1 0 r
.99142 .6204 m
0 0 rlineto s
.99142 .6204 m
1 .6225 L
s
% Start of user PostScript
58.970132 14.448007 67.232462 16.472188 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
168.34766 41.244943 191.93489 47.02375 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
480.59786 117.74554 547.93454 134.24289 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1372.0078 336.13917 1564.2401 383.2357 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
3916.7992 959.60797 4465.5829 1094.0589 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
11181.654 2739.4828 12748.318 3123.3124 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
31921.316 7820.6585 36393.819 8916.4128 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
91128.773 22326.367 103896.85 25454.519 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
260153.85 63737.173 296604.07 72667.403 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
742685.59 181956.48 846743.44 207450.45 MAarrowhead1
% End of user PostScript
.148 1 0 r
.42768 .43159 m
.41631 .4372 L
.40354 .44108 L
.38917 .4434 L
.37292 .4443 L
.35451 .44386 L
.33362 .44214 L
.30989 .43916 L
.28291 .43491 L
.2522 .42936 L
.21724 .42244 L
.17742 .41405 L
.13205 .40408 L
.08035 .39238 L
.02144 .37874 L
s
.02144 .37874 m
0 .3737 L
s
1 0 0 r
.42768 .43159 m
.41631 .4372 L
s
% Start of user PostScript
-8.6784127 -8.2094631 -10.043277 -7.5360436 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40354 .44108 m
.38917 .4434 L
s
% Start of user PostScript
-11.5747 -7.0703932 -13.300106 -6.7915701 MAarrowhead1
% End of user PostScript
1 .473 0 r
.21724 .42244 m
.17742 .41405 L
s
% Start of user PostScript
-33.931664 -9.3074988 -38.71018 -10.3135 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-97.076476 -24.017011 -110.6836 -27.312051 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-277.18229 -67.963926 -316.01971 -77.469934 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-791.30977 -193.88218 -902.18068 -221.0432 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2259.0289 -553.46058 -2575.542 -631.00516 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6449.0622 -1580.008 -7352.6418 -1801.3831 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-18410.743 -4510.5953 -20990.276 -5142.5758 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-52558.873 -12876.819 -59922.909 -14680.993 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-150044.74 -36760.662 -171067.55 -41911.206 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-428346.79 -104944.11 -488362.56 -119647.85 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1222841.8 -299593.78 -1394174.4 -341569.94 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3490961. -855278.46 -3980080.3 -975111.72 MAarrowhead1
% End of user PostScript
.421 0 1 r
.46452 .50952 m
.45999 .5054 L
.45476 .5016 L
.44873 .49802 L
.4418 .49457 L
.43387 .49116 L
.42478 .48772 L
.41439 .48415 L
.40252 .48039 L
.38897 .47637 L
.3735 .47198 L
.35585 .46717 L
.33571 .46182 L
.31274 .45585 L
.28655 .44915 L
.25668 .44159 L
.22262 .43305 L
.18378 .42336 L
.13949 .41237 L
.089 .39989 L
.03142 .38569 L
s
.03142 .38569 m
0 .37795 L
s
1 0 0 r
.46452 .50952 m
.45999 .5054 L
s
% Start of user PostScript
-4.2580848 1.1425787 -4.8011734 0.64740384 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45476 .5016 m
.44873 .49802 L
s
% Start of user PostScript
-5.4292197 0.19140642 -6.1526583 -0.23790883 MAarrowhead1
% End of user PostScript
1 .473 0 r
.3735 .47198 m
.35585 .46717 L
s
% Start of user PostScript
-15.180131 -3.3618329 -17.298276 -3.9399625 MAarrowhead1
% End of user PostScript
1 .788 0 r
.13949 .41237 m
.089 .39989 L
s
% Start of user PostScript
-43.261199 -10.515019 -49.320482 -12.013429 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-123.4842 -30.233685 -140.78512 -34.475639 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-352.5178 -86.361531 -401.90904 -98.463051 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1006.3646 -246.55624 -1147.3666 -281.10161 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2872.9633 -703.87 -3275.4948 -802.48946 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8201.7175 -2009.4043 -9350.8621 -2290.9424 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-23414.212 -5736.4351 -26694.783 -6540.1683 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-66842.746 -16376.339 -76208.099 -18670.832 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-190822.25 -46751.07 -217558.4 -53301.373 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-544758.18 -133464.66 -621084.37 -152164.43 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1555172.2 -381014.09 -1773067.8 -434398.06 MAarrowhead1
% End of user PostScript
1 .052 0 r
.44604 .53937 m
.43976 .52912 L
.4324 .52004 L
.42382 .51188 L
.41389 .50439 L
.40245 .49736 L
.38931 .49062 L
.37423 .48399 L
.35697 .47731 L
.33723 .47042 L
.31468 .46319 L
.28893 .45546 L
.25953 .44707 L
.22598 .43786 L
.18771 .42766 L
.14406 .41627 L
.09428 .4035 L
.0375 .38911 L
s
.0375 .38911 m
0 .37969 L
s
1 0 0 r
.44604 .53937 m
.43976 .52912 L
s
% Start of user PostScript
-6.4757935 4.7238293 -7.228628 3.4939517 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4324 .52004 m
.42382 .51188 L
s
% Start of user PostScript
-8.1125366 2.4051572 -9.141644 1.4252921 MAarrowhead1
% End of user PostScript
1 .473 0 r
.31468 .46319 m
.28893 .45546 L
s
% Start of user PostScript
-22.238173 -4.4168767 -25.328717 -5.3449299 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-63.269037 -15.258602 -72.127747 -17.469091 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-180.56925 -44.182238 -205.86746 -50.389669 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-515.47604 -126.27724 -587.69917 -143.97398 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1471.575 -360.52979 -1677.7576 -411.04464 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4201.0424 -1029.2462 -4789.6513 -1173.4544 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-11993.109 -2938.2876 -13673.467 -3349.9718 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-34237.854 -8388.2055 -39034.927 -9563.479 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-97742.01 -23946.597 -111436.67 -27301.76 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-279033.28 -68362.595 -318128.7 -77940.894 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-796582.47 -195161.11 -908191.82 -222505.18 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2274078.6 -557144.72 -2592700.3 -635206.39 MAarrowhead1
% End of user PostScript
1 .261 0 r
.45635 .57978 m
.45245 .56384 L
.44763 .55015 L
.44184 .5383 L
.43497 .52791 L
.42694 .51868 L
.4176 .51033 L
.4068 .50263 L
.39436 .49536 L
.38008 .48834 L
.36371 .4814 L
.34498 .47436 L
.32356 .46707 L
.29909 .45937 L
.27115 .4511 L
.23927 .4421 L
.20288 .43219 L
.16137 .4212 L
.11403 .40891 L
.06004 .39511 L
s
.06004 .39511 m
0 .37993 L
s
1 0 0 r
.45635 .57978 m
.45245 .56384 L
s
% Start of user PostScript
-5.2382547 9.5739477 -5.70638 7.6605394 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44763 .55015 m
.44184 .5383 L
s
% Start of user PostScript
-6.2841305 6.0182649 -6.9795704 4.5957805 MAarrowhead1
% End of user PostScript
1 .473 0 r
.36371 .4814 m
.34498 .47436 L
s
% Start of user PostScript
-16.354506 -2.2321964 -18.602493 -3.0769489 MAarrowhead1
% End of user PostScript
1 .788 0 r
.11403 .40891 m
.06004 .39511 L
s
% Start of user PostScript
-46.316484 -10.930755 -52.795696 -12.587182 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-132.1366 -32.275362 -150.6479 -36.826801 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-377.20222 -92.390815 -430.05155 -105.3426 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1076.8297 -263.81573 -1227.7044 -300.78063 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3074.1256 -753.15336 -3504.842 -858.67823 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8775.9944 -2150.1008 -10005.601 -2451.352 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-25053.654 -6138.095 -28563.927 -6998.1049 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-71523.014 -17522.995 -81544.12 -19978.146 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-204183.45 -50024.538 -232791.65 -57033.487 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-582901.65 -142809.74 -664572.13 -162818.84 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1664064. -407692.35 -1897216.4 -464814.22 MAarrowhead1
% End of user PostScript
0 1 .802 r
.57123 .45327 m
.57963 .46596 L
.58948 .47724 L
.60092 .48745 L
.61415 .49687 L
.62938 .50575 L
.64688 .51434 L
.66692 .52283 L
.68987 .53145 L
.7161 .54037 L
.74607 .5498 L
.7803 .55992 L
.81935 .57094 L
.86392 .58307 L
.91476 .59653 L
.97275 .61158 L
s
.97275 .61158 m
1 .61855 L
s
1 0 0 r
.57123 .45327 m
.57963 .46596 L
s
% Start of user PostScript
8.5470336 -5.6078111 9.5560052 -4.0846635 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58948 .47724 m
.60092 .48745 L
s
% Start of user PostScript
10.737582 -2.7306136 12.110772 -1.5059841 MAarrowhead1
% End of user PostScript
1 .473 0 r
.74607 .5498 m
.7803 .55992 L
s
% Start of user PostScript
29.528958 5.9756752 33.635447 7.1903109 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
84.035016 20.292824 95.801945 23.224668 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
239.84064 58.69107 273.44306 66.935096 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
684.68099 167.72917 780.6114 191.23463 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1954.6196 478.87406 2228.4817 545.97036 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5580.035 1367.0965 6361.8549 1558.641 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
15929.849 3902.7809 18161.784 4449.6004 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
45476.433 11141.635 51848.146 12702.692 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
129825.84 31807.07 148015.76 36263.566 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
370625.99 90802.625 422554.48 103525. MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1058060.8 259222.77 1206305.9 295542.53 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3020545.2 740027.53 3443754.5 843712.96 MAarrowhead1
% End of user PostScript
0 1 .49 r
.52843 .4968 m
.53217 .4994 L
.53647 .50186 L
.5414 .50424 L
.54706 .5066 L
.55353 .509 L
.56093 .5115 L
.56938 .51414 L
.57903 .51698 L
.59005 .52007 L
.60262 .52348 L
.61696 .52727 L
.63331 .5315 L
.65196 .53626 L
.67322 .54163 L
.69748 .54771 L
.72513 .5546 L
.75666 .56241 L
.79261 .5713 L
.83359 .5814 L
.88032 .59291 L
.9336 .60601 L
.99435 .62093 L
s
.99435 .62093 m
1 .62231 L
s
1 0 0 r
.52843 .4968 m
.53217 .4994 L
s
% Start of user PostScript
3.4118365 -0.38407173 3.8600026 -0.072161702 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53647 .50186 m
.5414 .50424 L
s
% Start of user PostScript
4.3759094 0.22286129 4.9682284 0.50866887 MAarrowhead1
% End of user PostScript
1 .473 0 r
.60262 .52348 m
.61696 .52727 L
s
% Start of user PostScript
12.314179 2.8175462 14.03464 3.2720905 MAarrowhead1
% End of user PostScript
1 .788 0 r
.79261 .5713 m
.83359 .5814 L
s
% Start of user PostScript
35.112613 8.5556991 40.031103 9.768476 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
100.22945 24.54502 114.27235 27.987324 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
286.13209 70.099208 326.22206 79.921598 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
816.84757 200.12541 931.29625 228.16521 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2331.9312 571.31833 2658.6586 651.36592 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
6657.1826 1630.9964 7589.922 1859.5157 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
19004.883 4656.1584 21667.662 5308.5338 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
54255.022 13292.372 61856.706 15154.769 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
154886.9 37946.98 176588.14 43263.74 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
442170.15 108330.8 504122.71 123509.05 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1262304.6 309262.1 1439166.4 352592.88 MAarrowhead1
% End of user PostScript
0 1 .337 r
.42297 .56972 m
.41435 .55293 L
.40416 .53819 L
.39224 .52505 L
.3784 .51314 L
.36242 .50211 L
.34402 .49167 L
.32289 .48154 L
.29869 .47148 L
.27099 .46125 L
.23933 .45062 L
.20316 .43936 L
.16187 .42724 L
.11474 .41402 L
.06097 .39945 L
s
.06097 .39945 m
0 .38336 L
s
1 0 0 r
.42297 .56972 m
.41435 .55293 L
s
% Start of user PostScript
-9.243228 8.3668273 -10.278022 6.3520126 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40416 .53819 m
.39224 .52505 L
s
% Start of user PostScript
-11.50092 4.582904 -12.931136 3.0064538 MAarrowhead1
% End of user PostScript
1 .473 0 r
.23933 .45062 m
.20316 .43936 L
s
% Start of user PostScript
-31.280353 -5.9259239 -35.620508 -7.277136 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-88.934443 -21.38074 -101.38508 -24.498717 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-253.8039 -62.085643 -289.36208 -70.813197 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-724.5377 -177.48779 -826.0523 -202.36239 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2068.401 -506.74882 -2358.205 -577.7511 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5904.8571 -1446.6769 -6732.188 -1649.3715 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-16857.149 -4129.9675 -19219.008 -4708.6182 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-48123.683 -11790.206 -54866.304 -13442.135 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-137383.19 -33658.607 -156631.98 -38374.522 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-392200.67 -96088.38 -447152. -109551.35 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1119652. -274312.51 -1276526.7 -312746.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3196375.6 -783105.63 -3644220.6 -892826.74 MAarrowhead1
% End of user PostScript
0 .918 1 r
.47212 .54886 m
.46958 .53901 L
.46645 .53054 L
.4627 .5232 L
.45827 .51676 L
.45308 .51102 L
.44706 .50581 L
.4401 .501 L
.43209 .49644 L
.4229 .49202 L
.41236 .48763 L
.4003 .48317 L
.38652 .47853 L
.37078 .47363 L
.3528 .46835 L
.33229 .46259 L
.30888 .45625 L
.28217 .44919 L
.25172 .44131 L
.21698 .43244 L
.17737 .42244 L
.1322 .41113 L
.0807 .39831 L
.02198 .38375 L
s
.02198 .38375 m
0 .37832 L
s
1 0 0 r
.47212 .54886 m
.46958 .53901 L
s
% Start of user PostScript
-3.34554 5.8627388 -3.6506867 4.6809144 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46645 .53054 m
.4627 .5232 L
s
% Start of user PostScript
-4.0256905 3.6653812 -4.4758492 2.7844566 MAarrowhead1
% End of user PostScript
1 .473 0 r
.41236 .48763 m
.4003 .48317 L
s
% Start of user PostScript
-10.51675 -1.4843476 -11.963514 -2.0197514 MAarrowhead1
% End of user PostScript
1 .788 0 r
.25172 .44131 m
.21698 .43244 L
s
% Start of user PostScript
-29.794037 -7.0430172 -33.962208 -8.1066985 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-85.002035 -20.76511 -96.910215 -23.692566 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-242.65065 -59.434783 -276.64814 -67.766443 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-692.71458 -169.71037 -789.7709 -193.48952 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1977.5566 -484.49662 -2254.6324 -552.37979 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-5645.516 -1383.1399 -6436.5105 -1576.932 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-16116.784 -3948.5797 -18374.91 -4501.8161 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-46010.093 -11272.381 -52456.578 -12851.757 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-131349.33 -32180.322 -149752.71 -36689.114 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-374975.24 -91868.183 -427513.1 -104739.85 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1070477. -262264.71 -1220461.7 -299010.68 MAarrowhead1
% End of user PostScript
.223 1 0 r
.50543 .49369 m
.506 .4951 L
.50669 .49632 L
.5075 .4974 L
.50844 .49836 L
.50953 .49925 L
.51079 .50007 L
.51224 .50085 L
.5139 .50161 L
.51581 .50238 L
.51798 .50316 L
.52047 .50397 L
.52332 .50484 L
.52656 .50578 L
.53026 .50681 L
.53449 .50795 L
.53931 .50921 L
.54481 .51063 L
.55108 .51222 L
.55823 .51402 L
.56638 .51606 L
.57567 .51837 L
.58627 .52099 L
.59836 .52398 L
.61213 .52737 L
.62784 .53124 L
.64575 .53564 L
.66617 .54065 L
.68945 .54637 L
.716 .55288 L
.74626 .5603 L
.78076 .56876 L
.8201 .5784 L
.86495 .58939 L
.91608 .60192 L
.97438 .61621 L
s
.97438 .61621 m
1 .62249 L
s
1 0 0 r
.50543 .49369 m
.506 .4951 L
s
% Start of user PostScript
0.6517262 -0.7572509 0.72059168 -0.58847346 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50669 .49632 m
.5075 .4974 L
s
% Start of user PostScript
0.80282486 -0.44158697 0.89968257 -0.3121143 MAarrowhead1
% End of user PostScript
1 .473 0 r
.51798 .50316 m
.52047 .50397 L
s
% Start of user PostScript
2.1580099 0.37883731 2.4567 0.47684473 MAarrowhead1
% End of user PostScript
1 .788 0 r
.55108 .51222 m
.55823 .51402 L
s
% Start of user PostScript
6.1292351 1.4664599 6.9871421 1.6824754 MAarrowhead1
% End of user PostScript
.897 1 0 r
.64575 .53564 m
.66617 .54065 L
s
% Start of user PostScript
17.49032 4.2768306 19.940691 4.8785354 MAarrowhead1
% End of user PostScript
.581 1 0 r
.91608 .60192 m
.97438 .61621 L
s
% Start of user PostScript
49.929524 12.230693 56.925114 13.94492 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
142.53809 34.92109 162.50912 39.814029 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
406.91674 99.69368 463.92994 113.66182 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
1161.6634 284.60517 1324.4243 324.48127 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
3316.3093 812.48913 3780.9581 926.32717 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
9467.379 2319.4889 10793.856 2644.473 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
27027.414 6621.6624 30814.232 7549.4251 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
77157.694 18903.481 87968.276 21552.052 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
220269.3 53965.538 251131.28 61526.662 MAarrowhead1
% End of user PostScript
.929 0 1 r
.52293 .45125 m
.52481 .46072 L
.52717 .46881 L
.53005 .47579 L
.53349 .48186 L
.53754 .48722 L
.54226 .49201 L
.54773 .49639 L
.55405 .50047 L
.56131 .50437 L
.56964 .50817 L
.57917 .51198 L
.59009 .51588 L
.60256 .51996 L
.6168 .52431 L
.63306 .52901 L
.65161 .53415 L
.67278 .53983 L
.69693 .54616 L
.72447 .55325 L
.75588 .56124 L
.7917 .57025 L
.83254 .58046 L
.8791 .59204 L
.9322 .60518 L
.99274 .62013 L
s
.99274 .62013 m
1 .62192 L
s
1 0 0 r
.52293 .45125 m
.52481 .46072 L
s
% Start of user PostScript
2.751228 -5.8503485 2.9769735 -4.7141522 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52717 .46881 m
.53005 .47579 L
s
% Start of user PostScript
3.2608104 -3.7427933 3.6064941 -2.9056855 MAarrowhead1
% End of user PostScript
1 .473 0 r
.56964 .50817 m
.57917 .51198 L
s
% Start of user PostScript
8.3562457 0.98085273 9.5009334 1.43797 MAarrowhead1
% End of user PostScript
1 .788 0 r
.69693 .54616 m
.72447 .55325 L
s
% Start of user PostScript
23.63166 5.5393108 26.936567 6.3904897 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
67.410991 16.456763 76.854521 18.780149 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
192.43214 47.131684 219.39352 53.739454 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
549.35118 134.5867 626.32082 153.44464 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1568.2836 384.22559 1788.0162 438.05975 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
4477.1262 1096.8868 5104.4173 1250.5719 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
12781.272 3131.386 14572.059 3570.1252 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
36487.895 8939.4612 41600.222 10191.971 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
104165.41 25520.318 118760.05 29095.976 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
297370.77 72855.244 339035.46 83063.009 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
848932.23 207986.7 967876.31 237127.76 MAarrowhead1
% End of user PostScript
.9 1 0 r
.45762 .44184 m
.45051 .44801 L
.4426 .45268 L
.43375 .45602 L
.42378 .45818 L
.41254 .45926 L
.39981 .45934 L
.38538 .45847 L
.36899 .45668 L
.35036 .45398 L
.32917 .45034 L
.30504 .44572 L
.27757 .44007 L
.24627 .4333 L
.21061 .42531 L
.16997 .41598 L
.12365 .40516 L
.07085 .39266 L
.01067 .37828 L
s
.01067 .37828 m
0 .37571 L
s
1 0 0 r
.45762 .44184 m
.45051 .44801 L
s
% Start of user PostScript
-5.0855555 -6.9795076 -5.9384623 -6.238596 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4426 .45268 m
.43375 .45602 L
s
% Start of user PostScript
-6.8876154 -5.6786289 -7.9503525 -5.2777834 MAarrowhead1
% End of user PostScript
1 .473 0 r
.32917 .45034 m
.30504 .44572 L
s
% Start of user PostScript
-20.499939 -5.9595925 -23.395133 -6.5136529 MAarrowhead1
% End of user PostScript
1 .788 0 r
.01067 .37828 m
0 0 rlineto s
.01067 .37828 m
0 .37571 L
s
% Start of user PostScript
-58.719679 -14.606251 -66.952294 -16.58677 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-167.67873 -41.132622 -191.1735 -46.880234 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-478.69904 -117.29244 -545.76996 -133.72267 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1366.5896 -334.81456 -1558.0628 -381.72465 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3901.3319 -955.81918 -4447.9485 -1089.739 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-11137.498 -2728.6649 -12697.976 -3110.9787 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-31795.26 -7789.7752 -36250.101 -8881.2023 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-90768.91 -22238.201 -103486.56 -25354.001 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-259126.52 -63485.478 -295432.79 -72380.443 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-739752.76 -181237.95 -843399.69 -206631.24 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2111841.6 -517396.96 -2407732.2 -589889.56 MAarrowhead1
% End of user PostScript
1 0 .175 r
.53163 .42181 m
.53396 .43661 L
.53696 .44923 L
.54068 .46005 L
.54516 .46942 L
.55046 .47762 L
.55668 .4849 L
.56391 .49147 L
.57228 .49753 L
.58191 .50323 L
.59297 .50873 L
.60566 .51417 L
.62017 .51966 L
.63677 .52535 L
.65573 .53135 L
.67739 .53778 L
.7021 .54478 L
.7303 .55247 L
.76247 .56101 L
.79917 .57054 L
.84102 .58125 L
.88874 .59333 L
.94316 .60698 L
s
.94316 .60698 m
1 .62114 L
s
1 0 0 r
.53163 .42181 m
.53396 .43661 L
s
% Start of user PostScript
3.7959409 -9.3833328 4.0753009 -7.606292 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53696 .44923 m
.54068 .46005 L
s
% Start of user PostScript
4.4356319 -6.0924751 4.8813487 -4.7939059 MAarrowhead1
% End of user PostScript
1 .473 0 r
.59297 .50873 m
.60566 .51417 L
s
% Start of user PostScript
11.156856 1.0476957 12.678776 1.6998331 MAarrowhead1
% End of user PostScript
1 .788 0 r
.76247 .56101 m
.79917 .57054 L
s
% Start of user PostScript
31.496916 7.3208677 35.900266 8.4652536 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
89.83417 21.916253 102.41858 25.014805 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
256.43853 62.805104 292.36766 71.611284 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
732.07454 179.35167 834.64555 204.48221 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2089.9207 512.0252 2382.74 583.76553 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
5966.2924 1461.7294 6802.231 1666.5328 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
17032.534 4172.9368 19418.967 4757.6079 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
48624.373 11912.874 55437.145 13581.989 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
138812.56 34008.798 158261.61 38773.779 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
396281.22 97088.105 451804.27 110691.14 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1131301.1 277166.51 1289808. 316000.38 MAarrowhead1
% End of user PostScript
0 1 .827 r
.43502 .52444 m
.42691 .51577 L
.41749 .50788 L
.40662 .50056 L
.39411 .49362 L
.37975 .48686 L
.3633 .48012 L
.34448 .47326 L
.32297 .46611 L
.2984 .45851 L
.27034 .45033 L
.23833 .44139 L
.2018 .43153 L
.16013 .42056 L
.1126 .40829 L
.0584 .39448 L
s
.0584 .39448 m
0 .37975 L
s
1 0 0 r
.43502 .52444 m
.42691 .51577 L
s
% Start of user PostScript
-7.7973808 2.9332924 -8.7712921 1.8922464 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41749 .50788 m
.40662 .50056 L
s
% Start of user PostScript
-9.9013036 0.94589543 -11.206032 0.06765461 MAarrowhead1
% End of user PostScript
1 .473 0 r
.27034 .45033 m
.23833 .44139 L
s
% Start of user PostScript
-27.558909 -5.9601865 -31.400812 -7.0326037 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-78.508932 -19.048638 -89.504285 -21.773274 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-224.08781 -54.857417 -255.48374 -62.556587 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-639.71533 -156.71873 -729.34574 -178.6797 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1826.2532 -447.42597 -2082.1299 -510.11564 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5213.5757 -1277.315 -5944.0509 -1456.2801 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-14883.683 -3646.4725 -16969.039 -4157.3806 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-42489.846 -10409.927 -48443.108 -11868.464 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-121299.75 -29718.195 -138295.08 -33882.018 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-346285.76 -84839.317 -394803.93 -96726.174 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-988574.42 -242198.75 -1127083.8 -276133.28 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2822176.1 -691427.49 -3217591.8 -788303.55 MAarrowhead1
% End of user PostScript
1 .342 0 r
.57517 .48693 m
.58493 .49454 L
.59618 .50165 L
.60912 .50845 L
.62396 .51511 L
.64096 .5218 L
.6604 .52868 L
.68261 .53588 L
.70798 .54356 L
.73693 .55188 L
.76998 .561 L
.80768 .57109 L
.85069 .58233 L
.89973 .59494 L
.95567 .60914 L
s
.95567 .60914 m
1 .62029 L
s
1 0 0 r
.57517 .48693 m
.58493 .49454 L
s
% Start of user PostScript
9.0198301 -1.568631 10.191096 -0.65569797 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59618 .50165 m
.60912 .50845 L
s
% Start of user PostScript
11.541794 0.19749082 13.094524 1.0136532 MAarrowhead1
% End of user PostScript
1 .473 0 r
.76998 .561 m
.80768 .57109 L
s
% Start of user PostScript
32.397707 7.319783 36.921837 8.5305014 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
92.359221 22.482811 105.29614 25.676355 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
263.63611 64.556269 300.57339 73.61147 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
752.61957 184.38229 858.06908 210.21854 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2148.572 526.39396 2449.6088 600.1477 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6133.7294 1502.751 6993.1277 1713.3019 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
17510.532 4290.0453 19963.937 4891.1245 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
49988.959 12247.195 56992.923 13963.152 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
142708.17 34963.215 162703.04 39861.919 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
407402.38 99812.768 464483.62 113797.56 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1163049.8 284944.87 1326004.9 324868.56 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3320267.2 813458.83 3785470.6 927432.73 MAarrowhead1
% End of user PostScript
.32 1 0 r
.54186 .49724 m
.5474 .50075 L
.55378 .50411 L
.56109 .50741 L
.56947 .51071 L
.57904 .5141 L
.58999 .51766 L
.60249 .52145 L
.61676 .52555 L
.63305 .53005 L
.65163 .53502 L
.67282 .54056 L
.69699 .54678 L
.72455 .55378 L
.75598 .56168 L
.79182 .57064 L
.83269 .58079 L
.87929 .59233 L
.93241 .60544 L
.99299 .62036 L
s
.99299 .62036 m
1 .62209 L
s
1 0 0 r
.54186 .49724 m
.5474 .50075 L
s
% Start of user PostScript
5.0228271 -0.33164037 5.6883304 0.090218346 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55378 .50411 m
.56109 .50741 L
s
% Start of user PostScript
6.4534136 0.49359691 7.3309794 0.8887598 MAarrowhead1
% End of user PostScript
1 .473 0 r
.65163 .53502 m
.67282 .54056 L
s
% Start of user PostScript
18.195048 4.2024054 20.738109 4.867753 MAarrowhead1
% End of user PostScript
1 .788 0 r
.93241 .60544 m
.99299 .62036 L
s
% Start of user PostScript
51.889547 12.652879 59.158336 14.44365 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
148.12138 36.275363 168.87435 41.362133 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
422.85303 103.59484 482.09899 118.11053 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1207.1575 295.7504 1376.2926 337.18828 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3446.1855 844.30838 3929.0314 962.60467 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
9838.1489 2410.3267 11216.574 2748.0382 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
28085.886 6880.9858 32021.006 7845.0824 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
80179.412 19643.795 91413.368 22396.092 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
228895.68 56078.984 260966.31 63936.224 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
653449.97 160093.93 745004.99 182524.73 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1865464.9 457035.16 2126835.6 521070.47 MAarrowhead1
% End of user PostScript
0 .699 1 r
.48875 .50035 m
.48725 .49947 L
.48553 .49862 L
.48355 .49777 L
.48129 .49692 L
.47871 .49604 L
.47576 .49511 L
.47238 .49411 L
.46854 .49302 L
.46415 .49182 L
.45914 .4905 L
.45343 .48901 L
.44691 .48735 L
.43948 .48547 L
.43101 .48334 L
.42135 .48094 L
.41033 .4782 L
.39777 .4751 L
.38345 .47157 L
.36713 .46755 L
.34851 .46297 L
.32729 .45776 L
.3031 .45182 L
.27551 .44505 L
.24406 .43733 L
.2082 .42854 L
.16731 .41852 L
.1207 .4071 L
.06756 .39407 L
.00697 .37922 L
s
.00697 .37922 m
0 .37752 L
s
1 0 0 r
.48875 .50035 m
.48725 .49947 L
s
% Start of user PostScript
-1.3499088 0.041980589 -1.5299202 -0.063867578 MAarrowhead1
% End of user PostScript
1 .158 0 r
.48553 .49862 m
.48355 .49777 L
s
% Start of user PostScript
-1.7366648 -0.16603596 -1.9736377 -0.26707554 MAarrowhead1
% End of user PostScript
1 .473 0 r
.45914 .4905 m
.45343 .48901 L
s
% Start of user PostScript
-4.9033972 -1.1404039 -5.5889219 -1.3184484 MAarrowhead1
% End of user PostScript
1 .788 0 r
.38345 .47157 m
.36713 .46755 L
s
% Start of user PostScript
-13.985409 -3.4120932 -15.944558 -3.8944504 MAarrowhead1
% End of user PostScript
.897 1 0 r
.16731 .41852 m
.1207 .4071 L
s
% Start of user PostScript
-39.922458 -9.7775636 -45.51592 -11.148507 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-113.96968 -27.921554 -129.93798 -31.833886 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-325.35976 -79.712305 -370.94599 -90.88087 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-928.83497 -227.56267 -1058.9743 -259.44654 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2651.6323 -649.64459 -3023.1531 -740.66644 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-7569.8632 -1854.6013 -8630.4785 -2114.45 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-21610.398 -5294.5043 -24638.236 -6036.3185 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-61693.23 -15114.718 -70337.082 -17232.444 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-176121.45 -43149.402 -200797.86 -49195.075 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-502790.41 -123182.64 -573236.49 -140441.79 MAarrowhead1
% End of user PostScript
0 1 .257 r
.43508 .53312 m
.42719 .52307 L
.41799 .51403 L
.40733 .50577 L
.39504 .49804 L
.38092 .49065 L
.36472 .48339 L
.34617 .47611 L
.32495 .46863 L
.30071 .46078 L
.27302 .4524 L
.24142 .44333 L
.20535 .43339 L
.1642 .42238 L
.11727 .41011 L
.06374 .39636 L
.0027 .38086 L
s
.0027 .38086 m
0 .38019 L
s
1 0 0 r
.43508 .53312 m
.42719 .52307 L
s
% Start of user PostScript
-7.7902616 3.9746384 -8.737724 2.7678426 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41799 .51403 m
.40733 .50577 L
s
% Start of user PostScript
-9.8417973 1.6841499 -11.120471 0.69240182 MAarrowhead1
% End of user PostScript
1 .473 0 r
.27302 .4524 m
.24142 .44333 L
s
% Start of user PostScript
-27.237228 -5.7114526 -31.0299 -6.7999592 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-77.554954 -18.775017 -88.415668 -21.473277 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-221.35603 -54.178768 -252.36898 -61.785661 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-631.9147 -154.80539 -720.45211 -176.49894 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1803.9835 -441.96943 -2056.74 -503.89475 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5150.0003 -1261.7391 -5871.568 -1438.5218 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-14702.189 -3602.0066 -16762.116 -4106.6846 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-41971.716 -10282.986 -47852.383 -11723.738 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-119820.59 -29355.805 -136608.68 -33468.854 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-342063.08 -83804.77 -389989.61 -95546.675 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-976519.54 -239245.33 -1113339.9 -272766.05 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2787761.9 -682996.08 -3178355.8 -778690.82 MAarrowhead1
% End of user PostScript
0 1 .388 r
.52702 .46872 m
.52988 .4757 L
.53329 .48178 L
.53731 .48713 L
.542 .49193 L
.54744 .4963 L
.55371 .50037 L
.56092 .50426 L
.56919 .50805 L
.57867 .51185 L
.58951 .51574 L
.6019 .5198 L
.61605 .52412 L
.6322 .52879 L
.65064 .5339 L
.67167 .53955 L
.69566 .54585 L
.72303 .5529 L
.75423 .56083 L
.78982 .56979 L
.83039 .57993 L
.87666 .59144 L
.92941 .6045 L
.98956 .61935 L
s
.98956 .61935 m
1 .62193 L
s
1 0 0 r
.52702 .46872 m
.52988 .4757 L
s
% Start of user PostScript
3.2426234 -3.7531895 3.5856135 -2.9157575 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53329 .48178 m
.53731 .48713 L
s
% Start of user PostScript
3.9951047 -2.1868478 4.4773588 -1.5442483 MAarrowhead1
% End of user PostScript
1 .473 0 r
.58951 .51574 m
.6019 .5198 L
s
% Start of user PostScript
10.741153 1.8882526 12.227901 2.3756459 MAarrowhead1
% End of user PostScript
1 .788 0 r
.75423 .56083 m
.78982 .56979 L
s
% Start of user PostScript
30.507856 7.2998309 34.778045 8.3749335 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
87.057024 21.287816 99.2536 24.282742 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
248.52125 60.877587 283.34139 69.410044 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
709.4749 173.81767 808.87953 198.17198 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2025.404 496.2194 2309.1838 565.74498 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
5782.1107 1416.6054 6592.2435 1615.0864 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
16506.733 4044.1166 18819.496 4610.7387 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
47123.319 11545.119 53725.778 13162.708 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
134527.36 32958.933 153376.02 37576.817 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
384047.86 94090.957 437856.89 107274.06 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1096377.4 268610.28 1249991.1 306245.32 MAarrowhead1
% End of user PostScript
0 .027 1 r
.49912 .5073 m
.49919 .50607 L
.49923 .50504 L
.49924 .50418 L
.49925 .50346 L
.49923 .50285 L
.4992 .50234 L
.49915 .50191 L
.49908 .50154 L
.49899 .50122 L
.49889 .50096 L
.49876 .50072 L
.49861 .50051 L
.49844 .50033 L
.49824 .50016 L
.498 .50001 L
.49774 .49986 L
.49743 .49972 L
.49708 .49957 L
.49667 .49943 L
.49621 .49927 L
.49569 .49911 L
.49509 .49894 L
.4944 .49875 L
.49362 .49853 L
.49273 .4983 L
.49171 .49804 L
.49056 .49774 L
.48923 .49741 L
.48773 .49703 L
.48601 .4966 L
.48405 .49612 L
.48181 .49557 L
.47927 .49494 L
.47636 .49422 L
.47305 .49341 L
.46927 .49248 L
.46497 .49143 L
.46006 .49022 L
.45446 .48885 L
.44808 .48729 L
.44081 .4855 L
.43252 .48347 L
.42306 .48115 L
.41228 .47851 L
.39999 .4755 L
.38598 .47207 L
.37 .46815 L
.35179 .46369 L
.33103 .4586 L
Mistroke
.30735 .4528 L
.28036 .44619 L
.24958 .43865 L
.2145 .43005 L
.1745 .42025 L
.12889 .40908 L
.07689 .39634 L
.01761 .38182 L
Mfstroke
.01761 .38182 m
0 .3775 L
s
1 0 0 r
.49912 .5073 m
.49919 .50607 L
s
% Start of user PostScript
-0.10504582 0.87592182 -0.097689495 0.72834744 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49923 .50504 m
.49924 .50418 L
s
% Start of user PostScript
-0.092959502 0.60487669 -0.090617961 0.50146802 MAarrowhead1
% End of user PostScript
1 .473 0 r
.49889 .50096 m
.49876 .50072 L
s
% Start of user PostScript
-0.13371963 0.11461473 -0.14884708 0.086492956 MAarrowhead1
% End of user PostScript
1 .788 0 r
.49708 .49957 m
.49667 .49943 L
s
% Start of user PostScript
-0.3508274 -0.051347432 -0.39913472 -0.068915531 MAarrowhead1
% End of user PostScript
.897 1 0 r
.49171 .49804 m
.49056 .49774 L
s
% Start of user PostScript
-0.99428097 -0.23547152 -1.133391 -0.27089931 MAarrowhead1
% End of user PostScript
.581 1 0 r
.47636 .49422 m
.47305 .49341 L
s
% Start of user PostScript
-2.8367627 -0.69309331 -3.2341754 -0.79077471 MAarrowhead1
% End of user PostScript
.266 1 0 r
.43252 .48347 m
.42306 .48115 L
s
% Start of user PostScript
-8.0979721 -1.983539 -9.2325699 -2.2615874 MAarrowhead1
% End of user PostScript
0 1 .049 r
.30735 .4528 m
.28036 .44619 L
s
% Start of user PostScript
-23.117946 -5.6637454 -26.357004 -6.4573256 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-65.996947 -16.169095 -75.243793 -18.434558 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-188.40767 -46.159495 -214.80551 -52.626914 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-537.86503 -131.77585 -613.22542 -150.239 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1535.4937 -376.19289 -1750.6321 -428.90136 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4383.5179 -1073.9531 -4997.6936 -1224.4249 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-12514.039 -3065.9146 -14267.384 -3495.4806 MAarrowhead1
% End of user PostScript
1 .046 0 r
.46747 .48572 m
.46276 .48561 L
.45741 .48518 L
.45134 .48442 L
.44443 .48333 L
.43657 .48191 L
.42762 .48014 L
.41743 .478 L
.40582 .47545 L
.39259 .47245 L
.37751 .46896 L
.36032 .46492 L
.34073 .46026 L
.3184 .45491 L
.29294 .44877 L
.26391 .44174 L
.23082 .4337 L
.1931 .42452 L
.15009 .41403 L
.10106 .40206 L
.04516 .3884 L
s
.04516 .3884 m
0 .37735 L
s
1 0 0 r
.46747 .48572 m
.46276 .48561 L
s
% Start of user PostScript
-3.9032319 -1.7130873 -4.4686427 -1.7262331 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45741 .48518 m
.45134 .48442 L
s
% Start of user PostScript
-5.1102037 -1.7788068 -5.839093 -1.870106 MAarrowhead1
% End of user PostScript
1 .473 0 r
.37751 .46896 m
.36032 .46492 L
s
% Start of user PostScript
-14.699086 -3.7249461 -16.761607 -4.2097664 MAarrowhead1
% End of user PostScript
1 .788 0 r
.15009 .41403 m
.10106 .40206 L
s
% Start of user PostScript
-41.988808 -10.316219 -47.872581 -11.75292 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-119.87548 -29.376073 -136.67143 -33.489916 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-342.2212 -83.845111 -390.16993 -95.592189 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-976.97129 -239.35639 -1113.855 -272.89255 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2789.0516 -683.31215 -3179.8263 -779.05114 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7962.1671 -1950.715 -9077.7482 -2224.0301 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-22730.345 -5568.889 -25915.099 -6349.1473 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-64890.447 -15898.03 -73982.262 -18125.506 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-185248.84 -45385.595 -211204.1 -51744.582 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-528847.24 -129566.51 -602944.14 -147720.11 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1509749.8 -369885.68 -1721281.2 -421710.44 MAarrowhead1
% End of user PostScript
.295 1 0 r
.53552 .53148 m
.54106 .52906 L
.54728 .52744 L
.55429 .52653 L
.56222 .52628 L
.5712 .52665 L
.58141 .52763 L
.593 .5292 L
.60619 .53136 L
.6212 .53416 L
.63829 .5376 L
.65775 .54176 L
.67993 .54667 L
.70521 .55244 L
.73401 .55914 L
.76684 .56688 L
.80427 .5758 L
.84693 .58604 L
.89556 .59779 L
.95101 .61122 L
s
.95101 .61122 m
1 .62313 L
s
1 0 0 r
.53552 .53148 m
.54106 .52906 L
s
% Start of user PostScript
4.2627183 3.7777433 4.9268873 3.4876264 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54728 .52744 m
.55429 .52653 L
s
% Start of user PostScript
5.6730269 3.2926131 6.5144585 3.1835385 MAarrowhead1
% End of user PostScript
1 .473 0 r
.63829 .5376 m
.65775 .54176 L
s
% Start of user PostScript
16.594452 4.5123789 18.930442 5.0106757 MAarrowhead1
% End of user PostScript
1 .788 0 r
.89556 .59779 m
.95101 .61122 L
s
% Start of user PostScript
47.467456 11.734336 54.120701 13.346988 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
135.5318 33.229652 154.5218 37.878082 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
386.92051 94.800535 441.13217 108.08133 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1104.5795 270.62112 1259.3424 308.5375 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3153.3469 772.56399 3595.163 880.80801 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
9002.155 2205.51 10263.449 2514.5245 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
25699.296 6296.2761 29300.03 7178.4487 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
73366.189 17974.57 83645.543 20492.991 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
209445.34 51313.689 238790.77 58503.261 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
597923.24 146490. 681698.41 167014.75 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1706947.5 418198.73 1946108.4 476792.65 MAarrowhead1
% End of user PostScript
0 .382 1 r
.42537 .55389 m
.41668 .53981 L
.40648 .52733 L
.39461 .5161 L
.38087 .50579 L
.36504 .49611 L
.34684 .48682 L
.32598 .47768 L
.30209 .46846 L
.27478 .45896 L
.24357 .44897 L
.20793 .43829 L
.16725 .42669 L
.12083 .41396 L
.06787 .39985 L
.00747 .3841 L
s
.00747 .3841 m
0 .38218 L
s
1 0 0 r
.42537 .55389 m
.41668 .53981 L
s
% Start of user PostScript
-8.9552871 6.4670158 -9.9979754 4.7766938 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40648 .52733 m
.39461 .5161 L
s
% Start of user PostScript
-11.221883 3.2796859 -12.646582 1.9318157 MAarrowhead1
% End of user PostScript
1 .473 0 r
.24357 .44897 m
.20793 .43829 L
s
% Start of user PostScript
-30.771472 -6.1233035 -35.048212 -7.4056247 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-87.54925 -21.11699 -99.807658 -24.175344 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-249.86533 -61.138455 -284.8721 -69.727976 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-713.2976 -174.73816 -813.23744 -199.22626 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2036.3137 -498.88847 -2321.622 -568.78914 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5813.2547 -1424.2348 -6627.7511 -1623.7849 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-16595.643 -4065.8991 -18920.862 -4635.5732 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-47377.138 -11607.304 -54015.159 -13233.606 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-135251.96 -33136.459 -154202.14 -37779.216 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-386116.44 -94597.755 -440215.3 -107851.87 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1102282.8 -270057.08 -1256723.9 -307894.84 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3146790.1 -770957.27 -3587687.5 -878976.27 MAarrowhead1
% End of user PostScript
1 .364 0 r
.56073 .49927 m
.56886 .50385 L
.57819 .50829 L
.58888 .51271 L
.60111 .51721 L
.61509 .52189 L
.63107 .52685 L
.6493 .53219 L
.67011 .53801 L
.69386 .54444 L
.72094 .55158 L
.75184 .55957 L
.78707 .56856 L
.82725 .57869 L
.87306 .59016 L
.9253 .60317 L
.98486 .61793 L
s
.98486 .61793 m
1 .62167 L
s
1 0 0 r
.56073 .49927 m
.56886 .50385 L
s
% Start of user PostScript
7.2881747 -0.087200071 8.2634731 0.46200885 MAarrowhead1
% End of user PostScript
1 .158 0 r
.57819 .50829 m
.58888 .51271 L
s
% Start of user PostScript
9.3830165 0.99515663 10.665757 1.525402 MAarrowhead1
% End of user PostScript
1 .473 0 r
.72094 .55158 m
.75184 .55957 L
s
% Start of user PostScript
26.513111 6.1895524 30.220375 7.148537 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
75.625254 18.45616 86.219366 21.063604 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
215.87942 52.87315 246.12593 60.286279 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
616.28769 150.98529 702.6358 172.14106 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1759.3734 431.04204 2005.8796 491.43571 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5022.6481 1230.5385 5726.3724 1402.9496 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
14338.624 3512.9342 16347.612 4005.1322 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
40933.815 10028.703 46669.061 11433.827 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
116857.6 28629.878 133230.54 32641.217 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
333604.34 81732.396 380345.72 93183.941 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
952371.6 233329.13 1085808.6 266020.93 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2718824.5 666106.56 3099759.6 759434.9 MAarrowhead1
% End of user PostScript
1 .054 0 r
.4602 .48179 m
.45442 .48177 L
.44786 .48134 L
.44041 .48049 L
.43194 .47923 L
.4223 .47754 L
.41133 .47542 L
.39883 .47283 L
.3846 .46974 L
.36838 .4661 L
.3499 .46184 L
.32884 .45691 L
.30483 .45122 L
.27746 .44468 L
.24626 .43716 L
.21069 .42856 L
.17015 .41872 L
.12392 .40747 L
.07122 .39462 L
.01113 .37996 L
s
.01113 .37996 m
0 .37724 L
s
1 0 0 r
.4602 .48179 m
.45442 .48177 L
s
% Start of user PostScript
-4.7761109 -2.1852983 -5.4701459 -2.1871549 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44786 .48134 m
.44041 .48049 L
s
% Start of user PostScript
-6.257305 -2.2396891 -7.1513179 -2.3416485 MAarrowhead1
% End of user PostScript
1 .473 0 r
.3499 .46184 m
.32884 .45691 L
s
% Start of user PostScript
-18.01155 -4.5787214 -20.539214 -5.1705051 MAarrowhead1
% End of user PostScript
1 .788 0 r
.07122 .39462 m
.01113 .37996 L
s
% Start of user PostScript
-51.454066 -12.645104 -58.66426 -14.405132 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-146.89892 -35.999089 -167.48118 -41.040187 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-419.36803 -102.74648 -478.12583 -117.14166 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1197.2097 -293.31448 -1364.951 -334.41069 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3417.7868 -837.35105 -3896.6537 -954.67247 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-9757.0765 -2390.4643 -11124.143 -2725.3927 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-27854.441 -6824.2823 -31757.133 -7780.4341 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-79518.685 -19481.919 -90660.066 -22211.535 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-227009.44 -55616.859 -258815.79 -63409.35 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-648065.14 -158774.66 -738865.7 -181020.62 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1850092.3 -453268.92 -2109309.2 -516776.53 MAarrowhead1
% End of user PostScript
1 .95 0 r
.5235 .55613 m
.52803 .54889 L
.53298 .54314 L
.53846 .53868 L
.54457 .53533 L
.55141 .53296 L
.55911 .53147 L
.56781 .53079 L
.57766 .53085 L
.58883 .53163 L
.60152 .5331 L
.61594 .53527 L
.63235 .53816 L
.65104 .54179 L
.67232 .54621 L
.69656 .55148 L
.72418 .5577 L
.75566 .56495 L
.79153 .57336 L
.83243 .58306 L
.87904 .59421 L
.93218 .60701 L
.99276 .62166 L
s
.99276 .62166 m
1 .62342 L
s
1 0 0 r
.5235 .55613 m
.52803 .54889 L
s
% Start of user PostScript
2.8202079 6.7350673 3.3633196 5.8668055 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53298 .54314 m
.53846 .53868 L
s
% Start of user PostScript
3.9580125 5.1770691 4.6155749 4.6411413 MAarrowhead1
% End of user PostScript
1 .473 0 r
.60152 .5331 m
.61594 .53527 L
s
% Start of user PostScript
12.181875 3.9724455 13.912867 4.2328689 MAarrowhead1
% End of user PostScript
1 .788 0 r
.79153 .57336 m
.83243 .58306 L
s
% Start of user PostScript
34.983973 8.8029697 39.891264 9.9668167 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
99.920686 24.534835 113.92193 27.956088 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
285.26438 69.90199 325.23315 79.69214 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
814.37364 199.52292 928.47579 227.47722 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2324.8694 569.58906 2650.6074 649.3941 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
6637.0228 1626.0575 7566.9376 1853.8847 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
18947.331 4642.0583 21602.046 5292.4581 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
54090.723 13252.119 61669.387 15108.876 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
154417.86 37832.066 176053.38 43132.726 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
440831.14 108002.75 502596.09 123135.04 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1258482. 308325.57 1434808.2 351525.13 MAarrowhead1
% End of user PostScript
.069 0 1 r
.49692 .43009 m
.49479 .44102 L
.49265 .45006 L
.49044 .45749 L
.48812 .46358 L
.48564 .46852 L
.48294 .47249 L
.47998 .47563 L
.4767 .47805 L
.47303 .47985 L
.46892 .48108 L
.46429 .48182 L
.45906 .4821 L
.45313 .48195 L
.4464 .48139 L
.43876 .48043 L
.43007 .47905 L
.42018 .47726 L
.40892 .47503 L
.39609 .47233 L
.38148 .46911 L
.36482 .46534 L
.34585 .46095 L
.32422 .45586 L
.29956 .45 L
.27146 .44326 L
.23942 .43553 L
.20289 .42669 L
.16125 .41657 L
.11378 .40501 L
.05965 .39181 L
s
.05965 .39181 m
0 .37725 L
s
1 0 0 r
.49692 .43009 m
.49479 .44102 L
s
% Start of user PostScript
-0.36973883 -8.3893884 -0.62471369 -7.0770032 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49265 .45006 m
.49044 .45749 L
s
% Start of user PostScript
-0.88175407 -5.9928944 -1.1467256 -5.1007649 MAarrowhead1
% End of user PostScript
1 .473 0 r
.46892 .48108 m
.46429 .48182 L
s
% Start of user PostScript
-3.7290218 -2.2700404 -4.2847041 -2.181462 MAarrowhead1
% End of user PostScript
1 .788 0 r
.40892 .47503 m
.39609 .47233 L
s
% Start of user PostScript
-10.930124 -2.9963569 -12.469344 -3.3206974 MAarrowhead1
% End of user PostScript
.897 1 0 r
.23942 .43553 m
.20289 .42669 L
s
% Start of user PostScript
-31.27006 -7.7358872 -35.653146 -8.797345 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-89.28526 -21.89227 -101.79547 -24.954337 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-254.89469 -62.452811 -290.60814 -71.201852 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-727.67262 -178.2793 -829.62702 -203.25777 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2077.3555 -508.94815 -2368.4142 -580.25693 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-5930.4214 -1452.9414 -6761.3341 -1656.5134 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-16930.13 -4147.848 -19302.214 -4729.0039 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-48332.029 -11841.25 -55103.841 -13500.331 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-137977.98 -33804.328 -157310.1 -38540.66 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-393898.66 -96504.384 -449087.89 -110025.64 MAarrowhead1
% End of user PostScript
0 1 .286 r
.47656 .45255 m
.47225 .45841 L
.46751 .46301 L
.46225 .46653 L
.45637 .4691 L
.44976 .47083 L
.44231 .4718 L
.43388 .47206 L
.42433 .47167 L
.41349 .47063 L
.40117 .46897 L
.38715 .46666 L
.3712 .4637 L
.35304 .46004 L
.33235 .45562 L
.30878 .4504 L
.28192 .44427 L
.25131 .43715 L
.21642 .42892 L
.17664 .41944 L
.13131 .40856 L
.07962 .39608 L
.0207 .3818 L
s
.0207 .3818 m
0 .37677 L
s
1 0 0 r
.47656 .45255 m
.47225 .45841 L
s
% Start of user PostScript
-2.8130888 -5.6937213 -3.3297516 -4.9912093 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46751 .46301 m
.46225 .46653 L
s
% Start of user PostScript
-3.8985063 -4.4388147 -4.5300143 -4.0163941 MAarrowhead1
% End of user PostScript
1 .473 0 r
.40117 .46897 m
.38715 .46666 L
s
% Start of user PostScript
-11.860194 -3.7237115 -13.541955 -4.0002244 MAarrowhead1
% End of user PostScript
1 .788 0 r
.21642 .42892 m
.17664 .41944 L
s
% Start of user PostScript
-34.029995 -8.5293483 -38.802648 -9.666819 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-97.188907 -23.856186 -110.80717 -27.185162 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-277.46374 -67.988651 -316.33951 -77.511382 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-792.10398 -194.06638 -903.08592 -221.25632 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2261.294 -554.01309 -2578.1245 -631.63582 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6455.5282 -1581.5916 -7360.0137 -1803.1887 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-18429.202 -4515.1175 -21011.321 -5147.7317 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-52611.57 -12889.729 -59982.989 -14695.712 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-150195.18 -36797.518 -171239.06 -41953.227 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-428776.26 -105049.33 -488852.2 -119767.81 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1224067.8 -299894.16 -1395572.2 -341912.4 MAarrowhead1
% End of user PostScript
0 1 .821 r
.45494 .55171 m
.45016 .54014 L
.44446 .53007 L
.43775 .52119 L
.42992 .51323 L
.42084 .50597 L
.41037 .49921 L
.39833 .49275 L
.38452 .48644 L
.3687 .48012 L
.3506 .47365 L
.32992 .46689 L
.3063 .45968 L
.27934 .45189 L
.24857 .44337 L
.21346 .43394 L
.17342 .42345 L
.12774 .41168 L
.07566 .39844 L
.01626 .38349 L
s
.01626 .38349 m
0 .37943 L
s
1 0 0 r
.45494 .55171 m
.45016 .54014 L
s
% Start of user PostScript
-5.4074678 6.2048299 -5.9807691 4.8169437 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44446 .53007 m
.43775 .52119 L
s
% Start of user PostScript
-6.6649352 3.6085559 -7.4704399 2.5428633 MAarrowhead1
% End of user PostScript
1 .473 0 r
.3506 .47365 m
.32992 .46689 L
s
% Start of user PostScript
-17.927532 -3.16149 -20.409232 -3.9733935 MAarrowhead1
% End of user PostScript
1 .788 0 r
.07566 .39844 m
.01626 .38349 L
s
% Start of user PostScript
-50.921241 -12.186623 -58.048753 -13.980724 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-145.30902 -35.532566 -165.66664 -40.531383 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-414.81306 -101.61244 -472.93222 -115.85415 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1184.2024 -290.12347 -1350.1212 -330.77386 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3380.6528 -828.25229 -3854.3168 -944.29917 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-9651.0663 -2364.4917 -11003.279 -2695.7813 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-27551.804 -6750.1367 -31412.093 -7695.8999 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-78654.717 -19270.248 -89675.047 -21970.207 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-224542.99 -55012.584 -256003.77 -62720.41 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-641023.94 -157049.58 -730837.95 -179053.83 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1829991.1 -448344.17 -2086391.6 -511161.77 MAarrowhead1
% End of user PostScript
.975 0 1 r
.48071 .55751 m
.47953 .54691 L
.47793 .53792 L
.4759 .53024 L
.47341 .52364 L
.47043 .51792 L
.4669 .51288 L
.46277 .50839 L
.45799 .50432 L
.45246 .50054 L
.4461 .49697 L
.43879 .49349 L
.43042 .49004 L
.42085 .48652 L
.4099 .48286 L
.3974 .47898 L
.38313 .4748 L
.36683 .47024 L
.34825 .46521 L
.32704 .45962 L
.30286 .45336 L
.27528 .44633 L
.24383 .4384 L
.20796 .42942 L
.16707 .41924 L
.12044 .40768 L
.06728 .39454 L
.00666 .3796 L
s
.00666 .3796 m
0 .37796 L
s
1 0 0 r
.48071 .55751 m
.47953 .54691 L
s
% Start of user PostScript
-2.3147842 6.9012834 -2.4562683 5.6293384 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47793 .53792 m
.4759 .53024 L
s
% Start of user PostScript
-2.6478669 4.5500945 -2.8915831 3.6291023 MAarrowhead1
% End of user PostScript
1 .473 0 r
.4461 .49697 m
.43879 .49349 L
s
% Start of user PostScript
-6.4685737 -0.36407914 -7.3450018 -0.78103569 MAarrowhead1
% End of user PostScript
1 .788 0 r
.34825 .46521 m
.32704 .45962 L
s
% Start of user PostScript
-18.21038 -4.174878 -20.754823 -4.8457469 MAarrowhead1
% End of user PostScript
.897 1 0 r
.06728 .39454 m
.00666 .3796 L
s
% Start of user PostScript
-51.926753 -12.654649 -59.200574 -14.44787 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-148.22605 -36.299283 -168.99365 -41.389921 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-423.15149 -103.66756 -482.43925 -118.19356 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1208.0095 -295.95903 -1377.2639 -337.42618 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-3448.6177 -844.90422 -3931.8043 -963.284 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-9845.0921 -2412.0278 -11224.49 -2749.9776 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-28105.707 -6885.8421 -32043.605 -7850.619 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-80235.998 -19657.659 -91477.882 -22411.898 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-229057.23 -56118.562 -261150.49 -63981.346 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-653911.14 -160206.92 -745530.78 -182653.55 MAarrowhead1
% End of user PostScript
0 1 .44 r
.52378 .43367 m
.52535 .44601 L
.52743 .45649 L
.53004 .46545 L
.53322 .47317 L
.53702 .4799 L
.5415 .48583 L
.54672 .49114 L
.55276 .49598 L
.55974 .5005 L
.56777 .50481 L
.57697 .50902 L
.58751 .51323 L
.59958 .51755 L
.61336 .52206 L
.6291 .52686 L
.64707 .53205 L
.66758 .53774 L
.69098 .54402 L
.71767 .55102 L
.74811 .55886 L
.78283 .56768 L
.82242 .57765 L
.86756 .58893 L
.91903 .60173 L
.97772 .61626 L
s
.97772 .61626 m
1 .62176 L
s
1 0 0 r
.52378 .43367 m
.52535 .44601 L
s
% Start of user PostScript
2.8541446 -7.9598979 3.0420466 -6.4793092 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52743 .45649 m
.53004 .46545 L
s
% Start of user PostScript
3.2913963 -5.2213267 3.6049846 -4.1458938 MAarrowhead1
% End of user PostScript
1 .473 0 r
.56777 .50481 m
.57697 .50902 L
s
% Start of user PostScript
8.1318425 0.57694775 9.2365467 1.0820754 MAarrowhead1
% End of user PostScript
1 .788 0 r
.69098 .54402 m
.71767 .55102 L
s
% Start of user PostScript
22.917842 5.2824971 26.12073 6.1222547 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
65.356001 15.934057 74.511135 18.189974 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
186.56154 45.68888 212.70027 52.095852 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
532.59086 130.47939 607.21218 148.76218 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1520.4362 372.50281 1733.4648 424.69456 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
4340.5314 1063.4213 4948.6843 1212.4175 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
12391.322 3035.849 14127.473 3461.2026 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
35374.669 8666.723 40331.022 9881.0195 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
100987.38 24741.707 115136.75 28208.273 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
288298.15 70632.47 328691.67 80528.801 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
823031.76 201641.13 938346.92 229893.12 MAarrowhead1
% End of user PostScript
.762 0 1 r
.45306 .44085 m
.44532 .44685 L
.43669 .45132 L
.427 .45444 L
.4161 .45635 L
.40378 .45716 L
.38983 .45693 L
.374 .45572 L
.35601 .45353 L
.33557 .45038 L
.3123 .44622 L
.28581 .44103 L
.25564 .43471 L
.22127 .42719 L
.1821 .41834 L
.13747 .40803 L
.0866 .39609 L
.02862 .38232 L
s
.02862 .38232 m
0 .37547 L
s
1 0 0 r
.45306 .44085 m
.44532 .44685 L
s
% Start of user PostScript
-5.6322358 -7.0981785 -6.5613645 -6.37847 MAarrowhead1
% End of user PostScript
1 .158 0 r
.43669 .45132 m
.427 .45444 L
s
% Start of user PostScript
-7.5974808 -5.8419186 -8.7594171 -5.4671372 MAarrowhead1
% End of user PostScript
1 .473 0 r
.3123 .44622 m
.28581 .44103 L
s
% Start of user PostScript
-22.524229 -6.4530445 -25.702986 -7.0769906 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-64.498087 -16.021364 -73.540302 -18.20033 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-184.17477 -45.173981 -209.9808 -51.48787 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-525.7918 -128.83004 -599.4609 -146.87682 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1501.0297 -367.75211 -1711.3394 -419.27709 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4285.1307 -1049.8491 -4885.5214 -1196.9435 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-12233.165 -2997.101 -13947.156 -3417.0255 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-34923.162 -8556.1048 -39816.254 -9754.9026 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-99698.424 -24425.914 -113667.19 -27848.235 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-284618.44 -69730.948 -324496.39 -79500.967 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-812526.94 -199067.47 -926370.28 -226958.86 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2319596.8 -568296.58 -2644596.1 -647920.75 MAarrowhead1
% End of user PostScript
0 1 .743 r
.54123 .48483 m
.54639 .49028 L
.55238 .49524 L
.55928 .49985 L
.56723 .50423 L
.57635 .50849 L
.5868 .51274 L
.59875 .51708 L
.61241 .52161 L
.62802 .52641 L
.64583 .5316 L
.66616 .53726 L
.68936 .54352 L
.71582 .55048 L
.746 .55827 L
.78042 .56703 L
.81967 .57692 L
.86442 .58812 L
.91545 .60081 L
.97364 .61523 L
s
.97364 .61523 m
1 .62174 L
s
1 0 0 r
.54123 .48483 m
.54639 .49028 L
s
% Start of user PostScript
4.9479449 -1.8198969 5.5669701 -1.1659067 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55238 .49524 m
.55928 .49985 L
s
% Start of user PostScript
6.2850251 -0.57087497 7.1139476 -0.018114351 MAarrowhead1
% End of user PostScript
1 .473 0 r
.64583 .5316 m
.66616 .53726 L
s
% Start of user PostScript
17.499697 3.7917891 19.93945 4.4716295 MAarrowhead1
% End of user PostScript
1 .788 0 r
.91545 .60081 m
.97364 .61523 L
s
% Start of user PostScript
49.854064 12.097776 56.836279 13.827684 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
142.29866 34.835563 162.23549 39.724572 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
406.22759 99.518531 463.14408 113.46402 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1159.6946 284.12136 1322.1797 323.93012 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3310.6887 811.11176 3774.5501 924.75692 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
9451.3334 2315.5577 10775.562 2639.991 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
26981.608 6610.4398 30762.007 7536.6301 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
77026.925 18871.442 87819.185 21515.524 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
219895.98 53874.076 250705.66 61422.385 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
627757.68 153799.37 715712.95 175348.24 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1792118.7 439065.49 2043212.9 500583.06 MAarrowhead1
% End of user PostScript
.95 1 0 r
.44188 .55113 m
.43534 .53869 L
.42761 .52777 L
.41858 .51802 L
.4081 .50916 L
.396 .50095 L
.38208 .49316 L
.3661 .48559 L
.34779 .47806 L
.32684 .47038 L
.30289 .46239 L
.27553 .45392 L
.2443 .44479 L
.20866 .43483 L
.16799 .42383 L
.1216 .41161 L
.06868 .39793 L
.00834 .38255 L
s
.00834 .38255 m
0 .38045 L
s
1 0 0 r
.44188 .55113 m
.43534 .53869 L
s
% Start of user PostScript
-6.9745437 6.1350566 -7.7597171 4.643216 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42761 .52777 m
.41858 .51802 L
s
% Start of user PostScript
-8.686715 3.3319112 -9.770138 2.1618996 MAarrowhead1
% End of user PostScript
1 .473 0 r
.30289 .46239 m
.27553 .45392 L
s
% Start of user PostScript
-23.653423 -4.512973 -26.936122 -5.5296265 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-67.256709 -16.176723 -76.672691 -18.533492 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-191.94088 -46.954448 -218.83203 -53.554436 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-547.93681 -134.22682 -624.70795 -153.03835 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1564.2431 -383.23253 -1783.4095 -436.9285 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4465.5906 -1094.0598 -5091.2655 -1247.3491 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-12748.34 -3123.3176 -14534.513 -3560.9264 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-36393.881 -8916.428 -41493.036 -10165.711 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-103897.02 -25454.563 -118454.06 -29021.008 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-296604.58 -72667.528 -338161.91 -82848.992 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-846744.89 -207450.8 -965382.52 -236516.78 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2417282. -592229.26 -2755968. -675206.64 MAarrowhead1
% End of user PostScript
.588 1 0 r
.45149 .51123 m
.44526 .50587 L
.43807 .50092 L
.42978 .49622 L
.42027 .49167 L
.40938 .48714 L
.39691 .48254 L
.38265 .47776 L
.36637 .47269 L
.34778 .46724 L
.32657 .46129 L
.30236 .45473 L
.27474 .44744 L
.24325 .43929 L
.20733 .43013 L
.16637 .41979 L
.11966 .40809 L
.0664 .39483 L
.00567 .37978 L
s
.00567 .37978 m
0 .37838 L
s
1 0 0 r
.45149 .51123 m
.44526 .50587 L
s
% Start of user PostScript
-5.8208238 1.347686 -6.5684734 0.70498487 MAarrowhead1
% End of user PostScript
1 .158 0 r
.43807 .50092 m
.42978 .49622 L
s
% Start of user PostScript
-7.4321265 0.10999273 -8.4261725 -0.45342816 MAarrowhead1
% End of user PostScript
1 .473 0 r
.32657 .46129 m
.30236 .45473 L
s
% Start of user PostScript
-20.81216 -4.6455644 -23.717057 -5.4323682 MAarrowhead1
% End of user PostScript
1 .788 0 r
.00567 .37978 m
0 0 rlineto s
.00567 .37978 m
0 .37838 L
s
% Start of user PostScript
-59.319321 -14.426661 -67.627959 -16.479896 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-169.3221 -41.458579 -193.04524 -47.274843 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-483.37442 -118.4199 -551.09998 -135.01349 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1379.933 -338.07946 -1573.2757 -385.44826 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3939.424 -965.15066 -4491.3775 -1100.3782 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-11246.243 -2755.3069 -12821.956 -3141.3536 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-32105.704 -7865.8331 -36604.041 -8967.9168 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-91655.162 -22455.331 -104496.99 -25601.553 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-261656.59 -64105.34 -298317.35 -73087.153 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-746975.58 -183007.52 -851634.5 -208648.75 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2132461.2 -522448.73 -2431240.9 -595649.14 MAarrowhead1
% End of user PostScript
1 .58 0 r
.5461 .47352 m
.55163 .48113 L
.5581 .48794 L
.56559 .49413 L
.57425 .49989 L
.5842 .50536 L
.59563 .51069 L
.60871 .516 L
.62368 .52143 L
.64079 .52709 L
.66034 .53311 L
.68265 .5396 L
.70812 .54669 L
.73717 .55452 L
.77032 .56324 L
.80812 .57299 L
.85123 .58397 L
.90039 .59636 L
.95644 .61038 L
s
.95644 .61038 m
1 .62121 L
s
1 0 0 r
.5461 .47352 m
.55163 .48113 L
s
% Start of user PostScript
5.5320332 -3.1777327 6.1961494 -2.2640369 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5581 .48794 m
.56559 .49413 L
s
% Start of user PostScript
6.9717007 -1.4474552 7.8712544 -0.70429679 MAarrowhead1
% End of user PostScript
1 .473 0 r
.66034 .53311 m
.68265 .5396 L
s
% Start of user PostScript
19.240846 3.9730396 21.918546 4.7518196 MAarrowhead1
% End of user PostScript
1 .788 0 r
.95644 .61038 m
0 0 rlineto s
.95644 .61038 m
1 .62121 L
s
% Start of user PostScript
54.773225 13.245357 62.443255 15.153321 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
156.32977 38.25963 178.23217 43.632442 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
446.28067 109.32828 508.80893 124.64917 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1274.0373 312.13433 1452.5429 355.86822 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3637.1132 891.08491 4146.7099 1015.9352 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
10383.208 2543.865 11838.001 2900.2866 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
29641.917 7262.2102 33795.053 8279.7202 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
84621.559 20732.113 96477.905 23636.894 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
241577.1 59185.905 275424.52 67478.456 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
689652.79 168963.55 786280.2 192637.07 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1968816.5 482356.09 2244667.8 549939.12 MAarrowhead1
% End of user PostScript
0 .524 1 r
.45339 .53163 m
.44791 .52316 L
.44149 .51563 L
.43403 .50884 L
.42539 .50258 L
.41545 .49669 L
.40403 .49101 L
.39094 .4854 L
.37596 .47972 L
.35883 .47385 L
.33925 .46765 L
.3169 .46101 L
.29139 .45379 L
.26229 .44585 L
.22908 .43703 L
.1912 .42719 L
.14801 .41614 L
.09875 .40367 L
.04258 .38958 L
s
.04258 .38958 m
0 .37897 L
s
1 0 0 r
.45339 .53163 m
.44791 .52316 L
s
% Start of user PostScript
-5.593628 3.7959099 -6.2508706 2.7789853 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44149 .51563 m
.43403 .50884 L
s
% Start of user PostScript
-7.0211537 1.8761623 -7.9168441 1.0609198 MAarrowhead1
% End of user PostScript
1 .473 0 r
.33925 .46765 m
.3169 .46101 L
s
% Start of user PostScript
-19.289554 -3.8814655 -21.971545 -4.6784447 MAarrowhead1
% End of user PostScript
1 .788 0 r
.04258 .38958 m
0 0 rlineto s
.04258 .38958 m
0 .37897 L
s
% Start of user PostScript
-54.890564 -13.2498 -62.57644 -15.165673 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-156.65965 -38.334743 -178.60813 -43.71979 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-447.22122 -109.55737 -509.88122 -124.91076 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1276.722 -312.79178 -1455.6038 -356.61788 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3644.7776 -892.96261 -4155.4482 -1018.076 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-10405.088 -2549.2256 -11862.947 -2906.3983 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-29704.381 -7277.5138 -33866.268 -8297.1679 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-84799.88 -20775.801 -96681.211 -23686.703 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-242086.17 -59310.627 -276004.92 -67620.652 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-691106.08 -169319.61 -787937.11 -193043.02 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1972965.3 -483372.55 -2249397.9 -551097.99 MAarrowhead1
% End of user PostScript
1 0 .57 r
.53639 .47976 m
.54077 .48566 L
.54589 .49095 L
.55182 .49576 L
.55867 .50025 L
.56655 .50452 L
.57558 .50868 L
.58593 .51285 L
.59777 .51711 L
.6113 .52156 L
.62675 .52629 L
.6444 .5314 L
.66453 .53699 L
.6875 .54317 L
.7137 .55005 L
.74359 .55775 L
.77767 .56642 L
.81654 .57621 L
.86085 .58729 L
.91139 .59985 L
.969 .61413 L
s
.969 .61413 m
1 .62178 L
s
1 0 0 r
.53639 .47976 m
.54077 .48566 L
s
% Start of user PostScript
4.3667033 -2.4287885 4.8928701 -1.7202658 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54589 .49095 m
.55182 .49576 L
s
% Start of user PostScript
5.5069483 -1.0862289 6.2189043 -0.50832769 MAarrowhead1
% End of user PostScript
1 .473 0 r
.62675 .52629 m
.6444 .5314 L
s
% Start of user PostScript
15.210331 3.1546516 17.327454 3.7680801 MAarrowhead1
% End of user PostScript
1 .788 0 r
.86085 .58729 m
.91139 .59985 L
s
% Start of user PostScript
43.302403 10.474729 49.366225 11.982598 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
123.59126 30.248084 140.90689 34.495601 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
352.82095 86.433024 402.25459 98.545394 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1007.2295 246.76747 1148.3526 281.34264 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2875.4321 704.4747 3278.3095 803.17893 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
8208.7655 2011.131 9358.8975 2292.9111 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
23434.332 5741.3645 26717.722 6545.7884 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
66900.186 16390.412 76273.586 18686.876 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
190986.23 46791.245 217745.36 53347.177 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
545226.3 133579.35 621618.09 152295.19 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1556508.6 381341.5 1774591.4 434771.35 MAarrowhead1
% End of user PostScript
0 1 .047 r
.54135 .53829 m
.54784 .53521 L
.55511 .5331 L
.56331 .53186 L
.57259 .53143 L
.58309 .53174 L
.59501 .53277 L
.60855 .53452 L
.62396 .53698 L
.64149 .54018 L
.66145 .54416 L
.68418 .54896 L
.71008 .55467 L
.73959 .56137 L
.77323 .56917 L
.81156 .57819 L
.85526 .58859 L
.90507 .60054 L
.96186 .61424 L
s
.96186 .61424 m
1 .62347 L
s
1 0 0 r
.54135 .53829 m
.54784 .53521 L
s
% Start of user PostScript
4.962271 4.5942183 5.7402475 4.2251133 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55511 .5331 m
.56331 .53186 L
s
% Start of user PostScript
6.6135236 3.9720826 7.5977221 3.8235921 MAarrowhead1
% End of user PostScript
1 .473 0 r
.66145 .54416 m
.68418 .54896 L
s
% Start of user PostScript
19.373572 5.2986969 22.101527 5.8755563 MAarrowhead1
% End of user PostScript
1 .788 0 r
.96186 .61424 m
0 0 rlineto s
.96186 .61424 m
1 .62347 L
s
% Start of user PostScript
55.423388 13.708281 63.191947 15.590081 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
158.24954 38.801266 180.42267 44.228594 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
451.77619 110.69141 515.07483 126.19827 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1289.7293 315.98279 1470.4337 360.2547 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3681.9116 902.06137 4197.7851 1028.4493 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
10511.098 2575.1982 11983.811 2936.0097 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
30007.018 7351.6594 34211.308 8381.7021 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
85663.848 20987.471 97666.229 23928.031 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
244552.62 59914.902 278816.94 68309.592 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
698147.28 171044.69 795964.86 195009.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1993066.5 488297.3 2272315.5 556712.75 MAarrowhead1
% End of user PostScript
0 1 .293 r
.42082 .52163 m
.41073 .51236 L
.39906 .50383 L
.38562 .4958 L
.37017 .48807 L
.35247 .48044 L
.33221 .47273 L
.30903 .46476 L
.28256 .45636 L
.25233 .44736 L
.21783 .43757 L
.17846 .42682 L
.13354 .41489 L
.08231 .40156 L
.02388 .3866 L
s
.02388 .3866 m
0 .38056 L
s
1 0 0 r
.42082 .52163 m
.41073 .51236 L
s
% Start of user PostScript
-9.5016954 2.5950047 -10.712458 1.4827987 MAarrowhead1
% End of user PostScript
1 .158 0 r
.39906 .50383 m
.38562 .4958 L
s
% Start of user PostScript
-12.112828 0.45925418 -13.726062 -0.5037113 MAarrowhead1
% End of user PostScript
1 .473 0 r
.21783 .43757 m
.17846 .42682 L
s
% Start of user PostScript
-33.86078 -7.4911763 -38.585322 -8.7819847 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-96.496755 -23.452577 -110.01231 -26.795162 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-275.4387 -67.437568 -314.02939 -76.89956 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-786.31138 -192.6343 -896.48139 -219.62746 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2244.7546 -549.95794 -2559.2676 -627.01341 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6408.311 -1570.0228 -7306.1809 -1789.9992 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-18294.406 -4482.0927 -20857.639 -5110.0798 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-52226.756 -12795.451 -59544.259 -14588.224 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-149096.62 -36528.373 -169986.58 -41646.371 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-425640.09 -104280.97 -485276.62 -118891.8 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1215114.7 -297700.66 -1385364.7 -339411.57 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3468901.8 -849873.99 -3954930.4 -968950.03 MAarrowhead1
% End of user PostScript
0 1 .745 r
.48551 .46529 m
.48272 .46977 L
.47966 .47333 L
.47628 .47609 L
.47252 .47817 L
.4683 .47964 L
.46355 .48056 L
.45818 .48099 L
.45211 .48095 L
.44522 .48047 L
.43739 .47957 L
.4285 .47823 L
.41838 .47646 L
.40685 .47422 L
.39373 .4715 L
.37878 .46824 L
.36174 .46441 L
.34233 .45994 L
.3202 .45475 L
.29498 .44877 L
.26624 .4419 L
.23346 .434 L
.1961 .42497 L
.15351 .41463 L
.10495 .40281 L
.04959 .38931 L
s
.04959 .38931 m
0 .37721 L
s
1 0 0 r
.48551 .46529 m
.48272 .46977 L
s
% Start of user PostScript
-1.7383876 -4.1647278 -2.0734871 -3.6274193 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47966 .47333 m
.47628 .47609 L
s
% Start of user PostScript
-2.4403733 -3.2005149 -2.8460119 -2.868721 MAarrowhead1
% End of user PostScript
1 .473 0 r
.43739 .47957 m
.4285 .47823 L
s
% Start of user PostScript
-7.5127079 -2.4517087 -8.5802763 -2.6120189 MAarrowhead1
% End of user PostScript
1 .788 0 r
.3202 .45475 m
.29498 .44877 L
s
% Start of user PostScript
-21.575422 -5.4294271 -24.601873 -6.1471292 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-61.623481 -15.131322 -70.258386 -17.241275 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-175.9294 -43.110261 -200.5791 -49.148078 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-502.2438 -123.05058 -572.61334 -140.29067 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1433.8028 -351.27926 -1634.6933 -400.49695 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-4093.2115 -1002.8287 -4666.7123 -1143.3353 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-11685.275 -2862.8689 -13322.501 -3263.9861 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-33359.049 -8172.9003 -38032.993 -9318.0072 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-95233.205 -23331.945 -108576.35 -26600.989 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-271871.16 -66607.89 -309963.09 -75940.336 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-776136.08 -190151.79 -884880.69 -216794. MAarrowhead1
% End of user PostScript
1 0 .552 r
.55569 .46667 m
.56234 .47608 L
.57012 .48448 L
.57914 .49211 L
.58956 .49918 L
.60155 .50589 L
.61531 .51241 L
.63108 .5189 L
.64912 .52551 L
.66975 .53239 L
.69331 .53968 L
.7202 .54754 L
.7509 .55613 L
.78592 .56559 L
.82587 .57612 L
.87144 .5879 L
.92341 .60114 L
.98267 .61609 L
s
.98267 .61609 m
1 .62043 L
s
1 0 0 r
.55569 .46667 m
.56234 .47608 L
s
% Start of user PostScript
6.6825484 -3.9994619 7.4808452 -2.8700594 MAarrowhead1
% End of user PostScript
1 .158 0 r
.57012 .48448 m
.57914 .49211 L
s
% Start of user PostScript
8.4138532 -1.8623581 9.4966595 -0.94703181 MAarrowhead1
% End of user PostScript
1 .473 0 r
.69331 .53968 m
.7202 .54754 L
s
% Start of user PostScript
23.196746 4.7618433 26.424291 5.7052185 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
66.028663 15.960561 75.274658 18.261651 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
188.45284 46.119773 214.85576 52.596852 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
537.98333 131.79291 613.36 150.26202 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1535.8289 376.27221 1751.0142 428.99264 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4384.4743 1074.1868 4998.7839 1224.6915 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
12516.77 3066.5833 14270.497 3496.2431 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
35732.796 8754.4634 40739.326 9981.0532 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
102009.76 24992.187 116302.37 28493.849 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
291216.83 71347.54 332019.29 81344.061 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
831363.99 203682.51 947846.59 232220.52 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2373372.7 581471.57 2705906.5 662941.68 MAarrowhead1
% End of user PostScript
.77 1 0 r
.43412 .46783 m
.42449 .46813 L
.41358 .46767 L
.4012 .46649 L
.38713 .46458 L
.37113 .46195 L
.35292 .45856 L
.33217 .45437 L
.30855 .44933 L
.28163 .44336 L
.25096 .43637 L
.21601 .42824 L
.17616 .41884 L
.13074 .40801 L
.07897 .39558 L
.01995 .38133 L
s
.01995 .38133 m
0 .37649 L
s
1 0 0 r
.43412 .46783 m
.42449 .46813 L
s
% Start of user PostScript
-7.9061997 -3.859999 -9.0610178 -3.8243465 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41358 .46767 m
.4012 .46649 L
s
% Start of user PostScript
-10.369838 -3.8792032 -11.855531 -4.0214282 MAarrowhead1
% End of user PostScript
1 .473 0 r
.25096 .43637 m
.21601 .42824 L
s
% Start of user PostScript
-29.884546 -7.6359673 -34.079372 -8.6116193 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-85.380149 -20.991768 -97.344588 -23.910805 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-243.7582 -59.7376 -277.91164 -68.102253 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-695.88301 -170.49401 -793.38344 -194.38075 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1986.6033 -486.7148 -2264.9468 -554.90823 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5671.343 -1389.4679 -6465.9562 -1584.1465 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-16190.515 -3966.6437 -18458.971 -4522.4111 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-46220.58 -11323.95 -52696.556 -12910.551 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-131950.22 -32327.54 -150437.8 -36856.96 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-376690.67 -92288.46 -429468.89 -105219.02 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1075374.2 -263464.52 -1226045.1 -300378.59 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3069971.5 -752136.87 -3500105.9 -857518.93 MAarrowhead1
% End of user PostScript
0 1 .392 r
.57215 .52694 m
.58248 .52794 L
.59423 .52954 L
.60759 .53174 L
.6228 .53458 L
.64011 .53807 L
.65983 .54228 L
.6823 .54727 L
.70791 .55311 L
.73709 .5599 L
.77036 .56775 L
.80827 .57679 L
.8515 .58717 L
.90077 .59907 L
.95695 .61268 L
s
.95695 .61268 m
1 .62315 L
s
1 0 0 r
.57215 .52694 m
.58248 .52794 L
s
% Start of user PostScript
8.6576922 3.2332351 9.8979502 3.3528525 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59423 .52954 m
.60759 .53174 L
s
% Start of user PostScript
11.30747 3.5444622 12.910715 3.8090007 MAarrowhead1
% End of user PostScript
1 .473 0 r
.77036 .56775 m
.80827 .57679 L
s
% Start of user PostScript
32.442888 8.130218 36.992919 9.2148519 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
92.655884 22.743188 105.63897 25.916946 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
264.52239 64.817479 301.58493 73.896066 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
755.15898 185.01479 860.96453 210.93655 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2155.8236 528.17303 2457.8766 602.1753 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6154.4319 1507.8236 7016.7308 1719.0851 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
17569.634 4304.5252 20031.319 4907.6332 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
50157.681 12288.531 57185.285 14010.28 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
143189.83 35081.223 163252.19 39996.461 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
408777.44 100149.66 466051.35 114181.65 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1166975.3 285906.61 1330480.5 325965.05 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3331473.8 816204.41 3798247.3 930562.99 MAarrowhead1
% End of user PostScript
1 .007 0 r
.49359 .44306 m
.49134 .45168 L
.489 .45876 L
.48651 .46454 L
.48383 .46921 L
.48091 .47294 L
.47769 .47586 L
.47411 .47807 L
.4701 .47967 L
.46559 .48072 L
.4605 .48127 L
.45475 .48136 L
.44822 .48101 L
.44081 .48024 L
.43239 .47905 L
.42281 .47743 L
.41191 .47536 L
.39949 .47283 L
.38534 .46978 L
.36923 .46619 L
.35086 .46198 L
.32993 .4571 L
.30607 .45146 L
.27887 .44496 L
.24787 .43751 L
.21252 .42897 L
.17223 .4192 L
.1263 .40803 L
.07393 .39527 L
.01422 .38069 L
s
.01422 .38069 m
0 .37722 L
s
1 0 0 r
.49359 .44306 m
.49134 .45168 L
s
% Start of user PostScript
-0.76876868 -6.8324172 -1.0391407 -5.7979419 MAarrowhead1
% End of user PostScript
1 .158 0 r
.489 .45876 m
.48651 .46454 L
s
% Start of user PostScript
-1.3204469 -4.9485 -1.6186837 -4.2553499 MAarrowhead1
% End of user PostScript
1 .473 0 r
.4605 .48127 m
.45475 .48136 L
s
% Start of user PostScript
-4.7397743 -2.2472071 -5.4304519 -2.2365099 MAarrowhead1
% End of user PostScript
1 .788 0 r
.38534 .46978 m
.36923 .46619 L
s
% Start of user PostScript
-13.758879 -3.6258895 -15.692882 -4.0574721 MAarrowhead1
% End of user PostScript
.897 1 0 r
.17223 .4192 m
.1263 .40803 L
s
% Start of user PostScript
-39.332251 -9.6961961 -44.844568 -11.036784 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-112.29802 -27.52685 -128.03247 -31.379428 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-320.59065 -78.547368 -365.50876 -89.551668 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-915.22087 -224.22806 -1043.4527 -255.64447 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2612.767 -640.12286 -2978.8424 -729.81057 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-7458.9109 -1827.4183 -8503.9806 -2083.4583 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-21293.652 -5216.9022 -24277.111 -5947.8435 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-60788.985 -14893.18 -69306.144 -16979.867 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-173540.02 -42516.956 -197854.75 -48474.017 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-495420.95 -121377.14 -564834.49 -138383.32 MAarrowhead1
% End of user PostScript
1 0 .755 r
.52089 .50573 m
.52383 .50635 L
.52718 .50708 L
.531 .50795 L
.53535 .50896 L
.54031 .51012 L
.54597 .51147 L
.55241 .51301 L
.55976 .51478 L
.56814 .51681 L
.57768 .51913 L
.58857 .52178 L
.60098 .52481 L
.61513 .52827 L
.63127 .53221 L
.64966 .53671 L
.67063 .54184 L
.69454 .54769 L
.7218 .55436 L
.75287 .56197 L
.7883 .57065 L
.8287 .58054 L
.87475 .59182 L
.92726 .60469 L
.98712 .61935 L
s
.98712 .61935 m
1 .62251 L
s
1 0 0 r
.52089 .50573 m
.52383 .50635 L
s
% Start of user PostScript
2.5065769 0.68721074 2.8595637 0.76158067 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52718 .50708 m
.531 .50795 L
s
% Start of user PostScript
3.261711 0.85000128 3.719956 0.95383971 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57768 .51913 m
.58857 .52178 L
s
% Start of user PostScript
9.3221871 2.2958661 10.628613 2.6139583 MAarrowhead1
% End of user PostScript
1 .788 0 r
.7218 .55436 m
.75287 .56197 L
s
% Start of user PostScript
26.615428 6.5235322 30.34459 7.4367047 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
75.982146 18.616132 86.628038 21.224245 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
216.91349 53.143526 247.3053 60.589432 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
619.24332 151.71341 706.00564 172.97 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1767.812 433.1104 2015.5005 493.7936 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
5046.7385 1236.4408 5753.8382 1409.6789 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
14407.398 3529.7836 16426.021 4024.3424 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
41130.149 10076.804 46892.903 11488.667 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
117418.09 28767.198 133869.57 32797.776 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
335204.44 82124.416 382170.01 93630.886 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
956939.53 234448.27 1091016.5 267296.87 MAarrowhead1
% End of user PostScript
1 .451 0 r
.41856 .43707 m
.4061 .44114 L
.39206 .44364 L
.37621 .44471 L
.35825 .44445 L
.33788 .44291 L
.31474 .44011 L
.28843 .43607 L
.25849 .43074 L
.2244 .42406 L
.18559 .41594 L
.14136 .40627 L
.09097 .3949 L
.03354 .38164 L
s
.03354 .38164 m
0 .37377 L
s
1 0 0 r
.41856 .43707 m
.4061 .44114 L
s
% Start of user PostScript
-9.7728042 -7.5517761 -11.268339 -7.0637485 MAarrowhead1
% End of user PostScript
1 .158 0 r
.39206 .44364 m
.37621 .44471 L
s
% Start of user PostScript
-12.952494 -6.7634854 -14.855165 -6.6348597 MAarrowhead1
% End of user PostScript
1 .473 0 r
.18559 .41594 m
.14136 .40627 L
s
% Start of user PostScript
-37.729795 -10.08671 -43.036763 -11.24725 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-107.88761 -26.630187 -123.00862 -30.30201 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-308.03841 -75.51527 -351.19888 -86.081799 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-879.39587 -215.46114 -1002.6085 -245.64618 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2510.4961 -615.06909 -2862.2424 -701.24579 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-7166.9492 -1755.8888 -8171.1121 -2001.9066 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-20460.162 -5012.6988 -23326.84 -5715.0292 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-58409.542 -14310.221 -66593.317 -16315.229 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-166747.2 -40852.729 -190110.18 -46576.615 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-476028.85 -116626.12 -542725.37 -132966.63 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1358964.2 -332943.51 -1549369. -379592.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3879562.5 -950485.05 -4423128.9 -1083657.7 MAarrowhead1
% End of user PostScript
.079 1 0 r
.57362 .42291 m
.58161 .44062 L
.5911 .4561 L
.60224 .4698 L
.61521 .48213 L
.63023 .49345 L
.64753 .50406 L
.66742 .51425 L
.69022 .52427 L
.71633 .53436 L
.74618 .54476 L
.78029 .5557 L
.81925 .56739 L
.86371 .58008 L
.91445 .594 L
.97233 .60943 L
s
.97233 .60943 m
1 .61665 L
s
1 0 0 r
.57362 .42291 m
.58161 .44062 L
s
% Start of user PostScript
8.8346701 -9.2510558 9.7930235 -7.1250625 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5911 .4561 m
.60224 .4698 L
s
% Start of user PostScript
10.931952 -5.2681414 12.269086 -3.624067 MAarrowhead1
% End of user PostScript
1 .473 0 r
.74618 .54476 m
.78029 .5557 L
s
% Start of user PostScript
29.541567 5.3717585 33.634963 6.6837483 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
83.943683 20.12792 95.694326 23.079386 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
239.55 58.586399 273.11089 66.825792 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
683.84427 167.51632 779.65725 190.99431 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1952.2293 478.28659 2225.7564 545.30114 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5573.2107 1365.4241 6354.0745 1556.7344 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
15910.367 3898.0077 18139.572 4444.1586 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
45420.816 11128.009 51784.737 12687.157 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
129667.06 31768.171 147834.74 36219.216 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
370172.72 90691.575 422037.7 103398.39 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1056766.8 258905.74 1204830.6 295181.08 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3016851.2 739122.49 3439542.9 842681.12 MAarrowhead1
% End of user PostScript
0 1 .767 r
.50463 .42332 m
.50338 .4359 L
.50226 .44639 L
.50125 .45511 L
.50032 .46237 L
.49944 .4684 L
.49859 .47341 L
.49775 .47755 L
.4969 .48097 L
.49602 .48378 L
.49509 .48608 L
.49409 .48794 L
.493 .48943 L
.4918 .49061 L
.49048 .4915 L
.48899 .49216 L
.48732 .4926 L
.48544 .49285 L
.48331 .49293 L
.4809 .49283 L
.47817 .49257 L
.47506 .49215 L
.47152 .49157 L
.46749 .49083 L
.46291 .4899 L
.45769 .48879 L
.45174 .48747 L
.44496 .48593 L
.43723 .48413 L
.42842 .48206 L
.41839 .47966 L
.40694 .47692 L
.3939 .47377 L
.37902 .47016 L
.36207 .46604 L
.34274 .46133 L
.3207 .45596 L
.29558 .44982 L
.26693 .44282 L
.23428 .43483 L
.19705 .42572 L
.1546 .41533 L
.1062 .40348 L
.05103 .38997 L
s
.05103 .38997 m
0 .37747 L
s
1 0 0 r
.50463 .42332 m
.50338 .4359 L
s
% Start of user PostScript
0.55589901 -9.2016916 0.40517675 -7.691621 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50226 .44639 m
.50125 .45511 L
s
% Start of user PostScript
0.27121022 -6.4337346 0.15007262 -5.3865353 MAarrowhead1
% End of user PostScript
1 .473 0 r
.49509 .48608 m
.49409 .48794 L
s
% Start of user PostScript
-0.58927398 -1.6706463 -0.70920345 -1.4471724 MAarrowhead1
% End of user PostScript
1 .788 0 r
.48331 .49293 m
.4809 .49283 L
s
% Start of user PostScript
-2.0024178 -0.84896555 -2.2917508 -0.8604796 MAarrowhead1
% End of user PostScript
.897 1 0 r
.45174 .48747 m
.44496 .48593 L
s
% Start of user PostScript
-5.7916656 -1.5030953 -6.6051974 -1.6884681 MAarrowhead1
% End of user PostScript
.581 1 0 r
.36207 .46604 m
.34274 .46133 L
s
% Start of user PostScript
-16.551662 -4.0748827 -18.871203 -4.6398923 MAarrowhead1
% End of user PostScript
.266 1 0 r
.1062 .40348 m
.05103 .38997 L
s
% Start of user PostScript
-47.255727 -11.582198 -53.876852 -13.203592 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-134.90633 -33.05287 -153.80811 -37.683588 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-385.12997 -94.356328 -439.09063 -107.57654 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-1099.4667 -269.3672 -1253.5132 -307.10828 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-3138.7507 -768.98764 -3578.5217 -876.73067 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-8960.4858 -2195.3011 -10215.941 -2502.8852 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-25580.339 -6267.1318 -29164.406 -7145.2211 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-73026.591 -17891.369 -83258.364 -20398.132 MAarrowhead1
% End of user PostScript
.025 0 1 r
.46776 .45853 m
.46242 .46279 L
.45647 .46597 L
.4498 .4682 L
.44229 .46959 L
.43381 .47021 L
.4242 .47011 L
.41331 .46931 L
.40093 .46785 L
.38686 .4657 L
.37084 .46287 L
.35261 .45931 L
.33185 .45498 L
.30819 .44982 L
.28124 .44375 L
.25053 .43666 L
.21552 .42845 L
.17562 .41898 L
.13013 .40809 L
.07827 .3956 L
.01916 .3813 L
s
.01916 .3813 m
0 .37665 L
s
1 0 0 r
.46776 .45853 m
.46242 .46279 L
s
% Start of user PostScript
-3.8683987 -4.9762068 -4.5090254 -4.465769 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45647 .46597 m
.4498 .4682 L
s
% Start of user PostScript
-5.2230713 -4.0838846 -6.0235303 -3.8154197 MAarrowhead1
% End of user PostScript
1 .473 0 r
.37084 .46287 m
.35261 .45931 L
s
% Start of user PostScript
-15.499029 -4.4556814 -17.686721 -4.882577 MAarrowhead1
% End of user PostScript
1 .788 0 r
.13013 .40809 m
.07827 .3956 L
s
% Start of user PostScript
-44.384652 -11.028758 -50.607181 -12.527652 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-126.74146 -31.087706 -144.50012 -35.432529 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-361.82834 -88.655743 -412.5244 -101.07476 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1032.9471 -253.07197 -1177.6736 -288.52934 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2948.8513 -722.46313 -3362.0155 -823.68746 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8418.3622 -2062.482 -9597.8609 -2351.4568 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-24032.688 -5887.9605 -27399.913 -6712.924 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-68608.367 -16808.913 -78221.102 -19164.013 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-195862.74 -47985.979 -223305.11 -54709.306 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-559147.72 -136990.07 -637490.04 -156183.78 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1596251.4 -391078.4 -1819902.6 -445872.49 MAarrowhead1
% End of user PostScript
.371 0 1 r
.52749 .51034 m
.53144 .51071 L
.53591 .51131 L
.54101 .51214 L
.5468 .51321 L
.5534 .51454 L
.56092 .51614 L
.56949 .51804 L
.57925 .52026 L
.59037 .52285 L
.60305 .52584 L
.6175 .52928 L
.63398 .53323 L
.65276 .53777 L
.67417 .54296 L
.69858 .54889 L
.72641 .55567 L
.75814 .56341 L
.79431 .57224 L
.83555 .58233 L
.88257 .59383 L
.93617 .60694 L
.99729 .6219 L
s
.99729 .6219 m
1 .62257 L
s
1 0 0 r
.52749 .51034 m
.53144 .51071 L
s
% Start of user PostScript
3.2993414 1.2410539 3.7722067 1.2852164 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53591 .51131 m
.54101 .51214 L
s
% Start of user PostScript
4.3095702 1.3570574 4.9207596 1.4568946 MAarrowhead1
% End of user PostScript
1 .473 0 r
.60305 .52584 m
.6175 .52928 L
s
% Start of user PostScript
12.36612 3.100403 14.100472 3.5135982 MAarrowhead1
% End of user PostScript
1 .788 0 r
.79431 .57224 m
.83555 .58233 L
s
% Start of user PostScript
35.31756 8.6693388 40.266318 9.8790233 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
100.82783 24.706517 114.95494 28.166983 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
287.84349 70.521993 328.17332 80.402571 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
821.73398 201.32339 936.86732 229.5308 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2345.8811 574.73622 2674.563 655.26262 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
6697.0066 1640.7532 7635.3257 1870.6395 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
19118.573 4684.012 21797.28 5340.29 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
54579.582 13371.888 62226.739 15245.427 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
155813.45 38173.983 177644.51 43522.549 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
444815.26 108978.85 507138.43 124247.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1269855.8 311112.14 1447775.6 354702.13 MAarrowhead1
% End of user PostScript
0 1 .477 r
.55154 .52838 m
.55914 .52763 L
.56775 .52756 L
.57751 .52814 L
.58859 .52934 L
.60119 .53116 L
.61553 .53362 L
.63185 .53674 L
.65043 .54055 L
.67159 .54513 L
.69571 .55052 L
.7232 .55683 L
.75452 .56415 L
.79023 .5726 L
.83093 .58232 L
.87732 .59348 L
.93022 .60627 L
.99051 .6209 L
s
.99051 .6209 m
1 .62321 L
s
1 0 0 r
.55154 .52838 m
.55914 .52763 L
s
% Start of user PostScript
6.1842438 3.4055334 7.0970004 3.3159754 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56775 .52756 m
.57751 .52814 L
s
% Start of user PostScript
8.1299762 3.3077554 9.3012855 3.3767156 MAarrowhead1
% End of user PostScript
1 .473 0 r
.69571 .55052 m
.7232 .55683 L
s
% Start of user PostScript
23.485443 6.0628731 26.783559 6.8197153 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
67.110912 16.514591 76.515614 18.806704 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
191.60303 46.959395 218.44899 53.53378 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
546.99071 134.01563 623.62981 152.79139 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1561.5465 382.57671 1780.3352 436.17934 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4457.8934 1092.1752 5082.4899 1245.2 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
12726.366 3117.9343 14509.46 3554.7888 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
36331.151 8901.0593 41421.517 10148.189 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
103717.94 25410.689 118249.89 28970.986 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
296093.34 72542.275 337579.04 82706.19 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
845285.41 207093.23 963718.54 236109.11 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2413115.5 591208.47 2751217.7 674042.82 MAarrowhead1
% End of user PostScript
1 0 .078 r
.53193 .41921 m
.53424 .43445 L
.53723 .44743 L
.54093 .45856 L
.54541 .46818 L
.55072 .4766 L
.55695 .48406 L
.56419 .49079 L
.57258 .49697 L
.58224 .50279 L
.59334 .50838 L
.60606 .5139 L
.62062 .51947 L
.63728 .52522 L
.6563 .53128 L
.67803 .53776 L
.70283 .54481 L
.73113 .55255 L
.76341 .56114 L
.80024 .57072 L
.84224 .58148 L
.89013 .59361 L
.94474 .60731 L
s
.94474 .60731 m
1 .62109 L
s
1 0 0 r
.53193 .41921 m
.53424 .43445 L
s
% Start of user PostScript
3.8321879 -9.6952712 4.1087722 -7.8657608 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53723 .44743 m
.54093 .45856 L
s
% Start of user PostScript
4.4672397 -6.3080559 4.9119178 -4.9727433 MAarrowhead1
% End of user PostScript
1 .473 0 r
.59334 .50838 m
.60606 .5139 L
s
% Start of user PostScript
11.200244 1.0058879 12.726959 1.6678874 MAarrowhead1
% End of user PostScript
1 .788 0 r
.76341 .56114 m
.80024 .57072 L
s
% Start of user PostScript
31.609779 7.3362064 36.028641 8.4864325 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
90.153789 21.991668 102.78291 25.101653 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
257.35037 63.027825 293.40724 71.865413 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
734.67751 179.98924 837.61322 205.20915 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2097.3517 513.84572 2391.2121 585.84113 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
5987.5062 1466.9267 6826.417 1672.4583 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
17093.095 4187.774 19488.013 4774.524 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
48797.261 11955.231 55634.257 13630.282 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
139306.12 34129.72 158824.33 38911.643 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
397690.23 97433.311 453410.7 111084.71 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1135323.6 278152.01 1294394. 317123.95 MAarrowhead1
% End of user PostScript
0 1 .076 r
.43313 .47694 m
.42359 .47571 L
.41275 .47398 L
.40041 .47172 L
.38636 .46892 L
.37036 .46554 L
.35213 .46152 L
.33136 .45681 L
.30769 .45132 L
.28071 .44497 L
.24995 .43765 L
.21489 .42924 L
.17492 .4196 L
.12935 .40856 L
.0774 .39594 L
.01818 .38151 L
s
.01818 .38151 m
0 .37708 L
s
1 0 0 r
.43313 .47694 m
.42359 .47571 L
s
% Start of user PostScript
-8.0248562 -2.767303 -9.1688363 -2.9148371 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41275 .47398 m
.40041 .47172 L
s
% Start of user PostScript
-10.46985 -3.1228347 -11.950438 -3.3931752 MAarrowhead1
% End of user PostScript
1 .473 0 r
.24995 .43765 m
.21489 .42924 L
s
% Start of user PostScript
-30.006258 -7.4824339 -34.213648 -8.4915399 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-85.68915 -21.02442 -97.695829 -23.960938 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-244.6313 -59.941399 -278.90682 -68.337638 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-698.37342 -171.10179 -796.22272 -195.07439 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1993.7124 -488.45595 -2273.0519 -556.89351 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5691.6379 -1394.44 -6489.0946 -1589.8153 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-16248.452 -3980.8383 -18525.027 -4538.5945 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-46385.98 -11364.472 -52885.13 -12956.751 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-132422.41 -32443.224 -150976.14 -36988.852 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-378038.66 -92618.714 -431005.74 -105595.54 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1079222.4 -264407.33 -1230432.5 -301453.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3080957.4 -754828.38 -3512631. -860587.56 MAarrowhead1
% End of user PostScript
.973 0 1 r
.47615 .55856 m
.47438 .54746 L
.47211 .538 L
.4693 .52988 L
.46591 .52286 L
.4619 .5167 L
.4572 .51124 L
.45173 .5063 L
.44541 .50175 L
.43813 .49746 L
.42977 .49332 L
.42019 .48923 L
.40922 .48509 L
.39668 .4808 L
.38236 .47628 L
.366 .47143 L
.34733 .46615 L
.32603 .46034 L
.30172 .45389 L
.274 .44669 L
.24239 .43861 L
.20634 .42949 L
.16523 .41918 L
.11835 .4075 L
.0649 .39424 L
.00396 .37917 L
s
.00396 .37917 m
0 .37819 L
s
1 0 0 r
.47615 .55856 m
.47438 .54746 L
s
% Start of user PostScript
-2.862569 7.0275819 -3.0744257 5.6952381 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47211 .538 m
.4693 .52988 L
s
% Start of user PostScript
-3.3473133 4.5600709 -3.6845896 3.5861144 MAarrowhead1
% End of user PostScript
1 .473 0 r
.42977 .49332 m
.42019 .48923 L
s
% Start of user PostScript
-8.4273101 -0.80138621 -9.5771347 -1.2923785 MAarrowhead1
% End of user PostScript
1 .788 0 r
.30172 .45389 m
.274 .44669 L
s
% Start of user PostScript
-23.793236 -5.5326688 -27.11965 -6.3967753 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-67.862559 -16.556542 -77.369093 -18.897162 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-193.719 -47.444413 -220.86061 -54.096764 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-553.02436 -135.48602 -630.50864 -154.47015 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1578.7697 -386.79451 -1799.9714 -440.98865 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-4507.0617 -1104.2209 -5138.5471 -1258.9336 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-12866.731 -3152.3234 -14669.492 -3593.9962 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-36731.864 -8999.2332 -41878.374 -10260.118 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-104861.9 -25690.955 -119554.12 -29290.52 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-299359.09 -73342.377 -341302.36 -83618.395 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-854608.46 -209377.36 -974347.84 -238713.27 MAarrowhead1
% End of user PostScript
.182 1 0 r
.53207 .56212 m
.5379 .55455 L
.54431 .54863 L
.55145 .54412 L
.55943 .54085 L
.5684 .53869 L
.57852 .53754 L
.58997 .53731 L
.60295 .53796 L
.61768 .53946 L
.63443 .5418 L
.65348 .545 L
.67517 .54909 L
.69986 .55412 L
.72799 .56015 L
.76004 .56729 L
.79656 .57565 L
.83819 .58535 L
.88563 .59656 L
.93971 .60947 L
s
.93971 .60947 m
1 .62395 L
s
1 0 0 r
.53207 .56212 m
.5379 .55455 L
s
% Start of user PostScript
3.8488847 7.4539757 4.5475548 6.5464772 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54431 .54863 m
.55145 .54412 L
s
% Start of user PostScript
5.3177078 5.8351941 6.1737341 5.2940467 MAarrowhead1
% End of user PostScript
1 .473 0 r
.63443 .5418 m
.65348 .545 L
s
% Start of user PostScript
16.1317 5.0164567 18.41797 5.4002798 MAarrowhead1
% End of user PostScript
1 .788 0 r
.88563 .59656 m
.93971 .60947 L
s
% Start of user PostScript
46.275914 11.587391 52.765761 13.135992 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
132.16061 32.437759 150.6791 36.965031 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
377.30359 92.452401 430.16802 105.4018 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1077.1268 263.89715 1228.0434 300.87087 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3074.9756 753.36362 3505.8111 858.91734 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
8778.4212 2150.6958 10008.368 2452.0302 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
25060.582 6139.7925 28571.826 7000.0402 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
71542.793 17527.841 81566.67 19983.671 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
204239.92 50038.371 232856.02 57049.259 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
583062.84 142849.23 664755.91 162863.87 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1664524.2 407805.09 1897741. 464942.75 MAarrowhead1
% End of user PostScript
1 .734 0 r
.5083 .57734 m
.51131 .5656 L
.51443 .55596 L
.51773 .54808 L
.52129 .54171 L
.52516 .53661 L
.52944 .53261 L
.53418 .52957 L
.53949 .52736 L
.54546 .52589 L
.55219 .52509 L
.5598 .52492 L
.56843 .52533 L
.57823 .52631 L
.58936 .52786 L
.60203 .52997 L
.61645 .53268 L
.63286 .53602 L
.65156 .54002 L
.67287 .54476 L
.69715 .55031 L
.72482 .55676 L
.75636 .56421 L
.79232 .57279 L
.8333 .58263 L
.88002 .59392 L
.93329 .60683 L
.99401 .6216 L
s
.99401 .6216 m
1 .62306 L
s
1 0 0 r
.5083 .57734 m
.51131 .5656 L
s
% Start of user PostScript
0.99596451 9.2806411 1.3567435 7.8719424 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51443 .55596 m
.51773 .54808 L
s
% Start of user PostScript
1.7314196 6.7146695 2.1280121 5.7696978 MAarrowhead1
% End of user PostScript
1 .473 0 r
.55219 .52509 m
.5598 .52492 L
s
% Start of user PostScript
6.2623798 3.011306 7.175964 2.9904334 MAarrowhead1
% End of user PostScript
1 .788 0 r
.65156 .54002 m
.67287 .54476 L
s
% Start of user PostScript
18.187636 4.8027498 20.744401 5.3716955 MAarrowhead1
% End of user PostScript
.897 1 0 r
.93329 .60683 m
.99401 .6216 L
s
% Start of user PostScript
51.9947 12.820032 59.281683 14.591837 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
148.45123 36.389375 169.25123 41.482166 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
423.80165 103.83505 483.1807 118.38205 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1209.8672 296.41611 1379.382 337.94672 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
3453.9217 846.20414 3937.8514 964.76592 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
9860.234 2415.7377 11241.754 2754.2072 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
28148.934 6896.4326 32092.888 7862.6934 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
80359.402 19687.893 91618.577 22446.368 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
229409.52 56204.873 261552.14 64079.751 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
654916.86 160453.32 746677.41 182934.47 MAarrowhead1
% End of user PostScript
.379 0 1 r
.4694 .50051 m
.46531 .49818 L
.46061 .49593 L
.45523 .49368 L
.44907 .4914 L
.44203 .48904 L
.43399 .48653 L
.42481 .48383 L
.41433 .48089 L
.40237 .47765 L
.38873 .47405 L
.37317 .47002 L
.35543 .46549 L
.33519 .46038 L
.31212 .4546 L
.28581 .44805 L
.25581 .44062 L
.22161 .43216 L
.18261 .42255 L
.13815 .4116 L
.08746 .39914 L
.02967 .38495 L
s
.02967 .38495 m
0 .37767 L
s
1 0 0 r
.4694 .50051 m
.46531 .49818 L
s
% Start of user PostScript
-3.6719068 0.061733416 -4.162843 -0.21780964 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46061 .49593 m
.45523 .49368 L
s
% Start of user PostScript
-4.7264634 -0.48877499 -5.372306 -0.75787061 MAarrowhead1
% End of user PostScript
1 .473 0 r
.38873 .47405 m
.37317 .47002 L
s
% Start of user PostScript
-13.352702 -3.114254 -15.219706 -3.5976979 MAarrowhead1
% End of user PostScript
1 .788 0 r
.18261 .42255 m
.13815 .4116 L
s
% Start of user PostScript
-38.08625 -9.2941599 -43.42162 -10.607427 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-108.72065 -26.627679 -123.95331 -30.361086 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-310.37322 -76.038783 -353.85963 -86.693204 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-886.05109 -217.08027 -1010.1959 -247.49558 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2529.493 -619.72062 -2883.9009 -706.54985 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7221.1809 -1769.1748 -8232.9422 -2017.0543 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-20614.982 -5050.6293 -23503.352 -5758.2742 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-58851.522 -14418.505 -67097.222 -16438.685 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-168008.96 -41161.858 -191548.73 -46929.055 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-479630.92 -117508.62 -546832.12 -133972.77 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1369247.4 -335462.86 -1561092.9 -382464.64 MAarrowhead1
% End of user PostScript
1 .634 0 r
.50274 .56958 m
.50481 .55867 L
.50689 .54966 L
.50903 .54224 L
.51128 .53616 L
.51367 .53121 L
.51627 .52723 L
.51912 .52408 L
.52228 .52164 L
.52579 .51982 L
.52974 .51855 L
.53418 .51777 L
.5392 .51744 L
.54488 .51754 L
.55133 .51803 L
.55866 .51892 L
.56699 .52021 L
.57646 .5219 L
.58726 .52402 L
.59955 .5266 L
.61355 .52966 L
.6295 .53326 L
.64768 .53746 L
.66841 .54233 L
.69203 .54794 L
.71896 .55439 L
.74965 .56179 L
.78465 .57026 L
.82454 .57994 L
.87002 .59102 L
.92188 .60366 L
.98099 .61809 L
s
.98099 .61809 m
1 .62274 L
s
1 0 0 r
.50274 .56958 m
.50481 .55867 L
s
% Start of user PostScript
0.32870318 8.3500845 0.57721243 7.0409611 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50689 .54966 m
.50903 .54224 L
s
% Start of user PostScript
0.82699993 5.9591185 1.0838014 5.0683605 MAarrowhead1
% End of user PostScript
1 .473 0 r
.52974 .51855 m
.53418 .51777 L
s
% Start of user PostScript
3.5684389 2.225917 4.1015048 2.1325896 MAarrowhead1
% End of user PostScript
1 .788 0 r
.58726 .52402 m
.59955 .5266 L
s
% Start of user PostScript
10.47069 2.8826739 11.945511 3.1914227 MAarrowhead1
% End of user PostScript
.897 1 0 r
.74965 .56179 m
.78465 .57026 L
s
% Start of user PostScript
29.958235 7.4142291 34.157515 8.4306984 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
85.540215 20.97468 97.525703 23.908201 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
244.20334 59.833439 278.41883 68.215484 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
697.15104 170.80157 794.82905 194.73233 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
1990.2226 487.60079 2269.0732 555.91858 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
5681.6752 1391.9991 6477.736 1587.0324 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
16220.011 3973.8702 18492.6 4530.6501 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
46304.786 11344.58 52792.56 12934.071 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
132190.61 32386.435 150711.87 36924.106 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
377376.93 92456.594 430251.3 105410.71 MAarrowhead1
% End of user PostScript
.287 1 0 r
.47747 .45229 m
.47329 .45825 L
.46868 .46296 L
.46357 .46657 L
.45787 .46923 L
.45147 .47105 L
.44425 .47211 L
.43609 .47247 L
.42684 .47217 L
.41635 .47124 L
.40443 .46969 L
.39087 .46751 L
.37544 .46468 L
.35787 .46117 L
.33786 .45693 L
.31506 .4519 L
.28908 .446 L
.25947 .43913 L
.22572 .43118 L
.18725 .42203 L
.1434 .41151 L
.0934 .39944 L
.03641 .38564 L
s
.03641 .38564 m
0 .37679 L
s
1 0 0 r
.47747 .45229 m
.47329 .45825 L
s
% Start of user PostScript
-2.7030688 -5.725151 -3.2057461 -5.0095401 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46868 .46296 m
.46357 .46657 L
s
% Start of user PostScript
-3.7583189 -4.4451109 -4.3711802 -4.0113888 MAarrowhead1
% End of user PostScript
1 .473 0 r
.40443 .46969 m
.39087 .46751 L
s
% Start of user PostScript
-11.468513 -3.6372935 -13.095629 -3.8988375 MAarrowhead1
% End of user PostScript
1 .788 0 r
.22572 .43118 m
.18725 .42203 L
s
% Start of user PostScript
-32.913829 -8.2581307 -37.53015 -9.3569293 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-94.002954 -23.07616 -107.17485 -26.295689 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-268.36862 -65.760486 -305.97007 -74.970992 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-766.13929 -187.70511 -873.48331 -214.00376 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2187.1702 -535.85291 -2493.6151 -610.93121 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6243.9199 -1529.748 -7118.757 -1744.0813 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-17825.104 -4367.1148 -20322.583 -4978.9922 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-50886.995 -12467.212 -58016.783 -14213.996 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-145271.87 -35591.318 -165625.95 -40578.026 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-414721.24 -101605.87 -472827.93 -115841.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1183943.6 -290063.81 -1349826.2 -330704.72 MAarrowhead1
% End of user PostScript
1 0 .731 r
.43953 .50369 m
.43151 .49866 L
.42229 .49384 L
.41172 .48912 L
.39961 .48437 L
.38577 .47949 L
.36994 .47438 L
.35187 .46892 L
.33125 .463 L
.30771 .45651 L
.28086 .44934 L
.25023 .44133 L
.21529 .43235 L
.17546 .42224 L
.13003 .41082 L
.07823 .39789 L
.01916 .38322 L
s
.01916 .38322 m
0 .37847 L
s
1 0 0 r
.43953 .50369 m
.43151 .49866 L
s
% Start of user PostScript
-7.2565577 0.44274545 -8.2189114 -0.16091158 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42229 .49384 m
.41172 .48912 L
s
% Start of user PostScript
-9.3251071 -0.73886296 -10.593807 -1.3057777 MAarrowhead1
% End of user PostScript
1 .473 0 r
.28086 .44934 m
.25023 .44133 L
s
% Start of user PostScript
-26.297006 -6.0797593 -29.9726 -7.0404027 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-74.996393 -18.288743 -85.502068 -20.876731 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-214.08136 -52.429493 -244.07586 -59.7814 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-611.15392 -149.72679 -696.78272 -170.70645 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1744.7174 -427.45117 -1989.1701 -487.34178 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4980.8081 -1220.2878 -5678.6703 -1391.2626 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-14219.18 -3483.6706 -16211.432 -3971.7685 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-40592.826 -9945.1611 -46280.296 -11338.58 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-115884.15 -28391.384 -132120.7 -32369.307 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-330825.34 -81051.545 -377177.35 -92407.696 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-944438.1 -231385.44 -1076763.5 -263804.91 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2696176. -660557.72 -3073937.8 -753108.62 MAarrowhead1
% End of user PostScript
1 .018 0 r
.50044 .48651 m
.50017 .4887 L
.49991 .49052 L
.49967 .49202 L
.49943 .49327 L
.49919 .49431 L
.49894 .49516 L
.49868 .49585 L
.4984 .49642 L
.4981 .49687 L
.49777 .49723 L
.4974 .49751 L
.49699 .49772 L
.49653 .49786 L
.49601 .49795 L
.49543 .49798 L
.49477 .49797 L
.49401 .49791 L
.49316 .4978 L
.49219 .49765 L
.49108 .49745 L
.48983 .4972 L
.48839 .4969 L
.48676 .49655 L
.4849 .49612 L
.48278 .49563 L
.48036 .49507 L
.47761 .49441 L
.47447 .49366 L
.47089 .4928 L
.46681 .49181 L
.46216 .49068 L
.45686 .48939 L
.45081 .48791 L
.44392 .48623 L
.43606 .48431 L
.4271 .48212 L
.41688 .47962 L
.40524 .47677 L
.39196 .47352 L
.37682 .46981 L
.35956 .46559 L
.33989 .46077 L
.31745 .45527 L
.29188 .44901 L
.26272 .44186 L
.22947 .43372 L
.19157 .42443 L
.14835 .41384 L
.09908 .40177 L
Mistroke
.04291 .38801 L
Mfstroke
.04291 .38801 m
0 .3775 L
s
1 0 0 r
.50044 .48651 m
.50017 .4887 L
s
% Start of user PostScript
0.052642548 -1.6182598 0.020084444 -1.3560045 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49991 .49052 m
.49967 .49202 L
s
% Start of user PostScript
-0.010419585 -1.1380149 -0.039677773 -0.95707237 MAarrowhead1
% End of user PostScript
1 .473 0 r
.49777 .49723 m
.4974 .49751 L
s
% Start of user PostScript
-0.26792823 -0.33225415 -0.3119949 -0.29888104 MAarrowhead1
% End of user PostScript
1 .788 0 r
.49316 .4978 m
.49219 .49765 L
s
% Start of user PostScript
-0.82080629 -0.26369781 -0.93734226 -0.2818777 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48036 .49507 m
.47761 .49441 L
s
% Start of user PostScript
-2.3563645 -0.59200383 -2.6868751 -0.67054306 MAarrowhead1
% End of user PostScript
.581 1 0 r
.44392 .48623 m
.43606 .48431 L
s
% Start of user PostScript
-6.730018 -1.6522924 -7.6730469 -1.8827608 MAarrowhead1
% End of user PostScript
.266 1 0 r
.33989 .46077 m
.31745 .45527 L
s
% Start of user PostScript
-19.213537 -4.7080886 -21.90557 -5.367497 MAarrowhead1
% End of user PostScript
0 1 .049 r
.04291 .38801 m
0 0 rlineto s
.04291 .38801 m
0 .3775 L
s
% Start of user PostScript
-54.850856 -13.43854 -62.536027 -15.32136 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-156.58792 -38.363772 -178.52749 -43.738916 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-447.02623 -109.52054 -509.65918 -124.86549 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-1276.1677 -312.65853 -1454.9718 -356.46519 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-3643.1956 -892.57562 -4153.6445 -1017.6346 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-10400.572 -2548.1193 -11857.798 -2905.1369 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-29691.488 -7274.3551 -33851.569 -8293.5666 MAarrowhead1
% End of user PostScript
1 0 .817 r
.42111 .4922 m
.41034 .48765 L
.39801 .48304 L
.38391 .47825 L
.36781 .4732 L
.34943 .46777 L
.32845 .46186 L
.30451 .45535 L
.27719 .44812 L
.24604 .44004 L
.21052 .43096 L
.17 .42072 L
.12381 .40914 L
.07113 .39602 L
.01107 .38113 L
s
.01107 .38113 m
0 .37839 L
s
1 0 0 r
.42111 .4922 m
.41034 .48765 L
s
% Start of user PostScript
-9.4671535 -0.93632512 -10.759737 -1.4821436 MAarrowhead1
% End of user PostScript
1 .158 0 r
.39801 .48304 m
.38391 .47825 L
s
% Start of user PostScript
-12.239035 -2.0357457 -13.930278 -2.6096018 MAarrowhead1
% End of user PostScript
1 .473 0 r
.21052 .43096 m
.17 .42072 L
s
% Start of user PostScript
-34.737959 -8.2846616 -39.599568 -9.5131986 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-99.122286 -24.23168 -113.00903 -27.642699 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-282.96255 -69.312794 -322.60819 -79.027962 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-807.7971 -197.90575 -920.97767 -225.63524 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2306.0935 -564.98761 -2629.2008 -644.14836 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6583.4212 -1612.9249 -7505.8258 -1838.9122 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-18794.31 -4604.5682 -21427.585 -5249.7153 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-53653.878 -13145.093 -61171.335 -14986.855 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-153170.76 -37526.528 -174631.54 -42784.379 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-437270.92 -107130.5 -498537.04 -122140.58 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1248318.3 -305835.48 -1423220.4 -348686.16 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3563691.2 -873097.22 -4063000.8 -995427.07 MAarrowhead1
% End of user PostScript
1 .099 0 r
.46492 .53189 m
.461 .52422 L
.45636 .51749 L
.45094 .51149 L
.44464 .50606 L
.43737 .50102 L
.42899 .49626 L
.41938 .49164 L
.40836 .48705 L
.39575 .48239 L
.38134 .47755 L
.36488 .47242 L
.34608 .4669 L
.32463 .46088 L
.30015 .45424 L
.27222 .44687 L
.24038 .43862 L
.20406 .42936 L
.16264 .4189 L
.11541 .40707 L
.06155 .39366 L
.00015 .37844 L
s
.00015 .37844 m
0 .3784 L
s
1 0 0 r
.46492 .53189 m
.461 .52422 L
s
% Start of user PostScript
-4.2091 3.8271636 -4.6798953 2.9069364 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45636 .51749 m
.45094 .51149 L
s
% Start of user PostScript
-5.236359 2.0990648 -5.8872296 1.3793169 MAarrowhead1
% End of user PostScript
1 .473 0 r
.38134 .47755 m
.36488 .47242 L
s
% Start of user PostScript
-14.239301 -2.6944984 -16.214932 -3.3100819 MAarrowhead1
% End of user PostScript
1 .788 0 r
.16264 .4189 m
.11541 .40707 L
s
% Start of user PostScript
-40.483691 -9.7319642 -46.151306 -11.151409 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-115.53348 -28.261689 -131.71983 -32.234565 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-329.81506 -80.79375 -376.02527 -92.116863 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-941.55182 -230.6759 -1073.4728 -262.99667 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2687.9358 -658.53831 -3064.543 -750.80644 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7673.5021 -1879.9925 -8748.6382 -2143.3987 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-21906.266 -5366.9912 -24975.558 -6118.9616 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-62537.871 -15321.653 -71300.066 -17468.373 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-178532.72 -43740.16 -203546.98 -49868.603 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-509674.1 -124869.13 -581084.66 -142364.58 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1455014.4 -356475.63 -1658876.8 -406421.51 MAarrowhead1
% End of user PostScript
0 .738 1 r
.52754 .55602 m
.53261 .5491 L
.53818 .54366 L
.54437 .53949 L
.55129 .53644 L
.55906 .53439 L
.56783 .53324 L
.57774 .53291 L
.58897 .53337 L
.60172 .53457 L
.6162 .53652 L
.63268 .53923 L
.65144 .54271 L
.67279 .54701 L
.69712 .5522 L
.72483 .55834 L
.75641 .56554 L
.7924 .57391 L
.83343 .58358 L
.88019 .59472 L
.9335 .60752 L
.99427 .62219 L
s
.99427 .62219 m
1 .62358 L
s
1 0 0 r
.52754 .55602 m
.53261 .5491 L
s
% Start of user PostScript
3.3052431 6.7228531 3.913105 5.8921654 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53818 .54366 m
.54437 .53949 L
s
% Start of user PostScript
4.5821517 5.2387592 5.324929 4.7388216 MAarrowhead1
% End of user PostScript
1 .473 0 r
.6162 .53652 m
.63268 .53923 L
s
% Start of user PostScript
13.944528 4.3828724 15.921961 4.7072219 MAarrowhead1
% End of user PostScript
1 .788 0 r
.83343 .58358 m
.88019 .59472 L
s
% Start of user PostScript
40.011491 10.029672 45.623065 11.3669 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
114.27216 28.049736 130.28416 31.963816 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
326.23462 79.93934 371.94373 91.135909 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
931.33517 228.17819 1061.8248 260.14741 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2658.7704 651.39413 3031.2914 742.6609 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
7590.2414 1859.5941 8653.7119 2120.1422 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
21668.574 5308.7572 24704.563 6052.5684 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
61859.309 15155.407 70526.431 17278.834 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
176595.57 43265.561 201338.41 49327.509 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
504143.93 123514.25 574779.65 140819.86 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1439226.9 352607.72 1640877.3 402011.67 MAarrowhead1
% End of user PostScript
1 0 .202 r
.51561 .50184 m
.51775 .5027 L
.5202 .50357 L
.523 .50448 L
.52619 .50546 L
.52984 .50651 L
.534 .50766 L
.53875 .50893 L
.54416 .51035 L
.55034 .51194 L
.55738 .51373 L
.56541 .51576 L
.57457 .51804 L
.58501 .52064 L
.59692 .52359 L
.61049 .52694 L
.62597 .53075 L
.64362 .5351 L
.66374 .54004 L
.68668 .54567 L
.71283 .55209 L
.74265 .5594 L
.77665 .56774 L
.81541 .57724 L
.8596 .58808 L
.90998 .60042 L
.96743 .6145 L
s
.96743 .6145 m
1 .62248 L
s
1 0 0 r
.51561 .50184 m
.51775 .5027 L
s
% Start of user PostScript
1.8737409 0.2212787 2.1304498 0.32356528 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5202 .50357 m
.523 .50448 L
s
% Start of user PostScript
2.4240906 0.42837386 2.7596781 0.53801423 MAarrowhead1
% End of user PostScript
1 .473 0 r
.55738 .51373 m
.56541 .51576 L
s
% Start of user PostScript
6.8855573 1.648082 7.8493428 1.8906464 MAarrowhead1
% End of user PostScript
1 .788 0 r
.66374 .54004 m
.68668 .54567 L
s
% Start of user PostScript
19.648693 4.8047646 22.401453 5.480697 MAarrowhead1
% End of user PostScript
.897 1 0 r
.96743 .6145 m
0 0 rlineto s
.96743 .6145 m
1 .62248 L
s
% Start of user PostScript
56.091052 13.740053 63.94993 15.665817 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
160.12794 39.23052 182.56348 44.727269 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
457.13212 111.99634 521.18101 127.6882 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1305.0179 319.72675 1487.8643 364.52374 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
3725.557 912.75399 4247.5456 1040.6402 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
10635.697 2605.7244 12125.867 2970.8131 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
30362.721 7438.8058 34616.848 8481.0585 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
86679.305 21236.256 98823.962 24211.673 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
247451.54 60625.132 282122.03 69119.333 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
706423.11 173072.25 805400.21 197321.44 MAarrowhead1
% End of user PostScript
1 0 .779 r
.44882 .43544 m
.44038 .44199 L
.43096 .44687 L
.4204 .45029 L
.40851 .45238 L
.39507 .45326 L
.37986 .45302 L
.36259 .4517 L
.34298 .44932 L
.32068 .44588 L
.29531 .44135 L
.26642 .43568 L
.23352 .4288 L
.19604 .42059 L
.15333 .41095 L
.10466 .39971 L
.04919 .38668 L
s
.04919 .38668 m
0 .375 L
s
1 0 0 r
.44882 .43544 m
.44038 .44199 L
s
% Start of user PostScript
-6.1414665 -7.7469408 -7.1547722 -6.9610447 MAarrowhead1
% End of user PostScript
1 .158 0 r
.43096 .44687 m
.4204 .45029 L
s
% Start of user PostScript
-8.2847342 -6.3750564 -9.5518918 -5.9656242 MAarrowhead1
% End of user PostScript
1 .473 0 r
.29531 .44135 m
.26642 .43568 L
s
% Start of user PostScript
-24.562711 -7.0381165 -28.029177 -7.7183615 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-70.335498 -17.471628 -80.196086 -19.847763 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-200.8436 -49.262532 -228.98522 -56.147853 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-573.37884 -140.48988 -653.71541 -160.16999 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1636.8811 -401.0357 -1866.225 -457.22397 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4672.9586 -1144.8662 -5327.6879 -1305.2735 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-13340.333 -3268.3551 -15209.45 -3726.285 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-38083.9 -9330.4793 -43419.844 -10637.775 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-108721.68 -26636.594 -123954.7 -30368.653 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-310377.97 -76041.982 -353865.1 -86696.241 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-886065.09 -217084.17 -1010211.9 -247499.89 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2529533.1 -619730.55 -2883946.6 -706561.13 MAarrowhead1
% End of user PostScript
1 0 .47 r
.52066 .52173 m
.52396 .51978 L
.52766 .51838 L
.53182 .51748 L
.53652 .51702 L
.54183 .51699 L
.54786 .51735 L
.5547 .51809 L
.56248 .51922 L
.57133 .52074 L
.5814 .52267 L
.59287 .52503 L
.60594 .52785 L
.62083 .53119 L
.6378 .53508 L
.65714 .5396 L
.67918 .54482 L
.70431 .55082 L
.73295 .55771 L
.76561 .56561 L
.80283 .57464 L
.84527 .58496 L
.89366 .59676 L
.94882 .61022 L
s
.94882 .61022 m
1 .62272 L
s
1 0 0 r
.52066 .52173 m
.52396 .51978 L
s
% Start of user PostScript
2.4792085 2.6077577 2.8755435 2.3734622 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52766 .51838 m
.53182 .51748 L
s
% Start of user PostScript
3.3192959 2.2056859 3.8184535 2.0972903 MAarrowhead1
% End of user PostScript
1 .473 0 r
.5814 .52267 m
.59287 .52503 L
s
% Start of user PostScript
9.7679985 2.7200979 11.1446 3.0031957 MAarrowhead1
% End of user PostScript
1 .788 0 r
.73295 .55771 m
.76561 .56561 L
s
% Start of user PostScript
27.954206 6.9254959 31.872756 7.8728141 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
79.819597 19.573668 91.00358 22.310735 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
227.87227 55.832482 259.79961 63.653915 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
650.52921 159.37935 741.67504 181.70973 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1857.1269 454.99262 2117.3294 518.74167 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
5301.7144 1298.9095 6044.5389 1480.9 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
15135.301 3708.1185 17255.912 4227.6639 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
43208.164 10585.914 49262.069 12069.108 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
123350.4 30220.6 140633.05 34454.815 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
352139.94 86273.58 401478.35 98361.391 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1005286.9 246293.28 1146137.9 280801.48 MAarrowhead1
% End of user PostScript
0 1 .76 r
.57777 .57558 m
.59005 .56922 L
.60383 .56478 L
.61934 .56207 L
.63686 .56092 L
.65671 .56124 L
.67922 .56298 L
.7048 .56608 L
.73388 .57057 L
.76698 .57648 L
.80465 .58388 L
.84757 .59286 L
.89645 .60356 L
.95216 .61614 L
s
.95216 .61614 m
1 .62719 L
s
1 0 0 r
.57777 .57558 m
.59005 .56922 L
s
% Start of user PostScript
9.3327387 9.0694434 10.80641 8.3067677 MAarrowhead1
% End of user PostScript
1 .158 0 r
.60383 .56478 m
.61934 .56207 L
s
% Start of user PostScript
12.459047 7.7741039 14.320283 7.4478703 MAarrowhead1
% End of user PostScript
1 .473 0 r
.80465 .58388 m
.84757 .59286 L
s
% Start of user PostScript
36.55846 10.06542 41.707816 11.14333 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
104.59942 25.886971 119.26125 29.435961 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
298.66439 73.233303 340.51182 83.475713 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
852.63806 208.90897 972.10172 238.17495 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2434.1088 596.35516 2775.1524 679.9096 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6948.8793 1702.4623 7922.4884 1940.9945 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
19837.617 4860.1768 22617.071 5541.1372 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
56632.307 13874.802 64567.072 15818.803 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
161673.55 39609.697 184325.67 45159.421 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
461544.65 113077.52 526211.78 128920.83 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1317614.8 322812.99 1502226.1 368042.39 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3761518.5 921564.5 4288545.7 1050685.1 MAarrowhead1
% End of user PostScript
.779 0 1 r
.42474 .53511 m
.41551 .52398 L
.40476 .51394 L
.39233 .50472 L
.37801 .49606 L
.36155 .48773 L
.34268 .47952 L
.32108 .47124 L
.29638 .46269 L
.26816 .45369 L
.23593 .44406 L
.19915 .43359 L
.15718 .4221 L
.10929 .40936 L
.05468 .39514 L
s
.05468 .39514 m
0 .38113 L
s
1 0 0 r
.42474 .53511 m
.41551 .52398 L
s
% Start of user PostScript
-9.031162 4.2131156 -10.139206 2.8771031 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40476 .51394 m
.39233 .50472 L
s
% Start of user PostScript
-11.42856 1.6730317 -12.920311 0.5665179 MAarrowhead1
% End of user PostScript
1 .473 0 r
.23593 .44406 m
.19915 .43359 L
s
% Start of user PostScript
-31.687893 -6.7131859 -36.101978 -7.9686274 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-90.242085 -21.862518 -102.87989 -24.99961 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-257.57081 -63.046427 -293.6577 -71.897235 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-735.29939 -180.13328 -838.32202 -205.37587 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2099.1252 -514.27829 -2393.2341 -586.3349 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5992.569 -1468.1667 -6832.1892 -1673.872 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-17107.548 -4191.3149 -19504.491 -4778.5611 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-48838.522 -11965.34 -55681.299 -13641.807 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-139423.91 -34158.578 -158958.62 -38944.544 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-398026.5 -97515.696 -453794.08 -111178.64 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1136283.6 -278387.2 -1295488.5 -317392.09 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3243855.2 -794738.04 -3698352.5 -906088.97 MAarrowhead1
% End of user PostScript
0 .08 1 r
.52012 .51744 m
.52325 .51613 L
.52676 .51526 L
.53072 .51479 L
.53521 .51469 L
.54029 .51493 L
.54606 .5155 L
.55261 .51641 L
.56007 .51765 L
.56856 .51925 L
.57822 .52121 L
.58923 .52357 L
.60178 .52636 L
.61607 .52963 L
.63237 .53342 L
.65094 .53781 L
.6721 .54285 L
.69624 .54865 L
.72374 .5553 L
.7551 .5629 L
.79086 .57159 L
.83162 .58152 L
.87809 .59286 L
.93107 .6058 L
.99147 .62057 L
s
.99147 .62057 m
1 .62266 L
s
1 0 0 r
.52012 .51744 m
.52325 .51613 L
s
% Start of user PostScript
2.4147392 2.0926609 2.7898175 1.9358763 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52676 .51526 m
.53072 .51479 L
s
% Start of user PostScript
3.2113601 1.8316735 3.6868856 1.7750694 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57822 .52121 m
.58923 .52357 L
s
% Start of user PostScript
9.3869555 2.5451324 10.708171 2.828181 MAarrowhead1
% End of user PostScript
1 .788 0 r
.72374 .5553 m
.7551 .5629 L
s
% Start of user PostScript
26.849288 6.6356305 30.612558 7.5480802 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
76.661263 18.795383 87.402621 21.424753 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
218.85493 53.622197 249.51882 61.134263 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
624.78636 153.07215 712.32534 174.5189 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1783.6364 436.98751 2033.5421 498.21388 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
5091.914 1247.5088 5805.3432 1422.2975 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
14536.364 3561.3801 16573.057 4060.3659 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
41498.322 10167.006 47312.661 11591.507 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
118469.15 29024.704 135067.89 33091.362 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
338204.99 82859.545 385590.97 94469.015 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
965505.48 236546.91 1100782.7 269689.55 MAarrowhead1
% End of user PostScript
1 .555 0 r
.43963 .45089 m
.43033 .4543 L
.41987 .45648 L
.40806 .45754 L
.39469 .45757 L
.37953 .45661 L
.36231 .45469 L
.34273 .45181 L
.32046 .44795 L
.29511 .44308 L
.26623 .43712 L
.23334 .42999 L
.19587 .42158 L
.15316 .41177 L
.10449 .40038 L
.049 .38724 L
s
.049 .38724 m
0 .37552 L
s
1 0 0 r
.43963 .45089 m
.43033 .4543 L
s
% Start of user PostScript
-7.2442886 -5.8931089 -8.3601108 -5.4842134 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41987 .45648 m
.40806 .45754 L
s
% Start of user PostScript
-9.6155678 -5.222559 -11.032991 -5.0948912 MAarrowhead1
% End of user PostScript
1 .473 0 r
.26623 .43712 m
.23334 .42999 L
s
% Start of user PostScript
-28.051815 -7.5457694 -31.998641 -8.4012169 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-80.223348 -19.812614 -91.467329 -22.541182 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-229.05427 -56.154949 -261.14802 -64.011706 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-653.91047 -160.21547 -745.53023 -182.66069 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1866.7814 -457.35974 -2128.3366 -521.43991 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5329.2762 -1305.6625 -6075.9623 -1488.599 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-15213.984 -3727.3959 -17345.619 -4249.6421 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-43432.788 -10640.946 -49518.166 -12131.852 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-123991.65 -30377.706 -141364.15 -34633.934 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-353970.59 -86722.087 -403565.49 -98872.738 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1010513. -247573.67 -1152096.2 -282261.27 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2884806.3 -706771.77 -3288997.2 -805797.72 MAarrowhead1
% End of user PostScript
0 .846 1 r
.56491 .57184 m
.57538 .56514 L
.58708 .56027 L
.60023 .55704 L
.61507 .5553 L
.63186 .55492 L
.65089 .55584 L
.67249 .558 L
.69704 .56141 L
.72497 .56608 L
.75676 .57205 L
.79296 .5794 L
.83419 .58824 L
.88117 .5987 L
.93471 .61093 L
.99573 .62515 L
s
.99573 .62515 m
1 .62616 L
s
1 0 0 r
.56491 .57184 m
.57538 .56514 L
s
% Start of user PostScript
7.7894042 8.6209294 9.0451153 7.8165169 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58708 .56027 m
.60023 .55704 L
s
% Start of user PostScript
10.449539 7.2327723 12.028022 6.8453836 MAarrowhead1
% End of user PostScript
1 .473 0 r
.75676 .57205 m
.79296 .5794 L
s
% Start of user PostScript
30.811448 8.6459064 35.155307 9.5283775 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
88.190477 21.86411 100.55317 24.850266 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
251.81966 61.755804 287.10366 70.39029 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
718.90589 176.14471 819.63231 200.82013 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2052.331 502.82033 2339.8837 573.2696 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5858.9825 1435.4398 6679.8859 1636.5593 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
16726.187 4097.8825 19069.697 4672.0377 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
47749.814 11698.609 54440.051 13337.704 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
136315.87 33397.115 155415.12 38076.393 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
389153.69 95341.876 443678.11 108700.25 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1110953.5 272181.39 1266609.5 310316.79 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3171543.2 777021.73 3615908.8 885890.43 MAarrowhead1
% End of user PostScript
.051 0 1 r
.54782 .46205 m
.5533 .47162 L
.55976 .48006 L
.56728 .48764 L
.576 .49455 L
.58606 .501 L
.59763 .50716 L
.6109 .51319 L
.62609 .51923 L
.64348 .52542 L
.66334 .5319 L
.68603 .5388 L
.71192 .54627 L
.74148 .55445 L
.7752 .56349 L
.81366 .57356 L
.85752 .58485 L
.90755 .59756 L
.9646 .61192 L
s
.9646 .61192 m
1 .62076 L
s
1 0 0 r
.54782 .46205 m
.5533 .47162 L
s
% Start of user PostScript
5.7382575 -4.5545766 6.396323 -3.4058926 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55976 .48006 m
.56728 .48764 L
s
% Start of user PostScript
7.1707652 -2.3922879 8.0738846 -1.4836468 MAarrowhead1
% End of user PostScript
1 .473 0 r
.66334 .5319 m
.68603 .5388 L
s
% Start of user PostScript
19.600709 3.8279023 22.323118 4.6562869 MAarrowhead1
% End of user PostScript
1 .788 0 r
.9646 .61192 m
0 0 rlineto s
.9646 .61192 m
1 .62076 L
s
% Start of user PostScript
55.751621 13.430281 63.557393 15.380577 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
159.11139 38.92826 181.40321 44.39861 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
454.21895 111.27012 517.85936 126.86398 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1296.6988 317.68564 1478.3794 362.19754 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3701.8069 906.93459 4220.4679 1034.0056 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
10567.895 2589.113 12048.565 2951.8742 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
30169.161 7391.384 34396.169 8426.9925 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
86126.732 21100.877 98193.968 24057.326 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
245874.06 60238.651 280323.53 68678.703 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
701919.72 171968.93 800265.85 196063.53 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2003836. 490935.82 2284593.9 559720.94 MAarrowhead1
% End of user PostScript
1 .602 0 r
.5231 .48049 m
.52572 .4853 L
.52881 .48954 L
.53242 .49333 L
.53661 .49677 L
.54144 .49998 L
.54699 .50302 L
.55337 .50599 L
.56068 .50896 L
.56903 .51198 L
.57858 .51514 L
.58949 .51849 L
.60195 .52211 L
.61616 .52607 L
.63238 .53044 L
.65088 .5353 L
.67198 .54075 L
.69604 .54687 L
.72348 .55379 L
.75477 .56161 L
.79044 .57049 L
.83112 .58056 L
.8775 .59202 L
.93038 .60505 L
.99067 .61989 L
s
.99067 .61989 m
1 .62218 L
s
1 0 0 r
.5231 .48049 m
.52572 .4853 L
s
% Start of user PostScript
2.7723966 -2.3408218 3.086901 -1.7634399 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52881 .48954 m
.53242 .49333 L
s
% Start of user PostScript
3.4577197 -1.2551501 3.8907137 -0.8007843 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57858 .51514 m
.58949 .51849 L
s
% Start of user PostScript
9.4300868 1.8167253 10.739254 2.2192472 MAarrowhead1
% End of user PostScript
1 .788 0 r
.72348 .55379 m
.75477 .56161 L
s
% Start of user PostScript
26.817406 6.4543047 30.571962 7.3933653 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
76.533851 18.723425 87.25636 21.354927 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
218.48265 53.521422 249.09415 61.022236 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
623.72156 152.80903 711.1113 174.21959 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1780.5961 436.24213 2030.0758 497.36422 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
5083.2346 1245.3822 5795.4477 1419.873 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
14511.586 3555.3096 16544.808 4053.4448 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
41427.586 10149.676 47232.014 11571.749 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
118267.21 28975.231 134837.66 33034.957 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
337628.5 82718.307 384933.71 94307.988 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
963859.74 236143.71 1098906.3 269229.85 MAarrowhead1
% End of user PostScript
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00833333 0.5 0.00833333 [
[0 .4875 -18.4688 -20 ]
[0 .4875 18.4688 0 ]
[.16667 .4875 -18.4688 -20 ]
[.16667 .4875 18.4688 0 ]
[.33333 .4875 -18.4688 -20 ]
[.33333 .4875 18.4688 0 ]
[.66667 .4875 -12 -20 ]
[.66667 .4875 12 0 ]
[.83333 .4875 -12 -20 ]
[.83333 .4875 12 0 ]
[1 .4875 -12 -20 ]
[1 .4875 12 0 ]
[.4875 0 -36.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .16667 -36.9375 -10 ]
[.4875 .16667 0 10 ]
[.4875 .33333 -36.9375 -10 ]
[.4875 .33333 0 10 ]
[.4875 .66667 -24 -10 ]
[.4875 .66667 0 10 ]
[.4875 .83333 -24 -10 ]
[.4875 .83333 0 10 ]
[.4875 1 -24 -10 ]
[.4875 1 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.16667 .5 m
.16667 .50625 L
s
gsave
.16667 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.33333 .5 m
.33333 .50625 L
s
gsave
.33333 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.66667 .5 m
.66667 .50625 L
s
gsave
.66667 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.83333 .5 m
.83333 .50625 L
s
gsave
.83333 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 .5 m
.04167 .50375 L
s
.08333 .5 m
.08333 .50375 L
s
.125 .5 m
.125 .50375 L
s
.20833 .5 m
.20833 .50375 L
s
.25 .5 m
.25 .50375 L
s
.29167 .5 m
.29167 .50375 L
s
.375 .5 m
.375 .50375 L
s
.41667 .5 m
.41667 .50375 L
s
.45833 .5 m
.45833 .50375 L
s
.54167 .5 m
.54167 .50375 L
s
.58333 .5 m
.58333 .50375 L
s
.625 .5 m
.625 .50375 L
s
.70833 .5 m
.70833 .50375 L
s
.75 .5 m
.75 .50375 L
s
.79167 .5 m
.79167 .50375 L
s
.875 .5 m
.875 .50375 L
s
.91667 .5 m
.91667 .50375 L
s
.95833 .5 m
.95833 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.5 .16667 m
.50625 .16667 L
s
gsave
.4875 .16667 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.5 .33333 m
.50625 .33333 L
s
gsave
.4875 .33333 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.5 .66667 m
.50625 .66667 L
s
gsave
.4875 .66667 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.5 .83333 m
.50625 .83333 L
s
gsave
.4875 .83333 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .04167 m
.50375 .04167 L
s
.5 .08333 m
.50375 .08333 L
s
.5 .125 m
.50375 .125 L
s
.5 .20833 m
.50375 .20833 L
s
.5 .25 m
.50375 .25 L
s
.5 .29167 m
.50375 .29167 L
s
.5 .375 m
.50375 .375 L
s
.5 .41667 m
.50375 .41667 L
s
.5 .45833 m
.50375 .45833 L
s
.5 .54167 m
.50375 .54167 L
s
.5 .58333 m
.50375 .58333 L
s
.5 .625 m
.50375 .625 L
s
.5 .70833 m
.50375 .70833 L
s
.5 .75 m
.50375 .75 L
s
.5 .79167 m
.50375 .79167 L
s
.5 .875 m
.50375 .875 L
s
.5 .91667 m
.50375 .91667 L
s
.5 .95833 m
.50375 .95833 L
s
.01 w
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .581 0 r
.5 Mabswid
.43922 .56504 m
.43266 .55019 L
.42486 .53723 L
.41569 .52577 L
.40502 .51546 L
.39266 .50602 L
.37841 .49717 L
.36203 .48869 L
.34325 .48037 L
.32175 .47199 L
.29716 .46337 L
.26906 .45432 L
.23696 .44465 L
.20033 .43417 L
.15853 .42267 L
.11084 .40994 L
.05645 .39574 L
s
.05645 .39574 m
0 .38124 L
s
1 .049 0 r
.46282 .48066 m
.45736 .48102 L
.45118 .48092 L
.44417 .48038 L
.4362 .47941 L
.42714 .47801 L
.41683 .47617 L
.40509 .47387 L
.39172 .47107 L
.37649 .46774 L
.35914 .46382 L
.33936 .45925 L
.31682 .45396 L
.29113 .44786 L
.26184 .44084 L
.22845 .43279 L
.19039 .42358 L
.14699 .41304 L
.09752 .401 L
.04112 .38725 L
s
.04112 .38725 m
0 .37721 L
s
1 0 .147 r
.54265 .58041 m
.55034 .5707 L
.55882 .56311 L
.56826 .55735 L
.57881 .55321 L
.59069 .5505 L
.60408 .5491 L
.61925 .5489 L
.63643 .54985 L
.65595 .55191 L
.67814 .55508 L
.70338 .55937 L
.73211 .56483 L
.76482 .57152 L
.80209 .57955 L
.84455 .58904 L
.89294 .60013 L
.94809 .613 L
s
.94809 .613 m
1 .62528 L
s
0 .48 1 r
.54302 .46218 m
.54786 .47138 L
.55358 .47946 L
.56026 .48668 L
.56801 .49323 L
.57697 .49931 L
.58728 .50507 L
.59911 .51067 L
.61266 .51625 L
.62816 .52193 L
.64589 .52784 L
.66614 .53411 L
.68925 .54086 L
.71563 .54824 L
.74573 .55637 L
.78007 .56542 L
.81923 .57555 L
.8639 .58693 L
.91483 .59978 L
.9729 .61431 L
s
.9729 .61431 m
1 .62106 L
s
1 .633 0 r
.52758 .53851 m
.53223 .53438 L
.53739 .53126 L
.54317 .52901 L
.54967 .52755 L
.557 .5268 L
.5653 .52671 L
.57472 .52724 L
.5854 .52838 L
.59755 .53012 L
.61137 .53248 L
.6271 .53547 L
.64502 .53914 L
.66543 .54354 L
.68868 .54874 L
.71518 .55482 L
.74538 .56187 L
.7798 .57001 L
.81904 .57938 L
.86377 .59014 L
.91476 .60246 L
.97289 .61657 L
s
.97289 .61657 m
1 .62316 L
s
0 .479 1 r
.41773 .57722 m
.40859 .55885 L
.39777 .54274 L
.38511 .5284 L
.37039 .51543 L
.35339 .50345 L
.33381 .49213 L
.31133 .48118 L
.28557 .47033 L
.25608 .45932 L
.22237 .4479 L
.18386 .43583 L
.13989 .42285 L
.08971 .40872 L
.03245 .39316 L
s
.03245 .39316 m
0 .38458 L
s
.899 1 0 r
.56939 .56752 m
.58035 .56184 L
.59264 .55786 L
.60648 .55543 L
.62212 .5544 L
.63983 .55468 L
.65992 .55622 L
.68274 .55899 L
.70869 .56299 L
.73822 .56826 L
.77184 .57486 L
.81013 .58287 L
.85375 .59242 L
.90346 .60364 L
.9601 .61673 L
s
.9601 .61673 m
1 .62609 L
s
.436 1 0 r
.5472 .55504 m
.55487 .54972 L
.56345 .54581 L
.57308 .54315 L
.58394 .54163 L
.59621 .54115 L
.61012 .54164 L
.62591 .54308 L
.64385 .54545 L
.66426 .54876 L
.68748 .55304 L
.71392 .55834 L
.74404 .56474 L
.77836 .57232 L
.81746 .58122 L
.86202 .59157 L
.91281 .60354 L
.97071 .61732 L
s
.97071 .61732 m
1 .62435 L
s
1 .635 0 r
.42762 .44516 m
.41657 .4486 L
.40412 .45068 L
.39005 .45151 L
.37412 .45118 L
.35604 .44973 L
.3355 .44718 L
.31215 .44353 L
.28558 .43875 L
.25532 .43278 L
.22086 .42555 L
.1816 .41693 L
.13686 .40681 L
.08588 .39502 L
.02777 .38137 L
s
.02777 .38137 m
0 .37477 L
s
1 0 .455 r
.49115 .56311 m
.49151 .55238 L
.49165 .54339 L
.4916 .53585 L
.49135 .52951 L
.49091 .52416 L
.49028 .51964 L
.48946 .51579 L
.48843 .51249 L
.48718 .50965 L
.4857 .50717 L
.48396 .50497 L
.48193 .503 L
.47958 .50119 L
.47687 .4995 L
.47375 .49788 L
.47018 .49629 L
.46609 .4947 L
.46142 .49305 L
.45607 .49133 L
.44997 .48949 L
.443 .48749 L
.43505 .4853 L
.42598 .48288 L
.41563 .48018 L
.40383 .47714 L
.39038 .47373 L
.37503 .46987 L
.35754 .46551 L
.33759 .46055 L
.31484 .45492 L
.2889 .44852 L
.25933 .44124 L
.22562 .43294 L
.18718 .4235 L
.14335 .41274 L
.09338 .40048 L
.03641 .3865 L
s
.03641 .3865 m
0 .37757 L
s
0 .906 1 r
.51827 .54962 m
.52193 .54304 L
.52593 .53777 L
.53033 .53365 L
.53522 .5305 L
.54069 .52822 L
.54684 .5267 L
.55377 .52588 L
.56162 .5257 L
.57051 .52612 L
.58061 .52713 L
.59208 .52872 L
.60514 .53089 L
.61999 .53368 L
.63691 .53712 L
.65618 .54125 L
.67813 .54613 L
.70315 .55185 L
.73167 .55849 L
.76417 .56617 L
.80122 .575 L
.84345 .58515 L
.8916 .59678 L
.94649 .61009 L
s
.94649 .61009 m
1 .6231 L
s
0 .211 1 r
.44611 .5348 m
.43974 .52528 L
.43227 .51682 L
.4236 .50916 L
.41358 .50209 L
.40204 .49541 L
.38879 .48894 L
.37361 .48254 L
.35623 .47605 L
.33636 .46931 L
.31366 .46219 L
.28775 .45454 L
.25817 .44621 L
.22442 .43704 L
.18592 .42685 L
.142 .41546 L
.09192 .40267 L
.03481 .38824 L
s
.03481 .38824 m
0 .37951 L
s
1 0 .388 r
.5201 .43203 m
.52113 .44436 L
.5226 .4548 L
.52453 .46367 L
.52693 .47128 L
.52983 .47784 L
.53329 .48357 L
.53736 .48864 L
.54209 .4932 L
.54756 .49737 L
.55388 .50129 L
.56114 .50504 L
.56946 .50872 L
.57899 .51243 L
.58989 .51625 L
.60234 .52026 L
.61656 .52454 L
.63279 .52918 L
.65132 .53427 L
.67245 .53992 L
.69655 .54621 L
.72404 .55327 L
.7554 .56122 L
.79115 .5702 L
.83191 .58037 L
.87839 .59192 L
.93139 .60503 L
.99182 .61995 L
s
.99182 .61995 m
1 .62196 L
s
.908 1 0 r
.49686 .56486 m
.49803 .55427 L
.49909 .54546 L
.50008 .53813 L
.50102 .53205 L
.50195 .52701 L
.50287 .52284 L
.50381 .5194 L
.5048 .51658 L
.50585 .51429 L
.50698 .51244 L
.50822 .51096 L
.50959 .50982 L
.51112 .50895 L
.51283 .50834 L
.51476 .50795 L
.51693 .50777 L
.51939 .50777 L
.52218 .50795 L
.52535 .50831 L
.52896 .50885 L
.53306 .50956 L
.53772 .51046 L
.54304 .51156 L
.54909 .51288 L
.55599 .51443 L
.56386 .51624 L
.57282 .51833 L
.58303 .52075 L
.59468 .52354 L
.60795 .52673 L
.62308 .53039 L
.64033 .53458 L
.66 .53937 L
.68242 .54483 L
.70798 .55107 L
.73713 .55819 L
.77035 .56632 L
.80823 .57558 L
.85142 .58615 L
.90066 .59821 L
.9568 .61195 L
s
.9568 .61195 m
1 .62253 L
s
.477 0 1 r
.56827 .54143 m
.57844 .53983 L
.58993 .53923 L
.60295 .53957 L
.61773 .54082 L
.63451 .54294 L
.65361 .54597 L
.67533 .54991 L
.70007 .55482 L
.72824 .56076 L
.76034 .56782 L
.79691 .57611 L
.8386 .58577 L
.88611 .59694 L
.94026 .60982 L
s
.94026 .60982 m
1 .62414 L
s
.323 1 0 r
.45805 .5317 m
.4532 .52356 L
.4475 .51636 L
.44086 .50989 L
.43317 .50397 L
.4243 .49843 L
.41411 .49312 L
.40243 .48791 L
.38904 .48267 L
.37374 .47729 L
.35625 .47164 L
.33628 .46561 L
.31348 .45908 L
.28746 .45191 L
.25778 .44398 L
.22392 .43514 L
.18531 .42522 L
.14128 .41404 L
.09106 .40142 L
.0338 .38713 L
s
.0338 .38713 m
0 .37873 L
s
0 .269 1 r
.45847 .44568 m
.45157 .45131 L
.44389 .45552 L
.43527 .4585 L
.42558 .46038 L
.41463 .46124 L
.40223 .46116 L
.38816 .46018 L
.37219 .45832 L
.35403 .45559 L
.33336 .45196 L
.30984 .44739 L
.28305 .44182 L
.25253 .43518 L
.21775 .42735 L
.17812 .41822 L
.13295 .40764 L
.08147 .39543 L
.02277 .38139 L
s
.02277 .38139 m
0 .3759 L
s
0 1 .458 r
.54613 .56115 m
.55382 .55478 L
.56237 .54998 L
.57196 .54658 L
.58275 .54443 L
.59494 .54341 L
.60874 .54346 L
.62438 .5445 L
.64215 .54653 L
.66236 .54954 L
.68534 .55356 L
.71151 .55862 L
.74131 .56479 L
.77526 .57217 L
.81394 .58086 L
.85803 .59101 L
.90827 .60277 L
.96554 .61635 L
s
.96554 .61635 m
1 .62459 L
s
.376 0 1 r
.44156 .46097 m
.43277 .46291 L
.42284 .46389 L
.41161 .46399 L
.39887 .46325 L
.38441 .46169 L
.36797 .45932 L
.34927 .45612 L
.32798 .45205 L
.30374 .44708 L
.27612 .44111 L
.24466 .43407 L
.2088 .42584 L
.16793 .4163 L
.12134 .40527 L
.06824 .39259 L
.00771 .37803 L
s
.00771 .37803 m
0 .37616 L
s
0 1 .143 r
.52729 .42474 m
.52911 .43876 L
.53151 .45067 L
.53453 .46086 L
.5382 .46965 L
.54258 .4773 L
.54773 .48405 L
.55375 .4901 L
.56071 .49563 L
.56875 .50079 L
.57799 .50571 L
.58859 .51053 L
.60072 .51535 L
.61461 .5203 L
.63047 .52548 L
.6486 .53099 L
.66928 .53696 L
.69289 .54349 L
.71983 .55071 L
.75055 .55876 L
.78559 .56778 L
.82555 .57793 L
.87112 .5894 L
.92308 .60238 L
.98232 .61711 L
s
.98232 .61711 m
1 .62148 L
s
.02 0 1 r
.50732 .52112 m
.50882 .51829 L
.51045 .51602 L
.51224 .51423 L
.51423 .51285 L
.51645 .51185 L
.51895 .51116 L
.52176 .51077 L
.52495 .51065 L
.52855 .51078 L
.53265 .51116 L
.5373 .51177 L
.54259 .51263 L
.54861 .51374 L
.55547 .51512 L
.56327 .51678 L
.57217 .51875 L
.58231 .52105 L
.59386 .52374 L
.60703 .52684 L
.62204 .53042 L
.63916 .53452 L
.65866 .53923 L
.6809 .54462 L
.70626 .55078 L
.73516 .55782 L
.76811 .56586 L
.80568 .57504 L
.84852 .58551 L
.89735 .59745 L
.95303 .61107 L
s
.95303 .61107 m
1 .62257 L
s
0 .573 1 r
.53829 .55502 m
.54478 .54905 L
.55198 .54451 L
.56004 .54122 L
.56911 .53905 L
.57933 .53789 L
.5909 .53766 L
.60401 .53833 L
.6189 .53985 L
.63582 .54222 L
.65506 .54545 L
.67697 .54958 L
.70192 .55466 L
.73034 .56077 L
.76272 .56798 L
.79962 .57642 L
.84167 .58622 L
.8896 .59755 L
.94424 .61059 L
s
.94424 .61059 m
1 .62399 L
s
0 1 .552 r
.4185 .46575 m
.40673 .46523 L
.39337 .46393 L
.37818 .46186 L
.36091 .459 L
.34126 .45533 L
.31887 .45081 L
.29338 .44536 L
.26433 .43891 L
.23123 .43135 L
.1935 .42257 L
.1505 .41243 L
.10149 .40074 L
.04561 .38732 L
s
.04561 .38732 m
0 .37631 L
s
.332 0 1 r
.46741 .44673 m
.46174 .45284 L
.45545 .45756 L
.44844 .46106 L
.44057 .46349 L
.43171 .46496 L
.42169 .46554 L
.41035 .46529 L
.39747 .46425 L
.38285 .46243 L
.36622 .45982 L
.34729 .45641 L
.32574 .45215 L
.3012 .447 L
.27324 .44086 L
.24139 .43365 L
.20508 .42525 L
.16369 .41552 L
.11652 .40431 L
.06275 .39142 L
.00145 .37665 L
s
.00145 .37665 m
0 .3763 L
s
1 .053 0 r
.46483 .52607 m
.46076 .51932 L
.45597 .51336 L
.45039 .50799 L
.44393 .50307 L
.43648 .49846 L
.42793 .49404 L
.41812 .4897 L
.40688 .48533 L
.39404 .48083 L
.37935 .47611 L
.36259 .47106 L
.34345 .46559 L
.32162 .45959 L
.2967 .45294 L
.26829 .44552 L
.23588 .4372 L
.19892 .42783 L
.15677 .41724 L
.10872 .40525 L
.05392 .39164 L
s
.05392 .39164 m
0 .3783 L
s
0 .528 1 r
.54452 .55018 m
.55172 .54544 L
.55977 .54198 L
.56882 .53967 L
.57902 .53839 L
.59055 .53806 L
.60363 .53864 L
.61847 .54008 L
.63534 .54238 L
.65453 .54555 L
.67637 .54963 L
.70124 .55466 L
.72957 .56071 L
.76184 .56788 L
.79862 .57627 L
.84053 .58603 L
.88831 .5973 L
.94277 .61028 L
s
.94277 .61028 m
1 .62403 L
s
.752 1 0 r
.47354 .48758 m
.46969 .48762 L
.46532 .48737 L
.46036 .48684 L
.45472 .48603 L
.44831 .48494 L
.44101 .48354 L
.43269 .48184 L
.42322 .4798 L
.41243 .47738 L
.40013 .47456 L
.38611 .47129 L
.37014 .46751 L
.35192 .46316 L
.33116 .45817 L
.3075 .45244 L
.28051 .4459 L
.24975 .43842 L
.21469 .42987 L
.17471 .42011 L
.12912 .40898 L
.07716 .39627 L
.01791 .38178 L
s
.01791 .38178 m
0 .3774 L
s
.044 0 1 r
.50475 .44612 m
.50407 .45507 L
.50351 .46254 L
.50307 .46878 L
.50271 .47399 L
.50244 .47834 L
.50224 .48198 L
.5021 .48502 L
.50201 .48757 L
.50198 .4897 L
.50199 .49149 L
.50205 .49299 L
.50215 .49426 L
.5023 .49534 L
.50249 .49625 L
.50274 .49703 L
.50303 .49771 L
.50338 .4983 L
.50379 .49882 L
.50427 .49928 L
.50483 .49971 L
.50547 .50011 L
.5062 .5005 L
.50705 .50087 L
.50802 .50125 L
.50912 .50164 L
.51038 .50205 L
.51183 .50248 L
.51347 .50296 L
.51535 .50347 L
.5175 .50405 L
.51994 .50469 L
.52273 .5054 L
.52591 .50621 L
.52954 .50712 L
.53368 .50815 L
.53839 .50933 L
.54377 .51066 L
.5499 .51217 L
.55689 .51389 L
.56486 .51585 L
.57395 .51808 L
.58431 .52063 L
.59612 .52353 L
.60959 .52683 L
.62494 .5306 L
.64245 .53489 L
.66241 .53978 L
.68516 .54536 L
.7111 .55171 L
Mistroke
.74068 .55896 L
.7744 .56722 L
.81285 .57664 L
.85668 .58738 L
.90666 .59963 L
.96364 .61359 L
Mfstroke
.96364 .61359 m
1 .6225 L
s
1 .002 0 r
.56642 .43195 m
.57366 .4477 L
.58226 .46146 L
.59235 .47365 L
.60409 .48464 L
.61767 .49474 L
.63333 .50422 L
.65131 .51334 L
.67193 .52232 L
.69553 .53139 L
.72253 .54074 L
.75337 .55058 L
.78858 .56111 L
.82878 .57255 L
.87465 .58511 L
.92698 .59904 L
.98667 .61458 L
s
.98667 .61458 m
1 .618 L
s
0 1 .024 r
.56449 .44692 m
.57184 .46013 L
.5805 .47177 L
.5906 .48219 L
.60232 .49169 L
.61584 .50053 L
.63138 .50895 L
.64922 .51717 L
.66966 .52539 L
.69303 .5338 L
.71975 .54258 L
.75026 .55192 L
.78509 .56201 L
.82485 .57305 L
.8702 .58524 L
.92194 .59882 L
.98094 .61403 L
s
.98094 .61403 m
1 .61888 L
s
.007 1 0 r
.48242 .47682 m
.4795 .47923 L
.47624 .48104 L
.47259 .48232 L
.46848 .48313 L
.46384 .48351 L
.45859 .48349 L
.45263 .48308 L
.44587 .48231 L
.43817 .48116 L
.42942 .47962 L
.41946 .47769 L
.40811 .47534 L
.39518 .47253 L
.38045 .46922 L
.36367 .46535 L
.34453 .46087 L
.32273 .4557 L
.29787 .44975 L
.26953 .44293 L
.23722 .43512 L
.20039 .42618 L
.1584 .41596 L
.11053 .40429 L
.05596 .39097 L
s
.05596 .39097 m
0 .37729 L
s
0 1 .225 r
.42767 .54695 m
.41912 .53415 L
.40911 .52275 L
.39748 .51244 L
.38403 .50293 L
.36855 .49394 L
.35078 .48526 L
.3304 .47665 L
.30709 .46792 L
.28043 .45888 L
.24997 .44932 L
.2152 .43904 L
.17552 .42786 L
.13023 .41555 L
.07857 .40187 L
.01965 .38659 L
s
.01965 .38659 m
0 .38157 L
s
.976 0 1 r
.49451 .52796 m
.49446 .52309 L
.49428 .519 L
.49398 .51554 L
.49356 .51262 L
.493 .51013 L
.49231 .508 L
.49147 .50616 L
.49048 .50455 L
.48932 .50312 L
.48796 .50184 L
.48639 .50066 L
.48458 .49956 L
.4825 .49849 L
.48012 .49745 L
.47739 .4964 L
.47427 .49531 L
.4707 .49417 L
.46663 .49295 L
.46199 .49162 L
.45668 .49017 L
.45063 .48856 L
.44373 .48676 L
.43586 .48474 L
.42689 .48247 L
.41665 .4799 L
.40498 .47698 L
.39167 .47368 L
.3765 .46993 L
.3592 .46566 L
.33948 .4608 L
.31699 .45527 L
.29135 .44897 L
.26212 .44179 L
.22879 .43362 L
.1908 .4243 L
.14748 .41368 L
.09808 .40157 L
.04177 .38777 L
s
.04177 .38777 m
0 .37753 L
s
.453 1 0 r
.51245 .47504 m
.51351 .47994 L
.51483 .48413 L
.51643 .48776 L
.51834 .49092 L
.52058 .49371 L
.52318 .49623 L
.5262 .49853 L
.52968 .50069 L
.53367 .50276 L
.53826 .50479 L
.5435 .50684 L
.54951 .50894 L
.55636 .51115 L
.5642 .51351 L
.57314 .51607 L
.58334 .51887 L
.59498 .52198 L
.60825 .52545 L
.62339 .52933 L
.64066 .53371 L
.66035 .53866 L
.6828 .54426 L
.7084 .55062 L
.73759 .55785 L
.77087 .56606 L
.80881 .57541 L
.85207 .58605 L
.90139 .59816 L
.95763 .61197 L
s
.95763 .61197 m
1 .62237 L
s
.617 1 0 r
.463 .47699 m
.45748 .47794 L
.45123 .47834 L
.44416 .47822 L
.43614 .4776 L
.42703 .47648 L
.41667 .47488 L
.40488 .47277 L
.39145 .47013 L
.37617 .46693 L
.35875 .46311 L
.3389 .45863 L
.31628 .4534 L
.2905 .44735 L
.26112 .44037 L
.22762 .43235 L
.18944 .42314 L
.1459 .41261 L
.09628 .40055 L
.0397 .38678 L
s
.0397 .38678 m
0 .3771 L
s
0 .112 1 r
.49378 .52012 m
.49343 .51645 L
.49296 .51334 L
.49234 .51069 L
.49157 .50842 L
.49065 .50646 L
.48955 .50474 L
.48827 .50322 L
.48677 .50184 L
.48504 .50058 L
.48305 .49939 L
.48076 .49824 L
.47814 .49711 L
.47514 .49596 L
.4717 .49478 L
.46778 .49354 L
.4633 .4922 L
.45819 .49075 L
.45235 .48916 L
.4457 .48739 L
.43811 .48542 L
.42945 .4832 L
.41958 .4807 L
.40832 .47787 L
.39548 .47467 L
.38085 .47104 L
.36416 .46691 L
.34513 .46222 L
.32343 .45688 L
.2987 .45079 L
.2705 .44387 L
.23834 .43597 L
.20169 .42698 L
.15989 .41673 L
.11224 .40504 L
.05791 .39173 L
s
.05791 .39173 m
0 .37753 L
s
.119 0 1 r
.42537 .54485 m
.41646 .53221 L
.40605 .52093 L
.39396 .51069 L
.38 .50119 L
.36394 .49219 L
.3455 .48344 L
.32437 .47474 L
.3002 .46587 L
.27257 .45665 L
.24101 .44687 L
.20497 .43633 L
.16385 .42483 L
.11692 .41214 L
.0634 .39803 L
.00235 .38225 L
s
.00235 .38225 m
0 .38165 L
s
.633 1 0 r
.54356 .47927 m
.54889 .48578 L
.5551 .49164 L
.56229 .49702 L
.57057 .50207 L
.58008 .50692 L
.59099 .5117 L
.60348 .51652 L
.61777 .52148 L
.63409 .5267 L
.65272 .53228 L
.67399 .53835 L
.69827 .545 L
.72596 .55238 L
.75755 .56061 L
.79357 .56985 L
.83465 .58026 L
.8815 .59202 L
.93491 .60535 L
.99582 .62047 L
s
.99582 .62047 m
1 .6215 L
s
1 0 .101 r
.50955 .52771 m
.5115 .52398 L
.51363 .521 L
.51598 .51865 L
.51858 .51684 L
.52148 .51552 L
.52474 .51462 L
.52842 .5141 L
.53257 .51394 L
.53728 .5141 L
.54263 .51459 L
.5487 .51539 L
.55561 .51651 L
.56347 .51796 L
.57243 .51975 L
.58262 .52192 L
.59424 .52449 L
.60748 .5275 L
.62257 .531 L
.63976 .53505 L
.65936 .53972 L
.68171 .54508 L
.70718 .55123 L
.73622 .55827 L
.76933 .56631 L
.80707 .57551 L
.8501 .586 L
.89916 .59798 L
.95509 .61166 L
s
.95509 .61166 m
1 .62264 L
s
1 .465 0 r
.47641 .41747 m
.47122 .42891 L
.46562 .43815 L
.4595 .4455 L
.45273 .45123 L
.4452 .45554 L
.43676 .45862 L
.42727 .46058 L
.41655 .46153 L
.40441 .46155 L
.39065 .46067 L
.37503 .45891 L
.35726 .4563 L
.33705 .45279 L
.31404 .44836 L
.28783 .44295 L
.25798 .43647 L
.22397 .42884 L
.18521 .41993 L
.14103 .4096 L
.09068 .39767 L
.03328 .38394 L
s
.03328 .38394 m
0 .37593 L
s
1 .289 0 r
.49934 .46153 m
.49831 .46763 L
.49729 .47267 L
.49626 .47684 L
.49519 .48026 L
.49406 .48306 L
.49284 .48533 L
.49153 .48714 L
.49007 .48857 L
.48846 .48967 L
.48666 .49047 L
.48464 .49101 L
.48236 .49132 L
.47978 .49141 L
.47686 .4913 L
.47355 .49099 L
.46978 .49048 L
.46549 .48978 L
.46062 .48888 L
.45506 .48776 L
.44873 .48642 L
.44153 .48482 L
.43331 .48295 L
.42395 .48077 L
.41328 .47826 L
.40112 .47536 L
.38726 .47203 L
.37145 .46822 L
.35343 .46385 L
.33289 .45886 L
.30947 .45315 L
.28278 .44664 L
.25234 .43921 L
.21763 .43072 L
.17807 .42105 L
.13296 .41001 L
.08153 .39742 L
.0229 .38306 L
s
.0229 .38306 m
0 .37746 L
s
1 .968 0 r
.44652 .51671 m
.43975 .51011 L
.43192 .50407 L
.42289 .49842 L
.41251 .49301 L
.4006 .4877 L
.38697 .48236 L
.37138 .47688 L
.35357 .47112 L
.33322 .46498 L
.30999 .45832 L
.28349 .45102 L
.25326 .44294 L
.21877 .43393 L
.17943 .42382 L
.13458 .41244 L
.08343 .39958 L
.0251 .38502 L
s
.0251 .38502 m
0 .37879 L
s
.176 0 1 r
.42875 .4678 m
.41841 .46771 L
.40668 .46687 L
.39335 .46531 L
.3782 .46302 L
.36096 .45998 L
.34133 .45615 L
.31898 .4515 L
.29352 .44595 L
.2645 .43942 L
.23143 .43179 L
.19375 .42296 L
.15079 .41277 L
.10182 .40105 L
.046 .3876 L
s
.046 .3876 m
0 .37647 L
s
0 1 .189 r
.50145 .51141 m
.50192 .5097 L
.50242 .50829 L
.50294 .50714 L
.50351 .50622 L
.50414 .50548 L
.50483 .50491 L
.50559 .50448 L
.50645 .50418 L
.50742 .50398 L
.50851 .50389 L
.50975 .5039 L
.51115 .50399 L
.51275 .50417 L
.51456 .50444 L
.51662 .5048 L
.51897 .50526 L
.52164 .50581 L
.52468 .50647 L
.52815 .50725 L
.5321 .50816 L
.53661 .50922 L
.54175 .51043 L
.5476 .51183 L
.55427 .51344 L
.56188 .51528 L
.57055 .51739 L
.58044 .51979 L
.59171 .52254 L
.60457 .52568 L
.61922 .52926 L
.63592 .53334 L
.65497 .538 L
.67668 .54331 L
.70144 .54938 L
.72966 .55629 L
.76184 .56417 L
.79853 .57315 L
.84036 .5834 L
.88804 .59508 L
.94241 .6084 L
s
.94241 .6084 m
1 .62251 L
s
0 1 .033 r
.55182 .53236 m
.55957 .531 L
.56831 .53042 L
.57822 .53058 L
.58946 .53145 L
.60223 .533 L
.61674 .53523 L
.63326 .53818 L
.65207 .54187 L
.67349 .54636 L
.69789 .5517 L
.7257 .55798 L
.75738 .5653 L
.7935 .57377 L
.83467 .58355 L
.8816 .59479 L
.9351 .60768 L
.99608 .62244 L
s
.99608 .62244 m
1 .6234 L
s
1 .045 0 r
.56466 .46175 m
.57239 .47261 L
.58143 .4823 L
.59192 .49111 L
.60402 .49928 L
.61796 .50703 L
.63395 .51457 L
.65227 .52208 L
.67323 .52974 L
.69719 .53772 L
.72456 .54618 L
.75581 .5553 L
.79147 .56526 L
.83216 .57624 L
.87857 .58847 L
.93151 .60214 L
.99188 .61753 L
s
.99188 .61753 m
1 .61958 L
s
.696 0 1 r
.5457 .48453 m
.55146 .49036 L
.55812 .49568 L
.56581 .50063 L
.57465 .50537 L
.58479 .50999 L
.59641 .51462 L
.6097 .51937 L
.62488 .52433 L
.64223 .52962 L
.66203 .53534 L
.68462 .5416 L
.7104 .54851 L
.7398 .55622 L
.77334 .56486 L
.81159 .57458 L
.8552 .58555 L
.90493 .59798 L
.96164 .61208 L
s
.96164 .61208 m
1 .62158 L
s
1 0 .287 r
.46645 .54248 m
.46299 .53323 L
.45884 .52521 L
.45394 .51816 L
.44821 .51188 L
.44155 .50618 L
.43386 .5009 L
.42502 .4959 L
.41486 .49105 L
.40322 .48622 L
.3899 .48131 L
.37468 .47621 L
.35729 .47081 L
.33744 .46499 L
.31478 .45864 L
.28893 .45164 L
.25944 .44386 L
.2258 .43515 L
.18744 .42537 L
.14369 .41433 L
.09381 .40184 L
.03693 .38768 L
s
.03693 .38768 m
0 .37852 L
s
1 0 .051 r
.50084 .56619 m
.50257 .55568 L
.50428 .54698 L
.506 .53979 L
.50778 .53388 L
.50966 .52904 L
.51166 .52512 L
.51384 .52196 L
.51624 .51947 L
.51889 .51756 L
.52185 .51614 L
.52518 .51517 L
.52893 .5146 L
.53317 .51439 L
.53797 .51453 L
.54341 .515 L
.5496 .51579 L
.55664 .51691 L
.56465 .51837 L
.57377 .52019 L
.58416 .52238 L
.59599 .52499 L
.60948 .52805 L
.62485 .53161 L
.64237 .53573 L
.66234 .54048 L
.6851 .54594 L
.71105 .5522 L
.74063 .55937 L
.77435 .56756 L
.8128 .57692 L
.85663 .58761 L
.90661 .59982 L
.96358 .61374 L
s
.96358 .61374 m
1 .62265 L
s
.552 0 1 r
.51618 .52153 m
.51888 .51928 L
.52188 .51759 L
.52525 .51639 L
.52904 .51563 L
.53331 .51526 L
.53815 .51527 L
.54364 .51564 L
.54988 .51635 L
.55697 .5174 L
.56504 .5188 L
.57422 .52058 L
.58467 .52274 L
.59659 .52533 L
.61016 .52838 L
.62563 .53194 L
.64326 .53607 L
.66336 .54083 L
.68626 .54631 L
.71238 .55259 L
.74215 .5598 L
.77609 .56803 L
.81478 .57745 L
.85889 .5882 L
.90918 .60048 L
.96652 .61449 L
s
.96652 .61449 m
1 .62267 L
s
1 .746 0 r
.57313 .51716 m
.58335 .51979 L
.59502 .52275 L
.60832 .5261 L
.62348 .52989 L
.64077 .53418 L
.66049 .53906 L
.68297 .54461 L
.7086 .55093 L
.73782 .55812 L
.77114 .56631 L
.80913 .57563 L
.85243 .58626 L
.90181 .59837 L
.95811 .61218 L
s
.95811 .61218 m
1 .62245 L
s
.18 0 1 r
.55344 .51591 m
.561 .51729 L
.5696 .51901 L
.5794 .52109 L
.59057 .52355 L
.60329 .52644 L
.61779 .52981 L
.63431 .5337 L
.65315 .53818 L
.67463 .54333 L
.69911 .54924 L
.72702 .556 L
.75883 .56373 L
.79511 .57257 L
.83646 .58265 L
.88361 .59417 L
.93736 .60731 L
.99864 .6223 L
s
.99864 .6223 m
1 .62263 L
s
.974 0 1 r
.51275 .42294 m
.51257 .43618 L
.5127 .44729 L
.51311 .45664 L
.51381 .46453 L
.51479 .4712 L
.51607 .47689 L
.51766 .48176 L
.51958 .48597 L
.52186 .48965 L
.52454 .49291 L
.52766 .49584 L
.53126 .49854 L
.53542 .50107 L
.5402 .5035 L
.54567 .50589 L
.55194 .5083 L
.55911 .51079 L
.5673 .51341 L
.57666 .51621 L
.58733 .51925 L
.59952 .52259 L
.61342 .5263 L
.62927 .53043 L
.64735 .53506 L
.66797 .54029 L
.69149 .54619 L
.7183 .55288 L
.74887 .56047 L
.78373 .56909 L
.82347 .5789 L
.86878 .59006 L
.92045 .60276 L
.97935 .61724 L
s
.97935 .61724 m
1 .62231 L
s
1 0 .477 r
.4716 .57804 m
.4697 .56349 L
.46719 .55113 L
.46404 .54056 L
.46021 .53144 L
.45565 .5235 L
.45028 .51649 L
.44401 .5102 L
.43675 .50446 L
.42838 .4991 L
.41875 .49399 L
.40771 .48898 L
.39506 .48396 L
.38059 .47881 L
.36406 .47343 L
.34518 .46769 L
.32363 .46147 L
.29903 .45467 L
.27097 .44715 L
.23896 .43877 L
.20245 .42937 L
.16081 .41879 L
.11334 .40685 L
.0592 .39332 L
s
.0592 .39332 m
0 .37861 L
s
1 0 .611 r
.53974 .48122 m
.5446 .48714 L
.55027 .49247 L
.55683 .49736 L
.56439 .50196 L
.57307 .50638 L
.58303 .51072 L
.59442 .51511 L
.60746 .51963 L
.62235 .52439 L
.63935 .52948 L
.65876 .53501 L
.68091 .54108 L
.70618 .54781 L
.735 .55532 L
.76787 .56374 L
.80536 .57324 L
.84811 .58397 L
.89685 .59613 L
.95242 .60993 L
s
.95242 .60993 m
1 .6217 L
s
.336 1 0 r
.47987 .53367 m
.478 .52682 L
.47571 .52092 L
.47296 .5158 L
.46972 .51129 L
.46594 .50726 L
.46154 .5036 L
.45648 .5002 L
.45064 .49697 L
.44395 .49383 L
.43628 .4907 L
.42751 .4875 L
.41748 .48418 L
.40603 .48064 L
.39295 .47683 L
.37803 .47267 L
.361 .46807 L
.34157 .46296 L
.31942 .45724 L
.29416 .4508 L
.26535 .44354 L
.23249 .43532 L
.19503 .426 L
.15232 .41542 L
.10362 .40339 L
.0481 .3897 L
s
.0481 .3897 m
0 .37787 L
s
1 0 .857 r
.57721 .5355 m
.58844 .5355 L
.60117 .53633 L
.61563 .53796 L
.63206 .54039 L
.65076 .54364 L
.67205 .54775 L
.69629 .55276 L
.72391 .55875 L
.75538 .56582 L
.79124 .57406 L
.83211 .58363 L
.8787 .59467 L
.9318 .60737 L
.99234 .62194 L
s
.99234 .62194 m
1 .62379 L
s
1 0 .181 r
.48513 .49739 m
.48307 .49672 L
.48072 .496 L
.47804 .49522 L
.47497 .49437 L
.47148 .49343 L
.46749 .49239 L
.46295 .49121 L
.45776 .4899 L
.45185 .48841 L
.44511 .48672 L
.43742 .48481 L
.42866 .48264 L
.41867 .48017 L
.40727 .47736 L
.39428 .47417 L
.37947 .47053 L
.36259 .46638 L
.34333 .46166 L
.32138 .45627 L
.29636 .45014 L
.26783 .44314 L
.2353 .43517 L
.19821 .42608 L
.15593 .41572 L
.10772 .4039 L
.05276 .39044 L
s
.05276 .39044 m
0 .37751 L
s
.517 0 1 r
.53847 .49833 m
.54359 .50142 L
.54947 .50439 L
.55621 .50733 L
.56393 .51028 L
.57275 .51334 L
.58283 .51655 L
.59435 .51999 L
.60749 .52373 L
.62249 .52784 L
.6396 .53239 L
.65911 .53747 L
.68137 .54317 L
.70675 .5496 L
.73569 .55686 L
.76869 .56509 L
.80632 .57443 L
.84922 .58505 L
.89813 .59712 L
.95391 .61085 L
s
.95391 .61085 m
1 .62219 L
s
0 1 .577 r
.4664 .56238 m
.46342 .54995 L
.45974 .53929 L
.4553 .53006 L
.45004 .52198 L
.44388 .5148 L
.43671 .50831 L
.42843 .50234 L
.41888 .49671 L
.40793 .49128 L
.39536 .48591 L
.38099 .48047 L
.36455 .47485 L
.34576 .46892 L
.32432 .46255 L
.29984 .45563 L
.27191 .44801 L
.24005 .43956 L
.20371 .43012 L
.16226 .41951 L
.11499 .40756 L
.06109 .39404 L
s
.06109 .39404 m
0 .37882 L
s
0 1 .17 r
.48895 .5343 m
.48831 .52801 L
.48743 .52268 L
.4863 .51814 L
.48491 .51424 L
.48323 .51085 L
.48125 .50789 L
.47892 .50525 L
.47623 .50287 L
.47311 .50066 L
.46952 .49858 L
.46539 .49657 L
.46067 .49458 L
.45526 .49255 L
.44908 .49046 L
.44202 .48824 L
.43395 .48586 L
.42475 .48327 L
.41425 .48041 L
.40227 .47724 L
.3886 .4737 L
.37302 .46972 L
.35525 .46522 L
.33498 .46015 L
.31188 .45439 L
.28553 .44786 L
.25549 .44043 L
.22124 .43198 L
.18219 .42237 L
.13767 .41142 L
.08691 .39896 L
.02904 .38475 L
s
.02904 .38475 m
0 .37763 L
s
1 0 .398 r
.45393 .57771 m
.44965 .56192 L
.44441 .54833 L
.43814 .53653 L
.43074 .52616 L
.42209 .51689 L
.41206 .50847 L
.40047 .50066 L
.38714 .49325 L
.37184 .48603 L
.35431 .47885 L
.33425 .47153 L
.31132 .4639 L
.28513 .45581 L
.25524 .44708 L
.22111 .43755 L
.18218 .42704 L
.13777 .41535 L
.08712 .40226 L
.02936 .38754 L
s
.02936 .38754 m
0 .38014 L
s
.276 0 1 r
.52296 .48911 m
.52577 .49253 L
.52904 .49562 L
.53283 .49845 L
.5372 .50111 L
.54221 .50366 L
.54796 .50618 L
.55455 .50872 L
.56208 .51133 L
.57068 .51408 L
.5805 .51702 L
.59172 .52022 L
.60451 .52373 L
.61911 .52761 L
.63576 .53195 L
.65475 .53682 L
.6764 .54231 L
.70109 .54851 L
.72925 .55553 L
.76136 .5635 L
.79796 .57256 L
.8397 .58286 L
.88729 .59458 L
.94154 .60792 L
s
.94154 .60792 m
1 .62228 L
s
.276 1 0 r
.50149 .4788 m
.50117 .4823 L
.5009 .48521 L
.50065 .48764 L
.50044 .48966 L
.50025 .49134 L
.50007 .49274 L
.4999 .49391 L
.49973 .49487 L
.49957 .49567 L
.49941 .49633 L
.49924 .49687 L
.49906 .49732 L
.49887 .49768 L
.49866 .49796 L
.49843 .49819 L
.49818 .49837 L
.4979 .49849 L
.49758 .49858 L
.49722 .49863 L
.49681 .49864 L
.49635 .49863 L
.49583 .49858 L
.49523 .4985 L
.49456 .49839 L
.49379 .49824 L
.49291 .49807 L
.49191 .49786 L
.49078 .4976 L
.48948 .49731 L
.488 .49697 L
.48632 .49657 L
.4844 .49611 L
.48221 .49559 L
.47972 .49499 L
.47688 .4943 L
.47364 .49351 L
.46994 .49261 L
.46573 .49158 L
.46093 .49041 L
.45546 .48907 L
.44922 .48755 L
.4421 .4858 L
.43399 .48382 L
.42474 .48155 L
.41419 .47897 L
.40217 .47603 L
.38846 .47267 L
.37284 .46884 L
.35502 .46448 L
Mistroke
.3347 .4595 L
.31154 .45383 L
.28514 .44736 L
.25504 .43998 L
.22071 .43157 L
.18158 .42199 L
.13697 .41106 L
.08611 .3986 L
.02812 .38439 L
Mfstroke
.02812 .38439 m
0 .3775 L
s
.256 1 0 r
.44365 .47495 m
.43548 .47481 L
.42621 .4741 L
.41568 .47281 L
.40371 .47096 L
.39008 .46853 L
.37457 .46548 L
.35691 .46178 L
.33678 .45737 L
.31385 .45219 L
.28771 .44615 L
.25792 .43916 L
.22397 .43109 L
.18526 .42182 L
.14114 .41119 L
.09084 .39901 L
.03349 .38509 L
s
.03349 .38509 m
0 .37693 L
s
1 0 .923 r
.42494 .53896 m
.41583 .52723 L
.40521 .5167 L
.3929 .50707 L
.37871 .49808 L
.3624 .48948 L
.34369 .48105 L
.32226 .4726 L
.29776 .46392 L
.26975 .45482 L
.23776 .44513 L
.20125 .43463 L
.15958 .42312 L
.11205 .4104 L
.05783 .39621 L
s
.05783 .39621 m
0 .38134 L
s
1 .52 0 r
.45415 .47095 m
.44728 .47222 L
.43953 .47278 L
.43076 .47269 L
.4208 .47196 L
.4095 .47062 L
.39664 .46867 L
.38201 .46608 L
.36536 .46283 L
.34639 .45887 L
.32478 .45416 L
.30016 .44861 L
.2721 .44214 L
.24012 .43464 L
.20367 .42599 L
.16211 .41604 L
.11474 .40463 L
.06074 .39156 L
s
.06074 .39156 m
0 .37682 L
s
0 .476 1 r
.42192 .54706 m
.4126 .53381 L
.40171 .52199 L
.38906 .51126 L
.37446 .50131 L
.35766 .49188 L
.33837 .48273 L
.31627 .47361 L
.29098 .46433 L
.26208 .45468 L
.22906 .44444 L
.19136 .43341 L
.14834 .42137 L
.09926 .4081 L
.04326 .39334 L
s
.04326 .39334 m
0 .38215 L
s
0 .084 1 r
.54459 .54616 m
.5517 .54206 L
.55966 .53914 L
.56862 .53728 L
.57873 .53636 L
.59018 .53634 L
.60317 .53716 L
.61791 .5388 L
.63468 .54127 L
.65375 .54457 L
.67546 .54875 L
.70019 .55385 L
.72835 .55995 L
.76044 .56715 L
.79702 .57556 L
.8387 .58531 L
.88621 .59656 L
.94037 .60951 L
s
.94037 .60951 m
1 .62386 L
s
.506 0 1 r
.5646 .48165 m
.57282 .48933 L
.58232 .49638 L
.59327 .503 L
.60586 .50938 L
.62028 .51565 L
.6368 .52199 L
.65568 .52852 L
.67726 .5354 L
.7019 .54277 L
.73002 .55077 L
.76211 .55956 L
.79872 .5693 L
.84048 .58017 L
.88811 .59238 L
.94242 .60613 L
s
.94242 .60613 m
1 .62059 L
s
0 1 .05 r
.53382 .45264 m
.53719 .46269 L
.54127 .47138 L
.5461 .47898 L
.55177 .48572 L
.55837 .4918 L
.56599 .4974 L
.57478 .50266 L
.58487 .50773 L
.59644 .51273 L
.60969 .51778 L
.62484 .523 L
.64214 .52849 L
.6619 .53438 L
.68446 .54078 L
.71019 .54782 L
.73955 .55562 L
.77304 .56433 L
.81123 .57412 L
.85479 .58514 L
.90445 .5976 L
.96109 .61172 L
s
.96109 .61172 m
1 .62138 L
s
.467 0 1 r
.57086 .43199 m
.5787 .44806 L
.58798 .46213 L
.59886 .47464 L
.61149 .48595 L
.6261 .49638 L
.64292 .50622 L
.66225 .51572 L
.68439 .52513 L
.70973 .53466 L
.73871 .54453 L
.77181 .55495 L
.80961 .56614 L
.85275 .57832 L
.90198 .59172 L
.95814 .6066 L
s
.95814 .6066 m
1 .61747 L
s
1 0 .975 r
.45067 .53814 m
.44499 .52843 L
.43831 .51985 L
.43052 .51215 L
.4215 .5051 L
.4111 .49852 L
.39914 .49223 L
.38542 .48606 L
.36971 .47987 L
.35175 .47352 L
.33122 .46686 L
.30777 .45975 L
.281 .45206 L
.25046 .44363 L
.21561 .4343 L
.17587 .42391 L
.13053 .41225 L
.07884 .39913 L
.01988 .3843 L
s
.01988 .3843 m
0 .37933 L
s
1 .971 0 r
.46423 .48443 m
.45905 .48429 L
.45318 .48379 L
.4465 .48294 L
.43891 .48173 L
.43027 .48016 L
.42043 .47821 L
.40923 .47584 L
.39646 .47303 L
.38192 .46974 L
.36534 .46589 L
.34644 .46145 L
.32491 .45633 L
.30035 .45044 L
.27237 .44369 L
.24046 .43596 L
.20408 .42713 L
.16261 .41703 L
.11533 .4055 L
.06143 .39233 L
s
.06143 .39233 m
0 .37732 L
s
.643 0 1 r
.50403 .56918 m
.50626 .55843 L
.50853 .54956 L
.51089 .54227 L
.51338 .53632 L
.51607 .53151 L
.51899 .52766 L
.52222 .52463 L
.5258 .52233 L
.52981 .52066 L
.53431 .51955 L
.53939 .51895 L
.54514 .51882 L
.55165 .51913 L
.55905 .51987 L
.56746 .52103 L
.57702 .52263 L
.5879 .52467 L
.60029 .52719 L
.61441 .53021 L
.63049 .53379 L
.64882 .53798 L
.66971 .54285 L
.69352 .54847 L
.72066 .55494 L
.7516 .56238 L
.78687 .5709 L
.82707 .58065 L
.87291 .59179 L
.92517 .60452 L
.98475 .61906 L
s
.98475 .61906 m
1 .62279 L
s
0 .517 1 r
.50678 .47683 m
.50713 .48103 L
.50762 .48458 L
.50826 .4876 L
.50907 .49019 L
.51004 .49242 L
.5112 .49437 L
.51257 .49609 L
.51416 .49764 L
.516 .49905 L
.51812 .50038 L
.52056 .50165 L
.52336 .5029 L
.52656 .50415 L
.53022 .50544 L
.53441 .50679 L
.53919 .50823 L
.54465 .5098 L
.55088 .51151 L
.55798 .51341 L
.56609 .51553 L
.57533 .5179 L
.58587 .52058 L
.59789 .5236 L
.6116 .52702 L
.62723 .5309 L
.64505 .53531 L
.66536 .54033 L
.68853 .54603 L
.71494 .55253 L
.74505 .55993 L
.77938 .56836 L
.81852 .57796 L
.86315 .58891 L
.91403 .60138 L
.97204 .6156 L
s
.97204 .6156 m
1 .62246 L
s
1 .168 0 r
.42716 .57933 m
.41933 .56131 L
.41002 .5456 L
.39906 .53171 L
.3863 .51923 L
.37153 .50781 L
.35449 .49713 L
.3349 .4869 L
.31244 .47686 L
.28672 .46678 L
.2573 .45642 L
.22369 .44556 L
.1853 .43395 L
.14147 .42139 L
.09147 .40761 L
.03442 .39235 L
s
.03442 .39235 m
0 .38336 L
s
1 .296 0 r
.58031 .42476 m
.58924 .44267 L
.59981 .45838 L
.61217 .47236 L
.62654 .48501 L
.64314 .4967 L
.66226 .50774 L
.68421 .51842 L
.70936 .52901 L
.73815 .53975 L
.77106 .5509 L
.80866 .56268 L
.85159 .57534 L
.90059 .58913 L
.9565 .60432 L
s
.9565 .60432 m
1 .61583 L
s
1 0 .872 r
.50711 .49188 m
.50786 .4937 L
.50876 .49528 L
.50982 .49668 L
.51106 .49793 L
.51249 .49907 L
.51414 .50014 L
.51604 .50116 L
.51822 .50215 L
.52072 .50314 L
.52358 .50416 L
.52684 .50523 L
.53057 .50637 L
.53482 .5076 L
.53968 .50894 L
.54522 .51043 L
.55154 .51208 L
.55874 .51394 L
.56696 .51603 L
.57634 .51839 L
.58703 .52106 L
.59921 .52409 L
.61311 .52753 L
.62895 .53144 L
.64701 .53589 L
.66761 .54096 L
.69109 .54673 L
.71786 .5533 L
.74838 .56079 L
.78318 .56933 L
.82286 .57906 L
.86809 .59015 L
.91967 .60279 L
.97847 .6172 L
s
.97847 .6172 m
1 .62248 L
s
1 .914 0 r
.55935 .51793 m
.56775 .51943 L
.57731 .5213 L
.5882 .52358 L
.6006 .52629 L
.61474 .52948 L
.63085 .5332 L
.64921 .53751 L
.67014 .54248 L
.694 .54819 L
.72119 .55475 L
.7522 .56225 L
.78755 .57083 L
.82784 .58064 L
.87378 .59185 L
.92616 .60463 L
.98588 .61923 L
s
.98588 .61923 m
1 .62268 L
s
0 .973 1 r
.57256 .48982 m
.58205 .49677 L
.59297 .50331 L
.60552 .50961 L
.61991 .51583 L
.63638 .52211 L
.65521 .52859 L
.67672 .53543 L
.70129 .54275 L
.72933 .55071 L
.76133 .55946 L
.79784 .56916 L
.83947 .57999 L
.88696 .59215 L
.94111 .60586 L
s
.94111 .60586 m
1 .62063 L
s
1 0 .218 r
.42293 .53367 m
.41341 .52263 L
.40236 .51266 L
.38957 .50347 L
.37485 .4948 L
.35793 .48644 L
.33855 .47817 L
.31636 .4698 L
.29099 .46113 L
.26201 .45199 L
.22892 .44218 L
.19115 .4315 L
.14805 .41975 L
.09889 .40672 L
.04281 .39215 L
s
.04281 .39215 m
0 .3812 L
s
1 0 .241 r
.50019 .50216 m
.50026 .50183 L
.50035 .50156 L
.50043 .50134 L
.50052 .50115 L
.50062 .50101 L
.50073 .50089 L
.50084 .5008 L
.50098 .50074 L
.50113 .50069 L
.5013 .50066 L
.50149 .50065 L
.5017 .50066 L
.50194 .50068 L
.50222 .50071 L
.50254 .50076 L
.5029 .50083 L
.5033 .50091 L
.50377 .501 L
.5043 .50112 L
.5049 .50126 L
.50559 .50142 L
.50638 .5016 L
.50727 .50181 L
.50829 .50206 L
.50945 .50234 L
.51078 .50266 L
.51229 .50303 L
.51401 .50345 L
.51598 .50393 L
.51821 .50447 L
.52077 .5051 L
.52368 .50581 L
.52699 .50662 L
.53078 .50754 L
.53509 .5086 L
.54 .5098 L
.54561 .51118 L
.552 .51274 L
.55929 .51453 L
.56759 .51656 L
.57706 .51888 L
.58786 .52153 L
.60017 .52454 L
.61421 .52798 L
.63021 .5319 L
.64845 .53637 L
.66925 .54147 L
.69296 .54728 L
.72 .5539 L
Mistroke
.75082 .56145 L
.78597 .57006 L
.82603 .57988 L
.87172 .59107 L
.9238 .60383 L
.98318 .61838 L
Mfstroke
.98318 .61838 m
1 .6225 L
s
1 0 .853 r
.4767 .4691 m
.47282 .47232 L
.4685 .47475 L
.46366 .47647 L
.45821 .47755 L
.45205 .47807 L
.44509 .47805 L
.43718 .47752 L
.42821 .4765 L
.418 .47498 L
.4064 .47295 L
.39318 .47039 L
.37813 .46728 L
.36098 .46355 L
.34145 .45916 L
.31918 .45404 L
.29381 .44809 L
.26489 .44124 L
.23191 .43335 L
.19433 .4243 L
.15148 .41394 L
.10263 .40208 L
.04695 .38853 L
s
.04695 .38853 m
0 .37709 L
s
1 0 .426 r
.47002 .44771 m
.46472 .45385 L
.45886 .45863 L
.45233 .46222 L
.44501 .46475 L
.43677 .46634 L
.42747 .46707 L
.41694 .467 L
.40499 .46617 L
.39142 .46459 L
.37599 .46227 L
.35844 .45919 L
.33845 .45531 L
.31569 .45058 L
.28977 .44493 L
.26022 .43828 L
.22655 .43053 L
.18818 .42154 L
.14444 .41116 L
.09458 .39923 L
.03774 .38555 L
s
.03774 .38555 m
0 .37642 L
s
1 0 .525 r
.45922 .57573 m
.4556 .56065 L
.45113 .5477 L
.44575 .5365 L
.43937 .52668 L
.43189 .51797 L
.42319 .5101 L
.41314 .50284 L
.40156 .49601 L
.38826 .48942 L
.37302 .4829 L
.35557 .4763 L
.33562 .46948 L
.31282 .46228 L
.2868 .45456 L
.25709 .44615 L
.2232 .43691 L
.18453 .42665 L
.14042 .41519 L
.09012 .40233 L
.03276 .38782 L
s
.03276 .38782 m
0 .3796 L
s
0 1 .244 r
.50647 .42681 m
.50554 .43897 L
.50479 .44913 L
.50419 .4576 L
.50371 .46468 L
.50334 .47059 L
.50307 .47553 L
.50289 .47966 L
.50277 .48312 L
.50273 .48602 L
.50276 .48845 L
.50284 .4905 L
.50299 .49223 L
.5032 .49369 L
.50348 .49493 L
.50382 .496 L
.50424 .49692 L
.50473 .49772 L
.50531 .49843 L
.50598 .49907 L
.50676 .49966 L
.50766 .50021 L
.50869 .50074 L
.50988 .50126 L
.51123 .50178 L
.51278 .50232 L
.51455 .50289 L
.51657 .5035 L
.51888 .50416 L
.52152 .50488 L
.52452 .50568 L
.52795 .50658 L
.53186 .50758 L
.53632 .50871 L
.5414 .50999 L
.5472 .51143 L
.55381 .51307 L
.56134 .51494 L
.56994 .51706 L
.57973 .51947 L
.5909 .52222 L
.60364 .52535 L
.61816 .52891 L
.63471 .53297 L
.65359 .5376 L
.67511 .54288 L
.69964 .54889 L
.72761 .55575 L
.7595 .56356 L
.79586 .57247 L
Mistroke
.83731 .58263 L
.88457 .59421 L
.93845 .60741 L
.99989 .62247 L
Mfstroke
.99989 .62247 m
1 .62249 L
s
.2 1 0 r
.49019 .53126 m
.48965 .52555 L
.48888 .52071 L
.4879 .51659 L
.48668 .51305 L
.48521 .50999 L
.48348 .50731 L
.48144 .50493 L
.47907 .50278 L
.47633 .5008 L
.47318 .49893 L
.46955 .49713 L
.4654 .49535 L
.46065 .49355 L
.45521 .49169 L
.449 .48973 L
.44191 .48762 L
.43382 .48533 L
.42458 .48281 L
.41405 .48002 L
.40203 .4769 L
.38832 .47339 L
.3727 .46944 L
.35487 .46497 L
.33455 .4599 L
.31138 .45415 L
.28496 .44762 L
.25484 .44019 L
.2205 .43173 L
.18135 .42211 L
.1367 .41114 L
.0858 .39865 L
.02777 .38441 L
s
.02777 .38441 m
0 .3776 L
s
0 1 .172 r
.49661 .49589 m
.49606 .4963 L
.49544 .4966 L
.49475 .49681 L
.49396 .49693 L
.49308 .49698 L
.49208 .49695 L
.49094 .49686 L
.48965 .49669 L
.48818 .49646 L
.48651 .49616 L
.4846 .49578 L
.48243 .49532 L
.47996 .49478 L
.47715 .49414 L
.47394 .4934 L
.47028 .49254 L
.46611 .49155 L
.46136 .49041 L
.45595 .4891 L
.44977 .48761 L
.44273 .4859 L
.43471 .48394 L
.42556 .48171 L
.41512 .47916 L
.40323 .47626 L
.38967 .47294 L
.37421 .46916 L
.35659 .46484 L
.33649 .45992 L
.31359 .45431 L
.28747 .44792 L
.25769 .44062 L
.22374 .43231 L
.18503 .42283 L
.1409 .41202 L
.09058 .39969 L
.03322 .38564 L
s
.03322 .38564 m
0 .3775 L
s
1 0 .571 r
.56237 .50984 m
.57097 .51285 L
.58081 .51601 L
.59204 .51939 L
.60486 .52305 L
.61948 .52707 L
.63617 .53153 L
.6552 .53649 L
.67691 .54207 L
.70167 .54834 L
.7299 .55543 L
.76209 .56347 L
.79879 .57258 L
.84064 .58294 L
.88835 .59471 L
.94275 .60811 L
s
.94275 .60811 m
1 .62219 L
s
.47 1 0 r
.48212 .58127 m
.48172 .56698 L
.4809 .55494 L
.47969 .54477 L
.47806 .53613 L
.476 .52875 L
.47349 .52239 L
.47048 .51687 L
.46693 .51201 L
.46279 .50766 L
.45799 .50371 L
.45245 .50003 L
.44607 .49653 L
.43875 .49313 L
.43037 .48972 L
.42078 .48625 L
.40982 .48263 L
.3973 .47878 L
.38301 .47462 L
.3667 .47008 L
.34809 .46507 L
.32686 .45949 L
.30265 .45324 L
.27503 .44621 L
.24354 .43828 L
.20764 .4293 L
.1667 .41911 L
.12002 .40755 L
.0668 .3944 L
.00611 .37945 L
s
.00611 .37945 m
0 .37794 L
s
1 .943 0 r
.44691 .43241 m
.43814 .4393 L
.42835 .44445 L
.41739 .44806 L
.40503 .45028 L
.39108 .45125 L
.37528 .45103 L
.35735 .44969 L
.33699 .44725 L
.31384 .4437 L
.28749 .43901 L
.2575 .43314 L
.22334 .42601 L
.18443 .4175 L
.14009 .4075 L
.08955 .39583 L
.03196 .38232 L
s
.03196 .38232 m
0 .37473 L
s
.892 1 0 r
.51096 .42901 m
.51069 .44115 L
.51068 .45133 L
.51092 .45989 L
.5114 .4671 L
.51213 .47319 L
.5131 .47836 L
.51432 .48278 L
.51582 .48658 L
.51761 .48988 L
.51973 .49279 L
.5222 .49539 L
.52506 .49776 L
.52837 .49996 L
.53217 .50205 L
.53654 .50408 L
.54154 .50612 L
.54726 .50819 L
.5538 .51035 L
.56127 .51265 L
.56979 .51513 L
.57952 .51784 L
.59063 .52083 L
.60329 .52416 L
.61773 .52789 L
.63421 .53208 L
.65299 .53682 L
.67441 .54218 L
.69883 .54825 L
.72668 .55515 L
.75843 .56299 L
.79463 .57192 L
.8359 .58207 L
.88296 .59364 L
.93661 .60681 L
.99778 .62183 L
s
.99778 .62183 m
1 .62237 L
s
0 1 .465 r
.47044 .51876 m
.46694 .5136 L
.46284 .509 L
.45807 .50483 L
.45257 .50098 L
.44623 .49734 L
.43896 .49382 L
.43062 .49032 L
.42108 .48677 L
.41017 .48309 L
.39771 .47919 L
.38348 .475 L
.36724 .47043 L
.34871 .4654 L
.32757 .45982 L
.30347 .45357 L
.27597 .44655 L
.24462 .43863 L
.20887 .42967 L
.1681 .41952 L
.12162 .40799 L
.06862 .39489 L
.00819 .37999 L
s
.00819 .37999 m
0 .37798 L
s
0 1 .593 r
.55317 .52888 m
.56101 .52817 L
.56988 .52815 L
.57994 .52879 L
.59136 .53006 L
.60435 .53197 L
.61913 .53453 L
.63595 .53777 L
.65511 .54172 L
.67693 .54645 L
.7018 .55203 L
.73014 .55854 L
.76244 .5661 L
.79925 .57482 L
.84121 .58485 L
.88905 .59636 L
.94359 .60955 L
s
.94359 .60955 m
1 .62324 L
s
1 0 .984 r
.56585 .5233 m
.57525 .52442 L
.58594 .52604 L
.5981 .5282 L
.61195 .5309 L
.62772 .53419 L
.64569 .53811 L
.66616 .54273 L
.68949 .54811 L
.71608 .55434 L
.74639 .56154 L
.78094 .56981 L
.82032 .57929 L
.86522 .59016 L
.91641 .60259 L
.97477 .61679 L
s
.97477 .61679 m
1 .62294 L
s
.856 1 0 r
.45311 .56244 m
.44835 .54903 L
.44262 .53741 L
.43584 .52722 L
.42791 .51816 L
.41868 .50997 L
.40802 .5024 L
.39575 .49526 L
.38165 .48836 L
.36549 .48153 L
.347 .4746 L
.32586 .46742 L
.3017 .45983 L
.27413 .45168 L
.24265 .44281 L
.20674 .43304 L
.16577 .42219 L
.11904 .41007 L
.06575 .39645 L
.00497 .38109 L
s
.00497 .38109 m
0 .37984 L
s
1 0 .675 r
.44764 .53886 m
.44157 .52881 L
.43444 .51992 L
.42614 .51193 L
.41652 .5046 L
.40544 .49773 L
.3927 .49115 L
.3781 .48468 L
.36137 .47817 L
.34225 .47148 L
.32039 .46445 L
.29544 .45693 L
.26695 .44878 L
.23444 .43985 L
.19735 .42995 L
.15505 .4189 L
.1068 .40652 L
.05178 .39256 L
s
.05178 .39256 m
0 .37955 L
s
1 .484 0 r
.57348 .48574 m
.58299 .49342 L
.59396 .50056 L
.60657 .50737 L
.62104 .51402 L
.63762 .52067 L
.65658 .52748 L
.67826 .53459 L
.70301 .54216 L
.73127 .55034 L
.76352 .55929 L
.80031 .56918 L
.84228 .58019 L
.89014 .59252 L
.94473 .6064 L
s
.94473 .6064 m
1 .62032 L
s
0 .57 1 r
.48884 .56191 m
.48886 .5512 L
.48862 .54221 L
.48813 .53463 L
.48738 .52823 L
.48638 .5228 L
.48511 .51816 L
.48356 .51416 L
.4817 .5107 L
.47951 .50764 L
.47695 .50492 L
.47398 .50244 L
.47055 .50014 L
.46661 .49795 L
.46208 .49583 L
.45689 .49371 L
.45095 .49155 L
.44417 .48929 L
.43642 .4869 L
.42757 .48432 L
.41747 .48151 L
.40595 .4784 L
.39281 .47494 L
.37782 .47107 L
.36073 .46672 L
.34123 .4618 L
.31901 .45624 L
.29366 .44993 L
.26476 .44277 L
.23182 .43463 L
.19425 .42537 L
.15142 .41483 L
.10258 .40283 L
.0469 .38916 L
s
.0469 .38916 m
0 .37764 L
s
0 1 .859 r
.56884 .50205 m
.57813 .50678 L
.58877 .51143 L
.60095 .51613 L
.61489 .52097 L
.63081 .52606 L
.64899 .5315 L
.66974 .53742 L
.69342 .54391 L
.72044 .5511 L
.75125 .55913 L
.7864 .56815 L
.82647 .5783 L
.87217 .58978 L
.92429 .60278 L
.9837 .61753 L
s
.9837 .61753 m
1 .62156 L
s
1 0 .514 r
.46788 .5059 m
.46371 .5026 L
.45891 .49952 L
.45339 .49658 L
.44705 .4937 L
.43979 .49082 L
.4315 .48786 L
.42201 .48477 L
.41118 .48147 L
.39881 .47791 L
.3847 .474 L
.3686 .46969 L
.35024 .46488 L
.32929 .45948 L
.30541 .45342 L
.27817 .44656 L
.24711 .4388 L
.2117 .43 L
.17132 .42 L
.12528 .40864 L
.07279 .3957 L
.01294 .38098 L
s
.01294 .38098 m
0 .3778 L
s
1 .632 0 r
.4455 .43108 m
.4365 .43808 L
.42647 .4433 L
.41522 .44696 L
.40255 .4492 L
.38824 .45015 L
.37203 .4499 L
.35364 .4485 L
.33275 .44598 L
.309 .44232 L
.28197 .4375 L
.2512 .43147 L
.21616 .42414 L
.17623 .4154 L
.13074 .40513 L
.0789 .39316 L
.0198 .37929 L
s
.0198 .37929 m
0 .37459 L
s
.233 0 1 r
.4402 .50303 m
.43225 .49815 L
.42312 .49347 L
.41265 .48887 L
.40066 .48423 L
.38696 .47945 L
.37129 .47443 L
.35341 .46906 L
.33299 .46323 L
.30969 .45684 L
.28311 .44975 L
.25279 .44184 L
.21821 .43297 L
.17878 .42298 L
.13382 .41169 L
.08255 .39889 L
.02408 .38438 L
s
.02408 .38438 m
0 .37842 L
s
0 1 .547 r
.45888 .51653 m
.45377 .51087 L
.44784 .50574 L
.44098 .50099 L
.43309 .4965 L
.42403 .49214 L
.41365 .48782 L
.40177 .48342 L
.38819 .47885 L
.37268 .47402 L
.35497 .46882 L
.33475 .46314 L
.31169 .45689 L
.28538 .44994 L
.25537 .44217 L
.22115 .43344 L
.18212 .42359 L
.13762 .41244 L
.08687 .39981 L
.02901 .38546 L
s
.02901 .38546 m
0 .37829 L
s
1 0 .307 r
.51207 .4212 m
.51176 .43467 L
.51174 .44596 L
.51199 .45545 L
.51251 .46345 L
.51329 .4702 L
.51434 .47594 L
.51568 .48083 L
.51731 .48504 L
.51927 .4887 L
.52158 .49192 L
.52427 .4948 L
.5274 .49741 L
.53101 .49984 L
.53517 .50214 L
.53994 .50438 L
.5454 .50661 L
.55165 .50889 L
.55879 .51127 L
.56695 .51379 L
.57627 .5165 L
.5869 .51947 L
.59903 .52274 L
.61287 .52639 L
.62866 .53046 L
.64666 .53505 L
.66718 .54022 L
.69059 .54608 L
.71728 .55272 L
.74771 .56026 L
.7824 .56883 L
.82196 .57858 L
.86707 .58968 L
.91849 .60232 L
.97712 .61672 L
s
.97712 .61672 m
1 .62234 L
s
0 1 .484 r
.48328 .45023 m
.47981 .45695 L
.47605 .46234 L
.47192 .4666 L
.46733 .46987 L
.46222 .47228 L
.45647 .47393 L
.44999 .4749 L
.44267 .47523 L
.43438 .47498 L
.42497 .47415 L
.41427 .47277 L
.40211 .47082 L
.38826 .46829 L
.3725 .46515 L
.35455 .46135 L
.3341 .45684 L
.31079 .45154 L
.28423 .44538 L
.25395 .43826 L
.21944 .43004 L
.1801 .42061 L
.13526 .40979 L
.08413 .3974 L
.02585 .38324 L
s
.02585 .38324 m
0 .37695 L
s
0 1 .654 r
.46513 .43223 m
.45879 .44049 L
.45181 .44697 L
.44405 .45189 L
.43537 .45547 L
.42561 .45783 L
.4146 .4591 L
.40214 .45936 L
.38802 .45866 L
.37199 .45704 L
.35378 .45449 L
.33305 .45102 L
.30946 .44658 L
.2826 .44112 L
.252 .43455 L
.21714 .42679 L
.17741 .4177 L
.13214 .40715 L
.08053 .39496 L
.0217 .38092 L
s
.0217 .38092 m
0 .37571 L
s
0 1 .598 r
.53704 .50663 m
.54217 .5083 L
.54803 .51007 L
.55471 .51199 L
.56235 .51409 L
.57105 .51642 L
.58098 .51902 L
.59231 .52193 L
.60523 .52521 L
.61995 .52891 L
.63675 .5331 L
.6559 .53786 L
.67773 .54327 L
.70263 .54941 L
.73102 .55641 L
.76338 .56437 L
.80028 .57343 L
.84234 .58376 L
.89031 .59553 L
.94499 .60894 L
s
.94499 .60894 m
1 .62243 L
s
1 0 .046 r
.45786 .43971 m
.45074 .44624 L
.44282 .45121 L
.43395 .4548 L
.42399 .45717 L
.41274 .45842 L
.40002 .45865 L
.3856 .45791 L
.36923 .45623 L
.35062 .45361 L
.32945 .45005 L
.30536 .4455 L
.27792 .43991 L
.24667 .43319 L
.21105 .42525 L
.17047 .41596 L
.12422 .40518 L
.0715 .39272 L
.01141 .37838 L
s
.01141 .37838 m
0 .37564 L
s
1 0 .714 r
.57869 .43297 m
.58761 .44945 L
.59812 .46396 L
.61039 .47692 L
.62464 .48871 L
.64107 .49967 L
.65999 .51008 L
.68169 .52022 L
.70655 .53034 L
.73499 .54066 L
.7675 .55143 L
.80464 .56287 L
.84703 .5752 L
.89542 .58868 L
.95062 .60356 L
s
.95062 .60356 m
1 .61655 L
s
1 0 .857 r
.56237 .52732 m
.5714 .52754 L
.58165 .52839 L
.5933 .52985 L
.60654 .53194 L
.62161 .53466 L
.63877 .53806 L
.65831 .54217 L
.68057 .54707 L
.70594 .55281 L
.73485 .55951 L
.76781 .56725 L
.80537 .57619 L
.84819 .58645 L
.897 .59822 L
.95265 .61169 L
s
.95265 .61169 m
1 .6232 L
s
.936 0 1 r
.45999 .51237 m
.45493 .50745 L
.44906 .50295 L
.4423 .49874 L
.43454 .4947 L
.42563 .49074 L
.41543 .48676 L
.40376 .48266 L
.39043 .47836 L
.3752 .47377 L
.35782 .46879 L
.33799 .46333 L
.31537 .45729 L
.28956 .45055 L
.26013 .44299 L
.22656 .43447 L
.18828 .42485 L
.14464 .41396 L
.09487 .4016 L
.03813 .38755 L
s
.03813 .38755 m
0 .37814 L
s
0 .964 1 r
.55566 .58046 m
.56509 .5717 L
.57558 .56503 L
.5873 .5602 L
.60049 .557 L
.61536 .55528 L
.63218 .55492 L
.65125 .55586 L
.67291 .55805 L
.69752 .56148 L
.72551 .56617 L
.75737 .57217 L
.79366 .57955 L
.83499 .58842 L
.88208 .5989 L
.93574 .61117 L
.9969 .62542 L
s
.9969 .62542 m
1 .62616 L
s
.937 1 0 r
.43005 .50212 m
.42072 .49664 L
.41 .49135 L
.39772 .48612 L
.38367 .48083 L
.3676 .47535 L
.34923 .46956 L
.32827 .46335 L
.30434 .45659 L
.27704 .44915 L
.24589 .44089 L
.21037 .43167 L
.16985 .4213 L
.12365 .40962 L
.07096 .39641 L
.01088 .38144 L
s
.01088 .38144 m
0 .37874 L
s
.073 0 1 r
.48854 .50151 m
.48704 .50043 L
.48531 .49941 L
.48333 .49842 L
.48105 .49745 L
.47845 .49647 L
.47547 .49545 L
.47207 .49437 L
.46819 .49322 L
.46376 .49197 L
.4587 .49059 L
.45293 .48906 L
.44635 .48735 L
.43885 .48543 L
.43029 .48326 L
.42053 .48081 L
.4094 .47804 L
.39671 .47489 L
.38224 .47132 L
.36575 .46725 L
.34694 .46262 L
.3255 .45734 L
.30105 .45134 L
.27318 .4445 L
.2414 .4367 L
.20517 .42781 L
.16387 .41769 L
.11677 .40614 L
.06308 .39298 L
.00186 .37798 L
s
.00186 .37798 m
0 .37752 L
s
1 .035 0 r
.44106 .51704 m
.43357 .50999 L
.42491 .50351 L
.41493 .49744 L
.40345 .4916 L
.3903 .48585 L
.37524 .48005 L
.35802 .47407 L
.33835 .46779 L
.31588 .46106 L
.29023 .45375 L
.26097 .44573 L
.22758 .43684 L
.1895 .42692 L
.14607 .41578 L
.09654 .40323 L
.04006 .38905 L
s
.04006 .38905 m
0 .37906 L
s
0 1 .86 r
.53639 .4277 m
.5395 .44191 L
.54337 .45409 L
.54807 .46461 L
.55365 .47379 L
.5602 .48191 L
.56783 .48922 L
.57666 .49593 L
.58685 .50221 L
.59855 .50823 L
.61197 .51416 L
.62733 .52012 L
.6449 .52626 L
.66497 .53271 L
.6879 .5396 L
.71407 .54708 L
.74393 .55528 L
.778 .56437 L
.81686 .57451 L
.86117 .58589 L
.91171 .5987 L
.96935 .61318 L
s
.96935 .61318 m
1 .62083 L
s
0 .109 1 r
.47043 .47307 m
.46581 .4752 L
.46061 .47665 L
.45476 .47748 L
.44814 .47775 L
.44064 .4775 L
.43213 .47673 L
.42245 .47546 L
.41145 .47368 L
.39894 .47138 L
.38468 .46853 L
.36844 .46508 L
.34995 .461 L
.32887 .4562 L
.30484 .45063 L
.27746 .44418 L
.24625 .43675 L
.21067 .42821 L
.17011 .41842 L
.12387 .40722 L
.07116 .39441 L
.01106 .37977 L
s
.01106 .37977 m
0 .37707 L
s
.414 0 1 r
.57607 .42415 m
.58442 .44185 L
.59431 .45733 L
.60592 .47107 L
.61941 .48347 L
.63502 .49488 L
.65301 .50561 L
.67366 .51595 L
.69734 .52616 L
.72445 .53648 L
.75545 .54714 L
.79086 .55837 L
.8313 .57042 L
.87745 .5835 L
.93011 .59789 L
.99019 .61385 L
s
.99019 .61385 m
1 .6164 L
s
.285 1 0 r
.45832 .50967 m
.45297 .50507 L
.44679 .5008 L
.43967 .49677 L
.4315 .49285 L
.42214 .48896 L
.41142 .48501 L
.39918 .48089 L
.38519 .47654 L
.36922 .47185 L
.35099 .46674 L
.33019 .46111 L
.30646 .45485 L
.2794 .44784 L
.24854 .43997 L
.21335 .43108 L
.17322 .42103 L
.12746 .40964 L
.07528 .39671 L
.01579 .38201 L
s
.01579 .38201 m
0 .37811 L
s
1 .161 0 r
.52117 .50428 m
.52411 .50515 L
.52747 .5061 L
.53131 .50714 L
.53568 .5083 L
.54067 .5096 L
.54636 .51105 L
.55285 .51269 L
.56024 .51455 L
.56868 .51665 L
.5783 .51903 L
.58926 .52175 L
.60177 .52483 L
.61602 .52834 L
.63228 .53234 L
.65081 .53689 L
.67194 .54207 L
.69603 .54798 L
.72349 .55472 L
.7548 .5624 L
.7905 .57115 L
.8312 .58112 L
.87761 .5925 L
.93051 .60546 L
.99083 .62024 L
s
.99083 .62024 m
1 .62249 L
s
1 .148 0 r
.46463 .49606 m
.45979 .49409 L
.45425 .49208 L
.44792 .48999 L
.44069 .48776 L
.43244 .48536 L
.42302 .48273 L
.41227 .47984 L
.40001 .47661 L
.38603 .473 L
.37009 .46894 L
.3519 .46436 L
.33117 .45917 L
.30753 .45329 L
.28057 .44661 L
.24983 .43902 L
.21479 .43038 L
.17484 .42055 L
.12928 .40936 L
.07735 .3966 L
.01813 .38207 L
s
.01813 .38207 m
0 .37762 L
s
1 .803 0 r
.57662 .4698 m
.58616 .48025 L
.59723 .48973 L
.61002 .49851 L
.62474 .50683 L
.64163 .5149 L
.66099 .52293 L
.68315 .53109 L
.70847 .53958 L
.7374 .54857 L
.77042 .55825 L
.80812 .56881 L
.85112 .58045 L
.90018 .5934 L
.95614 .60787 L
s
.95614 .60787 m
1 .61906 L
s
1 0 .312 r
.55339 .57308 m
.56234 .56534 L
.5723 .55948 L
.58346 .5553 L
.596 .5526 L
.61017 .55125 L
.62619 .55116 L
.64437 .55226 L
.66501 .55452 L
.68848 .55793 L
.71517 .56252 L
.74556 .56834 L
.78017 .57547 L
.81959 .58399 L
.8645 .59406 L
.91569 .60581 L
.97403 .61944 L
s
.97403 .61944 m
1 .62559 L
s
1 .207 0 r
.51622 .50438 m
.5185 .50487 L
.5211 .50545 L
.52406 .50613 L
.52744 .50692 L
.53129 .50783 L
.53568 .50888 L
.54068 .51008 L
.54638 .51146 L
.55288 .51304 L
.56029 .51484 L
.56874 .5169 L
.57837 .51925 L
.58936 .52193 L
.60188 .52499 L
.61615 .52848 L
.63243 .53247 L
.65098 .53701 L
.67214 .54219 L
.69626 .5481 L
.72375 .55483 L
.7551 .56251 L
.79085 .57126 L
.8316 .58125 L
.87806 .59263 L
.93103 .60561 L
.99142 .6204 L
s
.99142 .6204 m
1 .6225 L
s
.148 1 0 r
.42768 .43159 m
.41631 .4372 L
.40354 .44108 L
.38917 .4434 L
.37292 .4443 L
.35451 .44386 L
.33362 .44214 L
.30989 .43916 L
.28291 .43491 L
.2522 .42936 L
.21724 .42244 L
.17742 .41405 L
.13205 .40408 L
.08035 .39238 L
.02144 .37874 L
s
.02144 .37874 m
0 .3737 L
s
.421 0 1 r
.46452 .50952 m
.45999 .5054 L
.45476 .5016 L
.44873 .49802 L
.4418 .49457 L
.43387 .49116 L
.42478 .48772 L
.41439 .48415 L
.40252 .48039 L
.38897 .47637 L
.3735 .47198 L
.35585 .46717 L
.33571 .46182 L
.31274 .45585 L
.28655 .44915 L
.25668 .44159 L
.22262 .43305 L
.18378 .42336 L
.13949 .41237 L
.089 .39989 L
.03142 .38569 L
s
.03142 .38569 m
0 .37795 L
s
1 .052 0 r
.44604 .53937 m
.43976 .52912 L
.4324 .52004 L
.42382 .51188 L
.41389 .50439 L
.40245 .49736 L
.38931 .49062 L
.37423 .48399 L
.35697 .47731 L
.33723 .47042 L
.31468 .46319 L
.28893 .45546 L
.25953 .44707 L
.22598 .43786 L
.18771 .42766 L
.14406 .41627 L
.09428 .4035 L
.0375 .38911 L
s
.0375 .38911 m
0 .37969 L
s
1 .261 0 r
.45635 .57978 m
.45245 .56384 L
.44763 .55015 L
.44184 .5383 L
.43497 .52791 L
.42694 .51868 L
.4176 .51033 L
.4068 .50263 L
.39436 .49536 L
.38008 .48834 L
.36371 .4814 L
.34498 .47436 L
.32356 .46707 L
.29909 .45937 L
.27115 .4511 L
.23927 .4421 L
.20288 .43219 L
.16137 .4212 L
.11403 .40891 L
.06004 .39511 L
s
.06004 .39511 m
0 .37993 L
s
0 1 .802 r
.57123 .45327 m
.57963 .46596 L
.58948 .47724 L
.60092 .48745 L
.61415 .49687 L
.62938 .50575 L
.64688 .51434 L
.66692 .52283 L
.68987 .53145 L
.7161 .54037 L
.74607 .5498 L
.7803 .55992 L
.81935 .57094 L
.86392 .58307 L
.91476 .59653 L
.97275 .61158 L
s
.97275 .61158 m
1 .61855 L
s
0 1 .49 r
.52843 .4968 m
.53217 .4994 L
.53647 .50186 L
.5414 .50424 L
.54706 .5066 L
.55353 .509 L
.56093 .5115 L
.56938 .51414 L
.57903 .51698 L
.59005 .52007 L
.60262 .52348 L
.61696 .52727 L
.63331 .5315 L
.65196 .53626 L
.67322 .54163 L
.69748 .54771 L
.72513 .5546 L
.75666 .56241 L
.79261 .5713 L
.83359 .5814 L
.88032 .59291 L
.9336 .60601 L
.99435 .62093 L
s
.99435 .62093 m
1 .62231 L
s
0 1 .337 r
.42297 .56972 m
.41435 .55293 L
.40416 .53819 L
.39224 .52505 L
.3784 .51314 L
.36242 .50211 L
.34402 .49167 L
.32289 .48154 L
.29869 .47148 L
.27099 .46125 L
.23933 .45062 L
.20316 .43936 L
.16187 .42724 L
.11474 .41402 L
.06097 .39945 L
s
.06097 .39945 m
0 .38336 L
s
0 .918 1 r
.47212 .54886 m
.46958 .53901 L
.46645 .53054 L
.4627 .5232 L
.45827 .51676 L
.45308 .51102 L
.44706 .50581 L
.4401 .501 L
.43209 .49644 L
.4229 .49202 L
.41236 .48763 L
.4003 .48317 L
.38652 .47853 L
.37078 .47363 L
.3528 .46835 L
.33229 .46259 L
.30888 .45625 L
.28217 .44919 L
.25172 .44131 L
.21698 .43244 L
.17737 .42244 L
.1322 .41113 L
.0807 .39831 L
.02198 .38375 L
s
.02198 .38375 m
0 .37832 L
s
.223 1 0 r
.50543 .49369 m
.506 .4951 L
.50669 .49632 L
.5075 .4974 L
.50844 .49836 L
.50953 .49925 L
.51079 .50007 L
.51224 .50085 L
.5139 .50161 L
.51581 .50238 L
.51798 .50316 L
.52047 .50397 L
.52332 .50484 L
.52656 .50578 L
.53026 .50681 L
.53449 .50795 L
.53931 .50921 L
.54481 .51063 L
.55108 .51222 L
.55823 .51402 L
.56638 .51606 L
.57567 .51837 L
.58627 .52099 L
.59836 .52398 L
.61213 .52737 L
.62784 .53124 L
.64575 .53564 L
.66617 .54065 L
.68945 .54637 L
.716 .55288 L
.74626 .5603 L
.78076 .56876 L
.8201 .5784 L
.86495 .58939 L
.91608 .60192 L
.97438 .61621 L
s
.97438 .61621 m
1 .62249 L
s
.929 0 1 r
.52293 .45125 m
.52481 .46072 L
.52717 .46881 L
.53005 .47579 L
.53349 .48186 L
.53754 .48722 L
.54226 .49201 L
.54773 .49639 L
.55405 .50047 L
.56131 .50437 L
.56964 .50817 L
.57917 .51198 L
.59009 .51588 L
.60256 .51996 L
.6168 .52431 L
.63306 .52901 L
.65161 .53415 L
.67278 .53983 L
.69693 .54616 L
.72447 .55325 L
.75588 .56124 L
.7917 .57025 L
.83254 .58046 L
.8791 .59204 L
.9322 .60518 L
.99274 .62013 L
s
.99274 .62013 m
1 .62192 L
s
.9 1 0 r
.45762 .44184 m
.45051 .44801 L
.4426 .45268 L
.43375 .45602 L
.42378 .45818 L
.41254 .45926 L
.39981 .45934 L
.38538 .45847 L
.36899 .45668 L
.35036 .45398 L
.32917 .45034 L
.30504 .44572 L
.27757 .44007 L
.24627 .4333 L
.21061 .42531 L
.16997 .41598 L
.12365 .40516 L
.07085 .39266 L
.01067 .37828 L
s
.01067 .37828 m
0 .37571 L
s
1 0 .175 r
.53163 .42181 m
.53396 .43661 L
.53696 .44923 L
.54068 .46005 L
.54516 .46942 L
.55046 .47762 L
.55668 .4849 L
.56391 .49147 L
.57228 .49753 L
.58191 .50323 L
.59297 .50873 L
.60566 .51417 L
.62017 .51966 L
.63677 .52535 L
.65573 .53135 L
.67739 .53778 L
.7021 .54478 L
.7303 .55247 L
.76247 .56101 L
.79917 .57054 L
.84102 .58125 L
.88874 .59333 L
.94316 .60698 L
s
.94316 .60698 m
1 .62114 L
s
0 1 .827 r
.43502 .52444 m
.42691 .51577 L
.41749 .50788 L
.40662 .50056 L
.39411 .49362 L
.37975 .48686 L
.3633 .48012 L
.34448 .47326 L
.32297 .46611 L
.2984 .45851 L
.27034 .45033 L
.23833 .44139 L
.2018 .43153 L
.16013 .42056 L
.1126 .40829 L
.0584 .39448 L
s
.0584 .39448 m
0 .37975 L
s
1 .342 0 r
.57517 .48693 m
.58493 .49454 L
.59618 .50165 L
.60912 .50845 L
.62396 .51511 L
.64096 .5218 L
.6604 .52868 L
.68261 .53588 L
.70798 .54356 L
.73693 .55188 L
.76998 .561 L
.80768 .57109 L
.85069 .58233 L
.89973 .59494 L
.95567 .60914 L
s
.95567 .60914 m
1 .62029 L
s
.32 1 0 r
.54186 .49724 m
.5474 .50075 L
.55378 .50411 L
.56109 .50741 L
.56947 .51071 L
.57904 .5141 L
.58999 .51766 L
.60249 .52145 L
.61676 .52555 L
.63305 .53005 L
.65163 .53502 L
.67282 .54056 L
.69699 .54678 L
.72455 .55378 L
.75598 .56168 L
.79182 .57064 L
.83269 .58079 L
.87929 .59233 L
.93241 .60544 L
.99299 .62036 L
s
.99299 .62036 m
1 .62209 L
s
0 .699 1 r
.48875 .50035 m
.48725 .49947 L
.48553 .49862 L
.48355 .49777 L
.48129 .49692 L
.47871 .49604 L
.47576 .49511 L
.47238 .49411 L
.46854 .49302 L
.46415 .49182 L
.45914 .4905 L
.45343 .48901 L
.44691 .48735 L
.43948 .48547 L
.43101 .48334 L
.42135 .48094 L
.41033 .4782 L
.39777 .4751 L
.38345 .47157 L
.36713 .46755 L
.34851 .46297 L
.32729 .45776 L
.3031 .45182 L
.27551 .44505 L
.24406 .43733 L
.2082 .42854 L
.16731 .41852 L
.1207 .4071 L
.06756 .39407 L
.00697 .37922 L
s
.00697 .37922 m
0 .37752 L
s
0 1 .257 r
.43508 .53312 m
.42719 .52307 L
.41799 .51403 L
.40733 .50577 L
.39504 .49804 L
.38092 .49065 L
.36472 .48339 L
.34617 .47611 L
.32495 .46863 L
.30071 .46078 L
.27302 .4524 L
.24142 .44333 L
.20535 .43339 L
.1642 .42238 L
.11727 .41011 L
.06374 .39636 L
.0027 .38086 L
s
.0027 .38086 m
0 .38019 L
s
0 1 .388 r
.52702 .46872 m
.52988 .4757 L
.53329 .48178 L
.53731 .48713 L
.542 .49193 L
.54744 .4963 L
.55371 .50037 L
.56092 .50426 L
.56919 .50805 L
.57867 .51185 L
.58951 .51574 L
.6019 .5198 L
.61605 .52412 L
.6322 .52879 L
.65064 .5339 L
.67167 .53955 L
.69566 .54585 L
.72303 .5529 L
.75423 .56083 L
.78982 .56979 L
.83039 .57993 L
.87666 .59144 L
.92941 .6045 L
.98956 .61935 L
s
.98956 .61935 m
1 .62193 L
s
0 .027 1 r
.49912 .5073 m
.49919 .50607 L
.49923 .50504 L
.49924 .50418 L
.49925 .50346 L
.49923 .50285 L
.4992 .50234 L
.49915 .50191 L
.49908 .50154 L
.49899 .50122 L
.49889 .50096 L
.49876 .50072 L
.49861 .50051 L
.49844 .50033 L
.49824 .50016 L
.498 .50001 L
.49774 .49986 L
.49743 .49972 L
.49708 .49957 L
.49667 .49943 L
.49621 .49927 L
.49569 .49911 L
.49509 .49894 L
.4944 .49875 L
.49362 .49853 L
.49273 .4983 L
.49171 .49804 L
.49056 .49774 L
.48923 .49741 L
.48773 .49703 L
.48601 .4966 L
.48405 .49612 L
.48181 .49557 L
.47927 .49494 L
.47636 .49422 L
.47305 .49341 L
.46927 .49248 L
.46497 .49143 L
.46006 .49022 L
.45446 .48885 L
.44808 .48729 L
.44081 .4855 L
.43252 .48347 L
.42306 .48115 L
.41228 .47851 L
.39999 .4755 L
.38598 .47207 L
.37 .46815 L
.35179 .46369 L
.33103 .4586 L
Mistroke
.30735 .4528 L
.28036 .44619 L
.24958 .43865 L
.2145 .43005 L
.1745 .42025 L
.12889 .40908 L
.07689 .39634 L
.01761 .38182 L
Mfstroke
.01761 .38182 m
0 .3775 L
s
1 .046 0 r
.46747 .48572 m
.46276 .48561 L
.45741 .48518 L
.45134 .48442 L
.44443 .48333 L
.43657 .48191 L
.42762 .48014 L
.41743 .478 L
.40582 .47545 L
.39259 .47245 L
.37751 .46896 L
.36032 .46492 L
.34073 .46026 L
.3184 .45491 L
.29294 .44877 L
.26391 .44174 L
.23082 .4337 L
.1931 .42452 L
.15009 .41403 L
.10106 .40206 L
.04516 .3884 L
s
.04516 .3884 m
0 .37735 L
s
.295 1 0 r
.53552 .53148 m
.54106 .52906 L
.54728 .52744 L
.55429 .52653 L
.56222 .52628 L
.5712 .52665 L
.58141 .52763 L
.593 .5292 L
.60619 .53136 L
.6212 .53416 L
.63829 .5376 L
.65775 .54176 L
.67993 .54667 L
.70521 .55244 L
.73401 .55914 L
.76684 .56688 L
.80427 .5758 L
.84693 .58604 L
.89556 .59779 L
.95101 .61122 L
s
.95101 .61122 m
1 .62313 L
s
0 .382 1 r
.42537 .55389 m
.41668 .53981 L
.40648 .52733 L
.39461 .5161 L
.38087 .50579 L
.36504 .49611 L
.34684 .48682 L
.32598 .47768 L
.30209 .46846 L
.27478 .45896 L
.24357 .44897 L
.20793 .43829 L
.16725 .42669 L
.12083 .41396 L
.06787 .39985 L
.00747 .3841 L
s
.00747 .3841 m
0 .38218 L
s
1 .364 0 r
.56073 .49927 m
.56886 .50385 L
.57819 .50829 L
.58888 .51271 L
.60111 .51721 L
.61509 .52189 L
.63107 .52685 L
.6493 .53219 L
.67011 .53801 L
.69386 .54444 L
.72094 .55158 L
.75184 .55957 L
.78707 .56856 L
.82725 .57869 L
.87306 .59016 L
.9253 .60317 L
.98486 .61793 L
s
.98486 .61793 m
1 .62167 L
s
1 .054 0 r
.4602 .48179 m
.45442 .48177 L
.44786 .48134 L
.44041 .48049 L
.43194 .47923 L
.4223 .47754 L
.41133 .47542 L
.39883 .47283 L
.3846 .46974 L
.36838 .4661 L
.3499 .46184 L
.32884 .45691 L
.30483 .45122 L
.27746 .44468 L
.24626 .43716 L
.21069 .42856 L
.17015 .41872 L
.12392 .40747 L
.07122 .39462 L
.01113 .37996 L
s
.01113 .37996 m
0 .37724 L
s
1 .95 0 r
.5235 .55613 m
.52803 .54889 L
.53298 .54314 L
.53846 .53868 L
.54457 .53533 L
.55141 .53296 L
.55911 .53147 L
.56781 .53079 L
.57766 .53085 L
.58883 .53163 L
.60152 .5331 L
.61594 .53527 L
.63235 .53816 L
.65104 .54179 L
.67232 .54621 L
.69656 .55148 L
.72418 .5577 L
.75566 .56495 L
.79153 .57336 L
.83243 .58306 L
.87904 .59421 L
.93218 .60701 L
.99276 .62166 L
s
.99276 .62166 m
1 .62342 L
s
.069 0 1 r
.49692 .43009 m
.49479 .44102 L
.49265 .45006 L
.49044 .45749 L
.48812 .46358 L
.48564 .46852 L
.48294 .47249 L
.47998 .47563 L
.4767 .47805 L
.47303 .47985 L
.46892 .48108 L
.46429 .48182 L
.45906 .4821 L
.45313 .48195 L
.4464 .48139 L
.43876 .48043 L
.43007 .47905 L
.42018 .47726 L
.40892 .47503 L
.39609 .47233 L
.38148 .46911 L
.36482 .46534 L
.34585 .46095 L
.32422 .45586 L
.29956 .45 L
.27146 .44326 L
.23942 .43553 L
.20289 .42669 L
.16125 .41657 L
.11378 .40501 L
.05965 .39181 L
s
.05965 .39181 m
0 .37725 L
s
0 1 .286 r
.47656 .45255 m
.47225 .45841 L
.46751 .46301 L
.46225 .46653 L
.45637 .4691 L
.44976 .47083 L
.44231 .4718 L
.43388 .47206 L
.42433 .47167 L
.41349 .47063 L
.40117 .46897 L
.38715 .46666 L
.3712 .4637 L
.35304 .46004 L
.33235 .45562 L
.30878 .4504 L
.28192 .44427 L
.25131 .43715 L
.21642 .42892 L
.17664 .41944 L
.13131 .40856 L
.07962 .39608 L
.0207 .3818 L
s
.0207 .3818 m
0 .37677 L
s
0 1 .821 r
.45494 .55171 m
.45016 .54014 L
.44446 .53007 L
.43775 .52119 L
.42992 .51323 L
.42084 .50597 L
.41037 .49921 L
.39833 .49275 L
.38452 .48644 L
.3687 .48012 L
.3506 .47365 L
.32992 .46689 L
.3063 .45968 L
.27934 .45189 L
.24857 .44337 L
.21346 .43394 L
.17342 .42345 L
.12774 .41168 L
.07566 .39844 L
.01626 .38349 L
s
.01626 .38349 m
0 .37943 L
s
.975 0 1 r
.48071 .55751 m
.47953 .54691 L
.47793 .53792 L
.4759 .53024 L
.47341 .52364 L
.47043 .51792 L
.4669 .51288 L
.46277 .50839 L
.45799 .50432 L
.45246 .50054 L
.4461 .49697 L
.43879 .49349 L
.43042 .49004 L
.42085 .48652 L
.4099 .48286 L
.3974 .47898 L
.38313 .4748 L
.36683 .47024 L
.34825 .46521 L
.32704 .45962 L
.30286 .45336 L
.27528 .44633 L
.24383 .4384 L
.20796 .42942 L
.16707 .41924 L
.12044 .40768 L
.06728 .39454 L
.00666 .3796 L
s
.00666 .3796 m
0 .37796 L
s
0 1 .44 r
.52378 .43367 m
.52535 .44601 L
.52743 .45649 L
.53004 .46545 L
.53322 .47317 L
.53702 .4799 L
.5415 .48583 L
.54672 .49114 L
.55276 .49598 L
.55974 .5005 L
.56777 .50481 L
.57697 .50902 L
.58751 .51323 L
.59958 .51755 L
.61336 .52206 L
.6291 .52686 L
.64707 .53205 L
.66758 .53774 L
.69098 .54402 L
.71767 .55102 L
.74811 .55886 L
.78283 .56768 L
.82242 .57765 L
.86756 .58893 L
.91903 .60173 L
.97772 .61626 L
s
.97772 .61626 m
1 .62176 L
s
.762 0 1 r
.45306 .44085 m
.44532 .44685 L
.43669 .45132 L
.427 .45444 L
.4161 .45635 L
.40378 .45716 L
.38983 .45693 L
.374 .45572 L
.35601 .45353 L
.33557 .45038 L
.3123 .44622 L
.28581 .44103 L
.25564 .43471 L
.22127 .42719 L
.1821 .41834 L
.13747 .40803 L
.0866 .39609 L
.02862 .38232 L
s
.02862 .38232 m
0 .37547 L
s
0 1 .743 r
.54123 .48483 m
.54639 .49028 L
.55238 .49524 L
.55928 .49985 L
.56723 .50423 L
.57635 .50849 L
.5868 .51274 L
.59875 .51708 L
.61241 .52161 L
.62802 .52641 L
.64583 .5316 L
.66616 .53726 L
.68936 .54352 L
.71582 .55048 L
.746 .55827 L
.78042 .56703 L
.81967 .57692 L
.86442 .58812 L
.91545 .60081 L
.97364 .61523 L
s
.97364 .61523 m
1 .62174 L
s
.95 1 0 r
.44188 .55113 m
.43534 .53869 L
.42761 .52777 L
.41858 .51802 L
.4081 .50916 L
.396 .50095 L
.38208 .49316 L
.3661 .48559 L
.34779 .47806 L
.32684 .47038 L
.30289 .46239 L
.27553 .45392 L
.2443 .44479 L
.20866 .43483 L
.16799 .42383 L
.1216 .41161 L
.06868 .39793 L
.00834 .38255 L
s
.00834 .38255 m
0 .38045 L
s
.588 1 0 r
.45149 .51123 m
.44526 .50587 L
.43807 .50092 L
.42978 .49622 L
.42027 .49167 L
.40938 .48714 L
.39691 .48254 L
.38265 .47776 L
.36637 .47269 L
.34778 .46724 L
.32657 .46129 L
.30236 .45473 L
.27474 .44744 L
.24325 .43929 L
.20733 .43013 L
.16637 .41979 L
.11966 .40809 L
.0664 .39483 L
.00567 .37978 L
s
.00567 .37978 m
0 .37838 L
s
1 .58 0 r
.5461 .47352 m
.55163 .48113 L
.5581 .48794 L
.56559 .49413 L
.57425 .49989 L
.5842 .50536 L
.59563 .51069 L
.60871 .516 L
.62368 .52143 L
.64079 .52709 L
.66034 .53311 L
.68265 .5396 L
.70812 .54669 L
.73717 .55452 L
.77032 .56324 L
.80812 .57299 L
.85123 .58397 L
.90039 .59636 L
.95644 .61038 L
s
.95644 .61038 m
1 .62121 L
s
0 .524 1 r
.45339 .53163 m
.44791 .52316 L
.44149 .51563 L
.43403 .50884 L
.42539 .50258 L
.41545 .49669 L
.40403 .49101 L
.39094 .4854 L
.37596 .47972 L
.35883 .47385 L
.33925 .46765 L
.3169 .46101 L
.29139 .45379 L
.26229 .44585 L
.22908 .43703 L
.1912 .42719 L
.14801 .41614 L
.09875 .40367 L
.04258 .38958 L
s
.04258 .38958 m
0 .37897 L
s
1 0 .57 r
.53639 .47976 m
.54077 .48566 L
.54589 .49095 L
.55182 .49576 L
.55867 .50025 L
.56655 .50452 L
.57558 .50868 L
.58593 .51285 L
.59777 .51711 L
.6113 .52156 L
.62675 .52629 L
.6444 .5314 L
.66453 .53699 L
.6875 .54317 L
.7137 .55005 L
.74359 .55775 L
.77767 .56642 L
.81654 .57621 L
.86085 .58729 L
.91139 .59985 L
.969 .61413 L
s
.969 .61413 m
1 .62178 L
s
0 1 .047 r
.54135 .53829 m
.54784 .53521 L
.55511 .5331 L
.56331 .53186 L
.57259 .53143 L
.58309 .53174 L
.59501 .53277 L
.60855 .53452 L
.62396 .53698 L
.64149 .54018 L
.66145 .54416 L
.68418 .54896 L
.71008 .55467 L
.73959 .56137 L
.77323 .56917 L
.81156 .57819 L
.85526 .58859 L
.90507 .60054 L
.96186 .61424 L
s
.96186 .61424 m
1 .62347 L
s
0 1 .293 r
.42082 .52163 m
.41073 .51236 L
.39906 .50383 L
.38562 .4958 L
.37017 .48807 L
.35247 .48044 L
.33221 .47273 L
.30903 .46476 L
.28256 .45636 L
.25233 .44736 L
.21783 .43757 L
.17846 .42682 L
.13354 .41489 L
.08231 .40156 L
.02388 .3866 L
s
.02388 .3866 m
0 .38056 L
s
0 1 .745 r
.48551 .46529 m
.48272 .46977 L
.47966 .47333 L
.47628 .47609 L
.47252 .47817 L
.4683 .47964 L
.46355 .48056 L
.45818 .48099 L
.45211 .48095 L
.44522 .48047 L
.43739 .47957 L
.4285 .47823 L
.41838 .47646 L
.40685 .47422 L
.39373 .4715 L
.37878 .46824 L
.36174 .46441 L
.34233 .45994 L
.3202 .45475 L
.29498 .44877 L
.26624 .4419 L
.23346 .434 L
.1961 .42497 L
.15351 .41463 L
.10495 .40281 L
.04959 .38931 L
s
.04959 .38931 m
0 .37721 L
s
1 0 .552 r
.55569 .46667 m
.56234 .47608 L
.57012 .48448 L
.57914 .49211 L
.58956 .49918 L
.60155 .50589 L
.61531 .51241 L
.63108 .5189 L
.64912 .52551 L
.66975 .53239 L
.69331 .53968 L
.7202 .54754 L
.7509 .55613 L
.78592 .56559 L
.82587 .57612 L
.87144 .5879 L
.92341 .60114 L
.98267 .61609 L
s
.98267 .61609 m
1 .62043 L
s
.77 1 0 r
.43412 .46783 m
.42449 .46813 L
.41358 .46767 L
.4012 .46649 L
.38713 .46458 L
.37113 .46195 L
.35292 .45856 L
.33217 .45437 L
.30855 .44933 L
.28163 .44336 L
.25096 .43637 L
.21601 .42824 L
.17616 .41884 L
.13074 .40801 L
.07897 .39558 L
.01995 .38133 L
s
.01995 .38133 m
0 .37649 L
s
0 1 .392 r
.57215 .52694 m
.58248 .52794 L
.59423 .52954 L
.60759 .53174 L
.6228 .53458 L
.64011 .53807 L
.65983 .54228 L
.6823 .54727 L
.70791 .55311 L
.73709 .5599 L
.77036 .56775 L
.80827 .57679 L
.8515 .58717 L
.90077 .59907 L
.95695 .61268 L
s
.95695 .61268 m
1 .62315 L
s
1 .007 0 r
.49359 .44306 m
.49134 .45168 L
.489 .45876 L
.48651 .46454 L
.48383 .46921 L
.48091 .47294 L
.47769 .47586 L
.47411 .47807 L
.4701 .47967 L
.46559 .48072 L
.4605 .48127 L
.45475 .48136 L
.44822 .48101 L
.44081 .48024 L
.43239 .47905 L
.42281 .47743 L
.41191 .47536 L
.39949 .47283 L
.38534 .46978 L
.36923 .46619 L
.35086 .46198 L
.32993 .4571 L
.30607 .45146 L
.27887 .44496 L
.24787 .43751 L
.21252 .42897 L
.17223 .4192 L
.1263 .40803 L
.07393 .39527 L
.01422 .38069 L
s
.01422 .38069 m
0 .37722 L
s
1 0 .755 r
.52089 .50573 m
.52383 .50635 L
.52718 .50708 L
.531 .50795 L
.53535 .50896 L
.54031 .51012 L
.54597 .51147 L
.55241 .51301 L
.55976 .51478 L
.56814 .51681 L
.57768 .51913 L
.58857 .52178 L
.60098 .52481 L
.61513 .52827 L
.63127 .53221 L
.64966 .53671 L
.67063 .54184 L
.69454 .54769 L
.7218 .55436 L
.75287 .56197 L
.7883 .57065 L
.8287 .58054 L
.87475 .59182 L
.92726 .60469 L
.98712 .61935 L
s
.98712 .61935 m
1 .62251 L
s
1 .451 0 r
.41856 .43707 m
.4061 .44114 L
.39206 .44364 L
.37621 .44471 L
.35825 .44445 L
.33788 .44291 L
.31474 .44011 L
.28843 .43607 L
.25849 .43074 L
.2244 .42406 L
.18559 .41594 L
.14136 .40627 L
.09097 .3949 L
.03354 .38164 L
s
.03354 .38164 m
0 .37377 L
s
.079 1 0 r
.57362 .42291 m
.58161 .44062 L
.5911 .4561 L
.60224 .4698 L
.61521 .48213 L
.63023 .49345 L
.64753 .50406 L
.66742 .51425 L
.69022 .52427 L
.71633 .53436 L
.74618 .54476 L
.78029 .5557 L
.81925 .56739 L
.86371 .58008 L
.91445 .594 L
.97233 .60943 L
s
.97233 .60943 m
1 .61665 L
s
0 1 .767 r
.50463 .42332 m
.50338 .4359 L
.50226 .44639 L
.50125 .45511 L
.50032 .46237 L
.49944 .4684 L
.49859 .47341 L
.49775 .47755 L
.4969 .48097 L
.49602 .48378 L
.49509 .48608 L
.49409 .48794 L
.493 .48943 L
.4918 .49061 L
.49048 .4915 L
.48899 .49216 L
.48732 .4926 L
.48544 .49285 L
.48331 .49293 L
.4809 .49283 L
.47817 .49257 L
.47506 .49215 L
.47152 .49157 L
.46749 .49083 L
.46291 .4899 L
.45769 .48879 L
.45174 .48747 L
.44496 .48593 L
.43723 .48413 L
.42842 .48206 L
.41839 .47966 L
.40694 .47692 L
.3939 .47377 L
.37902 .47016 L
.36207 .46604 L
.34274 .46133 L
.3207 .45596 L
.29558 .44982 L
.26693 .44282 L
.23428 .43483 L
.19705 .42572 L
.1546 .41533 L
.1062 .40348 L
.05103 .38997 L
s
.05103 .38997 m
0 .37747 L
s
.025 0 1 r
.46776 .45853 m
.46242 .46279 L
.45647 .46597 L
.4498 .4682 L
.44229 .46959 L
.43381 .47021 L
.4242 .47011 L
.41331 .46931 L
.40093 .46785 L
.38686 .4657 L
.37084 .46287 L
.35261 .45931 L
.33185 .45498 L
.30819 .44982 L
.28124 .44375 L
.25053 .43666 L
.21552 .42845 L
.17562 .41898 L
.13013 .40809 L
.07827 .3956 L
.01916 .3813 L
s
.01916 .3813 m
0 .37665 L
s
.371 0 1 r
.52749 .51034 m
.53144 .51071 L
.53591 .51131 L
.54101 .51214 L
.5468 .51321 L
.5534 .51454 L
.56092 .51614 L
.56949 .51804 L
.57925 .52026 L
.59037 .52285 L
.60305 .52584 L
.6175 .52928 L
.63398 .53323 L
.65276 .53777 L
.67417 .54296 L
.69858 .54889 L
.72641 .55567 L
.75814 .56341 L
.79431 .57224 L
.83555 .58233 L
.88257 .59383 L
.93617 .60694 L
.99729 .6219 L
s
.99729 .6219 m
1 .62257 L
s
0 1 .477 r
.55154 .52838 m
.55914 .52763 L
.56775 .52756 L
.57751 .52814 L
.58859 .52934 L
.60119 .53116 L
.61553 .53362 L
.63185 .53674 L
.65043 .54055 L
.67159 .54513 L
.69571 .55052 L
.7232 .55683 L
.75452 .56415 L
.79023 .5726 L
.83093 .58232 L
.87732 .59348 L
.93022 .60627 L
.99051 .6209 L
s
.99051 .6209 m
1 .62321 L
s
1 0 .078 r
.53193 .41921 m
.53424 .43445 L
.53723 .44743 L
.54093 .45856 L
.54541 .46818 L
.55072 .4766 L
.55695 .48406 L
.56419 .49079 L
.57258 .49697 L
.58224 .50279 L
.59334 .50838 L
.60606 .5139 L
.62062 .51947 L
.63728 .52522 L
.6563 .53128 L
.67803 .53776 L
.70283 .54481 L
.73113 .55255 L
.76341 .56114 L
.80024 .57072 L
.84224 .58148 L
.89013 .59361 L
.94474 .60731 L
s
.94474 .60731 m
1 .62109 L
s
0 1 .076 r
.43313 .47694 m
.42359 .47571 L
.41275 .47398 L
.40041 .47172 L
.38636 .46892 L
.37036 .46554 L
.35213 .46152 L
.33136 .45681 L
.30769 .45132 L
.28071 .44497 L
.24995 .43765 L
.21489 .42924 L
.17492 .4196 L
.12935 .40856 L
.0774 .39594 L
.01818 .38151 L
s
.01818 .38151 m
0 .37708 L
s
.973 0 1 r
.47615 .55856 m
.47438 .54746 L
.47211 .538 L
.4693 .52988 L
.46591 .52286 L
.4619 .5167 L
.4572 .51124 L
.45173 .5063 L
.44541 .50175 L
.43813 .49746 L
.42977 .49332 L
.42019 .48923 L
.40922 .48509 L
.39668 .4808 L
.38236 .47628 L
.366 .47143 L
.34733 .46615 L
.32603 .46034 L
.30172 .45389 L
.274 .44669 L
.24239 .43861 L
.20634 .42949 L
.16523 .41918 L
.11835 .4075 L
.0649 .39424 L
.00396 .37917 L
s
.00396 .37917 m
0 .37819 L
s
.182 1 0 r
.53207 .56212 m
.5379 .55455 L
.54431 .54863 L
.55145 .54412 L
.55943 .54085 L
.5684 .53869 L
.57852 .53754 L
.58997 .53731 L
.60295 .53796 L
.61768 .53946 L
.63443 .5418 L
.65348 .545 L
.67517 .54909 L
.69986 .55412 L
.72799 .56015 L
.76004 .56729 L
.79656 .57565 L
.83819 .58535 L
.88563 .59656 L
.93971 .60947 L
s
.93971 .60947 m
1 .62395 L
s
1 .734 0 r
.5083 .57734 m
.51131 .5656 L
.51443 .55596 L
.51773 .54808 L
.52129 .54171 L
.52516 .53661 L
.52944 .53261 L
.53418 .52957 L
.53949 .52736 L
.54546 .52589 L
.55219 .52509 L
.5598 .52492 L
.56843 .52533 L
.57823 .52631 L
.58936 .52786 L
.60203 .52997 L
.61645 .53268 L
.63286 .53602 L
.65156 .54002 L
.67287 .54476 L
.69715 .55031 L
.72482 .55676 L
.75636 .56421 L
.79232 .57279 L
.8333 .58263 L
.88002 .59392 L
.93329 .60683 L
.99401 .6216 L
s
.99401 .6216 m
1 .62306 L
s
.379 0 1 r
.4694 .50051 m
.46531 .49818 L
.46061 .49593 L
.45523 .49368 L
.44907 .4914 L
.44203 .48904 L
.43399 .48653 L
.42481 .48383 L
.41433 .48089 L
.40237 .47765 L
.38873 .47405 L
.37317 .47002 L
.35543 .46549 L
.33519 .46038 L
.31212 .4546 L
.28581 .44805 L
.25581 .44062 L
.22161 .43216 L
.18261 .42255 L
.13815 .4116 L
.08746 .39914 L
.02967 .38495 L
s
.02967 .38495 m
0 .37767 L
s
1 .634 0 r
.50274 .56958 m
.50481 .55867 L
.50689 .54966 L
.50903 .54224 L
.51128 .53616 L
.51367 .53121 L
.51627 .52723 L
.51912 .52408 L
.52228 .52164 L
.52579 .51982 L
.52974 .51855 L
.53418 .51777 L
.5392 .51744 L
.54488 .51754 L
.55133 .51803 L
.55866 .51892 L
.56699 .52021 L
.57646 .5219 L
.58726 .52402 L
.59955 .5266 L
.61355 .52966 L
.6295 .53326 L
.64768 .53746 L
.66841 .54233 L
.69203 .54794 L
.71896 .55439 L
.74965 .56179 L
.78465 .57026 L
.82454 .57994 L
.87002 .59102 L
.92188 .60366 L
.98099 .61809 L
s
.98099 .61809 m
1 .62274 L
s
.287 1 0 r
.47747 .45229 m
.47329 .45825 L
.46868 .46296 L
.46357 .46657 L
.45787 .46923 L
.45147 .47105 L
.44425 .47211 L
.43609 .47247 L
.42684 .47217 L
.41635 .47124 L
.40443 .46969 L
.39087 .46751 L
.37544 .46468 L
.35787 .46117 L
.33786 .45693 L
.31506 .4519 L
.28908 .446 L
.25947 .43913 L
.22572 .43118 L
.18725 .42203 L
.1434 .41151 L
.0934 .39944 L
.03641 .38564 L
s
.03641 .38564 m
0 .37679 L
s
1 0 .731 r
.43953 .50369 m
.43151 .49866 L
.42229 .49384 L
.41172 .48912 L
.39961 .48437 L
.38577 .47949 L
.36994 .47438 L
.35187 .46892 L
.33125 .463 L
.30771 .45651 L
.28086 .44934 L
.25023 .44133 L
.21529 .43235 L
.17546 .42224 L
.13003 .41082 L
.07823 .39789 L
.01916 .38322 L
s
.01916 .38322 m
0 .37847 L
s
1 .018 0 r
.50044 .48651 m
.50017 .4887 L
.49991 .49052 L
.49967 .49202 L
.49943 .49327 L
.49919 .49431 L
.49894 .49516 L
.49868 .49585 L
.4984 .49642 L
.4981 .49687 L
.49777 .49723 L
.4974 .49751 L
.49699 .49772 L
.49653 .49786 L
.49601 .49795 L
.49543 .49798 L
.49477 .49797 L
.49401 .49791 L
.49316 .4978 L
.49219 .49765 L
.49108 .49745 L
.48983 .4972 L
.48839 .4969 L
.48676 .49655 L
.4849 .49612 L
.48278 .49563 L
.48036 .49507 L
.47761 .49441 L
.47447 .49366 L
.47089 .4928 L
.46681 .49181 L
.46216 .49068 L
.45686 .48939 L
.45081 .48791 L
.44392 .48623 L
.43606 .48431 L
.4271 .48212 L
.41688 .47962 L
.40524 .47677 L
.39196 .47352 L
.37682 .46981 L
.35956 .46559 L
.33989 .46077 L
.31745 .45527 L
.29188 .44901 L
.26272 .44186 L
.22947 .43372 L
.19157 .42443 L
.14835 .41384 L
.09908 .40177 L
Mistroke
.04291 .38801 L
Mfstroke
.04291 .38801 m
0 .3775 L
s
1 0 .817 r
.42111 .4922 m
.41034 .48765 L
.39801 .48304 L
.38391 .47825 L
.36781 .4732 L
.34943 .46777 L
.32845 .46186 L
.30451 .45535 L
.27719 .44812 L
.24604 .44004 L
.21052 .43096 L
.17 .42072 L
.12381 .40914 L
.07113 .39602 L
.01107 .38113 L
s
.01107 .38113 m
0 .37839 L
s
1 .099 0 r
.46492 .53189 m
.461 .52422 L
.45636 .51749 L
.45094 .51149 L
.44464 .50606 L
.43737 .50102 L
.42899 .49626 L
.41938 .49164 L
.40836 .48705 L
.39575 .48239 L
.38134 .47755 L
.36488 .47242 L
.34608 .4669 L
.32463 .46088 L
.30015 .45424 L
.27222 .44687 L
.24038 .43862 L
.20406 .42936 L
.16264 .4189 L
.11541 .40707 L
.06155 .39366 L
.00015 .37844 L
s
.00015 .37844 m
0 .3784 L
s
0 .738 1 r
.52754 .55602 m
.53261 .5491 L
.53818 .54366 L
.54437 .53949 L
.55129 .53644 L
.55906 .53439 L
.56783 .53324 L
.57774 .53291 L
.58897 .53337 L
.60172 .53457 L
.6162 .53652 L
.63268 .53923 L
.65144 .54271 L
.67279 .54701 L
.69712 .5522 L
.72483 .55834 L
.75641 .56554 L
.7924 .57391 L
.83343 .58358 L
.88019 .59472 L
.9335 .60752 L
.99427 .62219 L
s
.99427 .62219 m
1 .62358 L
s
1 0 .202 r
.51561 .50184 m
.51775 .5027 L
.5202 .50357 L
.523 .50448 L
.52619 .50546 L
.52984 .50651 L
.534 .50766 L
.53875 .50893 L
.54416 .51035 L
.55034 .51194 L
.55738 .51373 L
.56541 .51576 L
.57457 .51804 L
.58501 .52064 L
.59692 .52359 L
.61049 .52694 L
.62597 .53075 L
.64362 .5351 L
.66374 .54004 L
.68668 .54567 L
.71283 .55209 L
.74265 .5594 L
.77665 .56774 L
.81541 .57724 L
.8596 .58808 L
.90998 .60042 L
.96743 .6145 L
s
.96743 .6145 m
1 .62248 L
s
1 0 .779 r
.44882 .43544 m
.44038 .44199 L
.43096 .44687 L
.4204 .45029 L
.40851 .45238 L
.39507 .45326 L
.37986 .45302 L
.36259 .4517 L
.34298 .44932 L
.32068 .44588 L
.29531 .44135 L
.26642 .43568 L
.23352 .4288 L
.19604 .42059 L
.15333 .41095 L
.10466 .39971 L
.04919 .38668 L
s
.04919 .38668 m
0 .375 L
s
1 0 .47 r
.52066 .52173 m
.52396 .51978 L
.52766 .51838 L
.53182 .51748 L
.53652 .51702 L
.54183 .51699 L
.54786 .51735 L
.5547 .51809 L
.56248 .51922 L
.57133 .52074 L
.5814 .52267 L
.59287 .52503 L
.60594 .52785 L
.62083 .53119 L
.6378 .53508 L
.65714 .5396 L
.67918 .54482 L
.70431 .55082 L
.73295 .55771 L
.76561 .56561 L
.80283 .57464 L
.84527 .58496 L
.89366 .59676 L
.94882 .61022 L
s
.94882 .61022 m
1 .62272 L
s
0 1 .76 r
.57777 .57558 m
.59005 .56922 L
.60383 .56478 L
.61934 .56207 L
.63686 .56092 L
.65671 .56124 L
.67922 .56298 L
.7048 .56608 L
.73388 .57057 L
.76698 .57648 L
.80465 .58388 L
.84757 .59286 L
.89645 .60356 L
.95216 .61614 L
s
.95216 .61614 m
1 .62719 L
s
.779 0 1 r
.42474 .53511 m
.41551 .52398 L
.40476 .51394 L
.39233 .50472 L
.37801 .49606 L
.36155 .48773 L
.34268 .47952 L
.32108 .47124 L
.29638 .46269 L
.26816 .45369 L
.23593 .44406 L
.19915 .43359 L
.15718 .4221 L
.10929 .40936 L
.05468 .39514 L
s
.05468 .39514 m
0 .38113 L
s
0 .08 1 r
.52012 .51744 m
.52325 .51613 L
.52676 .51526 L
.53072 .51479 L
.53521 .51469 L
.54029 .51493 L
.54606 .5155 L
.55261 .51641 L
.56007 .51765 L
.56856 .51925 L
.57822 .52121 L
.58923 .52357 L
.60178 .52636 L
.61607 .52963 L
.63237 .53342 L
.65094 .53781 L
.6721 .54285 L
.69624 .54865 L
.72374 .5553 L
.7551 .5629 L
.79086 .57159 L
.83162 .58152 L
.87809 .59286 L
.93107 .6058 L
.99147 .62057 L
s
.99147 .62057 m
1 .62266 L
s
1 .555 0 r
.43963 .45089 m
.43033 .4543 L
.41987 .45648 L
.40806 .45754 L
.39469 .45757 L
.37953 .45661 L
.36231 .45469 L
.34273 .45181 L
.32046 .44795 L
.29511 .44308 L
.26623 .43712 L
.23334 .42999 L
.19587 .42158 L
.15316 .41177 L
.10449 .40038 L
.049 .38724 L
s
.049 .38724 m
0 .37552 L
s
0 .846 1 r
.56491 .57184 m
.57538 .56514 L
.58708 .56027 L
.60023 .55704 L
.61507 .5553 L
.63186 .55492 L
.65089 .55584 L
.67249 .558 L
.69704 .56141 L
.72497 .56608 L
.75676 .57205 L
.79296 .5794 L
.83419 .58824 L
.88117 .5987 L
.93471 .61093 L
.99573 .62515 L
s
.99573 .62515 m
1 .62616 L
s
.051 0 1 r
.54782 .46205 m
.5533 .47162 L
.55976 .48006 L
.56728 .48764 L
.576 .49455 L
.58606 .501 L
.59763 .50716 L
.6109 .51319 L
.62609 .51923 L
.64348 .52542 L
.66334 .5319 L
.68603 .5388 L
.71192 .54627 L
.74148 .55445 L
.7752 .56349 L
.81366 .57356 L
.85752 .58485 L
.90755 .59756 L
.9646 .61192 L
s
.9646 .61192 m
1 .62076 L
s
1 .602 0 r
.5231 .48049 m
.52572 .4853 L
.52881 .48954 L
.53242 .49333 L
.53661 .49677 L
.54144 .49998 L
.54699 .50302 L
.55337 .50599 L
.56068 .50896 L
.56903 .51198 L
.57858 .51514 L
.58949 .51849 L
.60195 .52211 L
.61616 .52607 L
.63238 .53044 L
.65088 .5353 L
.67198 .54075 L
.69604 .54687 L
.72348 .55379 L
.75477 .56161 L
.79044 .57049 L
.83112 .58056 L
.8775 .59202 L
.93038 .60505 L
.99067 .61989 L
s
.99067 .61989 m
1 .62218 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0333333 0.5 0.0333333 [
[0 .4875 -18.4688 -20 ]
[0 .4875 18.4688 0 ]
[.16667 .4875 -18.4688 -20 ]
[.16667 .4875 18.4688 0 ]
[.33333 .4875 -13.4688 -20 ]
[.33333 .4875 13.4688 0 ]
[.66667 .4875 -7 -20 ]
[.66667 .4875 7 0 ]
[.83333 .4875 -12 -20 ]
[.83333 .4875 12 0 ]
[1 .4875 -12 -20 ]
[1 .4875 12 0 ]
[.4875 0 -36.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .16667 -36.9375 -10 ]
[.4875 .16667 0 10 ]
[.4875 .33333 -26.9375 -10 ]
[.4875 .33333 0 10 ]
[.4875 .66667 -14 -10 ]
[.4875 .66667 0 10 ]
[.4875 .83333 -24 -10 ]
[.4875 .83333 0 10 ]
[.4875 1 -24 -10 ]
[.4875 1 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.16667 .5 m
.16667 .50625 L
s
gsave
.16667 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.33333 .5 m
.33333 .50625 L
s
gsave
.33333 .4875 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.66667 .5 m
.66667 .50625 L
s
gsave
.66667 .4875 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.83333 .5 m
.83333 .50625 L
s
gsave
.83333 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.5 .16667 m
.50625 .16667 L
s
gsave
.4875 .16667 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 .33333 m
.50625 .33333 L
s
gsave
.4875 .33333 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .66667 m
.50625 .66667 L
s
gsave
.4875 .66667 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .83333 m
.50625 .83333 L
s
gsave
.4875 .83333 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.01 w
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .581 0 r
.5 Mabswid
.25688 .76016 m
.23064 .70077 L
.19943 .64893 L
.16277 .60307 L
.12006 .56185 L
.07062 .52407 L
.01363 .48869 L
s
.01363 .48869 m
0 .48163 L
s
1 0 0 r
.25688 .76016 m
.23064 .70077 L
s
% Start of user PostScript
-7.293702 7.8048668 -8.0807984 6.0229653 MAarrowhead1
% End of user PostScript
1 .158 0 r
.19943 .64893 m
.16277 .60307 L
s
% Start of user PostScript
-9.0170783 4.4677727 -10.116999 3.0921333 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-24.341298 -4.3957901 -27.71338 -5.4816758 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-69.160516 -16.576065 -78.841599 -19.008898 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-197.36179 -48.266806 -225.01208 -55.055392 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-563.40907 -138.0138 -642.34795 -157.35703 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1608.4124 -394.05306 -1833.7673 -449.26535 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4591.6848 -1124.9525 -5235.0267 -1282.5701 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-13108.313 -3211.5101 -14944.921 -3661.4756 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-37421.529 -9168.1997 -42664.668 -10452.758 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-106830.75 -26173.319 -121798.83 -29840.469 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-304979.75 -74719.429 -347710.53 -85188.385 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-870654.29 -213308.56 -992641.86 -243195.27 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2485538.4 -608951.94 -2833787.8 -694272.34 MAarrowhead1
% End of user PostScript
1 .049 0 r
.3513 .42264 m
.32946 .42407 L
.30473 .42367 L
.27667 .42151 L
.2448 .41764 L
.20855 .41205 L
.16732 .40469 L
.12036 .39547 L
.06689 .38428 L
.00597 .37095 L
s
.00597 .37095 m
0 .3696 L
s
1 0 0 r
.3513 .42264 m
.32946 .42407 L
s
% Start of user PostScript
-4.4611492 -2.320897 -5.1162638 -2.2779699 MAarrowhead1
% End of user PostScript
1 .158 0 r
.30473 .42367 m
.27667 .42151 L
s
% Start of user PostScript
-5.8581863 -2.2900124 -6.6999045 -2.3546231 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-16.903216 -4.341958 -19.276443 -4.8901435 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-48.297296 -11.879867 -55.065395 -13.53023 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-137.8887 -33.793522 -157.20859 -38.525023 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-393.64613 -96.445113 -448.80005 -109.95728 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1123.7791 -275.32423 -1281.232 -313.89979 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3208.1576 -785.99233 -3657.6533 -896.11785 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-9158.6283 -2243.8456 -10441.846 -2558.2313 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-26145.995 -6405.7164 -29809.316 -7303.2228 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-74641.422 -18286.999 -85099.449 -20849.195 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-213085.87 -52205.611 -242941.38 -59520.151 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-608316.2 -149036.25 -693547.52 -169917.75 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1736617.3 -425467.76 -1979935.1 -485080.14 MAarrowhead1
% End of user PostScript
1 0 .147 r
.6706 .82162 m
.70136 .7828 L
.73529 .75243 L
.77302 .72941 L
.81525 .71283 L
.86274 .702 L
.91634 .69639 L
.97698 .69561 L
s
.97698 .69561 m
1 .69688 L
s
1 0 0 r
.6706 .82162 m
.70136 .7828 L
s
% Start of user PostScript
5.1181345 9.6486924 6.0407574 8.4839825 MAarrowhead1
% End of user PostScript
1 .158 0 r
.73529 .75243 m
.77302 .72941 L
s
% Start of user PostScript
7.0586009 7.5730057 8.1906472 6.8822416 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
21.376657 6.6093598 24.405338 7.1240626 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
61.313773 15.343933 69.912348 17.397191 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
175.10576 42.97621 199.64172 48.974939 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
499.9067 122.4939 569.94917 139.65123 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1427.1342 349.6492 1627.0905 398.63738 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4074.1748 998.16565 4645.0084 1138.0186 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
11630.929 2849.5545 13260.541 3248.8062 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
33203.903 8134.8899 37856.11 9274.6712 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
94790.296 23223.433 108071.39 26477.273 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
270606.74 66298.111 308521.52 75587.154 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
772526.44 189267.43 880765.3 215785.74 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2205403.7 540319.48 2514403.3 616023.77 MAarrowhead1
% End of user PostScript
0 .48 1 r
.67206 .34873 m
.69144 .38552 L
.71431 .41786 L
.74104 .44671 L
.77206 .47293 L
.80788 .49723 L
.84911 .52028 L
.89642 .54269 L
.95063 .56499 L
s
.95063 .56499 m
1 .58307 L
s
1 0 0 r
.67206 .34873 m
.69144 .38552 L
s
% Start of user PostScript
5.1619022 -4.538154 5.7430735 -3.4344231 MAarrowhead1
% End of user PostScript
1 .158 0 r
.71431 .41786 m
.74104 .44671 L
s
% Start of user PostScript
6.4292085 -2.4642413 7.2311145 -1.5985756 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
17.506735 3.340647 19.936387 4.0930386 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
49.77916 11.973089 56.748277 13.717404 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
142.06252 34.75274 161.96565 39.637631 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
405.54822 99.346224 462.36937 113.26933 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1157.7539 283.64452 1319.967 323.38688 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3305.1481 809.754 3768.2332 923.20902 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
9435.5161 2311.6824 10757.528 2635.5728 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
26936.452 6599.3769 30710.525 7524.0171 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
76898.016 18839.86 87672.215 21479.517 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
219527.98 53783.915 250286.09 61319.591 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
626707.09 153541.98 714515.17 175054.79 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1789119.5 438330.7 2039793.4 499745.31 MAarrowhead1
% End of user PostScript
1 .633 0 r
.61033 .65402 m
.6289 .63753 L
.64956 .62504 L
.67267 .61606 L
.69867 .61021 L
.72802 .6072 L
.76122 .60683 L
.79887 .60896 L
.84162 .61351 L
.89021 .62048 L
.94549 .6299 L
s
.94549 .6299 m
1 .64028 L
s
1 0 0 r
.61033 .65402 m
.6289 .63753 L
s
% Start of user PostScript
3.3100021 4.6206614 3.8670364 4.125982 MAarrowhead1
% End of user PostScript
1 .158 0 r
.64956 .62504 m
.67267 .61606 L
s
% Start of user PostScript
4.4866652 3.7512003 5.1802183 3.4817695 MAarrowhead1
% End of user PostScript
1 .473 0 r
.94549 .6299 m
0 0 rlineto s
.94549 .6299 m
1 .64028 L
s
% Start of user PostScript
13.364801 3.8970469 15.252591 4.2563901 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
38.284371 9.5258068 43.651983 10.816638 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
109.32465 26.818653 124.643 30.565929 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
312.10654 76.473539 355.83606 87.185847 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
891.00149 218.29548 1015.84 248.88034 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2543.6259 623.1837 2900.0139 710.49797 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
7261.5274 1779.0598 8278.9417 2028.3242 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
20730.163 5078.8485 23634.671 5790.4471 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
59180.34 14499.065 67472.111 16530.532 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
168947.67 41391.84 192618.96 47191.26 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
482310.74 118165.17 549887.41 134721.31 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1376897.7 337337.18 1569815.1 384601.57 MAarrowhead1
% End of user PostScript
0 .479 1 r
.17092 .80887 m
.13435 .73539 L
.09108 .67095 L
.04042 .61362 L
s
.04042 .61362 m
0 .57798 L
s
1 0 0 r
.17092 .80887 m
.13435 .73539 L
s
% Start of user PostScript
-9.872273 9.2662423 -10.96941 7.0616166 MAarrowhead1
% End of user PostScript
1 .158 0 r
.09108 .67095 m
.04042 .61362 L
s
% Start of user PostScript
-12.26766 5.1284253 -13.787349 3.4085574 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-33.315399 -6.2523068 -37.936469 -7.7008706 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-94.707958 -22.754806 -107.96653 -26.077425 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-270.27762 -66.112175 -308.1437 -75.406734 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-771.56476 -189.0071 -879.66827 -215.49634 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2202.6531 -539.63979 -2511.2672 -615.25058 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6288.119 -1540.5752 -7169.1488 -1756.426 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-17951.283 -4398.028 -20466.441 -5014.2368 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-51247.209 -12555.464 -58427.467 -14314.613 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-146300.21 -35843.259 -166798.37 -40865.267 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-417656.93 -102325.11 -476174.94 -116661.91 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1192324.4 -292117.09 -1359381.2 -333045.68 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3403840.3 -833934.05 -3880753.1 -950776.74 MAarrowhead1
% End of user PostScript
.899 1 0 r
.77756 .77008 m
.8214 .74734 L
.87055 .73146 L
.92592 .72171 L
.98846 .7176 L
s
.98846 .7176 m
1 .71778 L
s
1 0 0 r
.77756 .77008 m
.8214 .74734 L
s
% Start of user PostScript
8.3267645 8.1025174 9.6418504 7.420347 MAarrowhead1
% End of user PostScript
1 .158 0 r
.87055 .73146 m
.92592 .72171 L
s
% Start of user PostScript
11.116605 6.9436869 12.777472 6.6514499 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
32.62086 8.9829558 37.215635 9.9445036 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
93.333687 23.099237 106.41639 26.265926 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
266.49723 65.345921 303.83756 74.485175 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
760.80609 186.4088 867.40312 212.52273 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2171.9472 532.12572 2476.2593 606.68108 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6200.4619 1519.1014 7069.21 1731.9429 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
17701.04 4336.7195 20181.137 4944.3382 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
50532.818 12380.439 57612.983 14115.066 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
144260.77 35343.601 164473.18 40295.601 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
411834.76 100898.69 469537.02 115035.63 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1175703.3 288044.95 1340431.3 328403. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3356390.4 822308.93 3826655. 937522.82 MAarrowhead1
% End of user PostScript
.436 1 0 r
.68878 .72015 m
.71949 .69887 L
.7538 .68323 L
.79232 .67262 L
.83575 .66652 L
.88485 .66459 L
.9405 .66658 L
s
.9405 .66658 m
1 .672 L
s
1 0 0 r
.68878 .72015 m
.71949 .69887 L
s
% Start of user PostScript
5.6634772 6.6045811 6.5847115 5.9659803 MAarrowhead1
% End of user PostScript
1 .158 0 r
.7538 .68323 m
.79232 .67262 L
s
% Start of user PostScript
7.6138604 5.4970062 8.7695493 5.1785003 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
22.497796 6.3646392 25.670844 7.0007596 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
64.405441 15.979428 73.434205 18.158286 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
183.90625 45.103677 209.67455 51.40907 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
525.02428 128.64094 598.58582 146.66154 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1498.8384 367.21499 1708.841 418.66479 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4278.8749 1048.3164 4878.3891 1195.1961 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
12215.306 2992.7255 13926.795 3412.037 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
34872.178 8543.6138 39758.127 9740.6615 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
99552.876 24390.255 113501.25 27807.58 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
284202.93 69629.148 324022.66 79384.904 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
811340.74 198776.86 925017.88 226627.53 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2316210.5 567466.93 2640735.3 646974.85 MAarrowhead1
% End of user PostScript
1 .635 0 r
.21047 .28063 m
.16626 .29439 L
.11647 .30271 L
.06021 .30604 L
s
.06021 .30604 m
0 .30479 L
s
1 0 0 r
.21047 .28063 m
.16626 .29439 L
s
% Start of user PostScript
-8.6860417 -6.581073 -10.012063 -6.1682203 MAarrowhead1
% End of user PostScript
1 .158 0 r
.11647 .30271 m
.06021 .30604 L
s
% Start of user PostScript
-11.505813 -5.9186789 -13.193784 -5.8186916 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-33.496954 -8.9345302 -38.208039 -9.9681556 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-95.779573 -23.636705 -109.20345 -26.897216 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-273.46678 -67.038941 -311.78325 -76.419753 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-780.69966 -191.27928 -890.0839 -218.07663 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2228.7385 -546.03868 -2541.0076 -622.54362 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6362.5892 -1558.8221 -7254.053 -1777.2289 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-18163.88 -4450.1143 -20708.825 -5073.6209 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-51854.131 -12704.158 -59119.425 -14484.141 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-148032.85 -36267.752 -168773.77 -41349.235 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-422603.25 -103536.95 -481814.29 -118043.54 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1206445.1 -295576.64 -1375480.4 -336989.95 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3444152. -843810.35 -3926712.9 -962036.81 MAarrowhead1
% End of user PostScript
1 0 .455 r
.4646 .75243 m
.46604 .70952 L
.46661 .67357 L
.46638 .64341 L
.46538 .61804 L
.46363 .59665 L
.46112 .57855 L
.45783 .56315 L
.45372 .54997 L
.44873 .53859 L
.4428 .52866 L
.43583 .51989 L
.42772 .512 L
.41832 .50477 L
.40748 .49801 L
.39502 .49153 L
.38073 .48518 L
.36438 .47878 L
.34567 .47221 L
.32429 .46531 L
.29987 .45795 L
.27201 .44996 L
.2402 .44121 L
.20392 .43151 L
.16254 .4207 L
.11534 .40858 L
.06151 .39492 L
.00013 .3795 L
s
.00013 .3795 m
0 .37946 L
s
1 0 0 r
.4646 .75243 m
.46604 .70952 L
s
% Start of user PostScript
-1.0619257 7.5728311 -1.0189454 6.2856766 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46661 .67357 m
.46638 .64341 L
s
% Start of user PostScript
-1.0017129 5.2071999 -1.0085726 4.3021901 MAarrowhead1
% End of user PostScript
1 .473 0 r
.4428 .52866 m
.43583 .51989 L
s
% Start of user PostScript
-1.7159048 0.85990901 -1.9249763 0.59658064 MAarrowhead1
% End of user PostScript
1 .788 0 r
.34567 .47221 m
.32429 .46531 L
s
% Start of user PostScript
-4.6299891 -0.83371659 -5.2713381 -1.0406494 MAarrowhead1
% End of user PostScript
.897 1 0 r
.06151 .39492 m
.00013 .3795 L
s
% Start of user PostScript
-13.154603 -3.1522641 -14.99597 -3.6150893 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-37.538873 -9.1803744 -42.798047 -10.471607 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-107.16226 -26.250648 -122.1767 -29.929799 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-305.92534 -74.950182 -348.78859 -85.451743 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-873.35356 -213.96966 -995.71932 -243.94906 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-2493.2442 -610.8398 -2842.5733 -696.42472 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-7117.6981 -1743.8218 -8114.9604 -1988.149 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-20319.56 -4978.2515 -23166.538 -5675.7555 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-58008.153 -14211.881 -66135.688 -16203.111 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-165601.31 -40571.99 -188803.75 -46256.541 MAarrowhead1
% End of user PostScript
0 .906 1 r
.57307 .69846 m
.58773 .67214 L
.60371 .6511 L
.62132 .63459 L
.64088 .62201 L
.66276 .61288 L
.68736 .60681 L
.7151 .60351 L
.74648 .60278 L
.78205 .60447 L
.82244 .60851 L
.86833 .61486 L
.92054 .62358 L
.97997 .63473 L
s
.97997 .63473 m
1 .6388 L
s
1 0 0 r
.57307 .69846 m
.58773 .67214 L
s
% Start of user PostScript
2.1921351 5.953894 2.6318899 5.1642336 MAarrowhead1
% End of user PostScript
1 .158 0 r
.60371 .6511 m
.62132 .63459 L
s
% Start of user PostScript
3.1112888 4.5329571 3.6395262 4.0376869 MAarrowhead1
% End of user PostScript
1 .473 0 r
.82244 .60851 m
.86833 .61486 L
s
% Start of user PostScript
9.6730558 3.2552582 11.050026 3.4459333 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
27.800302 7.0189099 31.700499 7.9400091 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
79.407739 19.503551 90.53477 22.221564 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
226.70296 55.553232 258.46664 63.333372 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
647.19259 158.56358 737.87095 180.77915 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1847.6019 452.6594 2106.4699 516.08143 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
5274.5225 1292.2476 6013.5371 1473.3047 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
15057.674 3689.1 17167.408 4205.9807 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
42986.554 10531.62 49009.41 12007.207 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
122717.74 30065.602 139911.76 34278.1 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
350333.85 85831.092 399419.21 97856.906 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1000130.9 245030.07 1140259.5 279361.29 MAarrowhead1
% End of user PostScript
0 .211 1 r
.28445 .63919 m
.25894 .60113 L
.22909 .56728 L
.19441 .53664 L
.15432 .50835 L
.10816 .48162 L
.05516 .45578 L
s
.05516 .45578 m
0 .43252 L
s
1 0 0 r
.28445 .63919 m
.25894 .60113 L
s
% Start of user PostScript
-6.4666449 4.1756621 -7.2316727 3.0339828 MAarrowhead1
% End of user PostScript
1 .158 0 r
.22909 .56728 m
.19441 .53664 L
s
% Start of user PostScript
-8.1272506 2.0184083 -9.1677995 1.0992151 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-22.360549 -4.5368228 -25.470442 -5.4547121 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-63.637267 -15.369942 -72.548087 -17.589698 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-181.6249 -44.445831 -207.07114 -50.688707 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-518.49075 -127.01701 -591.1363 -144.81704 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1480.1816 -362.63866 -1687.5701 -413.44891 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4225.6125 -1035.2659 -4817.6641 -1180.3175 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-12063.252 -2955.4725 -13753.437 -3369.5644 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-34438.097 -8437.2647 -39263.226 -9619.4118 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-98313.664 -24086.651 -112088.41 -27461.437 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-280665.23 -68762.42 -319989.3 -78396.739 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-801241.35 -196302.53 -913503.46 -223806.52 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2287378.8 -560403.23 -2607864. -638921.45 MAarrowhead1
% End of user PostScript
1 0 .388 r
.58039 .22813 m
.58452 .27744 L
.59041 .31919 L
.59811 .3547 L
.6077 .3851 L
.61934 .41136 L
.63317 .43428 L
.64942 .45455 L
.66835 .47278 L
.69026 .48949 L
.71552 .50514 L
.74455 .52015 L
.77784 .5349 L
.81595 .54973 L
.85954 .56499 L
.90936 .58102 L
.96624 .59815 L
s
.96624 .59815 m
1 .60781 L
s
1 0 0 r
.58039 .22813 m
.58452 .27744 L
s
% Start of user PostScript
2.4118366 -8.1561744 2.5356144 -6.6767317 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59041 .31919 m
.59811 .3547 L
s
% Start of user PostScript
2.7122121 -5.424422 2.9431525 -4.3590993 MAarrowhead1
% End of user PostScript
1 .473 0 r
.71552 .50514 m
.74455 .52015 L
s
% Start of user PostScript
6.4655541 0.15434124 7.3364424 0.60456504 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
18.157918 4.1129513 20.69381 4.7898551 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
51.766692 12.603911 59.017806 14.393478 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
147.7667 36.184036 168.46987 41.259338 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
421.83956 103.3455 480.94349 117.82657 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1204.264 295.04125 1372.9937 336.37986 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
3437.9252 842.28455 3919.6137 960.2973 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
9814.5673 2404.5493 11189.689 2741.4513 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
28018.565 6864.4924 31944.253 7826.278 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
79987.225 19596.71 91194.254 22342.41 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
228347.03 55944.566 260340.79 63782.971 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
651883.68 159710.2 743219.25 182087.23 MAarrowhead1
% End of user PostScript
.908 1 0 r
.48744 .75942 m
.4921 .71708 L
.49636 .68184 L
.50032 .65254 L
.5041 .6282 L
.50778 .60803 L
.51147 .59136 L
.51525 .57761 L
.51919 .56634 L
.52339 .55716 L
.52793 .54975 L
.53289 .54386 L
.53838 .53927 L
.54449 .53582 L
.55133 .53337 L
.55903 .53181 L
.56772 .53107 L
.57757 .53108 L
.58873 .53181 L
.60141 .53325 L
.61582 .53539 L
.63222 .53825 L
.65089 .54185 L
.67216 .54625 L
.69638 .55151 L
.72397 .55771 L
.75542 .56494 L
.79127 .57333 L
.83213 .58302 L
.8787 .59416 L
.9318 .60694 L
.99232 .62157 L
s
.99232 .62157 m
1 .62344 L
s
1 0 0 r
.48744 .75942 m
.4921 .71708 L
s
% Start of user PostScript
-0.37694864 7.7827429 -0.23696554 6.5123803 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49636 .68184 m
.50032 .65254 L
s
% Start of user PostScript
-0.10930992 5.4551387 0.0095825783 4.5760836 MAarrowhead1
% End of user PostScript
1 .473 0 r
.52793 .54975 m
.53289 .54386 L
s
% Start of user PostScript
0.83786839 1.4924585 0.98677503 1.3156943 MAarrowhead1
% End of user PostScript
1 .788 0 r
.58873 .53181 m
.60141 .53325 L
s
% Start of user PostScript
2.6619498 0.95440935 3.0423156 0.99752693 MAarrowhead1
% End of user PostScript
.897 1 0 r
.75542 .56494 m
.79127 .57333 L
s
% Start of user PostScript
7.662717 1.9483171 8.7380795 2.2000218 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
21.890363 5.3797585 24.957835 6.1285224 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
62.495968 15.3153 71.252388 17.459957 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
178.41392 43.711972 203.41156 49.836191 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
509.33513 124.7863 580.6982 142.27008 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
1454.0468 356.23861 1657.7736 406.15126 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
4151.0037 1016.9876 4732.6018 1159.478 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
11850.26 2903.2899 13510.602 3310.0705 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
33830.047 8288.2938 38569.983 9449.5685 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
96577.806 23661.369 110109.35 26976.569 MAarrowhead1
% End of user PostScript
.477 0 1 r
.77306 .66573 m
.81374 .65932 L
.85972 .65693 L
.9118 .65829 L
.97091 .66326 L
s
.97091 .66326 m
1 .66695 L
s
1 0 0 r
.77306 .66573 m
.81374 .65932 L
s
% Start of user PostScript
8.1918675 4.9719691 9.4122203 4.7797484 MAarrowhead1
% End of user PostScript
1 .158 0 r
.85972 .65693 m
.9118 .65829 L
s
% Start of user PostScript
10.791531 4.7078496 12.354065 4.7487355 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
31.240544 8.1384958 35.629528 9.1335009 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
89.286969 21.988921 101.79977 25.035681 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
254.91975 62.481548 290.63727 71.227842 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
727.74891 178.3033 829.71413 203.28354 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2077.5744 509.00304 2368.6638 580.31913 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5931.0466 1453.0949 6762.047 1656.6883 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
16931.915 4148.2854 19304.249 4729.5025 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
48337.125 11842.499 55109.651 13501.754 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
137992.52 33807.892 157326.69 38544.723 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
393940.19 96514.558 449135.24 110037.24 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1124618. 275529.16 1282188.5 314133.61 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3210552.4 786578.92 3660383.7 896786.67 MAarrowhead1
% End of user PostScript
.323 1 0 r
.33219 .62681 m
.31279 .59424 L
.28999 .56544 L
.26343 .53957 L
.23267 .51588 L
.19721 .49371 L
.15645 .47247 L
.1097 .45164 L
.05617 .43069 L
s
.05617 .43069 m
0 .41094 L
s
1 0 0 r
.33219 .62681 m
.31279 .59424 L
s
% Start of user PostScript
-5.0341752 3.8043963 -5.6161806 2.8272062 MAarrowhead1
% End of user PostScript
1 .158 0 r
.28999 .56544 m
.26343 .53957 L
s
% Start of user PostScript
-6.3001635 1.963299 -7.097027 1.1870969 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-17.250051 -3.4028074 -19.646801 -4.1264214 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-49.072612 -11.829348 -55.943453 -13.544722 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-140.05163 -34.266971 -159.67318 -39.081733 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-399.80899 -97.941743 -455.82606 -111.66758 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1141.37 -279.63086 -1301.2875 -318.81075 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3258.3753 -798.29485 -3714.907 -910.1443 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-9301.9894 -2278.9687 -10605.293 -2598.2755 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-26555.261 -6505.9858 -30275.925 -7417.541 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-75809.794 -18573.248 -86431.522 -21175.55 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-216421.33 -53022.792 -246744.17 -60451.827 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-617838.25 -151369.13 -704403.71 -172577.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1763800.8 -432127.66 -2010927.3 -492673.17 MAarrowhead1
% End of user PostScript
0 .269 1 r
.33389 .28273 m
.3063 .30522 L
.27555 .32209 L
.24109 .33402 L
.20231 .3415 L
.1585 .34495 L
.10891 .34462 L
.05265 .34071 L
s
.05265 .34071 m
0 .33459 L
s
1 0 0 r
.33389 .28273 m
.3063 .30522 L
s
% Start of user PostScript
-4.9832376 -6.518144 -5.8111273 -5.843384 MAarrowhead1
% End of user PostScript
1 .158 0 r
.27555 .32209 m
.24109 .33402 L
s
% Start of user PostScript
-6.7335277 -5.3371684 -7.7672401 -4.9795272 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-19.996342 -5.7648998 -22.819231 -6.3130599 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-57.267055 -14.233617 -65.295733 -16.166946 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-163.52828 -40.111837 -186.44143 -45.717605 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-466.84952 -114.38841 -532.26019 -130.41203 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1332.7614 -326.52652 -1519.495 -372.27543 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3804.7596 -932.1591 -4337.8453 -1062.7639 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-10861.804 -2661.1204 -12383.654 -3033.9705 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-31008.21 -7596.9495 -35352.778 -8661.3598 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-88522.045 -21687.724 -100924.89 -24726.396 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-252712.18 -61913.979 -288119.74 -70588.76 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-721441.16 -176751.64 -822522.44 -201516.35 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2059565.7 -504589.47 -2348131.9 -575287.62 MAarrowhead1
% End of user PostScript
0 1 .458 r
.68453 .74461 m
.71526 .71911 L
.74949 .69993 L
.78785 .68633 L
.83101 .67772 L
.87976 .67366 L
.93494 .67382 L
.99753 .67801 L
s
.99753 .67801 m
1 .67829 L
s
1 0 0 r
.68453 .74461 m
.71526 .71911 L
s
% Start of user PostScript
5.5357503 7.3383388 6.4578186 6.5731973 MAarrowhead1
% End of user PostScript
1 .158 0 r
.74949 .69993 m
.78785 .68633 L
s
% Start of user PostScript
7.4848154 5.9979486 8.6354619 5.5899789 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
22.241113 6.4267995 25.381258 7.0341425 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
63.698893 15.835687 72.629381 17.985603 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
181.89536 44.617908 207.38208 50.853172 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
519.28505 127.23646 592.04251 145.05979 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1482.4544 363.20133 1690.1615 414.08866 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4232.1021 1036.8572 4825.0629 1182.1313 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
12081.779 2960.0118 13774.56 3374.7397 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
34490.987 8450.2228 39323.527 9634.1854 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
98464.654 24123.643 112260.56 27503.612 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
281096.28 68868.025 320480.74 78517.14 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
802471.9 196604.01 914906.42 224150.24 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2290891.8 561263.9 2611869.1 639902.71 MAarrowhead1
% End of user PostScript
.376 0 1 r
.26624 .34388 m
.23107 .35164 L
.19137 .35558 L
.14644 .35597 L
.0955 .353 L
.03765 .34676 L
s
.03765 .34676 m
0 .34133 L
s
1 0 0 r
.26624 .34388 m
.23107 .35164 L
s
% Start of user PostScript
-7.0128061 -4.6835904 -8.0679723 -4.4508184 MAarrowhead1
% End of user PostScript
1 .158 0 r
.19137 .35558 m
.14644 .35597 L
s
% Start of user PostScript
-9.2589505 -4.3327108 -10.606762 -4.3209338 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-26.865413 -7.0666774 -30.641399 -7.9114858 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-76.796889 -18.928895 -87.559705 -21.546909 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-219.26315 -53.745757 -249.98482 -61.268076 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-625.95668 -153.36441 -713.65977 -174.85045 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1786.9785 -437.80764 -2037.3526 -499.14853 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5101.4555 -1249.8467 -5816.2216 -1424.9629 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-14563.603 -3568.0537 -16604.113 -4067.9745 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-41576.084 -10186.057 -47401.318 -11613.228 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-118691.14 -29079.093 -135320.99 -33153.371 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-338838.74 -83014.812 -386313.51 -94646.037 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-967314.71 -236990.17 -1102845.4 -270194.91 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2761484. -676558.05 -3148396.1 -771350.75 MAarrowhead1
% End of user PostScript
0 1 .143 r
.60915 .19894 m
.61642 .25503 L
.62604 .30269 L
.63811 .34346 L
.6528 .37859 L
.67032 .4092 L
.69094 .43621 L
.71499 .46042 L
.74285 .48253 L
.77499 .50315 L
.81195 .52285 L
.85434 .54211 L
.90289 .56141 L
.95843 .5812 L
s
.95843 .5812 m
1 .59476 L
s
1 0 0 r
.60915 .19894 m
.61642 .25503 L
s
% Start of user PostScript
3.2745971 -9.03175 3.4926459 -7.3491373 MAarrowhead1
% End of user PostScript
1 .158 0 r
.62604 .30269 m
.63811 .34346 L
s
% Start of user PostScript
3.7811314 -5.919174 4.1433145 -4.6963462 MAarrowhead1
% End of user PostScript
1 .473 0 r
.81195 .52285 m
.85434 .54211 L
s
% Start of user PostScript
9.3583812 0.68541631 10.630235 1.2633088 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
26.379075 6.0854024 30.065814 7.0511724 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
75.22765 18.342004 85.765643 20.938473 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
214.74083 52.590266 244.82771 59.964939 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
613.03643 150.18781 698.92898 171.23213 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1750.0915 428.76778 1995.2972 488.84287 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
4996.1502 1224.0465 5696.1619 1395.548 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
14262.978 3494.401 16261.367 3984.0024 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
40717.861 9975.7944 46422.85 11373.505 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
116241.1 28478.836 132527.66 32469.012 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
331844.35 81301.202 378339.14 92692.332 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
947347.19 232098.16 1080080.2 264617.49 MAarrowhead1
% End of user PostScript
.02 0 1 r
.52927 .5845 m
.53527 .57316 L
.54179 .56407 L
.54896 .55691 L
.55692 .55142 L
.56581 .54739 L
.5758 .54465 L
.58706 .54309 L
.59979 .5426 L
.61421 .54313 L
.63059 .54463 L
.64919 .5471 L
.67035 .55053 L
.69444 .55498 L
.72186 .56048 L
.7531 .56712 L
.78868 .57499 L
.82923 .58422 L
.87545 .59495 L
.92813 .60737 L
.98817 .62167 L
s
.98817 .62167 m
1 .62451 L
s
1 0 0 r
.52927 .5845 m
.53527 .57316 L
s
% Start of user PostScript
0.87817673 2.534967 1.0580118 2.194705 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54179 .56407 m
.54896 .55691 L
s
% Start of user PostScript
1.2536347 1.921981 1.4688162 1.7071708 MAarrowhead1
% End of user PostScript
1 .473 0 r
.63059 .54463 m
.64919 .5471 L
s
% Start of user PostScript
3.9176093 1.3389798 4.4757893 1.4129155 MAarrowhead1
% End of user PostScript
1 .788 0 r
.87545 .59495 m
.92813 .60737 L
s
% Start of user PostScript
11.263505 2.8485679 12.843816 3.2209913 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
32.173659 7.9033871 36.682029 9.0044655 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
91.853545 22.508843 104.72329 25.661091 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
262.22395 64.245497 298.96424 73.246602 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
748.59555 183.40468 853.48145 209.10147 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
2137.086 523.58184 2436.5136 596.941 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
6100.9396 1494.718 6955.7437 1704.1433 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
17416.924 4267.1116 19857.214 4864.9776 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
49721.727 12181.724 56688.249 13888.508 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
141945.28 34776.308 161833.26 39648.825 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
405224.49 99279.188 462000.58 113189.22 MAarrowhead1
% End of user PostScript
0 .573 1 r
.65318 .72009 m
.67911 .6962 L
.70793 .67803 L
.74018 .66487 L
.77642 .65619 L
.81732 .65155 L
.86358 .65066 L
.91603 .65331 L
.97558 .65938 L
s
.97558 .65938 m
1 .6628 L
s
1 0 0 r
.65318 .72009 m
.67911 .6962 L
s
% Start of user PostScript
4.5952807 6.6028311 5.373214 5.8860552 MAarrowhead1
% End of user PostScript
1 .158 0 r
.70793 .67803 m
.74018 .66487 L
s
% Start of user PostScript
6.2379295 5.3408634 7.2052666 4.9462326 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
18.607756 5.4540769 21.23681 5.9498807 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
53.309093 13.270822 60.783388 15.067185 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
152.23056 37.345538 173.56082 42.563234 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
434.5972 106.48703 495.48899 121.40348 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1240.6878 303.96875 1414.5209 346.55706 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3541.9083 867.76109 4038.1659 989.34311 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
10111.418 2477.2773 11528.131 2824.3692 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
28866.013 7072.1154 32910.436 8062.9911 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
82406.513 20189.431 93952.508 23018.177 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
235253.6 57636.661 268215.03 65712.146 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
671600.5 164540.78 765698.6 187594.63 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1917280.9 469729.99 2185911.6 535543.96 MAarrowhead1
% End of user PostScript
0 1 .552 r
.17399 .363 m
.12691 .36093 L
.07347 .35573 L
.01274 .34744 L
s
.01274 .34744 m
0 .34533 L
s
1 0 0 r
.17399 .363 m
.12691 .36093 L
s
% Start of user PostScript
-9.7802985 -4.1100684 -11.192578 -4.1721318 MAarrowhead1
% End of user PostScript
1 .158 0 r
.07347 .35573 m
.01274 .34744 L
s
% Start of user PostScript
-12.795781 -4.3280114 -14.61781 -4.57675 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-36.779584 -9.2910634 -41.939638 -10.508856 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-105.05689 -25.804506 -119.77805 -29.400262 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-299.92955 -73.497585 -341.95313 -83.790718 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-856.24025 -209.78077 -976.20836 -239.17212 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2444.3901 -598.87153 -2786.8742 -682.7793 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6978.2297 -1709.6525 -7955.9511 -1949.1923 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-19921.407 -4880.7048 -22712.599 -5564.5414 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-56871.507 -13933.405 -64839.787 -15885.618 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-162356.42 -39776.999 -185104.22 -45350.163 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-463494.1 -113555.13 -528434.37 -129465.36 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1323180.1 -324176.47 -1508571.1 -369596.91 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3777406.2 -925456.96 -4306659.4 -1055122.9 MAarrowhead1
% End of user PostScript
.332 0 1 r
.36966 .2869 m
.34696 .31135 L
.32182 .33024 L
.29376 .34426 L
.26229 .35398 L
.22684 .35983 L
.18677 .36215 L
.14139 .36116 L
.08989 .35699 L
.03139 .3497 L
s
.03139 .3497 m
0 .34478 L
s
1 0 0 r
.36966 .2869 m
.34696 .31135 L
s
% Start of user PostScript
-3.9103037 -6.3929192 -4.5912341 -5.6593515 MAarrowhead1
% End of user PostScript
1 .158 0 r
.32182 .33024 m
.29376 .34426 L
s
% Start of user PostScript
-5.3455265 -5.0929246 -6.1871114 -4.6723392 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-16.053983 -4.8215274 -18.325058 -5.230767 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-46.017154 -11.482696 -52.469734 -13.029009 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-131.41324 -32.244957 -149.82678 -36.748123 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-375.16796 -91.9269 -427.73311 -104.80335 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1071.0296 -262.4028 -1221.0918 -299.16731 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3057.5691 -749.09894 -3485.9658 -854.05517 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8728.7293 -2138.5213 -9951.7135 -2438.15 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-24918.722 -6105.037 -28410.09 -6960.4151 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-71137.811 -17428.621 -81104.946 -19870.549 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-203083.78 -49755.119 -231537.89 -56726.321 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-579762.3 -142040.6 -660992.93 -161941.95 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1655101.8 -405496.63 -1886998.5 -462310.85 MAarrowhead1
% End of user PostScript
1 .053 0 r
.35933 .60427 m
.34302 .57729 L
.32386 .55342 L
.30155 .53195 L
.27571 .51228 L
.24594 .49384 L
.21171 .47617 L
.17247 .4588 L
.12753 .44132 L
.07614 .42333 L
.01742 .40444 L
s
.01742 .40444 m
0 .3992 L
s
1 0 0 r
.35933 .60427 m
.34302 .57729 L
s
% Start of user PostScript
-4.219969 3.1281435 -4.7093354 2.3187312 MAarrowhead1
% End of user PostScript
1 .158 0 r
.32386 .55342 m
.30155 .53195 L
s
% Start of user PostScript
-5.2841478 1.6026166 -5.9535814 0.9586271 MAarrowhead1
% End of user PostScript
1 .473 0 r
.01742 .40444 m
0 0 rlineto s
.01742 .40444 m
0 .3992 L
s
% Start of user PostScript
-14.477411 -2.8666541 -16.489189 -3.4722375 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-41.18732 -9.9310773 -46.954175 -11.370408 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-117.5478 -28.761469 -134.01653 -32.802489 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-335.56685 -82.2044 -382.58298 -93.724718 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-957.97231 -234.69923 -1092.194 -267.58361 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2734.8129 -670.02321 -3117.9882 -763.90046 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7807.3267 -1912.7793 -8901.2131 -2180.7793 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-22288.308 -5460.5907 -25411.127 -6225.6753 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-63628.521 -15588.86 -72543.528 -17773.019 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-181646.3 -44502.981 -207096.81 -50738.304 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-518562.74 -127046.83 -591218.68 -144847.39 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1480389.7 -362692.5 -1687807.4 -413509.43 MAarrowhead1
% End of user PostScript
0 .528 1 r
.67809 .70072 m
.70689 .68175 L
.73909 .66793 L
.77526 .65867 L
.81606 .65356 L
.86221 .65225 L
.91452 .65454 L
.97389 .66031 L
s
.97389 .66031 m
1 .66387 L
s
1 0 0 r
.67809 .70072 m
.70689 .68175 L
s
% Start of user PostScript
5.3427735 6.0216534 6.2067263 5.4525748 MAarrowhead1
% End of user PostScript
1 .158 0 r
.73909 .66793 m
.77526 .65867 L
s
% Start of user PostScript
7.1726135 5.0378152 8.257884 4.760221 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
21.164481 5.9555428 24.148699 6.5590576 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
60.581809 15.023289 69.074368 17.073985 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
172.98651 42.423817 197.22473 48.355097 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
493.84972 121.00216 563.04336 137.95282 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1409.8412 345.41061 1607.3744 393.80547 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4024.8063 986.07003 4588.7228 1124.2284 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
11489.992 2815.0252 13099.857 3209.4389 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
32801.557 8036.3159 37397.391 9162.286 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
93641.681 22942.024 106761.84 26156.437 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
267327.69 65494.748 304783.03 74671.232 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
763165.41 186974. 870092.69 213170.97 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2178679.8 533772.2 2483935.2 608559.14 MAarrowhead1
% End of user PostScript
.752 1 0 r
.39416 .45033 m
.37875 .45049 L
.36128 .44949 L
.34144 .44736 L
.31889 .44412 L
.29323 .43974 L
.26402 .43418 L
.23076 .42736 L
.19288 .41918 L
.14971 .40953 L
.10052 .39825 L
.04445 .38515 L
s
.04445 .38515 m
0 .37464 L
s
1 0 0 r
.39416 .45033 m
.37875 .45049 L
s
% Start of user PostScript
-3.1751051 -1.4901131 -3.6374063 -1.4853834 MAarrowhead1
% End of user PostScript
1 .158 0 r
.36128 .44949 m
.34144 .44736 L
s
% Start of user PostScript
-4.161592 -1.5153631 -4.7568112 -1.5790551 MAarrowhead1
% End of user PostScript
1 .473 0 r
.10052 .39825 m
.04445 .38515 L
s
% Start of user PostScript
-11.984485 -3.0525869 -13.666484 -3.4453874 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-34.237653 -8.4154906 -39.035368 -9.5863927 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-97.747172 -23.95428 -111.44271 -27.308595 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-279.04936 -68.368042 -318.14707 -77.946652 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-796.62869 -195.17279 -908.24453 -222.51839 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2274.2107 -557.17715 -2592.8509 -635.24334 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6492.4025 -1590.6256 -7402.0545 -1813.4885 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-18534.47 -4540.9081 -21131.339 -5177.1357 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-52912.089 -12963.356 -60325.614 -14779.655 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-151053.1 -37007.708 -172217.19 -42192.866 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-431225.45 -105649.37 -491644.55 -120451.93 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1231059.7 -301607.17 -1403543.8 -343865.42 MAarrowhead1
% End of user PostScript
.044 0 1 r
.519 .28446 m
.51627 .32027 L
.51405 .35017 L
.51227 .37512 L
.51085 .39596 L
.50976 .41337 L
.50895 .42792 L
.50839 .44009 L
.50805 .45027 L
.50791 .4588 L
.50796 .46596 L
.50819 .47198 L
.50861 .47706 L
.5092 .48135 L
.50997 .485 L
.51095 .48813 L
.51212 .49083 L
.51352 .49318 L
.51517 .49527 L
.51709 .49714 L
.51931 .49885 L
.52187 .50045 L
.52482 .50199 L
.5282 .50349 L
.53206 .505 L
.53648 .50656 L
.54154 .50819 L
.54731 .50994 L
.5539 .51182 L
.56141 .51389 L
.56999 .51619 L
.57977 .51874 L
.59093 .52161 L
.60366 .52484 L
.61817 .52848 L
.63471 .53262 L
.65358 .5373 L
.67508 .54262 L
.69961 .54868 L
.72757 .55557 L
.75945 .56341 L
.7958 .57234 L
.83724 .58251 L
.88449 .59411 L
.93836 .60732 L
.99977 .62238 L
s
.99977 .62238 m
1 .62244 L
s
1 0 0 r
.519 .28446 m
.51627 .32027 L
s
% Start of user PostScript
0.56992547 -6.4660575 0.4880579 -5.3917578 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51405 .35017 m
.51227 .37512 L
s
% Start of user PostScript
0.42151182 -4.4950054 0.36799533 -3.7463257 MAarrowhead1
% End of user PostScript
1 .473 0 r
.50796 .46596 m
.50819 .47198 L
s
% Start of user PostScript
0.2387631 -1.0212018 0.24578316 -0.84060946 MAarrowhead1
% End of user PostScript
1 .788 0 r
.51517 .49527 m
.51709 .49714 L
s
% Start of user PostScript
0.45513436 -0.14201162 0.51269671 -0.085908807 MAarrowhead1
% End of user PostScript
.897 1 0 r
.54154 .50819 m
.54731 .50994 L
s
% Start of user PostScript
1.2461349 0.24577309 1.4192738 0.29805362 MAarrowhead1
% End of user PostScript
.581 1 0 r
.61817 .52848 m
.63471 .53262 L
s
% Start of user PostScript
3.5449712 0.85453349 4.0413157 0.97845252 MAarrowhead1
% End of user PostScript
.266 1 0 r
.83724 .58251 m
.88449 .59411 L
s
% Start of user PostScript
10.11723 2.475419 11.534677 2.8232344 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
28.881915 7.0752408 32.928548 8.0667855 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
82.45175 20.200333 94.004079 23.03066 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
235.3827 57.668248 268.36223 65.748173 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
671.96906 164.63106 766.1188 187.69756 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1918.3331 469.98776 2187.1112 535.83785 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
5476.4453 1341.7181 6243.7513 1529.7066 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
15634.122 3830.3285 17824.622 4366.9967 MAarrowhead1
% End of user PostScript
1 .002 0 r
.76568 .22782 m
.79465 .29079 L
.82904 .34584 L
.8694 .39462 L
.91636 .43858 L
.97069 .47896 L
s
.97069 .47896 m
1 .49672 L
s
1 0 0 r
.76568 .22782 m
.79465 .29079 L
s
% Start of user PostScript
7.9704315 -8.1654465 8.8394578 -6.276268 MAarrowhead1
% End of user PostScript
1 .158 0 r
.82904 .34584 m
.8694 .39462 L
s
% Start of user PostScript
9.8712819 -4.62491 11.081915 -3.1614427 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
26.703011 4.8883689 30.403887 6.0690619 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
75.884672 18.203269 86.507384 20.870145 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
216.55363 52.964026 246.89278 60.412162 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
618.19683 151.43558 704.812 172.65967 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1764.8199 432.37233 2012.0891 492.95362 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5038.1959 1234.3467 5744.0987 1407.2917 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
14383.01 3523.8084 16398.217 4017.53 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
41060.527 10059.747 46813.527 11469.22 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
117219.34 28718.503 133642.96 32742.259 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
334637.03 81985.402 381523.1 93472.395 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
955319.69 234051.41 1089169.8 266844.41 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2727240.7 668168.51 3109355. 761785.75 MAarrowhead1
% End of user PostScript
0 1 .024 r
.75796 .28766 m
.78736 .34051 L
.82199 .38708 L
.86241 .42876 L
.90927 .46675 L
.96335 .50212 L
s
.96335 .50212 m
1 .52198 L
s
1 0 0 r
.75796 .28766 m
.78736 .34051 L
s
% Start of user PostScript
7.7388468 -6.3700888 8.6207686 -4.7845856 MAarrowhead1
% End of user PostScript
1 .158 0 r
.82199 .38708 m
.86241 .42876 L
s
% Start of user PostScript
9.6597831 -3.3874676 10.872346 -2.1371175 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
26.369669 5.1094255 30.031252 6.2303397 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
74.996553 18.056762 85.49657 20.681803 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
214.03314 52.363201 244.01955 59.722152 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
611.00485 149.67748 696.61246 170.65406 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1744.2892 427.34325 1988.6818 487.21964 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4979.585 1219.9874 5677.2757 1390.9204 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
14215.688 3482.8148 16207.451 3970.7929 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
40582.857 9942.7186 46268.93 11335.795 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
115855.69 28384.411 132088.25 32361.358 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
330744.09 81031.64 377084.72 92385.001 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
944206.16 231328.62 1076499.1 263740.12 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2695513.8 660395.5 3073182.9 752923.66 MAarrowhead1
% End of user PostScript
.007 1 0 r
.4297 .40729 m
.418 .41693 L
.40497 .42417 L
.39037 .4293 L
.37394 .43253 L
.35538 .43405 L
.33437 .43396 L
.31054 .43234 L
.28347 .42923 L
.2527 .42462 L
.21769 .41849 L
.17783 .41077 L
.13244 .40136 L
.08073 .39011 L
.02181 .37687 L
s
.02181 .37687 m
0 .37184 L
s
1 0 0 r
.4297 .40729 m
.418 .41693 L
s
% Start of user PostScript
-2.1090171 -2.7814425 -2.4599572 -2.4922256 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40497 .42417 m
.39037 .4293 L
s
% Start of user PostScript
-2.8508819 -2.2749632 -3.2889155 -2.121103 MAarrowhead1
% End of user PostScript
1 .473 0 r
.21769 .41849 m
.17783 .41077 L
s
% Start of user PostScript
-8.4693781 -2.4451515 -9.6650871 -2.6767721 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-24.255977 -6.0295839 -27.656616 -6.8483339 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-69.264045 -16.989961 -78.969146 -19.36431 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-197.73884 -48.450413 -225.4442 -55.237375 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-564.50462 -138.30363 -643.59752 -157.68104 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1611.5445 -394.82544 -1837.3384 -450.14445 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-4600.6272 -1127.1445 -5245.2222 -1285.069 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-13133.842 -3217.765 -14974.028 -3668.6068 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-37494.41 -9186.0554 -42747.76 -10473.116 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-107038.81 -26224.293 -122036.04 -29898.585 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-305573.72 -74864.949 -348387.72 -85354.294 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-872349.94 -213723.99 -994575.09 -243668.91 MAarrowhead1
% End of user PostScript
0 1 .225 r
.21069 .68782 m
.17649 .63658 L
.13644 .59101 L
.08992 .54978 L
.03614 .51171 L
s
.03614 .51171 m
0 .49074 L
s
1 0 0 r
.21069 .68782 m
.17649 .63658 L
s
% Start of user PostScript
-8.6793164 5.6345811 -9.7053733 4.0974435 MAarrowhead1
% End of user PostScript
1 .158 0 r
.13644 .59101 m
.08992 .54978 L
s
% Start of user PostScript
-10.906669 2.7303825 -12.302541 1.4933712 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-30.003026 -6.0821481 -34.1757 -7.3146015 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-85.386353 -20.621628 -97.342563 -23.600221 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-243.69795 -59.635571 -277.84081 -68.012091 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-695.69271 -170.4269 -793.16597 -194.31037 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1986.0557 -486.57583 -2264.3224 -554.75123 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5669.7787 -1389.0835 -6464.1727 -1583.7086 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-16186.049 -3965.5493 -18453.88 -4521.1634 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-46207.831 -11320.826 -52682.02 -12906.99 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-131913.83 -32318.623 -150396.3 -36846.793 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-376586.77 -92263.004 -429350.43 -105190. MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1075077.6 -263391.85 -1225706.9 -300295.74 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3069124.7 -751929.4 -3499140.4 -857282.4 MAarrowhead1
% End of user PostScript
.976 0 1 r
.47805 .61183 m
.47785 .59236 L
.47714 .57599 L
.47593 .56218 L
.47422 .55048 L
.472 .54053 L
.46924 .532 L
.4659 .52463 L
.46193 .51819 L
.45727 .51249 L
.45184 .50736 L
.44556 .50265 L
.43833 .49823 L
.43001 .49398 L
.42048 .4898 L
.40956 .48559 L
.39708 .48125 L
.38282 .47668 L
.36653 .4718 L
.34794 .4665 L
.32673 .46068 L
.30253 .45423 L
.27493 .44704 L
.24344 .43896 L
.20754 .42987 L
.1666 .41958 L
.11992 .40794 L
.06669 .39472 L
.00601 .37971 L
s
.00601 .37971 m
0 .37823 L
s
1 0 0 r
.47805 .61183 m
.47785 .59236 L
s
% Start of user PostScript
-0.65847524 3.3549646 -0.66464882 2.7709122 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47714 .57599 m
.47593 .56218 L
s
% Start of user PostScript
-0.68594908 2.2796626 -0.7221327 1.8652868 MAarrowhead1
% End of user PostScript
1 .473 0 r
.45184 .50736 m
.44556 .50265 L
s
% Start of user PostScript
-1.4447926 0.22076548 -1.6331521 0.079401757 MAarrowhead1
% End of user PostScript
1 .788 0 r
.36653 .4718 m
.34794 .4665 L
s
% Start of user PostScript
-4.004024 -0.84602677 -4.5617249 -1.0050196 MAarrowhead1
% End of user PostScript
.897 1 0 r
.11992 .40794 m
.06669 .39472 L
s
% Start of user PostScript
-11.402355 -2.7618668 -12.999165 -3.1583319 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-32.544724 -7.9659518 -37.10439 -9.0842936 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-92.906913 -22.760261 -105.92408 -25.94973 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-265.22971 -64.980337 -302.39109 -74.08487 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-757.17603 -185.50651 -863.26413 -211.4979 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-2161.5814 -529.58309 -2464.441 -603.7831 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-6170.869 -1511.8505 -7035.4709 -1723.6763 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-17616.558 -4316.0215 -20084.818 -4920.7403 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-50291.64 -12321.351 -57338.014 -14047.699 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-143572.26 -35174.917 -163688.2 -40103.282 MAarrowhead1
% End of user PostScript
.453 1 0 r
.54981 .40014 m
.55405 .41974 L
.55933 .43653 L
.56574 .45102 L
.57335 .46367 L
.5823 .47486 L
.59272 .48492 L
.60479 .49414 L
.6187 .50277 L
.63469 .51104 L
.65302 .51917 L
.67401 .52735 L
.69802 .53576 L
.72545 .5446 L
.75678 .55404 L
.79254 .56427 L
.83335 .57549 L
.8799 .58792 L
.933 .60178 L
.99357 .61733 L
s
.99357 .61733 m
1 .61897 L
s
1 0 0 r
.54981 .40014 m
.55405 .41974 L
s
% Start of user PostScript
1.4944156 -2.9957502 1.6214932 -2.4076577 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55933 .43653 m
.56574 .45102 L
s
% Start of user PostScript
1.7800111 -1.9041331 1.9721155 -1.4693642 MAarrowhead1
% End of user PostScript
1 .473 0 r
.65302 .51917 m
.67401 .52735 L
s
% Start of user PostScript
4.5906612 0.57520442 5.220407 0.82052568 MAarrowhead1
% End of user PostScript
1 .788 0 r
.933 .60178 m
.99357 .61733 L
s
% Start of user PostScript
12.990124 3.0535295 14.807015 3.5200394 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
37.057061 9.04861 42.248392 10.325495 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
105.78391 25.909733 120.60514 29.542084 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
301.98975 73.985215 344.30157 84.351801 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
862.11811 211.21682 982.90967 240.81057 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
2461.1693 602.98147 2806.0043 687.46536 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
7026.1308 1721.388 8010.5636 1962.572 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
20058.154 4914.2076 22868.507 5602.7384 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
57261.893 14029.049 65284.87 15994.663 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
163470.9 40050.042 186374.84 45661.463 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
466675.69 114334.61 532061.73 130354.06 MAarrowhead1
% End of user PostScript
.617 1 0 r
.35201 .40794 m
.32991 .41177 L
.30494 .41337 L
.27666 .41287 L
.24457 .41038 L
.20812 .40593 L
.16667 .39951 L
.11951 .39108 L
.06582 .38052 L
.00466 .36771 L
s
.00466 .36771 m
0 .36669 L
s
1 0 0 r
.35201 .40794 m
.32991 .41177 L
s
% Start of user PostScript
-4.4396705 -2.7617881 -5.1026984 -2.646886 MAarrowhead1
% End of user PostScript
1 .158 0 r
.30494 .41337 m
.27666 .41287 L
s
% Start of user PostScript
-5.8518334 -2.599027 -6.7002649 -2.6138305 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-16.950227 -4.4263994 -19.331826 -4.9645548 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-48.446801 -11.933618 -55.236266 -13.58638 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-138.3191 -33.902989 -157.69939 -38.648622 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-394.87567 -96.747292 -450.20188 -110.30152 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1127.2893 -276.18447 -1285.2341 -314.88048 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3218.1788 -788.44755 -3669.0785 -898.91706 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-9187.2367 -2250.8546 -10474.462 -2566.2224 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-26227.666 -6425.7256 -29902.43 -7326.0355 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-74874.577 -18344.121 -85365.271 -20914.32 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-213751.47 -52368.683 -243700.24 -59706.071 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-610216.37 -149501.79 -695713.93 -170448.52 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1742041.9 -426796.77 -1986119.8 -486595.37 MAarrowhead1
% End of user PostScript
0 .112 1 r
.4751 .58049 m
.47373 .56581 L
.47182 .55337 L
.46935 .54278 L
.46629 .5337 L
.46259 .52584 L
.45821 .51897 L
.45307 .51287 L
.44709 .50737 L
.44017 .5023 L
.4322 .49754 L
.42305 .49296 L
.41256 .48843 L
.40055 .48385 L
.38681 .47913 L
.37112 .47415 L
.35321 .46881 L
.33275 .46301 L
.30942 .45663 L
.2828 .44956 L
.25243 .44166 L
.2178 .43279 L
.17831 .4228 L
.13328 .4115 L
.08193 .3987 L
.02339 .38417 L
s
.02339 .38417 m
0 .37838 L
s
1 0 0 r
.4751 .58049 m
.47373 .56581 L
s
% Start of user PostScript
-0.74692283 2.4145726 -0.78798092 1.9741773 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47182 .55337 m
.46935 .54278 L
s
% Start of user PostScript
-0.84532712 1.6010848 -0.91949817 1.2833525 MAarrowhead1
% End of user PostScript
1 .473 0 r
.4322 .49754 m
.42305 .49296 L
s
% Start of user PostScript
-2.0339364 -0.073738566 -2.3085173 -0.21134869 MAarrowhead1
% End of user PostScript
1 .788 0 r
.30942 .45663 m
.2828 .44956 L
s
% Start of user PostScript
-5.7174078 -1.3010618 -6.5160344 -1.5132396 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-16.301108 -3.9703307 -18.584487 -4.533632 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-46.531391 -11.394601 -53.05078 -12.992749 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-132.83637 -32.543354 -151.44807 -37.103398 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-379.22017 -92.90788 -432.35279 -105.92531 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-1082.5953 -265.23361 -1234.278 -302.39558 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-3090.5863 -757.18744 -3523.6091 -863.27716 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-8822.9865 -2161.614 -10059.177 -2464.4783 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-25187.807 -6170.9622 -28716.876 -7035.5772 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-71905.993 -17616.824 -81980.759 -20085.122 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-205276.78 -50292.4 -234038.16 -57338.88 MAarrowhead1
% End of user PostScript
.119 0 1 r
.2015 .67939 m
.16585 .62882 L
.1242 .58371 L
.07584 .54275 L
.02001 .50477 L
s
.02001 .50477 m
0 .49355 L
s
1 0 0 r
.2015 .67939 m
.16585 .62882 L
s
% Start of user PostScript
-8.9551361 5.3817434 -10.024374 3.8647189 MAarrowhead1
% End of user PostScript
1 .158 0 r
.1242 .58371 m
.07584 .54275 L
s
% Start of user PostScript
-11.274149 2.511388 -12.724666 1.2823539 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-31.079157 -6.3760792 -35.40335 -7.6406377 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-88.464839 -21.382961 -100.85255 -24.466093 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-252.48788 -61.790756 -287.86234 -70.468739 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-720.7865 -176.57522 -821.77567 -201.32002 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2057.6934 -504.12701 -2345.9972 -574.76149 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5874.2896 -1439.1883 -6697.3376 -1640.8336 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-16769.885 -4108.588 -19119.517 -4684.2433 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-47874.563 -11729.172 -54582.279 -13372.549 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-136672. -33484.367 -155821.15 -38175.869 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-390170.38 -95590.962 -444837.24 -108984.23 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1113856. -272892.48 -1269918.6 -311127.51 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3179829. -779051.75 -3625355.6 -888204.87 MAarrowhead1
% End of user PostScript
.633 1 0 r
.67424 .41708 m
.69558 .44311 L
.72041 .46656 L
.74915 .48809 L
.78228 .50829 L
.82034 .5277 L
.86398 .5468 L
.91393 .56606 L
.97107 .58592 L
s
.97107 .58592 m
1 .59517 L
s
1 0 0 r
.67424 .41708 m
.69558 .44311 L
s
% Start of user PostScript
5.227152 -2.4877109 5.867273 -1.7065837 MAarrowhead1
% End of user PostScript
1 .158 0 r
.72041 .46656 m
.74915 .48809 L
s
% Start of user PostScript
6.6123654 -1.0031656 7.4746049 -0.35733901 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
18.326683 3.8740641 20.879359 4.6015062 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
52.189696 12.641746 59.498465 14.45634 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
148.96048 36.461061 169.83054 41.579809 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
425.24432 104.17603 484.82521 118.77455 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1213.9832 297.42157 1384.0746 339.09394 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3465.6712 849.08206 3951.2471 968.04727 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
9893.7763 2423.9553 11279.996 2763.5763 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
28244.691 6919.8927 32202.061 7889.4404 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
80632.767 19754.866 91930.242 22522.725 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
230189.92 56396.069 262441.88 64297.736 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
657144.74 160999.15 749217.44 183556.77 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1876012.7 459619.36 2138861.3 524016.73 MAarrowhead1
% End of user PostScript
1 0 .101 r
.53818 .61082 m
.54602 .59593 L
.55454 .58399 L
.56391 .57459 L
.57431 .56737 L
.58592 .56207 L
.59896 .55847 L
.61367 .5564 L
.63029 .55575 L
.64913 .55642 L
.67051 .55836 L
.69481 .56157 L
.72244 .56604 L
.75389 .57184 L
.7897 .57901 L
.83049 .58767 L
.87696 .59795 L
.92991 .60999 L
.99026 .62401 L
s
.99026 .62401 m
1 .6263 L
s
1 0 0 r
.53818 .61082 m
.54602 .59593 L
s
% Start of user PostScript
1.1455366 3.3246666 1.3805613 2.877949 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55454 .58399 m
.56391 .57459 L
s
% Start of user PostScript
1.6361691 2.5198207 1.9172894 2.2376485 MAarrowhead1
% End of user PostScript
1 .473 0 r
.67051 .55836 m
.69481 .56157 L
s
% Start of user PostScript
5.1154138 1.7508093 5.8443164 1.8469616 MAarrowhead1
% End of user PostScript
1 .788 0 r
.99026 .62401 m
0 0 rlineto s
.99026 .62401 m
1 .6263 L
s
% Start of user PostScript
14.707819 3.720212 16.771396 4.2064296 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
42.012297 10.32036 47.899321 11.758125 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
119.9422 29.392039 136.74748 33.508234 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
342.41159 83.891666 390.38699 95.645293 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
977.51478 239.48952 1114.4746 273.04434 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
2790.6032 683.69227 3181.5952 779.48453 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
7966.5965 1951.8002 9082.7982 2225.2674 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
22742.99 5571.987 25929.515 6352.6794 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
64926.545 15906.874 74023.419 18135.589 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
185351.9 45410.844 211321.59 51773.367 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
529141.44 129638.59 603279.56 147802.29 MAarrowhead1
% End of user PostScript
1 .465 0 r
.40563 .16987 m
.38489 .21565 L
.36249 .2526 L
.338 .282 L
.31093 .30491 L
.2808 .32217 L
.24705 .33447 L
.20907 .34232 L
.16619 .34613 L
.11766 .34618 L
.06262 .34266 L
.00011 .33566 L
s
.00011 .33566 m
0 .33564 L
s
1 0 0 r
.40563 .16987 m
.38489 .21565 L
s
% Start of user PostScript
-2.8310787 -9.9040313 -3.4532306 -8.5305767 MAarrowhead1
% End of user PostScript
1 .158 0 r
.36249 .2526 m
.338 .282 L
s
% Start of user PostScript
-4.1251959 -7.4221172 -4.8601427 -6.5399995 MAarrowhead1
% End of user PostScript
1 .473 0 r
.06262 .34266 m
.00011 .33566 L
s
% Start of user PostScript
-13.121494 -4.7201814 -14.996806 -4.9302242 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-37.774952 -9.608273 -43.076264 -10.848522 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-107.91385 -26.521677 -123.03571 -30.212753 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-308.08919 -75.500723 -351.25611 -86.073305 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-879.53518 -215.48893 -1002.7672 -245.67977 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2510.8925 -615.16471 -2862.6942 -701.35526 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7168.0804 -1756.1656 -8172.4018 -2002.2223 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-20463.391 -5013.49 -23330.522 -5715.9312 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-58418.762 -14312.48 -66603.828 -16317.804 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-166773.52 -40859.177 -190140.19 -46583.966 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-476103.99 -116644.52 -542811.03 -132987.62 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1359178.7 -332996.06 -1549613.5 -379652.21 MAarrowhead1
% End of user PostScript
1 .289 0 r
.49735 .34613 m
.49323 .37051 L
.48915 .39069 L
.48502 .40734 L
.48074 .42104 L
.47623 .43223 L
.47138 .44131 L
.4661 .44858 L
.4603 .4543 L
.45386 .45868 L
.44666 .46189 L
.43857 .46406 L
.42945 .46528 L
.41914 .46564 L
.40745 .46519 L
.39419 .46395 L
.37912 .46194 L
.36197 .45914 L
.34246 .45552 L
.32025 .45105 L
.29494 .44567 L
.26611 .43928 L
.23325 .4318 L
.19581 .4231 L
.15313 .41303 L
.10448 .40144 L
.04903 .38813 L
s
.04903 .38813 m
0 .3763 L
s
1 0 0 r
.49735 .34613 m
.49323 .37051 L
s
% Start of user PostScript
-0.079448626 -4.6159961 -0.20311212 -3.8847911 MAarrowhead1
% End of user PostScript
1 .158 0 r
.48915 .39069 m
.48502 .40734 L
s
% Start of user PostScript
-0.32545909 -3.2794208 -0.44939366 -2.7796964 MAarrowhead1
% End of user PostScript
1 .473 0 r
.44666 .46189 m
.43857 .46406 L
s
% Start of user PostScript
-1.6003066 -1.1433739 -1.8429193 -1.0783462 MAarrowhead1
% End of user PostScript
1 .788 0 r
.34246 .45552 m
.32025 .45105 L
s
% Start of user PostScript
-4.7261437 -1.3343053 -5.3926436 -1.4683708 MAarrowhead1
% End of user PostScript
.897 1 0 r
.04903 .38813 m
0 0 rlineto s
.04903 .38813 m
0 .3763 L
s
% Start of user PostScript
-13.52917 -3.3560415 -15.42576 -3.8138398 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-38.63168 -9.4744104 -44.044612 -10.798956 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-110.28752 -27.022505 -125.73998 -30.80795 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-314.8486 -77.137813 -358.96212 -87.945449 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-898.82793 -220.21117 -1024.7629 -251.06497 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-2565.9684 -628.65715 -2925.4868 -716.73844 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-7325.3105 -1794.6864 -8351.6615 -2046.1403 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-20912.251 -5123.4596 -23842.271 -5841.3087 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-59700.163 -14626.42 -68064.766 -16675.731 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-170431.65 -41755.413 -194310.87 -47605.774 MAarrowhead1
% End of user PostScript
1 .968 0 r
.28606 .56682 m
.25901 .54044 L
.22768 .51628 L
.19155 .49368 L
.15003 .47204 L
.10241 .4508 L
.04788 .42945 L
s
.04788 .42945 m
0 .4126 L
s
1 0 0 r
.28606 .56682 m
.25901 .54044 L
s
% Start of user PostScript
-6.4181632 2.0046699 -7.229839 1.2131956 MAarrowhead1
% End of user PostScript
1 .158 0 r
.22768 .51628 m
.19155 .49368 L
s
% Start of user PostScript
-8.1697473 0.48848246 -9.2534512 -0.18954735 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-22.800613 -5.0014271 -25.980898 -5.8774534 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-64.9684 -15.779843 -74.067777 -18.031916 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-185.44259 -45.400827 -211.4242 -51.771611 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-529.39357 -129.6928 -603.56684 -147.86635 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1511.3079 -370.26563 -1723.0575 -422.14416 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4314.4719 -1057.0366 -4918.9735 -1205.1383 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-12316.927 -3017.6224 -14042.655 -3440.4222 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-35162.287 -8614.69 -40088.883 -9821.6961 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-100381.08 -24593.163 -114445.49 -28038.917 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-286567.27 -70208.408 -326718.28 -80045.325 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-818090.46 -200430.53 -932713.3 -228512.89 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2335479.5 -572187.81 -2662704.1 -652357.18 MAarrowhead1
% End of user PostScript
.176 0 1 r
.21502 .37121 m
.17365 .37085 L
.12672 .3675 L
.07341 .36124 L
.0128 .35206 L
s
.0128 .35206 m
0 .34981 L
s
1 0 0 r
.21502 .37121 m
.17365 .37085 L
s
% Start of user PostScript
-8.5494581 -3.8635929 -9.790633 -3.8746112 MAarrowhead1
% End of user PostScript
1 .158 0 r
.12672 .3675 m
.07341 .36124 L
s
% Start of user PostScript
-11.198534 -3.9750292 -12.797711 -4.1628178 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-32.227815 -8.1848917 -36.75034 -9.2449995 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-92.064417 -22.62349 -104.96525 -25.77292 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-262.83917 -64.411011 -299.66601 -73.430873 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-750.35495 -183.8392 -855.48745 -209.59583 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2142.1094 -524.8134 -2442.2409 -598.34486 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6115.2807 -1498.2317 -6972.0941 -1708.1493 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-17457.865 -4277.1421 -19903.891 -4876.4134 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-49838.605 -12210.358 -56821.503 -13921.155 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-142278.94 -34858.055 -162213.67 -39742.025 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-406177.02 -99512.557 -463086.58 -113455.28 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1159551.6 -284087.83 -1322016.7 -323891.44 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3310280.7 -811012.15 -3774084.9 -924643.25 MAarrowhead1
% End of user PostScript
0 1 .189 r
.50579 .54566 m
.50769 .53879 L
.50967 .53316 L
.51177 .52858 L
.51405 .52488 L
.51655 .52194 L
.5193 .51965 L
.52237 .51793 L
.52581 .51671 L
.52968 .51594 L
.53405 .51557 L
.539 .51559 L
.54461 .51596 L
.55099 .51669 L
.55823 .51777 L
.56648 .51921 L
.57587 .52103 L
.58656 .52324 L
.59873 .52589 L
.61261 .52901 L
.62842 .53264 L
.64644 .53686 L
.66698 .54173 L
.6904 .54733 L
.71709 .55376 L
.74752 .56112 L
.78222 .56954 L
.82177 .57917 L
.86686 .59016 L
.91827 .60271 L
.97688 .61703 L
s
.97688 .61703 m
1 .62268 L
s
1 0 0 r
.50579 .54566 m
.50769 .53879 L
s
% Start of user PostScript
0.17373191 1.3696687 0.23056361 1.1637324 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50967 .53316 m
.51177 .52858 L
s
% Start of user PostScript
0.28997541 0.99485212 0.35322055 0.85730068 MAarrowhead1
% End of user PostScript
1 .473 0 r
.53405 .51557 m
.539 .51559 L
s
% Start of user PostScript
1.0216046 0.46720604 1.1700523 0.46763938 MAarrowhead1
% End of user PostScript
1 .788 0 r
.59873 .52589 m
.61261 .52901 L
s
% Start of user PostScript
2.9619719 0.77660992 3.3782214 0.87015224 MAarrowhead1
% End of user PostScript
.897 1 0 r
.78222 .56954 m
.82177 .57917 L
s
% Start of user PostScript
8.4665029 2.0862355 9.6530393 2.3749533 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
24.172628 5.9250536 27.559529 6.7543724 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
69.008457 16.907593 78.677264 19.276322 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
197.00505 48.265998 224.60748 55.028511 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
562.40882 137.78907 641.20805 157.09472 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
1605.5612 393.35929 1830.5167 448.47294 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
4583.546 1122.9596 5225.7477 1280.2977 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
13085.079 3205.8181 14918.432 3654.986 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
37355.201 9151.9494 42589.046 10434.231 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
106641.39 26126.928 121582.94 29787.578 MAarrowhead1
% End of user PostScript
0 1 .033 r
.70729 .62944 m
.73826 .624 L
.77325 .6217 L
.81288 .62234 L
.85783 .62578 L
.9089 .63198 L
.96697 .64094 L
s
.96697 .64094 m
1 .64683 L
s
1 0 0 r
.70729 .62944 m
.73826 .624 L
s
% Start of user PostScript
6.2188047 3.8832474 7.1478917 3.7199508 MAarrowhead1
% End of user PostScript
1 .158 0 r
.77325 .6217 m
.81288 .62234 L
s
% Start of user PostScript
8.1975828 3.6509654 9.3863613 3.6700903 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
23.746966 6.2036438 27.083601 6.9572168 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
67.873594 16.719455 77.385596 19.034874 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
193.78411 47.497983 220.93576 54.146561 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
553.21812 135.54233 630.72976 154.53169 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1579.3247 386.93256 1800.6043 441.14542 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4508.6465 1104.6096 5140.354 1259.3767 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
12871.256 3153.432 14674.65 3595.2601 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
36744.781 9002.3978 41893.101 10263.726 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
104898.77 25699.989 119596.16 29300.82 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
299464.36 73368.168 341422.38 83647.799 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
854908.97 209450.99 974690.46 238797.21 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2440588.8 597939.37 2782540.2 681716.79 MAarrowhead1
% End of user PostScript
1 .045 0 r
.75862 .34701 m
.78956 .39043 L
.82571 .4292 L
.86766 .46442 L
.9161 .49711 L
.97183 .52813 L
s
.97183 .52813 m
1 .54141 L
s
1 0 0 r
.75862 .34701 m
.78956 .39043 L
s
% Start of user PostScript
7.7586616 -4.5896772 8.6868287 -3.2869985 MAarrowhead1
% End of user PostScript
1 .158 0 r
.82571 .4292 m
.86766 .46442 L
s
% Start of user PostScript
9.7713664 -2.1241498 11.029823 -1.0673194 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
26.947485 5.5412035 30.697131 6.6356134 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
76.706974 18.543956 87.448307 21.216829 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
218.93034 53.579005 249.60328 61.103505 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
624.98869 153.10724 712.55566 174.56325 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1784.2109 437.12488 2034.197 498.37151 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5093.5535 1247.9097 5807.2124 1422.7548 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
14541.045 3562.5266 16578.394 4061.6731 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
41511.683 10170.279 47327.895 11595.239 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
118507.29 29034.05 135111.38 33102.017 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
338313.88 82886.224 385715.12 94499.432 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
965816.36 236623.07 1101137.1 269776.39 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2757206.5 675510.07 3143519.3 770155.95 MAarrowhead1
% End of user PostScript
.696 0 1 r
.68282 .43812 m
.70582 .46143 L
.73248 .4827 L
.76323 .50254 L
.7986 .52147 L
.83917 .53997 L
.88564 .5585 L
.93879 .57748 L
.99953 .59734 L
s
.99953 .59734 m
1 .59748 L
s
1 0 0 r
.68282 .43812 m
.70582 .46143 L
s
% Start of user PostScript
5.4845344 -1.8564685 6.1746275 -1.1572287 MAarrowhead1
% End of user PostScript
1 .158 0 r
.73248 .4827 m
.76323 .50254 L
s
% Start of user PostScript
6.9743893 -0.5189527 7.897035 0.076148326 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
19.443153 4.2404666 22.154531 4.9914049 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
55.396468 13.449205 63.155073 15.370395 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
158.11973 38.710178 180.27321 44.142516 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
451.39316 110.58365 514.6378 126.07958 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1288.633 315.71091 1469.1836 359.94571 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3678.781 901.29361 4194.2158 1027.5742 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
10502.161 2573.0083 11973.621 2933.5131 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
29981.503 7345.4083 34182.219 8374.5751 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
85591.008 20969.626 97583.184 23907.685 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
244344.68 59863.957 278579.86 68251.509 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
697553.66 170899.25 795288.06 194843.98 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1991371.8 487882.11 2270383.4 556239.38 MAarrowhead1
% End of user PostScript
1 0 .287 r
.3658 .66992 m
.35197 .63294 L
.33537 .60084 L
.31576 .57264 L
.29282 .54751 L
.2662 .52471 L
.23545 .50359 L
.20006 .48359 L
.15943 .46418 L
.11288 .44489 L
.05962 .42526 L
s
.05962 .42526 m
0 .40527 L
s
1 0 0 r
.3658 .66992 m
.35197 .63294 L
s
% Start of user PostScript
-4.0259252 5.0977165 -4.441049 3.9880725 MAarrowhead1
% End of user PostScript
1 .158 0 r
.33537 .60084 m
.31576 .57264 L
s
% Start of user PostScript
-4.9390122 3.0251172 -5.5273333 2.1793445 MAarrowhead1
% End of user PostScript
1 .473 0 r
.05962 .42526 m
0 0 rlineto s
.05962 .42526 m
0 .40527 L
s
% Start of user PostScript
-13.211463 -2.2423438 -15.038179 -2.8546329 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-37.507402 -8.9557393 -42.756857 -10.280529 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-107.02692 -26.166554 -122.02114 -29.849192 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-305.52827 -74.840942 -348.3356 -85.330783 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-872.21751 -213.68852 -994.42403 -243.62937 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2490.0005 -610.04442 -2838.875 -695.5181 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7108.4376 -1741.5528 -8104.4024 -1985.5622 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-20293.123 -4971.7745 -23136.397 -5668.371 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-57932.681 -14193.391 -66049.643 -16182.03 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-165385.86 -40519.204 -188558.11 -46196.359 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-472142.51 -115673.97 -538294.51 -131881.08 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1347869.5 -330225.33 -1536719.8 -376493.27 MAarrowhead1
% End of user PostScript
1 0 .051 r
.50336 .76476 m
.51029 .72274 L
.51712 .68793 L
.52402 .65918 L
.53114 .63553 L
.53863 .61617 L
.54665 .60046 L
.55537 .58785 L
.56495 .57789 L
.57556 .57022 L
.58742 .56456 L
.60072 .56067 L
.61571 .55838 L
.63266 .55756 L
.65186 .55811 L
.67365 .55999 L
.69841 .56316 L
.72656 .56765 L
.75861 .57349 L
.79509 .58075 L
.83664 .58953 L
.88398 .59996 L
.93792 .6122 L
.9994 .62645 L
s
.9994 .62645 m
1 .62659 L
s
1 0 0 r
.50336 .76476 m
.51029 .72274 L
s
% Start of user PostScript
0.10067271 7.9429232 0.30863218 6.6820637 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51712 .68793 m
.52402 .65918 L
s
% Start of user PostScript
0.5136133 5.6378004 0.72051931 4.7753306 MAarrowhead1
% End of user PostScript
1 .473 0 r
.58742 .56456 m
.60072 .56067 L
s
% Start of user PostScript
2.6224885 1.936742 3.0216114 1.8201114 MAarrowhead1
% End of user PostScript
1 .788 0 r
.75861 .57349 m
.79509 .58075 L
s
% Start of user PostScript
7.7581521 2.2046253 8.8525885 2.4224143 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
22.211671 5.5131707 25.3255 6.2642312 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
63.424708 15.555681 72.311568 17.730168 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
181.06797 44.365225 206.43755 50.580068 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
516.91255 126.64346 589.3373 144.38723 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
1475.6789 361.53859 1682.4366 412.19378 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
4212.7589 1032.1176 4803.0096 1176.7278 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
12026.558 2946.4826 13711.602 3359.315 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
34333.342 8411.6002 39143.795 9590.1514 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
98014.612 24013.384 111747.46 27377.904 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
279811.5 68553.258 319015.95 78158.27 MAarrowhead1
% End of user PostScript
.552 0 1 r
.56473 .58612 m
.57551 .57713 L
.58753 .57036 L
.60099 .56555 L
.61614 .5625 L
.63325 .56105 L
.65261 .56109 L
.67457 .56254 L
.69952 .56538 L
.72788 .56959 L
.76014 .57522 L
.79687 .58231 L
.8387 .59098 L
.88635 .60133 L
.94065 .61352 L
s
.94065 .61352 m
1 .62718 L
s
1 0 0 r
.56473 .58612 m
.57551 .57713 L
s
% Start of user PostScript
1.9417693 2.5836796 2.2654378 2.313756 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58753 .57036 m
.60099 .56555 L
s
% Start of user PostScript
2.6259058 2.1107034 3.0297459 1.9665472 MAarrowhead1
% End of user PostScript
1 .473 0 r
.76014 .57522 m
.79687 .58231 L
s
% Start of user PostScript
7.8042235 2.2565631 8.9061102 2.4694429 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
22.351722 5.5570279 25.485408 6.3113719 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
63.826528 15.656367 72.769743 17.84429 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
182.21556 44.646907 207.74593 50.901059 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
520.18877 127.44626 593.07257 145.30247 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1485.0319 363.83008 1693.1 414.80633 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
4239.4598 1038.6592 4833.4515 1184.186 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
12102.783 2965.1577 13798.507 3380.6066 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
34550.95 8464.9136 39391.892 9650.9346 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
98635.837 24165.583 112455.73 27551.428 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
281584.97 68987.754 321037.9 78653.644 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
803867.01 196945.81 916497.01 224539.93 MAarrowhead1
% End of user PostScript
1 .746 0 r
.7925 .56864 m
.83341 .57917 L
.88006 .59101 L
.93326 .6044 L
.99392 .61955 L
s
.99392 .61955 m
1 .62106 L
s
1 0 0 r
.7925 .56864 m
.83341 .57917 L
s
% Start of user PostScript
8.7750148 2.0593373 10.002268 2.3750088 MAarrowhead1
% End of user PostScript
1 .158 0 r
.88006 .59101 m
.93326 .6044 L
s
% Start of user PostScript
11.401839 2.7304134 12.99781 3.1318627 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
32.53668 7.9566254 37.09504 9.0758656 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
92.882407 22.75253 105.8961 25.941433 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
265.15939 64.962704 302.31091 74.064887 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
756.97519 185.45722 863.03516 211.44173 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2161.008 529.44259 2463.7873 603.62293 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6169.2322 1511.4495 7033.6047 1723.2191 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
17611.885 4314.8767 20079.491 4919.435 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
50278.3 12318.083 57322.805 14043.972 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
143534.18 35165.586 163644.78 40092.645 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
409760.47 100390.5 467172.11 114456.23 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1169781.6 286594.16 1333680. 326748.93 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3339485.3 818167.22 3807381.4 932800.82 MAarrowhead1
% End of user PostScript
.18 0 1 r
.71376 .56362 m
.74399 .56916 L
.77841 .57604 L
.8176 .58435 L
.86226 .59421 L
.91315 .60577 L
.97115 .61923 L
s
.97115 .61923 m
1 .62602 L
s
1 0 0 r
.71376 .56362 m
.74399 .56916 L
s
% Start of user PostScript
6.4129155 1.9087012 7.3196944 2.0749387 MAarrowhead1
% End of user PostScript
1 .158 0 r
.77841 .57604 m
.8176 .58435 L
s
% Start of user PostScript
8.3521533 2.281232 9.5281279 2.530416 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
23.892964 5.9089008 27.241964 6.7202586 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
68.221058 16.726977 77.779843 19.066714 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
194.75977 47.718795 222.04768 54.403775 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
555.99961 136.2195 633.90086 155.30504 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1587.2644 388.87676 1809.6563 443.36232 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4531.3124 1110.1625 5166.1956 1265.7076 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
12935.962 3169.2849 14748.423 3613.3341 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
36929.504 9047.6547 42103.706 10315.324 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
105426.12 25829.188 120197.4 29448.121 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
300969.82 73737.005 343138.78 84068.313 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
859206.77 210503.94 979590.43 239997.7 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2452858.1 600945.33 2796528.6 685143.92 MAarrowhead1
% End of user PostScript
.974 0 1 r
.551 .19175 m
.55029 .24471 L
.55079 .28917 L
.55244 .32656 L
.55522 .35811 L
.55916 .38482 L
.56427 .40755 L
.57063 .42704 L
.57831 .44387 L
.58744 .45859 L
.59815 .47162 L
.61062 .48336 L
.62505 .49414 L
.64168 .50426 L
.66078 .51399 L
.68269 .52356 L
.70776 .53322 L
.73644 .54317 L
.76921 .55365 L
.80663 .56485 L
.84934 .57702 L
.89807 .59038 L
.95367 .60518 L
s
.95367 .60518 m
1 .61726 L
s
1 0 0 r
.551 .19175 m
.55029 .24471 L
s
% Start of user PostScript
1.5299905 -9.2475968 1.508782 -7.6586536 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55079 .28917 m
.55244 .32656 L
s
% Start of user PostScript
1.5236295 -6.324976 1.5731192 -5.2031574 MAarrowhead1
% End of user PostScript
1 .473 0 r
.59815 .47162 m
.61062 .48336 L
s
% Start of user PostScript
2.9445738 -0.85137124 3.3186338 -0.49916556 MAarrowhead1
% End of user PostScript
1 .788 0 r
.76921 .55365 m
.80663 .56485 L
s
% Start of user PostScript
8.0762322 1.6093626 9.1987539 1.9455594 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
22.978511 5.5429761 26.195912 6.3455987 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
65.58072 16.046784 74.768751 18.301207 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
187.21516 45.862558 213.4458 52.289805 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
534.45966 130.94042 609.3429 149.28685 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
1525.7719 373.81079 1739.5481 426.18558 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
4355.7639 1067.1534 4966.051 1216.6725 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
12434.808 3046.503 14177.051 3473.3492 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
35498.811 8697.1376 40472.558 9915.6956 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
101341.78 24828.534 115540.8 28307.266 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
289309.89 70880.344 329845.17 80811.406 MAarrowhead1
% End of user PostScript
1 0 .477 r
.3864 .81217 m
.3788 .75398 L
.36877 .70452 L
.35617 .66223 L
.34086 .62576 L
.32259 .59399 L
.3011 .56596 L
.27604 .54082 L
.24701 .51785 L
.21351 .49642 L
.175 .47595 L
.13083 .45592 L
.08024 .43584 L
.02237 .41526 L
s
.02237 .41526 m
0 .40797 L
s
1 0 0 r
.3864 .81217 m
.3788 .75398 L
s
% Start of user PostScript
-3.4081049 9.3649988 -3.6359002 7.6193704 MAarrowhead1
% End of user PostScript
1 .158 0 r
.36877 .70452 m
.35617 .66223 L
s
% Start of user PostScript
-3.936982 6.1357373 -4.3147646 4.8668841 MAarrowhead1
% End of user PostScript
1 .473 0 r
.175 .47595 m
.13083 .45592 L
s
% Start of user PostScript
-9.7498651 -0.72151334 -11.075105 -1.322395 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-27.484134 -6.3420945 -31.325358 -7.3480401 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-78.379418 -19.110883 -89.358925 -21.816068 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-223.73779 -54.793728 -255.08521 -62.47736 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-638.72072 -156.48023 -728.2119 -178.40623 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1823.4149 -446.7318 -2078.8939 -509.32385 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-5205.4731 -1275.3302 -5934.8131 -1454.0171 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-14860.552 -3640.8054 -16942.667 -4150.9195 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-42423.811 -10393.749 -48367.821 -11850.019 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-121111.23 -29672.009 -138080.15 -33829.361 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-345747.58 -84707.466 -394190.36 -96575.848 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-987038.04 -241822.34 -1125332.2 -275704.13 MAarrowhead1
% End of user PostScript
1 0 .611 r
.65894 .42489 m
.67842 .44856 L
.70109 .46988 L
.72732 .48946 L
.75755 .50784 L
.79228 .5255 L
.8321 .5429 L
.87769 .56044 L
.92982 .57853 L
.98939 .59756 L
s
.98939 .59756 m
1 .60073 L
s
1 0 0 r
.65894 .42489 m
.67842 .44856 L
s
% Start of user PostScript
4.7682628 -2.2531597 5.3525834 -1.543187 MAarrowhead1
% End of user PostScript
1 .158 0 r
.70109 .46988 m
.72732 .48946 L
s
% Start of user PostScript
6.0326499 -0.90366039 6.8195786 -0.31629952 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
16.72238 3.5377268 19.051666 4.201043 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
47.62164 11.535898 54.290705 13.191559 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
135.92242 33.269888 154.96578 37.940583 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
388.024 95.057864 442.38996 108.37861 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1107.727 271.38919 1262.9308 309.4141 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3162.3317 774.76454 3605.4067 883.31709 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
9027.8047 2211.794 10292.692 2521.689 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
25772.52 6314.2159 29383.514 7198.9021 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
73575.23 18025.784 83883.872 20551.381 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
210042.11 51459.896 239471.16 58669.954 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
599626.9 146907.39 683640.76 167490.62 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1711811.1 419390.3 1951653.4 478151.17 MAarrowhead1
% End of user PostScript
.336 1 0 r
.4195 .63469 m
.412 .60727 L
.40282 .58368 L
.39184 .56318 L
.37888 .54515 L
.36374 .52904 L
.34618 .5144 L
.3259 .5008 L
.30257 .48789 L
.2758 .47532 L
.24513 .4628 L
.21003 .45002 L
.16992 .4367 L
.12411 .42256 L
.0718 .40732 L
.0121 .39067 L
s
.0121 .39067 m
0 .3874 L
s
1 0 0 r
.4195 .63469 m
.412 .60727 L
s
% Start of user PostScript
-2.4150703 4.0406541 -2.6400377 3.2181026 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40282 .58368 m
.39184 .56318 L
s
% Start of user PostScript
-2.9153137 2.5103658 -3.2448342 1.895416 MAarrowhead1
% End of user PostScript
1 .473 0 r
.24513 .4628 m
.21003 .45002 L
s
% Start of user PostScript
-7.6462022 -1.116149 -8.6989767 -1.4995137 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-21.669504 -5.1312012 -24.701271 -5.9034313 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-61.824671 -15.105176 -70.485918 -17.23408 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-176.48793 -43.229388 -201.21545 -49.289205 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-503.83458 -123.43616 -574.4269 -140.73152 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1438.3433 -352.3907 -1639.8699 -401.7644 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-4106.1734 -1006.0041 -4681.4903 -1146.9557 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-11722.278 -2871.9347 -13364.689 -3274.3221 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-33464.687 -8198.7813 -38153.432 -9347.5144 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-95534.779 -23405.83 -108920.18 -26685.226 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-272732.09 -66818.816 -310944.65 -76180.816 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-778593.87 -190753.94 -887682.83 -217480.52 MAarrowhead1
% End of user PostScript
1 0 .857 r
.80886 .64201 m
.85376 .64202 L
.90468 .64532 L
.96251 .65184 L
s
.96251 .65184 m
1 .65739 L
s
1 0 0 r
.80886 .64201 m
.85376 .64202 L
s
% Start of user PostScript
9.2657297 4.2602841 10.612677 4.2605695 MAarrowhead1
% End of user PostScript
1 .158 0 r
.90468 .64532 m
.96251 .65184 L
s
% Start of user PostScript
12.140274 4.3597369 13.875167 4.5552656 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
34.948587 8.8876315 39.853206 10.035362 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
99.839245 24.536797 113.82961 27.951755 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
285.03648 69.851301 324.97344 79.632806 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
813.72411 199.36499 927.73529 227.2968 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2323.0154 569.13511 2648.4936 648.87647 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6631.73 1624.7608 7560.9033 1852.4064 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
18932.222 4638.3564 21584.819 5288.2376 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
54047.588 13241.551 61620.208 15096.828 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
154294.72 37801.897 175912.98 43098.329 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
440479.59 107916.62 502195.29 123036.84 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1257478.4 308079.69 1433664. 351244.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3589841.4 879503.97 4092814.9 1002731.5 MAarrowhead1
% End of user PostScript
1 0 .181 r
.44051 .48958 m
.43228 .48687 L
.42288 .484 L
.41214 .48089 L
.39989 .47749 L
.38592 .47373 L
.36997 .46954 L
.35179 .46486 L
.33105 .45958 L
.3074 .45363 L
.28044 .44689 L
.24969 .43924 L
.21463 .43056 L
.17466 .42069 L
.12909 .40946 L
.07713 .39667 L
.01789 .38211 L
s
.01789 .38211 m
0 .37772 L
s
1 0 0 r
.44051 .48958 m
.43228 .48687 L
s
% Start of user PostScript
-1.7845868 -0.31260627 -2.0315749 -0.39376251 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42288 .484 m
.41214 .48089 L
s
% Start of user PostScript
-2.3136739 -0.48010068 -2.6357196 -0.57337215 MAarrowhead1
% End of user PostScript
1 .473 0 r
.28044 .44689 m
.24969 .43924 L
s
% Start of user PostScript
-6.5868656 -1.5934008 -7.5092542 -1.8227585 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-18.79987 -4.601148 -21.433807 -5.2472497 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-53.668749 -13.147613 -61.188262 -14.990065 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-153.21297 -37.536608 -174.67967 -42.79595 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-437.39138 -107.15995 -498.67439 -122.17418 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1248.6622 -305.91972 -1423.6125 -348.78221 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-3564.673 -873.33774 -4064.1201 -995.70129 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-10176.406 -2493.1991 -11602.225 -2842.5218 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-29051.541 -7117.5693 -33121.959 -8114.8136 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-82936.157 -20319.192 -94556.361 -23166.119 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-236765.62 -58007.104 -269938.91 -66134.492 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-675917.02 -165598.32 -770619.91 -188800.34 MAarrowhead1
% End of user PostScript
.517 0 1 r
.65387 .49331 m
.67434 .50568 L
.69786 .51758 L
.72483 .5293 L
.7557 .54114 L
.791 .55335 L
.83133 .5662 L
.87739 .57997 L
.92996 .59492 L
.98995 .61134 L
s
.98995 .61134 m
1 .61402 L
s
1 0 0 r
.65387 .49331 m
.67434 .50568 L
s
% Start of user PostScript
4.6161383 -0.20060834 5.2303075 0.1704588 MAarrowhead1
% End of user PostScript
1 .158 0 r
.69786 .51758 m
.72483 .5293 L
s
% Start of user PostScript
5.9359287 0.52738546 6.7449206 0.87914622 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
16.751418 3.8864219 19.093135 4.4961943 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
47.77619 11.653967 54.468872 13.302127 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
136.38045 33.400937 155.48845 38.084348 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
389.33553 95.383609 443.88536 108.74867 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1111.4721 272.30777 1267.2006 310.46107 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3173.0234 777.38422 3617.5964 886.30374 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
9058.3272 2219.272 10327.492 2530.2147 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
25859.656 6335.5639 29482.858 7223.2413 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
73823.984 18086.728 84167.48 20620.864 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
210752.25 51633.879 240280.79 58868.314 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
601654.2 147404.08 685952.11 168056.89 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1717598.7 420808.23 1958251.8 479767.77 MAarrowhead1
% End of user PostScript
0 1 .577 r
.36559 .74953 m
.35367 .69982 L
.33894 .65717 L
.32119 .62024 L
.30015 .58791 L
.2755 .55919 L
.24684 .53325 L
.2137 .50935 L
.17554 .48683 L
.1317 .4651 L
.08145 .44363 L
.02394 .42189 L
s
.02394 .42189 m
0 .4137 L
s
1 0 0 r
.36559 .74953 m
.35367 .69982 L
s
% Start of user PostScript
-4.0323055 7.4859631 -4.3898161 5.994517 MAarrowhead1
% End of user PostScript
1 .158 0 r
.33894 .65717 m
.32119 .62024 L
s
% Start of user PostScript
-4.8317867 4.7149538 -5.3643572 3.6072387 MAarrowhead1
% End of user PostScript
1 .473 0 r
.08145 .44363 m
.02394 .42189 L
s
% Start of user PostScript
-12.556395 -1.6912396 -14.281766 -2.343412 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-35.555381 -8.3857799 -40.529092 -9.6582075 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-101.43506 -24.775024 -115.64528 -28.26915 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-289.56016 -70.923729 -330.13006 -80.866244 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-826.63077 -202.51867 -942.45009 -230.89487 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2359.8595 -578.15986 -2690.4999 -659.16626 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6736.9118 -1650.5297 -7680.8221 -1881.7858 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-19232.494 -4711.9224 -21927.163 -5372.111 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-54904.803 -13451.567 -62597.528 -15336.269 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-156741.89 -38401.449 -178703.03 -43781.885 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-447465.77 -109628.22 -510160.3 -124988.25 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1277422.5 -312965.95 -1456402.4 -356815.68 MAarrowhead1
% End of user PostScript
0 1 .17 r
.45581 .63721 m
.45324 .61206 L
.44972 .59073 L
.4452 .57255 L
.43962 .55694 L
.43292 .54342 L
.42498 .53156 L
.4157 .52101 L
.4049 .51146 L
.39243 .50265 L
.37807 .49432 L
.36158 .48628 L
.34268 .4783 L
.32105 .47021 L
.29632 .46182 L
.26807 .45296 L
.23581 .44344 L
.199 .43306 L
.15699 .42165 L
.10907 .40896 L
.05441 .39479 L
s
.05441 .39479 m
0 .38088 L
s
1 0 0 r
.45581 .63721 m
.45324 .61206 L
s
% Start of user PostScript
-1.3256579 4.1164142 -1.4026671 3.3617787 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44972 .59073 m
.4452 .57255 L
s
% Start of user PostScript
-1.5084791 2.7219806 -1.6441452 2.1765682 MAarrowhead1
% End of user PostScript
1 .473 0 r
.37807 .49432 m
.36158 .48628 L
s
% Start of user PostScript
-3.6578905 -0.17026308 -4.1526267 -0.41173361 MAarrowhead1
% End of user PostScript
1 .788 0 r
.15699 .42165 m
.10907 .40896 L
s
% Start of user PostScript
-10.290251 -2.3506428 -11.727847 -2.731089 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-29.340789 -7.1484124 -33.450753 -8.161976 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-83.753505 -20.510044 -95.487997 -23.386528 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-239.09701 -58.576082 -272.59689 -66.783852 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-682.57219 -167.2283 -778.20752 -190.65885 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-1948.6027 -477.40364 -2221.6219 -544.29281 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-5562.8588 -1362.8892 -6342.2722 -1553.844 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-15880.815 -3890.7678 -18105.879 -4435.9042 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-45336.45 -11107.34 -51688.551 -12663.591 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-129426.22 -31709.164 -147560.15 -36151.942 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-369485.15 -90523.122 -421253.8 -103206.34 MAarrowhead1
% End of user PostScript
1 0 .398 r
.3157 .81083 m
.2986 .74767 L
.27765 .69333 L
.25256 .64613 L
.22296 .60462 L
.18837 .56757 L
.14823 .53389 L
.10188 .50265 L
.04855 .47298 L
s
.04855 .47298 m
0 .4501 L
s
1 0 0 r
.3157 .81083 m
.2986 .74767 L
s
% Start of user PostScript
-5.5288539 9.3250216 -6.0420462 7.4300163 MAarrowhead1
% End of user PostScript
1 .158 0 r
.27765 .69333 m
.25256 .64613 L
s
% Start of user PostScript
-6.6704573 5.7998963 -7.4230544 4.3839049 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-17.483342 -2.5378088 -19.890202 -3.4166721 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-49.54517 -11.728598 -56.476921 -13.494765 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-141.35527 -34.535518 -161.15823 -39.403148 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-403.51994 -98.83898 -460.05666 -112.69411 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1151.9615 -282.22295 -1313.3629 -321.76686 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3288.6113 -805.70194 -3749.3793 -918.58939 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-9388.3067 -2300.1161 -10703.704 -2622.3859 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-26801.679 -6566.3577 -30556.869 -7486.3716 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-76513.266 -18745.597 -87233.558 -21372.047 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-218429.59 -53514.814 -249033.82 -61012.786 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-623571.44 -152773.76 -710940.18 -174178.92 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1780167.9 -436137.56 -2029587.6 -497244.9 MAarrowhead1
% End of user PostScript
.276 0 1 r
.59183 .45644 m
.60308 .47014 L
.61618 .48248 L
.63133 .49381 L
.64879 .50444 L
.66885 .51466 L
.69185 .52472 L
.71819 .53486 L
.74831 .54532 L
.78272 .55632 L
.82201 .56809 L
.86686 .58087 L
.91804 .5949 L
.97643 .61045 L
s
.97643 .61045 m
1 .6166 L
s
1 0 0 r
.59183 .45644 m
.60308 .47014 L
s
% Start of user PostScript
2.7549758 -1.3069341 3.0924554 -0.89591349 MAarrowhead1
% End of user PostScript
1 .158 0 r
.61618 .48248 m
.63133 .49381 L
s
% Start of user PostScript
3.4852577 -0.52573443 3.9398023 -0.18581251 MAarrowhead1
% End of user PostScript
1 .473 0 r
.82201 .56809 m
.86686 .58087 L
s
% Start of user PostScript
9.6602942 2.042812 11.00587 2.4261422 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
27.510195 6.6638799 31.362793 7.6203598 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
78.519978 19.219378 89.520993 21.917563 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
224.1546 54.913234 255.56085 62.608397 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
639.91427 156.77673 729.57278 178.74305 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1826.823 447.56776 2082.7796 510.27665 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
5215.203 1277.7142 5945.9062 1456.7351 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
14888.329 3647.6107 16974.336 4158.6783 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
42503.108 10413.176 48458.228 11872.169 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
121337.61 29727.471 138338.25 33892.594 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
346393.84 84865.798 394927.16 96756.365 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
988882.98 242274.35 1127435.6 276219.47 MAarrowhead1
% End of user PostScript
.276 1 0 r
.50597 .41521 m
.50469 .42919 L
.50359 .44084 L
.50262 .45055 L
.50176 .45864 L
.50098 .46537 L
.50027 .47097 L
.49959 .47563 L
.49894 .47949 L
.49829 .48268 L
.49764 .48532 L
.49697 .48749 L
.49625 .48927 L
.49549 .49071 L
.49466 .49186 L
.49374 .49277 L
.49272 .49346 L
.49159 .49397 L
.49031 .49432 L
.48887 .49451 L
.48725 .49457 L
.4854 .4945 L
.48331 .49431 L
.48093 .49399 L
.47823 .49355 L
.47515 .49298 L
.47164 .49228 L
.46765 .49143 L
.4631 .49042 L
.45792 .48924 L
.45201 .48787 L
.44528 .48628 L
.43761 .48445 L
.42886 .48235 L
.41889 .47994 L
.40752 .47719 L
.39456 .47404 L
.37978 .47044 L
.36293 .46633 L
.34372 .46164 L
.32183 .45629 L
.29686 .45018 L
.2684 .44322 L
.23595 .43527 L
.19895 .42621 L
.15677 .41588 L
.10868 .40411 L
.05385 .39068 L
s
.05385 .39068 m
0 .37749 L
s
1 0 0 r
.50597 .41521 m
.50469 .42919 L
s
% Start of user PostScript
0.17897962 -2.5437024 0.14070824 -2.1244019 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50359 .44084 m
.50262 .45055 L
s
% Start of user PostScript
0.10756949 -1.7748624 0.07854383 -1.483568 MAarrowhead1
% End of user PostScript
1 .473 0 r
.49764 .48532 m
.49697 .48749 L
s
% Start of user PostScript
-0.070747059 -0.44026769 -0.091013703 -0.37516584 MAarrowhead1
% End of user PostScript
1 .788 0 r
.49031 .49432 m
.48887 .49451 L
s
% Start of user PostScript
-0.29068602 -0.17052473 -0.33384533 -0.16464655 MAarrowhead1
% End of user PostScript
.897 1 0 r
.47164 .49228 m
.46765 .49143 L
s
% Start of user PostScript
-0.85068 -0.23173274 -0.97043984 -0.25721062 MAarrowhead1
% End of user PostScript
.581 1 0 r
.41889 .47994 m
.40752 .47719 L
s
% Start of user PostScript
-2.4334073 -0.60165506 -2.7744866 -0.68431174 MAarrowhead1
% End of user PostScript
.266 1 0 r
.2684 .44322 m
.23595 .43527 L
s
% Start of user PostScript
-6.9480244 -1.7035377 -7.9215452 -1.9418353 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-19.835446 -4.8599465 -22.614603 -5.5407842 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-56.626171 -13.87337 -64.560079 -15.817149 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-161.65606 -39.605427 -184.30572 -45.154547 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-461.4947 -113.06528 -526.15483 -128.90688 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1317.4722 -322.77805 -1502.0635 -368.00256 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3761.1114 -921.46476 -4288.0816 -1050.5714 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-10737.197 -2630.5918 -12241.588 -2999.1647 MAarrowhead1
% End of user PostScript
.256 1 0 r
.27461 .39981 m
.24193 .39926 L
.20485 .39639 L
.16273 .39126 L
.11484 .38385 L
.06034 .37411 L
s
.06034 .37411 m
0 .36225 L
s
1 0 0 r
.27461 .39981 m
.24193 .39926 L
s
% Start of user PostScript
-6.7617277 -3.0055629 -7.7421399 -3.0222824 MAarrowhead1
% End of user PostScript
1 .158 0 r
.20485 .39639 m
.16273 .39126 L
s
% Start of user PostScript
-8.8544467 -3.1083393 -10.118034 -3.2623497 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-25.474594 -6.4617106 -29.049243 -7.3009648 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-72.770962 -17.880511 -82.968186 -20.370234 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-207.75695 -50.912193 -236.86612 -58.041868 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-593.10579 -145.31259 -676.20605 -165.67151 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1693.1953 -414.83013 -1930.4293 -472.95187 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4833.7235 -1184.2527 -5510.9776 -1350.1786 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-13799.284 -3380.7969 -15732.705 -3854.4811 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-39394.109 -9651.4778 -44913.627 -11003.749 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-112462.06 -27552.979 -128219.14 -31413.433 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-321055.97 -78658.071 -366039.2 -89678.872 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-916548.59 -224552.57 -1044966.4 -256014.68 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2616557.2 -641051.27 -2983163.6 -730869.12 MAarrowhead1
% End of user PostScript
1 0 .923 r
.19977 .65586 m
.16332 .60892 L
.12083 .5668 L
.07162 .52829 L
.01486 .49231 L
s
.01486 .49231 m
0 .48447 L
s
1 0 0 r
.19977 .65586 m
.16332 .60892 L
s
% Start of user PostScript
-9.0069654 4.6756553 -10.10044 3.2675658 MAarrowhead1
% End of user PostScript
1 .158 0 r
.12083 .5668 m
.07162 .52829 L
s
% Start of user PostScript
-11.375036 2.0039961 -12.851506 0.84856798 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-31.468419 -6.5847822 -35.849927 -7.8446065 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-89.599876 -21.687654 -102.14727 -24.805499 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-255.73376 -62.592239 -291.56316 -71.380644 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-730.05413 -178.84724 -832.34182 -203.90993 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2084.1509 -510.60938 -2376.1617 -582.152 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5949.8203 -1457.6933 -6783.4509 -1661.9312 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-16985.51 -4161.4157 -19365.353 -4744.4726 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-48490.127 -11879.984 -55284.089 -13544.491 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-138429.31 -33914.904 -157824.67 -38666.729 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-395187.13 -96820.056 -450556.89 -110385.54 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1128177.8 -276401.29 -1286247. -315127.94 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3220714.8 -789068.68 -3671969.9 -899625.27 MAarrowhead1
% End of user PostScript
1 .52 0 r
.31658 .38378 m
.28914 .38887 L
.25814 .39112 L
.22304 .39075 L
.18322 .38785 L
.13799 .38249 L
.08656 .37466 L
.02804 .36431 L
s
.02804 .36431 m
0 .35884 L
s
1 0 0 r
.31658 .38378 m
.28914 .38887 L
s
% Start of user PostScript
-5.5025331 -3.4865561 -6.3258475 -3.3339924 MAarrowhead1
% End of user PostScript
1 .158 0 r
.25814 .39112 m
.22304 .39075 L
s
% Start of user PostScript
-7.2558434 -3.2662577 -8.3089049 -3.2776425 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-21.026194 -5.500904 -23.980736 -6.1668548 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-60.098766 -14.806148 -68.521227 -16.856038 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-171.5868 -42.057693 -195.62833 -47.944629 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-489.84896 -120.01654 -558.48192 -136.83073 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1398.4187 -342.61084 -1594.3515 -390.61381 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3992.1972 -978.08057 -4551.5449 -1115.1196 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-11396.9 -2792.2177 -12993.722 -3183.4359 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-32535.798 -7971.2054 -37094.396 -9088.0528 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-92882.993 -22756.147 -105896.85 -25944.516 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-265161.79 -64964.107 -302313.67 -74066.243 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-756982.21 -185459.13 -863043.16 -211443.85 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2161028.1 -529447.56 -2463810.2 -603628.58 MAarrowhead1
% End of user PostScript
0 .476 1 r
.18768 .68822 m
.15041 .63523 L
.10683 .58796 L
.05626 .54504 L
s
.05626 .54504 m
0 .50672 L
s
1 0 0 r
.18768 .68822 m
.15041 .63523 L
s
% Start of user PostScript
-9.3695165 5.6467396 -10.48784 4.0569684 MAarrowhead1
% End of user PostScript
1 .158 0 r
.10683 .58796 m
.05626 .54504 L
s
% Start of user PostScript
-11.795065 2.6389012 -13.312322 1.3512479 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-32.512746 -6.6673982 -37.036332 -7.9907326 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-92.544872 -22.368494 -105.50389 -25.593926 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-264.13258 -64.640382 -301.13851 -73.718617 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-754.02903 -184.7188 -859.6758 -210.60483 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2152.5938 -527.37724 -2454.1942 -601.26937 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6145.2106 -1505.5634 -7006.2175 -1716.5085 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-17543.309 -4298.0753 -20001.306 -4900.2797 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-50082.528 -12270.119 -57099.603 -13989.288 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-142975.29 -35028.66 -163007.59 -39936.533 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-408164.96 -99999.598 -465353.05 -114010.57 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1165226.8 -285478.23 -1328487. -325476.65 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3326482.1 -814981.46 -3792556.3 -929168.7 MAarrowhead1
% End of user PostScript
0 .084 1 r
.67835 .68464 m
.70679 .66825 L
.73864 .65658 L
.77447 .6491 L
.81494 .64545 L
.86073 .64536 L
.91267 .64864 L
.97165 .65522 L
s
.97165 .65522 m
1 .65939 L
s
1 0 0 r
.67835 .68464 m
.70679 .66825 L
s
% Start of user PostScript
5.3504085 5.5391075 6.2035717 5.0476383 MAarrowhead1
% End of user PostScript
1 .158 0 r
.73864 .65658 m
.77447 .6491 L
s
% Start of user PostScript
7.1591222 4.6973035 8.2342469 4.4730882 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
21.055231 5.8495991 24.022204 6.4620062 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
60.253315 14.924218 68.699394 16.966606 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
172.04483 42.188742 196.151 48.088393 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
491.16049 120.34228 559.97732 137.20079 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1402.1638 343.52942 1598.6213 391.66078 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4002.8888 980.70025 4563.7345 1118.1062 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
11427.422 2799.6957 13028.521 3191.9616 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
32622.933 7992.5534 37193.74 9112.3919 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
93131.747 22817.092 106180.46 26013.999 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
265871.93 65138.09 303123.31 74264.603 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
759009.52 185955.81 865354.52 212010.12 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2166815.6 530865.49 2470408.7 605245.18 MAarrowhead1
% End of user PostScript
.506 0 1 r
.75841 .42662 m
.79127 .45731 L
.82929 .48552 L
.87309 .51202 L
.92342 .5375 L
.98113 .56261 L
s
.98113 .56261 m
1 .56985 L
s
1 0 0 r
.75841 .42662 m
.79127 .45731 L
s
% Start of user PostScript
7.7522813 -2.2014306 8.7380616 -1.280554 MAarrowhead1
% End of user PostScript
1 .158 0 r
.82929 .48552 m
.87309 .51202 L
s
% Start of user PostScript
9.8785919 -0.43431317 11.192799 0.36057478 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
27.602552 6.0923076 31.453543 7.1468343 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
78.658995 19.113915 89.676072 21.83915 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
224.52219 54.970534 255.97915 62.683547 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
640.95681 157.02446 730.7612 179.02779 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1829.7977 448.29473 2086.171 511.10602 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5223.6945 1279.7942 5955.5875 1459.1066 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
14912.57 3653.5498 17001.974 4165.4495 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
42572.313 10430.131 48537.129 11891.499 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
121535.17 29775.874 138563.49 33947.778 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
346957.85 85003.979 395570.19 96913.906 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
990493.1 242668.83 1129271.3 276669.21 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2827653.5 692769.45 3223836.7 789833.54 MAarrowhead1
% End of user PostScript
0 1 .05 r
.63527 .31057 m
.64878 .35075 L
.66508 .38551 L
.68441 .41591 L
.70709 .44288 L
.73346 .46721 L
.76397 .48959 L
.79911 .51064 L
.83949 .53091 L
.88578 .55091 L
.93876 .57112 L
.99934 .59199 L
s
.99934 .59199 m
1 .59219 L
s
1 0 0 r
.63527 .31057 m
.64878 .35075 L
s
% Start of user PostScript
4.0582038 -5.6829775 4.4633282 -4.4775136 MAarrowhead1
% End of user PostScript
1 .158 0 r
.66508 .38551 m
.68441 .41591 L
s
% Start of user PostScript
4.9522969 -3.4347725 5.5323705 -2.5226141 MAarrowhead1
% End of user PostScript
1 .473 0 r
.93876 .57112 m
.99934 .59199 L
s
% Start of user PostScript
13.162774 2.1334615 14.980293 2.7595599 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
37.348066 8.893937 42.574638 10.216892 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
106.56727 26.048595 121.49696 29.716309 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
304.21495 74.517925 346.83823 84.962884 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
868.46798 212.7696 990.14914 242.58179 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2479.2963 607.42184 2826.671 692.52809 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
7077.8793 1734.0661 8069.5626 1977.0265 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
20205.886 4950.4015 23036.937 5644.0034 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
57683.636 14132.375 65765.703 16112.466 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
164674.88 40345.017 187747.52 45997.766 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
470112.83 115176.7 535980.44 131314.14 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1342075.2 328805.73 1530113.6 374874.78 MAarrowhead1
% End of user PostScript
.467 0 1 r
.78345 .22797 m
.8148 .29222 L
.85193 .34852 L
.89542 .39855 L
.94597 .44379 L
s
.94597 .44379 m
1 .48238 L
s
1 0 0 r
.78345 .22797 m
.8148 .29222 L
s
% Start of user PostScript
8.5034516 -8.1609415 9.4440728 -6.2333343 MAarrowhead1
% End of user PostScript
1 .158 0 r
.85193 .34852 m
.89542 .39855 L
s
% Start of user PostScript
10.558034 -4.5444251 11.862739 -3.0433698 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
28.645136 5.3435773 32.61762 6.5942277 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
81.424717 19.555729 92.823527 22.41355 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
232.3683 56.837452 264.92322 64.828635 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
663.34421 162.49633 756.28498 185.27022 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1893.7063 463.94917 2159.0339 528.95473 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5406.14 1324.4923 6163.5955 1510.0676 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
15433.414 3781.1554 17595.794 4310.934 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
44059.215 10794.419 50232.362 12306.828 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
125779.97 30815.841 143403.03 35133.456 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
359075.88 87972.871 409386.08 100298.77 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1025087.6 251144.4 1168712.8 286332.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2926413.6 716965.47 3336434.1 817419.67 MAarrowhead1
% End of user PostScript
1 0 .975 r
.30269 .65256 m
.27996 .6137 L
.25323 .57939 L
.22208 .54859 L
.186 .52042 L
.14439 .4941 L
.09655 .46892 L
.04169 .44425 L
s
.04169 .44425 m
0 .42782 L
s
1 0 0 r
.30269 .65256 m
.27996 .6137 L
s
% Start of user PostScript
-5.9193663 4.5766517 -6.6011803 3.4111413 MAarrowhead1
% End of user PostScript
1 .158 0 r
.25323 .57939 m
.22208 .54859 L
s
% Start of user PostScript
-7.4029679 2.3816526 -8.3374888 1.4576554 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-20.253897 -3.9770714 -23.067559 -4.829612 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-57.61406 -13.884025 -65.680716 -15.898659 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-164.42774 -40.230155 -187.46442 -45.883093 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-469.39589 -114.9883 -535.16274 -131.10316 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1340.0258 -328.30064 -1527.777 -374.29981 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3825.4966 -937.2383 -4361.4878 -1068.5552 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-10921.004 -2675.6238 -12451.148 -3050.5062 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-31177.213 -7638.3547 -35545.459 -8708.5663 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-89004.512 -21805.927 -101474.95 -24861.161 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-254089.53 -62251.425 -289690.07 -70973.486 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-725373.19 -177714.98 -827005.39 -202614.67 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2070790.8 -507339.61 -2360929.8 -578423.08 MAarrowhead1
% End of user PostScript
1 .971 0 r
.35693 .43771 m
.33622 .43715 L
.31271 .43515 L
.28601 .43175 L
.25564 .42693 L
.22107 .42065 L
.18172 .41284 L
.13691 .40338 L
.08584 .39214 L
.02766 .37894 L
s
.02766 .37894 m
0 .37253 L
s
1 0 0 r
.35693 .43771 m
.33622 .43715 L
s
% Start of user PostScript
-4.2921665 -1.8687239 -4.9135484 -1.8855846 MAarrowhead1
% End of user PostScript
1 .158 0 r
.31271 .43515 m
.28601 .43175 L
s
% Start of user PostScript
-5.618678 -1.945391 -6.4198382 -2.0474369 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-16.159488 -4.0926054 -18.426867 -4.6259815 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-46.160022 -11.340474 -52.628281 -12.919989 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-131.78392 -32.29416 -150.24838 -36.816695 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-376.21746 -92.174253 -428.92941 -105.08829 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1074.0236 -263.13404 -1224.5053 -300.00169 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3066.116 -751.19237 -3495.7102 -856.44208 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8753.1287 -2144.499 -9979.5316 -2444.9653 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-24988.377 -6122.1024 -28489.504 -6979.8716 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-71336.663 -17477.34 -81331.659 -19926.094 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-203651.46 -49894.2 -232185.11 -56884.888 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-581382.92 -142437.65 -662840.61 -162394.62 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1659728.3 -406630.12 -1892273.2 -463603.15 MAarrowhead1
% End of user PostScript
.643 0 1 r
.51611 .77671 m
.52504 .73371 L
.53413 .69824 L
.54356 .66909 L
.55354 .64529 L
.56427 .62602 L
.57598 .61062 L
.58888 .59854 L
.60321 .58933 L
.61924 .58265 L
.63725 .57821 L
.65757 .5758 L
.68056 .57527 L
.70662 .57651 L
.7362 .57947 L
.76982 .58413 L
.80807 .59052 L
.8516 .59869 L
.90117 .60876 L
.95764 .62085 L
s
.95764 .62085 m
1 .63028 L
s
1 0 0 r
.51611 .77671 m
.52504 .73371 L
s
% Start of user PostScript
0.48329649 8.3013712 0.75134599 7.0113801 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53413 .69824 m
.54356 .66909 L
s
% Start of user PostScript
1.0237627 5.9470501 1.306657 5.0726704 MAarrowhead1
% End of user PostScript
1 .473 0 r
.63725 .57821 m
.65757 .5758 L
s
% Start of user PostScript
4.1175124 2.346286 4.7271627 2.2740664 MAarrowhead1
% End of user PostScript
1 .788 0 r
.90117 .60876 m
.95764 .62085 L
s
% Start of user PostScript
12.035213 3.2626557 13.729158 3.6256401 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
34.423928 8.5075347 39.248878 9.6774211 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
98.288684 24.097846 112.06036 27.46901 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
280.59755 68.749904 319.91224 78.38125 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
801.04899 196.25635 913.28418 223.75359 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
2286.8299 560.26896 2607.2381 638.76831 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
6528.4277 1599.4518 7443.1271 1823.5513 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
18637.314 4566.1048 21248.593 5205.8627 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
53205.689 13035.287 60660.35 14861.664 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
151891.27 37213.057 173172.79 42426.987 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
433618.24 106235.6 494372.6 121120.3 MAarrowhead1
% End of user PostScript
0 .517 1 r
.52714 .40731 m
.52851 .4241 L
.53047 .43832 L
.53305 .4504 L
.53626 .46075 L
.54017 .46968 L
.54481 .47747 L
.55027 .48436 L
.55663 .49055 L
.56399 .49622 L
.57248 .50152 L
.58224 .5066 L
.59343 .51159 L
.60624 .5166 L
.6209 .52175 L
.63764 .52716 L
.65677 .53293 L
.6786 .53919 L
.70351 .54605 L
.73193 .55364 L
.76435 .56211 L
.80132 .57161 L
.84349 .58231 L
.89157 .59439 L
.94639 .60808 L
s
.94639 .60808 m
1 .6214 L
s
1 0 0 r
.52714 .40731 m
.52851 .4241 L
s
% Start of user PostScript
0.81405499 -2.7806423 0.85515423 -2.2768658 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53047 .43832 m
.53305 .4504 L
s
% Start of user PostScript
0.9140988 -1.8505092 0.99138658 -1.4879001 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57248 .50152 m
.58224 .5066 L
s
% Start of user PostScript
2.17441 0.045632004 2.4671421 0.19804712 MAarrowhead1
% End of user PostScript
1 .788 0 r
.70351 .54605 m
.73193 .55364 L
s
% Start of user PostScript
6.1053159 1.381418 6.957933 1.6092554 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
17.405426 4.2374394 19.843447 4.8391987 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
49.683268 12.165996 56.644248 13.872466 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
141.83416 34.747605 161.70654 39.616544 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
404.90697 99.201049 461.63857 113.10023 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
1155.9258 283.19943 1317.8828 322.87859 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
3299.9297 808.47616 3762.2837 921.75195 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
9420.6188 2308.0328 10740.544 2631.4117 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
26893.924 6588.9575 30662.038 7512.1378 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
76776.606 18810.115 87533.793 21445.604 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
219181.37 53698.998 249890.93 61222.777 MAarrowhead1
% End of user PostScript
1 .168 0 r
.20864 .8173 m
.17733 .74524 L
.14006 .68238 L
.09626 .62682 L
.04521 .57692 L
s
.04521 .57692 m
0 .54198 L
s
1 0 0 r
.20864 .8173 m
.17733 .74524 L
s
% Start of user PostScript
-8.7408053 9.5190068 -9.6800104 7.3571235 MAarrowhead1
% End of user PostScript
1 .158 0 r
.14006 .68238 m
.09626 .62682 L
s
% Start of user PostScript
-10.798101 5.4714493 -12.112307 3.8047433 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-29.123682 -5.2293398 -33.157547 -6.5333778 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-82.742309 -19.824184 -94.324397 -22.735912 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-236.11835 -57.743445 -269.19838 -65.865393 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-674.04716 -165.11553 -768.48746 -188.2573 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1924.2604 -471.43416 -2193.8689 -537.48865 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5493.3655 -1345.8622 -6263.0421 -1534.4317 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-15682.425 -3842.1625 -17879.693 -4380.4888 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-44770.089 -10968.582 -51042.837 -12505.393 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-127809.37 -31313.04 -145716.77 -35700.317 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-364869.39 -89392.271 -415991.33 -101917.04 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1041626.9 -255196.5 -1187569.4 -290952.14 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2973629.9 -728533.37 -3390265.8 -830608.34 MAarrowhead1
% End of user PostScript
1 .296 0 r
.82125 .19904 m
.85696 .27069 L
.89922 .33352 L
.94869 .38942 L
s
.94869 .38942 m
1 .43461 L
s
1 0 0 r
.82125 .19904 m
.85696 .27069 L
s
% Start of user PostScript
9.6374489 -9.0289157 10.708903 -6.879431 MAarrowhead1
% End of user PostScript
1 .158 0 r
.89922 .33352 m
.94869 .38942 L
s
% Start of user PostScript
11.976676 -4.9944626 13.460621 -3.3173561 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
32.527756 6.1075304 37.039649 7.5213618 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
92.46951 22.217707 105.41473 25.461681 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
263.88968 64.549802 300.86081 73.624659 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
753.32908 184.54002 858.87761 210.40319 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2150.5941 526.88559 2451.9142 600.70935 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6139.5014 1504.1642 6999.7084 1714.9134 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
17527.01 4294.0821 19982.723 4895.727 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
50035.999 12258.719 57046.554 13976.291 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
142842.46 34996.116 162856.15 39899.43 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
407785.75 99906.693 464920.71 113904.64 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1164144.2 285213. 1327252.7 325174.26 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3323391.6 814224.3 3789032.8 928305.45 MAarrowhead1
% End of user PostScript
1 0 .872 r
.52843 .46752 m
.53145 .4748 L
.53505 .48113 L
.53929 .48672 L
.54423 .49172 L
.54996 .49629 L
.55657 .50056 L
.56417 .50462 L
.57289 .5086 L
.58288 .51258 L
.5943 .51666 L
.60736 .52092 L
.62227 .52547 L
.63929 .53038 L
.65871 .53576 L
.68087 .54171 L
.70615 .54833 L
.73498 .55575 L
.76786 .56411 L
.80535 .57355 L
.8481 .58423 L
.89685 .59635 L
.95243 .61011 L
s
.95243 .61011 m
1 .62186 L
s
1 0 0 r
.52843 .46752 m
.53145 .4748 L
s
% Start of user PostScript
0.85294162 -0.97433633 0.94347787 -0.75611824 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53505 .48113 m
.53929 .48672 L
s
% Start of user PostScript
1.0514985 -0.56609372 1.1786583 -0.39847692 MAarrowhead1
% End of user PostScript
1 .473 0 r
.5943 .51666 m
.60736 .52092 L
s
% Start of user PostScript
2.8290246 0.49969437 3.2206648 0.62768762 MAarrowhead1
% End of user PostScript
1 .788 0 r
.76786 .56411 m
.80535 .57355 L
s
% Start of user PostScript
8.0357105 1.9233191 9.1604839 2.20641 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
22.93077 5.6073293 26.143344 6.3961701 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
65.460381 16.035159 74.631989 18.282599 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
186.87536 45.783502 213.0585 52.198415 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
533.49049 130.70396 608.23797 149.01697 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
1523.0053 373.13322 1736.3939 425.41301 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
4347.866 1065.2185 4957.0465 1214.4665 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
12412.261 3040.979 14151.345 3467.0513 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
35434.444 8681.3679 40399.172 9897.7164 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
101158.03 24783.515 115331.31 28255.939 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
288785.31 70751.824 329247.09 80664.878 MAarrowhead1
% End of user PostScript
1 .914 0 r
.73739 .57173 m
.77099 .57771 L
.80923 .58521 L
.85279 .59431 L
.90241 .60516 L
.95895 .61793 L
s
.95895 .61793 m
1 .62741 L
s
1 0 0 r
.73739 .57173 m
.77099 .57771 L
s
% Start of user PostScript
7.1217978 2.1518297 8.1295987 2.3313111 MAarrowhead1
% End of user PostScript
1 .158 0 r
.80923 .58521 m
.85279 .59431 L
s
% Start of user PostScript
9.2769521 2.5561533 10.583684 2.8293629 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
26.543216 6.5695594 30.26382 7.470079 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
75.789361 18.583862 86.408608 21.182969 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
216.36627 53.012971 246.68149 60.439531 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
617.68185 151.33168 704.22542 172.53454 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1763.3545 432.01852 2010.4185 492.54867 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5034.0134 1233.3232 5739.3301 1406.1244 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
14371.07 3520.8834 16384.604 4014.1951 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
41026.441 10051.396 46774.665 11459.699 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
117122.03 28694.662 133532.02 32715.078 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
334359.23 81917.342 381206.38 93394.799 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
954526.64 233857.12 1088265.6 266622.89 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2724976.7 667613.83 3106773.8 761153.36 MAarrowhead1
% End of user PostScript
0 .973 1 r
.79026 .45926 m
.82819 .48709 L
.87189 .51325 L
.92209 .53845 L
.97964 .56331 L
s
.97964 .56331 m
1 .57108 L
s
1 0 0 r
.79026 .45926 m
.82819 .48709 L
s
% Start of user PostScript
8.7077952 -1.222085 9.8456979 -0.38740292 MAarrowhead1
% End of user PostScript
1 .158 0 r
.87189 .51325 m
.92209 .53845 L
s
% Start of user PostScript
11.156642 0.39757891 12.662617 1.1535053 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
31.359943 7.1346711 35.740364 8.2987271 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
89.411121 21.776766 101.93538 24.86652 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
255.2233 62.498959 290.98195 71.264767 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
728.60353 178.49931 830.68816 203.51101 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2080.0113 509.59694 2371.4421 580.99719 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5938.003 1454.7984 6769.9779 1658.6307 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
16951.774 4153.1505 19326.891 4735.0494 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
48393.817 11856.388 55174.286 13517.59 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
138154.37 33847.544 157511.21 38589.931 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
394402.23 96627.756 449662.01 110166.29 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1125937. 275852.31 1283692.3 314502.04 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3214317.9 787501.46 3664676.8 897838.47 MAarrowhead1
% End of user PostScript
1 0 .218 r
.19171 .63468 m
.15366 .59054 L
.10942 .55064 L
.05828 .51387 L
s
.05828 .51387 m
0 .47958 L
s
1 0 0 r
.19171 .63468 m
.15366 .59054 L
s
% Start of user PostScript
-9.2488296 4.0404891 -10.390292 2.7160533 MAarrowhead1
% End of user PostScript
1 .158 0 r
.10942 .55064 m
.05828 .51387 L
s
% Start of user PostScript
-11.717262 1.5192557 -13.251496 0.41609145 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-32.529498 -6.9388768 -37.061978 -8.2200943 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-92.648784 -22.456733 -105.6239 -25.675708 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-264.4424 -64.731028 -301.49209 -73.817544 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-754.91659 -184.93971 -860.6878 -210.85565 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2155.1284 -527.999 -2457.0838 -601.978 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6152.4463 -1507.3363 -7014.467 -1718.5298 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-17563.965 -4303.1361 -20024.856 -4906.0496 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-50141.498 -12284.567 -57166.835 -14005.76 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-143143.64 -35069.904 -163199.52 -39983.556 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-408645.56 -100117.34 -465900.98 -114144.81 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1166598.8 -285814.37 -1330051.2 -325859.88 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3330398.9 -815941.07 -3797021.9 -930262.76 MAarrowhead1
% End of user PostScript
1 0 .241 r
.50075 .50865 m
.50106 .50733 L
.50138 .50624 L
.50172 .50534 L
.50208 .50461 L
.50247 .50403 L
.5029 .50357 L
.50338 .50321 L
.50391 .50295 L
.50451 .50276 L
.50518 .50265 L
.50594 .50261 L
.5068 .50263 L
.50778 .50271 L
.50889 .50285 L
.51015 .50305 L
.51158 .5033 L
.51322 .50363 L
.51508 .50402 L
.5172 .50449 L
.51962 .50503 L
.52237 .50567 L
.52551 .50641 L
.52909 .50726 L
.53317 .50824 L
.53782 .50936 L
.54312 .51064 L
.54916 .51211 L
.55605 .51379 L
.5639 .5157 L
.57286 .51789 L
.58307 .52038 L
.59471 .52323 L
.60798 .52648 L
.62311 .53018 L
.64035 .5344 L
.66002 .53922 L
.68244 .54471 L
.708 .55097 L
.73715 .55811 L
.77037 .56625 L
.80825 .57553 L
.85144 .58611 L
.90068 .59817 L
.95682 .61192 L
s
.95682 .61192 m
1 .6225 L
s
1 0 0 r
.50075 .50865 m
.50106 .50733 L
s
% Start of user PostScript
0.022429925 0.25962922 0.031794275 0.21982138 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50138 .50624 m
.50172 .50534 L
s
% Start of user PostScript
0.041439925 0.18705746 0.051577051 0.16023342 MAarrowhead1
% End of user PostScript
1 .473 0 r
.50518 .50265 m
.50594 .50261 L
s
% Start of user PostScript
0.15541122 0.079613572 0.17820285 0.0783159 MAarrowhead1
% End of user PostScript
1 .788 0 r
.51508 .50402 m
.5172 .50449 L
s
% Start of user PostScript
0.4523803 0.12058563 0.51600219 0.13455704 MAarrowhead1
% End of user PostScript
.897 1 0 r
.54312 .51064 m
.54916 .51211 L
s
% Start of user PostScript
1.2934984 0.31919465 1.4747868 0.36323055 MAarrowhead1
% End of user PostScript
.581 1 0 r
.62311 .53018 m
.64035 .5344 L
s
% Start of user PostScript
3.6931515 0.90535246 4.210613 1.0320404 MAarrowhead1
% End of user PostScript
.266 1 0 r
.85144 .58611 m
.90068 .59817 L
s
% Start of user PostScript
10.543299 2.5832133 12.020526 2.9451101 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
30.098969 7.3742169 34.316144 8.4074113 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
85.926356 21.051792 97.965518 24.001362 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
245.30203 60.098507 279.67135 68.518922 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
700.28669 171.56884 798.40402 195.60739 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1999.1741 489.79365 2279.2788 558.41875 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
5707.2297 1398.2598 6506.8709 1594.1704 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
16292.964 3991.7435 18575.774 4551.0276 MAarrowhead1
% End of user PostScript
1 0 .853 r
.40681 .37641 m
.39129 .3893 L
.374 .39899 L
.35463 .40586 L
.33283 .41022 L
.30821 .41227 L
.28034 .4122 L
.24873 .41008 L
.21283 .40599 L
.17202 .39991 L
.12558 .3918 L
.07272 .38158 L
.01252 .3691 L
s
.01252 .3691 m
0 .36638 L
s
1 0 0 r
.40681 .37641 m
.39129 .3893 L
s
% Start of user PostScript
-2.7956182 -3.7077824 -3.2613183 -3.3210839 MAarrowhead1
% End of user PostScript
1 .158 0 r
.374 .39899 m
.35463 .40586 L
s
% Start of user PostScript
-3.7800074 -3.0303336 -4.361141 -2.8241031 MAarrowhead1
% End of user PostScript
1 .473 0 r
.12558 .3918 m
.07272 .38158 L
s
% Start of user PostScript
-11.232542 -3.2460363 -12.818432 -3.5527215 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-32.170232 -7.9976565 -36.680451 -9.0834312 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-91.863714 -22.533667 -104.73543 -25.682698 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-262.25767 -64.259001 -299.00281 -73.260427 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-748.69291 -183.42977 -853.59248 -209.1297 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2137.3641 -523.65029 -2436.8307 -597.01895 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6101.7339 -1494.9127 -6956.6492 -1704.3652 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-17419.192 -4267.6671 -19859.799 -4865.611 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-49728.2 -12183.309 -56695.629 -13890.316 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-141963.75 -34780.836 -161854.33 -39653.986 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-405277.24 -99292.112 -462060.73 -113203.95 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1156982.9 -283458.5 -1319088.1 -323173.94 MAarrowhead1
% End of user PostScript
1 0 .426 r
.38009 .29082 m
.35889 .31542 L
.33544 .33452 L
.30932 .34886 L
.28005 .35899 L
.2471 .36535 L
.20989 .36827 L
.16775 .368 L
.11996 .36467 L
.06568 .35837 L
.00397 .34908 L
s
.00397 .34908 m
0 .34839 L
s
1 0 0 r
.38009 .29082 m
.35889 .31542 L
s
% Start of user PostScript
-3.5973372 -6.2752805 -4.233415 -5.5375102 MAarrowhead1
% End of user PostScript
1 .158 0 r
.33544 .33452 m
.30932 .34886 L
s
% Start of user PostScript
-4.9367365 -4.9642575 -5.7203477 -4.5341926 MAarrowhead1
% End of user PostScript
1 .473 0 r
.00397 .34908 m
0 0 rlineto s
.00397 .34908 m
0 .34839 L
s
% Start of user PostScript
-14.880991 -4.5274512 -16.987554 -4.897495 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-42.667098 -10.660367 -48.650263 -12.091935 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-121.84919 -29.901415 -138.9227 -34.076338 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-347.8645 -85.237519 -396.60415 -97.176746 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-993.08379 -243.30622 -1132.2251 -277.39511 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2835.05 -694.5822 -3232.2695 -791.90008 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8093.4831 -1982.8873 -9227.4629 -2260.7101 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-23105.225 -5660.7339 -26342.503 -6453.8606 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-65960.652 -16160.228 -75202.414 -18424.441 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-188304.06 -46134.117 -214687.38 -52597.979 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-537569.25 -131703.39 -612888.2 -150156.38 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1534649.3 -375986.01 -1749669.4 -428665.5 MAarrowhead1
% End of user PostScript
1 0 .525 r
.33687 .80294 m
.32241 .74259 L
.30454 .69081 L
.28299 .64599 L
.25746 .60674 L
.22755 .57188 L
.19277 .54039 L
.15256 .51138 L
.10624 .48404 L
.05304 .45767 L
s
.05304 .45767 m
0 .435 L
s
1 0 0 r
.33687 .80294 m
.32241 .74259 L
s
% Start of user PostScript
-4.8937785 9.0880816 -5.3276002 7.2775524 MAarrowhead1
% End of user PostScript
1 .158 0 r
.30454 .69081 m
.28299 .64599 L
s
% Start of user PostScript
-5.8639279 5.7242495 -6.5102116 4.3795729 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-15.238185 -2.0519091 -17.332046 -2.8434591 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-43.149168 -10.176655 -49.185143 -11.720863 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-123.09916 -30.066345 -140.34434 -34.306738 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-351.40327 -86.07133 -400.63792 -98.137329 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1003.1793 -245.7718 -1143.7348 -280.20848 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2863.8689 -701.64094 -3265.1262 -799.94837 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8175.7547 -2003.0433 -9321.2616 -2283.6902 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-23340.093 -5718.2761 -26610.279 -6519.4651 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-66631.153 -16324.499 -75966.859 -18611.728 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-190218.2 -46603.078 -216869.71 -53132.646 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-543033.73 -133042.18 -619118.31 -151682.75 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1550249.3 -379807.97 -1767455.1 -433022.95 MAarrowhead1
% End of user PostScript
0 1 .244 r
.52586 .20725 m
.52216 .2559 L
.51916 .2965 L
.51675 .3304 L
.51484 .35871 L
.51337 .38236 L
.51229 .40213 L
.51154 .41866 L
.5111 .43249 L
.51093 .44409 L
.51103 .45382 L
.51138 .462 L
.51197 .4689 L
.51282 .47475 L
.51392 .47972 L
.51529 .48398 L
.51695 .48766 L
.51892 .49088 L
.52123 .49372 L
.52393 .49629 L
.52704 .49864 L
.53064 .50084 L
.53477 .50296 L
.5395 .50504 L
.54492 .50713 L
.55112 .50929 L
.55821 .51157 L
.5663 .51399 L
.57553 .51663 L
.58607 .51952 L
.59809 .52273 L
.6118 .5263 L
.62744 .53031 L
.64527 .53483 L
.6656 .53994 L
.68879 .54573 L
.71523 .55229 L
.74538 .55975 L
.77975 .56823 L
.81894 .57788 L
.86361 .58887 L
.91456 .60139 L
.97263 .61565 L
s
.97263 .61565 m
1 .62236 L
s
1 0 0 r
.52586 .20725 m
.52216 .2559 L
s
% Start of user PostScript
0.77589817 -8.7823644 0.66494642 -7.3230901 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51916 .2965 m
.51675 .3304 L
s
% Start of user PostScript
0.57484051 -6.1049684 0.50247227 -5.0879632 MAarrowhead1
% End of user PostScript
1 .473 0 r
.51103 .45382 m
.51138 .462 L
s
% Start of user PostScript
0.33088786 -1.3854794 0.34134476 -1.1399564 MAarrowhead1
% End of user PostScript
1 .788 0 r
.52123 .49372 m
.52393 .49629 L
s
% Start of user PostScript
0.63698363 -0.18829278 0.71780114 -0.11144415 MAarrowhead1
% End of user PostScript
.897 1 0 r
.55821 .51157 m
.5663 .51399 L
s
% Start of user PostScript
1.7462231 0.34696545 1.9889073 0.41981788 MAarrowhead1
% End of user PostScript
.581 1 0 r
.6656 .53994 m
.68879 .54573 L
s
% Start of user PostScript
4.9681459 1.1982005 5.6637692 1.3717721 MAarrowhead1
% End of user PostScript
.266 1 0 r
.97263 .61565 m
0 0 rlineto s
.97263 .61565 m
1 .62236 L
s
% Start of user PostScript
14.17905 3.4693809 16.16557 3.956813 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
40.477327 9.9158173 46.148589 11.305439 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
115.5542 28.310302 131.74452 32.276939 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
329.88336 80.820705 376.10339 92.144529 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
941.74894 230.72659 1073.6976 263.05375 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
2688.499 658.67686 3065.1852 750.96423 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
7675.1101 1880.3866 8750.4715 2143.848 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
21910.856 5368.1159 24980.791 6120.2439 MAarrowhead1
% End of user PostScript
.2 1 0 r
.46078 .62506 m
.45858 .60221 L
.45553 .58285 L
.45159 .56635 L
.44673 .5522 L
.44086 .53995 L
.43391 .52923 L
.42576 .51971 L
.41628 .51111 L
.40533 .50319 L
.39271 .49573 L
.37822 .48853 L
.3616 .48141 L
.34259 .47422 L
.32084 .46677 L
.296 .45892 L
.26764 .4505 L
.23526 .44133 L
.19832 .43126 L
.15618 .42008 L
.10811 .40759 L
.0533 .39356 L
s
.0533 .39356 m
0 .38008 L
s
1 0 0 r
.46078 .62506 m
.45858 .60221 L
s
% Start of user PostScript
-1.1766061 3.7517266 -1.2425538 3.0662684 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45553 .58285 m
.45159 .56635 L
s
% Start of user PostScript
-1.3341273 2.4854143 -1.4522024 1.99058 MAarrowhead1
% End of user PostScript
1 .473 0 r
.39271 .49573 m
.37822 .48853 L
s
% Start of user PostScript
-3.2187364 -0.12824806 -3.653548 -0.34417315 MAarrowhead1
% End of user PostScript
1 .788 0 r
.19832 .43126 m
.15618 .42008 L
s
% Start of user PostScript
-9.0503119 -2.0622581 -10.314557 -2.3976827 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-25.804249 -6.2855829 -29.418797 -7.1771714 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-73.658173 -18.037557 -83.978228 -20.567365 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-210.2771 -51.515461 -239.73902 -58.733906 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-600.29733 -147.07117 -684.40511 -167.67749 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-1713.725 -419.85908 -1953.8354 -478.68566 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-4892.3313 -1198.6114 -5577.797 -1366.5491 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-13966.597 -3421.7883 -15923.46 -3901.2158 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-39871.753 -9768.4998 -45458.194 -11137.167 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-113825.63 -27887.052 -129773.77 -31794.313 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-324948.7 -79611.782 -370477.34 -90766.207 MAarrowhead1
% End of user PostScript
0 1 .172 r
.48646 .48356 m
.48424 .48519 L
.48176 .48639 L
.47898 .48723 L
.47585 .48772 L
.47231 .48791 L
.46831 .48781 L
.46376 .48743 L
.45859 .48677 L
.45271 .48584 L
.44602 .48463 L
.43841 .48312 L
.42973 .48129 L
.41985 .47912 L
.40859 .47656 L
.39576 .47359 L
.38113 .47015 L
.36446 .46619 L
.34545 .46163 L
.32378 .45641 L
.29908 .45043 L
.27093 .44358 L
.23882 .43577 L
.20222 .42684 L
.1605 .41665 L
.11292 .40503 L
.05869 .39176 L
s
.05869 .39176 m
0 .3774 L
s
1 0 0 r
.48646 .48356 m
.48424 .48519 L
s
% Start of user PostScript
-0.40625305 -0.49334314 -0.47281453 -0.44440817 MAarrowhead1
% End of user PostScript
1 .158 0 r
.48176 .48639 m
.47898 .48723 L
s
% Start of user PostScript
-0.54710469 -0.40817536 -0.63047103 -0.38318417 MAarrowhead1
% End of user PostScript
1 .473 0 r
.44602 .48463 m
.43841 .48312 L
s
% Start of user PostScript
-1.6193757 -0.46111228 -1.8478427 -0.50642238 MAarrowhead1
% End of user PostScript
1 .788 0 r
.34545 .46163 m
.32378 .45641 L
s
% Start of user PostScript
-4.636486 -1.1510438 -5.2864751 -1.3077859 MAarrowhead1
% End of user PostScript
.897 1 0 r
.05869 .39176 m
0 0 rlineto s
.05869 .39176 m
0 .3774 L
s
% Start of user PostScript
-13.239382 -3.2471709 -15.094441 -3.7010688 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-37.796449 -9.2608875 -43.092138 -10.558183 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-107.90124 -26.435784 -123.01931 -30.139649 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-308.03583 -75.468207 -351.1948 -86.042061 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-879.37877 -215.44605 -1002.5887 -245.63224 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-2510.445 -615.054 -2862.184 -701.22936 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-7166.8027 -1755.8523 -8170.9451 -2001.8652 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-20459.744 -5012.5962 -23326.363 -5714.9122 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-58408.348 -14309.928 -66591.955 -16314.896 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-166743.79 -40851.894 -190106.3 -46575.663 MAarrowhead1
% End of user PostScript
1 0 .571 r
.74948 .53936 m
.7839 .5514 L
.82323 .56404 L
.86815 .57756 L
.91942 .59221 L
.97793 .60829 L
s
.97793 .60829 m
1 .61418 L
s
1 0 0 r
.74948 .53936 m
.7839 .5514 L
s
% Start of user PostScript
7.4843488 1.1807454 8.5169983 1.5419086 MAarrowhead1
% End of user PostScript
1 .158 0 r
.82323 .56404 m
.86815 .57756 L
s
% Start of user PostScript
9.6969806 1.9212482 11.0445 2.326683 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
27.587542 6.6521754 31.450226 7.6162051 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
78.734357 19.264702 89.765233 21.971396 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
224.7651 55.061115 256.25684 62.777504 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
641.65676 157.20324 731.5594 179.22944 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1831.7974 448.78637 2088.451 511.66603 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5229.4037 1281.1934 5962.0967 1460.7017 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
14928.869 3657.543 17020.556 4170.0022 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
42618.842 10441.531 48590.178 11904.496 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
121668. 29808.417 138714.94 33984.882 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
347337.06 85096.884 396002.53 97019.828 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
991575.66 242934.05 1130505.6 276971.6 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2830744. 693526.62 3227360.2 790696.79 MAarrowhead1
% End of user PostScript
.47 1 0 r
.4285 .82508 m
.42686 .76792 L
.42361 .71977 L
.41875 .67907 L
.41224 .64451 L
.40401 .61499 L
.39395 .58958 L
.38192 .56749 L
.36773 .54804 L
.35117 .53065 L
.33196 .51483 L
.30979 .50012 L
.28428 .48613 L
.25501 .4725 L
.22148 .4589 L
.18312 .445 L
.13928 .43051 L
.0892 .41511 L
.03203 .3985 L
s
.03203 .3985 m
0 .38958 L
s
1 0 0 r
.4285 .82508 m
.42686 .76792 L
s
% Start of user PostScript
-2.1451464 9.7522513 -2.1940828 8.0375489 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42361 .71977 m
.41875 .67907 L
s
% Start of user PostScript
-2.2915615 6.5930403 -2.4374775 5.3720183 MAarrowhead1
% End of user PostScript
1 .473 0 r
.33196 .51483 m
.30979 .50012 L
s
% Start of user PostScript
-5.0411642 0.44483029 -5.7063555 0.0035516634 MAarrowhead1
% End of user PostScript
1 .788 0 r
.03203 .3985 m
0 0 rlineto s
.03203 .3985 m
0 .38958 L
s
% Start of user PostScript
-14.039095 -3.0450999 -15.996459 -3.5899983 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-39.995979 -9.7063158 -45.597557 -11.094035 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-114.16084 -27.94743 -130.15541 -31.869671 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-325.9011 -79.84001 -371.56305 -91.027943 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-930.37934 -227.93988 -1060.735 -259.87695 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2656.0409 -650.72442 -3028.1794 -741.89765 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-7582.4489 -1857.6847 -8644.8275 -2117.9654 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-21646.328 -5303.3069 -24679.2 -6046.3545 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-61795.801 -15139.848 -70454.025 -17261.095 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-176414.27 -43221.142 -201131.71 -49276.866 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-503626.35 -123387.45 -574189.55 -140675.29 MAarrowhead1
% End of user PostScript
1 .943 0 r
.28765 .22962 m
.25255 .2572 L
.21342 .27779 L
.16954 .29222 L
.12014 .30113 L
.06432 .30498 L
.00112 .30412 L
s
.00112 .30412 m
0 .30404 L
s
1 0 0 r
.28765 .22962 m
.25255 .2572 L
s
% Start of user PostScript
-6.3706274 -8.1113406 -7.4235875 -7.2840914 MAarrowhead1
% End of user PostScript
1 .158 0 r
.21342 .27779 m
.16954 .29222 L
s
% Start of user PostScript
-8.5975098 -6.6662653 -9.9137438 -6.2333076 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-25.500632 -7.3182897 -29.099744 -8.0226856 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-73.02364 -18.142048 -83.261153 -20.608569 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-208.52017 -51.146054 -237.73742 -58.294443 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-595.29445 -145.85981 -678.70163 -166.29211 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1699.4458 -416.36407 -1937.5556 -474.69996 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4851.5679 -1188.6252 -5531.3222 -1355.1635 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-13850.226 -3393.2778 -15790.784 -3868.7107 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-39539.538 -9687.1078 -45079.432 -11044.371 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-112877.23 -27654.695 -128692.48 -31529.4 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-322241.2 -78948.45 -367390.49 -90009.935 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-919932.17 -225381.54 -1048824.1 -256959.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2626216.6 -643417.81 -2994176.4 -733567.23 MAarrowhead1
% End of user PostScript
.892 1 0 r
.54382 .21606 m
.54275 .26461 L
.54272 .30534 L
.54368 .33956 L
.54561 .36838 L
.5485 .39275 L
.55238 .41344 L
.55729 .4311 L
.56329 .44631 L
.57046 .45953 L
.57892 .47117 L
.5888 .48157 L
.60025 .49103 L
.61348 .49983 L
.62869 .50819 L
.64615 .51633 L
.66616 .52446 L
.68904 .53276 L
.71519 .54141 L
.74507 .5506 L
.77917 .56052 L
.81809 .57136 L
.8625 .58333 L
.91316 .59665 L
.97093 .61156 L
s
.97093 .61156 m
1 .61896 L
s
1 0 0 r
.54382 .21606 m
.54275 .26461 L
s
% Start of user PostScript
1.3146347 -8.5182857 1.2823992 -7.0616092 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54272 .30534 m
.54368 .33956 L
s
% Start of user PostScript
1.2815028 -5.8398891 1.3103963 -4.8133079 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57892 .47117 m
.5888 .48157 L
s
% Start of user PostScript
2.3675508 -0.86491109 2.6638936 -0.55292338 MAarrowhead1
% End of user PostScript
1 .788 0 r
.71519 .54141 m
.74507 .5506 L
s
% Start of user PostScript
6.4557651 1.2423665 7.3519775 1.5181454 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
18.358707 4.4181812 20.929 5.0610958 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
52.393612 12.817624 59.734035 14.619112 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
149.56903 36.639722 170.52508 41.774638 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
426.98782 104.61013 486.81316 119.26739 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
1218.9619 298.64299 1389.751 340.48601 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
3479.8849 852.56478 3967.4524 972.01784 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
9934.3536 2433.8967 11326.258 2774.9106 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
28360.531 6948.2733 32334.131 7921.7974 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
80963.466 19835.887 92307.276 22615.098 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
231134. 56627.367 263518.23 64561.44 MAarrowhead1
% End of user PostScript
0 1 .465 r
.38177 .57506 m
.36776 .55439 L
.35135 .53599 L
.3323 .51933 L
.31028 .50392 L
.28493 .48936 L
.25583 .47527 L
.22248 .46128 L
.18431 .44708 L
.14068 .43234 L
.09083 .41676 L
.03392 .4 L
s
.03392 .4 m
0 .39046 L
s
1 0 0 r
.38177 .57506 m
.36776 .55439 L
s
% Start of user PostScript
-3.5467885 2.2517284 -3.9673295 1.6316964 MAarrowhead1
% End of user PostScript
1 .158 0 r
.35135 .53599 m
.3323 .51933 L
s
% Start of user PostScript
-4.4594498 1.0797784 -5.0310814 0.57984152 MAarrowhead1
% End of user PostScript
1 .473 0 r
.09083 .41676 m
.03392 .4 L
s
% Start of user PostScript
-12.275125 -2.4973059 -13.982508 -3.0001149 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-34.935954 -8.4394706 -39.827906 -9.657831 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-99.70982 -24.400584 -113.6795 -27.827786 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-284.64507 -69.73087 -324.5266 -79.502857 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-812.60159 -199.08421 -926.45534 -226.97841 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2319.8096 -568.34835 -2644.8387 -647.97987 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6622.5779 -1622.5182 -7550.4688 -1849.8497 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-18906.094 -4631.9552 -21555.031 -5280.9395 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-53972.999 -13223.277 -61535.168 -15075.993 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-154081.78 -37749.728 -175670.21 -43038.851 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-439871.7 -107767.69 -501502.23 -122867.04 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1255743. -307654.52 -1431685.4 -350760.07 MAarrowhead1
% End of user PostScript
0 1 .593 r
.71267 .6155 m
.74402 .61268 L
.77951 .61261 L
.81975 .61516 L
.86545 .62026 L
.91741 .6279 L
.97652 .63813 L
s
.97652 .63813 m
1 .64265 L
s
1 0 0 r
.71267 .6155 m
.74402 .61268 L
s
% Start of user PostScript
6.3802329 3.4650902 7.320732 3.3804174 MAarrowhead1
% End of user PostScript
1 .158 0 r
.77951 .61261 m
.81975 .61516 L
s
% Start of user PostScript
8.3852907 3.37834 9.5925688 3.4547816 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
24.215999 6.2437439 27.616519 7.0253625 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
69.196893 17.026095 78.893872 19.389742 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
197.55817 48.418495 225.23851 55.197284 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
563.99142 138.18079 643.01249 157.54013 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1610.08 394.46733 1835.6687 449.73595 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4596.4466 1126.1204 5240.4558 1283.9014 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
13121.907 3214.841 14960.42 3665.2731 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
37460.338 9177.7079 42708.915 10463.599 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
106941.54 26200.463 121925.14 29871.416 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
305296.04 74796.919 348071.14 85276.732 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
871557.23 213529.78 993671.31 243447.48 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2488116.1 609583.47 2836726.6 694992.35 MAarrowhead1
% End of user PostScript
1 0 .984 r
.76339 .5932 m
.801 .59766 L
.84376 .60417 L
.89241 .61279 L
.9478 .6236 L
s
.9478 .6236 m
1 .63448 L
s
1 0 0 r
.76339 .5932 m
.801 .59766 L
s
% Start of user PostScript
7.9018397 2.7958641 9.030021 2.9298027 MAarrowhead1
% End of user PostScript
1 .158 0 r
.84376 .60417 m
.89241 .61279 L
s
% Start of user PostScript
10.312784 3.1252154 11.772366 3.3836399 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
29.566439 7.3842737 33.712441 8.3767501 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
84.43557 20.719549 96.266665 23.612676 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
241.05306 59.065267 274.82725 67.338592 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
688.1584 168.59925 784.57647 192.22118 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1964.5507 481.31141 2239.8043 548.74793 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5608.3871 1374.0437 6394.1795 1566.5613 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
16010.788 3922.6111 18254.064 4472.2091 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
45707.499 11198.246 52111.587 12767.234 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
130485.48 31968.682 148767.83 36447.821 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
372509.14 91263.993 424701.48 104051.01 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1063436.8 260539.88 1212435.1 297044.18 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3035892.6 743787.61 3461252.2 847999.87 MAarrowhead1
% End of user PostScript
.856 1 0 r
.31244 .74976 m
.2934 .69611 L
.2705 .64962 L
.24338 .60888 L
.21163 .57264 L
.17473 .53986 L
.13209 .50961 L
.08298 .48105 L
.02659 .45345 L
s
.02659 .45345 m
0 .4422 L
s
1 0 0 r
.31244 .74976 m
.2934 .69611 L
s
% Start of user PostScript
-5.6267646 7.4929162 -6.1979414 5.8832536 MAarrowhead1
% End of user PostScript
1 .158 0 r
.2705 .64962 m
.24338 .60888 L
s
% Start of user PostScript
-6.8851277 4.4886568 -7.6986164 3.2662655 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-18.360204 -3.0481746 -20.897156 -3.9099492 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-52.110424 -12.426473 -59.403292 -14.269618 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-148.69309 -36.349565 -169.52456 -41.466477 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-424.47134 -103.97586 -483.94366 -118.54957 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1211.7742 -296.87785 -1381.5561 -338.47479 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3459.3645 -847.53634 -3944.0568 -966.28517 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-9875.772 -2419.5441 -11259.469 -2758.5471 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-28193.292 -6907.3001 -32143.461 -7875.0835 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-80486.034 -19718.917 -91762.951 -22481.739 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-229771.03 -56293.442 -261964.3 -64180.729 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-655948.89 -160706.17 -747854.04 -183222.74 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1872598.8 -458782.96 -2134969. -523063.14 MAarrowhead1
% End of user PostScript
1 0 .675 r
.29057 .65545 m
.26629 .61525 L
.23777 .57968 L
.20455 .5477 L
.1661 .51839 L
.12177 .49093 L
.07082 .4646 L
.01239 .43873 L
s
.01239 .43873 m
0 .4339 L
s
1 0 0 r
.29057 .65545 m
.26629 .61525 L
s
% Start of user PostScript
-6.2828276 4.663645 -7.0112565 3.4575496 MAarrowhead1
% End of user PostScript
1 .158 0 r
.23777 .57968 m
.20455 .5477 L
s
% Start of user PostScript
-7.8669041 2.3905325 -8.8634271 1.4310432 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-21.552634 -4.2664855 -24.547557 -5.1682018 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-61.315649 -14.78415 -69.900771 -16.926927 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-174.9936 -42.817183 -199.51062 -48.833065 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-499.5589 -122.3778 -569.55189 -139.52812 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1426.1349 -349.39711 -1625.9509 -398.35214 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4071.3203 -997.46459 -4641.7539 -1137.2198 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-11622.779 -2847.5575 -13251.25 -3246.5295 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-33180.638 -8129.1899 -37829.585 -9268.1726 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-94723.879 -23207.161 -107995.66 -26458.721 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-270417.14 -66251.657 -308305.34 -75534.192 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-771985.15 -189134.82 -880148.17 -215634.54 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2203858.4 -539940.9 -2512641.5 -615592.14 MAarrowhead1
% End of user PostScript
1 .484 0 r
.79393 .44297 m
.83195 .47366 L
.87583 .50225 L
.92628 .52949 L
.98417 .55609 L
s
.98417 .55609 m
1 .56244 L
s
1 0 0 r
.79393 .44297 m
.83195 .47366 L
s
% Start of user PostScript
8.8178488 -1.7109788 9.9585419 -0.79015158 MAarrowhead1
% End of user PostScript
1 .158 0 r
.87583 .50225 m
.92628 .52949 L
s
% Start of user PostScript
11.274759 0.067425394 12.788493 0.88474292 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
31.621819 7.1145136 36.036867 8.3010218 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
90.141036 21.935796 102.76708 25.053766 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
257.3029 63.003809 293.35281 71.841745 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
734.5394 179.95249 837.45568 205.16813 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2096.9568 513.74828 2390.7618 585.73025 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5986.3786 1466.6503 6825.1315 1672.1432 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
17089.876 4186.9854 19484.343 4773.6249 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
48788.072 11952.98 55623.78 13627.715 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
139279.88 34123.293 158794.42 38904.315 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
397615.34 97414.962 453325.32 111063.8 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1135109.8 278099.63 1294150.3 317064.23 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3240504.3 793917.08 3694532.1 905152.98 MAarrowhead1
% End of user PostScript
0 .57 1 r
.45537 .74763 m
.45544 .70482 L
.45448 .66884 L
.45251 .63854 L
.44953 .61293 L
.44553 .59119 L
.44045 .57263 L
.43425 .55666 L
.42682 .54278 L
.41805 .53058 L
.40781 .51968 L
.39592 .50976 L
.38221 .50056 L
.36642 .49182 L
.34831 .48331 L
.32755 .47484 L
.30381 .46619 L
.27667 .45718 L
.24567 .44761 L
.21028 .4373 L
.16989 .42603 L
.12381 .4136 L
.07124 .39976 L
.01129 .38428 L
s
.01129 .38428 m
0 .3814 L
s
1 0 0 r
.45537 .74763 m
.45544 .70482 L
s
% Start of user PostScript
-1.3390451 7.4290188 -1.3367507 6.1444737 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45448 .66884 m
.45251 .63854 L
s
% Start of user PostScript
-1.3655967 5.0652015 -1.424734 4.1561391 MAarrowhead1
% End of user PostScript
1 .473 0 r
.40781 .51968 m
.39592 .50976 L
s
% Start of user PostScript
-2.7658036 0.59027702 -3.1222805 0.2928904 MAarrowhead1
% End of user PostScript
1 .788 0 r
.24567 .44761 m
.21028 .4373 L
s
% Start of user PostScript
-7.6298367 -1.5715869 -8.6915664 -1.8810295 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-21.719161 -5.2512476 -24.760526 -6.0079568 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-61.989061 -15.170782 -70.673961 -17.301285 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-176.96254 -43.351615 -201.75671 -49.426775 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-505.19075 -123.76982 -575.97312 -141.11151 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-1442.2152 -353.33963 -1644.2843 -402.84619 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-4117.2269 -1008.7123 -4694.0925 -1150.0432 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-11753.834 -2879.6657 -13400.666 -3283.1363 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-33554.771 -8220.8517 -38256.138 -9372.6771 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-95791.95 -23468.836 -109213.38 -26757.06 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-273466.26 -66998.687 -311781.68 -76385.888 MAarrowhead1
% End of user PostScript
0 1 .859 r
.77537 .50819 m
.8125 .5271 L
.85507 .54573 L
.90381 .56451 L
.95955 .58386 L
s
.95955 .58386 m
1 .5968 L
s
1 0 0 r
.77537 .50819 m
.8125 .5271 L
s
% Start of user PostScript
8.2611067 0.24559442 9.3750345 0.81312349 MAarrowhead1
% End of user PostScript
1 .158 0 r
.85507 .54573 m
.90381 .56451 L
s
% Start of user PostScript
10.652248 1.371848 12.11443 1.9351664 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
30.150294 7.096089 34.367542 8.1774618 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
86.011897 21.004491 98.061372 23.967896 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
245.53191 60.1388 279.93305 68.569666 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
700.9396 171.72504 799.14831 195.7866 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2001.0372 490.24922 2281.4029 558.93842 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5712.5483 1399.5627 6512.9347 1595.6558 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
16308.147 3995.4634 18593.085 4555.2687 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
46556.396 11406.224 53079.424 13004.353 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
132908.91 32562.417 151530.81 37124.745 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
379427.53 92958.984 432589.2 105983.49 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1083187.3 265378.73 1234953. 302561. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3092276.4 757601.53 3525536. 863749.26 MAarrowhead1
% End of user PostScript
1 0 .514 r
.3715 .5236 m
.35485 .51039 L
.33563 .49807 L
.31354 .48631 L
.2882 .4748 L
.25918 .46327 L
.22598 .45144 L
.18804 .43907 L
.14472 .42589 L
.09525 .41163 L
.03881 .39601 L
s
.03881 .39601 m
0 .3856 L
s
1 0 0 r
.3715 .5236 m
.35485 .51039 L
s
% Start of user PostScript
-3.8549762 0.70791394 -4.3546445 0.311749 MAarrowhead1
% End of user PostScript
1 .158 0 r
.33563 .49807 m
.31354 .48631 L
s
% Start of user PostScript
-4.9310233 -0.057858457 -5.5937502 -0.41078295 MAarrowhead1
% End of user PostScript
1 .473 0 r
.03881 .39601 m
0 0 rlineto s
.03881 .39601 m
0 .3856 L
s
% Start of user PostScript
-13.835774 -3.1196565 -15.767695 -3.6377172 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-39.441626 -9.5997033 -44.966249 -10.963731 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-112.58441 -27.568064 -128.35827 -31.435095 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-321.40213 -78.739383 -366.43378 -89.772624 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-917.53607 -224.79368 -1046.0922 -256.28982 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2619.3761 -641.7417 -2986.3775 -731.65634 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7477.7784 -1832.0407 -8525.4917 -2088.7284 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-21347.515 -5230.0985 -24338.52 -5962.8888 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-60942.753 -14930.852 -69481.456 -17022.818 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-173978.99 -42624.504 -198355.23 -48596.633 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-496674.13 -121684.17 -566263.26 -138733.37 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1417902.2 -347383.2 -1616564.8 -396055.14 MAarrowhead1
% End of user PostScript
1 .632 0 r
.28199 .22432 m
.24601 .25232 L
.20588 .27321 L
.16088 .28782 L
.11021 .2968 L
.05296 .30061 L
s
.05296 .30061 m
0 .2998 L
s
1 0 0 r
.28199 .22432 m
.24601 .25232 L
s
% Start of user PostScript
-6.5402189 -8.270537 -7.6198208 -7.4303246 MAarrowhead1
% End of user PostScript
1 .158 0 r
.20588 .27321 m
.16088 .28782 L
s
% Start of user PostScript
-8.8236404 -6.8035617 -10.173563 -6.3652902 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-26.163367 -7.4998878 -29.855806 -8.2239629 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-74.919646 -18.611081 -85.42292 -21.141964 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-213.93382 -52.473448 -243.90961 -59.807501 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-610.74954 -149.64652 -696.32214 -170.6093 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1743.5669 -427.17372 -1987.8586 -487.02413 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4977.5246 -1219.4844 -5674.9268 -1390.3463 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-14209.806 -3481.3743 -16200.746 -3969.1504 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-40566.067 -9938.6052 -46249.787 -11331.105 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-115807.75 -28372.668 -132033.6 -32347.969 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-330607.25 -80998.115 -376928.71 -92346.779 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-943815.51 -231232.91 -1076053.7 -263631.01 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2694398.6 -660122.27 -3071911.4 -752612.16 MAarrowhead1
% End of user PostScript
.233 0 1 r
.26079 .5121 m
.22901 .4926 L
.19249 .47388 L
.15061 .45546 L
.10266 .43691 L
.04782 .4178 L
s
.04782 .4178 m
0 .40247 L
s
1 0 0 r
.26079 .5121 m
.22901 .4926 L
s
% Start of user PostScript
-7.1761611 0.36306905 -8.1296833 -0.22196119 MAarrowhead1
% End of user PostScript
1 .158 0 r
.19249 .47388 m
.15061 .45546 L
s
% Start of user PostScript
-9.2254071 -0.78361131 -10.481831 -1.3360585 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-26.026894 -6.0298249 -29.66504 -6.9786027 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-74.228685 -18.10447 -84.62689 -20.665496 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-211.89051 -51.893635 -241.57807 -59.170195 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-604.89969 -148.19473 -689.65222 -168.95967 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1726.8629 -423.07691 -1968.8141 -482.35462 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4929.8373 -1207.8 -5620.5579 -1377.0252 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-14073.669 -3448.0206 -16045.533 -3931.1235 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-40177.421 -9843.3877 -45806.689 -11222.547 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-114698.25 -28100.842 -130768.65 -32038.057 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-327439.85 -80222.108 -373317.52 -91462.046 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-934773.24 -229017.57 -1065744.5 -261105.28 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2668584.8 -653797.93 -3042480.8 -745401.71 MAarrowhead1
% End of user PostScript
0 1 .547 r
.33552 .56611 m
.31508 .54348 L
.29134 .52295 L
.26392 .50396 L
.23236 .48599 L
.19612 .46857 L
.1546 .45127 L
.10708 .43368 L
.05276 .41541 L
s
.05276 .41541 m
0 .39897 L
s
1 0 0 r
.33552 .56611 m
.31508 .54348 L
s
% Start of user PostScript
-4.9344018 1.983376 -5.5476085 1.3042777 MAarrowhead1
% End of user PostScript
1 .158 0 r
.29134 .52295 m
.26392 .50396 L
s
% Start of user PostScript
-6.2596793 0.68857413 -7.0823211 0.11888193 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-17.403953 -3.7421537 -19.82965 -4.4228875 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-49.575243 -12.023319 -56.518242 -13.744637 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-141.50139 -34.638791 -161.32648 -39.500664 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-403.95126 -98.960496 -460.5488 -112.8279 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1153.1961 -282.52916 -1314.7707 -322.11486 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3292.1368 -806.56654 -3753.3988 -919.57488 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-9398.3714 -2302.5821 -10715.179 -2625.1974 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-26830.412 -6573.3972 -30589.627 -7494.3974 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-76595.292 -18765.693 -87327.076 -21394.959 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-218663.76 -53572.184 -249300.79 -61078.195 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-624239.94 -152937.54 -711702.34 -174365.65 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1782076.3 -436605.12 -2031763.4 -497777.97 MAarrowhead1
% End of user PostScript
1 0 .307 r
.54829 .1848 m
.54705 .23868 L
.54696 .28386 L
.54797 .32182 L
.55004 .35379 L
.55317 .38081 L
.55738 .40375 L
.56272 .42333 L
.56925 .44018 L
.57707 .45482 L
.58631 .46769 L
.59709 .47919 L
.6096 .48964 L
.62405 .49935 L
.64067 .50856 L
.65974 .51753 L
.68159 .52646 L
.70659 .53557 L
.73517 .54507 L
.76781 .55514 L
.80508 .56601 L
.84761 .57788 L
.89614 .59097 L
.95149 .60554 L
s
.95149 .60554 m
1 .61807 L
s
1 0 0 r
.54829 .1848 m
.54705 .23868 L
s
% Start of user PostScript
1.4486282 -9.4558644 1.4114092 -7.8396426 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54696 .28386 m
.54797 .32182 L
s
% Start of user PostScript
1.4087668 -6.484218 1.4389535 -5.3454093 MAarrowhead1
% End of user PostScript
1 .473 0 r
.58631 .46769 m
.59709 .47919 L
s
% Start of user PostScript
2.589164 -0.96922908 2.9126739 -0.62430828 MAarrowhead1
% End of user PostScript
1 .788 0 r
.73517 .54507 m
.76781 .55514 L
s
% Start of user PostScript
7.0551532 1.3519723 8.0344343 1.6542728 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
20.062025 4.8267456 22.870755 5.5295258 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
57.254397 14.006454 65.275816 15.975124 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
163.44514 40.038858 186.34536 45.650173 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
466.60114 114.3152 531.97671 130.33227 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
1332.0498 326.34926 1518.6836 372.07421 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
3802.7274 931.66053 4335.5284 1062.1957 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
10856.002 2659.6988 12377.039 3032.3498 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
30991.648 7592.8916 35333.894 8656.7334 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
88474.762 21676.14 100870.98 24713.188 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
252577.2 61880.908 287965.85 70551.056 MAarrowhead1
% End of user PostScript
0 1 .484 r
.4331 .30093 m
.41925 .3278 L
.40421 .34936 L
.38768 .36638 L
.36934 .37947 L
.34887 .38912 L
.32588 .39572 L
.29998 .39958 L
.27069 .40093 L
.23752 .3999 L
.19986 .39661 L
.15708 .39107 L
.10842 .38328 L
.05305 .37316 L
s
.05305 .37316 m
0 .36258 L
s
1 0 0 r
.4331 .30093 m
.41925 .3278 L
s
% Start of user PostScript
-2.0069975 -5.9721741 -2.4223706 -5.1659973 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40421 .34936 m
.38768 .36638 L
s
% Start of user PostScript
-2.8737137 -4.5190509 -3.3697488 -4.0085522 MAarrowhead1
% End of user PostScript
1 .473 0 r
.19986 .39661 m
.15708 .39107 L
s
% Start of user PostScript
-9.0041201 -3.101772 -10.28762 -3.2678239 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-25.892811 -6.5540207 -29.525808 -7.4092519 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-73.962756 -18.170115 -84.326904 -20.701128 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-211.15877 -51.745074 -240.74456 -58.991611 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-602.81718 -147.69173 -687.2781 -168.38403 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1720.9193 -421.62242 -1962.0377 -480.69585 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-4912.8698 -1203.6434 -5601.2131 -1372.2861 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-14025.23 -3436.1533 -15990.308 -3917.5935 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-40039.139 -9809.5089 -45649.032 -11183.921 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-114303.48 -28004.125 -130318.57 -31927.789 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-326312.87 -79946.001 -372032.64 -91147.253 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-931555.95 -228229.34 -1062076.5 -260206.61 MAarrowhead1
% End of user PostScript
0 1 .654 r
.36051 .22893 m
.33517 .26196 L
.30723 .28786 L
.27619 .30758 L
.24146 .32186 L
.20243 .33132 L
.15839 .3364 L
.10857 .33743 L
.05209 .33464 L
s
.05209 .33464 m
0 .32936 L
s
1 0 0 r
.36051 .22893 m
.33517 .26196 L
s
% Start of user PostScript
-4.1846673 -8.1322191 -4.9449746 -7.1410867 MAarrowhead1
% End of user PostScript
1 .158 0 r
.30723 .28786 m
.27619 .30758 L
s
% Start of user PostScript
-5.7829836 -6.3640506 -6.7143565 -5.7726327 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-17.546991 -5.4606127 -20.033943 -5.8774641 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-50.336713 -12.605152 -57.396079 -14.289495 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-143.75815 -35.284504 -163.90171 -40.209024 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-410.4133 -100.56548 -467.91677 -114.65122 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1171.6485 -287.05507 -1335.8085 -327.27336 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3344.8155 -819.47394 -3813.4584 -934.29037 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-9548.7587 -2339.427 -10886.637 -2667.2045 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-27259.737 -6678.5809 -31079.105 -7614.3184 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-77820.926 -19065.971 -88724.433 -21737.309 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-222162.69 -54429.415 -253289.96 -62055.533 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-634228.67 -155384.75 -723090.59 -177155.75 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1810592. -443591.42 -2064274.5 -505743.12 MAarrowhead1
% End of user PostScript
0 1 .598 r
.64815 .52654 m
.66867 .53318 L
.69211 .54027 L
.71886 .54795 L
.74938 .55637 L
.78421 .56568 L
.82393 .57607 L
.86923 .58771 L
.9209 .60083 L
.97982 .61564 L
s
.97982 .61564 m
1 .62068 L
s
1 0 0 r
.64815 .52654 m
.66867 .53318 L
s
% Start of user PostScript
4.4446134 0.79610509 5.0601805 0.99542835 MAarrowhead1
% End of user PostScript
1 .158 0 r
.69211 .54027 m
.71886 .54795 L
s
% Start of user PostScript
5.7631825 1.2081363 6.5656731 1.4385135 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
16.40994 3.9725417 18.707969 4.5434832 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
46.836955 11.463722 53.399016 13.073276 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
133.70749 32.755428 152.44121 37.34559 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
381.70675 93.51677 435.18775 106.61961 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1089.6939 266.97268 1242.3712 304.37833 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3110.8513 762.15232 3546.7134 868.93767 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
8880.839 2175.7878 10125.135 2480.6379 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
25352.964 6211.4253 28905.173 7081.7096 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
72377.482 17732.338 82518.308 20216.82 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
206622.78 50622.169 235572.75 57714.852 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
589865.43 144515.85 672511.61 164764. MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1683944.2 412562.95 1919882. 470367.24 MAarrowhead1
% End of user PostScript
1 0 .046 r
.33146 .25885 m
.30295 .28497 L
.27126 .30483 L
.23581 .3192 L
.19595 .32866 L
.15098 .33369 L
.1001 .33461 L
.04242 .33165 L
s
.04242 .33165 m
0 .32729 L
s
1 0 0 r
.33146 .25885 m
.30295 .28497 L
s
% Start of user PostScript
-5.0562175 -7.2346261 -5.9114355 -6.4508248 MAarrowhead1
% End of user PostScript
1 .158 0 r
.27126 .30483 m
.23581 .3192 L
s
% Start of user PostScript
-6.8621598 -5.8549859 -7.9258005 -5.4241118 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-20.46557 -5.9940462 -23.356999 -6.5400811 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-58.630558 -14.594484 -66.850933 -16.570336 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-167.42642 -41.07317 -190.8859 -46.811743 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-477.97923 -117.11664 -544.94933 -133.52208 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1364.5348 -334.31127 -1555.7201 -381.15081 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3895.466 -954.38208 -4441.2607 -1088.1006 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-11120.752 -2724.5622 -12678.883 -3106.3012 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-31747.454 -7778.0627 -36195.597 -8867.8489 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-90632.433 -22204.765 -103330.96 -25315.879 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-258736.9 -63390.024 -294988.59 -72271.615 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-738640.5 -180965.44 -842131.59 -206320.55 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2108666.3 -516619.02 -2404112. -589002.63 MAarrowhead1
% End of user PostScript
1 0 .714 r
.81478 .23189 m
.85043 .29781 L
.89247 .35584 L
.94158 .40768 L
.99854 .45485 L
s
.99854 .45485 m
1 .45583 L
s
1 0 0 r
.81478 .23189 m
.85043 .29781 L
s
% Start of user PostScript
9.4432579 -8.0434268 10.512795 -6.0655585 MAarrowhead1
% End of user PostScript
1 .158 0 r
.89247 .35584 m
.94158 .40768 L
s
% Start of user PostScript
11.774193 -4.3249451 13.247373 -2.7696126 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
32.100557 6.1717219 36.556729 7.5439278 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
91.285366 21.967242 104.06565 25.164237 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
260.51751 63.732937 297.0164 72.690552 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
743.70419 182.18412 847.90422 207.71655 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2123.1175 520.15439 2420.5878 593.03488 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6061.0614 1484.9467 6910.2781 1693.0033 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
17303.08 4239.2197 19727.419 4833.1778 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
49396.725 12102.099 56317.711 13797.726 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
141017.46 34548.996 160775.45 39389.664 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
402575.77 98630.257 458980.75 112449.37 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1149270.8 281569.04 1310295.4 321019.75 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3280931.1 803821.54 3740623.1 916445.16 MAarrowhead1
% End of user PostScript
1 0 .857 r
.74947 .6093 m
.7856 .61017 L
.8266 .61355 L
.87318 .61941 L
.92615 .62775 L
.98643 .63865 L
s
.98643 .63865 m
1 .64134 L
s
1 0 0 r
.74947 .6093 m
.7856 .61017 L
s
% Start of user PostScript
7.4840688 3.2788951 8.5680475 3.3050242 MAarrowhead1
% End of user PostScript
1 .158 0 r
.8266 .61355 m
.87318 .61941 L
s
% Start of user PostScript
9.7980406 3.406595 11.195477 3.5822856 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
28.18243 7.1408752 32.136861 8.0705657 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
80.504581 19.778931 91.785454 22.533532 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
229.83561 56.322289 262.03825 64.209713 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
656.136 160.75506 748.06744 183.27758 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1873.1336 458.9147 2135.5788 523.21313 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5347.4102 1310.105 6096.6371 1493.664 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
15265.753 3740.079 17404.642 4264.1024 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
43580.577 10677.154 49686.662 12173.133 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
124413.56 30481.073 141845.17 34751.783 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
355175.05 87017.177 404938.71 99209.173 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1013951.5 248416.09 1156016.5 283221.73 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2894622.5 709176.71 3300188.7 808539.62 MAarrowhead1
% End of user PostScript
.936 0 1 r
.33996 .54946 m
.3197 .52981 L
.29625 .51181 L
.26922 .49496 L
.23814 .47881 L
.20251 .46296 L
.1617 .44703 L
.11503 .43064 L
.06171 .41344 L
.00081 .39507 L
s
.00081 .39507 m
0 .39484 L
s
1 0 0 r
.33996 .54946 m
.3197 .52981 L
s
% Start of user PostScript
-4.8013256 1.4838685 -5.408914 0.8943009 MAarrowhead1
% End of user PostScript
1 .158 0 r
.29625 .51181 m
.26922 .49496 L
s
% Start of user PostScript
-6.1124212 0.35424524 -6.9234989 -0.1512489 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-17.06126 -3.7451682 -19.441073 -4.4002513 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-48.615172 -11.808525 -55.424155 -13.493626 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-138.76487 -33.973143 -158.20666 -38.740315 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-396.14006 -97.047893 -451.6432 -110.64698 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1130.897 -277.06618 -1289.3472 -315.88638 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3228.4774 -790.97019 -3680.8201 -901.79329 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-9216.637 -2258.0575 -10507.982 -2574.4345 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-26311.598 -6446.2888 -29998.122 -7349.4798 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-75114.185 -18402.825 -85638.45 -20981.249 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-214435.51 -52536.27 -244480.11 -59897.138 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-612169.14 -149980.21 -697940.3 -170993.98 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1747616.6 -428162.58 -1992475.6 -488152.54 MAarrowhead1
% End of user PostScript
0 .964 1 r
.72263 .82184 m
.76036 .7868 L
.8023 .76013 L
.84921 .7408 L
.90194 .728 L
.96143 .72111 L
s
.96143 .72111 m
1 .7203 L
s
1 0 0 r
.72263 .82184 m
.76036 .7868 L
s
% Start of user PostScript
6.6788151 9.6551551 7.8109025 8.6040388 MAarrowhead1
% End of user PostScript
1 .158 0 r
.8023 .76013 m
.84921 .7408 L
s
% Start of user PostScript
9.0690833 7.8039021 10.476413 7.223932 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
27.06128 7.9406402 30.884931 8.6602879 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
77.529312 19.302281 88.399496 21.914469 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
221.39475 54.313533 252.41619 61.901752 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
632.05151 154.86832 720.60881 176.56187 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1804.3803 442.07354 2057.1925 504.01137 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5151.1344 1262.0185 5872.861 1438.84 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
14705.426 3602.8002 16765.807 4107.5894 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
41980.959 10285.251 47862.921 11726.32 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
119846.98 29362.27 136638.77 33476.225 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
342138.41 83823.226 390075.5 95567.717 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
976734.6 239298.02 1113585.1 272826.12 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2788375.8 683146.5 3179055.8 778862.31 MAarrowhead1
% End of user PostScript
.937 1 0 r
.22019 .50846 m
.18288 .48656 L
.14002 .46542 L
.09089 .4445 L
.03467 .42331 L
s
.03467 .42331 m
0 .41149 L
s
1 0 0 r
.22019 .50846 m
.18288 .48656 L
s
% Start of user PostScript
-8.3941829 0.25391301 -9.513729 -0.40314673 MAarrowhead1
% End of user PostScript
1 .158 0 r
.14002 .46542 m
.09089 .4445 L
s
% Start of user PostScript
-10.799506 -1.0375191 -12.273252 -1.6650356 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-30.492986 -7.0930746 -34.75612 -8.200098 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-86.971968 -21.219285 -99.15546 -24.218906 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-248.26843 -60.804448 -283.05287 -69.330015 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-708.7508 -173.63764 -808.05392 -197.96751 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2023.3363 -495.7122 -2306.8264 -565.1669 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5776.2077 -1415.159 -6585.5134 -1613.4374 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-16489.881 -4039.9879 -18800.283 -4606.0315 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-47075.211 -11533.332 -53670.929 -13149.27 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-134390.02 -32925.285 -153219.43 -37538.454 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-383655.78 -93994.899 -437409.88 -107164.55 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1095258.1 -268336.05 -1248715. -305932.67 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3126736.1 -766044.08 -3564823.8 -873374.69 MAarrowhead1
% End of user PostScript
.073 0 1 r
.45416 .50604 m
.44816 .50171 L
.44125 .49763 L
.43331 .49369 L
.42421 .4898 L
.4138 .48586 L
.40189 .48179 L
.38829 .47749 L
.37276 .47288 L
.35503 .46786 L
.3348 .46235 L
.31172 .45623 L
.2854 .44939 L
.25538 .44171 L
.22115 .43305 L
.18211 .42326 L
.1376 .41216 L
.08685 .39957 L
.02898 .38526 L
s
.02898 .38526 m
0 .37812 L
s
1 0 0 r
.45416 .50604 m
.44816 .50171 L
s
% Start of user PostScript
-1.3752107 0.18106658 -1.5552103 0.051152113 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44125 .49763 m
.43331 .49369 L
s
% Start of user PostScript
-1.7625307 -0.071239011 -2.0006517 -0.18931464 MAarrowhead1
% End of user PostScript
1 .473 0 r
.3348 .46235 m
.31172 .45623 L
s
% Start of user PostScript
-4.9560244 -1.1295506 -5.6483414 -1.3131933 MAarrowhead1
% End of user PostScript
1 .788 0 r
.02898 .38526 m
0 0 rlineto s
.02898 .38526 m
0 .37812 L
s
% Start of user PostScript
-14.130668 -3.4421054 -16.110032 -3.9303392 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-40.335972 -9.8775644 -45.987339 -11.262912 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-115.1499 -28.210399 -131.28355 -32.163293 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-328.72899 -80.537686 -374.78727 -91.821917 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-938.4534 -229.91914 -1069.9403 -262.13319 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2679.0909 -656.37189 -3054.4589 -748.33631 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-7648.2519 -1873.8064 -8719.8503 -2136.3459 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-21834.182 -5349.3309 -24893.374 -6098.8268 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-62332.086 -15271.236 -71065.449 -17410.893 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-177945.25 -43596.23 -202877.2 -49704.508 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-507996.99 -124458.25 -579172.56 -141896.12 MAarrowhead1
% End of user PostScript
1 .035 0 r
.26425 .56815 m
.2343 .53995 L
.19964 .51406 L
.1597 .48975 L
.11382 .4664 L
.0612 .4434 L
.00097 .42021 L
s
.00097 .42021 m
0 .41987 L
s
1 0 0 r
.26425 .56815 m
.2343 .53995 L
s
% Start of user PostScript
-7.0725956 2.0444499 -7.971065 1.1985586 MAarrowhead1
% End of user PostScript
1 .158 0 r
.19964 .51406 m
.1597 .48975 L
s
% Start of user PostScript
-9.0107391 0.42174267 -10.208864 -0.30739803 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-25.17225 -5.5497647 -28.684024 -6.5124242 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-71.732074 -17.429249 -81.778922 -19.914723 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-204.74987 -50.129269 -233.43658 -57.163096 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-584.5115 -143.19616 -666.40735 -163.2618 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1668.6581 -408.81602 -1902.4541 -466.09589 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4763.6743 -1167.0902 -5431.1138 -1330.6116 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-13599.308 -3331.803 -15504.71 -3798.6228 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-38823.218 -9511.6108 -44262.749 -10844.285 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-110832.28 -27153.687 -126361.02 -30958.196 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-316403.31 -77518.176 -360734.64 -88379.266 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-903266.18 -221298.41 -1029823. -252304.58 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2578638.6 -631761.31 -2939932.3 -720277.53 MAarrowhead1
% End of user PostScript
0 1 .86 r
.64556 .21079 m
.658 .26766 L
.6735 .31636 L
.69227 .35842 L
.71459 .39515 L
.7408 .42765 L
.77133 .45689 L
.80666 .4837 L
.84739 .50883 L
.89419 .53293 L
.94786 .55663 L
s
.94786 .55663 m
1 .57686 L
s
1 0 0 r
.64556 .21079 m
.658 .26766 L
s
% Start of user PostScript
4.3667045 -8.6763547 4.7399191 -6.9702776 MAarrowhead1
% End of user PostScript
1 .158 0 r
.6735 .31636 m
.69227 .35842 L
s
% Start of user PostScript
5.2049543 -5.5092003 5.7681264 -4.2472596 MAarrowhead1
% End of user PostScript
1 .473 0 r
.94786 .55663 m
0 0 rlineto s
.94786 .55663 m
1 .57686 L
s
% Start of user PostScript
13.435927 1.6987629 15.279438 2.4143319 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
38.022639 8.9414232 43.340843 10.30634 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
108.46833 26.486696 123.6637 30.224082 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
309.63629 75.839648 353.019 86.471741 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
883.94342 216.55953 1007.7928 246.90318 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2523.4751 618.24522 2877.0398 704.86804 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
7204.0008 1764.9655 8213.355 2012.2553 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
20565.936 5038.6132 23447.434 5744.5745 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
58711.507 14384.202 66937.589 16399.575 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
167609.24 41063.929 191093.01 46817.405 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
478489.82 117229.05 545531.14 133654.04 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1365989.7 334664.75 1557378.9 381554.71 MAarrowhead1
% End of user PostScript
0 .109 1 r
.38172 .39228 m
.36322 .40079 L
.34245 .40658 L
.31903 .40993 L
.29256 .41102 L
.26256 .40999 L
.22851 .40692 L
.18982 .40185 L
.14582 .39474 L
.09574 .38553 L
.03872 .37412 L
s
.03872 .37412 m
0 .3659 L
s
1 0 0 r
.38172 .39228 m
.36322 .40079 L
s
% Start of user PostScript
-3.5483891 -3.2317208 -4.1033902 -2.9763233 MAarrowhead1
% End of user PostScript
1 .158 0 r
.34245 .40658 m
.31903 .40993 L
s
% Start of user PostScript
-4.726571 -2.8024678 -5.4290717 -2.702142 MAarrowhead1
% End of user PostScript
1 .473 0 r
.03872 .37412 m
0 0 rlineto s
.03872 .37412 m
0 .3659 L
s
% Start of user PostScript
-13.83834 -3.776495 -15.786687 -4.1898663 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-39.586605 -9.789304 -45.135313 -11.133706 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-113.03061 -27.713562 -128.86788 -31.590134 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-322.68355 -79.061822 -367.89493 -90.137693 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-921.19602 -225.69235 -1050.265 -257.31381 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2629.8249 -644.30211 -2998.2903 -734.57534 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7507.6077 -1839.3489 -8559.5004 -2097.0605 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-21432.672 -5250.9617 -24435.608 -5986.6751 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-61185.857 -14990.413 -69758.622 -17090.723 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-174673. -42794.536 -199146.48 -48790.488 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-498655.4 -122169.57 -568522.12 -139286.78 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1423558.3 -348768.94 -1623013.4 -397635.03 MAarrowhead1
% End of user PostScript
.414 0 1 r
.80428 .19659 m
.83766 .26738 L
.87725 .32932 L
.92367 .38428 L
.97765 .43388 L
s
.97765 .43388 m
1 .45021 L
s
1 0 0 r
.80428 .19659 m
.83766 .26738 L
s
% Start of user PostScript
9.1284498 -9.102407 10.129842 -6.9785717 MAarrowhead1
% End of user PostScript
1 .158 0 r
.87725 .32932 m
.92367 .38428 L
s
% Start of user PostScript
11.317529 -5.120303 12.709992 -3.4715151 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
30.653503 5.6567129 34.902999 7.0048708 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
87.120661 20.909215 99.316503 23.969267 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
248.62023 60.809279 283.45197 69.359913 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
709.73806 173.86041 809.17903 198.22723 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2026.1507 496.39724 2310.0351 565.94926 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5784.2413 1417.1262 6594.6726 1615.6805 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
16512.816 4045.6065 18826.43 4612.4374 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
47140.683 11549.373 53745.575 13167.558 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
134576.93 32971.078 153432.53 37590.663 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
384189.37 94125.627 438018.23 107313.59 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1096781.4 268709.25 1250451.7 306358.17 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3131084.7 767109.49 3569781.7 874589.38 MAarrowhead1
% End of user PostScript
.285 1 0 r
.33329 .53868 m
.31188 .52026 L
.28714 .50321 L
.25868 .48706 L
.22599 .4714 L
.18855 .45585 L
.1457 .44002 L
.09671 .42358 L
.04075 .40616 L
s
.04075 .40616 m
0 .3942 L
s
1 0 0 r
.33329 .53868 m
.31188 .52026 L
s
% Start of user PostScript
-5.0013555 1.1604681 -5.6436878 0.60784673 MAarrowhead1
% End of user PostScript
1 .158 0 r
.28714 .50321 m
.25868 .48706 L
s
% Start of user PostScript
-6.385694 0.096286305 -7.2397363 -0.38809003 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-17.881465 -3.9909663 -20.377294 -4.6670432 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-50.966094 -12.395027 -58.104724 -14.159146 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-145.47848 -35.620437 -165.86098 -40.61767 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-415.30655 -101.74422 -473.49512 -116.00114 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1185.6135 -290.47174 -1351.73 -331.17016 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3384.6817 -829.23997 -3858.9102 -945.42505 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-9662.5681 -2367.3098 -11016.393 -2698.9941 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-27584.639 -6758.1814 -31449.529 -7705.0717 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-78748.456 -19293.214 -89781.92 -21996.391 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-224810.6 -55078.147 -256308.86 -62795.158 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-641787.89 -157236.75 -731708.94 -179267.23 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1832172.1 -448878.49 -2088878.1 -511770.96 MAarrowhead1
% End of user PostScript
1 .161 0 r
.58468 .51712 m
.59645 .5206 L
.60989 .5244 L
.62523 .52857 L
.64272 .53321 L
.66267 .53839 L
.68543 .54421 L
.71138 .55077 L
.74097 .55819 L
.77471 .56659 L
.81319 .57614 L
.85705 .58698 L
.90707 .59932 L
.96409 .61336 L
s
.96409 .61336 m
1 .62219 L
s
1 0 0 r
.58468 .51712 m
.59645 .5206 L
s
% Start of user PostScript
2.5402863 0.51352123 2.8935417 0.61810013 MAarrowhead1
% End of user PostScript
1 .158 0 r
.60989 .5244 m
.62523 .52857 L
s
% Start of user PostScript
3.2967332 0.73192594 3.7567844 0.8571898 MAarrowhead1
% End of user PostScript
1 .473 0 r
.81319 .57614 m
.85705 .58698 L
s
% Start of user PostScript
9.3956 2.2841127 10.711584 2.6094735 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
26.818768 6.5663673 30.57625 7.4876348 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
76.561176 18.756354 87.288156 21.384605 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
218.56616 53.548042 249.18951 61.050739 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
623.96126 152.86921 711.38462 174.28776 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1781.2807 436.41019 2030.8564 497.55573 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
5085.189 1245.8611 5797.676 1420.419 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
14517.166 3556.6766 16551.169 4055.0033 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
41443.514 10153.578 47250.175 11576.198 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
118312.69 28986.371 134889.5 33047.658 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
337758.32 82750.112 385081.71 94344.249 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
964230.33 236234.5 1099328.9 269333.37 MAarrowhead1
% End of user PostScript
1 .148 0 r
.35851 .48424 m
.33915 .47637 L
.317 .46833 L
.29169 .45994 L
.26277 .45104 L
.22975 .44143 L
.19208 .43094 L
.14909 .41935 L
.10005 .40645 L
.04412 .39202 L
s
.04412 .39202 m
0 .38078 L
s
1 0 0 r
.35851 .48424 m
.33915 .47637 L
s
% Start of user PostScript
-4.2445835 -0.47270463 -4.8254067 -0.70897418 MAarrowhead1
% End of user PostScript
1 .158 0 r
.317 .46833 m
.29169 .45994 L
s
% Start of user PostScript
-5.4899097 -0.95017736 -6.2494357 -1.2016724 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-15.589735 -3.7267437 -17.771747 -4.2766914 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-44.486032 -10.87722 -50.718447 -12.407756 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-126.99388 -31.108135 -144.7869 -35.468235 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-362.54026 -88.820438 -413.33583 -101.26545 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1034.9774 -253.56712 -1179.9883 -289.09455 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2954.647 -723.88254 -3368.6233 -825.30591 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8434.9078 -2066.5355 -9616.7247 -2356.0783 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-24079.922 -5899.5327 -27453.766 -6726.1176 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-68743.211 -16841.949 -78374.839 -19201.679 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-196247.69 -48080.291 -223744. -54816.832 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-560246.68 -137259.32 -638742.97 -156490.75 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1599388.7 -391847.04 -1823479.4 -446748.81 MAarrowhead1
% End of user PostScript
1 .803 0 r
.80649 .37921 m
.84464 .42101 L
.88892 .45893 L
.94008 .49405 L
.99895 .52733 L
s
.99895 .52733 m
1 .52782 L
s
1 0 0 r
.80649 .37921 m
.84464 .42101 L
s
% Start of user PostScript
9.1947463 -3.62374 10.339158 -2.369819 MAarrowhead1
% End of user PostScript
1 .158 0 r
.88892 .45893 m
.94008 .49405 L
s
% Start of user PostScript
11.667747 -1.2320605 13.202372 -0.17838965 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
32.450932 6.9899115 36.974125 8.2572099 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
92.439237 22.421897 105.3854 25.631044 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
263.84765 64.58919 300.8141 73.654671 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
753.21951 184.52484 858.75296 210.38238 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2150.2837 526.81229 2451.5604 600.62496 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6138.6159 1503.9479 6998.6988 1714.6666 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
17524.482 4293.4629 19979.842 4895.021 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
50028.783 12256.952 57038.327 13974.276 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
142821.86 34991.069 162832.66 39893.675 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
407726.94 99892.285 464853.66 113888.22 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1163976.3 285171.87 1327061.3 325127.37 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3322912.3 814106.87 3788486.4 928171.57 MAarrowhead1
% End of user PostScript
1 0 .312 r
.71357 .79233 m
.74937 .76134 L
.78921 .73793 L
.83382 .72118 L
.88401 .71038 L
.94066 .70499 L
s
.94066 .70499 m
1 .70465 L
s
1 0 0 r
.71357 .79233 m
.74937 .76134 L
s
% Start of user PostScript
6.4071427 8.7700445 7.4811263 7.8403013 MAarrowhead1
% End of user PostScript
1 .158 0 r
.78921 .73793 m
.83382 .72118 L
s
% Start of user PostScript
8.6763823 7.1378906 10.01474 6.635421 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
25.820675 7.5029023 29.467228 8.2013267 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
73.959574 18.396287 84.328832 20.890954 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
211.1973 51.807801 240.78979 59.047152 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
602.93833 147.73392 687.41653 168.42839 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1721.2678 421.71074 1962.4351 480.79565 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4913.8653 1203.888 5602.3481 1372.5648 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
14028.072 3436.8498 15993.548 3918.3875 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
40047.252 9811.4967 45658.282 11186.188 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
114326.65 28009.799 130344.98 31934.259 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
326378.99 79962.2 372108.03 91165.723 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
931744.71 228275.59 1062291.7 260259.34 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2659939. 651679.73 3032623.7 742986.72 MAarrowhead1
% End of user PostScript
1 .207 0 r
.56487 .51753 m
.57399 .5195 L
.5844 .52182 L
.59625 .52453 L
.60976 .52768 L
.62515 .53132 L
.64271 .53552 L
.66271 .54033 L
.68552 .54584 L
.71153 .55214 L
.74117 .55935 L
.77497 .56759 L
.8135 .57699 L
.85743 .58772 L
.90751 .59997 L
.96461 .61394 L
s
.96461 .61394 m
1 .6226 L
s
1 0 0 r
.56487 .51753 m
.57399 .5195 L
s
% Start of user PostScript
1.9459743 0.52591147 2.2198285 0.5848623 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5844 .52182 m
.59625 .52453 L
s
% Start of user PostScript
2.5318531 0.65451384 2.8874293 0.73596095 MAarrowhead1
% End of user PostScript
1 .473 0 r
.74117 .55935 m
.77497 .56759 L
s
% Start of user PostScript
7.2350957 1.7806178 8.2490033 2.0276922 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
20.656391 5.0626609 23.550609 5.7714259 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
58.970132 14.448007 67.232462 16.472188 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
168.34766 41.244943 191.93489 47.02375 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
480.59786 117.74554 547.93454 134.24289 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1372.0078 336.13917 1564.2401 383.2357 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
3916.7992 959.60797 4465.5829 1094.0589 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
11181.654 2739.4828 12748.318 3123.3124 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
31921.316 7820.6585 36393.819 8916.4128 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
91128.773 22326.367 103896.85 25454.519 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
260153.85 63737.173 296604.07 72667.403 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
742685.59 181956.48 846743.44 207450.45 MAarrowhead1
% End of user PostScript
.148 1 0 r
.21072 .22635 m
.16522 .2488 L
.11418 .26432 L
.05666 .27361 L
s
.05666 .27361 m
0 .27674 L
s
1 0 0 r
.21072 .22635 m
.16522 .2488 L
s
% Start of user PostScript
-8.6784127 -8.2094631 -10.043277 -7.5360436 MAarrowhead1
% End of user PostScript
1 .158 0 r
.11418 .26432 m
.05666 .27361 L
s
% Start of user PostScript
-11.5747 -7.0703932 -13.300106 -6.7915701 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-33.931664 -9.3074988 -38.71018 -10.3135 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-97.076476 -24.017011 -110.6836 -27.312051 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-277.18229 -67.963926 -316.01971 -77.469934 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-791.30977 -193.88218 -902.18068 -221.0432 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2259.0289 -553.46058 -2575.542 -631.00516 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6449.0622 -1580.008 -7352.6418 -1801.3831 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-18410.743 -4510.5953 -20990.276 -5142.5758 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-52558.873 -12876.819 -59922.909 -14680.993 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-150044.74 -36760.662 -171067.55 -41911.206 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-428346.79 -104944.11 -488362.56 -119647.85 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1222841.8 -299593.78 -1394174.4 -341569.94 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3490961. -855278.46 -3980080.3 -975111.72 MAarrowhead1
% End of user PostScript
.421 0 1 r
.35806 .53809 m
.33996 .52158 L
.31903 .50638 L
.29491 .49207 L
.26721 .47827 L
.23546 .46464 L
.19912 .45086 L
.15756 .43661 L
.11009 .42158 L
.05587 .40546 L
s
.05587 .40546 m
0 .38964 L
s
1 0 0 r
.35806 .53809 m
.33996 .52158 L
s
% Start of user PostScript
-4.2580848 1.1425787 -4.8011734 0.64740384 MAarrowhead1
% End of user PostScript
1 .158 0 r
.31903 .50638 m
.29491 .49207 L
s
% Start of user PostScript
-5.4292197 0.19140642 -6.1526583 -0.23790883 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-15.180131 -3.3618329 -17.298276 -3.9399625 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-43.261199 -10.515019 -49.320482 -12.013429 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-123.4842 -30.233685 -140.78512 -34.475639 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-352.5178 -86.361531 -401.90904 -98.463051 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1006.3646 -246.55624 -1147.3666 -281.10161 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2872.9633 -703.87 -3275.4948 -802.48946 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8201.7175 -2009.4043 -9350.8621 -2290.9424 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-23414.212 -5736.4351 -26694.783 -6540.1683 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-66842.746 -16376.339 -76208.099 -18670.832 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-190822.25 -46751.07 -217558.4 -53301.373 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-544758.18 -133464.66 -621084.37 -152164.43 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1555172.2 -381014.09 -1773067.8 -434398.06 MAarrowhead1
% End of user PostScript
1 .052 0 r
.28414 .65746 m
.25905 .61647 L
.22958 .58017 L
.19528 .54751 L
.15557 .51754 L
.10981 .48945 L
.05723 .46247 L
s
.05723 .46247 m
0 .4373 L
s
1 0 0 r
.28414 .65746 m
.25905 .61647 L
s
% Start of user PostScript
-6.4757935 4.7238293 -7.228628 3.4939517 MAarrowhead1
% End of user PostScript
1 .158 0 r
.22958 .58017 m
.19528 .54751 L
s
% Start of user PostScript
-8.1125366 2.4051572 -9.141644 1.4252921 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-22.238173 -4.4168767 -25.328717 -5.3449299 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-63.269037 -15.258602 -72.127747 -17.469091 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-180.56925 -44.182238 -205.86746 -50.389669 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-515.47604 -126.27724 -587.69917 -143.97398 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1471.575 -360.52979 -1677.7576 -411.04464 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4201.0424 -1029.2462 -4789.6513 -1173.4544 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-11993.109 -2938.2876 -13673.467 -3349.9718 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-34237.854 -8388.2055 -39034.927 -9563.479 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-97742.01 -23946.597 -111436.67 -27301.76 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-279033.28 -68362.595 -318128.7 -77940.894 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-796582.47 -195161.11 -908191.82 -222505.18 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2274078.6 -557144.72 -2592700.3 -635206.39 MAarrowhead1
% End of user PostScript
1 .261 0 r
.32539 .81913 m
.30979 .75535 L
.29053 .70061 L
.26735 .65319 L
.2399 .61164 L
.20775 .57472 L
.17038 .54132 L
.12719 .51051 L
.07745 .48145 L
.02032 .45338 L
s
.02032 .45338 m
0 .44476 L
s
1 0 0 r
.32539 .81913 m
.30979 .75535 L
s
% Start of user PostScript
-5.2382547 9.5739477 -5.70638 7.6605394 MAarrowhead1
% End of user PostScript
1 .158 0 r
.29053 .70061 m
.26735 .65319 L
s
% Start of user PostScript
-6.2841305 6.0182649 -6.9795704 4.5957805 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-16.354506 -2.2321964 -18.602493 -3.0769489 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-46.316484 -10.930755 -52.795696 -12.587182 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-132.1366 -32.275362 -150.6479 -36.826801 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-377.20222 -92.390815 -430.05155 -105.3426 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1076.8297 -263.81573 -1227.7044 -300.78063 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3074.1256 -753.15336 -3504.842 -858.67823 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8775.9944 -2150.1008 -10005.601 -2451.352 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-25053.654 -6138.095 -28563.927 -6998.1049 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-71523.014 -17522.995 -81544.12 -19978.146 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-204183.45 -50024.538 -232791.65 -57033.487 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-582901.65 -142809.74 -664572.13 -162818.84 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1664064. -407692.35 -1897216.4 -464814.22 MAarrowhead1
% End of user PostScript
0 1 .802 r
.7849 .31307 m
.81853 .36384 L
.85792 .40898 L
.90369 .4498 L
.9566 .48747 L
s
.9566 .48747 m
1 .51278 L
s
1 0 0 r
.7849 .31307 m
.81853 .36384 L
s
% Start of user PostScript
8.5470336 -5.6078111 9.5560052 -4.0846635 MAarrowhead1
% End of user PostScript
1 .158 0 r
.85792 .40898 m
.90369 .4498 L
s
% Start of user PostScript
10.737582 -2.7306136 12.110772 -1.5059841 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
29.528958 5.9756752 33.635447 7.1903109 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
84.035016 20.292824 95.801945 23.224668 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
239.84064 58.69107 273.44306 66.935096 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
684.68099 167.72917 780.6114 191.23463 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1954.6196 478.87406 2228.4817 545.97036 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5580.035 1367.0965 6361.8549 1558.641 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
15929.849 3902.7809 18161.784 4449.6004 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
45476.433 11141.635 51848.146 12702.692 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
129825.84 31807.07 148015.76 36263.566 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
370625.99 90802.625 422554.48 103525. MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1058060.8 259222.77 1206305.9 295542.53 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3020545.2 740027.53 3443754.5 843712.96 MAarrowhead1
% End of user PostScript
0 1 .49 r
.61373 .4872 m
.62867 .49759 L
.64586 .50743 L
.66561 .51696 L
.68823 .52641 L
.71412 .53602 L
.74372 .54599 L
.77753 .55655 L
.81614 .56791 L
.8602 .58028 L
.91047 .59392 L
.96782 .60907 L
s
.96782 .60907 m
1 .61741 L
s
1 0 0 r
.61373 .4872 m
.62867 .49759 L
s
% Start of user PostScript
3.4118365 -0.38407173 3.8600026 -0.072161702 MAarrowhead1
% End of user PostScript
1 .158 0 r
.64586 .50743 m
.66561 .51696 L
s
% Start of user PostScript
4.3759094 0.22286129 4.9682284 0.50866887 MAarrowhead1
% End of user PostScript
1 .473 0 r
.91047 .59392 m
.96782 .60907 L
s
% Start of user PostScript
12.314179 2.8175462 14.03464 3.2720905 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
35.112613 8.5556991 40.031103 9.768476 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
100.22945 24.54502 114.27235 27.987324 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
286.13209 70.099208 326.22206 79.921598 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
816.84757 200.12541 931.29625 228.16521 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2331.9312 571.31833 2658.6586 651.36592 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
6657.1826 1630.9964 7589.922 1859.5157 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
19004.883 4656.1584 21667.662 5308.5338 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
54255.022 13292.372 61856.706 15154.769 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
154886.9 37946.98 176588.14 43263.74 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
442170.15 108330.8 504122.71 123509.05 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1262304.6 309262.1 1439166.4 352592.88 MAarrowhead1
% End of user PostScript
0 1 .337 r
.19189 .77889 m
.1574 .71173 L
.11664 .65276 L
.06896 .60022 L
.01361 .55256 L
s
.01361 .55256 m
0 .54317 L
s
1 0 0 r
.19189 .77889 m
.1574 .71173 L
s
% Start of user PostScript
-9.243228 8.3668273 -10.278022 6.3520126 MAarrowhead1
% End of user PostScript
1 .158 0 r
.11664 .65276 m
.06896 .60022 L
s
% Start of user PostScript
-11.50092 4.582904 -12.931136 3.0064538 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-31.280353 -5.9259239 -35.620508 -7.277136 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-88.934443 -21.38074 -101.38508 -24.498717 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-253.8039 -62.085643 -289.36208 -70.813197 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-724.5377 -177.48779 -826.0523 -202.36239 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2068.401 -506.74882 -2358.205 -577.7511 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5904.8571 -1446.6769 -6732.188 -1649.3715 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-16857.149 -4129.9675 -19219.008 -4708.6182 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-48123.683 -11790.206 -54866.304 -13442.135 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-137383.19 -33658.607 -156631.98 -38374.522 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-392200.67 -96088.38 -447152. -109551.35 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1119652. -274312.51 -1276526.7 -312746.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3196375.6 -783105.63 -3644220.6 -892826.74 MAarrowhead1
% End of user PostScript
0 .918 1 r
.38848 .69542 m
.37831 .65603 L
.36581 .62218 L
.35081 .59282 L
.33307 .56704 L
.31232 .54407 L
.28823 .52325 L
.2604 .50399 L
.22836 .48575 L
.19159 .46808 L
.14944 .45052 L
.10122 .43267 L
.04609 .41414 L
s
.04609 .41414 m
0 .39977 L
s
1 0 0 r
.38848 .69542 m
.37831 .65603 L
s
% Start of user PostScript
-3.34554 5.8627388 -3.6506867 4.6809144 MAarrowhead1
% End of user PostScript
1 .158 0 r
.36581 .62218 m
.35081 .59282 L
s
% Start of user PostScript
-4.0256905 3.6653812 -4.4758492 2.7844566 MAarrowhead1
% End of user PostScript
1 .473 0 r
.14944 .45052 m
.10122 .43267 L
s
% Start of user PostScript
-10.51675 -1.4843476 -11.963514 -2.0197514 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-29.794037 -7.0430172 -33.962208 -8.1066985 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-85.002035 -20.76511 -96.910215 -23.692566 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-242.65065 -59.434783 -276.64814 -67.766443 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-692.71458 -169.71037 -789.7709 -193.48952 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1977.5566 -484.49662 -2254.6324 -552.37979 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-5645.516 -1383.1399 -6436.5105 -1576.932 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-16116.784 -3948.5797 -18374.91 -4501.8161 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-46010.093 -11272.381 -52456.578 -12851.757 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-131349.33 -32180.322 -149752.71 -36689.114 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-374975.24 -91868.183 -427513.1 -104739.85 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1070477. -262264.71 -1220461.7 -299010.68 MAarrowhead1
% End of user PostScript
.223 1 0 r
.52172 .47476 m
.52402 .48038 L
.52676 .48528 L
.52999 .4896 L
.53376 .49346 L
.53812 .49698 L
.54316 .50027 L
.54896 .50339 L
.55561 .50645 L
.56322 .5095 L
.57193 .51263 L
.58189 .51589 L
.59326 .51937 L
.60624 .52313 L
.62106 .52724 L
.63796 .53178 L
.65724 .53684 L
.67923 .54251 L
.70431 .54888 L
.7329 .55608 L
.76551 .56423 L
.80269 .57348 L
.84509 .58398 L
.89342 .59591 L
.94854 .60949 L
s
.94854 .60949 m
1 .62216 L
s
1 0 0 r
.52172 .47476 m
.52402 .48038 L
s
% Start of user PostScript
0.6517262 -0.7572509 0.72059168 -0.58847346 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52676 .48528 m
.52999 .4896 L
s
% Start of user PostScript
0.80282486 -0.44158697 0.89968257 -0.3121143 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57193 .51263 m
.58189 .51589 L
s
% Start of user PostScript
2.1580099 0.37883731 2.4567 0.47684473 MAarrowhead1
% End of user PostScript
1 .788 0 r
.70431 .54888 m
.7329 .55608 L
s
% Start of user PostScript
6.1292351 1.4664599 6.9871421 1.6824754 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
17.49032 4.2768306 19.940691 4.8785354 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
49.929524 12.230693 56.925114 13.94492 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
142.53809 34.92109 162.50912 39.814029 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
406.91674 99.69368 463.92994 113.66182 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
1161.6634 284.60517 1324.4243 324.48127 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
3316.3093 812.48913 3780.9581 926.32717 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
9467.379 2319.4889 10793.856 2644.473 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
27027.414 6621.6624 30814.232 7549.4251 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
77157.694 18903.481 87968.276 21552.052 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
220269.3 53965.538 251131.28 61526.662 MAarrowhead1
% End of user PostScript
.929 0 1 r
.59171 .30499 m
.59923 .34286 L
.60869 .37524 L
.62022 .40314 L
.63397 .42744 L
.65016 .44886 L
.66904 .46806 L
.69093 .48557 L
.71619 .5019 L
.74523 .51747 L
.77854 .5327 L
.8167 .54793 L
.86034 .56354 L
.91023 .57986 L
.9672 .59724 L
s
.9672 .59724 m
1 .60671 L
s
1 0 0 r
.59171 .30499 m
.59923 .34286 L
s
% Start of user PostScript
2.751228 -5.8503485 2.9769735 -4.7141522 MAarrowhead1
% End of user PostScript
1 .158 0 r
.60869 .37524 m
.62022 .40314 L
s
% Start of user PostScript
3.2608104 -3.7427933 3.6064941 -2.9056855 MAarrowhead1
% End of user PostScript
1 .473 0 r
.77854 .5327 m
.8167 .54793 L
s
% Start of user PostScript
8.3562457 0.98085273 9.5009334 1.43797 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
23.63166 5.5393108 26.936567 6.3904897 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
67.410991 16.456763 76.854521 18.780149 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
192.43214 47.131684 219.39352 53.739454 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
549.35118 134.5867 626.32082 153.44464 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1568.2836 384.22559 1788.0162 438.05975 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
4477.1262 1096.8868 5104.4173 1250.5719 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
12781.272 3131.386 14572.059 3570.1252 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
36487.895 8939.4612 41600.222 10191.971 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
104165.41 25520.318 118760.05 29095.976 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
297370.77 72855.244 339035.46 83063.009 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
848932.23 207986.7 967876.31 237127.76 MAarrowhead1
% End of user PostScript
.9 1 0 r
.33048 .26735 m
.30205 .29205 L
.27041 .31071 L
.23499 .32407 L
.19514 .3327 L
.15016 .33702 L
.09925 .33735 L
.04152 .33389 L
s
.04152 .33389 m
0 .32936 L
s
1 0 0 r
.33048 .26735 m
.30205 .29205 L
s
% Start of user PostScript
-5.0855555 -6.9795076 -5.9384623 -6.238596 MAarrowhead1
% End of user PostScript
1 .158 0 r
.27041 .31071 m
.23499 .32407 L
s
% Start of user PostScript
-6.8876154 -5.6786289 -7.9503525 -5.2777834 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-20.499939 -5.9595925 -23.395133 -6.5136529 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-58.719679 -14.606251 -66.952294 -16.58677 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-167.67873 -41.132622 -191.1735 -46.880234 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-478.69904 -117.29244 -545.76996 -133.72267 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1366.5896 -334.81456 -1558.0628 -381.72465 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3901.3319 -955.81918 -4447.9485 -1089.739 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-11137.498 -2728.6649 -12697.976 -3110.9787 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-31795.26 -7789.7752 -36250.101 -8881.2023 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-90768.91 -22238.201 -103486.56 -25354.001 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-259126.52 -63485.478 -295432.79 -72380.443 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-739752.76 -181237.95 -843399.69 -206631.24 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2111841.6 -517396.96 -2407732.2 -589889.56 MAarrowhead1
% End of user PostScript
1 0 .175 r
.62653 .18722 m
.63584 .24646 L
.64785 .29692 L
.66271 .3402 L
.68062 .37767 L
.70185 .41047 L
.72673 .43959 L
.75566 .46589 L
.78911 .49011 L
.82764 .51292 L
.8719 .53492 L
.92263 .55666 L
.98069 .57865 L
s
.98069 .57865 m
1 .58527 L
s
1 0 0 r
.62653 .18722 m
.63584 .24646 L
s
% Start of user PostScript
3.7959409 -9.3833328 4.0753009 -7.606292 MAarrowhead1
% End of user PostScript
1 .158 0 r
.64785 .29692 m
.66271 .3402 L
s
% Start of user PostScript
4.4356319 -6.0924751 4.8813487 -4.7939059 MAarrowhead1
% End of user PostScript
1 .473 0 r
.8719 .53492 m
.92263 .55666 L
s
% Start of user PostScript
11.156856 1.0476957 12.678776 1.6998331 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
31.496916 7.3208677 35.900266 8.4652536 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
89.83417 21.916253 102.41858 25.014805 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
256.43853 62.805104 292.36766 71.611284 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
732.07454 179.35167 834.64555 204.48221 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2089.9207 512.0252 2382.74 583.76553 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
5966.2924 1461.7294 6802.231 1666.5328 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
17032.534 4172.9368 19418.967 4757.6079 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
48624.373 11912.874 55437.145 13581.989 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
138812.56 34008.798 158261.61 38773.779 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
396281.22 97088.105 451804.27 110691.14 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1131301.1 277166.51 1289808. 316000.38 MAarrowhead1
% End of user PostScript
0 1 .827 r
.24009 .59778 m
.20762 .56307 L
.16996 .53153 L
.12647 .50226 L
.07643 .47446 L
.01899 .44743 L
s
.01899 .44743 m
0 .43965 L
s
1 0 0 r
.24009 .59778 m
.20762 .56307 L
s
% Start of user PostScript
-7.7973808 2.9332924 -8.7712921 1.8922464 MAarrowhead1
% End of user PostScript
1 .158 0 r
.16996 .53153 m
.12647 .50226 L
s
% Start of user PostScript
-9.9013036 0.94589543 -11.206032 0.06765461 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-27.558909 -5.9601865 -31.400812 -7.0326037 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-78.508932 -19.048638 -89.504285 -21.773274 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-224.08781 -54.857417 -255.48374 -62.556587 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-639.71533 -156.71873 -729.34574 -178.6797 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1826.2532 -447.42597 -2082.1299 -510.11564 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5213.5757 -1277.315 -5944.0509 -1456.2801 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-14883.683 -3646.4725 -16969.039 -4157.3806 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-42489.846 -10409.927 -48443.108 -11868.464 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-121299.75 -29718.195 -138295.08 -33882.018 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-346285.76 -84839.317 -394803.93 -96726.174 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-988574.42 -242198.75 -1127083.8 -276133.28 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2822176.1 -691427.49 -3217591.8 -788303.55 MAarrowhead1
% End of user PostScript
1 .342 0 r
.80066 .44771 m
.8397 .47814 L
.88473 .50658 L
.93648 .53379 L
.99585 .56045 L
s
.99585 .56045 m
1 .56209 L
s
1 0 0 r
.80066 .44771 m
.8397 .47814 L
s
% Start of user PostScript
9.0198301 -1.568631 10.191096 -0.65569797 MAarrowhead1
% End of user PostScript
1 .158 0 r
.88473 .50658 m
.93648 .53379 L
s
% Start of user PostScript
11.541794 0.19749082 13.094524 1.0136532 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
32.397707 7.319783 36.921837 8.5305014 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
92.359221 22.482811 105.29614 25.676355 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
263.63611 64.556269 300.57339 73.61147 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
752.61957 184.38229 858.06908 210.21854 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2148.572 526.39396 2449.6088 600.1477 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6133.7294 1502.751 6993.1277 1713.3019 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
17510.532 4290.0453 19963.937 4891.1245 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
49988.959 12247.195 56992.923 13963.152 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
142708.17 34963.215 162703.04 39861.919 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
407402.38 99812.768 464483.62 113797.56 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1163049.8 284944.87 1326004.9 324868.56 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3320267.2 813458.83 3785470.6 927432.73 MAarrowhead1
% End of user PostScript
.32 1 0 r
.66743 .48895 m
.68961 .50301 L
.71511 .51645 L
.74437 .52963 L
.77786 .54284 L
.81618 .55641 L
.85996 .57062 L
.90997 .58579 L
.96705 .6022 L
s
.96705 .6022 m
1 .6113 L
s
1 0 0 r
.66743 .48895 m
.68961 .50301 L
s
% Start of user PostScript
5.0228271 -0.33164037 5.6883304 0.090218346 MAarrowhead1
% End of user PostScript
1 .158 0 r
.71511 .51645 m
.74437 .52963 L
s
% Start of user PostScript
6.4534136 0.49359691 7.3309794 0.8887598 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
18.195048 4.2024054 20.738109 4.867753 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
51.889547 12.652879 59.158336 14.44365 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
148.12138 36.275363 168.87435 41.362133 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
422.85303 103.59484 482.09899 118.11053 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1207.1575 295.7504 1376.2926 337.18828 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3446.1855 844.30838 3929.0314 962.60467 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
9838.1489 2410.3267 11216.574 2748.0382 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
28085.886 6880.9858 32021.006 7845.0824 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
80179.412 19643.795 91413.368 22396.092 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
228895.68 56078.984 260966.31 63936.224 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
653449.97 160093.93 745004.99 182524.73 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1865464.9 457035.16 2126835.6 521070.47 MAarrowhead1
% End of user PostScript
0 .699 1 r
.455 .5014 m
.449 .49787 L
.44211 .49447 L
.43421 .4911 L
.42517 .48769 L
.41483 .48416 L
.40302 .48043 L
.38954 .47643 L
.37415 .47208 L
.35659 .4673 L
.33655 .46199 L
.3137 .45605 L
.28764 .44939 L
.25792 .44187 L
.22403 .43337 L
.18539 .42374 L
.14133 .41281 L
.0911 .40039 L
.03382 .38626 L
s
.03382 .38626 m
0 .37794 L
s
1 0 0 r
.455 .5014 m
.449 .49787 L
s
% Start of user PostScript
-1.3499088 0.041980589 -1.5299202 -0.063867578 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44211 .49447 m
.43421 .4911 L
s
% Start of user PostScript
-1.7366648 -0.16603596 -1.9736377 -0.26707554 MAarrowhead1
% End of user PostScript
1 .473 0 r
.33655 .46199 m
.3137 .45605 L
s
% Start of user PostScript
-4.9033972 -1.1404039 -5.5889219 -1.3184484 MAarrowhead1
% End of user PostScript
1 .788 0 r
.03382 .38626 m
0 0 rlineto s
.03382 .38626 m
0 .37794 L
s
% Start of user PostScript
-13.985409 -3.4120932 -15.944558 -3.8944504 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-39.922458 -9.7775636 -45.51592 -11.148507 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-113.96968 -27.921554 -129.93798 -31.833886 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-325.35976 -79.712305 -370.94599 -90.88087 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-928.83497 -227.56267 -1058.9743 -259.44654 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2651.6323 -649.64459 -3023.1531 -740.66644 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-7569.8632 -1854.6013 -8630.4785 -2114.45 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-21610.398 -5294.5043 -24638.236 -6036.3185 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-61693.23 -15114.718 -70337.082 -17232.444 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-176121.45 -43149.402 -200797.86 -49195.075 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-502790.41 -123182.64 -573236.49 -140441.79 MAarrowhead1
% End of user PostScript
0 1 .257 r
.24032 .63249 m
.20874 .59226 L
.17194 .55614 L
.12932 .52308 L
.08017 .49217 L
.02367 .46259 L
s
.02367 .46259 m
0 .45199 L
s
1 0 0 r
.24032 .63249 m
.20874 .59226 L
s
% Start of user PostScript
-7.7902616 3.9746384 -8.737724 2.7678426 MAarrowhead1
% End of user PostScript
1 .158 0 r
.17194 .55614 m
.12932 .52308 L
s
% Start of user PostScript
-9.8417973 1.6841499 -11.120471 0.69240182 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-27.237228 -5.7114526 -31.0299 -6.7999592 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-77.554954 -18.775017 -88.415668 -21.473277 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-221.35603 -54.178768 -252.36898 -61.785661 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-631.9147 -154.80539 -720.45211 -176.49894 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1803.9835 -441.96943 -2056.74 -503.89475 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5150.0003 -1261.7391 -5871.568 -1438.5218 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-14702.189 -3602.0066 -16762.116 -4106.6846 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-41971.716 -10282.986 -47852.383 -11723.738 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-119820.59 -29355.805 -136608.68 -33468.854 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-342063.08 -83804.77 -389989.61 -95546.675 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-976519.54 -239245.33 -1113339.9 -272766.05 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2787761.9 -682996.08 -3178355.8 -778690.82 MAarrowhead1
% End of user PostScript
0 1 .388 r
.60809 .37489 m
.61952 .40281 L
.63317 .42711 L
.64925 .44853 L
.668 .46771 L
.68974 .4852 L
.71483 .5015 L
.74367 .51704 L
.77677 .53221 L
.81468 .5474 L
.85804 .56294 L
.9076 .57919 L
.9642 .59648 L
s
.9642 .59648 m
1 .60683 L
s
1 0 0 r
.60809 .37489 m
.61952 .40281 L
s
% Start of user PostScript
3.2426234 -3.7531895 3.5856135 -2.9157575 MAarrowhead1
% End of user PostScript
1 .158 0 r
.63317 .42711 m
.64925 .44853 L
s
% Start of user PostScript
3.9951047 -2.1868478 4.4773588 -1.5442483 MAarrowhead1
% End of user PostScript
1 .473 0 r
.85804 .56294 m
.9076 .57919 L
s
% Start of user PostScript
10.741153 1.8882526 12.227901 2.3756459 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
30.507856 7.2998309 34.778045 8.3749335 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
87.057024 21.287816 99.2536 24.282742 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
248.52125 60.877587 283.34139 69.410044 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
709.4749 173.81767 808.87953 198.17198 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2025.404 496.2194 2309.1838 565.74498 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
5782.1107 1416.6054 6592.2435 1615.0864 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
16506.733 4044.1166 18819.496 4610.7387 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
47123.319 11545.119 53725.778 13162.708 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
134527.36 32958.933 153376.02 37576.817 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
384047.86 94090.957 437856.89 107274.06 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1096377.4 268610.28 1249991.1 306245.32 MAarrowhead1
% End of user PostScript
0 .027 1 r
.4965 .5292 m
.49674 .52428 L
.4969 .52016 L
.49698 .51672 L
.49698 .51382 L
.49692 .5114 L
.49678 .50935 L
.49658 .50762 L
.49631 .50615 L
.49596 .5049 L
.49554 .50382 L
.49504 .50288 L
.49444 .50206 L
.49375 .50132 L
.49294 .50065 L
.49201 .50003 L
.49094 .49944 L
.48971 .49886 L
.48831 .49829 L
.4867 .4977 L
.48485 .49709 L
.48275 .49644 L
.48035 .49575 L
.47761 .49498 L
.47449 .49414 L
.47092 .4932 L
.46686 .49215 L
.46222 .49097 L
.45693 .48964 L
.4509 .48813 L
.44403 .48642 L
.43619 .48448 L
.42725 .48227 L
.41706 .47976 L
.40544 .4769 L
.39219 .47364 L
.37709 .46993 L
.35987 .46571 L
.34024 .46089 L
.31785 .4554 L
.29234 .44914 L
.26324 .44201 L
.23007 .43388 L
.19225 .42461 L
.14913 .41405 L
.09997 .402 L
.04392 .38827 L
s
.04392 .38827 m
0 .37751 L
s
1 0 0 r
.4965 .5292 m
.49674 .52428 L
s
% Start of user PostScript
-0.10504582 0.87592182 -0.097689495 0.72834744 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4969 .52016 m
.49698 .51672 L
s
% Start of user PostScript
-0.092959502 0.60487669 -0.090617961 0.50146802 MAarrowhead1
% End of user PostScript
1 .473 0 r
.49554 .50382 m
.49504 .50288 L
s
% Start of user PostScript
-0.13371963 0.11461473 -0.14884708 0.086492956 MAarrowhead1
% End of user PostScript
1 .788 0 r
.48831 .49829 m
.4867 .4977 L
s
% Start of user PostScript
-0.3508274 -0.051347432 -0.39913472 -0.068915531 MAarrowhead1
% End of user PostScript
.897 1 0 r
.46686 .49215 m
.46222 .49097 L
s
% Start of user PostScript
-0.99428097 -0.23547152 -1.133391 -0.27089931 MAarrowhead1
% End of user PostScript
.581 1 0 r
.40544 .4769 m
.39219 .47364 L
s
% Start of user PostScript
-2.8367627 -0.69309331 -3.2341754 -0.79077471 MAarrowhead1
% End of user PostScript
.266 1 0 r
.23007 .43388 m
.19225 .42461 L
s
% Start of user PostScript
-8.0979721 -1.983539 -9.2325699 -2.2615874 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-23.117946 -5.6637454 -26.357004 -6.4573256 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-65.996947 -16.169095 -75.243793 -18.434558 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-188.40767 -46.159495 -214.80551 -52.626914 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-537.86503 -131.77585 -613.22542 -150.239 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1535.4937 -376.19289 -1750.6321 -428.90136 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4383.5179 -1073.9531 -4997.6936 -1224.4249 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-12514.039 -3065.9146 -14267.384 -3495.4806 MAarrowhead1
% End of user PostScript
1 .046 0 r
.36989 .4429 m
.35105 .44246 L
.32966 .44071 L
.30536 .43766 L
.27773 .43332 L
.24629 .42764 L
.2105 .42056 L
.16973 .41198 L
.12328 .40178 L
.07035 .38979 L
.01003 .37584 L
s
.01003 .37584 m
0 .37348 L
s
1 0 0 r
.36989 .4429 m
.35105 .44246 L
s
% Start of user PostScript
-3.9032319 -1.7130873 -4.4686427 -1.7262331 MAarrowhead1
% End of user PostScript
1 .158 0 r
.32966 .44071 m
.30536 .43766 L
s
% Start of user PostScript
-5.1102037 -1.7788068 -5.839093 -1.870106 MAarrowhead1
% End of user PostScript
1 .473 0 r
.01003 .37584 m
0 0 rlineto s
.01003 .37584 m
0 .37348 L
s
% Start of user PostScript
-14.699086 -3.7249461 -16.761607 -4.2097664 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-41.988808 -10.316219 -47.872581 -11.75292 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-119.87548 -29.376073 -136.67143 -33.489916 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-342.2212 -83.845111 -390.16993 -95.592189 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-976.97129 -239.35639 -1113.855 -272.89255 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2789.0516 -683.31215 -3179.8263 -779.05114 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7962.1671 -1950.715 -9077.7482 -2224.0301 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-22730.345 -5568.889 -25915.099 -6349.1473 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-64890.447 -15898.03 -73982.262 -18125.506 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-185248.84 -45385.595 -211204.1 -51744.582 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-528847.24 -129566.51 -602944.14 -147720.11 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1509749.8 -369885.68 -1721281.2 -421710.44 MAarrowhead1
% End of user PostScript
.295 1 0 r
.64209 .62592 m
.66423 .61625 L
.6891 .60975 L
.71715 .60612 L
.74887 .60512 L
.78482 .60662 L
.82563 .61051 L
.872 .61678 L
.92475 .62546 L
.98479 .63662 L
s
.98479 .63662 m
1 .63969 L
s
1 0 0 r
.64209 .62592 m
.66423 .61625 L
s
% Start of user PostScript
4.2627183 3.7777433 4.9268873 3.4876264 MAarrowhead1
% End of user PostScript
1 .158 0 r
.6891 .60975 m
.71715 .60612 L
s
% Start of user PostScript
5.6730269 3.2926131 6.5144585 3.1835385 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
16.594452 4.5123789 18.930442 5.0106757 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
47.467456 11.734336 54.120701 13.346988 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
135.5318 33.229652 154.5218 37.878082 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
386.92051 94.800535 441.13217 108.08133 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1104.5795 270.62112 1259.3424 308.5375 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3153.3469 772.56399 3595.163 880.80801 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
9002.155 2205.51 10263.449 2514.5245 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
25699.296 6296.2761 29300.03 7178.4487 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
73366.189 17974.57 83645.543 20492.991 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
209445.34 51313.689 238790.77 58503.261 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
597923.24 146490. 681698.41 167014.75 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1706947.5 418198.73 1946108.4 476792.65 MAarrowhead1
% End of user PostScript
0 .382 1 r
.20149 .71557 m
.16673 .65922 L
.12594 .60932 L
.07845 .56439 L
.02349 .52315 L
s
.02349 .52315 m
0 .5088 L
s
1 0 0 r
.20149 .71557 m
.16673 .65922 L
s
% Start of user PostScript
-8.9552871 6.4670158 -9.9979754 4.7766938 MAarrowhead1
% End of user PostScript
1 .158 0 r
.12594 .60932 m
.07845 .56439 L
s
% Start of user PostScript
-11.221883 3.2796859 -12.646582 1.9318157 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-30.771472 -6.1233035 -35.048212 -7.4056247 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-87.54925 -21.11699 -99.807658 -24.175344 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-249.86533 -61.138455 -284.8721 -69.727976 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-713.2976 -174.73816 -813.23744 -199.22626 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2036.3137 -498.88847 -2321.622 -568.78914 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5813.2547 -1424.2348 -6627.7511 -1623.7849 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-16595.643 -4065.8991 -18920.862 -4635.5732 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-47377.138 -11607.304 -54015.159 -13233.606 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-135251.96 -33136.459 -154202.14 -37779.216 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-386116.44 -94597.755 -440215.3 -107851.87 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1102282.8 -270057.08 -1256723.9 -307894.84 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3146790.1 -770957.27 -3587687.5 -878976.27 MAarrowhead1
% End of user PostScript
1 .364 0 r
.74294 .49709 m
.77545 .5154 L
.81277 .53317 L
.85553 .55085 L
.90445 .56884 L
.96038 .58755 L
s
.96038 .58755 m
1 .59985 L
s
1 0 0 r
.74294 .49709 m
.77545 .5154 L
s
% Start of user PostScript
7.2881747 -0.087200071 8.2634731 0.46200885 MAarrowhead1
% End of user PostScript
1 .158 0 r
.81277 .53317 m
.85553 .55085 L
s
% Start of user PostScript
9.3830165 0.99515663 10.665757 1.525402 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
26.513111 6.1895524 30.220375 7.148537 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
75.625254 18.45616 86.219366 21.063604 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
215.87942 52.87315 246.12593 60.286279 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
616.28769 150.98529 702.6358 172.14106 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1759.3734 431.04204 2005.8796 491.43571 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5022.6481 1230.5385 5726.3724 1402.9496 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
14338.624 3512.9342 16347.612 4005.1322 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
40933.815 10028.703 46669.061 11433.827 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
116857.6 28629.878 133230.54 32641.217 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
333604.34 81732.396 380345.72 93183.941 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
952371.6 233329.13 1085808.6 266020.93 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2718824.5 666106.56 3099759.6 759434.9 MAarrowhead1
% End of user PostScript
1 .054 0 r
.3408 .42716 m
.31766 .42709 L
.29142 .42534 L
.26162 .42195 L
.22774 .4169 L
.1892 .41017 L
.14531 .40169 L
.09534 .39134 L
.03841 .37897 L
s
.03841 .37897 m
0 .37033 L
s
1 0 0 r
.3408 .42716 m
.31766 .42709 L
s
% Start of user PostScript
-4.7761109 -2.1852983 -5.4701459 -2.1871549 MAarrowhead1
% End of user PostScript
1 .158 0 r
.29142 .42534 m
.26162 .42195 L
s
% Start of user PostScript
-6.257305 -2.2396891 -7.1513179 -2.3416485 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-18.01155 -4.5787214 -20.539214 -5.1705051 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-51.454066 -12.645104 -58.66426 -14.405132 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-146.89892 -35.999089 -167.48118 -41.040187 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-419.36803 -102.74648 -478.12583 -117.14166 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1197.2097 -293.31448 -1364.951 -334.41069 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3417.7868 -837.35105 -3896.6537 -954.67247 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-9757.0765 -2390.4643 -11124.143 -2725.3927 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-27854.441 -6824.2823 -31757.133 -7780.4341 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-79518.685 -19481.919 -90660.066 -22211.535 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-227009.44 -55616.859 -258815.79 -63409.35 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-648065.14 -158774.66 -738865.7 -181020.62 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1850092.3 -453268.92 -2109309.2 -516776.53 MAarrowhead1
% End of user PostScript
1 .95 0 r
.59401 .7245 m
.61211 .69556 L
.63193 .67257 L
.65385 .6547 L
.67827 .6413 L
.70564 .63183 L
.73645 .62589 L
.77124 .62315 L
.81063 .62341 L
.85531 .62652 L
.90606 .63241 L
.96376 .6411 L
s
.96376 .6411 m
1 .64746 L
s
1 0 0 r
.59401 .7245 m
.61211 .69556 L
s
% Start of user PostScript
2.8202079 6.7350673 3.3633196 5.8668055 MAarrowhead1
% End of user PostScript
1 .158 0 r
.63193 .67257 m
.65385 .6547 L
s
% Start of user PostScript
3.9580125 5.1770691 4.6155749 4.6411413 MAarrowhead1
% End of user PostScript
1 .473 0 r
.90606 .63241 m
.96376 .6411 L
s
% Start of user PostScript
12.181875 3.9724455 13.912867 4.2328689 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
34.983973 8.8029697 39.891264 9.9668167 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
99.920686 24.534835 113.92193 27.956088 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
285.26438 69.90199 325.23315 79.69214 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
814.37364 199.52292 928.47579 227.47722 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2324.8694 569.58906 2650.6074 649.3941 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
6637.0228 1626.0575 7566.9376 1853.8847 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
18947.331 4642.0583 21602.046 5292.4581 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
54090.723 13252.119 61669.387 15108.876 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
154417.86 37832.066 176053.38 43132.726 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
440831.14 108002.75 502596.09 123135.04 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1258482. 308325.57 1434808.2 351525.13 MAarrowhead1
% End of user PostScript
.069 0 1 r
.48768 .22035 m
.47918 .2641 L
.47061 .30024 L
.46178 .32997 L
.45249 .35432 L
.44255 .37409 L
.43176 .38997 L
.41992 .40253 L
.40679 .41221 L
.39214 .41938 L
.3757 .42433 L
.35718 .42728 L
.33624 .42841 L
.31253 .42781 L
.28562 .42557 L
.25504 .42171 L
.22028 .41622 L
.18071 .40905 L
.13566 .40012 L
.08436 .38931 L
.0259 .37646 L
s
.0259 .37646 m
0 .37059 L
s
1 0 0 r
.48768 .22035 m
.47918 .2641 L
s
% Start of user PostScript
-0.36973883 -8.3893884 -0.62471369 -7.0770032 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47061 .30024 m
.46178 .32997 L
s
% Start of user PostScript
-0.88175407 -5.9928944 -1.1467256 -5.1007649 MAarrowhead1
% End of user PostScript
1 .473 0 r
.3757 .42433 m
.35718 .42728 L
s
% Start of user PostScript
-3.7290218 -2.2700404 -4.2847041 -2.181462 MAarrowhead1
% End of user PostScript
1 .788 0 r
.13566 .40012 m
.08436 .38931 L
s
% Start of user PostScript
-10.930124 -2.9963569 -12.469344 -3.3206974 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-31.27006 -7.7358872 -35.653146 -8.797345 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-89.28526 -21.89227 -101.79547 -24.954337 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-254.89469 -62.452811 -290.60814 -71.201852 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-727.67262 -178.2793 -829.62702 -203.25777 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2077.3555 -508.94815 -2368.4142 -580.25693 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-5930.4214 -1452.9414 -6761.3341 -1656.5134 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-16930.13 -4147.848 -19302.214 -4729.0039 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-48332.029 -11841.25 -55103.841 -13500.331 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-137977.98 -33804.328 -157310.1 -38540.66 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-393898.66 -96504.384 -449087.89 -110025.64 MAarrowhead1
% End of user PostScript
0 1 .286 r
.40623 .31021 m
.38901 .33363 L
.37005 .35204 L
.349 .36612 L
.32547 .37641 L
.29904 .38332 L
.26923 .38719 L
.23552 .38826 L
.19731 .38667 L
.15395 .38254 L
.10466 .37588 L
.0486 .36666 L
s
.0486 .36666 m
0 .35762 L
s
1 0 0 r
.40623 .31021 m
.38901 .33363 L
s
% Start of user PostScript
-2.8130888 -5.6937213 -3.3297516 -4.9912093 MAarrowhead1
% End of user PostScript
1 .158 0 r
.37005 .35204 m
.349 .36612 L
s
% Start of user PostScript
-3.8985063 -4.4388147 -4.5300143 -4.0163941 MAarrowhead1
% End of user PostScript
1 .473 0 r
.10466 .37588 m
.0486 .36666 L
s
% Start of user PostScript
-11.860194 -3.7237115 -13.541955 -4.0002244 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-34.029995 -8.5293483 -38.802648 -9.666819 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-97.188907 -23.856186 -110.80717 -27.185162 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-277.46374 -67.988651 -316.33951 -77.511382 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-792.10398 -194.06638 -903.08592 -221.25632 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2261.294 -554.01309 -2578.1245 -631.63582 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6455.5282 -1581.5916 -7360.0137 -1803.1887 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-18429.202 -4515.1175 -21011.321 -5147.7317 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-52611.57 -12889.729 -59982.989 -14695.712 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-150195.18 -36797.518 -171239.06 -41953.227 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-428776.26 -105049.33 -488852.2 -119767.81 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1224067.8 -299894.16 -1395572.2 -341912.4 MAarrowhead1
% End of user PostScript
0 1 .821 r
.31975 .70683 m
.30064 .66056 L
.27784 .62029 L
.25099 .58476 L
.21966 .55294 L
.18336 .5239 L
.14148 .49683 L
.09333 .471 L
.03808 .44576 L
s
.03808 .44576 m
0 .43056 L
s
1 0 0 r
.31975 .70683 m
.30064 .66056 L
s
% Start of user PostScript
-5.4074678 6.2048299 -5.9807691 4.8169437 MAarrowhead1
% End of user PostScript
1 .158 0 r
.27784 .62029 m
.25099 .58476 L
s
% Start of user PostScript
-6.6649352 3.6085559 -7.4704399 2.5428633 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-17.927532 -3.16149 -20.409232 -3.9733935 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-50.921241 -12.186623 -58.048753 -13.980724 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-145.30902 -35.532566 -165.66664 -40.531383 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-414.81306 -101.61244 -472.93222 -115.85415 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1184.2024 -290.12347 -1350.1212 -330.77386 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3380.6528 -828.25229 -3854.3168 -944.29917 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-9651.0663 -2364.4917 -11003.279 -2695.7813 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-27551.804 -6750.1367 -31412.093 -7695.8999 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-78654.717 -19270.248 -89675.047 -21970.207 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-224542.99 -55012.584 -256003.77 -62720.41 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-641023.94 -157049.58 -730837.95 -179053.83 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1829991.1 -448344.17 -2086391.6 -511161.77 MAarrowhead1
% End of user PostScript
.975 0 1 r
.42284 .73004 m
.41812 .68764 L
.41174 .65167 L
.40361 .62097 L
.39365 .59458 L
.3817 .57166 L
.36759 .55153 L
.35109 .53358 L
.33195 .51728 L
.30983 .50218 L
.28438 .48786 L
.25517 .47397 L
.22169 .46014 L
.18339 .44606 L
.13961 .43142 L
.0896 .4159 L
.0325 .39919 L
s
.0325 .39919 m
0 .39009 L
s
1 0 0 r
.42284 .73004 m
.41812 .68764 L
s
% Start of user PostScript
-2.3147842 6.9012834 -2.4562683 5.6293384 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41174 .65167 m
.40361 .62097 L
s
% Start of user PostScript
-2.6478669 4.5500945 -2.8915831 3.6291023 MAarrowhead1
% End of user PostScript
1 .473 0 r
.28438 .48786 m
.25517 .47397 L
s
% Start of user PostScript
-6.4685737 -0.36407914 -7.3450018 -0.78103569 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-18.21038 -4.174878 -20.754823 -4.8457469 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-51.926753 -12.654649 -59.200574 -14.44787 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-148.22605 -36.299283 -168.99365 -41.389921 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-423.15149 -103.66756 -482.43925 -118.19356 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1208.0095 -295.95903 -1377.2639 -337.42618 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-3448.6177 -844.90422 -3931.8043 -963.284 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-9845.0921 -2412.0278 -11224.49 -2749.9776 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-28105.707 -6885.8421 -32043.605 -7850.619 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-80235.998 -19657.659 -91477.882 -22411.898 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-229057.23 -56118.562 -261150.49 -63981.346 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-653911.14 -160206.92 -745530.78 -182653.55 MAarrowhead1
% End of user PostScript
0 1 .44 r
.59514 .23467 m
.6014 .28402 L
.60971 .32596 L
.62017 .3618 L
.6329 .3927 L
.64809 .41959 L
.66599 .44331 L
.68686 .46455 L
.71105 .48393 L
.73896 .502 L
.77106 .51923 L
.80788 .53607 L
.85006 .55292 L
.8983 .57018 L
.95344 .58823 L
s
.95344 .58823 m
1 .60244 L
s
1 0 0 r
.59514 .23467 m
.6014 .28402 L
s
% Start of user PostScript
2.8541446 -7.9598979 3.0420466 -6.4793092 MAarrowhead1
% End of user PostScript
1 .158 0 r
.60971 .32596 m
.62017 .3618 L
s
% Start of user PostScript
3.2913963 -5.2213267 3.6049846 -4.1458938 MAarrowhead1
% End of user PostScript
1 .473 0 r
.77106 .51923 m
.80788 .53607 L
s
% Start of user PostScript
8.1318425 0.57694775 9.2365467 1.0820754 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
22.917842 5.2824971 26.12073 6.1222547 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
65.356001 15.934057 74.511135 18.189974 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
186.56154 45.68888 212.70027 52.095852 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
532.59086 130.47939 607.21218 148.76218 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1520.4362 372.50281 1733.4648 424.69456 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
4340.5314 1063.4213 4948.6843 1212.4175 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
12391.322 3035.849 14127.473 3461.2026 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
35374.669 8666.723 40331.022 9881.0195 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
100987.38 24741.707 115136.75 28208.273 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
288298.15 70632.47 328691.67 80528.801 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
823031.76 201641.13 938346.92 229893.12 MAarrowhead1
% End of user PostScript
.762 0 1 r
.31226 .26339 m
.28129 .28738 L
.24675 .30527 L
.20802 .31776 L
.1644 .32542 L
.11512 .32864 L
.0593 .32774 L
s
.0593 .32774 m
0 .32318 L
s
1 0 0 r
.31226 .26339 m
.28129 .28738 L
s
% Start of user PostScript
-5.6322358 -7.0981785 -6.5613645 -6.37847 MAarrowhead1
% End of user PostScript
1 .158 0 r
.24675 .30527 m
.20802 .31776 L
s
% Start of user PostScript
-7.5974808 -5.8419186 -8.7594171 -5.4671372 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-22.524229 -6.4530445 -25.702986 -7.0769906 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-64.498087 -16.021364 -73.540302 -18.20033 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-184.17477 -45.173981 -209.9808 -51.48787 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-525.7918 -128.83004 -599.4609 -146.87682 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1501.0297 -367.75211 -1711.3394 -419.27709 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4285.1307 -1049.8491 -4885.5214 -1196.9435 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-12233.165 -2997.101 -13947.156 -3417.0255 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-34923.162 -8556.1048 -39816.254 -9754.9026 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-99698.424 -24425.914 -113667.19 -27848.235 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-284618.44 -69730.948 -324496.39 -79500.967 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-812526.94 -199067.47 -926370.28 -226958.86 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2319596.8 -568296.58 -2644596.1 -647920.75 MAarrowhead1
% End of user PostScript
0 1 .743 r
.66493 .43934 m
.68557 .46114 L
.7095 .48097 L
.73713 .4994 L
.76892 .51691 L
.8054 .53396 L
.84719 .55097 L
.895 .56833 L
.94964 .58643 L
s
.94964 .58643 m
1 .60194 L
s
1 0 0 r
.66493 .43934 m
.68557 .46114 L
s
% Start of user PostScript
4.9479449 -1.8198969 5.5669701 -1.1659067 MAarrowhead1
% End of user PostScript
1 .158 0 r
.7095 .48097 m
.73713 .4994 L
s
% Start of user PostScript
6.2850251 -0.57087497 7.1139476 -0.018114351 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
17.499697 3.7917891 19.93945 4.4716295 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
49.854064 12.097776 56.836279 13.827684 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
142.29866 34.835563 162.23549 39.724572 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
406.22759 99.518531 463.14408 113.46402 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1159.6946 284.12136 1322.1797 323.93012 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3310.6887 811.11176 3774.5501 924.75692 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
9451.3334 2315.5577 10775.562 2639.991 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
26981.608 6610.4398 30762.007 7536.6301 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
77026.925 18871.442 87819.185 21515.524 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
219895.98 53874.076 250705.66 61422.385 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
627757.68 153799.37 715712.95 175348.24 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1792118.7 439065.49 2043212.9 500583.06 MAarrowhead1
% End of user PostScript
.95 1 0 r
.26752 .7045 m
.24134 .65477 L
.21044 .61106 L
.17433 .57206 L
.13242 .53664 L
.08402 .50379 L
.02832 .47263 L
s
.02832 .47263 m
0 .45922 L
s
1 0 0 r
.26752 .7045 m
.24134 .65477 L
s
% Start of user PostScript
-6.9745437 6.1350566 -7.7597171 4.643216 MAarrowhead1
% End of user PostScript
1 .158 0 r
.21044 .61106 m
.17433 .57206 L
s
% Start of user PostScript
-8.686715 3.3319112 -9.770138 2.1618996 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-23.653423 -4.512973 -26.936122 -5.5296265 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-67.256709 -16.176723 -76.672691 -18.533492 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-191.94088 -46.954448 -218.83203 -53.554436 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-547.93681 -134.22682 -624.70795 -153.03835 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1564.2431 -383.23253 -1783.4095 -436.9285 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4465.5906 -1094.0598 -5091.2655 -1247.3491 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-12748.34 -3123.3176 -14534.513 -3560.9264 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-36393.881 -8916.428 -41493.036 -10165.711 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-103897.02 -25454.563 -118454.06 -29021.008 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-296604.58 -72667.528 -338161.91 -82848.992 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-846744.89 -207450.8 -965382.52 -236516.78 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2417282. -592229.26 -2755968. -675206.64 MAarrowhead1
% End of user PostScript
.588 1 0 r
.30597 .54492 m
.28105 .5235 L
.25226 .50367 L
.21913 .48489 L
.18109 .46667 L
.1375 .44857 L
.08763 .43016 L
.03062 .41102 L
s
.03062 .41102 m
0 .4015 L
s
1 0 0 r
.30597 .54492 m
.28105 .5235 L
s
% Start of user PostScript
-5.8208238 1.347686 -6.5684734 0.70498487 MAarrowhead1
% End of user PostScript
1 .158 0 r
.25226 .50367 m
.21913 .48489 L
s
% Start of user PostScript
-7.4321265 0.10999273 -8.4261725 -0.45342816 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-20.81216 -4.6455644 -23.717057 -5.4323682 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-59.319321 -14.426661 -67.627959 -16.479896 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-169.3221 -41.458579 -193.04524 -47.274843 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-483.37442 -118.4199 -551.09998 -135.01349 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1379.933 -338.07946 -1573.2757 -385.44826 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3939.424 -965.15066 -4491.3775 -1100.3782 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-11246.243 -2755.3069 -12821.956 -3141.3536 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-32105.704 -7865.8331 -36604.041 -8967.9168 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-91655.162 -22455.331 -104496.99 -25601.553 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-261656.59 -64105.34 -298317.35 -73087.153 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-746975.58 -183007.52 -851634.5 -208648.75 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2132461.2 -522448.73 -2431240.9 -595649.14 MAarrowhead1
% End of user PostScript
1 .58 0 r
.6844 .39408 m
.70654 .42453 L
.73239 .45175 L
.76238 .47652 L
.79699 .49954 L
.83681 .52143 L
.8825 .54274 L
.93485 .56401 L
.99473 .58573 L
s
.99473 .58573 m
1 .58747 L
s
1 0 0 r
.6844 .39408 m
.70654 .42453 L
s
% Start of user PostScript
5.5320332 -3.1777327 6.1961494 -2.2640369 MAarrowhead1
% End of user PostScript
1 .158 0 r
.73239 .45175 m
.76238 .47652 L
s
% Start of user PostScript
6.9717007 -1.4474552 7.8712544 -0.70429679 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
19.240846 3.9730396 21.918546 4.7518196 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
54.773225 13.245357 62.443255 15.153321 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
156.32977 38.25963 178.23217 43.632442 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
446.28067 109.32828 508.80893 124.64917 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1274.0373 312.13433 1452.5429 355.86822 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3637.1132 891.08491 4146.7099 1015.9352 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
10383.208 2543.865 11838.001 2900.2866 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
29641.917 7262.2102 33795.053 8279.7202 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
84621.559 20732.113 96477.905 23636.894 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
241577.1 59185.905 275424.52 67478.456 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
689652.79 168963.55 786280.2 192637.07 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1968816.5 482356.09 2244667.8 549939.12 MAarrowhead1
% End of user PostScript
0 .524 1 r
.31355 .62653 m
.29164 .59263 L
.26596 .56254 L
.23611 .53536 L
.20158 .51034 L
.16181 .48677 L
.11613 .46404 L
.06377 .44159 L
.00384 .41888 L
s
.00384 .41888 m
0 .41756 L
s
1 0 0 r
.31355 .62653 m
.29164 .59263 L
s
% Start of user PostScript
-5.593628 3.7959099 -6.2508706 2.7789853 MAarrowhead1
% End of user PostScript
1 .158 0 r
.26596 .56254 m
.23611 .53536 L
s
% Start of user PostScript
-7.0211537 1.8761623 -7.9168441 1.0609198 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-19.289554 -3.8814655 -21.971545 -4.6784447 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-54.890564 -13.2498 -62.57644 -15.165673 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-156.65965 -38.334743 -178.60813 -43.71979 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-447.22122 -109.55737 -509.88122 -124.91076 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1276.722 -312.79178 -1455.6038 -356.61788 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3644.7776 -892.96261 -4155.4482 -1018.076 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-10405.088 -2549.2256 -11862.947 -2906.3983 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-29704.381 -7277.5138 -33866.268 -8297.1679 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-84799.88 -20775.801 -96681.211 -23686.703 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-242086.17 -59310.627 -276004.92 -67620.652 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-691106.08 -169319.61 -787937.11 -193043.02 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1972965.3 -483372.55 -2249397.9 -551097.99 MAarrowhead1
% End of user PostScript
1 0 .57 r
.64556 .41904 m
.6631 .44266 L
.68356 .46379 L
.7073 .48306 L
.73468 .50099 L
.76618 .51807 L
.80232 .53473 L
.84372 .55139 L
.89107 .56843 L
.94519 .58623 L
s
.94519 .58623 m
1 .60301 L
s
1 0 0 r
.64556 .41904 m
.6631 .44266 L
s
% Start of user PostScript
4.3667033 -2.4287885 4.8928701 -1.7202658 MAarrowhead1
% End of user PostScript
1 .158 0 r
.68356 .46379 m
.7073 .48306 L
s
% Start of user PostScript
5.5069483 -1.0862289 6.2189043 -0.50832769 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
15.210331 3.1546516 17.327454 3.7680801 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
43.302403 10.474729 49.366225 11.982598 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
123.59126 30.248084 140.90689 34.495601 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
352.82095 86.433024 402.25459 98.545394 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1007.2295 246.76747 1148.3526 281.34264 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2875.4321 704.4747 3278.3095 803.17893 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
8208.7655 2011.131 9358.8975 2292.9111 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
23434.332 5741.3645 26717.722 6545.7884 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
66900.186 16390.412 76273.586 18686.876 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
190986.23 46791.245 217745.36 53347.177 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
545226.3 133579.35 621618.09 152295.19 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1556508.6 381341.5 1774591.4 434771.35 MAarrowhead1
% End of user PostScript
0 1 .047 r
.66541 .65314 m
.69134 .64084 L
.72045 .6324 L
.75326 .62745 L
.79034 .6257 L
.83236 .62696 L
.88004 .6311 L
.93422 .63808 L
.99583 .64792 L
s
.99583 .64792 m
1 .64868 L
s
1 0 0 r
.66541 .65314 m
.69134 .64084 L
s
% Start of user PostScript
4.962271 4.5942183 5.7402475 4.2251133 MAarrowhead1
% End of user PostScript
1 .158 0 r
.72045 .6324 m
.75326 .62745 L
s
% Start of user PostScript
6.6135236 3.9720826 7.5977221 3.8235921 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
19.373572 5.2986969 22.101527 5.8755563 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
55.423388 13.708281 63.191947 15.590081 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
158.24954 38.801266 180.42267 44.228594 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
451.77619 110.69141 515.07483 126.19827 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1289.7293 315.98279 1470.4337 360.2547 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3681.9116 902.06137 4197.7851 1028.4493 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
10511.098 2575.1982 11983.811 2936.0097 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
30007.018 7351.6594 34211.308 8381.7021 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
85663.848 20987.471 97666.229 23928.031 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
244552.62 59914.902 278816.94 68309.592 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
698147.28 171044.69 795964.86 195009.8 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1993066.5 488297.3 2272315.5 556712.75 MAarrowhead1
% End of user PostScript
0 1 .293 r
.18328 .5865 m
.14292 .54943 L
.09624 .51531 L
.04246 .48321 L
s
.04246 .48321 m
0 .46195 L
s
1 0 0 r
.18328 .5865 m
.14292 .54943 L
s
% Start of user PostScript
-9.5016954 2.5950047 -10.712458 1.4827987 MAarrowhead1
% End of user PostScript
1 .158 0 r
.09624 .51531 m
.04246 .48321 L
s
% Start of user PostScript
-12.112828 0.45925418 -13.726062 -0.5037113 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-33.86078 -7.4911763 -38.585322 -8.7819847 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-96.496755 -23.452577 -110.01231 -26.795162 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-275.4387 -67.437568 -314.02939 -76.89956 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-786.31138 -192.6343 -896.48139 -219.62746 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2244.7546 -549.95794 -2559.2676 -627.01341 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6408.311 -1570.0228 -7306.1809 -1789.9992 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-18294.406 -4482.0927 -20857.639 -5110.0798 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-52226.756 -12795.451 -59544.259 -14588.224 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-149096.62 -36528.373 -169986.58 -41646.371 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-425640.09 -104280.97 -485276.62 -118891.8 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1215114.7 -297700.66 -1385364.7 -339411.57 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3468901.8 -849873.99 -3954930.4 -968950.03 MAarrowhead1
% End of user PostScript
0 1 .745 r
.44205 .36118 m
.43088 .37909 L
.41865 .39332 L
.40513 .40438 L
.39007 .41268 L
.37319 .41855 L
.35419 .42224 L
.33273 .42394 L
.30843 .4238 L
.28088 .4219 L
.24958 .41828 L
.21399 .41293 L
.1735 .40583 L
.12741 .39689 L
.07492 .38598 L
.01512 .37297 L
s
.01512 .37297 m
0 .36957 L
s
1 0 0 r
.44205 .36118 m
.43088 .37909 L
s
% Start of user PostScript
-1.7383876 -4.1647278 -2.0734871 -3.6274193 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41865 .39332 m
.40513 .40438 L
s
% Start of user PostScript
-2.4403733 -3.2005149 -2.8460119 -2.868721 MAarrowhead1
% End of user PostScript
1 .473 0 r
.24958 .41828 m
.21399 .41293 L
s
% Start of user PostScript
-7.5127079 -2.4517087 -8.5802763 -2.6120189 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-21.575422 -5.4294271 -24.601873 -6.1471292 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-61.623481 -15.131322 -70.258386 -17.241275 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-175.9294 -43.110261 -200.5791 -49.148078 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-502.2438 -123.05058 -572.61334 -140.29067 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1433.8028 -351.27926 -1634.6933 -400.49695 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-4093.2115 -1002.8287 -4666.7123 -1143.3353 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-11685.275 -2862.8689 -13322.501 -3263.9861 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-33359.049 -8172.9003 -38032.993 -9318.0072 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-95233.205 -23331.945 -108576.35 -26600.989 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-271871.16 -66607.89 -309963.09 -75940.336 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-776136.08 -190151.79 -884880.69 -216794. MAarrowhead1
% End of user PostScript
1 0 .552 r
.72275 .36668 m
.74936 .40433 L
.78046 .43792 L
.81656 .46843 L
.85824 .49672 L
.9062 .52356 L
.96125 .54963 L
s
.96125 .54963 m
1 .56557 L
s
1 0 0 r
.72275 .36668 m
.74936 .40433 L
s
% Start of user PostScript
6.6825484 -3.9994619 7.4808452 -2.8700594 MAarrowhead1
% End of user PostScript
1 .158 0 r
.78046 .43792 m
.81656 .46843 L
s
% Start of user PostScript
8.4138532 -1.8623581 9.4966595 -0.94703181 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
23.196746 4.7618433 26.424291 5.7052185 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
66.028663 15.960561 75.274658 18.261651 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
188.45284 46.119773 214.85576 52.596852 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
537.98333 131.79291 613.36 150.26202 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1535.8289 376.27221 1751.0142 428.99264 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4384.4743 1074.1868 4998.7839 1224.6915 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
12516.77 3066.5833 14270.497 3496.2431 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
35732.796 8754.4634 40739.326 9981.0532 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
102009.76 24992.187 116302.37 28493.849 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
291216.83 71347.54 332019.29 81344.061 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
831363.99 203682.51 947846.59 232220.52 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2373372.7 581471.57 2705906.5 662941.68 MAarrowhead1
% End of user PostScript
.77 1 0 r
.23646 .37133 m
.19797 .37252 L
.15434 .37069 L
.10482 .36595 L
.04853 .35833 L
s
.04853 .35833 m
0 .35034 L
s
1 0 0 r
.23646 .37133 m
.19797 .37252 L
s
% Start of user PostScript
-7.9061997 -3.859999 -9.0610178 -3.8243465 MAarrowhead1
% End of user PostScript
1 .158 0 r
.15434 .37069 m
.10482 .36595 L
s
% Start of user PostScript
-10.369838 -3.8792032 -11.855531 -4.0214282 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-29.884546 -7.6359673 -34.079372 -8.6116193 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-85.380149 -20.991768 -97.344588 -23.910805 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-243.7582 -59.7376 -277.91164 -68.102253 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-695.88301 -170.49401 -793.38344 -194.38075 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1986.6033 -486.7148 -2264.9468 -554.90823 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5671.343 -1389.4679 -6465.9562 -1584.1465 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-16190.515 -3966.6437 -18458.971 -4522.4111 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-46220.58 -11323.95 -52696.556 -12910.551 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-131950.22 -32327.54 -150437.8 -36856.96 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-376690.67 -92288.46 -429468.89 -105219.02 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1075374.2 -263464.52 -1226045.1 -300378.59 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3069971.5 -752136.87 -3500105.9 -857518.93 MAarrowhead1
% End of user PostScript
0 1 .392 r
.78859 .60777 m
.82993 .61176 L
.87692 .61815 L
.93036 .62697 L
.99118 .6383 L
s
.99118 .6383 m
1 .64008 L
s
1 0 0 r
.78859 .60777 m
.82993 .61176 L
s
% Start of user PostScript
8.6576922 3.2332351 9.8979502 3.3528525 MAarrowhead1
% End of user PostScript
1 .158 0 r
.87692 .61815 m
.93036 .62697 L
s
% Start of user PostScript
11.30747 3.5444622 12.910715 3.8090007 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
32.442888 8.130218 36.992919 9.2148519 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
92.655884 22.743188 105.63897 25.916946 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
264.52239 64.817479 301.58493 73.896066 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
755.15898 185.01479 860.96453 210.93655 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2155.8236 528.17303 2457.8766 602.1753 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6154.4319 1507.8236 7016.7308 1719.0851 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
17569.634 4304.5252 20031.319 4907.6332 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
50157.681 12288.531 57185.285 14010.28 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
143189.83 35081.223 163252.19 39996.461 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
408777.44 100149.66 466051.35 114181.65 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1166975.3 285906.61 1330480.5 325965.05 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3331473.8 816204.41 3798247.3 930562.99 MAarrowhead1
% End of user PostScript
1 .007 0 r
.47437 .27225 m
.46536 .30674 L
.45599 .33505 L
.44604 .35816 L
.43534 .37684 L
.42365 .39176 L
.41076 .40343 L
.39643 .4123 L
.38039 .41869 L
.36236 .42289 L
.34201 .42509 L
.31898 .42545 L
.29288 .42406 L
.26325 .42097 L
.22956 .4162 L
.19124 .40972 L
.14762 .40146 L
.09795 .39131 L
.04137 .37914 L
s
.04137 .37914 m
0 .3699 L
s
1 0 0 r
.47437 .27225 m
.46536 .30674 L
s
% Start of user PostScript
-0.76876868 -6.8324172 -1.0391407 -5.7979419 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45599 .33505 m
.44604 .35816 L
s
% Start of user PostScript
-1.3204469 -4.9485 -1.6186837 -4.2553499 MAarrowhead1
% End of user PostScript
1 .473 0 r
.34201 .42509 m
.31898 .42545 L
s
% Start of user PostScript
-4.7397743 -2.2472071 -5.4304519 -2.2365099 MAarrowhead1
% End of user PostScript
1 .788 0 r
.04137 .37914 m
0 0 rlineto s
.04137 .37914 m
0 .3699 L
s
% Start of user PostScript
-13.758879 -3.6258895 -15.692882 -4.0574721 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-39.332251 -9.6961961 -44.844568 -11.036784 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-112.29802 -27.52685 -128.03247 -31.379428 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-320.59065 -78.547368 -365.50876 -89.551668 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-915.22087 -224.22806 -1043.4527 -255.64447 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2612.767 -640.12286 -2978.8424 -729.81057 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-7458.9109 -1827.4183 -8503.9806 -2083.4583 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-21293.652 -5216.9022 -24277.111 -5947.8435 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-60788.985 -14893.18 -69306.144 -16979.867 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-173540.02 -42516.956 -197854.75 -48474.017 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-495420.95 -121377.14 -564834.49 -138383.32 MAarrowhead1
% End of user PostScript
1 0 .755 r
.58355 .52291 m
.59532 .52539 L
.60872 .52833 L
.624 .53179 L
.64141 .53583 L
.66125 .54049 L
.68386 .54587 L
.70965 .55205 L
.73904 .55914 L
.77254 .56725 L
.81074 .57653 L
.85429 .58713 L
.90393 .59924 L
.96054 .61306 L
s
.96054 .61306 m
1 .62271 L
s
1 0 0 r
.58355 .52291 m
.59532 .52539 L
s
% Start of user PostScript
2.5065769 0.68721074 2.8595637 0.76158067 MAarrowhead1
% End of user PostScript
1 .158 0 r
.60872 .52833 m
.624 .53179 L
s
% Start of user PostScript
3.261711 0.85000128 3.719956 0.95383971 MAarrowhead1
% End of user PostScript
1 .473 0 r
.81074 .57653 m
.85429 .58713 L
s
% Start of user PostScript
9.3221871 2.2958661 10.628613 2.6139583 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
26.615428 6.5235322 30.34459 7.4367047 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
75.982146 18.616132 86.628038 21.224245 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
216.91349 53.143526 247.3053 60.589432 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
619.24332 151.71341 706.00564 172.97 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1767.812 433.1104 2015.5005 493.7936 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
5046.7385 1236.4408 5753.8382 1409.6789 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
14407.398 3529.7836 16426.021 4024.3424 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
41130.149 10076.804 46892.903 11488.667 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
117418.09 28767.198 133869.57 32797.776 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
335204.44 82124.416 382170.01 93630.886 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
956939.53 234448.27 1091016.5 267296.87 MAarrowhead1
% End of user PostScript
1 .451 0 r
.17424 .24827 m
.12439 .26454 L
.06825 .27455 L
.00483 .27884 L
s
.00483 .27884 m
0 .27877 L
s
1 0 0 r
.17424 .24827 m
.12439 .26454 L
s
% Start of user PostScript
-9.7728042 -7.5517761 -11.268339 -7.0637485 MAarrowhead1
% End of user PostScript
1 .158 0 r
.06825 .27455 m
.00483 .27884 L
s
% Start of user PostScript
-12.952494 -6.7634854 -14.855165 -6.6348597 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-37.729795 -10.08671 -43.036763 -11.24725 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-107.88761 -26.630187 -123.00862 -30.30201 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-308.03841 -75.51527 -351.19888 -86.081799 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-879.39587 -215.46114 -1002.6085 -245.64618 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2510.4961 -615.06909 -2862.2424 -701.24579 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-7166.9492 -1755.8888 -8171.1121 -2001.9066 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-20460.162 -5012.6988 -23326.84 -5715.0292 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-58409.542 -14310.221 -66593.317 -16315.229 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-166747.2 -40852.729 -190110.18 -46576.615 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-476028.85 -116626.12 -542725.37 -132966.63 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1358964.2 -332943.51 -1549369. -379592.3 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3879562.5 -950485.05 -4423128.9 -1083657.7 MAarrowhead1
% End of user PostScript
.079 1 0 r
.79449 .19163 m
.82643 .2625 L
.8644 .3244 L
.90897 .3792 L
.96086 .42852 L
s
.96086 .42852 m
1 .45802 L
s
1 0 0 r
.79449 .19163 m
.82643 .2625 L
s
% Start of user PostScript
8.8346701 -9.2510558 9.7930235 -7.1250625 MAarrowhead1
% End of user PostScript
1 .158 0 r
.8644 .3244 m
.90897 .3792 L
s
% Start of user PostScript
10.931952 -5.2681414 12.269086 -3.624067 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
29.541567 5.3717585 33.634963 6.6837483 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
83.943683 20.12792 95.694326 23.079386 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
239.55 58.586399 273.11089 66.825792 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
683.84427 167.51632 779.65725 190.99431 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1952.2293 478.28659 2225.7564 545.30114 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5573.2107 1365.4241 6354.0745 1556.7344 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
15910.367 3898.0077 18139.572 4444.1586 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
45420.816 11128.009 51784.737 12687.157 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
129667.06 31768.171 147834.74 36219.216 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
370172.72 90691.575 422037.7 103398.39 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1056766.8 258905.74 1204830.6 295181.08 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3016851.2 739122.49 3439542.9 842681.12 MAarrowhead1
% End of user PostScript
0 1 .767 r
.51853 .19328 m
.51351 .24361 L
.50904 .28554 L
.505 .32045 L
.50128 .34949 L
.49776 .37361 L
.49437 .39363 L
.49101 .4102 L
.48761 .42388 L
.48408 .43512 L
.48036 .44431 L
.47636 .45176 L
.47201 .45773 L
.46722 .46242 L
.4619 .46601 L
.45596 .46864 L
.44929 .47041 L
.44176 .47141 L
.43325 .4717 L
.42361 .47132 L
.41266 .47029 L
.40022 .46862 L
.38607 .4663 L
.36997 .46331 L
.35163 .45962 L
.33074 .45517 L
.30694 .4499 L
.27983 .44372 L
.24892 .43653 L
.21369 .42823 L
.17354 .41866 L
.12777 .40767 L
.07559 .39507 L
.0161 .38066 L
s
.0161 .38066 m
0 .37674 L
s
1 0 0 r
.51853 .19328 m
.51351 .24361 L
s
% Start of user PostScript
0.55589901 -9.2016916 0.40517675 -7.691621 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50904 .28554 m
.505 .32045 L
s
% Start of user PostScript
0.27121022 -6.4337346 0.15007262 -5.3865353 MAarrowhead1
% End of user PostScript
1 .473 0 r
.48036 .44431 m
.47636 .45176 L
s
% Start of user PostScript
-0.58927398 -1.6706463 -0.70920345 -1.4471724 MAarrowhead1
% End of user PostScript
1 .788 0 r
.43325 .4717 m
.42361 .47132 L
s
% Start of user PostScript
-2.0024178 -0.84896555 -2.2917508 -0.8604796 MAarrowhead1
% End of user PostScript
.897 1 0 r
.30694 .4499 m
.27983 .44372 L
s
% Start of user PostScript
-5.7916656 -1.5030953 -6.6051974 -1.6884681 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-16.551662 -4.0748827 -18.871203 -4.6398923 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-47.255727 -11.582198 -53.876852 -13.203592 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-134.90633 -33.05287 -153.80811 -37.683588 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-385.12997 -94.356328 -439.09063 -107.57654 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-1099.4667 -269.3672 -1253.5132 -307.10828 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-3138.7507 -768.98764 -3578.5217 -876.73067 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-8960.4858 -2195.3011 -10215.941 -2502.8852 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-25580.339 -6267.1318 -29164.406 -7145.2211 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-73026.591 -17891.369 -83258.364 -20398.132 MAarrowhead1
% End of user PostScript
.025 0 1 r
.37105 .33413 m
.3497 .35114 L
.3259 .36387 L
.29922 .37282 L
.26917 .37838 L
.23524 .38085 L
.19682 .38043 L
.15323 .37725 L
.10372 .37138 L
.04742 .36281 L
s
.04742 .36281 m
0 .35442 L
s
1 0 0 r
.37105 .33413 m
.3497 .35114 L
s
% Start of user PostScript
-3.8683987 -4.9762068 -4.5090254 -4.465769 MAarrowhead1
% End of user PostScript
1 .158 0 r
.3259 .36387 m
.29922 .37282 L
s
% Start of user PostScript
-5.2230713 -4.0838846 -6.0235303 -3.8154197 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-15.499029 -4.4556814 -17.686721 -4.882577 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-44.384652 -11.028758 -50.607181 -12.527652 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-126.74146 -31.087706 -144.50012 -35.432529 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-361.82834 -88.655743 -412.5244 -101.07476 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1032.9471 -253.07197 -1177.6736 -288.52934 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2948.8513 -722.46313 -3362.0155 -823.68746 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8418.3622 -2062.482 -9597.8609 -2351.4568 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-24032.688 -5887.9605 -27399.913 -6712.924 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-68608.367 -16808.913 -78221.102 -19164.013 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-195862.74 -47985.979 -223305.11 -54709.306 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-559147.72 -136990.07 -637490.04 -156183.78 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1596251.4 -391078.4 -1819902.6 -445872.49 MAarrowhead1
% End of user PostScript
.371 0 1 r
.60998 .54137 m
.62574 .54284 L
.64365 .54524 L
.66403 .54856 L
.68721 .55286 L
.71361 .55817 L
.74369 .56457 L
.77795 .57216 L
.81699 .58105 L
.86149 .59139 L
.9122 .60335 L
.97002 .61712 L
s
.97002 .61712 m
1 .62432 L
s
1 0 0 r
.60998 .54137 m
.62574 .54284 L
s
% Start of user PostScript
3.2993414 1.2410539 3.7722067 1.2852164 MAarrowhead1
% End of user PostScript
1 .158 0 r
.64365 .54524 m
.66403 .54856 L
s
% Start of user PostScript
4.3095702 1.3570574 4.9207596 1.4568946 MAarrowhead1
% End of user PostScript
1 .473 0 r
.9122 .60335 m
.97002 .61712 L
s
% Start of user PostScript
12.36612 3.100403 14.100472 3.5135982 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
35.31756 8.6693388 40.266318 9.8790233 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
100.82783 24.706517 114.95494 28.166983 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
287.84349 70.521993 328.17332 80.402571 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
821.73398 201.32339 936.86732 229.5308 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2345.8811 574.73622 2674.563 655.26262 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
6697.0066 1640.7532 7635.3257 1870.6395 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
19118.573 4684.012 21797.28 5340.29 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
54579.582 13371.888 62226.739 15245.427 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
155813.45 38173.983 177644.51 43522.549 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
444815.26 108978.85 507138.43 124247.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1269855.8 311112.14 1447775.6 354702.13 MAarrowhead1
% End of user PostScript
0 1 .477 r
.70614 .61352 m
.73657 .61053 L
.771 .61026 L
.81004 .61256 L
.85438 .61736 L
.90478 .62465 L
.96212 .63447 L
s
.96212 .63447 m
1 .64171 L
s
1 0 0 r
.70614 .61352 m
.73657 .61053 L
s
% Start of user PostScript
6.1842438 3.4055334 7.0970004 3.3159754 MAarrowhead1
% End of user PostScript
1 .158 0 r
.771 .61026 m
.81004 .61256 L
s
% Start of user PostScript
8.1299762 3.3077554 9.3012855 3.3767156 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
23.485443 6.0628731 26.783559 6.8197153 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
67.110912 16.514591 76.515614 18.806704 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
191.60303 46.959395 218.44899 53.53378 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
546.99071 134.01563 623.62981 152.79139 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1561.5465 382.57671 1780.3352 436.17934 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4457.8934 1092.1752 5082.4899 1245.2 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
12726.366 3117.9343 14509.46 3554.7888 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
36331.151 8901.0593 41421.517 10148.189 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
103717.94 25410.689 118249.89 28970.986 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
296093.34 72542.275 337579.04 82706.19 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
845285.41 207093.23 963718.54 236109.11 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2413115.5 591208.47 2751217.7 674042.82 MAarrowhead1
% End of user PostScript
1 0 .078 r
.62774 .17682 m
.63696 .23781 L
.64891 .28973 L
.66373 .33424 L
.68163 .37273 L
.70287 .40639 L
.72779 .43624 L
.75678 .46315 L
.79031 .48789 L
.82895 .51115 L
.87334 .53353 L
.92423 .5556 L
.98249 .57788 L
s
.98249 .57788 m
1 .58392 L
s
1 0 0 r
.62774 .17682 m
.63696 .23781 L
s
% Start of user PostScript
3.8321879 -9.6952712 4.1087722 -7.8657608 MAarrowhead1
% End of user PostScript
1 .158 0 r
.64891 .28973 m
.66373 .33424 L
s
% Start of user PostScript
4.4672397 -6.3080559 4.9119178 -4.9727433 MAarrowhead1
% End of user PostScript
1 .473 0 r
.87334 .53353 m
.92423 .5556 L
s
% Start of user PostScript
11.200244 1.0058879 12.726959 1.6678874 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
31.609779 7.3362064 36.028641 8.4864325 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
90.153789 21.991668 102.78291 25.101653 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
257.35037 63.027825 293.40724 71.865413 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
734.67751 179.98924 837.61322 205.20915 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2097.3517 513.84572 2391.2121 585.84113 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
5987.5062 1466.9267 6826.417 1672.4583 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
17093.095 4187.774 19488.013 4774.524 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
48797.261 11955.231 55634.257 13630.282 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
139306.12 34129.72 158824.33 38911.643 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
397690.23 97433.311 453410.7 111084.71 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1135323.6 278152.01 1294394. 317123.95 MAarrowhead1
% End of user PostScript
0 1 .076 r
.2325 .40776 m
.19437 .40284 L
.15101 .39591 L
.10165 .38689 L
.04546 .3757 L
s
.04546 .3757 m
0 .36608 L
s
1 0 0 r
.2325 .40776 m
.19437 .40284 L
s
% Start of user PostScript
-8.0248562 -2.767303 -9.1688363 -2.9148371 MAarrowhead1
% End of user PostScript
1 .158 0 r
.15101 .39591 m
.10165 .38689 L
s
% Start of user PostScript
-10.46985 -3.1228347 -11.950438 -3.3931752 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-30.006258 -7.4824339 -34.213648 -8.4915399 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-85.68915 -21.02442 -97.695829 -23.960938 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-244.6313 -59.941399 -278.90682 -68.337638 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-698.37342 -171.10179 -796.22272 -195.07439 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1993.7124 -488.45595 -2273.0519 -556.89351 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5691.6379 -1394.44 -6489.0946 -1589.8153 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-16248.452 -3980.8383 -18525.027 -4538.5945 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-46385.98 -11364.472 -52885.13 -12956.751 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-132422.41 -32443.224 -150976.14 -36988.852 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-378038.66 -92618.714 -431005.74 -105595.54 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1079222.4 -264407.33 -1230432.5 -301453.5 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3080957.4 -754828.38 -3512631. -860587.56 MAarrowhead1
% End of user PostScript
.973 0 1 r
.40458 .73425 m
.39752 .68984 L
.38842 .652 L
.37718 .61954 L
.36364 .59143 L
.34759 .56682 L
.32878 .54495 L
.30692 .5252 L
.28164 .507 L
.25253 .48984 L
.21909 .47329 L
.18076 .45692 L
.13689 .44035 L
.08674 .42321 L
.02943 .40512 L
s
.02943 .40512 m
0 .39639 L
s
1 0 0 r
.40458 .73425 m
.39752 .68984 L
s
% Start of user PostScript
-2.862569 7.0275819 -3.0744257 5.6952381 MAarrowhead1
% End of user PostScript
1 .158 0 r
.38842 .652 m
.37718 .61954 L
s
% Start of user PostScript
-3.3473133 4.5600709 -3.6845896 3.5861144 MAarrowhead1
% End of user PostScript
1 .473 0 r
.21909 .47329 m
.18076 .45692 L
s
% Start of user PostScript
-8.4273101 -0.80138621 -9.5771347 -1.2923785 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-23.793236 -5.5326688 -27.11965 -6.3967753 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-67.862559 -16.556542 -77.369093 -18.897162 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-193.719 -47.444413 -220.86061 -54.096764 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-553.02436 -135.48602 -630.50864 -154.47015 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1578.7697 -386.79451 -1799.9714 -440.98865 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-4507.0617 -1104.2209 -5138.5471 -1258.9336 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-12866.731 -3152.3234 -14669.492 -3593.9962 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-36731.864 -8999.2332 -41878.374 -10260.118 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-104861.9 -25690.955 -119554.12 -29290.52 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-299359.09 -73342.377 -341302.36 -83618.395 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-854608.46 -209377.36 -974347.84 -238713.27 MAarrowhead1
% End of user PostScript
.182 1 0 r
.6283 .74847 m
.65159 .71822 L
.67726 .69451 L
.70579 .67647 L
.73771 .66341 L
.77359 .65477 L
.81407 .65015 L
.85987 .64925 L
.91179 .65185 L
.97073 .65785 L
s
.97073 .65785 m
1 .66194 L
s
1 0 0 r
.6283 .74847 m
.65159 .71822 L
s
% Start of user PostScript
3.8488847 7.4539757 4.5475548 6.5464772 MAarrowhead1
% End of user PostScript
1 .158 0 r
.67726 .69451 m
.70579 .67647 L
s
% Start of user PostScript
5.3177078 5.8351941 6.1737341 5.2940467 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
16.1317 5.0164567 18.41797 5.4002798 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
46.275914 11.587391 52.765761 13.135992 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
132.16061 32.437759 150.6791 36.965031 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
377.30359 92.452401 430.16802 105.4018 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1077.1268 263.89715 1228.0434 300.87087 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3074.9756 753.36362 3505.8111 858.91734 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
8778.4212 2150.6958 10008.368 2452.0302 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
25060.582 6139.7925 28571.826 7000.0402 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
71542.793 17527.841 81566.67 19983.671 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
204239.92 50038.371 232856.02 57049.259 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
583062.84 142849.23 664755.91 162863.87 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1664524.2 407805.09 1897741. 464942.75 MAarrowhead1
% End of user PostScript
1 .734 0 r
.5332 .80935 m
.54522 .7624 L
.55771 .72382 L
.57093 .69232 L
.58516 .66682 L
.60066 .64644 L
.61774 .63045 L
.63673 .61827 L
.65796 .60943 L
.68183 .60356 L
.70875 .60038 L
.7392 .59968 L
.77372 .60133 L
.81291 .60526 L
.85745 .61143 L
.90812 .61989 L
.96579 .63072 L
s
.96579 .63072 m
1 .63767 L
s
1 0 0 r
.5332 .80935 m
.54522 .7624 L
s
% Start of user PostScript
0.99596451 9.2806411 1.3567435 7.8719424 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55771 .72382 m
.57093 .69232 L
s
% Start of user PostScript
1.7314196 6.7146695 2.1280121 5.7696978 MAarrowhead1
% End of user PostScript
1 .473 0 r
.70875 .60038 m
.7392 .59968 L
s
% Start of user PostScript
6.2623798 3.011306 7.175964 2.9904334 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
18.187636 4.8027498 20.744401 5.3716955 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
51.9947 12.820032 59.281683 14.591837 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
148.45123 36.389375 169.25123 41.482166 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
423.80165 103.83505 483.1807 118.38205 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1209.8672 296.41611 1379.382 337.94672 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
3453.9217 846.20414 3937.8514 964.76592 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
9860.234 2415.7377 11241.754 2754.2072 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
28148.934 6896.4326 32092.888 7862.6934 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
80359.402 19687.893 91618.577 22446.368 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
229409.52 56204.873 261552.14 64079.751 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
654916.86 160453.32 746677.41 182934.47 MAarrowhead1
% End of user PostScript
.379 0 1 r
.3776 .50206 m
.36124 .49274 L
.34245 .48371 L
.32092 .47474 L
.29629 .46562 L
.26813 .45615 L
.23596 .44612 L
.19922 .43533 L
.1573 .42356 L
.10947 .4106 L
.05491 .39619 L
s
.05491 .39619 m
0 .38197 L
s
1 0 0 r
.3776 .50206 m
.36124 .49274 L
s
% Start of user PostScript
-3.6719068 0.061733416 -4.162843 -0.21780964 MAarrowhead1
% End of user PostScript
1 .158 0 r
.34245 .48371 m
.32092 .47474 L
s
% Start of user PostScript
-4.7264634 -0.48877499 -5.372306 -0.75787061 MAarrowhead1
% End of user PostScript
1 .473 0 r
.05491 .39619 m
0 0 rlineto s
.05491 .39619 m
0 .38197 L
s
% Start of user PostScript
-13.352702 -3.114254 -15.219706 -3.5976979 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-38.08625 -9.2941599 -43.42162 -10.607427 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-108.72065 -26.627679 -123.95331 -30.361086 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-310.37322 -76.038783 -353.85963 -86.693204 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-886.05109 -217.08027 -1010.1959 -247.49558 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2529.493 -619.72062 -2883.9009 -706.54985 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7221.1809 -1769.1748 -8232.9422 -2017.0543 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-20614.982 -5050.6293 -23503.352 -5758.2742 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-58851.522 -14418.505 -67097.222 -16438.685 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-168008.96 -41161.858 -191548.73 -46929.055 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-479630.92 -117508.62 -546832.12 -133972.77 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1369247.4 -335462.86 -1561092.9 -382464.64 MAarrowhead1
% End of user PostScript
1 .634 0 r
.51096 .77834 m
.51924 .7347 L
.52757 .69864 L
.53613 .66895 L
.54511 .64462 L
.5547 .62484 L
.56509 .60893 L
.57649 .59632 L
.5891 .58655 L
.60317 .57928 L
.61895 .5742 L
.63672 .57109 L
.65679 .56978 L
.67953 .57015 L
.70532 .57214 L
.73463 .5757 L
.76794 .58084 L
.80586 .58761 L
.84902 .59609 L
.89818 .60638 L
.95419 .61864 L
s
.95419 .61864 m
1 .62899 L
s
1 0 0 r
.51096 .77834 m
.51924 .7347 L
s
% Start of user PostScript
0.32870318 8.3500845 0.57721243 7.0409611 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52757 .69864 m
.53613 .66895 L
s
% Start of user PostScript
0.82699993 5.9591185 1.0838014 5.0683605 MAarrowhead1
% End of user PostScript
1 .473 0 r
.61895 .5742 m
.63672 .57109 L
s
% Start of user PostScript
3.5684389 2.225917 4.1015048 2.1325896 MAarrowhead1
% End of user PostScript
1 .788 0 r
.84902 .59609 m
.89818 .60638 L
s
% Start of user PostScript
10.47069 2.8826739 11.945511 3.1914227 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
29.958235 7.4142291 34.157515 8.4306984 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
85.540215 20.97468 97.525703 23.908201 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
244.20334 59.833439 278.41883 68.215484 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
697.15104 170.80157 794.82905 194.73233 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
1990.2226 487.60079 2269.0732 555.91858 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
5681.6752 1391.9991 6477.736 1587.0324 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
16220.011 3973.8702 18492.6 4530.6501 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
46304.786 11344.58 52792.56 12934.071 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
132190.61 32386.435 150711.87 36924.106 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
377376.93 92456.594 430251.3 105410.71 MAarrowhead1
% End of user PostScript
.287 1 0 r
.4099 .30916 m
.39314 .33302 L
.37472 .35183 L
.35429 .36629 L
.33148 .37694 L
.30587 .38421 L
.277 .38844 L
.24436 .38987 L
.20738 .38868 L
.16541 .38496 L
.11772 .37876 L
.06348 .37004 L
.00175 .35873 L
s
.00175 .35873 m
0 .35838 L
s
1 0 0 r
.4099 .30916 m
.39314 .33302 L
s
% Start of user PostScript
-2.7030688 -5.725151 -3.2057461 -5.0095401 MAarrowhead1
% End of user PostScript
1 .158 0 r
.37472 .35183 m
.35429 .36629 L
s
% Start of user PostScript
-3.7583189 -4.4451109 -4.3711802 -4.0113888 MAarrowhead1
% End of user PostScript
1 .473 0 r
.11772 .37876 m
.06348 .37004 L
s
% Start of user PostScript
-11.468513 -3.6372935 -13.095629 -3.8988375 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-32.913829 -8.2581307 -37.53015 -9.3569293 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-94.002954 -23.07616 -107.17485 -26.295689 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-268.36862 -65.760486 -305.97007 -74.970992 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-766.13929 -187.70511 -873.48331 -214.00376 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2187.1702 -535.85291 -2493.6151 -610.93121 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6243.9199 -1529.748 -7118.757 -1744.0813 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-17825.104 -4367.1148 -20322.583 -4978.9922 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-50886.995 -12467.212 -58016.783 -14213.996 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-145271.87 -35591.318 -165625.95 -40578.026 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-414721.24 -101605.87 -472827.93 -115841.9 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1183943.6 -290063.81 -1349826.2 -330704.72 MAarrowhead1
% End of user PostScript
1 0 .731 r
.25811 .51476 m
.22604 .49464 L
.18916 .47537 L
.14687 .45647 L
.09845 .43749 L
.04307 .41798 L
s
.04307 .41798 m
0 .40405 L
s
1 0 0 r
.25811 .51476 m
.22604 .49464 L
s
% Start of user PostScript
-7.2565577 0.44274545 -8.2189114 -0.16091158 MAarrowhead1
% End of user PostScript
1 .158 0 r
.18916 .47537 m
.14687 .45647 L
s
% Start of user PostScript
-9.3251071 -0.73886296 -10.593807 -1.3057777 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-26.297006 -6.0797593 -29.9726 -7.0404027 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-74.996393 -18.288743 -85.502068 -20.876731 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-214.08136 -52.429493 -244.07586 -59.7814 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-611.15392 -149.72679 -696.78272 -170.70645 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1744.7174 -427.45117 -1989.1701 -487.34178 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4980.8081 -1220.2878 -5678.6703 -1391.2626 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-14219.18 -3483.6706 -16211.432 -3971.7685 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-40592.826 -9945.1611 -46280.296 -11338.58 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-115884.15 -28391.384 -132120.7 -32369.307 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-330825.34 -81051.545 -377177.35 -92407.696 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-944438.1 -231385.44 -1076763.5 -263804.91 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2696176. -660557.72 -3073937.8 -753108.62 MAarrowhead1
% End of user PostScript
1 .018 0 r
.50175 .44606 m
.50067 .4548 L
.49965 .46207 L
.49868 .4681 L
.49772 .47309 L
.49675 .47722 L
.49576 .48062 L
.49472 .4834 L
.4936 .48567 L
.4924 .48749 L
.49107 .48892 L
.4896 .49004 L
.48796 .49086 L
.48612 .49144 L
.48405 .49179 L
.48171 .49193 L
.47906 .49187 L
.47606 .49163 L
.47264 .49121 L
.46876 .4906 L
.46433 .48981 L
.4593 .48882 L
.45357 .48761 L
.44704 .48618 L
.4396 .4845 L
.43112 .48254 L
.42145 .48027 L
.41044 .47765 L
.39788 .47464 L
.38356 .47119 L
.36724 .46724 L
.34863 .46272 L
.32742 .45755 L
.30324 .45166 L
.27567 .44492 L
.24423 .43724 L
.20839 .42848 L
.16753 .41848 L
.12095 .40708 L
.06784 .39408 L
.00729 .37925 L
s
.00729 .37925 m
0 .37746 L
s
1 0 0 r
.50175 .44606 m
.50067 .4548 L
s
% Start of user PostScript
0.052642548 -1.6182598 0.020084444 -1.3560045 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49965 .46207 m
.49868 .4681 L
s
% Start of user PostScript
-0.010419585 -1.1380149 -0.039677773 -0.95707237 MAarrowhead1
% End of user PostScript
1 .473 0 r
.49107 .48892 m
.4896 .49004 L
s
% Start of user PostScript
-0.26792823 -0.33225415 -0.3119949 -0.29888104 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47264 .49121 m
.46876 .4906 L
s
% Start of user PostScript
-0.82080629 -0.26369781 -0.93734226 -0.2818777 MAarrowhead1
% End of user PostScript
.897 1 0 r
.42145 .48027 m
.41044 .47765 L
s
% Start of user PostScript
-2.3563645 -0.59200383 -2.6868751 -0.67054306 MAarrowhead1
% End of user PostScript
.581 1 0 r
.27567 .44492 m
.24423 .43724 L
s
% Start of user PostScript
-6.730018 -1.6522924 -7.6730469 -1.8827608 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-19.213537 -4.7080886 -21.90557 -5.367497 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-54.850856 -13.43854 -62.536027 -15.32136 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-156.58792 -38.363772 -178.52749 -43.738916 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-447.02623 -109.52054 -509.65918 -124.86549 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-1276.1677 -312.65853 -1454.9718 -356.46519 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-3643.1956 -892.57562 -4153.6445 -1017.6346 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-10400.572 -2548.1193 -11857.798 -2905.1369 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-29691.488 -7274.3551 -33851.569 -8293.5666 MAarrowhead1
% End of user PostScript
1 0 .817 r
.18443 .46879 m
.14134 .4506 L
.09203 .43214 L
.03566 .41301 L
s
.03566 .41301 m
0 .40182 L
s
1 0 0 r
.18443 .46879 m
.14134 .4506 L
s
% Start of user PostScript
-9.4671535 -0.93632512 -10.759737 -1.4821436 MAarrowhead1
% End of user PostScript
1 .158 0 r
.09203 .43214 m
.03566 .41301 L
s
% Start of user PostScript
-12.239035 -2.0357457 -13.930278 -2.6096018 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-34.737959 -8.2846616 -39.599568 -9.5131986 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-99.122286 -24.23168 -113.00903 -27.642699 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-282.96255 -69.312794 -322.60819 -79.027962 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-807.7971 -197.90575 -920.97767 -225.63524 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2306.0935 -564.98761 -2629.2008 -644.14836 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6583.4212 -1612.9249 -7505.8258 -1838.9122 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-18794.31 -4604.5682 -21427.585 -5249.7153 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-53653.878 -13145.093 -61171.335 -14986.855 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-153170.76 -37526.528 -174631.54 -42784.379 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-437270.92 -107130.5 -498537.04 -122140.58 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1248318.3 -305835.48 -1423220.4 -348686.16 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3563691.2 -873097.22 -4063000.8 -995427.07 MAarrowhead1
% End of user PostScript
1 .099 0 r
.3597 .62757 m
.344 .5969 L
.32545 .56997 L
.30376 .54598 L
.27857 .52422 L
.24946 .50409 L
.21596 .48504 L
.1775 .46657 L
.13343 .44822 L
.08301 .42956 L
.02536 .41018 L
s
.02536 .41018 m
0 .40228 L
s
1 0 0 r
.3597 .62757 m
.344 .5969 L
s
% Start of user PostScript
-4.2091 3.8271636 -4.6798953 2.9069364 MAarrowhead1
% End of user PostScript
1 .158 0 r
.32545 .56997 m
.30376 .54598 L
s
% Start of user PostScript
-5.236359 2.0990648 -5.8872296 1.3793169 MAarrowhead1
% End of user PostScript
1 .473 0 r
.02536 .41018 m
0 0 rlineto s
.02536 .41018 m
0 .40228 L
s
% Start of user PostScript
-14.239301 -2.6944984 -16.214932 -3.3100819 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-40.483691 -9.7319642 -46.151306 -11.151409 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-115.53348 -28.261689 -131.71983 -32.234565 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-329.81506 -80.79375 -376.02527 -92.116863 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-941.55182 -230.6759 -1073.4728 -262.99667 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2687.9358 -658.53831 -3064.543 -750.80644 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7673.5021 -1879.9925 -8748.6382 -2143.3987 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-21906.266 -5366.9912 -24975.558 -6118.9616 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-62537.871 -15321.653 -71300.066 -17468.373 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-178532.72 -43740.16 -203546.98 -49868.603 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-509674.1 -124869.13 -581084.66 -142364.58 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1455014.4 -356475.63 -1658876.8 -406421.51 MAarrowhead1
% End of user PostScript
0 .738 1 r
.61017 .7241 m
.63044 .69641 L
.65274 .67463 L
.6775 .65796 L
.70517 .64578 L
.73625 .63757 L
.77131 .63295 L
.81095 .63165 L
.85587 .63347 L
.90687 .63829 L
.96482 .6461 L
s
.96482 .6461 m
1 .65187 L
s
1 0 0 r
.61017 .7241 m
.63044 .69641 L
s
% Start of user PostScript
3.3052431 6.7228531 3.913105 5.8921654 MAarrowhead1
% End of user PostScript
1 .158 0 r
.65274 .67463 m
.6775 .65796 L
s
% Start of user PostScript
4.5821517 5.2387592 5.324929 4.7388216 MAarrowhead1
% End of user PostScript
1 .473 0 r
.96482 .6461 m
0 0 rlineto s
.96482 .6461 m
1 .65187 L
s
% Start of user PostScript
13.944528 4.3828724 15.921961 4.7072219 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
40.011491 10.029672 45.623065 11.3669 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
114.27216 28.049736 130.28416 31.963816 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
326.23462 79.93934 371.94373 91.135909 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
931.33517 228.17819 1061.8248 260.14741 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2658.7704 651.39413 3031.2914 742.6609 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
7590.2414 1859.5941 8653.7119 2120.1422 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
21668.574 5308.7572 24704.563 6052.5684 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
61859.309 15155.407 70526.431 17278.834 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
176595.57 43265.561 201338.41 49327.509 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
504143.93 123514.25 574779.65 140819.86 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1439226.9 352607.72 1640877.3 402011.67 MAarrowhead1
% End of user PostScript
1 0 .202 r
.56246 .50738 m
.57101 .51079 L
.5808 .51428 L
.59199 .51793 L
.60477 .52183 L
.61935 .52604 L
.63599 .53064 L
.65498 .53574 L
.67664 .54142 L
.70135 .54778 L
.72952 .55494 L
.76164 .56302 L
.79828 .57218 L
.84005 .58256 L
.88767 .59435 L
.94197 .60776 L
s
.94197 .60776 m
1 .62206 L
s
1 0 0 r
.56246 .50738 m
.57101 .51079 L
s
% Start of user PostScript
1.8737409 0.2212787 2.1304498 0.32356528 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5808 .51428 m
.59199 .51793 L
s
% Start of user PostScript
2.4240906 0.42837386 2.7596781 0.53801423 MAarrowhead1
% End of user PostScript
1 .473 0 r
.72952 .55494 m
.76164 .56302 L
s
% Start of user PostScript
6.8855573 1.648082 7.8493428 1.8906464 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
19.648693 4.8047646 22.401453 5.480697 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
56.091052 13.740053 63.94993 15.665817 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
160.12794 39.23052 182.56348 44.727269 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
457.13212 111.99634 521.18101 127.6882 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1305.0179 319.72675 1487.8643 364.52374 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
3725.557 912.75399 4247.5456 1040.6402 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
10635.697 2605.7244 12125.867 2970.8131 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
30362.721 7438.8058 34616.848 8481.0585 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
86679.305 21236.256 98823.962 24211.673 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
247451.54 60625.132 282122.03 69119.333 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
706423.11 173072.25 805400.21 197321.44 MAarrowhead1
% End of user PostScript
1 0 .779 r
.29528 .24177 m
.26151 .26797 L
.22384 .2875 L
.1816 .30115 L
.13403 .30951 L
.08029 .31305 L
.01943 .31207 L
s
.01943 .31207 m
0 .31059 L
s
1 0 0 r
.29528 .24177 m
.26151 .26797 L
s
% Start of user PostScript
-6.1414665 -7.7469408 -7.1547722 -6.9610447 MAarrowhead1
% End of user PostScript
1 .158 0 r
.22384 .2875 m
.1816 .30115 L
s
% Start of user PostScript
-8.2847342 -6.3750564 -9.5518918 -5.9656242 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-24.562711 -7.0381165 -28.029177 -7.7183615 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-70.335498 -17.471628 -80.196086 -19.847763 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-200.8436 -49.262532 -228.98522 -56.147853 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-573.37884 -140.48988 -653.71541 -160.16999 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1636.8811 -401.0357 -1866.225 -457.22397 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4672.9586 -1144.8662 -5327.6879 -1305.2735 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-13340.333 -3268.3551 -15209.45 -3726.285 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-38083.9 -9330.4793 -43419.844 -10637.775 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-108721.68 -26636.594 -123954.7 -30368.653 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-310377.97 -76041.982 -353865.1 -86696.241 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-886065.09 -217084.17 -1010211.9 -247499.89 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2529533.1 -619730.55 -2883946.6 -706561.13 MAarrowhead1
% End of user PostScript
1 0 .47 r
.58264 .58693 m
.59585 .57912 L
.61064 .57352 L
.62728 .56991 L
.64606 .5681 L
.66732 .56795 L
.69142 .56939 L
.71879 .57237 L
.74991 .57688 L
.78531 .58296 L
.8256 .59067 L
.87149 .60011 L
.92376 .61141 L
.98332 .62474 L
s
.98332 .62474 m
1 .62857 L
s
1 0 0 r
.58264 .58693 m
.59585 .57912 L
s
% Start of user PostScript
2.4792085 2.6077577 2.8755435 2.3734622 MAarrowhead1
% End of user PostScript
1 .158 0 r
.61064 .57352 m
.62728 .56991 L
s
% Start of user PostScript
3.3192959 2.2056859 3.8184535 2.0972903 MAarrowhead1
% End of user PostScript
1 .473 0 r
.8256 .59067 m
.87149 .60011 L
s
% Start of user PostScript
9.7679985 2.7200979 11.1446 3.0031957 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
27.954206 6.9254959 31.872756 7.8728141 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
79.819597 19.573668 91.00358 22.310735 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
227.87227 55.832482 259.79961 63.653915 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
650.52921 159.37935 741.67504 181.70973 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1857.1269 454.99262 2117.3294 518.74167 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
5301.7144 1298.9095 6044.5389 1480.9 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
15135.301 3708.1185 17255.912 4227.6639 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
43208.164 10585.914 49262.069 12069.108 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
123350.4 30220.6 140633.05 34454.815 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
352139.94 86273.58 401478.35 98361.391 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1005286.9 246293.28 1146137.9 280801.48 MAarrowhead1
% End of user PostScript
0 1 .76 r
.81109 .80231 m
.86021 .77689 L
.9153 .75914 L
.97734 .74826 L
s
.97734 .74826 m
1 .74678 L
s
1 0 0 r
.81109 .80231 m
.86021 .77689 L
s
% Start of user PostScript
9.3327387 9.0694434 10.80641 8.3067677 MAarrowhead1
% End of user PostScript
1 .158 0 r
.9153 .75914 m
.97734 .74826 L
s
% Start of user PostScript
12.459047 7.7741039 14.320283 7.4478703 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
36.55846 10.06542 41.707816 11.14333 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
104.59942 25.886971 119.26125 29.435961 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
298.66439 73.233303 340.51182 83.475713 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
852.63806 208.90897 972.10172 238.17495 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2434.1088 596.35516 2775.1524 679.9096 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6948.8793 1702.4623 7922.4884 1940.9945 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
19837.617 4860.1768 22617.071 5541.1372 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
56632.307 13874.802 64567.072 15818.803 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
161673.55 39609.697 184325.67 45159.421 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
461544.65 113077.52 526211.78 128920.83 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1317614.8 322812.99 1502226.1 368042.39 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3761518.5 921564.5 4288545.7 1050685.1 MAarrowhead1
% End of user PostScript
.779 0 1 r
.19896 .64044 m
.16203 .5959 L
.11905 .55577 L
.06932 .51888 L
.01203 .48424 L
s
.01203 .48424 m
0 .47815 L
s
1 0 0 r
.19896 .64044 m
.16203 .5959 L
s
% Start of user PostScript
-9.031162 4.2131156 -10.139206 2.8771031 MAarrowhead1
% End of user PostScript
1 .158 0 r
.11905 .55577 m
.06932 .51888 L
s
% Start of user PostScript
-11.42856 1.6730317 -12.920311 0.5665179 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-31.687893 -6.7131859 -36.101978 -7.9686274 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-90.242085 -21.862518 -102.87989 -24.99961 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-257.57081 -63.046427 -293.6577 -71.897235 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-735.29939 -180.13328 -838.32202 -205.37587 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2099.1252 -514.27829 -2393.2341 -586.3349 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5992.569 -1468.1667 -6832.1892 -1673.872 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-17107.548 -4191.3149 -19504.491 -4778.5611 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-48838.522 -11965.34 -55681.299 -13641.807 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-139423.91 -34158.578 -158958.62 -38944.544 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-398026.5 -97515.696 -453794.08 -111178.64 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1136283.6 -278387.2 -1295488.5 -317392.09 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3243855.2 -794738.04 -3698352.5 -906088.97 MAarrowhead1
% End of user PostScript
0 .08 1 r
.58049 .56976 m
.59299 .56453 L
.60705 .56106 L
.6229 .55917 L
.64083 .55875 L
.66115 .55971 L
.68423 .56201 L
.71045 .56564 L
.74028 .57062 L
.77424 .57699 L
.8129 .58484 L
.85694 .59427 L
.90712 .60544 L
.9643 .6185 L
s
.9643 .6185 m
1 .62682 L
s
1 0 0 r
.58049 .56976 m
.59299 .56453 L
s
% Start of user PostScript
2.4147392 2.0926609 2.7898175 1.9358763 MAarrowhead1
% End of user PostScript
1 .158 0 r
.60705 .56106 m
.6229 .55917 L
s
% Start of user PostScript
3.2113601 1.8316735 3.6868856 1.7750694 MAarrowhead1
% End of user PostScript
1 .473 0 r
.8129 .58484 m
.85694 .59427 L
s
% Start of user PostScript
9.3869555 2.5451324 10.708171 2.828181 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
26.849288 6.6356305 30.612558 7.5480802 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
76.661263 18.795383 87.402621 21.424753 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
218.85493 53.622197 249.51882 61.134263 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
624.78636 153.07215 712.32534 174.5189 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1783.6364 436.98751 2033.5421 498.21388 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
5091.914 1247.5088 5805.3432 1422.2975 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
14536.364 3561.3801 16573.057 4060.3659 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
41498.322 10167.006 47312.661 11591.507 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
118469.15 29024.704 135067.89 33091.362 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
338204.99 82859.545 385590.97 94469.015 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
965505.48 236546.91 1100782.7 269689.55 MAarrowhead1
% End of user PostScript
1 .555 0 r
.25852 .30356 m
.22133 .31719 L
.17948 .32591 L
.13223 .33017 L
.07875 .33028 L
.0181 .32644 L
s
.0181 .32644 m
0 .32442 L
s
1 0 0 r
.25852 .30356 m
.22133 .31719 L
s
% Start of user PostScript
-7.2442886 -5.8931089 -8.3601108 -5.4842134 MAarrowhead1
% End of user PostScript
1 .158 0 r
.17948 .32591 m
.13223 .33017 L
s
% Start of user PostScript
-9.6155678 -5.222559 -11.032991 -5.0948912 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-28.051815 -7.5457694 -31.998641 -8.4012169 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-80.223348 -19.812614 -91.467329 -22.541182 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-229.05427 -56.154949 -261.14802 -64.011706 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-653.91047 -160.21547 -745.53023 -182.66069 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1866.7814 -457.35974 -2128.3366 -521.43991 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5329.2762 -1305.6625 -6075.9623 -1488.599 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-15213.984 -3727.3959 -17345.619 -4249.6421 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-43432.788 -10640.946 -49518.166 -12131.852 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-123991.65 -30377.706 -141364.15 -34633.934 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-353970.59 -86722.087 -403565.49 -98872.738 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1010513. -247573.67 -1152096.2 -282261.27 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2884806.3 -706771.77 -3288997.2 -805797.72 MAarrowhead1
% End of user PostScript
0 .846 1 r
.75965 .78736 m
.8015 .76055 L
.84832 .74109 L
.90093 .72818 L
.96029 .72119 L
s
.96029 .72119 m
1 .7203 L
s
1 0 0 r
.75965 .78736 m
.8015 .76055 L
s
% Start of user PostScript
7.7894042 8.6209294 9.0451153 7.8165169 MAarrowhead1
% End of user PostScript
1 .158 0 r
.84832 .74109 m
.90093 .72818 L
s
% Start of user PostScript
10.449539 7.2327723 12.028022 6.8453836 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
30.811448 8.6459064 35.155307 9.5283775 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
88.190477 21.86411 100.55317 24.850266 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
251.81966 61.755804 287.10366 70.39029 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
718.90589 176.14471 819.63231 200.82013 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2052.331 502.82033 2339.8837 573.2696 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5858.9825 1435.4398 6679.8859 1636.5593 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
16726.187 4097.8825 19069.697 4672.0377 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
47749.814 11698.609 54440.051 13337.704 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
136315.87 33397.115 155415.12 38076.393 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
389153.69 95341.876 443678.11 108700.25 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1110953.5 272181.39 1266609.5 310316.79 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3171543.2 777021.73 3615908.8 885890.43 MAarrowhead1
% End of user PostScript
.051 0 1 r
.69128 .34818 m
.71321 .38647 L
.73903 .42026 L
.76913 .45055 L
.80401 .47821 L
.84425 .50402 L
.89052 .52866 L
.94359 .55276 L
s
.94359 .55276 m
1 .57518 L
s
1 0 0 r
.69128 .34818 m
.71321 .38647 L
s
% Start of user PostScript
5.7382575 -4.5545766 6.396323 -3.4058926 MAarrowhead1
% End of user PostScript
1 .158 0 r
.73903 .42026 m
.76913 .45055 L
s
% Start of user PostScript
7.1707652 -2.3922879 8.0738846 -1.4836468 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
19.600709 3.8279023 22.323118 4.6562869 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
55.751621 13.430281 63.557393 15.380577 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
159.11139 38.92826 181.40321 44.39861 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
454.21895 111.27012 517.85936 126.86398 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1296.6988 317.68564 1478.3794 362.19754 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3701.8069 906.93459 4220.4679 1034.0056 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
10567.895 2589.113 12048.565 2951.8742 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
30169.161 7391.384 34396.169 8426.9925 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
86126.732 21100.877 98193.968 24057.326 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
245874.06 60238.651 280323.53 68678.703 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
701919.72 171968.93 800265.85 196063.53 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2003836. 490935.82 2284593.9 559720.94 MAarrowhead1
% End of user PostScript
1 .602 0 r
.59241 .42197 m
.6029 .44122 L
.61526 .45816 L
.62969 .47331 L
.64643 .48709 L
.66575 .49991 L
.68798 .5121 L
.71349 .52397 L
.7427 .53582 L
.77613 .54793 L
.81434 .56056 L
.85798 .57397 L
.90779 .58846 L
.96465 .60428 L
s
.96465 .60428 m
1 .61381 L
s
1 0 0 r
.59241 .42197 m
.6029 .44122 L
s
% Start of user PostScript
2.7723966 -2.3408218 3.086901 -1.7634399 MAarrowhead1
% End of user PostScript
1 .158 0 r
.61526 .45816 m
.62969 .47331 L
s
% Start of user PostScript
3.4577197 -1.2551501 3.8907137 -0.8007843 MAarrowhead1
% End of user PostScript
1 .473 0 r
.81434 .56056 m
.85798 .57397 L
s
% Start of user PostScript
9.4300868 1.8167253 10.739254 2.2192472 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
26.817406 6.4543047 30.571962 7.3933653 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
76.533851 18.723425 87.25636 21.354927 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
218.48265 53.521422 249.09415 61.022236 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
623.72156 152.80903 711.1113 174.21959 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1780.5961 436.24213 2030.0758 497.36422 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
5083.2346 1245.3822 5795.4477 1419.873 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
14511.586 3555.3096 16544.808 4053.4448 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
41427.586 10149.676 47232.014 11571.749 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
118267.21 28975.231 134837.66 33034.957 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
337628.5 82718.307 384933.71 94307.988 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
963859.74 236143.71 1098906.3 269229.85 MAarrowhead1
% End of user PostScript
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0333333 0.5 0.0333333 [
[0 .4875 -18.4688 -20 ]
[0 .4875 18.4688 0 ]
[.16667 .4875 -18.4688 -20 ]
[.16667 .4875 18.4688 0 ]
[.33333 .4875 -13.4688 -20 ]
[.33333 .4875 13.4688 0 ]
[.66667 .4875 -7 -20 ]
[.66667 .4875 7 0 ]
[.83333 .4875 -12 -20 ]
[.83333 .4875 12 0 ]
[1 .4875 -12 -20 ]
[1 .4875 12 0 ]
[.4875 0 -36.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .16667 -36.9375 -10 ]
[.4875 .16667 0 10 ]
[.4875 .33333 -26.9375 -10 ]
[.4875 .33333 0 10 ]
[.4875 .66667 -14 -10 ]
[.4875 .66667 0 10 ]
[.4875 .83333 -24 -10 ]
[.4875 .83333 0 10 ]
[.4875 1 -24 -10 ]
[.4875 1 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.16667 .5 m
.16667 .50625 L
s
gsave
.16667 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.33333 .5 m
.33333 .50625 L
s
gsave
.33333 .4875 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.66667 .5 m
.66667 .50625 L
s
gsave
.66667 .4875 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.83333 .5 m
.83333 .50625 L
s
gsave
.83333 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.5 .16667 m
.50625 .16667 L
s
gsave
.4875 .16667 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 .33333 m
.50625 .33333 L
s
gsave
.4875 .33333 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .66667 m
.50625 .66667 L
s
gsave
.4875 .66667 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .83333 m
.50625 .83333 L
s
gsave
.4875 .83333 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.01 w
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .581 0 r
.5 Mabswid
.25688 .76016 m
.23064 .70077 L
.19943 .64893 L
.16277 .60307 L
.12006 .56185 L
.07062 .52407 L
.01363 .48869 L
s
.01363 .48869 m
0 .48163 L
s
1 .049 0 r
.3513 .42264 m
.32946 .42407 L
.30473 .42367 L
.27667 .42151 L
.2448 .41764 L
.20855 .41205 L
.16732 .40469 L
.12036 .39547 L
.06689 .38428 L
.00597 .37095 L
s
.00597 .37095 m
0 .3696 L
s
1 0 .147 r
.6706 .82162 m
.70136 .7828 L
.73529 .75243 L
.77302 .72941 L
.81525 .71283 L
.86274 .702 L
.91634 .69639 L
.97698 .69561 L
s
.97698 .69561 m
1 .69688 L
s
0 .48 1 r
.67206 .34873 m
.69144 .38552 L
.71431 .41786 L
.74104 .44671 L
.77206 .47293 L
.80788 .49723 L
.84911 .52028 L
.89642 .54269 L
.95063 .56499 L
s
.95063 .56499 m
1 .58307 L
s
1 .633 0 r
.61033 .65402 m
.6289 .63753 L
.64956 .62504 L
.67267 .61606 L
.69867 .61021 L
.72802 .6072 L
.76122 .60683 L
.79887 .60896 L
.84162 .61351 L
.89021 .62048 L
.94549 .6299 L
s
.94549 .6299 m
1 .64028 L
s
0 .479 1 r
.17092 .80887 m
.13435 .73539 L
.09108 .67095 L
.04042 .61362 L
s
.04042 .61362 m
0 .57798 L
s
.899 1 0 r
.77756 .77008 m
.8214 .74734 L
.87055 .73146 L
.92592 .72171 L
.98846 .7176 L
s
.98846 .7176 m
1 .71778 L
s
.436 1 0 r
.68878 .72015 m
.71949 .69887 L
.7538 .68323 L
.79232 .67262 L
.83575 .66652 L
.88485 .66459 L
.9405 .66658 L
s
.9405 .66658 m
1 .672 L
s
1 .635 0 r
.21047 .28063 m
.16626 .29439 L
.11647 .30271 L
.06021 .30604 L
s
.06021 .30604 m
0 .30479 L
s
1 0 .455 r
.4646 .75243 m
.46604 .70952 L
.46661 .67357 L
.46638 .64341 L
.46538 .61804 L
.46363 .59665 L
.46112 .57855 L
.45783 .56315 L
.45372 .54997 L
.44873 .53859 L
.4428 .52866 L
.43583 .51989 L
.42772 .512 L
.41832 .50477 L
.40748 .49801 L
.39502 .49153 L
.38073 .48518 L
.36438 .47878 L
.34567 .47221 L
.32429 .46531 L
.29987 .45795 L
.27201 .44996 L
.2402 .44121 L
.20392 .43151 L
.16254 .4207 L
.11534 .40858 L
.06151 .39492 L
.00013 .3795 L
s
.00013 .3795 m
0 .37946 L
s
0 .906 1 r
.57307 .69846 m
.58773 .67214 L
.60371 .6511 L
.62132 .63459 L
.64088 .62201 L
.66276 .61288 L
.68736 .60681 L
.7151 .60351 L
.74648 .60278 L
.78205 .60447 L
.82244 .60851 L
.86833 .61486 L
.92054 .62358 L
.97997 .63473 L
s
.97997 .63473 m
1 .6388 L
s
0 .211 1 r
.28445 .63919 m
.25894 .60113 L
.22909 .56728 L
.19441 .53664 L
.15432 .50835 L
.10816 .48162 L
.05516 .45578 L
s
.05516 .45578 m
0 .43252 L
s
1 0 .388 r
.58039 .22813 m
.58452 .27744 L
.59041 .31919 L
.59811 .3547 L
.6077 .3851 L
.61934 .41136 L
.63317 .43428 L
.64942 .45455 L
.66835 .47278 L
.69026 .48949 L
.71552 .50514 L
.74455 .52015 L
.77784 .5349 L
.81595 .54973 L
.85954 .56499 L
.90936 .58102 L
.96624 .59815 L
s
.96624 .59815 m
1 .60781 L
s
.908 1 0 r
.48744 .75942 m
.4921 .71708 L
.49636 .68184 L
.50032 .65254 L
.5041 .6282 L
.50778 .60803 L
.51147 .59136 L
.51525 .57761 L
.51919 .56634 L
.52339 .55716 L
.52793 .54975 L
.53289 .54386 L
.53838 .53927 L
.54449 .53582 L
.55133 .53337 L
.55903 .53181 L
.56772 .53107 L
.57757 .53108 L
.58873 .53181 L
.60141 .53325 L
.61582 .53539 L
.63222 .53825 L
.65089 .54185 L
.67216 .54625 L
.69638 .55151 L
.72397 .55771 L
.75542 .56494 L
.79127 .57333 L
.83213 .58302 L
.8787 .59416 L
.9318 .60694 L
.99232 .62157 L
s
.99232 .62157 m
1 .62344 L
s
.477 0 1 r
.77306 .66573 m
.81374 .65932 L
.85972 .65693 L
.9118 .65829 L
.97091 .66326 L
s
.97091 .66326 m
1 .66695 L
s
.323 1 0 r
.33219 .62681 m
.31279 .59424 L
.28999 .56544 L
.26343 .53957 L
.23267 .51588 L
.19721 .49371 L
.15645 .47247 L
.1097 .45164 L
.05617 .43069 L
s
.05617 .43069 m
0 .41094 L
s
0 .269 1 r
.33389 .28273 m
.3063 .30522 L
.27555 .32209 L
.24109 .33402 L
.20231 .3415 L
.1585 .34495 L
.10891 .34462 L
.05265 .34071 L
s
.05265 .34071 m
0 .33459 L
s
0 1 .458 r
.68453 .74461 m
.71526 .71911 L
.74949 .69993 L
.78785 .68633 L
.83101 .67772 L
.87976 .67366 L
.93494 .67382 L
.99753 .67801 L
s
.99753 .67801 m
1 .67829 L
s
.376 0 1 r
.26624 .34388 m
.23107 .35164 L
.19137 .35558 L
.14644 .35597 L
.0955 .353 L
.03765 .34676 L
s
.03765 .34676 m
0 .34133 L
s
0 1 .143 r
.60915 .19894 m
.61642 .25503 L
.62604 .30269 L
.63811 .34346 L
.6528 .37859 L
.67032 .4092 L
.69094 .43621 L
.71499 .46042 L
.74285 .48253 L
.77499 .50315 L
.81195 .52285 L
.85434 .54211 L
.90289 .56141 L
.95843 .5812 L
s
.95843 .5812 m
1 .59476 L
s
.02 0 1 r
.52927 .5845 m
.53527 .57316 L
.54179 .56407 L
.54896 .55691 L
.55692 .55142 L
.56581 .54739 L
.5758 .54465 L
.58706 .54309 L
.59979 .5426 L
.61421 .54313 L
.63059 .54463 L
.64919 .5471 L
.67035 .55053 L
.69444 .55498 L
.72186 .56048 L
.7531 .56712 L
.78868 .57499 L
.82923 .58422 L
.87545 .59495 L
.92813 .60737 L
.98817 .62167 L
s
.98817 .62167 m
1 .62451 L
s
0 .573 1 r
.65318 .72009 m
.67911 .6962 L
.70793 .67803 L
.74018 .66487 L
.77642 .65619 L
.81732 .65155 L
.86358 .65066 L
.91603 .65331 L
.97558 .65938 L
s
.97558 .65938 m
1 .6628 L
s
0 1 .552 r
.17399 .363 m
.12691 .36093 L
.07347 .35573 L
.01274 .34744 L
s
.01274 .34744 m
0 .34533 L
s
.332 0 1 r
.36966 .2869 m
.34696 .31135 L
.32182 .33024 L
.29376 .34426 L
.26229 .35398 L
.22684 .35983 L
.18677 .36215 L
.14139 .36116 L
.08989 .35699 L
.03139 .3497 L
s
.03139 .3497 m
0 .34478 L
s
1 .053 0 r
.35933 .60427 m
.34302 .57729 L
.32386 .55342 L
.30155 .53195 L
.27571 .51228 L
.24594 .49384 L
.21171 .47617 L
.17247 .4588 L
.12753 .44132 L
.07614 .42333 L
.01742 .40444 L
s
.01742 .40444 m
0 .3992 L
s
0 .528 1 r
.67809 .70072 m
.70689 .68175 L
.73909 .66793 L
.77526 .65867 L
.81606 .65356 L
.86221 .65225 L
.91452 .65454 L
.97389 .66031 L
s
.97389 .66031 m
1 .66387 L
s
.752 1 0 r
.39416 .45033 m
.37875 .45049 L
.36128 .44949 L
.34144 .44736 L
.31889 .44412 L
.29323 .43974 L
.26402 .43418 L
.23076 .42736 L
.19288 .41918 L
.14971 .40953 L
.10052 .39825 L
.04445 .38515 L
s
.04445 .38515 m
0 .37464 L
s
.044 0 1 r
.519 .28446 m
.51627 .32027 L
.51405 .35017 L
.51227 .37512 L
.51085 .39596 L
.50976 .41337 L
.50895 .42792 L
.50839 .44009 L
.50805 .45027 L
.50791 .4588 L
.50796 .46596 L
.50819 .47198 L
.50861 .47706 L
.5092 .48135 L
.50997 .485 L
.51095 .48813 L
.51212 .49083 L
.51352 .49318 L
.51517 .49527 L
.51709 .49714 L
.51931 .49885 L
.52187 .50045 L
.52482 .50199 L
.5282 .50349 L
.53206 .505 L
.53648 .50656 L
.54154 .50819 L
.54731 .50994 L
.5539 .51182 L
.56141 .51389 L
.56999 .51619 L
.57977 .51874 L
.59093 .52161 L
.60366 .52484 L
.61817 .52848 L
.63471 .53262 L
.65358 .5373 L
.67508 .54262 L
.69961 .54868 L
.72757 .55557 L
.75945 .56341 L
.7958 .57234 L
.83724 .58251 L
.88449 .59411 L
.93836 .60732 L
.99977 .62238 L
s
.99977 .62238 m
1 .62244 L
s
1 .002 0 r
.76568 .22782 m
.79465 .29079 L
.82904 .34584 L
.8694 .39462 L
.91636 .43858 L
.97069 .47896 L
s
.97069 .47896 m
1 .49672 L
s
0 1 .024 r
.75796 .28766 m
.78736 .34051 L
.82199 .38708 L
.86241 .42876 L
.90927 .46675 L
.96335 .50212 L
s
.96335 .50212 m
1 .52198 L
s
.007 1 0 r
.4297 .40729 m
.418 .41693 L
.40497 .42417 L
.39037 .4293 L
.37394 .43253 L
.35538 .43405 L
.33437 .43396 L
.31054 .43234 L
.28347 .42923 L
.2527 .42462 L
.21769 .41849 L
.17783 .41077 L
.13244 .40136 L
.08073 .39011 L
.02181 .37687 L
s
.02181 .37687 m
0 .37184 L
s
0 1 .225 r
.21069 .68782 m
.17649 .63658 L
.13644 .59101 L
.08992 .54978 L
.03614 .51171 L
s
.03614 .51171 m
0 .49074 L
s
.976 0 1 r
.47805 .61183 m
.47785 .59236 L
.47714 .57599 L
.47593 .56218 L
.47422 .55048 L
.472 .54053 L
.46924 .532 L
.4659 .52463 L
.46193 .51819 L
.45727 .51249 L
.45184 .50736 L
.44556 .50265 L
.43833 .49823 L
.43001 .49398 L
.42048 .4898 L
.40956 .48559 L
.39708 .48125 L
.38282 .47668 L
.36653 .4718 L
.34794 .4665 L
.32673 .46068 L
.30253 .45423 L
.27493 .44704 L
.24344 .43896 L
.20754 .42987 L
.1666 .41958 L
.11992 .40794 L
.06669 .39472 L
.00601 .37971 L
s
.00601 .37971 m
0 .37823 L
s
.453 1 0 r
.54981 .40014 m
.55405 .41974 L
.55933 .43653 L
.56574 .45102 L
.57335 .46367 L
.5823 .47486 L
.59272 .48492 L
.60479 .49414 L
.6187 .50277 L
.63469 .51104 L
.65302 .51917 L
.67401 .52735 L
.69802 .53576 L
.72545 .5446 L
.75678 .55404 L
.79254 .56427 L
.83335 .57549 L
.8799 .58792 L
.933 .60178 L
.99357 .61733 L
s
.99357 .61733 m
1 .61897 L
s
.617 1 0 r
.35201 .40794 m
.32991 .41177 L
.30494 .41337 L
.27666 .41287 L
.24457 .41038 L
.20812 .40593 L
.16667 .39951 L
.11951 .39108 L
.06582 .38052 L
.00466 .36771 L
s
.00466 .36771 m
0 .36669 L
s
0 .112 1 r
.4751 .58049 m
.47373 .56581 L
.47182 .55337 L
.46935 .54278 L
.46629 .5337 L
.46259 .52584 L
.45821 .51897 L
.45307 .51287 L
.44709 .50737 L
.44017 .5023 L
.4322 .49754 L
.42305 .49296 L
.41256 .48843 L
.40055 .48385 L
.38681 .47913 L
.37112 .47415 L
.35321 .46881 L
.33275 .46301 L
.30942 .45663 L
.2828 .44956 L
.25243 .44166 L
.2178 .43279 L
.17831 .4228 L
.13328 .4115 L
.08193 .3987 L
.02339 .38417 L
s
.02339 .38417 m
0 .37838 L
s
.119 0 1 r
.2015 .67939 m
.16585 .62882 L
.1242 .58371 L
.07584 .54275 L
.02001 .50477 L
s
.02001 .50477 m
0 .49355 L
s
.633 1 0 r
.67424 .41708 m
.69558 .44311 L
.72041 .46656 L
.74915 .48809 L
.78228 .50829 L
.82034 .5277 L
.86398 .5468 L
.91393 .56606 L
.97107 .58592 L
s
.97107 .58592 m
1 .59517 L
s
1 0 .101 r
.53818 .61082 m
.54602 .59593 L
.55454 .58399 L
.56391 .57459 L
.57431 .56737 L
.58592 .56207 L
.59896 .55847 L
.61367 .5564 L
.63029 .55575 L
.64913 .55642 L
.67051 .55836 L
.69481 .56157 L
.72244 .56604 L
.75389 .57184 L
.7897 .57901 L
.83049 .58767 L
.87696 .59795 L
.92991 .60999 L
.99026 .62401 L
s
.99026 .62401 m
1 .6263 L
s
1 .465 0 r
.40563 .16987 m
.38489 .21565 L
.36249 .2526 L
.338 .282 L
.31093 .30491 L
.2808 .32217 L
.24705 .33447 L
.20907 .34232 L
.16619 .34613 L
.11766 .34618 L
.06262 .34266 L
.00011 .33566 L
s
.00011 .33566 m
0 .33564 L
s
1 .289 0 r
.49735 .34613 m
.49323 .37051 L
.48915 .39069 L
.48502 .40734 L
.48074 .42104 L
.47623 .43223 L
.47138 .44131 L
.4661 .44858 L
.4603 .4543 L
.45386 .45868 L
.44666 .46189 L
.43857 .46406 L
.42945 .46528 L
.41914 .46564 L
.40745 .46519 L
.39419 .46395 L
.37912 .46194 L
.36197 .45914 L
.34246 .45552 L
.32025 .45105 L
.29494 .44567 L
.26611 .43928 L
.23325 .4318 L
.19581 .4231 L
.15313 .41303 L
.10448 .40144 L
.04903 .38813 L
s
.04903 .38813 m
0 .3763 L
s
1 .968 0 r
.28606 .56682 m
.25901 .54044 L
.22768 .51628 L
.19155 .49368 L
.15003 .47204 L
.10241 .4508 L
.04788 .42945 L
s
.04788 .42945 m
0 .4126 L
s
.176 0 1 r
.21502 .37121 m
.17365 .37085 L
.12672 .3675 L
.07341 .36124 L
.0128 .35206 L
s
.0128 .35206 m
0 .34981 L
s
0 1 .189 r
.50579 .54566 m
.50769 .53879 L
.50967 .53316 L
.51177 .52858 L
.51405 .52488 L
.51655 .52194 L
.5193 .51965 L
.52237 .51793 L
.52581 .51671 L
.52968 .51594 L
.53405 .51557 L
.539 .51559 L
.54461 .51596 L
.55099 .51669 L
.55823 .51777 L
.56648 .51921 L
.57587 .52103 L
.58656 .52324 L
.59873 .52589 L
.61261 .52901 L
.62842 .53264 L
.64644 .53686 L
.66698 .54173 L
.6904 .54733 L
.71709 .55376 L
.74752 .56112 L
.78222 .56954 L
.82177 .57917 L
.86686 .59016 L
.91827 .60271 L
.97688 .61703 L
s
.97688 .61703 m
1 .62268 L
s
0 1 .033 r
.70729 .62944 m
.73826 .624 L
.77325 .6217 L
.81288 .62234 L
.85783 .62578 L
.9089 .63198 L
.96697 .64094 L
s
.96697 .64094 m
1 .64683 L
s
1 .045 0 r
.75862 .34701 m
.78956 .39043 L
.82571 .4292 L
.86766 .46442 L
.9161 .49711 L
.97183 .52813 L
s
.97183 .52813 m
1 .54141 L
s
.696 0 1 r
.68282 .43812 m
.70582 .46143 L
.73248 .4827 L
.76323 .50254 L
.7986 .52147 L
.83917 .53997 L
.88564 .5585 L
.93879 .57748 L
.99953 .59734 L
s
.99953 .59734 m
1 .59748 L
s
1 0 .287 r
.3658 .66992 m
.35197 .63294 L
.33537 .60084 L
.31576 .57264 L
.29282 .54751 L
.2662 .52471 L
.23545 .50359 L
.20006 .48359 L
.15943 .46418 L
.11288 .44489 L
.05962 .42526 L
s
.05962 .42526 m
0 .40527 L
s
1 0 .051 r
.50336 .76476 m
.51029 .72274 L
.51712 .68793 L
.52402 .65918 L
.53114 .63553 L
.53863 .61617 L
.54665 .60046 L
.55537 .58785 L
.56495 .57789 L
.57556 .57022 L
.58742 .56456 L
.60072 .56067 L
.61571 .55838 L
.63266 .55756 L
.65186 .55811 L
.67365 .55999 L
.69841 .56316 L
.72656 .56765 L
.75861 .57349 L
.79509 .58075 L
.83664 .58953 L
.88398 .59996 L
.93792 .6122 L
.9994 .62645 L
s
.9994 .62645 m
1 .62659 L
s
.552 0 1 r
.56473 .58612 m
.57551 .57713 L
.58753 .57036 L
.60099 .56555 L
.61614 .5625 L
.63325 .56105 L
.65261 .56109 L
.67457 .56254 L
.69952 .56538 L
.72788 .56959 L
.76014 .57522 L
.79687 .58231 L
.8387 .59098 L
.88635 .60133 L
.94065 .61352 L
s
.94065 .61352 m
1 .62718 L
s
1 .746 0 r
.7925 .56864 m
.83341 .57917 L
.88006 .59101 L
.93326 .6044 L
.99392 .61955 L
s
.99392 .61955 m
1 .62106 L
s
.18 0 1 r
.71376 .56362 m
.74399 .56916 L
.77841 .57604 L
.8176 .58435 L
.86226 .59421 L
.91315 .60577 L
.97115 .61923 L
s
.97115 .61923 m
1 .62602 L
s
.974 0 1 r
.551 .19175 m
.55029 .24471 L
.55079 .28917 L
.55244 .32656 L
.55522 .35811 L
.55916 .38482 L
.56427 .40755 L
.57063 .42704 L
.57831 .44387 L
.58744 .45859 L
.59815 .47162 L
.61062 .48336 L
.62505 .49414 L
.64168 .50426 L
.66078 .51399 L
.68269 .52356 L
.70776 .53322 L
.73644 .54317 L
.76921 .55365 L
.80663 .56485 L
.84934 .57702 L
.89807 .59038 L
.95367 .60518 L
s
.95367 .60518 m
1 .61726 L
s
1 0 .477 r
.3864 .81217 m
.3788 .75398 L
.36877 .70452 L
.35617 .66223 L
.34086 .62576 L
.32259 .59399 L
.3011 .56596 L
.27604 .54082 L
.24701 .51785 L
.21351 .49642 L
.175 .47595 L
.13083 .45592 L
.08024 .43584 L
.02237 .41526 L
s
.02237 .41526 m
0 .40797 L
s
1 0 .611 r
.65894 .42489 m
.67842 .44856 L
.70109 .46988 L
.72732 .48946 L
.75755 .50784 L
.79228 .5255 L
.8321 .5429 L
.87769 .56044 L
.92982 .57853 L
.98939 .59756 L
s
.98939 .59756 m
1 .60073 L
s
.336 1 0 r
.4195 .63469 m
.412 .60727 L
.40282 .58368 L
.39184 .56318 L
.37888 .54515 L
.36374 .52904 L
.34618 .5144 L
.3259 .5008 L
.30257 .48789 L
.2758 .47532 L
.24513 .4628 L
.21003 .45002 L
.16992 .4367 L
.12411 .42256 L
.0718 .40732 L
.0121 .39067 L
s
.0121 .39067 m
0 .3874 L
s
1 0 .857 r
.80886 .64201 m
.85376 .64202 L
.90468 .64532 L
.96251 .65184 L
s
.96251 .65184 m
1 .65739 L
s
1 0 .181 r
.44051 .48958 m
.43228 .48687 L
.42288 .484 L
.41214 .48089 L
.39989 .47749 L
.38592 .47373 L
.36997 .46954 L
.35179 .46486 L
.33105 .45958 L
.3074 .45363 L
.28044 .44689 L
.24969 .43924 L
.21463 .43056 L
.17466 .42069 L
.12909 .40946 L
.07713 .39667 L
.01789 .38211 L
s
.01789 .38211 m
0 .37772 L
s
.517 0 1 r
.65387 .49331 m
.67434 .50568 L
.69786 .51758 L
.72483 .5293 L
.7557 .54114 L
.791 .55335 L
.83133 .5662 L
.87739 .57997 L
.92996 .59492 L
.98995 .61134 L
s
.98995 .61134 m
1 .61402 L
s
0 1 .577 r
.36559 .74953 m
.35367 .69982 L
.33894 .65717 L
.32119 .62024 L
.30015 .58791 L
.2755 .55919 L
.24684 .53325 L
.2137 .50935 L
.17554 .48683 L
.1317 .4651 L
.08145 .44363 L
.02394 .42189 L
s
.02394 .42189 m
0 .4137 L
s
0 1 .17 r
.45581 .63721 m
.45324 .61206 L
.44972 .59073 L
.4452 .57255 L
.43962 .55694 L
.43292 .54342 L
.42498 .53156 L
.4157 .52101 L
.4049 .51146 L
.39243 .50265 L
.37807 .49432 L
.36158 .48628 L
.34268 .4783 L
.32105 .47021 L
.29632 .46182 L
.26807 .45296 L
.23581 .44344 L
.199 .43306 L
.15699 .42165 L
.10907 .40896 L
.05441 .39479 L
s
.05441 .39479 m
0 .38088 L
s
1 0 .398 r
.3157 .81083 m
.2986 .74767 L
.27765 .69333 L
.25256 .64613 L
.22296 .60462 L
.18837 .56757 L
.14823 .53389 L
.10188 .50265 L
.04855 .47298 L
s
.04855 .47298 m
0 .4501 L
s
.276 0 1 r
.59183 .45644 m
.60308 .47014 L
.61618 .48248 L
.63133 .49381 L
.64879 .50444 L
.66885 .51466 L
.69185 .52472 L
.71819 .53486 L
.74831 .54532 L
.78272 .55632 L
.82201 .56809 L
.86686 .58087 L
.91804 .5949 L
.97643 .61045 L
s
.97643 .61045 m
1 .6166 L
s
.276 1 0 r
.50597 .41521 m
.50469 .42919 L
.50359 .44084 L
.50262 .45055 L
.50176 .45864 L
.50098 .46537 L
.50027 .47097 L
.49959 .47563 L
.49894 .47949 L
.49829 .48268 L
.49764 .48532 L
.49697 .48749 L
.49625 .48927 L
.49549 .49071 L
.49466 .49186 L
.49374 .49277 L
.49272 .49346 L
.49159 .49397 L
.49031 .49432 L
.48887 .49451 L
.48725 .49457 L
.4854 .4945 L
.48331 .49431 L
.48093 .49399 L
.47823 .49355 L
.47515 .49298 L
.47164 .49228 L
.46765 .49143 L
.4631 .49042 L
.45792 .48924 L
.45201 .48787 L
.44528 .48628 L
.43761 .48445 L
.42886 .48235 L
.41889 .47994 L
.40752 .47719 L
.39456 .47404 L
.37978 .47044 L
.36293 .46633 L
.34372 .46164 L
.32183 .45629 L
.29686 .45018 L
.2684 .44322 L
.23595 .43527 L
.19895 .42621 L
.15677 .41588 L
.10868 .40411 L
.05385 .39068 L
s
.05385 .39068 m
0 .37749 L
s
.256 1 0 r
.27461 .39981 m
.24193 .39926 L
.20485 .39639 L
.16273 .39126 L
.11484 .38385 L
.06034 .37411 L
s
.06034 .37411 m
0 .36225 L
s
1 0 .923 r
.19977 .65586 m
.16332 .60892 L
.12083 .5668 L
.07162 .52829 L
.01486 .49231 L
s
.01486 .49231 m
0 .48447 L
s
1 .52 0 r
.31658 .38378 m
.28914 .38887 L
.25814 .39112 L
.22304 .39075 L
.18322 .38785 L
.13799 .38249 L
.08656 .37466 L
.02804 .36431 L
s
.02804 .36431 m
0 .35884 L
s
0 .476 1 r
.18768 .68822 m
.15041 .63523 L
.10683 .58796 L
.05626 .54504 L
s
.05626 .54504 m
0 .50672 L
s
0 .084 1 r
.67835 .68464 m
.70679 .66825 L
.73864 .65658 L
.77447 .6491 L
.81494 .64545 L
.86073 .64536 L
.91267 .64864 L
.97165 .65522 L
s
.97165 .65522 m
1 .65939 L
s
.506 0 1 r
.75841 .42662 m
.79127 .45731 L
.82929 .48552 L
.87309 .51202 L
.92342 .5375 L
.98113 .56261 L
s
.98113 .56261 m
1 .56985 L
s
0 1 .05 r
.63527 .31057 m
.64878 .35075 L
.66508 .38551 L
.68441 .41591 L
.70709 .44288 L
.73346 .46721 L
.76397 .48959 L
.79911 .51064 L
.83949 .53091 L
.88578 .55091 L
.93876 .57112 L
.99934 .59199 L
s
.99934 .59199 m
1 .59219 L
s
.467 0 1 r
.78345 .22797 m
.8148 .29222 L
.85193 .34852 L
.89542 .39855 L
.94597 .44379 L
s
.94597 .44379 m
1 .48238 L
s
1 0 .975 r
.30269 .65256 m
.27996 .6137 L
.25323 .57939 L
.22208 .54859 L
.186 .52042 L
.14439 .4941 L
.09655 .46892 L
.04169 .44425 L
s
.04169 .44425 m
0 .42782 L
s
1 .971 0 r
.35693 .43771 m
.33622 .43715 L
.31271 .43515 L
.28601 .43175 L
.25564 .42693 L
.22107 .42065 L
.18172 .41284 L
.13691 .40338 L
.08584 .39214 L
.02766 .37894 L
s
.02766 .37894 m
0 .37253 L
s
.643 0 1 r
.51611 .77671 m
.52504 .73371 L
.53413 .69824 L
.54356 .66909 L
.55354 .64529 L
.56427 .62602 L
.57598 .61062 L
.58888 .59854 L
.60321 .58933 L
.61924 .58265 L
.63725 .57821 L
.65757 .5758 L
.68056 .57527 L
.70662 .57651 L
.7362 .57947 L
.76982 .58413 L
.80807 .59052 L
.8516 .59869 L
.90117 .60876 L
.95764 .62085 L
s
.95764 .62085 m
1 .63028 L
s
0 .517 1 r
.52714 .40731 m
.52851 .4241 L
.53047 .43832 L
.53305 .4504 L
.53626 .46075 L
.54017 .46968 L
.54481 .47747 L
.55027 .48436 L
.55663 .49055 L
.56399 .49622 L
.57248 .50152 L
.58224 .5066 L
.59343 .51159 L
.60624 .5166 L
.6209 .52175 L
.63764 .52716 L
.65677 .53293 L
.6786 .53919 L
.70351 .54605 L
.73193 .55364 L
.76435 .56211 L
.80132 .57161 L
.84349 .58231 L
.89157 .59439 L
.94639 .60808 L
s
.94639 .60808 m
1 .6214 L
s
1 .168 0 r
.20864 .8173 m
.17733 .74524 L
.14006 .68238 L
.09626 .62682 L
.04521 .57692 L
s
.04521 .57692 m
0 .54198 L
s
1 .296 0 r
.82125 .19904 m
.85696 .27069 L
.89922 .33352 L
.94869 .38942 L
s
.94869 .38942 m
1 .43461 L
s
1 0 .872 r
.52843 .46752 m
.53145 .4748 L
.53505 .48113 L
.53929 .48672 L
.54423 .49172 L
.54996 .49629 L
.55657 .50056 L
.56417 .50462 L
.57289 .5086 L
.58288 .51258 L
.5943 .51666 L
.60736 .52092 L
.62227 .52547 L
.63929 .53038 L
.65871 .53576 L
.68087 .54171 L
.70615 .54833 L
.73498 .55575 L
.76786 .56411 L
.80535 .57355 L
.8481 .58423 L
.89685 .59635 L
.95243 .61011 L
s
.95243 .61011 m
1 .62186 L
s
1 .914 0 r
.73739 .57173 m
.77099 .57771 L
.80923 .58521 L
.85279 .59431 L
.90241 .60516 L
.95895 .61793 L
s
.95895 .61793 m
1 .62741 L
s
0 .973 1 r
.79026 .45926 m
.82819 .48709 L
.87189 .51325 L
.92209 .53845 L
.97964 .56331 L
s
.97964 .56331 m
1 .57108 L
s
1 0 .218 r
.19171 .63468 m
.15366 .59054 L
.10942 .55064 L
.05828 .51387 L
s
.05828 .51387 m
0 .47958 L
s
1 0 .241 r
.50075 .50865 m
.50106 .50733 L
.50138 .50624 L
.50172 .50534 L
.50208 .50461 L
.50247 .50403 L
.5029 .50357 L
.50338 .50321 L
.50391 .50295 L
.50451 .50276 L
.50518 .50265 L
.50594 .50261 L
.5068 .50263 L
.50778 .50271 L
.50889 .50285 L
.51015 .50305 L
.51158 .5033 L
.51322 .50363 L
.51508 .50402 L
.5172 .50449 L
.51962 .50503 L
.52237 .50567 L
.52551 .50641 L
.52909 .50726 L
.53317 .50824 L
.53782 .50936 L
.54312 .51064 L
.54916 .51211 L
.55605 .51379 L
.5639 .5157 L
.57286 .51789 L
.58307 .52038 L
.59471 .52323 L
.60798 .52648 L
.62311 .53018 L
.64035 .5344 L
.66002 .53922 L
.68244 .54471 L
.708 .55097 L
.73715 .55811 L
.77037 .56625 L
.80825 .57553 L
.85144 .58611 L
.90068 .59817 L
.95682 .61192 L
s
.95682 .61192 m
1 .6225 L
s
1 0 .853 r
.40681 .37641 m
.39129 .3893 L
.374 .39899 L
.35463 .40586 L
.33283 .41022 L
.30821 .41227 L
.28034 .4122 L
.24873 .41008 L
.21283 .40599 L
.17202 .39991 L
.12558 .3918 L
.07272 .38158 L
.01252 .3691 L
s
.01252 .3691 m
0 .36638 L
s
1 0 .426 r
.38009 .29082 m
.35889 .31542 L
.33544 .33452 L
.30932 .34886 L
.28005 .35899 L
.2471 .36535 L
.20989 .36827 L
.16775 .368 L
.11996 .36467 L
.06568 .35837 L
.00397 .34908 L
s
.00397 .34908 m
0 .34839 L
s
1 0 .525 r
.33687 .80294 m
.32241 .74259 L
.30454 .69081 L
.28299 .64599 L
.25746 .60674 L
.22755 .57188 L
.19277 .54039 L
.15256 .51138 L
.10624 .48404 L
.05304 .45767 L
s
.05304 .45767 m
0 .435 L
s
0 1 .244 r
.52586 .20725 m
.52216 .2559 L
.51916 .2965 L
.51675 .3304 L
.51484 .35871 L
.51337 .38236 L
.51229 .40213 L
.51154 .41866 L
.5111 .43249 L
.51093 .44409 L
.51103 .45382 L
.51138 .462 L
.51197 .4689 L
.51282 .47475 L
.51392 .47972 L
.51529 .48398 L
.51695 .48766 L
.51892 .49088 L
.52123 .49372 L
.52393 .49629 L
.52704 .49864 L
.53064 .50084 L
.53477 .50296 L
.5395 .50504 L
.54492 .50713 L
.55112 .50929 L
.55821 .51157 L
.5663 .51399 L
.57553 .51663 L
.58607 .51952 L
.59809 .52273 L
.6118 .5263 L
.62744 .53031 L
.64527 .53483 L
.6656 .53994 L
.68879 .54573 L
.71523 .55229 L
.74538 .55975 L
.77975 .56823 L
.81894 .57788 L
.86361 .58887 L
.91456 .60139 L
.97263 .61565 L
s
.97263 .61565 m
1 .62236 L
s
.2 1 0 r
.46078 .62506 m
.45858 .60221 L
.45553 .58285 L
.45159 .56635 L
.44673 .5522 L
.44086 .53995 L
.43391 .52923 L
.42576 .51971 L
.41628 .51111 L
.40533 .50319 L
.39271 .49573 L
.37822 .48853 L
.3616 .48141 L
.34259 .47422 L
.32084 .46677 L
.296 .45892 L
.26764 .4505 L
.23526 .44133 L
.19832 .43126 L
.15618 .42008 L
.10811 .40759 L
.0533 .39356 L
s
.0533 .39356 m
0 .38008 L
s
0 1 .172 r
.48646 .48356 m
.48424 .48519 L
.48176 .48639 L
.47898 .48723 L
.47585 .48772 L
.47231 .48791 L
.46831 .48781 L
.46376 .48743 L
.45859 .48677 L
.45271 .48584 L
.44602 .48463 L
.43841 .48312 L
.42973 .48129 L
.41985 .47912 L
.40859 .47656 L
.39576 .47359 L
.38113 .47015 L
.36446 .46619 L
.34545 .46163 L
.32378 .45641 L
.29908 .45043 L
.27093 .44358 L
.23882 .43577 L
.20222 .42684 L
.1605 .41665 L
.11292 .40503 L
.05869 .39176 L
s
.05869 .39176 m
0 .3774 L
s
1 0 .571 r
.74948 .53936 m
.7839 .5514 L
.82323 .56404 L
.86815 .57756 L
.91942 .59221 L
.97793 .60829 L
s
.97793 .60829 m
1 .61418 L
s
.47 1 0 r
.4285 .82508 m
.42686 .76792 L
.42361 .71977 L
.41875 .67907 L
.41224 .64451 L
.40401 .61499 L
.39395 .58958 L
.38192 .56749 L
.36773 .54804 L
.35117 .53065 L
.33196 .51483 L
.30979 .50012 L
.28428 .48613 L
.25501 .4725 L
.22148 .4589 L
.18312 .445 L
.13928 .43051 L
.0892 .41511 L
.03203 .3985 L
s
.03203 .3985 m
0 .38958 L
s
1 .943 0 r
.28765 .22962 m
.25255 .2572 L
.21342 .27779 L
.16954 .29222 L
.12014 .30113 L
.06432 .30498 L
.00112 .30412 L
s
.00112 .30412 m
0 .30404 L
s
.892 1 0 r
.54382 .21606 m
.54275 .26461 L
.54272 .30534 L
.54368 .33956 L
.54561 .36838 L
.5485 .39275 L
.55238 .41344 L
.55729 .4311 L
.56329 .44631 L
.57046 .45953 L
.57892 .47117 L
.5888 .48157 L
.60025 .49103 L
.61348 .49983 L
.62869 .50819 L
.64615 .51633 L
.66616 .52446 L
.68904 .53276 L
.71519 .54141 L
.74507 .5506 L
.77917 .56052 L
.81809 .57136 L
.8625 .58333 L
.91316 .59665 L
.97093 .61156 L
s
.97093 .61156 m
1 .61896 L
s
0 1 .465 r
.38177 .57506 m
.36776 .55439 L
.35135 .53599 L
.3323 .51933 L
.31028 .50392 L
.28493 .48936 L
.25583 .47527 L
.22248 .46128 L
.18431 .44708 L
.14068 .43234 L
.09083 .41676 L
.03392 .4 L
s
.03392 .4 m
0 .39046 L
s
0 1 .593 r
.71267 .6155 m
.74402 .61268 L
.77951 .61261 L
.81975 .61516 L
.86545 .62026 L
.91741 .6279 L
.97652 .63813 L
s
.97652 .63813 m
1 .64265 L
s
1 0 .984 r
.76339 .5932 m
.801 .59766 L
.84376 .60417 L
.89241 .61279 L
.9478 .6236 L
s
.9478 .6236 m
1 .63448 L
s
.856 1 0 r
.31244 .74976 m
.2934 .69611 L
.2705 .64962 L
.24338 .60888 L
.21163 .57264 L
.17473 .53986 L
.13209 .50961 L
.08298 .48105 L
.02659 .45345 L
s
.02659 .45345 m
0 .4422 L
s
1 0 .675 r
.29057 .65545 m
.26629 .61525 L
.23777 .57968 L
.20455 .5477 L
.1661 .51839 L
.12177 .49093 L
.07082 .4646 L
.01239 .43873 L
s
.01239 .43873 m
0 .4339 L
s
1 .484 0 r
.79393 .44297 m
.83195 .47366 L
.87583 .50225 L
.92628 .52949 L
.98417 .55609 L
s
.98417 .55609 m
1 .56244 L
s
0 .57 1 r
.45537 .74763 m
.45544 .70482 L
.45448 .66884 L
.45251 .63854 L
.44953 .61293 L
.44553 .59119 L
.44045 .57263 L
.43425 .55666 L
.42682 .54278 L
.41805 .53058 L
.40781 .51968 L
.39592 .50976 L
.38221 .50056 L
.36642 .49182 L
.34831 .48331 L
.32755 .47484 L
.30381 .46619 L
.27667 .45718 L
.24567 .44761 L
.21028 .4373 L
.16989 .42603 L
.12381 .4136 L
.07124 .39976 L
.01129 .38428 L
s
.01129 .38428 m
0 .3814 L
s
0 1 .859 r
.77537 .50819 m
.8125 .5271 L
.85507 .54573 L
.90381 .56451 L
.95955 .58386 L
s
.95955 .58386 m
1 .5968 L
s
1 0 .514 r
.3715 .5236 m
.35485 .51039 L
.33563 .49807 L
.31354 .48631 L
.2882 .4748 L
.25918 .46327 L
.22598 .45144 L
.18804 .43907 L
.14472 .42589 L
.09525 .41163 L
.03881 .39601 L
s
.03881 .39601 m
0 .3856 L
s
1 .632 0 r
.28199 .22432 m
.24601 .25232 L
.20588 .27321 L
.16088 .28782 L
.11021 .2968 L
.05296 .30061 L
s
.05296 .30061 m
0 .2998 L
s
.233 0 1 r
.26079 .5121 m
.22901 .4926 L
.19249 .47388 L
.15061 .45546 L
.10266 .43691 L
.04782 .4178 L
s
.04782 .4178 m
0 .40247 L
s
0 1 .547 r
.33552 .56611 m
.31508 .54348 L
.29134 .52295 L
.26392 .50396 L
.23236 .48599 L
.19612 .46857 L
.1546 .45127 L
.10708 .43368 L
.05276 .41541 L
s
.05276 .41541 m
0 .39897 L
s
1 0 .307 r
.54829 .1848 m
.54705 .23868 L
.54696 .28386 L
.54797 .32182 L
.55004 .35379 L
.55317 .38081 L
.55738 .40375 L
.56272 .42333 L
.56925 .44018 L
.57707 .45482 L
.58631 .46769 L
.59709 .47919 L
.6096 .48964 L
.62405 .49935 L
.64067 .50856 L
.65974 .51753 L
.68159 .52646 L
.70659 .53557 L
.73517 .54507 L
.76781 .55514 L
.80508 .56601 L
.84761 .57788 L
.89614 .59097 L
.95149 .60554 L
s
.95149 .60554 m
1 .61807 L
s
0 1 .484 r
.4331 .30093 m
.41925 .3278 L
.40421 .34936 L
.38768 .36638 L
.36934 .37947 L
.34887 .38912 L
.32588 .39572 L
.29998 .39958 L
.27069 .40093 L
.23752 .3999 L
.19986 .39661 L
.15708 .39107 L
.10842 .38328 L
.05305 .37316 L
s
.05305 .37316 m
0 .36258 L
s
0 1 .654 r
.36051 .22893 m
.33517 .26196 L
.30723 .28786 L
.27619 .30758 L
.24146 .32186 L
.20243 .33132 L
.15839 .3364 L
.10857 .33743 L
.05209 .33464 L
s
.05209 .33464 m
0 .32936 L
s
0 1 .598 r
.64815 .52654 m
.66867 .53318 L
.69211 .54027 L
.71886 .54795 L
.74938 .55637 L
.78421 .56568 L
.82393 .57607 L
.86923 .58771 L
.9209 .60083 L
.97982 .61564 L
s
.97982 .61564 m
1 .62068 L
s
1 0 .046 r
.33146 .25885 m
.30295 .28497 L
.27126 .30483 L
.23581 .3192 L
.19595 .32866 L
.15098 .33369 L
.1001 .33461 L
.04242 .33165 L
s
.04242 .33165 m
0 .32729 L
s
1 0 .714 r
.81478 .23189 m
.85043 .29781 L
.89247 .35584 L
.94158 .40768 L
.99854 .45485 L
s
.99854 .45485 m
1 .45583 L
s
1 0 .857 r
.74947 .6093 m
.7856 .61017 L
.8266 .61355 L
.87318 .61941 L
.92615 .62775 L
.98643 .63865 L
s
.98643 .63865 m
1 .64134 L
s
.936 0 1 r
.33996 .54946 m
.3197 .52981 L
.29625 .51181 L
.26922 .49496 L
.23814 .47881 L
.20251 .46296 L
.1617 .44703 L
.11503 .43064 L
.06171 .41344 L
.00081 .39507 L
s
.00081 .39507 m
0 .39484 L
s
0 .964 1 r
.72263 .82184 m
.76036 .7868 L
.8023 .76013 L
.84921 .7408 L
.90194 .728 L
.96143 .72111 L
s
.96143 .72111 m
1 .7203 L
s
.937 1 0 r
.22019 .50846 m
.18288 .48656 L
.14002 .46542 L
.09089 .4445 L
.03467 .42331 L
s
.03467 .42331 m
0 .41149 L
s
.073 0 1 r
.45416 .50604 m
.44816 .50171 L
.44125 .49763 L
.43331 .49369 L
.42421 .4898 L
.4138 .48586 L
.40189 .48179 L
.38829 .47749 L
.37276 .47288 L
.35503 .46786 L
.3348 .46235 L
.31172 .45623 L
.2854 .44939 L
.25538 .44171 L
.22115 .43305 L
.18211 .42326 L
.1376 .41216 L
.08685 .39957 L
.02898 .38526 L
s
.02898 .38526 m
0 .37812 L
s
1 .035 0 r
.26425 .56815 m
.2343 .53995 L
.19964 .51406 L
.1597 .48975 L
.11382 .4664 L
.0612 .4434 L
.00097 .42021 L
s
.00097 .42021 m
0 .41987 L
s
0 1 .86 r
.64556 .21079 m
.658 .26766 L
.6735 .31636 L
.69227 .35842 L
.71459 .39515 L
.7408 .42765 L
.77133 .45689 L
.80666 .4837 L
.84739 .50883 L
.89419 .53293 L
.94786 .55663 L
s
.94786 .55663 m
1 .57686 L
s
0 .109 1 r
.38172 .39228 m
.36322 .40079 L
.34245 .40658 L
.31903 .40993 L
.29256 .41102 L
.26256 .40999 L
.22851 .40692 L
.18982 .40185 L
.14582 .39474 L
.09574 .38553 L
.03872 .37412 L
s
.03872 .37412 m
0 .3659 L
s
.414 0 1 r
.80428 .19659 m
.83766 .26738 L
.87725 .32932 L
.92367 .38428 L
.97765 .43388 L
s
.97765 .43388 m
1 .45021 L
s
.285 1 0 r
.33329 .53868 m
.31188 .52026 L
.28714 .50321 L
.25868 .48706 L
.22599 .4714 L
.18855 .45585 L
.1457 .44002 L
.09671 .42358 L
.04075 .40616 L
s
.04075 .40616 m
0 .3942 L
s
1 .161 0 r
.58468 .51712 m
.59645 .5206 L
.60989 .5244 L
.62523 .52857 L
.64272 .53321 L
.66267 .53839 L
.68543 .54421 L
.71138 .55077 L
.74097 .55819 L
.77471 .56659 L
.81319 .57614 L
.85705 .58698 L
.90707 .59932 L
.96409 .61336 L
s
.96409 .61336 m
1 .62219 L
s
1 .148 0 r
.35851 .48424 m
.33915 .47637 L
.317 .46833 L
.29169 .45994 L
.26277 .45104 L
.22975 .44143 L
.19208 .43094 L
.14909 .41935 L
.10005 .40645 L
.04412 .39202 L
s
.04412 .39202 m
0 .38078 L
s
1 .803 0 r
.80649 .37921 m
.84464 .42101 L
.88892 .45893 L
.94008 .49405 L
.99895 .52733 L
s
.99895 .52733 m
1 .52782 L
s
1 0 .312 r
.71357 .79233 m
.74937 .76134 L
.78921 .73793 L
.83382 .72118 L
.88401 .71038 L
.94066 .70499 L
s
.94066 .70499 m
1 .70465 L
s
1 .207 0 r
.56487 .51753 m
.57399 .5195 L
.5844 .52182 L
.59625 .52453 L
.60976 .52768 L
.62515 .53132 L
.64271 .53552 L
.66271 .54033 L
.68552 .54584 L
.71153 .55214 L
.74117 .55935 L
.77497 .56759 L
.8135 .57699 L
.85743 .58772 L
.90751 .59997 L
.96461 .61394 L
s
.96461 .61394 m
1 .6226 L
s
.148 1 0 r
.21072 .22635 m
.16522 .2488 L
.11418 .26432 L
.05666 .27361 L
s
.05666 .27361 m
0 .27674 L
s
.421 0 1 r
.35806 .53809 m
.33996 .52158 L
.31903 .50638 L
.29491 .49207 L
.26721 .47827 L
.23546 .46464 L
.19912 .45086 L
.15756 .43661 L
.11009 .42158 L
.05587 .40546 L
s
.05587 .40546 m
0 .38964 L
s
1 .052 0 r
.28414 .65746 m
.25905 .61647 L
.22958 .58017 L
.19528 .54751 L
.15557 .51754 L
.10981 .48945 L
.05723 .46247 L
s
.05723 .46247 m
0 .4373 L
s
1 .261 0 r
.32539 .81913 m
.30979 .75535 L
.29053 .70061 L
.26735 .65319 L
.2399 .61164 L
.20775 .57472 L
.17038 .54132 L
.12719 .51051 L
.07745 .48145 L
.02032 .45338 L
s
.02032 .45338 m
0 .44476 L
s
0 1 .802 r
.7849 .31307 m
.81853 .36384 L
.85792 .40898 L
.90369 .4498 L
.9566 .48747 L
s
.9566 .48747 m
1 .51278 L
s
0 1 .49 r
.61373 .4872 m
.62867 .49759 L
.64586 .50743 L
.66561 .51696 L
.68823 .52641 L
.71412 .53602 L
.74372 .54599 L
.77753 .55655 L
.81614 .56791 L
.8602 .58028 L
.91047 .59392 L
.96782 .60907 L
s
.96782 .60907 m
1 .61741 L
s
0 1 .337 r
.19189 .77889 m
.1574 .71173 L
.11664 .65276 L
.06896 .60022 L
.01361 .55256 L
s
.01361 .55256 m
0 .54317 L
s
0 .918 1 r
.38848 .69542 m
.37831 .65603 L
.36581 .62218 L
.35081 .59282 L
.33307 .56704 L
.31232 .54407 L
.28823 .52325 L
.2604 .50399 L
.22836 .48575 L
.19159 .46808 L
.14944 .45052 L
.10122 .43267 L
.04609 .41414 L
s
.04609 .41414 m
0 .39977 L
s
.223 1 0 r
.52172 .47476 m
.52402 .48038 L
.52676 .48528 L
.52999 .4896 L
.53376 .49346 L
.53812 .49698 L
.54316 .50027 L
.54896 .50339 L
.55561 .50645 L
.56322 .5095 L
.57193 .51263 L
.58189 .51589 L
.59326 .51937 L
.60624 .52313 L
.62106 .52724 L
.63796 .53178 L
.65724 .53684 L
.67923 .54251 L
.70431 .54888 L
.7329 .55608 L
.76551 .56423 L
.80269 .57348 L
.84509 .58398 L
.89342 .59591 L
.94854 .60949 L
s
.94854 .60949 m
1 .62216 L
s
.929 0 1 r
.59171 .30499 m
.59923 .34286 L
.60869 .37524 L
.62022 .40314 L
.63397 .42744 L
.65016 .44886 L
.66904 .46806 L
.69093 .48557 L
.71619 .5019 L
.74523 .51747 L
.77854 .5327 L
.8167 .54793 L
.86034 .56354 L
.91023 .57986 L
.9672 .59724 L
s
.9672 .59724 m
1 .60671 L
s
.9 1 0 r
.33048 .26735 m
.30205 .29205 L
.27041 .31071 L
.23499 .32407 L
.19514 .3327 L
.15016 .33702 L
.09925 .33735 L
.04152 .33389 L
s
.04152 .33389 m
0 .32936 L
s
1 0 .175 r
.62653 .18722 m
.63584 .24646 L
.64785 .29692 L
.66271 .3402 L
.68062 .37767 L
.70185 .41047 L
.72673 .43959 L
.75566 .46589 L
.78911 .49011 L
.82764 .51292 L
.8719 .53492 L
.92263 .55666 L
.98069 .57865 L
s
.98069 .57865 m
1 .58527 L
s
0 1 .827 r
.24009 .59778 m
.20762 .56307 L
.16996 .53153 L
.12647 .50226 L
.07643 .47446 L
.01899 .44743 L
s
.01899 .44743 m
0 .43965 L
s
1 .342 0 r
.80066 .44771 m
.8397 .47814 L
.88473 .50658 L
.93648 .53379 L
.99585 .56045 L
s
.99585 .56045 m
1 .56209 L
s
.32 1 0 r
.66743 .48895 m
.68961 .50301 L
.71511 .51645 L
.74437 .52963 L
.77786 .54284 L
.81618 .55641 L
.85996 .57062 L
.90997 .58579 L
.96705 .6022 L
s
.96705 .6022 m
1 .6113 L
s
0 .699 1 r
.455 .5014 m
.449 .49787 L
.44211 .49447 L
.43421 .4911 L
.42517 .48769 L
.41483 .48416 L
.40302 .48043 L
.38954 .47643 L
.37415 .47208 L
.35659 .4673 L
.33655 .46199 L
.3137 .45605 L
.28764 .44939 L
.25792 .44187 L
.22403 .43337 L
.18539 .42374 L
.14133 .41281 L
.0911 .40039 L
.03382 .38626 L
s
.03382 .38626 m
0 .37794 L
s
0 1 .257 r
.24032 .63249 m
.20874 .59226 L
.17194 .55614 L
.12932 .52308 L
.08017 .49217 L
.02367 .46259 L
s
.02367 .46259 m
0 .45199 L
s
0 1 .388 r
.60809 .37489 m
.61952 .40281 L
.63317 .42711 L
.64925 .44853 L
.668 .46771 L
.68974 .4852 L
.71483 .5015 L
.74367 .51704 L
.77677 .53221 L
.81468 .5474 L
.85804 .56294 L
.9076 .57919 L
.9642 .59648 L
s
.9642 .59648 m
1 .60683 L
s
0 .027 1 r
.4965 .5292 m
.49674 .52428 L
.4969 .52016 L
.49698 .51672 L
.49698 .51382 L
.49692 .5114 L
.49678 .50935 L
.49658 .50762 L
.49631 .50615 L
.49596 .5049 L
.49554 .50382 L
.49504 .50288 L
.49444 .50206 L
.49375 .50132 L
.49294 .50065 L
.49201 .50003 L
.49094 .49944 L
.48971 .49886 L
.48831 .49829 L
.4867 .4977 L
.48485 .49709 L
.48275 .49644 L
.48035 .49575 L
.47761 .49498 L
.47449 .49414 L
.47092 .4932 L
.46686 .49215 L
.46222 .49097 L
.45693 .48964 L
.4509 .48813 L
.44403 .48642 L
.43619 .48448 L
.42725 .48227 L
.41706 .47976 L
.40544 .4769 L
.39219 .47364 L
.37709 .46993 L
.35987 .46571 L
.34024 .46089 L
.31785 .4554 L
.29234 .44914 L
.26324 .44201 L
.23007 .43388 L
.19225 .42461 L
.14913 .41405 L
.09997 .402 L
.04392 .38827 L
s
.04392 .38827 m
0 .37751 L
s
1 .046 0 r
.36989 .4429 m
.35105 .44246 L
.32966 .44071 L
.30536 .43766 L
.27773 .43332 L
.24629 .42764 L
.2105 .42056 L
.16973 .41198 L
.12328 .40178 L
.07035 .38979 L
.01003 .37584 L
s
.01003 .37584 m
0 .37348 L
s
.295 1 0 r
.64209 .62592 m
.66423 .61625 L
.6891 .60975 L
.71715 .60612 L
.74887 .60512 L
.78482 .60662 L
.82563 .61051 L
.872 .61678 L
.92475 .62546 L
.98479 .63662 L
s
.98479 .63662 m
1 .63969 L
s
0 .382 1 r
.20149 .71557 m
.16673 .65922 L
.12594 .60932 L
.07845 .56439 L
.02349 .52315 L
s
.02349 .52315 m
0 .5088 L
s
1 .364 0 r
.74294 .49709 m
.77545 .5154 L
.81277 .53317 L
.85553 .55085 L
.90445 .56884 L
.96038 .58755 L
s
.96038 .58755 m
1 .59985 L
s
1 .054 0 r
.3408 .42716 m
.31766 .42709 L
.29142 .42534 L
.26162 .42195 L
.22774 .4169 L
.1892 .41017 L
.14531 .40169 L
.09534 .39134 L
.03841 .37897 L
s
.03841 .37897 m
0 .37033 L
s
1 .95 0 r
.59401 .7245 m
.61211 .69556 L
.63193 .67257 L
.65385 .6547 L
.67827 .6413 L
.70564 .63183 L
.73645 .62589 L
.77124 .62315 L
.81063 .62341 L
.85531 .62652 L
.90606 .63241 L
.96376 .6411 L
s
.96376 .6411 m
1 .64746 L
s
.069 0 1 r
.48768 .22035 m
.47918 .2641 L
.47061 .30024 L
.46178 .32997 L
.45249 .35432 L
.44255 .37409 L
.43176 .38997 L
.41992 .40253 L
.40679 .41221 L
.39214 .41938 L
.3757 .42433 L
.35718 .42728 L
.33624 .42841 L
.31253 .42781 L
.28562 .42557 L
.25504 .42171 L
.22028 .41622 L
.18071 .40905 L
.13566 .40012 L
.08436 .38931 L
.0259 .37646 L
s
.0259 .37646 m
0 .37059 L
s
0 1 .286 r
.40623 .31021 m
.38901 .33363 L
.37005 .35204 L
.349 .36612 L
.32547 .37641 L
.29904 .38332 L
.26923 .38719 L
.23552 .38826 L
.19731 .38667 L
.15395 .38254 L
.10466 .37588 L
.0486 .36666 L
s
.0486 .36666 m
0 .35762 L
s
0 1 .821 r
.31975 .70683 m
.30064 .66056 L
.27784 .62029 L
.25099 .58476 L
.21966 .55294 L
.18336 .5239 L
.14148 .49683 L
.09333 .471 L
.03808 .44576 L
s
.03808 .44576 m
0 .43056 L
s
.975 0 1 r
.42284 .73004 m
.41812 .68764 L
.41174 .65167 L
.40361 .62097 L
.39365 .59458 L
.3817 .57166 L
.36759 .55153 L
.35109 .53358 L
.33195 .51728 L
.30983 .50218 L
.28438 .48786 L
.25517 .47397 L
.22169 .46014 L
.18339 .44606 L
.13961 .43142 L
.0896 .4159 L
.0325 .39919 L
s
.0325 .39919 m
0 .39009 L
s
0 1 .44 r
.59514 .23467 m
.6014 .28402 L
.60971 .32596 L
.62017 .3618 L
.6329 .3927 L
.64809 .41959 L
.66599 .44331 L
.68686 .46455 L
.71105 .48393 L
.73896 .502 L
.77106 .51923 L
.80788 .53607 L
.85006 .55292 L
.8983 .57018 L
.95344 .58823 L
s
.95344 .58823 m
1 .60244 L
s
.762 0 1 r
.31226 .26339 m
.28129 .28738 L
.24675 .30527 L
.20802 .31776 L
.1644 .32542 L
.11512 .32864 L
.0593 .32774 L
s
.0593 .32774 m
0 .32318 L
s
0 1 .743 r
.66493 .43934 m
.68557 .46114 L
.7095 .48097 L
.73713 .4994 L
.76892 .51691 L
.8054 .53396 L
.84719 .55097 L
.895 .56833 L
.94964 .58643 L
s
.94964 .58643 m
1 .60194 L
s
.95 1 0 r
.26752 .7045 m
.24134 .65477 L
.21044 .61106 L
.17433 .57206 L
.13242 .53664 L
.08402 .50379 L
.02832 .47263 L
s
.02832 .47263 m
0 .45922 L
s
.588 1 0 r
.30597 .54492 m
.28105 .5235 L
.25226 .50367 L
.21913 .48489 L
.18109 .46667 L
.1375 .44857 L
.08763 .43016 L
.03062 .41102 L
s
.03062 .41102 m
0 .4015 L
s
1 .58 0 r
.6844 .39408 m
.70654 .42453 L
.73239 .45175 L
.76238 .47652 L
.79699 .49954 L
.83681 .52143 L
.8825 .54274 L
.93485 .56401 L
.99473 .58573 L
s
.99473 .58573 m
1 .58747 L
s
0 .524 1 r
.31355 .62653 m
.29164 .59263 L
.26596 .56254 L
.23611 .53536 L
.20158 .51034 L
.16181 .48677 L
.11613 .46404 L
.06377 .44159 L
.00384 .41888 L
s
.00384 .41888 m
0 .41756 L
s
1 0 .57 r
.64556 .41904 m
.6631 .44266 L
.68356 .46379 L
.7073 .48306 L
.73468 .50099 L
.76618 .51807 L
.80232 .53473 L
.84372 .55139 L
.89107 .56843 L
.94519 .58623 L
s
.94519 .58623 m
1 .60301 L
s
0 1 .047 r
.66541 .65314 m
.69134 .64084 L
.72045 .6324 L
.75326 .62745 L
.79034 .6257 L
.83236 .62696 L
.88004 .6311 L
.93422 .63808 L
.99583 .64792 L
s
.99583 .64792 m
1 .64868 L
s
0 1 .293 r
.18328 .5865 m
.14292 .54943 L
.09624 .51531 L
.04246 .48321 L
s
.04246 .48321 m
0 .46195 L
s
0 1 .745 r
.44205 .36118 m
.43088 .37909 L
.41865 .39332 L
.40513 .40438 L
.39007 .41268 L
.37319 .41855 L
.35419 .42224 L
.33273 .42394 L
.30843 .4238 L
.28088 .4219 L
.24958 .41828 L
.21399 .41293 L
.1735 .40583 L
.12741 .39689 L
.07492 .38598 L
.01512 .37297 L
s
.01512 .37297 m
0 .36957 L
s
1 0 .552 r
.72275 .36668 m
.74936 .40433 L
.78046 .43792 L
.81656 .46843 L
.85824 .49672 L
.9062 .52356 L
.96125 .54963 L
s
.96125 .54963 m
1 .56557 L
s
.77 1 0 r
.23646 .37133 m
.19797 .37252 L
.15434 .37069 L
.10482 .36595 L
.04853 .35833 L
s
.04853 .35833 m
0 .35034 L
s
0 1 .392 r
.78859 .60777 m
.82993 .61176 L
.87692 .61815 L
.93036 .62697 L
.99118 .6383 L
s
.99118 .6383 m
1 .64008 L
s
1 .007 0 r
.47437 .27225 m
.46536 .30674 L
.45599 .33505 L
.44604 .35816 L
.43534 .37684 L
.42365 .39176 L
.41076 .40343 L
.39643 .4123 L
.38039 .41869 L
.36236 .42289 L
.34201 .42509 L
.31898 .42545 L
.29288 .42406 L
.26325 .42097 L
.22956 .4162 L
.19124 .40972 L
.14762 .40146 L
.09795 .39131 L
.04137 .37914 L
s
.04137 .37914 m
0 .3699 L
s
1 0 .755 r
.58355 .52291 m
.59532 .52539 L
.60872 .52833 L
.624 .53179 L
.64141 .53583 L
.66125 .54049 L
.68386 .54587 L
.70965 .55205 L
.73904 .55914 L
.77254 .56725 L
.81074 .57653 L
.85429 .58713 L
.90393 .59924 L
.96054 .61306 L
s
.96054 .61306 m
1 .62271 L
s
1 .451 0 r
.17424 .24827 m
.12439 .26454 L
.06825 .27455 L
.00483 .27884 L
s
.00483 .27884 m
0 .27877 L
s
.079 1 0 r
.79449 .19163 m
.82643 .2625 L
.8644 .3244 L
.90897 .3792 L
.96086 .42852 L
s
.96086 .42852 m
1 .45802 L
s
0 1 .767 r
.51853 .19328 m
.51351 .24361 L
.50904 .28554 L
.505 .32045 L
.50128 .34949 L
.49776 .37361 L
.49437 .39363 L
.49101 .4102 L
.48761 .42388 L
.48408 .43512 L
.48036 .44431 L
.47636 .45176 L
.47201 .45773 L
.46722 .46242 L
.4619 .46601 L
.45596 .46864 L
.44929 .47041 L
.44176 .47141 L
.43325 .4717 L
.42361 .47132 L
.41266 .47029 L
.40022 .46862 L
.38607 .4663 L
.36997 .46331 L
.35163 .45962 L
.33074 .45517 L
.30694 .4499 L
.27983 .44372 L
.24892 .43653 L
.21369 .42823 L
.17354 .41866 L
.12777 .40767 L
.07559 .39507 L
.0161 .38066 L
s
.0161 .38066 m
0 .37674 L
s
.025 0 1 r
.37105 .33413 m
.3497 .35114 L
.3259 .36387 L
.29922 .37282 L
.26917 .37838 L
.23524 .38085 L
.19682 .38043 L
.15323 .37725 L
.10372 .37138 L
.04742 .36281 L
s
.04742 .36281 m
0 .35442 L
s
.371 0 1 r
.60998 .54137 m
.62574 .54284 L
.64365 .54524 L
.66403 .54856 L
.68721 .55286 L
.71361 .55817 L
.74369 .56457 L
.77795 .57216 L
.81699 .58105 L
.86149 .59139 L
.9122 .60335 L
.97002 .61712 L
s
.97002 .61712 m
1 .62432 L
s
0 1 .477 r
.70614 .61352 m
.73657 .61053 L
.771 .61026 L
.81004 .61256 L
.85438 .61736 L
.90478 .62465 L
.96212 .63447 L
s
.96212 .63447 m
1 .64171 L
s
1 0 .078 r
.62774 .17682 m
.63696 .23781 L
.64891 .28973 L
.66373 .33424 L
.68163 .37273 L
.70287 .40639 L
.72779 .43624 L
.75678 .46315 L
.79031 .48789 L
.82895 .51115 L
.87334 .53353 L
.92423 .5556 L
.98249 .57788 L
s
.98249 .57788 m
1 .58392 L
s
0 1 .076 r
.2325 .40776 m
.19437 .40284 L
.15101 .39591 L
.10165 .38689 L
.04546 .3757 L
s
.04546 .3757 m
0 .36608 L
s
.973 0 1 r
.40458 .73425 m
.39752 .68984 L
.38842 .652 L
.37718 .61954 L
.36364 .59143 L
.34759 .56682 L
.32878 .54495 L
.30692 .5252 L
.28164 .507 L
.25253 .48984 L
.21909 .47329 L
.18076 .45692 L
.13689 .44035 L
.08674 .42321 L
.02943 .40512 L
s
.02943 .40512 m
0 .39639 L
s
.182 1 0 r
.6283 .74847 m
.65159 .71822 L
.67726 .69451 L
.70579 .67647 L
.73771 .66341 L
.77359 .65477 L
.81407 .65015 L
.85987 .64925 L
.91179 .65185 L
.97073 .65785 L
s
.97073 .65785 m
1 .66194 L
s
1 .734 0 r
.5332 .80935 m
.54522 .7624 L
.55771 .72382 L
.57093 .69232 L
.58516 .66682 L
.60066 .64644 L
.61774 .63045 L
.63673 .61827 L
.65796 .60943 L
.68183 .60356 L
.70875 .60038 L
.7392 .59968 L
.77372 .60133 L
.81291 .60526 L
.85745 .61143 L
.90812 .61989 L
.96579 .63072 L
s
.96579 .63072 m
1 .63767 L
s
.379 0 1 r
.3776 .50206 m
.36124 .49274 L
.34245 .48371 L
.32092 .47474 L
.29629 .46562 L
.26813 .45615 L
.23596 .44612 L
.19922 .43533 L
.1573 .42356 L
.10947 .4106 L
.05491 .39619 L
s
.05491 .39619 m
0 .38197 L
s
1 .634 0 r
.51096 .77834 m
.51924 .7347 L
.52757 .69864 L
.53613 .66895 L
.54511 .64462 L
.5547 .62484 L
.56509 .60893 L
.57649 .59632 L
.5891 .58655 L
.60317 .57928 L
.61895 .5742 L
.63672 .57109 L
.65679 .56978 L
.67953 .57015 L
.70532 .57214 L
.73463 .5757 L
.76794 .58084 L
.80586 .58761 L
.84902 .59609 L
.89818 .60638 L
.95419 .61864 L
s
.95419 .61864 m
1 .62899 L
s
.287 1 0 r
.4099 .30916 m
.39314 .33302 L
.37472 .35183 L
.35429 .36629 L
.33148 .37694 L
.30587 .38421 L
.277 .38844 L
.24436 .38987 L
.20738 .38868 L
.16541 .38496 L
.11772 .37876 L
.06348 .37004 L
.00175 .35873 L
s
.00175 .35873 m
0 .35838 L
s
1 0 .731 r
.25811 .51476 m
.22604 .49464 L
.18916 .47537 L
.14687 .45647 L
.09845 .43749 L
.04307 .41798 L
s
.04307 .41798 m
0 .40405 L
s
1 .018 0 r
.50175 .44606 m
.50067 .4548 L
.49965 .46207 L
.49868 .4681 L
.49772 .47309 L
.49675 .47722 L
.49576 .48062 L
.49472 .4834 L
.4936 .48567 L
.4924 .48749 L
.49107 .48892 L
.4896 .49004 L
.48796 .49086 L
.48612 .49144 L
.48405 .49179 L
.48171 .49193 L
.47906 .49187 L
.47606 .49163 L
.47264 .49121 L
.46876 .4906 L
.46433 .48981 L
.4593 .48882 L
.45357 .48761 L
.44704 .48618 L
.4396 .4845 L
.43112 .48254 L
.42145 .48027 L
.41044 .47765 L
.39788 .47464 L
.38356 .47119 L
.36724 .46724 L
.34863 .46272 L
.32742 .45755 L
.30324 .45166 L
.27567 .44492 L
.24423 .43724 L
.20839 .42848 L
.16753 .41848 L
.12095 .40708 L
.06784 .39408 L
.00729 .37925 L
s
.00729 .37925 m
0 .37746 L
s
1 0 .817 r
.18443 .46879 m
.14134 .4506 L
.09203 .43214 L
.03566 .41301 L
s
.03566 .41301 m
0 .40182 L
s
1 .099 0 r
.3597 .62757 m
.344 .5969 L
.32545 .56997 L
.30376 .54598 L
.27857 .52422 L
.24946 .50409 L
.21596 .48504 L
.1775 .46657 L
.13343 .44822 L
.08301 .42956 L
.02536 .41018 L
s
.02536 .41018 m
0 .40228 L
s
0 .738 1 r
.61017 .7241 m
.63044 .69641 L
.65274 .67463 L
.6775 .65796 L
.70517 .64578 L
.73625 .63757 L
.77131 .63295 L
.81095 .63165 L
.85587 .63347 L
.90687 .63829 L
.96482 .6461 L
s
.96482 .6461 m
1 .65187 L
s
1 0 .202 r
.56246 .50738 m
.57101 .51079 L
.5808 .51428 L
.59199 .51793 L
.60477 .52183 L
.61935 .52604 L
.63599 .53064 L
.65498 .53574 L
.67664 .54142 L
.70135 .54778 L
.72952 .55494 L
.76164 .56302 L
.79828 .57218 L
.84005 .58256 L
.88767 .59435 L
.94197 .60776 L
s
.94197 .60776 m
1 .62206 L
s
1 0 .779 r
.29528 .24177 m
.26151 .26797 L
.22384 .2875 L
.1816 .30115 L
.13403 .30951 L
.08029 .31305 L
.01943 .31207 L
s
.01943 .31207 m
0 .31059 L
s
1 0 .47 r
.58264 .58693 m
.59585 .57912 L
.61064 .57352 L
.62728 .56991 L
.64606 .5681 L
.66732 .56795 L
.69142 .56939 L
.71879 .57237 L
.74991 .57688 L
.78531 .58296 L
.8256 .59067 L
.87149 .60011 L
.92376 .61141 L
.98332 .62474 L
s
.98332 .62474 m
1 .62857 L
s
0 1 .76 r
.81109 .80231 m
.86021 .77689 L
.9153 .75914 L
.97734 .74826 L
s
.97734 .74826 m
1 .74678 L
s
.779 0 1 r
.19896 .64044 m
.16203 .5959 L
.11905 .55577 L
.06932 .51888 L
.01203 .48424 L
s
.01203 .48424 m
0 .47815 L
s
0 .08 1 r
.58049 .56976 m
.59299 .56453 L
.60705 .56106 L
.6229 .55917 L
.64083 .55875 L
.66115 .55971 L
.68423 .56201 L
.71045 .56564 L
.74028 .57062 L
.77424 .57699 L
.8129 .58484 L
.85694 .59427 L
.90712 .60544 L
.9643 .6185 L
s
.9643 .6185 m
1 .62682 L
s
1 .555 0 r
.25852 .30356 m
.22133 .31719 L
.17948 .32591 L
.13223 .33017 L
.07875 .33028 L
.0181 .32644 L
s
.0181 .32644 m
0 .32442 L
s
0 .846 1 r
.75965 .78736 m
.8015 .76055 L
.84832 .74109 L
.90093 .72818 L
.96029 .72119 L
s
.96029 .72119 m
1 .7203 L
s
.051 0 1 r
.69128 .34818 m
.71321 .38647 L
.73903 .42026 L
.76913 .45055 L
.80401 .47821 L
.84425 .50402 L
.89052 .52866 L
.94359 .55276 L
s
.94359 .55276 m
1 .57518 L
s
1 .602 0 r
.59241 .42197 m
.6029 .44122 L
.61526 .45816 L
.62969 .47331 L
.64643 .48709 L
.66575 .49991 L
.68798 .5121 L
.71349 .52397 L
.7427 .53582 L
.77613 .54793 L
.81434 .56056 L
.85798 .57397 L
.90779 .58846 L
.96465 .60428 L
s
.96465 .60428 m
1 .61381 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{1000, 1000},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000?X0003j2000`400?l00000o`00003ooooonf[o
oookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00
oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[
oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Z
oooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooook
J_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z
003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooook
J^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooo
nf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oo
oo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]Zjooo
nfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oo
oo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[o
oookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00
oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[
oookJP00i?oonfX5o`00O`Gooo]Z1Ol007oooookJ^Cooo]Z1Ol007l5oookJPGo001ooooonfX4oook
JP00hooonfX7o`00O`?ooo]Z1ol007oooookJ^;ooo]Z1ol007l3oookJPOo001ooooonfX3oookJP00
hooonfX3o`00O`;ooo]Z0ol007l2oookJP?o001o00Cooo]Zo`00Ool007oo001ooooonf[RoookJP?o
001o0_oonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007oooookJP?ooo]Z003FoookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX4o`00
0?oooo]Zb_oonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`Kooo]Z1?l0003goookJP00e_oonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`Kooo]Z1_l0003ooookJ/Sooo]Z2_l007l2oookJP?o001o0ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJPKo0000mOoonfX00>;ooo]Z1?l007l2
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z1?l0003ooookJ]Kooo]Z1?l0
07l2oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z1?l0003goookJP00h_oo
nfX8o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX4o`000?oooo]Ze_oonfX8o`00O`;ooo]Z0ol0
07l3oookJP?o001o1_oonfX4o`000?Oooo]Z003RoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`?ooo]Z0ol007l6oookJPCo0000oooonf[FoookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000mooonfX00>;ooo]Z0ol007l7oookJP?o001o0ooo
nfX3o`00O`Kooo]Z1?l0003ooookJ]Kooo]Z0ol007l7oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0
003goookJP00h_oonfX3o`00O`Oooo]Z0ol007l3oookJP?o001o1_oonfX4o`000?oooo]Ze_oonfX3
o`00O`Oooo]Z0ol007l3oookJP?o001o1_oonfX4o`000?Oooo]Z003SoookJP?o001o0_oonfX3o`00
O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPCo0000oooonf[GoookJP?o001o0_oonfX3
o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPCo0000mooonfX00>?ooo]Z1ol007l3
oookJPOo001o1ooonfX4o`000?oooo]ZeooonfX7o`00O`?ooo]Z1ol007l7oookJPCo0000mooonfX0
0>Gooo]Z1?l007l5oookJPGo001o2?oonfX4o`000?oooo]ZfOoonfX4o`00O`Gooo]Z1Ol007l8oook
JPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]Z
kooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003o
oookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo
0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooo
nfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPGo0000oooonf[^oookJPGo0000m_oonfX0
0?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oo
oo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0
003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oook
JPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]Z
kooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003o
oookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo
0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooo
nfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX0
0?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oo
oo]Z003koookJPGo0000oooonf[^oookJPGo0000m_oonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0
003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oook
JPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]Z
kooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003o
oookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo
0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooo
nfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX0
0?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oo
oo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0
003goookJP00nooonfX5o`000?oooo]Zk_oonfX5o`000?Kooo]Z003koookJPCo0000oooonf[_oook
JPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]Z
kooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003o
oookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo
0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooo
nfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX0
0?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oo
oo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00>Oooo]Z0ol007l4oookJPGo001o2?oo
nfX4o`000?oooo]ZfooonfX3o`00O`Cooo]Z1Ol007l8oookJPCo0000mooonfX00>Oooo]Z0ol007l3
oookJPOo001o1ooonfX4o`000?oooo]ZfooonfX3o`00O`?ooo]Z1ol007l7oookJPCo0000mooonfX0
0>Oooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`000?oooo]ZfooonfX3
o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPCo0000mooonfX00=Kooo]Z2_l007l2
oookJPWo001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z1?l0003ooookJ/[ooo]Z2_l0
07l2oookJPWo001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z1?l0003goookJP00e_oo
nfX:o`00O`;ooo]Z2Ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX6o`000?oooo]Z
b?oonfX:o`00O`;ooo]Z2Ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX6o`000?Go
oo]Z003RoookJP;o001o0ooonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX4o`000?oooo]Z
e_oonfX2o`00O`?ooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0003goookJP00hooo
nfX2o`00O`;ooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0003ooookJ]Oooo]Z0_l0
07l2oookJP?o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000mooonfX00>?ooo]Z0ol007l0
1?oonf[o001oo`00Ool007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0003ooookJ]Oooo]Z0ol0
07l01?oonf[o001oo`00Ool007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0003goookJP00i?oo
nfX2o`00O`04oookJ_l007oo001oo`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX4o`000?oooo]Z
f?oonfX2o`00O`04oookJ_l007oo001oo`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX4o`000?Oo
oo]Z003UoookJPGo001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000oooonf[IoookJPGo001o
0_oonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000mooonfX00>Gooo]Z1Ol007l3oookJP?o001o00Co
oo]Zo`00Ool007oo001o1ooonfX4o`000?oooo]ZfOoonfX5o`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l7oookJPCo0000mooonfX00>Kooo]Z1?l007l3oookJPOo001o1ooonfX4o`000?oooo]Z
f_oonfX4o`00O`?ooo]Z1ol007l7oookJPCo0000mooonfX00>Oooo]Z0ol007l4oookJPGo001o2?oo
nfX4o`000?oooo]ZfooonfX3o`00O`Cooo]Z1Ol007l8oookJPCo0000mooonfX00?_ooo]Z1?l0003o
oookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo
0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooo
nfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX0
0?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oo
oo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1Ol0003ooookJ^kooo]Z1Ol0
003foookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oook
JPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]Z
kooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003o
oookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo
0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooo
nfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX0
0?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oo
oo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0
003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPGo0000oooonf[^oook
JPGo0000m_oonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]Z
kooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003o
oookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo
0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooo
nfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX0
0?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oo
oo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0
003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oook
JPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]Z
kooonfX4o`000?Oooo]Z003koookJPGo0000oooonf[^oookJPGo0000m_oonfX00?_ooo]Z1?l0003o
oookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo
0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooo
nfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX0
0?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oo
oo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0
003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oook
JPCo0000mooonfX00>;ooo]Z2Ol007l3oookJPGo001o2?oonfX4o`000?oooo]Ze_oonfX9o`00O`?o
oo]Z1Ol007l8oookJPCo0000mooonfX00>;ooo]Z2Ol007l2oookJPOo001o1ooonfX4o`000?oooo]Z
e_oonfX9o`00O`;ooo]Z1ol007l7oookJPCo0000mooonfX00>;ooo]Z1?l007l7oookJP?o001o00Co
oo]Zo`00Ool007oo001o1ooonfX4o`000?oooo]Ze_oonfX4o`00O`Oooo]Z0ol007l01?oonf[o001o
o`00Ool007l7oookJPCo0000mooonfX00=Kooo]Z2_l007l3oookJPCo001o1OoonfX3o`00O`?ooo]Z
0ol007l6oookJPCo0000oooonf[:oookJP[o001o0ooonfX4o`00O`Gooo]Z0ol007l3oookJP?o001o
1_oonfX4o`000?Oooo]Z003FoookJP[o001o1?oonfX5o`00O`?ooo]Z0ol007l3oookJP?o001o1_oo
nfX6o`000?oooo]Zb?oonfX:o`00O`Cooo]Z1Ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z1_l0
003eoookJP00i_oonfX4o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX4o`000?oooo]Zf_oonfX4
o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX4o`000?Oooo]Z003WoookJP?o001o0_oonfX3o`00
O`?ooo]Z0ol007l6oookJPCo0000oooonf[KoookJP?o001o0_oonfX3o`00O`?ooo]Z0ol007l6oook
JPCo0000mooonfX00>Sooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX4o`00
0?oooo]Zg?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJPCo0000mooonfX0
0>;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z1?l0003o
oookJ]Kooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z1?l0
003goookJP00h_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oo
nfX4o`000?oooo]Ze_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o
1_oonfX4o`000?Oooo]Z003RoookJPCo001o0_oonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00
Ool007l7oookJPCo0000oooonf[FoookJPCo001o0_oonfX3o`00O`;ooo]Z0ol007l01?oonf[o001o
o`00Ool007l7oookJPCo0000mooonfX00>?ooo]Z1ol007l3oookJPOo001o1ooonfX4o`000?oooo]Z
eooonfX7o`00O`?ooo]Z1ol007l7oookJPCo0000mooonfX00>Cooo]Z1Ol007l5oookJPGo001o2?oo
nfX4o`000?oooo]Zf?oonfX5o`00O`Gooo]Z1Ol007l8oookJPCo0000mooonfX00?_ooo]Z1?l0003o
oookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo
0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooo
nfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX0
0?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oo
oo]Z000ZoookJPOo0?l<b_oonfX4o`000?oooo]Z7_oonfX3oomc0<kooo]Z1?l0003goookJP00:_oo
nfX3oon>00Co0?l<1OoUo`35oookJPGo0000oooonfXMoookJP?oohh00oooL`3;oookJPGo0000m_oo
nfX002[ooo]Z0ooo6@04oon>00?oog<00_oUo`35oookJPCo0000oooonfXNoookJP?ooaT01?ooSP03
oomc0<Oooo]Z1?l0003goookJP00:_oonfX2o`3o3003ool0dOoo6@3ooaT000;ooaT01?ooSP000ooo
0<Ooog<0onGo0005onGo00KoolT0^?oonfX4o`000?oooo]Z7_oonfX2o`3oB`03ool0dOoo6@3ooaT0
00;ooaT01OooSP000oooL`3ooo]ZoookJP32oookJPCo0000mooonfX002[ooo]Z0oo70?l01?l0o`co
o`3Aool0dOoo0=43oolI0003ool0^oooSP3oohh000;oohh000Coo`37oomc0?oUo`3oiOl01_oob@2h
oookJPCo0000oooonfXNoookJP?oa`3o0_l0od/2ool0d@?ooaT000?oo`2kof40ooooSP000oooSP02
oomc0;oooo]Z1?l0003goookJP00:_oonfX3o`3o30Coa`3o0ooo0=44oolI0003of40ooooSP3oohh0
00;oohh000?oo`37oomc0?ooL`001_oob@2eoookJPCo0000oooonfXNoookJP?o0?mF1?o70?l00ol0
od_oo`3Aool0d@04oolI00;oH@3o1?ooSP03oomc0;[ooo]Z1?l0003goookJP00:ooonfX01_oob@3o
0?l<o`3o3?l0o`coolT0o`1Qo`Coa`3o00?o0?m;ool0dOoo0=401?oo6@000ol0o`coohh0oon>0002
oon>0005ool0aoooL`3oog<0oomc0?lUo`001_oob@2_oookJPCo0000oooonfXQoookJP?o0?mF00?o
067oolL0ooo70?l00_o70?l00ol0od_oo`3Aool0d@04oolI0003odWo0?mQ0?ooohh000?oohh01?oo
L`2eoookJPCo0000mooonfX002gooo]Z00CoolT0o`3o3?oonf[o07[o0_l0oeH2o`1Qo`?oa`3o0_l0
od/2ool0d@?ooaT000?oo`2kodWo0?ooSP000oooSP02ool0a`WoA?l0ZooonfX4o`000?oooo]Z9?oo
nfX2o`1jo`;o0?mF00Co067oolL0ooo70?ooa`3o0_l0od/2ool0d@?ooaT000?oo`2kodWo0?m9o`00
1?ooSP000ooo0<Ooog<0oomc0002oomc0;3ooo]Z1?l0003goookJP00;_oonfX00ooob@3ooo]Zoook
JP02oookJP03onGo0?oob@3o0?mF00;oiOl01?o70?l2o`3oB`03ool0dOoo6@3ooaT000;ooaT000?o
o`@0odWo0?ooSP000oooSP03ool0a`CoA?l01Ooob@2VoookJPCo0000oooonfXXoookJP;o07[o00?o
0?mFo`1Qooo70?l00oo70?l3o`3oB`CooaT000?oo`@0odWo0?m9o`001?ooSP02ool0a`Coog<0Zooo
nfX4o`000?Oooo]Z000eoookJP?oolT00ooUo`000ooob@3oa`3oolL0o`02olL0o`?o0?m;1?oo6@02
ool400Coohh00ooo0<L3oomc0003obGo0?oob@3ooo]Z09kooo]Z0_oo0005oookJPCo0000oooonfX[
oookJP?o07[o00?o0?mFo`1Qooo70?l00oo70?l3o`3oB`CooaT00_oo10001?m9o`3oohh0oon>0?oo
SP03ool0a`Coog<0YooonfX4o`000?Oooo]Z000goookJP?oolT000?oiOl0ooo90?oob@000ooob@04
olL0o`?oA?l01?oo6@02ool400Coohh01?oo0<L6ooo909Wooo]Z1?oo0003oookJPCo0000oooonfX_
oookJPCo07[o00?o067oolL0ooo70?l00_o70?l3o`3oB`CooaT00_oo1004oon>00Coo`370oooL`2S
oookJPCo0000mooonfX003Wooo]Z00?oolT0oookJ_oonfX01_oob@02o`1Qo`Coa`3o0_m4o`001?oo
0;_ooaT0oolI0?oo6@02ool0d@03ool40?ooSP3oohh000;oohh01?oo0<L2ooo90003oomc0?oob@3o
olT000CoolT0T_oonfX6ool00003oookJ_l0003o000000;o00002?oo0003oookJPCoo`00oooonfXT
oookJP?o07[o0_l0HOl4olL0o`;o0?m;00?oo`2koolI0?oo6@000_oo6@000ooo0=7oo`@0oon>0003
oon>00Coo`371?ooL`2NoookJPCo0000mooonfX003kooo]Z00?oolT0oookJ_oonfX01?oob@03o`1Q
o`Coa`3o0_m4o`04oolI00;oo`3A00?oo`@0oon>0?ooSP000_ooSP04ool0a`?oog<01Ooob@2>oook
JPSoo`0000?o0000ool00?oo00004?oo003ooookJRSooo]Z0ol0N_l2o`1Qo`Coa`3o0_l0od/01?oo
0;_ooaT0oolI0?oo6@02ool0d@03ool40?ooSP3oohh000;oohh01?oo0<L4oomc09[ooo]Z1?l0003g
oookJP00@_oonfX3ooo90005oookJ_oob@3oolT0ool[0?l0HOl00_m4o`03olL0o`03oo?o0?l0od_o
olT000CooaT00_oo0=400ooo103oohh0oon>0002oon>00Goo`370_ooL`000ooob@3ooo]ZoookJP2<
oookJQ_oo`00oooonfX/oookJP;o07[o00?oob/0o`1Qool0HOl00oo70?l00ooco`3o0?m;o`3oB`04
oolI00;oo`3A00?oo`@0oon>0?ooSP000_ooSP05ool0a`?oog<0U_oonfX4o`000?Oooo]Z0014oook
JP04ooo90?oonf[ooo]Zooo900?ooo]Z0om4o`000ol0HOooa`3oolL0o`02olL0o`?oolT00ooo6@04
ool0d@Coohh000?o``3oool0aooo0<L00_oo0<L@oomi07gooo]Z7?oo000=oookJP?oo`00oooonfXO
oookJP;o07[o0_l0oeH4olL0o`03oo?o0?l0od_o0?m;00CooaT00ooo0=45oon>00Coo`370oooL`2B
oookJPCo0000mooonfX004gooo]Z00?oA?l0ooo90?oob@000ol0oeH4olL0o`;oolT000?ooaT0ooo9
0?oob@001Ooob@04oon>0003ooo90?oo0<Ooo`3700;oo`3700?oolT0oomi0?ooN@002OooN@1loook
JPOoo`0000?ooo]Zool00?oo00004ooo000:oookJPOoo`00oooonfXRoookJP04o`1joooo:`3o0?mF
o`3oEPCoa`3o0ol0od/4oolI00?oo`3A00?oo`@0oon>0?ooSP000_ooSP04ool0a`Coog<0SOoonfX4
o`000?Oooo]Z001?oookJP?oolT000Gooo]Zo`3oE_l0oeKo0?mFooo90004olL0o`03o`3oBooob@3o
olT000OoolT01?ooSP000ooob@3oo`37ool0a`02ool0a`OoolT000?oogT0oookJ_oonfX0M?oonfX0
0ooo003ooo]ZoookJP03oookJPKoo`000_oonfXEool000Sooo]Z2Ooo003ooookJRKooo]Z00Co07[o
o`3oE_l0oeKo0?mF1?o70?l3o`3oB`CooaT00ooo0=400ooo103oohh0oon>0002oon>00Coo`371Ooo
L`28oookJPCo0000mooonfX0057ooo]Z00?oolT0oookJ_oonfX00_oonfX2o`3oEP?oolT01?o70?l:
ooo900Coohh000?oolT0ool0aooo0<L00ooo0<L2ooo900GoogT00ooonfX8oomi05oooo]Z0_oo0006
oookJP;oo`000ooonfX7ool000;ooo]Z5Ooo0007oookJP[oo`00oooonfXYoookJP05o`1jool0oeKo
0?mFo`3oE_oo:`001?o70?l3o`3oB`CooaT00ooo0=400ooo103oohh0oon>0002oon>00Goo`371Ooo
L`23oookJPCo0000mooonfX005Wooo]Z1?l0oeH2ooo900Coa`3o1ooob@03ool0d@Goohh000?oolT0
ool0aooo0<L00_oo0<L2oomi00;oog<03?ooN@1LoookJP?oo`001OoonfX3ool000?ooo]Z1ooo0000
0ooonf[oo`00ool0000Dool000Kooo]Z3?oo003ooookJRcooo]Z1?l0oeH00ol0NOooa`3oolL0o`03
olL0o`;o0?m;1?oo6@03ool0d@03ool40?ooSP3oohh000?oohh01?oo0<L00olUo`3oog<0oomc0002
oomc07oooo]Z1?l0003goookJP00FooonfX2ooo900?o0?mF0ooob@04olL0o`KoolT01?oo0=400ooo
103oohh0oon>0002oon>0003ol<0oooo0<Ooo`3700?oo`370oooL`08oomi05_ooo]Z1Ooo0003oook
JRGoo`001?oonfX>ool00?oooo]Z;ooonfX00ol0N_oo0?mFo`3oEP02o`3oEP03o`1iool0HOooa`3o
00?oa`3o0_l0od/4oolI00?oo`3A0_oo1004oon>00Goo`371?ooL`1coookJP03oomg0?oonf[ooo]Z
00Gooo]Z1Ol0003foookJP00GOoonfX01ooob@3ooo]ZoookJ_oonf[o0?mFooo90?l0oeH00ooob@04
olL0o`CoolT00_oo6@000ooo0=7oogT0oomi0002oomi00Goohh000?oogT0ool0aooo0<L00_oo0<L2
oomi00;oog<000?oolT0oomi0?ooN@00F_oonfX6ool000;ooo]Z3_oo0002oookJP?oo`002?oo:00;
ool000?ooo]Z3ooo003ooookJS?ooo]Z00?o07[oo`3oE_l0oeH00_l0oeH2o`1Qo`Coa`3o0_l0od/4
oolI00?oo`3A0_oo1005oon>00Coo`371?ooL`1_oookJP03oomg0?oonf[ooo]Z00Gooo]Z1?l0000<
oookJP03ool04ooonf[ooo]Z0>Sooo]Z001ToookJP03o`1jool0oeKoolT000;oolT00_l0HOl4olL0
o`;oolT01Ooo6@05oomi00Goohh01?oo0<L5ooo900?oogT0E?oonfXGool00003oolX0?oo003oo`00
00;oo`002?oo:007ool000?oobP000Coo`00oookJ_oonf[ooo]Z3ooo003ooookJSKooo]Z00?o07[o
ool[0?l0oeH00ol0oeH2o`1Qo`Coa`3o00?o0?m;o`3o@Ooo6@000ooo6@02ool0d@;oo`@00_m9o`05
oon>00?oo`371?ooL`02obGo06Sooo]Z00?oogL0oookJ_oonfX01_oonfX4o`000005o`3oa?oonf[o
oo]Zool0C_oi0?l01ooonfX00ooo01?ooo]ZoookJP0?oookJP03oaCo0?oonf[ooo]Z0=Kooo]Z001X
oookJP07ooo90?l0oeKoiOl0o`3oE_l0HOooiOl0o`1Qo`03olL0o`;oolT000?o0?m1oomi0?oo6@00
0ooo6@06oomi00Goohh00_oo0<L2ooo900?oog<00_lUo`1AoookJQgoo`002?oo:004ool000KoobP0
00?oo`00oookJ_oonfX00_oonfX?ool00?oooo]Z>OoonfX00ol0N_ooob/0o`3oEP02o`3oEP?o067o
0oo70?l2o`3oB`03o`3odooo6@3ooaT000?ooaT000?oo`3Aool40?oo10000_m9o`000ol0odWoohh0
oon>0003oon>00;oo`371?ooL`03obGo06?ooo]Z00?oogL0oookJ_oonfX01_oonfX4o`000005o`3o
a?oonf[ooo]Zool0C_oi0?l01OoonfX00ol0obCooo]Zool04`0AoookJP03oaCo0?mY0?oood/00=Ko
oo]Z001[oookJP05o`1joooo:`3o0?mFo`3oE_l0HOl00_oob@04olL0o`CoogT01Ooo6@02oomi0004
ool40?oob@3oolT0ooo900Goohh000?oo`37onGo0?ooL`001?ooL`04oomi04Wooo]Z7_oo0007oolX
00?oo`002?oo:0000ooo003ooo]ZoookJP03oookJPkoo`00oooonfXloookJP03o`1joooo:`3oob/0
00;o0?mF0ol0HOl4olL0o`;o0?m;00?o0?oBo`26oooo6@000ooo6@03ool400;oBOl000?o0?m9o`3o
YoooSP001?ooSP000ooo0<Ooog<0oomc0003oomc00?o9Ol0G_oonfX00oooM`3ooo]ZoookJP06oook
JPCo000000Go0?o4o`3o?_oonf[oo`1>ooT0o`05oookJP05o`3o9?oonf[oo`0CoookJ_l0om`04?oo
nfX00olDo`3ood/0oookJP3EoookJP00K_oonfX2o`1jo`03ool[0?l0oeKoolT000?o067o1?o70?l5
oomi00CooaT00ooo1003ooo90003oomi0?ooSP3oohh001SoogT0=ooonfX00ooo:03oo`00ool0000N
ool000OoobP00ooo000:oolX00?ooo]Z3ooo003ooookJSoooo]Z0_l0N_l2ool[00;o0?mF0ol0HOl3
olL0o`?o0?m;00?o0?oBo`26oooo6@000ooo6@03ool400;oBOl000?o0?lCo`3oNooVo`001OooSP00
0oooX@3oog<0oomc0003oomc00?o9Ol0F?oonfX00oooM`3ooo]ZoookJP07oookJP09o`000?lA0?oo
0000o`000?l0olCo0?lnoookJ_oo04kon@3o00Gooo]Z00Go0?lToookJ_oo02coo`0Co`3og00@oook
JP03oaCo0?mY0?oood/00=Gooo]Z001aoookJP?o07[o0_l0oeH3o`1Qo`04oomi0?o70?ooa`3oolL0
o`CoogT000?oolT0oomi0?oo6@000ooo6@03ool400;oBOl04OooN@02obGo00SoogT0<OoonfX3oolX
00coo`000_oo:00Dool000GoobP00_oo000<oolX00;ooo]Z4Ooo003ooookJT7ooo]Z0ol0N_l00ooo
:`3o0?mFo`3oEP03o`1Qo`?oa`3o1?l0od/00ol0om;oo`3AoolI0003oolI00?oo`@00om9o`000ol0
oa?oi_l0onKo0005oon>0003oonQ0?ooL`3oog<000?oog<01OlUo`0noookJP;o9Ol01_oonfX00ooo
X@3ooo40oookJP06oookJP03o`3oYooonf[oogL000Wooo]Z00Wo0000oa40ool0003o0000o`3oa?l0
ockooo]Zool0C_oi0?l00_oonfX01?oo06?ooo]ZoookJ_l0ob@2oookJP03ool04ol0omcooo]Z00[o
oo]Z00?oo`00oookJ_mg0?l00_oonfX00olDo`3oJ@3ooom;003EoookJP00M?oonfX3o`1jo`03ool[
0?l0oeKo0?mF00?oogT000?oa`3ooomi0?ooN@003_ooN@02odWo00googT01OooL`09oomi02[ooo]Z
1?oo:00<ool000CoobP05Ooo000BoolX0003oookJ_oo003oo`00013oo`00oooonfY4oookJP?o07[o
0_oo:`02o`3oEP;o067o1?o70?l4o`3oB`03o`3od_oo0=7ooaT000?ooaT00ooo1004odWo0003o`3o
4ooVo`3oi_l000Goohh000?ooj40oomc0?ooL`001OooL`04obGo03Gooo]Z0olUo`07oookJP03oonQ
0?oonf[ooo]Z00Oooo]Z00?o0?nWoomg0?oonfX02OoonfX02Ol0003o4@3oo`000?l0003o0?o4o`3o
?_oonf[oo`1>ooT0o`02oookJP08ool0Hol0og3ooo]ZoookJ_l0obCooo]Zool04ol0om`;oookJP03
ool00?oonf[oM`3o00?ooo]Z00?o5?l0ofT0ooooB`00e?oonfX007Oooo]Z1?ooN@000ooo:`3oogT0
oomi000@oomi00Coo`@02_ooN@000oooSP3oogT0oomi000<oomi02Oooo]Z1_oo:00<ool000KoobP0
2Ooo00000ooo:03oo`00ool00006ool001;oobP00_oo00000ooonf[oo`00ool0000>ool000;oobP0
oooonfY7oookJPCo07[o00?oob/0o`3oE_l0oeH00ol0HOl4olL0o`Co0?m;00?o0?oBool0dOoo6@00
0ooo6@04ool400CoBOl00_oVo`000oo30?ooohh0oon>0002oon>0004ool0aoooX@3ooj40oonQ00Ko
og<00olUo`0^oookJP03obGo0?ooL`3oog<000Sooo]Z00?ooj40oookJ_oonfX00_oo0<L5oookJP03
o`3oYooonf[oogL000[ooo]Z00Wo4@3oo`000?l0003o0000o`3oa?l0ockooo]Zool0C_oi0?l00_oo
nfX02Ooo06?o0?m`oookJ_oonf[o0?lToookJ_oo01?ooo]Zo`3og00;oookJP03ool00?oonf[oM`3o
00;ooo]Z00?o5?l0ofT0ooooB`00e?oonfX007Wooo]Z5OooN@04oolI0003of40oooo103oogT000So
ogT01?ooSP0:oomi00;oog<01_ooN@0KoookJP[oobP02_oo0007oolX00Goo`0000?oobP0ool00?oo
00001?oo:003ool00003oolX0?oo003oo`0001;oobP00ooo0002oookJPkoo`001?oo:0000ooonf[o
obP0oookJP3ooookJTOooo]Z0ol0N_l00ooo:`3o0?mFo`3oEP04o`1Qo`Coa`3o0ol0od/00ol0om;o
o`3Aool0d@04oolI00Goo`@00om9o`000ol60?ooi_l0onKo0004oon>00?oo`370oooX@05oomc00Ko
9Ol08ooonfX01?lUo`3oog<0oomc0?ooL`08oookJP;ooj4000?ooo]Zool0aooo0<L01OoonfX01?oo
00_o0?nWoookJ_ooM`0;oookJP09oa40ool0003o0000o`000?l0olCo0?lnoookJ_oo04kon@3o00;o
oo]Z00Woo`1So`3oL?oonf[ooo]Zo`3o9?oonf[oo`0CoookJ_l0om`02ooonfX00ooo003ooo]ZogL0
o`02oookJP04oaCo0?mY0?oooo]Zoom;0=?ooo]Z001koookJQ;oogT000Go0?m;oomi0?ooN@3oogT0
ool0d@04oolI00_oogT01?ooSP05oomi0003ool0aoooN@3oogT000Soog<02?lUo`0>oookJPgoobP0
1Ooo000:oolX00Ooo`001_oo:004ool00003oolX0?oo003oobP000SoobP000?oo`00oolX0?oo:000
1Ooo:00Cool00003oookJ_oo:03oobP000GoobP0oooonfY;oookJP?o07[o00Cooo]Zool[0?l0oeKo
0?mF1?l0HOl4olL0o`;o0?m;0_l0om82ool0d@GooaT01?oo1003odWo0003o`H0oooVo`3oi_l000Co
ohh01Ooo0<L2oonQ00Soog<02?lUo`0EoookJP03obGo0?ooL`3oog<000;oog<02?oonfX3oonQ0003
oookJ_oo0<Ooo`3700Cooo]Z0_o30?l01?oVo`3o0?nWoookJ_ooM`0<oookJP09oa40ool0003o0000
o`000?l0olCo0?lnoookJ_oo04kon@3o00;ooo]Z00Woo`1SoookJ_l0og3ooo]Zo`3o9?oonf[oo`0C
oookJ_l0om`03?oonfX00ooo003ooo]ZogL0o`02oookJP03oaCo0?mY0?oood/00=?ooo]Z001loook
JQ;oogT00_o70?l4oomi0004o`3od_oo0=7oo`3AoolI00?oogT000?ooaT0ool40?oo10000_oo1005
oomi00Goohh000?oogT0ool0aooo0<L00ooo0<L5oomi01Coog<07Ooo:009ool000GoobP00ooo000:
oolX00?oo`001_oo:00Dool000WoobP0oooonfY=oookJP?o07[o00?ooo]Zool[0?l0oeH00_l0oeH3
o`1Qo`03o`1iooo70?ooa`3o00;oa`3o00Co0?m;o`3od_l0om;o0?oB0ooo0=44oolI00Coo`@00om9
o`000ol60?ooaOl0onKo0005oon>00Goo`3700?ooo40oonQ0?ooX@000_ooX@0Noomc00Wooo]Z0ooo
X@001?ool@3ooo]Zool0aooo0<L4oookJP;o``3o00Gooo]ZonKo0?oonf[ooo]Zoomg000=oookJP09
ool10?l0003o0000o`3oa?oonf[o0?lnoookJ_oo04kon@3o00;ooo]Z00Goo`1SoookJ_l0og3ooo]Z
o`3o9002oookJP03ool04ol0omcooo]Z00cooo]Z00Soo`00oookJ_mg0?oooo]ZoaCo0?mY0?oooo]Z
oom;0=;ooo]Z001noookJQ;oogT00oo70?l3oomi0003o`3od_ooN@3oogT000;oogT000?oo`3AoolI
0?oo6@000_oo6@03ool400OoogT01OooSP000oooN@3oo`37ool0a`05ool0a`CoogT000?ooj40oomi
0?oonfX03ooonfXIoolX00Woo`001?oo:003ool000[oobP01Ooo0004oolX01?oo`002ooo:03ooook
JU3ooo]Z0ol0N_l00ooonf[oob/0o`3oEP02o`3oEPCo067o00Koo`0golL0ooo70?ooa`3oo`3oBol0
od42o`3odP;o08Ko0_oo0=44oolI00Coo`@00om9o`001?l60?ooaOl0olGo0?oVo`05oon>00Soo`37
1OooX@0JoookJPGooj400_ool@000oooXP3oo`37ool0a`04oookJP;o``3o00Cooo]Zool02ooVo`3o
oo]Z0_ooM`03oookJP03oe@0oooonf[ooo]Z00Sooo]Z00Goo`40o`000?l0003o0?o4o`3o?P02oook
JP07ool0C_oi0?oooo]ZoookJ_oo06?ooo]Zo`3oL002oookJP05o`3o9?oonf[oo`0CoookJ_l0om`0
2OoonfX01_l0o`Kooo]ZoookJ_oo003ooo]ZogL0o`;ooo]Z00?o5?l0ofT0ooooB`00d_oonfX0083o
oo]Z4_ooN@000ol0HOooa`3oolL0o`02olL0o`;olol01OooN@02ool0d@?ooaT000?oH@3oool40?oo
10000oooN@02odWo00?oolT000?oaOl0oon>0?ooSP001_ooSP09ool0a`OoogT02_oonfX00oooX@3o
obP0oolX0005oolX0003oooa0?oo:03oobP000[oobP02Ooo0003oolX00?oo`001_oo:0000ooo003o
obP0ool00002oolX00Goo`001Ooo:00Bool000coobP0oooonfYBoookJP?o07[o0_oonfX3o`3oEP03
oookJ_l0HOoo067o00;o067o0oo70?l00ol0od_olol0o`3odP02o`3odP;o08Ko0_oo0=43oolI0003
ool0^ooo103oo`@000;oo`@00om9o`04olGo0003onKo0?ooSP3oohh000Koohh02?oo0<L5oonQ00co
oo]Z1_ooX@001?oonf[ooo40oooa0?ool@02oonR00;oo`371OoonfX00oo30?oooo]Zool02`02onKo
0003oookJ_ooM`3ooo]Z00?ooo]Z00?oE03oool0KOoo06d02?oonfX01_oo0@3o0000o`000?l0003o
0?o4o`3o?P;ooo]Z00Ooo`1>ooT0oooonf[ooo]Zool0Hooonf[o0?m`00;ooo]Z00Go0?lToookJ_oo
01?ooo]Zo`3og009oookJP07o`3o1_oonf[ooo]ZoookJ_oo003ooo]ZogL0o`02oookJP03oaCo0?oo
nf[ood/00=7ooo]Z0022oookJPooogT000?o0?mFoomi0?oob@000ol0HOl3olL0o`03o`3oBoooN@3o
ogT000GoogT000Ooo`3AoolI0?oo6@3ooaT0ool0^omQ0?ooogT000?oo`@00_m9o`001?l0oa?o1P3o
olGo0?o5o`05ooo900Ooohh00_ooN@08ool0a`Wooj401_ool@02oolX00;oo`372ooo:00:ool000;o
obP00_oo000=oolX00Goo`0000?oobP0ool00?oo00000_oo:00Bool000_oobP0oooonfYEoookJP?o
07[o0_oonfX3o`3oEP03ool[0?l0NOoo067o00;o067o0oo70?l3o`3oB`03oo?o0?l0om;oo`d000;o
08Ko00Coo`3AoolI0?oo6@3ooaT00_oo0;/4ool400;oBOl000Ko0?lCo`H0ooo5o`3oaOl0ool0KOl]
0?l3onKo0003ol<0ooooSP3oohh000Coohh00_ool@08ool0a`Wooj401oool@02oookJP?oo`371Ooo
nfX01_o30?ooohh0oon>0?oo00_oi_l0o`3oY`;oogL01?oonfX00omD0?ooo`1]oookJP05oookJP05
o`3oNooonf[ooo]ZoookJ_oo0@000ol000001_l0olCo0?lnoookJ_oonf[oo`1>ooT0o`?ooo]Z00Wo
k@3oo`3oL?oonf[ooo]Zo`3o9?oonf[oo`0CoookJ_l0om`02_oonfX01_l0o`Kooo]ZoookJ_oo003o
oo]ZogL0o`;ooo]Z00Co5?l0ofT0oooonf[ood/0d?oonfX008?ooo]Z0oooN@02oookJP03oomi0?oo
nf[oogT000OoogT00ol0oeH2oomi00?o067o1?o70?l5oomi00?oolT00ooo6@02ool0^`04of40oooo
103oo`@0ool400?oBOl00ol60?l2ooo900CoogT00_oVo`000oo30?ooohh0oon>0002oon>00?o``3o
0oooN@0Aool0a`goobP01Ooo000@oolX02?oo`002ooo:03ooookJUOooo]Z0ol0N_l2oookJP?o0?mF
00?oob/0o`1iool0HOl00_l0HOl4olL0o`?o0?m;0_l0om800ooo3@3o08Koo`26o`03oolI0003ool0
dOoo0;_oH@3o00?oo`@01?m9o`02o`H0o`06o`3oBOoo06goo`1]obd0ooooM`3o0?nW0ooVo`04oon>
00Co``3o0_oonfXBool0a`Kooo]Z00?o``3ooon>0?ooSP000ooVo`000ol0ojOoogL0oookJP04oook
JP03oe@0oooo06gooo]Z00?ooo]Z00Co0?m9odWo0?oonf[o0?mk0ooonfX01_oo0@3o0000o`000?l0
003o0?o4o`3o?P;ooo]Z00?oo`1>ooT0oooonfX00_oonfX02_o]0?oooo]Zo`3oL?oonf[o0?lTo`3o
3?oonf[oo`0CoookJ_l0om`9oookJP07o`3o1_l0olgooo]ZoookJ_oo003ooo]ZogL0o`02oookJP04
oaCo0?mY0?oooo]Zoom;0<oooo]Z000XoookJPGo001o1OoonfX5o`00Oc_ooo]Z0ol007l4oookJPGo
001o1ooonfX00oooN@3ooo]ZoookJP04oookJPWoogT00ol0oeH2oomi00?o067o00KoogT0olL0ooo7
0?ooa`3ooomi0?l0od/2oomi00CoolT01?oo6@02ool0^`03ool40?m4o`3oA?l000koA?l00_ooN@06
oon>00Co``3o2oooN@000oo30?ooobP0oolX000<oolX0003oomg0?oo:03oo`0001GoobP04ooo0000
0ooo:03oo`00ool0000:ool000_oobP04?oonfX9o`00O`?ooo]Z1Ol007lkoookJP?o001o1?oonfX5
o`00OcOooo]Z1Ol007l5oookJPGo001oA?oonfX5o`00O`Gooo]Z1Ol007ljoookJP?o001o1?oonfX5
o`00Oa;ooo]Z0ol0N_l2oookJPCo0?mF00Go07Woo`1Qool0HOoo067oool0=`03olL0o`?o0?m;0ol0
om800ooo0?Wo08KooolI0003oolI0003ool0dOoo0;_oo`@000Coo`@01?m9o`001ol60?ooaOl0olGo
0?o5o`3o;@3ooe@0ooooM`000_l0ojL00ooVo`3oohh0oon>0004oon>00Go``3o2ooonfX2ol<0o`Oo
ohh00_oVo`001?l0ojOo04Cooomg0?ooM`05oookJP03oe@0oooo06gooo]Z00Cooo]Z00?oBOl0oook
J_l0og/00ooonfX00ooo0@3ooo]Zo`000002o`000006o`3oa?l0ockooo]ZoookJ_oo04kon@3o0ooo
nfX02_o]0?oooo]Zo`3oL?oonf[o0?lTo`3o3?oonf[oo`0CoookJ_l0om`:oookJP04o`3ocOoonf[o
oo]Zool000;ooo]Z00CoM`3ooookJ_oonf[o5?l00_oonfX00oooB`3ooo]ZoookJP0@oookJPWo001o
0ooonfX5o`00Oc[ooo]Z0ol007l4oookJPGo001o>?oonfX5o`00O`Gooo]Z1Ol007lNoookJP009ooo
nfX7o`00O`?ooo]Z1ol007ljoookJP?o001o0ooonfX7o`00O`kooo]Z00?oogT0oookJ_ooN@001ooo
N@000ooonf[o0?mFo`3oEP03oomi00?o067o00CoogT0olL0ooo70?ooa`3o0_l0od/7ooo900GooaT0
3_m4o`02olGo00?oogT00_oVo`000oooN@3oohh0oon>000<oon>01;oobP01Ooo000@oolX01Coo`00
00?oobP0ool00?oo00002ooo000;oolX00oooo]Z2Ol007l2oookJPOo001o>_oonfX3o`00O`?ooo]Z
1ol007leoookJPOo001o0ooonfX7o`00Od;ooo]Z1ol007l3oookJPOo001o>OoonfX3o`00O`?ooo]Z
1ol007lDoookJP?o07[o0ooonfX3o`3oEP05o`1iool0HOoo067oo`1Qoooo03L00oo70?l3o`3oB`Co
0?oB00?oo`1jo`26oooo6@001?oo6@02of40o`Goo`@01Om9o`04olGo00;oE03o00CoH03oonKo0?oV
o`3oi_l04_ooSP000ooo00_oi_l0onKo0002onKo0003o`3oYol0A?ooogL000?oogL01OoonfX00omD
0?ooo`1]ool0K@03oookJP03o`H0oooonf[oBOl000;ooo]Z00Ko0?mkoookJ_oonf[ooo]Zool10?oo
nfX3o`000006o`3oa?l0ockooo]ZoookJ_oo04kon@3o0ooonfX00ooo06?ok@3oo`3oL002oookJP06
o`3o3?oonf[oo`0/ool04ooonf[o0?oL2OoonfX01ol0o`Ko0?o=oookJ_oonf[oo`00oookJ_mg0?l0
0_oonfX01OlDo`3oJ@3ooookJ_oonf[ood/0017ooo]Z2Ol007l2oookJPOo001o>OoonfX3o`00O`?o
oo]Z1ol007lfoookJPOo001o0ooonfX7o`00Oagooo]Z000WoookJP?o001o0_oonfX3o`00O`;ooo]Z
0ol007l01?oonf[o001oo`00Ool007ljoookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00
Oa?ooo]Z1OooN@02o`1jo`;ooo]Z00?o0?mFoomi0?ooN@000_l0NOl2o`1Qo`;oogT00oo70?l00ol0
od_oolT0ooo90003ooo900;oogT000?o08Koooo90?oo0=401?oo6@0:odCo00CoBOl03OooN@0:onKo
00_oobP01_oo000AoolX00Koo`0000?oobP0ool00?oo00002?oo00000ooo01?oo`00oolX0002oolX
00_oo`003?oo:00?oookJPCo001o1ooonfX3o`00O`04oookJ_l007oo001oo`00Oc[ooo]Z0ol007l3
oookJP?o001o00Cooo]Zo`00Ool007oo001o=OoonfX3o`00O`;ooo]Z0ol007l2oookJP?o001o00Co
oo]Zo`00Ool007oo001o@_oonfX3o`00O`;ooo]Z0ol007l2oookJP?o001o00Cooo]Zo`00Ool007oo
001o>OoonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007lGoookJP?o07[o0ooonfX3o`3o
EP05o`1iool0HOoo067oo`1Qoooo0>`00oo70?l3o`3oB`03o`3o@Ol0om;o0?oB00;o0?oB0_l0Q_l0
0ooo0=7ooaT0oolI0002oolI0003ooT0oomQ0?ooH@3o00Coo`@000?o0?lCodWo0?m9o`001?m9o`02
olGo0007ool0KOl]0?ooE03ooe@0oomP0?oooo]Zo`14o`04oomg00[oi_l000?o0?nWo`14ooooM`00
0oooM`02oookJP?oH03o1?mD0?l00ooo06gooo]ZoookJP02oookJP03o`H0oooonf[oBOl000;ooo]Z
00?o0?mkoookJ_oonfX00_oonfX00ooo0@3ooo]Zo`000002o`000006o`3oa?l0ockooo]ZoookJ_oT
o`3oo`1>1?oonfX02_o]0?oo0?m`oookJ_oonf[o0?lTo`3o3?oonf[oo`0CoookJ_l0om`:oookJP04
o`3o1_l0olgooo]Zool000;ooo]Z00CoM`3ooookJ_oonf[o5?l00_oonfX00oooB`3ooo]ZoookJP0?
oookJPCo001o1ooonfX3o`00O`04oookJ_l007oo001oo`00OcWooo]Z0ol007l3oookJP?o001o00Co
oo]Zo`00Ool007oo001o=_oonfX3o`00O`;ooo]Z0ol007l2oookJP?o001o00Cooo]Zo`00Ool007oo
001o7OoonfX001[ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007lXoookJP[o001o0_oonfX9o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007lDoook
JP?oogT00_oonfX3o`1jo`03oookJ_ooN@3o0?mF00;o0?mF00Co07Woo`1Qool0HOoo067o0_ooN@02
olL0o`03o`3oBooob@3oolT000;oogT000Co0?oBoomi0?ooN@3oogT00_oob@02ool0d@?ooaT01om4
o`001?oo103o0?lCo`3o4ol0oa<3odWo00googT01Ooo:002oomi00_oobP01?oo000DoolX00Goo`00
00?oobP0ool00?oo00002Ooo0004oolX00;oo`0000?oobP0ool00?oo00001Ooo000>oolX00oooo]Z
1?l007l5oookJP?o001o0ooonfX3o`00OcCooo]Z2Ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o<ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o=?oonfX:o`00
O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00ObOooo]Z2_l007l2
oookJPWo001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00OaWooo]Z0ol0N_l2oookJP05ool[0?l0
oeKo0?mFoookJ_l0NOl00_l0HOl2ool0k0;oa`3o00Koo`0go`3oBol0od_o0?m;o`3o@Ol0om<3o`3o
dP04o`3oTol0Q_ooo`3Aool0d@?ooaT00_oi0?l2of40o`Coo`@00ol0oa<4odWo00Co1P3o0_oo06d2
oe@0o`?oH03o2_ooM`02oookJPCoH03o0omD0?l2oookJP;oo`1]0ooonfX2o`H0o`05o`3oBOm9o`3o
oo]ZoookJ_l0og/01?oonfX00ooo0@3ooo]ZoookJP02o`000003oom90?l0olCo0?ln00;ooo]Z00?o
i?l0ool0C_oonfX00ooonfX02oo]0?oooo]Zo`3oL?oonf[o0?lTo`3o3?oonf[oo`0/ool04ol0omco
3@3o00Kooo]Z00Soo`/0oookJ_oonf[o0?l6oookJ_l0olgooo]Zool000;ooo]Z00CoM`3ooookJ_oo
nf[o5?l00_oonfX00oooB`3ooo]ZoookJP0?oookJPCo001o1OoonfX3o`00O`?ooo]Z0ol007lcoook
JPWo001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00OcCooo]Z0ol007l3oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00Oacooo]Z000JoookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o:?oonfX:o`00O`;ooo]Z2Ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o5OoonfX00oooN@3ooo]ZoookJP04oookJP?o07[o00Oooo]Zool[0?l0oeKo
0?mFoomi0?l0NOoo067o00?oogT00oo70?l3o`3oB`03oo?o0?l0om?oogT000;oogT000GoolT0oomi
0?ooN@3oogT0ool0d@03oolI00?oA?l00_mQ0?l4ool400;o0?lC1_m9o`02oomi00;o1P3o1Ooob@00
0ooo:03oogT0oomi0006oomi00GoobP01Ooo000FoolX00?oo`000ooo:009ool000KoobP000?oo`00
oolX0?oonfX01Ooo000?oolX013ooo]Z1Ol007l3oookJP?o001o0ooonfX3o`00OcCooo]Z2Ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o<ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o=?oonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00ObOooo]Z2_l007l2oookJPWo001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
Oacooo]Z0ol0N_l00ooonf[oob/0o`3oEP02o`3oEP05oookJ_l0HOoo067oo`00Oooo0>`00oo70?l0
1?oo03Oo0?m;o`3oBol0od/2o`3od`?o0?oB00Co001oo`26ool0Q_ooo`3A0ooo6@000ooo0=7on@3o
ooT0o`02of40o`Coo`@00ol0oa<5odWo00Go1P3o0_oo06d?oe@0o`;ooo]Z0ooo06d2oookJP?o1P3o
00?ooo]Zo`3oBOm9o`000ooonfX01_l0og_ooo]ZoookJ_oonf[o0?nnool100;ooo]Z0_l000000ooo
B@3o0?o4o`3o?P02oookJP03onCo0?oo04kooo]Z00?ooo]Z00?ok@3ooookJ_l0og000_oonfX01_l0
o`cooo]Zool0;?oo01?ooo]Zo`d0o`Kooo]Z00Soo`/0oookJ_oonf[ooo]Zo`3o1_oonf[o0?o=ool0
00;ooo]Z00GoM`3ooookJ_oonf[ooo]ZoaCo0002oookJP03oom;0?oonf[ooo]Z00oooo]Z1Ol007l3
oookJP?o001o0ooonfX3o`00Oc?ooo]Z2Ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o=?oo
nfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o7?oonfX002Kooo]Z1?l0
07l2oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00OcCooo]Z0_l007l3oookJP?o001o
0_oonfX3o`00O`?ooo]Z0ol007lOoookJP?o07[o00?ooo]Zo`3oE_l0oeH00_ooN@000ol0HOooogT0
oomi0002oomi00;oa`3o00GoogT0o`3oBol0od_o0?m;oo?o0007oomi00;oA?l00ooo6@001?oi0?oo
U?l0oiCo0?nDo`02of40o`?oo`@000GoogT0o`3o4ol0oa?o0?lCoomi0002odWo013oogT01Ooo:003
ool00003o`H0oooo:03oobP000?oobP000CoBOl0oolX0?oo:03o0?mk1_oo:0000ooo0@3oobP0oolX
0006oolX0003ool00?oo:03oobP000;oobP01Ooo00000ooo:03oo`00ool0000:oolX0004ool00?oo
nf[oo`00ool0017oobP04OoonfX4o`00O`;ooo]Z0ol007l3oookJP?o001o=?oonfX2o`00O`?ooo]Z
0ol007l2oookJP?o001o0ooonfX3o`00Oc?ooo]Z1?l007l2oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00Od3ooo]Z1?l007l2oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
Oc?ooo]Z0_l007l3oookJP?o001o0_oonfX3o`00O`?ooo]Z0ol007lOoookJP?o07[o00Gooo]Zool[
0?l0oeKo0?mFoookJP03o`1Qo`03oookJ_oo0>coa`3o00;oa`3o00Coo`0go`3oBol0od_o0?m;0_l0
om<3o`3odP04ool0nOl0Q_oo08Koo`26o`?ooaT000Coo`3AooT0oooi0?oon@3o0_mQ0?l3ool40003
o`3oa?oo0@3o0?lC00;o0?lC1_m9o`05o`H0o`_oaOl00_oo06d2oookJP?o1P3o0_oonfX00ol0odWo
BOl0odWo0002oookJP;o0?mk1?oonfX01?l0okkoo`40oookJ_oonfX2o`000003o`3oa?l0003o0?ln
00;ooo]Z00?oi?l0ool0C_oonfX00ooonfX00ooo06?ok@3oo`3oL002oookJP09o`3o9?l0o`cooo]Z
ool0;?oo01?o0?oLo`d0oooonf[oo`2=00Cooo]Z00Soo`/0oookJ_oonf[ooo]Zo`3o1_l0olgooo]Z
ool000;ooo]Z00GoM`3ooookJ_oonf[ooo]ZoaCo0002oookJP03oom;0?oonf[ooo]Z013ooo]Z1?l0
07l2oookJP?o001o0ooonfX3o`00Oc?ooo]Z0_l007l3oookJP?o001o0_oonfX3o`00O`?ooo]Z0ol0
07ldoookJPCo001o0_oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007lLoookJP009_oo
nfX8o`00O`;ooo]Z0ol007l3oookJP?o001o=OoonfX2o`00O`;ooo]Z0ol007l2oookJP?o001o0ooo
nfX3o`00Ob;ooo]Z0_l0N_l01_oonf[o0?mFo`3oE_l0oeKoogT0o`1Qo`?oogT000Go0?liolL0ooo7
0?ooa`3ooomi0003o`3oB`OoogT00om4o`04oolI00?oU?l000?oH@3ooomi0?oo10000ooo100Coomi
00CoobP01?l60?l3ool000?oBOl000?oobP0o`3oNol0og/01_oo:0001?oo0@3oobP0oolX0?oo:002
oomi00[oobP01?oo00000ooo:03oo`00oolX000;oolX0003ool00?oo:03oobP000koobP000?o5?l0
oolX0?oo:0004_oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o=OoonfX2o`00O`;ooo]Z0ol007l2
oookJP?o001o0ooonfX3o`00Oc?ooo]Z2?l007l2oookJP?o001o0ooonfX3o`00Od3ooo]Z2?l007l2
oookJP?o001o0ooonfX3o`00OcCooo]Z0_l007l2oookJP?o001o0_oonfX3o`00O`?ooo]Z0ol007lR
oookJP?o07[o00?oob/0o`3oE_l0oeH00_oonfX3o`1Qo`03oookJ_oo0>coa`3o00;oa`3o00Cooo]Z
o`3oBol0od_o0?m;0_l0om<3o`3odP04ool80?l0Q_oo08Koo`26o`CooaT01?oi0?l00omQ0?ooo`@0
ool40002ool40003o`3oa?l0oa?o0?lC00;o0?lC00?o0?mko`3oBOm9o`001Om9o`0>o`H0o`?ooo]Z
00?o0?m9odWo0?m9o`000_oonfX2o`3oN`;ooo]Z0_oo0=X00ooonf[oo`40ool10003oookJP;o0000
00?o0?o4o`000?l0och00_oonfX00ooTo`3oo`1>ooT0o`04oookJP03o`3oHol0og3ooo]Z00;ooo]Z
00So0?l<oookJ_oo02coo`0CoookJ_l=0?oooo]Zool0S@Gooo]Z00Soo`/0oookJ_oonf[oold0oook
J_l0olgooo]Zool000;ooo]Z00GoM`3ooookJ_oonf[ooo]ZoaCo0002oookJP03oom;0?oonf[ooo]Z
013ooo]Z0ol007l2oookJP?o001o0ooonfX3o`00OcCooo]Z0_l007l2oookJP?o001o0_oonfX3o`00
O`?ooo]Z0ol007ldoookJPSo001o0_oonfX3o`00O`?ooo]Z0ol007lLoookJP009_oonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l3oookJP?o001o=OoonfX3o`00O`04oookJ_l007oo001o
o`00O`;ooo]Z0ol007l3oookJP?o001o9?oonfX2o`1jo`06oookJ_ooN@3o0?mFo`3oE_oo:`3oogT0
0ol0HOl00ooonf[oogT0olL0o`02olL0o`04oomi0?l0od_o0?m;o`3oB`KoogT000KoA?l0o`26ool0
Q_ooo`2kool0dOoo6@09oomi00;oo`@04?ooN@0;odWo00?oo`002?oo:0000ooo0@3oobP0oomi0004
oomi00_oobP00_oo0004oolX0003ool00?oo:03oobP000SoobP00_oo000:oolX00;ooo]Z00OoobP0
oookJ_oonf[oobP0oaCo0?oonf[oobP001;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o=OoonfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z0ol007l3oookJP?o001o<ooonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l3oookJP?o001o@?oonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l3oookJP?o001o=?oonfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z
0ol007l3oookJP?o001o9OoonfX2o`1jo`04oookJ_l0oeKo0?mFool[00;ooo]Z0ol0HOl00olN0?oo
o`3/olL0o`02olL0o`04oookJ_l0od_o0?m;o`3o@@;o0?oC0ol0om801Ooo203o08Koo`26ool0Q_oo
o`2k00CooaT01?oi0?l01_mQ0?ooo`@0ool40?oo103o0?o4o`3o_PKo0?lC0_l0og/BodWo0005oook
J_l0og_o0?mko`3oNooonfX00_l06ol01Ooo0=[ooo]ZoookJ_oo0@3o0?nn00Cooo]Z00Go0000oom9
0?l0olCo0000o`3o?P03oookJP03ool0C_oi0?oooo]Z00?ooo]Z00?o0?mSoookJ_l0og000_oonfX0
2Ol0obCo0?l<oookJ_oo02coo`0Co`3og?l=0?oooo]Zool0S@05oookJP08ool;0?oonf[ooo]Zooo=
0?l0o`Ko0?o=oookJ_oo0002oookJP08ogL0oooonf[ooo]ZoookJ_lDo`3oJ@3ooookJ_ooB`0Boook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00OcCooo]Z0ol007l01?oonf[o001oo`00Ool0
07l2oookJP?o001o0ooonfX3o`00OcCooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o
0ooonfX3o`00Oacooo]Z000VoookJP?o001o1ooonfX3o`00O`?ooo]Z0ol007lfoookJP;o001o00Co
oo]Zo`00Ool007oo001o0_oonfX3o`00O`?ooo]Z0ol007lVoookJP?o07[o00KoogT0o`3oE_l0oeKo
0?mFool[0?oonfX3o`1Qo`03o`3o>OooN@3oa`3o00;oa`3o00?oogT0o`3oBol0od/01OooN@02ooo9
00?o08Ko00?oU?l0ool0dOooN@005oooN@05oolX00[oo`000_ooN@04oolX00WoogT02ooo:0000ooo
003oobP0oolX000?oolX00;oo`002_oo:0000ooo003ooo]ZoolX0003oookJP03oaCo0?oonf[ood/0
00_ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00OcKooo]Z0_l007l0
1?oonf[o001oo`00Ool007l2oookJP?o001o0ooonfX3o`00Oc?ooo]Z0ol007l7oookJP?o001o0ooo
nfX3o`00Od3ooo]Z0ol007l7oookJP?o001o0ooonfX3o`00OcGooo]Z0_l007l01?oonf[o001oo`00
Ool007l2oookJP?o001o0ooonfX3o`00ObOooo]Z0ol0N_l3o`3oEP03ool[0?oonf[ooo]Z00?o067o
00?o7P3oool0=oo70?l00_o70?l2o`3oB`04oo?o0?l0od7o0?oCo`3od`?o0?oB00Koo`P0o`26ool0
Q_oo08Koool0^ooo0=43oolI00Con@3o00?oH@3oool40?oo10000ooo10000ol0olCo0?nno`3o_P05
o`3o4`Co01_o3?l0og/2oookJP;o01_o00Ooo`3JoookJ_oonf[ooo]Zo`3o__oo0@3o4@3o00Cooo]Z
00Go0000oom90?l0olCo0000o`3o?P03oookJP03ool0C_oi0?oooo]Z00?ooo]Z00?oo`1So`3oHol0
og000ooonfX02Ol0o`cooo]ZoonD0?oo01?ooo]Zo`3og?l=0?oooo]Zool0S@05oookJP07ool;0?oo
nf[ooo]Zooo=0?l0o`Ko0?o=oookJP02ool00003oookJ_mg0?ooM`3o00;ooo]Z00Co5?l0ofT0oooo
nf[ood/02ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o=OoonfX2
o`00O`04oookJ_l007oo001oo`00O`;ooo]Z0ol007l3oookJP?o001o=?oonfX3o`00O`Oooo]Z0ol0
07l3oookJP?o001o7?oonfX002Kooo]Z0ol007l7oookJP?o001o0ooonfX3o`00OcOooo]Z1Ol007l2
oookJP?o001o0ooonfX3o`00ObWooo]Z0_l0N_l2oookJP;o0?mF00?oob/0oookJ_l0NOl00ol0HOl0
0olN0?ooo`0golL0o`02olL0o`?o0?m;1?ooN@000ooob@3oogT0oomi0002o`26o`03oiCo0?ooN@3o
ogT000_oogT01Ooo1005oomi00GoobP02_oo0002oomi0003oolX0?ooN@3oogT000[oogT07_oo:000
0ooo003oobP0oolX0008oolX0004oookJ_oo003ooo]ZogL0o`?ooo]Z00?o5?l0ool0]_ooB`002_oo
nfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o=ooonfX5o`00O`;ooo]Z
0ol007l3oookJP?o001o<ooonfX3o`00O`Oooo]Z0ol007l3oookJP?o001o@?oonfX3o`00O`Oooo]Z
0ol007l3oookJP?o001o=_oonfX5o`00O`;ooo]Z0ol007l3oookJP?o001o:_oonfX2o`1jo`04oook
J_l0oeKo0?mFo`3oEP;ooo]Z00Ko07Woo`1Qool0HOoo067oool0k?oo03L3olL0o`;o0?m;00Co0?m1
oom20?l0om?o0?oC1?l0om83o`26o`03onoo0?oo0=7ooaT000?ooaT01?oi0?l2of40o`Goo`@000?o
0?o4o`3o__l0okh01_l0oa<<o`0Ko`03ool0f_oonf[ooo]Z00;ooo]Z0_oo0@000olA0?oo0Ol0oook
JP03oookJP06o`000?l0olCo0000o`000?l0ocko08Co0_oonfX00ooo04kon@3ooookJP04oookJP03
o`3oHooonf[o0?m`00;ooo]Z00[o0?lTo`3o3?ooU03ooo]Zool04ooonf[o0?oLo`d0oooonf[oo`2=
1OoonfX01_oo2`3ooo]ZoookJ_ooc@3o0?l6o`3oc@;ooo]Z00Coo`00oookJ_oonf[oM`3o0_oonfX0
1?lDo`3oJ@3ooookJ_ooB`0:oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007lfoookJPGo001o0_oonfX3o`00O`?ooo]Z0ol007ldoookJP?o001o1ooonfX3o`00O`?ooo]Z
0ol007lLoookJP009ooonfX3o`00O`;ooo]Z0ol007l2oookJP?o001o00Cooo]Zo`00Ool007oo001o
>?oonfX5o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l/oookJP;o07[o0_oonfX3o`3oEP03
oookJ_l007oo07Wo00;o067o0_lN0?l01?oo03Ooa`3oolL0ooo70?l2o`3oB`GoogT000Go0?oCo`3o
d_l0om;o0?oBoiCo000;oomi0003oolX0?ooN@3oogT000;oH@3o1?oo10000oooN@3oobP0oolX0002
oolX00_oo`003oooN@04oolX0003ool00?oo:03oobP000GoobP000?oogT0oolX0?oo:0004?oo:000
0ooo003oobP0oolX0008oolX0004oookJ_oo003ooo]ZogL0o`?ooo]Z00?o5?l0ool0]_ooB`002Ooo
nfX4o`00O`;ooo]Z0ol007l2oookJP?o001o00Cooo]Zo`00Ool007oo001o>?oonfX5o`00O`?ooo]Z
0ol007l01?oonf[o001oo`00Ool007leoookJP?o001o0_oonfX3o`00O`;ooo]Z0ol007l01?oonf[o
001oo`00Ool007m2oookJP?o001o0_oonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007lg
oookJPGo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00Obgooo]Z0_l0N_l2oookJP?o0?mF00?o
001oo`1iool0NOl00_l0HOl00olN0?ooo`0gool0=`02olL0o`;o0?m;0_l0od42oom200;o0?oC0ol0
om83o`26o`03onoo0?oo0=7oo`3A00?ooaT00ooi0?l2ool0P`?oH@3o1Ooo1002o`3o_POoo`401?oo
0=X2oigo00;ooo]Z00Co0?nnool10?oo0@3oo`400_lA0?l00ol1o`3ooo]ZoookJP03oookJP06oom9
0?l0olCo0000odKo0?l0ocko08Co0_oonfX00ooo04kon@3ooookJP04oookJP04o`3oHoo]0?oooo]Z
ool0T@;ooo]Z00[oX_l0o`3o3?ooU03oo`0Co`1joooonf[o0?oLo`d0oooonf[oo`2=1OoonfX01_oo
2`3ooo]ZoookJ_ooc@3o0?l6o`3oc@;ooo]Z00Coo`00oookJ_oonf[oM`3o0_oonfX01?lDo`3oJ@3o
oookJ_ooB`09oookJPCo001o0_oonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007lgoook
JPGo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00OcKooo]Z0ol007l2oookJP?o001o0_oonfX3
o`00O`04oookJ_l007oo001oo`00Oagooo]Z000WoookJPOo001o0ooonfX7o`00OcWooo]Z1?l007l3
oookJPOo001o;_oonfX2o`1jo`?ooo]Z0_l0oeH00ooo:`3o001oo`1io`03o`1Qo`03oah0oooo03Oo
o`0g00;oa`3o0_l0od/01?oco`3oogT0oomi0?ooN@03o`3od`;o0?oB2OooN@0:oolX00Coo`@000?o
obP0ool00?oo00002?oo000<oomi00;oo`000_ooN@04oolX00;oo`0000?oogT0oolX0?oo:0001?oo
:0000oooN@3oobP0oolX000?oolX00;oo`002_oo:0001?oonf[oo`00oookJ_mg0?l3oookJP;o5?l0
00?ood/0oookJ_oonfX01ooonfX7o`00O`?ooo]Z1ol007lioookJPCo001o0ooonfX7o`00OcGooo]Z
1ol007l3oookJPOo001o@_oonfX7o`00O`?ooo]Z1ol007lhoookJPCo001o0ooonfX7o`00Oboooo]Z
0_l0N_l3oookJP;o0?mF0_l007l01?l0NOoo067oo`1Qool0HOl2ool0=`;oa`3o0_l0od/00ooco`3o
0?m1o`3o@@02oom200;o0?oC0ol0om82o`26o`;okol00_oo0=43oolI00?on@3o00?oJ`3oool0PomQ
0?l00omQ0?l00ol01_ooo`@0ool40002ool40005ool;0?lA0?oo4@3ooa40ool0okh02Ooo0@001?lA
0?oo0Ol0o`7o0?l1o`07oookJP06oom90?l0olCo0000odKo0?l0ocko08Co0_oonfX01OoTo`3oo`1>
ooT0oooonf[ooiX000?ooo]Z013o0?mSond0oooo097oo`2LoookJ_nRo`3o0?l<oookJ_ooU03oo`0C
o`1joooonf[o3@3ooookJ_n10?ooo`2=1OoonfX01_oo2`3ooo]Zooo=0?oonf[o0?l6o`3oc@;ooo]Z
00Coo`00oookJ_oonf[oM`3o0_oonfX2oaCo0003oookJ_ooB`3ooo]Z00Sooo]Z1ol007l3oookJPOo
001o>?oonfX4o`00O`?ooo]Z1ol007lfoookJPOo001o0ooonfX7o`00Oagooo]Z000YoookJPCo001o
1OoonfX5o`00Oc_ooo]Z0ol007l4oookJPGo001o<OoonfX2o`1jo`?ooo]Z0_l0oeH01?oo:`3o001o
o`00Ool0NOl2o`1Qo`03oah0oooo0>coo`0g00;oa`3o0ol0od/2o`3o@@;oogT00_l0om<2o`3odPOo
ogT00ooo6@06oolX00CoH@3o00?oobP0ool40?nDo`003onDo`06oomi00?oo`0000Co0?o4oomi0?oo
:03oobP00_oo0004oomi00CoobP000?oogT0oolX0?oo:0002Ooo:0000ooo01?oobP0oolX0004oolX
00;oo`002Ooo:002oookJP;oo`0000OoM`3ooookJ_oonf[ooo]ZofT0oolDo`3ood/000Wooo]Z1Ol0
07l5oookJPGo001o>ooonfX3o`00O`Cooo]Z1Ol007lhoookJPCo001o1OoonfX5o`00OdGooo]Z1?l0
07l5oookJPGo001o>_oonfX3o`00O`Cooo]Z1Ol007lboookJP;o07[o0ooonfX2o`3oEP04ool[0?l0
07oo07Woo`1io`;o067o00Coo`3/ool0=oo70?ooa`3o0ol0od/00ooco`3o0?m1oom20002oom200;o
0?oC0_l0om82o`26o`?okol00_oo0=43oolI00Con@3o0_oo08<4of40o`05o`06oooo103oo`@0ool4
0?l0ol@01Ooo2`04oooh00;o0Ol02_oonfX03OooB@3o0?o4o`000?m6o`3o0?lnoookJ_l0Q?oooo]Z
onCo0?oo04kon@3ooookJ_ooVP000ooonfX02_oo06?o0?mSoookJ_oo097o0?nnoookJ_nb0?oo0?l<
oookJ_ooU002ool04`05oookJ_l=0?oooo]Zoh40oooo08d01OoonfX00ooo2`3ooo]Zooo=0002oook
JP03o`3ocOoonf[ooo]Z00;oo`0000?ooo]ZogL0oooonfX00_oonfX00olDo`3oJ@3ooom;0009oook
JPGo001o1OoonfX5o`00Oc[ooo]Z0ol007l4oookJPGo001o>OoonfX4o`00O`Gooo]Z1Ol007lNoook
JP00/OoonfX2o`1jo`?ooo]Z0ol0oeH2oookJP03o`1iool0HOoo067o00;o7P3o00CoogT0olL0ooo7
0?ooogT00_l0od/3o`3o@@03oomi0?l0om?o0?oC00;o0?oB1OooN@03oolX00;ooaT01?oo:002ooT0
o`;oolT01?mQ0?l>oiCo00CoiOl000CoogT0ool00?oo003oo`000_oo:0000ooo003oobP0oolX0002
ool000GoogT01?oo:0000oooN@3oobP0oolX0009oolX0003ool04ooo003oobP000CoobP00_oo0009
oolX00?ooo]Z00?oo`00ogL0oomg0?l00ooonfX00olDo`3ood/0oom;003ooookJW7ooo]Z0_l0N_l3
oookJP;o0?mF00Coob/0oookJ_l0NOoo07Wo0_l0HOl01OlN0?ooo`3/olL0ooo70?oooo]Z00?o0?m;
0_l0od42oom200;o0?oC0_l0om83o`26o`;okol000?oo`1jool0dOoo0=400_oo6@05ooT0o`;oo`23
00GoobD0of40oomQ0?ooH@3oo`06o`04ool40003o`06ooo0o`3oo`/000Goo`/02OoonfX02?ooB@3o
0?o4o`000?l0003oo`@0o`3o?_oonf[o08Co0_oonfX01?oTo`3oo`1>ooT0oooonfX2oonJ00;ooo]Z
00Ooo`1So`3oHooonf[oo`2Aool0W?nb0?ooX_l000;o0?l<00Wooi@0ool0;?oo01?ooo]Zo`d0oooo
nf[oP@3oool0SOooE`001?oonfX00ooo2`3ooo]Zooo=0002oookJP06o`3ocOoonf[ooo]ZoookJ_oo
003ooo]Z0_mg0?l2oookJP04oaCo0?mY0?oood/0oom;0<7ooo]Z002coookJP;o07[o1?oonfX2o`3o
EP?ooo]Z0_l0HOl00ol0NOooogT0oomi0002olL0o`04oomi0?l0od_o0?m;oo?o00;o0?m100?ood80
o`3odol0om<00_l0om82oomi0003o`26oooo:03oobP000?oobP00ooo6@001Ooo003oogT0oomi0?oo
N@3on@3o00?oogT000?oA?l0of40oomQ0?l03?nDo`04onGo00Coo`000ooo:0000ooo003oobP0ooo9
0008oomi00[oobP00_ooN@03oolX0004ool04ooo003oobP0o`d0o`;oobP00_oo000:oolX0006o`3o
cOoonf[ooo]Zool00?oonf[oM`3o0ooonfX01?lDo`3oJ@3ooom;0?ooB`3ooookJW7ooo]Z00?o07[o
oookJ_oonfX00_oonfX2o`3oEP?ooo]Z00Go07Woo`1Qool0HOoo7P3oo`3o>@02olL0o`;ooo]Z0_l0
od/01?oco`3o0?m1oom20?oo@P02o`3od`;o0?oB00Cooo]Zo`26ool0Q_oo08Ko0_o_o`001?oo07[o
o`3AoolI0?oo6@05ooT0o`04of/0oooo08?oo`23oookJPCoH@3o00?o097oool40?oo10000_oo1000
0ol0olCoodT0ol3o0003ol3o00Kooo]Z00WoodT0o`3oa?l0olCo0000ool40?m6o`3o0?lnoookJ_l0
Q?l00_oonfX01?oTo`3ooo]Zool0C_m60?l2oookJP0<oonJ0?oonf[ooo]Zool0Hol0of?ooo]Zool0
TOoo09co/P3oo`3o9?nRo`3o0?l<0_ooU0001ooo01?ooo]Zo`d0ool=0?ooP@3oool0SOooE`001?oo
nfX00ooo2`3ooo]Zooo=0002oookJP;o0?o=0_oonfX01?oo003ooo]ZoookJ_mg0?l2oookJP03oaCo
0?mY0?oooo]Z00;ood/0_ooonfX00;Gooo]Z0_l0N_l4oookJP;o0?mF0ooonfX2o`1Qo`03o`1ioooo
N@3oogT000;oa`3o00CoogT0o`3oBol0od_o0?m;0_l0od401?oo@P3o0?oCo`3odol0om83oomi00Oo
obP00_oo6@06ool00005oomi0?oo08?oA?l0odCo0?mQ0?l02_nDo`04onGo00?oo`001_oo:0000ooo
003oogT0oomi0004oomi00Coo`002Ooo:003oomi00;oobP00_oo01<01?oo003o3@3ooolX0?oo:002
oomi00[oobP000Go0?o=oookJ_oonf[oo`00oookJP02ogL0o`;ooo]Z00?o5?l0ofT0oooonfX00_oo
B`3ooookJW3ooo]Z0_l0N_l4oookJP;o0?mF1?oonfX01?l0HOoo07Wooah0ool0ocT3olL0o`05oook
J_l0od_o0?m;oo?o0?l0od400_oo@P02o`3od`04o`3od_oo0?Wooo]ZoookJP;o08Ko0_o_o`001Ooo
07[oo`3AoolI0?oo6@3oU_l000Gon@3o1?oo08<00ooo9@3oH@3oof40o`02oolU0003o`2boooo103o
o`@000;oo`@00_l0ol@6oom900;o0?o40_l000001Ooo103o2`3oo`3o?_oo0=oo08Co00?ooo]Z00?o
i?l0oookJ_oo04h00_oonfX02OooVP3ooo]ZoookJ_oonf[oo`1So`3oHoo]0?ooo`2Ao`3o_P02ok80
o`05oj;o0?l0o`cooo]ZoonD0?oo01<00_oonfX01?l=0?oo0?Woool0SOooE`04oookJP;oo`/00_oo
c@000ooonf[o0?l6o`3oc@02oookJP03ool00?oonf[ooo]Z00;oM`3o00?ooo]ZoaCo0?mY0?l00_oo
nfX00oooB`3ooo]ZoookJP2loookJP00]ooonfX2o`1jo`Cooo]Z00?o0?mFoookJ_oonfX00_oonfX2
o`1Qo`03o`1ioolN0?ooo`0g00;oa`3o0_ooN@02o`3oB`;o0?m100?ood80o`3odol0om<00_l0om82
oomi00GoobP00_oo0002oolI00Soo`000_ooN@000om4o`3oU?l0oiCo0005oiCo00?oo`@00_oUo`03
ool000SoobP00_ooN@07ooo900;oobP000?oo`00oolX0?oo:0001Ooo:003oomi00?oobP000?oo`0C
oolX0?l=0?l01?ooN@0:oolX0004o`3ocOoonf[ooo]Zool000;ooo]Z00?oM`3ooookJ_oonfX00_lD
o`001?oo0;Kooo]Zoom;0?ooB`3ooookJW3ooo]Z0_l0N_l4oookJP03o`3oE_oo:`3ooo]Z00;ooo]Z
0_l0HOl01?l0NOoo7P3oo`3o>Ooo03L2olL0o`05oookJ_l0od_o0?m;oo?o0?l0od400_oo@P001?l0
om?o0?oBo`3od_oo0?T2oookJP?o08Ko0_o_o`001?oo0=7ooaT0oolI0?nFo`02ooT0o`05odSo0?oi
0?oon@3oooT0oomho`000ooo08<3of40o`04oolU0?lco`3o01coo`06o`Coo`@01Ol0ol@02Ooonf[o
0000o`000?oo103o2`3oo`3o?_lio`3oo`3Oo`24o`03oookJP05onCo0?oo04koAP3oodH0oooonfX0
0_ooVP02oookJP0@ool0Hol0of?ok@3oool0TOl0okkooo]Zok80oonRo`3o0?l<oookJ_ooU03oo`0C
o`1joooonf[o3@3oo`3io`;oo`2=00?oog/0oookJ_oonfX00_oonfX01Ooo2`3ooo]Zooo=0?ooc@3o
oo]Z00;o0?o=00?ooo]Zool00?oonfX00_oonfX01_mg0?oooo]ZoaCo0?lDo`3oo`2foookJP;ood/0
_?oonfX00;Wooo]Z0_l0N_l3oookJP;o0?mF1?oonfX2o`1Qo`;o7P3o00GoogT0olL0ooo70?oooo]Z
oomi0002oolX00;o0?m100?ood80o`3odol0om<00_l0om801Ooo0?WoogT0oolX0?oo:03o08Ko00Co
o`000_oo6@06ool00003oolX0?ooN@3oogT000;oogT01OnDo`04oolX0003onGo0?oo003oo`0000[o
obP00_oUo`06ooo900;oobP00_ooVP02ool000CoobP000Coo`2Aoomi0?ooN@3oogT00_oo:0000ooo
U03oo`0CoolX0002o`d0o`?oogT000?oo`2=oolX0?oo:0000_oo:0000ooo2`3ooo]ZoolX0002oolX
0003o`3ocOoonf[ooo]Z00;oo`0000?ooo]ZogL0oomg0?l00_oonfX01?lDo`3oJ@3ooookJ_oonfX2
oom;0?oooo]ZL?oonfX2o`1jo`?ooo]Z0_l0oeH4oookJP;o067o0_lN0?l01Ooo0>coo`0golL0ooo7
0?oooo]Z00;o0?m;00Golol0o`3o@Ooo@P3ood80o`3od`02o`3odP;oo`3i00Coo`P0oookJ_l0Q_oo
08Ko0_o_o`001Ooo07[ooaT0oolI0?nFo`3on@3o00;oB?l000KoJ`3oooT0oom[0?ooE_l0oookJ_oo
08<2oookJP;oH@3o0_lco`02o`0Lo`;o0;;o1?oo10002?l0obcooo]Zo`3o;?l0obcoo`@0o`/0ool0
ocko>Ol00_oo0=l02?l0Q?oooo]ZoookJ_oonf[oi?l0ool0C_l0oggoAP3o0_oonfX01?ooVP3ooo]Z
oookJ_oo06<2o`3oH`;oo`2A00Co0?m`ok80oonb0?oo0?l<0_oonfX00ooo01?o07[ooookJP02o`d0
o`04o`3ioooo08goo`2=oomk00?ooo]Z00?oo`/0oookJ_oonfX00_ooc@000ol0o`Ko0?o=oookJP02
ool000;ooo]Z0_mg0?l00ooonf[o5?l0ofT0o`02oookJP;ood/0^_oonfX002Sooo]ZTol00002o`1j
o`?o00000_l0oeH4o`0000;o067o0_lN0?l01?oo03Ooa`3oolL0ooooN@04oolX0005o`3o@Ooo@P3o
0?oCo`3odol0om800_oo0?T2oolX0003o`26oooo:03oo`0000?oo`000_oo6@03ool000;oobP01Ooo
N@001?oo:03oU?l0oiCo0?nDo`04oolX00?oo`003?oo:006ooo90005oolX0?ooN@3oogT0oolX0?oo
VP001?ooN@02oolX0003ool0TOooN@3oogT000;oogT000?oobP0oonD0?oo01<00_ooN@02o`d0o`;o
ogT00_oo08d3oolX0005ool;0?l0003o0000o`000?oo:0000_l0old2o`000003ool00?l0003o0000
00;oM`3o00Co0000oaCo0?lDo`3oJ@3o0_l000000oooB`3o0000o`00002Co`0004Sooo]ZTol00002
o`1jo`?o00000_l0oeH4o`0000;o067o00Go0000oah0oooo0>coo`0golL0o`02o`0000;o0?m;0_l0
od42oom20004o`3odol0om;o0?oBool0n@;oo`P000Ko0000o`26ool0oi?okol0ool0N_oo0;/2oolI
00;on@3o00Cok`3oodSo0?oi0?oon@3o0_mFo`001_oo08?o0000o`000?l0003oH@3oo`2Ao`;o<ol0
00?oo`1do`0Lool0/_l00_l0/_l6ool40004o`000?l0ocko0?lnocWo00;oo`3O00Oo08Coo`000?l0
003o0000onCo0?oo04ko0?mm00;oAP3o00Co0000oonJ0?mAo`3oDOl00_oo06<01_l0of?o0000ool0
TOl0og3o0000ok80o`;o0?l<00?o0000ool04ooo01<00_l00002o`d0o`03o`3ioooo08goo`2=00?o
000000Coo`/0o`000?l0003o00000_ooc@02o`3oc@03o`000?oo003oo`0000;o00000_mg0?l2oaCo
0004ofT0ool0003o0000oom;09Ko00008ooonfX002Sooo]ZUOl00002o`1jo`?o000000?o0?mFool[
0?l000000ol000001ol0HOoo07Wooah0oolN0?ooo`0golL0ool000001_oo:0001Ooo@P3oobP0o`3o
d_l0om;oo`3i00;oobP000?o08KooolX0?oo00001?oo0002oolI0003ool00?oo:03oogT000KoogT0
0_oo:0000onDo`3oobP0oolX000CoolX00CoolT000?oobP0oomi0?ooN@000_ooN@02oonJ00[oogT0
00?oobP0oomi0?ooN@000oooN@02o`d0o`04oomi0?oo:03oo`2=ool0S@;oobP00_oo2`03o`000004
ooo=0?l0olgo0?o=o`3oc@;oo`000_l000001?mg0?oo0000o`000?lDo`02ofT0o`03o`000?ooB`3o
od/009?o0000B?oonfZEo`0000;o07[o0ol000000ol0oeKoob/0o`000003o`000005o`1Qool0NOoo
0000oah0oooo0>`00_o70?l2o`0000;o0?m;0_l0od400ooo@P3o0?oCo`3od`02o`3odP09ool0nOoo
203oo`P0o`26ool0oi?okol0o`000?oo07[oo`2k00;ooaT000Con@3oo`000?m8o`3oB?l00_oi0?l0
0omho`3oo`23ool0P`02o`000003of40ool0TOoo0?l[00;o<ol000?oo`1do`0LoolB0?l00_l0/_l2
o`0000;o00Ko0_oo03d01_l0ocko>Ol0ocWo0?lio`3oo`3Oo`24o`?o000000Coi?l0ool0C_l0oggo
0?mm0_m60?l2oonJ00;oDOl000?o0000o`3oHol0of<00_oo09400ol0og3ooed0ok80o`02o`3o3005
oonD0?oo01?oo`0Co`000?l0om`00_l=0?l00ol0nOooo`2=ool0S@02o`0000;oo`/00ol000001_oo
c@3o0?l6o`3ocOl0olgo0000ool000?o000000KoM`3oo`000?lDo`3o5?l0ofT0ool00002oom;09Co
00008ooonfX002Sooo]ZUol00002o`1jo`;o00000_l0oeH4o`0000;o067o00?o0000oah0oooo0>`0
0_o70?l9oolX00?o0?oB00?oobP0o`26ool0Q_l01_oo00001?oo6@3oobP0ool00?oo0002oomi00;o
obP00oooN@0GoolX00CoolT01_ooN@03oonJ00ooogT00_l=0?l00oooN@3oobP0ool0S@02oolX0003
oomi0?oo2`3oo`/000;o00000_ooc@001?l0o`Ko0?o=o`3ocOoo0002o`0000;oM`3o00?o0000oaCo
0?oo0;H00_mY0?l00ol0003ood/0oom;002Ao`0004Sooo]ZUol00002o`1jo`;o00000_l0oeH4o`00
00;o067o00Ko0000o`3o>Ooo0>coo`3/olL0oooo03L2o`0000;o0?m;00?o0?m1oom20?oo@P000_l0
om<2o`3odP;o00000_l0Q_l01_o_o`3o0000ool0N_oo04Woo`2koolI00;on@3o00Kok`3oodSo0?m[
0?oon@3oogSo0?mFo`02ool0P`;o00000_l0TOl01_l0003o<ol0ool0M?l0003o01coooT0o`?o0000
00?o00Koool0?Ol000000_oo03d00ol0ocko>Ol0ool0<`02ool0<`;o08Co0_l000001?oTo`3oo`1>
o`3oOOl0ogd2odH0o`?ooiX00_l000001?l0of?o0000ool0TOoo0942oomM0004ok80ool0o`co0?l<
oonD00;oo`0C0_l0om`2o`d0o`03oomG0?oo08gooeL000;o00000_oo2`02o`0000;oold000?o0?l6
o`3ocOl0old00_oo0002o`0000;oM`3o00Go0000oaCo0?mY0?ooJ@3oo`000002oom;09;o00008ooo
nfX002Sooo]ZVOl000001?l0N_oo0000o`000?l00002o`3oEPCo000000?o067oo`000?lN0?l03_oo
:0001Ol0om;oobP0oolX0?l0Q_ooobP000Coo`0000?oobP0oolI0?oo00001?oo0003oolX00;oogT0
2?oo:003ool000CoiOl02?oo:002ool0<`[oogT000?ooiX0oomi0?ooN@001?ooN@000ol0okkoogT0
oomi0007oomi0003o`d0ooooN@3oobP000;oo`2=00?oobP0oomi0?l000000_oo2`02o`000003ooo=
0?l0o`Ko000000;o0?o=00?oo`00o`000?l000000_mg0?l2oaCo0005ool0]_mY0?ooJ@3oo`000?oo
B`00T?l00018oookJYWo000000Co07[oo`000?l0003o00000_l0oeH4o`0000;o067o00?o0000oah0
oooo0>`00_o70?l2o`000004oo?o0?l0od_o0?m1o`3o@@;ood8000Oo0?oCool0[?l0om;o0?oBo`00
0?oo203o08Ko00;o0?nC0_oo07X01ooo04WooaT0o`3[oooi0?ook`3oodSo0?l000000_oi0?l00omF
o`3o0000ool0P`03o`000007o`2Aool0003o<ol0ool0M?l0003o01coooT0o`02o`000003o`06ool0
003o0?l`00Co0?l`0_oo=0002Ooo0<7oo`0cool0<ooo03?oobT0o`24ool0003oi?l0ool0CP02o`3o
O@03ooT0oom60?ooQ03o00;ooiX000CoDOl0o`3oHol0of?o0?mS0_oo09400ol0okkooed0ok80o`02
o`3o3007oonD0?oo01?oo`0Cool04ol0omco3@3oo`3io`02ool0S@;ooeL000?o0000ool;0?oo2`00
0_l000000oooc@3o0?l6o`000002o`3oc@;oo`000_l00002ogL0o`;o5?l00_mY0?l00ol0003ood/0
o`00002@o`0002?ooo]Z0032oookJP;o07[o0ooonfX00ol0oeKoob/0oookJP02oookJP03o`1Qoooo
nf[ooo]Z00koobP000Go0?oBoolX0?oo:03o08KooolX0003ool00003oolX0?oo6@3oo`0000Ooo`00
0oooN@06oolX00Koo`001OoUo`06ooo90003oolX0?ooN@3oogT001[oogT00ol=0?l01_ooN@3oo`2=
ool0SOooE`3oogT0oookJP;oo`/000Gooo]Zooo=0?ooc@3o0?l6oookJP02o`3oc@;oo`0000?ooo]Z
ogL0oomg0?l00_lDo`000ooo0;KoJ@3ooookJP02oom;0?oooo]ZLOoonfX2o`1jo`?ooo]Z00?o0?mF
ool[0?oonfX00ooonfX00ol0HOoooo]Zo`3o>@02ool0k00NolL0oooonf[ooo]ZoookJ_l0od_ooo]Z
o`3o@Ooonf[ood80o`3odooo0:cooo]Zo`3od_oonf[oo`P0o`26oooonf[o0?nCoookJ_oo07[oo`19
oolI0?oo3@3on@3oonl0oom8o`3ooo]Zof/0oooi0?ooE_l01OoonfX01?l0TOoo<ol0ool0M?oonfX2
o`0Lo`;o000000?o00Koo`3o<?l0oc000ooonfX4onSo00?oo`311?oo03<00ooo:@3o0?nIo`3oV@03
o`3oO@03ooT0oon40?oooiX000?oDOl00_l0of<01Ooo097o0?nno`3o__l0okko/P3o00;o0?l<0_oo
U002ool04`;o3@3o00?o0?Woool0SOoo08d00_ooE`001?oonf[oo`/0ool;0?oonfX2ooo=0004o`3o
1_oonf[o0?o=o`3oc@?oo`0000?ooo]ZogL0oomg0?l00_lDo`02ofT0o`;ood/0/_oonfX00<Cooo]Z
00Co07[ooookJ_oonf[ooo]Z0_l0oeH3oookJP03o`1Qoooonf[ooo]Z00koobP000?o0?oBoolX0?oo
:0000_oo:0001Ooo003oobP0oolX0?oo003ooaT000Soo`0000?oogT0oolX0?oo:0001Ooo:003ool0
00GoobP00_oUo`04oolX00?oolT000?oobP0oomi0?ooN@004_ooN@000ooo097oogT0oomi0008oomi
00?o3@3o0_oo08d00oooE`3ooo]ZoookJP03ool;00?oold000?ooo]Zo`3ocOoonfX00ooo0002ogL0
o`?o5?l000CoJ@3ooookJ_ooB`3ood/0oooonfYaoookJP;o07[o0_oonfX2o`3oEPCooo]Z00Ko067o
oookJ_oonf[o7P3oool0k?o70?l3oookJP0;o`3oBooco`3o0?m1oookJ_oo@P3o0?oCool0[?oo08Ko
0?oBoookJ_oo20000_l0Q_l03Ol0oi?ooo]Zool0N_oo04WooaT0oookJ_oi0?ook`3oodSo0?oonf[o
n@3ooookJ_mFo`001OoonfX01Ol0TOoo<ol0ool0M?oonf[o01co00?o000000?o0?l`oookJ_oonfX0
0_oXo`03oookJP?o1@3o1?mN0?l00ooo0<7oo`0cool0<`03ool0<`04o`3oVOl0oggo0?mmo`3oO@?o
oiX00omAo`04ool0T@06o`3o__ooG@3o0?l<o`3o3?oo02cooi@00_oo01<3o`d0o`;oo`2=0_ooE`00
1?oonf[oo`/0ool;0?oo2`03ooo=0004oookJ_l0olgooo]ZoookJP;oo`0000?ooo]ZogL0oomg0?l0
0_lDo`02ofT0o`;ood/0/?oonfX00<Gooo]Z00?o07[ooookJ_oonfX00_oonfX01Ol0oeKooo]Zoook
J_oonf[o067o013oobP000?o0?oBoolX0?oo:0001?oo:002ool000;oobP01_oo00000oooN@3oobP0
oolX0005oolX00?oo`003Ooo:0000ooob@3oobP0oomi000Eoomi0004ool0TOooN@3oogT0o`3o_PSo
ogT00_l=0?l2ool0S@04oomG0?oonf[ooo]ZoookJP;oo`/000?ooo]Zooo=0?ooc@000_l0old2oook
JP;oo`0000?ooo]ZogL0oomg0?l00_lDo`001?mY0?oooo]Zoom;0?ooB`3ooookJW7ooo]Z00Co07[o
oookJ_oonf[ooo]Z0_l0oeH3oookJP07o`1Qool0NOoooo]Zoah0oooo0>coa`3oool0=`02oookJP0J
o`3oBooco`3o0?m1oookJ_oo@P3o0?oCool=0?oo0:co0?oBoookJ_oo203ooo]Zo`26ool0oi?oo`1j
oookJ_oo04WooaT0o`3[oooi0?ook`3ooookJ_l0ogOon@3ooookJ_mFo`04oookJP06o`2Aoooonf[o
<ol0ool0M?l07?oon@3o0_l000000ol0oc3ooo]ZonSo0002oookJP?o1@3o1OoonfX2o`D0o`KoGP3o
0ooo03<01?oo0<7o0?mmo`3oOOl0ogd4oonJ0003oe7o0?l0of?o0?mS00?oo`2A00Sooed0ok80ool0
o`coo`0/oonD0?oo01?o07[oo`3og0;o3@3o0_oo08d2oomG00;ooo]Z0_oo2`000ooonf[oold0ooo=
0002o`3oc@;ooo]Z0_oo00000ooonf[oM`3oogL0o`02oaCo0004ofT0oooonf[ood/0oom;0:kooo]Z
0036oookJP03o`1joooonf[ooo]Z00;ooo]Z00Go0?mFoookJ_oonf[oobP0o`1Qo`0@oolX0003o`3o
d_oo:03oobP000CoobP000Coo`00oolX0?oo:03oobP01Ooo00000oooN@3oobP0oolX0004oolX00Co
o`004?oo:008o`0Doa;oogT000?oo`2Ao`3o__ooG@000oooN@02ool04`03oomi0?l=0?oo3@3o00;o
o`2=00CooeL0oookJ_oonf[ooo]Z0_oo2`000ooonf[oold0ooo=0003o`3oc@04oookJ_oo003oo`00
oookJP;oM`3o0_lDo`02ool0]P03oom;0?oonf[ooo]Z0?oooo]ZKooonfX01_l0N_oooo]ZoookJ_oo
nf[oob/0o`3oEP?ooo]Z00Go067oo`1ioooonf[o7P3oool0k002olL0o`;ooo]Z01Co0?m;oo?o0?l0
od7ooo]Zoom20?l0om?oo`d0o`3od_oo0?Wooo]Zool80?oonf[o08Koo`3oTooo07[oo`19oookJ_oo
6@3o0>_oooT0o`;ooo]Z00?o0?mgooT0oomFo`001?oonfX01_l0TOoo0?l[oc?o0?oo07Co01coooT0
o`?o000000Gooo]ZonSo0?oonf[ooo]Zo`D0o`02oookJP;oo`0I3?l05?l2oeh0o`?oo`0c00?oo`31
o`3oOOl0ogd00_l0ogd3oonJ0003oe7o0?l0of?o0?mS00?oo`2A00?ooed0ok80ool0o``00ooo01<0
1?l0omco3@3oo`d0ool=0?l2ool0S@03oomG0?oonf[ooo]Z00;oo`/000?ooo]Zooo=0?ooc@000ol0
old01?oonf[oo`00ool00?oonfX2ogL0o`;o5?l000?oJ@3oool0]_ooB`00[OoonfX00<Oooo]Z00?o
07[ooookJ_oonfX00_oonfX00ol0oeKooo]ZoookJP0BoolX0003o`3od_oo:03oobP000CoobP000?o
o`00oolX0?oo:0000_oo:005ool000?oobP01_oo000@oolX00Soo`1h5?ooN@02ool0T@04o`3o__oo
G@3ooi@0oonD00?oo`0C0_l=0?l2ool0S@;ooeL00_ooN@03ool;00;oold000Co0?l6o`3ocOl0olgo
0?o=0ooo0002ogL0o`;o5?l00_oo0;H00oooB`3ooo]ZoookJP3ooookJVkooo]Z00Ko07[ooookJ_oo
nf[ooo]Zool[0?l0oeH3oookJP;o067o00Gooo]Zoah0oooo0>coo`3/olL0o`02oookJP0Do`3oBooc
o`3o0?m1oookJ_oo@P3o0?oCool=0?l0om;oo`3ioookJ_oo203o08Koo`3oTooom`3oo`1jool0BOoo
nf[ooaT0o`3[oooi0?l2oookJP03o`3oMooi0?ooE_l000?ooo]Z00Ko097oo`3o:olco`3oo`1doook
J_l07?l3o`000004onSo0?oonf[ooo]Zo`D0o`;ooo]Z00Goo`0=o`0Dool05?ooS@3ooookJP0:ool0
N0Ko01Co1Ooo03<2o`3oO@;ooiX00_mAo`02o`3oH`;oo`2A00Co0?nnoomM0?ooU03ooi@00ooo01<0
0ol0omco3@3oo`d0o`02ool0S@;ooeL000Cooo]Zool;0?oo2`3oo`/00_ooc@001?l0o`Ko0?o=o`3o
cOl0old3ool000;oM`3o0olDo`000ooo0;Kood/0oookJP2ZoookJP00b?oonfX00ol0N_oooo]Zoook
JP02oookJP03o`3oE_oonf[ooo]Z01;oobP000?o0?oBoolX0?oo:0001?oo:0000ooo003oobP0oolX
0003oolX00coo`003ooo:006oomi00CoobP04?ooN@03oonJ00;oogT00ooo0944oomi00;oo`0C0_l=
0?l2ool0S@;oogT000?ooeL0oomi0?ooN@000_oo2`001?ooc@3oogT0oomi0?oonfX3o`3oc@;oo`00
0_mg0?l3oaCo0003ool0]_ooB`3ooo]Z0?oooo]ZK_oonfX01_l0N_oooo]ZoookJ_oonf[oob/0o`3o
EPCooo]Z00Ko067ooookJ_lN0?oo0?liool0k?o70?l2oookJP09o`3oBooonf[o0?m1oookJ_oo@P3o
0?oCool=0?l0om;oo`3i00;ooo]Z00So08Koo`3oTomBo`3oo`1jool0BOoo6@3o0>_oooT0o`?ooo]Z
00?on@3ooeKo0?oonfX00ooonfX01Ol0TOoo<ol0ool0M?oonf[o01co00?o000000?oj?l0oookJ_l5
0?l00_oonfX00ooo00goS@3ooookJP03ool0N003oonR0?nT0?ooY03o00WoY03o0_ooXP02ool0N0?o
01Co00Coo`31oeh0oooo03?oo`0c0_mN0?l4oonJ0003oe7o0?l0of?oo`2A00;oo`2A00Co0?nnoomM
0?ooU03ooi@00ooo01<2o`d0o`;oo`2=0_ooE`02oookJP;oo`/00_ooc@000ol0o`Kooo]Zo`3oc@02
o`3oc@;oo`000omg0?l2oaCo0003ofT0ooooB`3ooo]Z0:Sooo]Z0039oookJP03o`1joooonf[ooo]Z
00;ooo]Z00?o0?mFoookJ_oonfX03_oo:002ool000ooobP03?oo0008oolX0003ool00?oo:03oobP0
01googT000?oo`0coomi0?ooN@001?ooVP000ol0of?oogT0oomi0005oomi0004ool04ol=0?oo3@3o
o`d0o`;oo`2=0_ooE`07oomi0004o`3o1_oonf[o0?o=o`3oc@;oo`0000?ooo]ZogL0oomg0?l00_lD
o`000ooo0;Kood/0oom;003ooookJVgooo]Z00?o07[ooookJ_oonfX00_oonfX00ol0oeKooo]Zoook
JP02oookJP06o`1Qoooonf[o7P3oo`3o>Ooo0>coa`3o0_oonfX02?l0od_ooo]Zo`3o@Ooo@P3ofol0
o`3odooo0:co0?oB0_oonfX02Ol0Q_oooo]Zo`3oTomBo`3oo`1jool0BOoo6@3o0>_oooT0o`03oook
JP03ooT0oomFo`3ooo]Z00?ooo]Z00Co097ooc?o0?oonf[on@3o0ol000002OoXo`3o1@3ooookJ_oo
nf[oo`0=ohd0oooonf[oo`1hoonR0003oj@0o`kooo]Z0_nT0?l2ool0N0Go01Co0_oo07P00ooo03?o
GP3oool0`@04oonJ0006o`3oHooo097oo`2Aool0TOl0okkooed00_ooU002ool04`?o3@3o0_oo08d0
1OooE`3ooo]ZoookJ_oonf[oo`/000;oold00_l0o`H00ooonf[o0?o=o`3oc@02ool00003oookJ_mg
0?ooM`3o00?o5?l00_ooB`2VoookJP00b_oonfX00ol0N_oooo]ZoookJP02oookJPooobP01Ooo000?
oolX00[oo`001_oo:002ool00003oolX0?oo003oobP001googT00ol05?l3ool0<`04oomi0?ooVP3o
oiX0oonJ00SoogT000Coo`0Co`d0ool=0?oo3@3o0_oo08d00oooE`3oogT0oomi0004oomi0003ooo=
0?l0o`Kooo]Z00;o0?o=0ooo0002ogL0o`;o5?l000?oJ@3ooom;0?ooB`00oooonfY/oookJP03o`1j
oooonf[ooo]Z00;ooo]Z00_o0?mFoookJ_oonf[ooo]Zo`1iool0HOoooo]Zoah0oooonf[oo`0golL0
o`02oookJP08oo?o0?oonf[o0?m1oom20?oKo`3o0?oCo`3od_oo0?T2oookJP09o`26ool0oi?ooo]Z
oe;o0?oo07[oo`19oolI0?l0jooon@3o00;ooo]Z00?on@3ooeKo0?oonfX00ooonfX01?l0TOoo<ol0
ool0M?oi0?l3o`000004onSo0?oonf[ooo]Zool03@;ooo]Z00?ooj80oookJ_nT0?l02_oonfX8oonk
00Ooo`3k00?ooj80o`0Dool05?l00ol05?l3ool0<`05ool0`OooVP3ooiX0oonJ0?l0of<00ooo0940
1?l0okkooed0o`3o3?ooU002ool04`;o3@3o0_oo08d2oomG0003oomk0?oonf[ooo]Z00?oold000?o
0?l6oookJ_l0old00_l0old2ool000;oM`3o00Cooo]ZoaCo0?lDo`3oJ@3o0_ooB`2SoookJP00booo
nfX01?l0N_oooo]ZoookJ_oonfX>oolX00Soo`003ooo:008ool000?oobP00ooo00000ooo:03oo`00
ool00002oolX01KoogT02_oob@05o`0Do`;oo`0c0oooVP08oomi0004ool04ol=0?oo3@3oo`d0o`So
ogT00_ooc@001?l0o`Ko0?o=o`3ocOl0old2ool000;oM`3o0olDo`000omY0?oood/0oom;003ooook
JV[ooo]Z00Ko07[ooookJ_oonf[ooo]Zo`3oE_oo:`03oookJP06o`1iool0HOoooo]Zoah0oooonf[o
a`3o0ooonfX02?oco`3o0?m1ool0IOoo@P3ofol0ool=0?l0om;oo`3i0_oonfX02?l0Q_oo0?nCoe;o
0?oo07[oo`19oolI0?l0jooon@3o0_oonfX00ooi0?ooN?l0oeKo0003oookJP04o`2Aoolco`3oo`1d
ooT0o`;o000000Woj?l0oookJ_oonf[ooo]Zool03Ooonf[ooj80oookJ_nT0?l01_oonfX5oonk00Ko
Bol00_l0ogX8oonk00Coo`3k00?ooj80o`0Dool05?l00ol05?l2ool0<`?ooiX000?o0?mSool0TOoo
09400_oo09401?l0og3ooed0oonD0?oo01<3o`d0o`;oo`2=0_ooE`02oomk0006oookJ_ooc@3oold0
ooo=0?l0o`Kooo]Z0_l0old2ool000?oM`3o0olDo`03oom;0:3ooo]Z003<oookJP;oobP00_oonfX<
oolX00[oo`003ooo:007ool00003oolX0?oo003oo`0000;oo`0000CoobP0ool00?oo003ooj800_oo
:00;oomi00KoobP02?oob@02o`3oNPGook/00oooN@02ool0N0Go01Co0oooVP04oomi00;oolT000?o
ogT0oonD0?oo01<02_ooN@03ooo=0003o`3o1_l0olgo0?o=00;oogT000?oo`00ogL0oomg0?l00olD
o`000omY0?oood/0oookJP3ooookJVSooo]Z00Ko07[ooookJ_oonf[ooo]Zo`3oE_oo:`03oookJP06
o`1Qoooonf[ooo]Zoah0oooo0>coa`3o0ooonfX02?oco`3o0?m1oookJ_oo@P3ooo]Zool=0?l0om;o
o`3i0_oonfX02?l0Q_oo0?nCoe;o0?oo07[oo`19oolI0?l0jooon@3o0_oonfX00ooi0?ooE_l0oook
JP02oookJP04o`2Aoolco`3oo`1dooT0o`;o000000Coj?l0oookJ_oonf[oo`0=0_oonfX00oooXP3o
Y03ooookJP05oookJP05oonk0?oonf[oBol0od_o0?ooXP000_oonfX5o`3oNPGo0?nG1Ol0ogX5oonk
00;o0?mT00?oo`3kool0N?oo07P01Ol05?l3oonJ00;o0?mS0ooo09401?l0okko0?m`oonD0?oo01<4
o`d0o`03ool0SOooE`3ooeL000;oog/000Gooo]Zooo=0?ooc@3oold0o`3o1P03o`3oc@;oo`000omg
0?l3oaCo00;ood/0W_oonfX00<cooo]Z0ooo:0000ooonf[oobP0oolX0009oolX00_oo`004?oo:00=
ool00004oonR0?ooN@3oobP0oolX00SoogT05ooo:0000ol0og[oogT0oomi0005oomi00?oo`1h0ol0
5?l4oonJ00CoolT000?oo`2Aoomi0?ooN@002_ooN@001?oo2`3oold0ooo=0?l0o`H3oomi00;oo`00
00?ooo]ZogL0oooo0;H00olDo`000omY0?oood/0oookJP02oomi0?oooo]ZHooonfX00ol0N_oooo]Z
oookJP02oookJP03o`3oE_oo:`3ooo]Z00;ooo]Z00Ko067ooookJ_oonf[o7P3oool0k?o70?l2oook
JP08oo?o0?oonf[o0?m1oom20?oKo`3oo`d0ool0[?l0om83oookJP07o`26ool0oi?oD_l0ool0N_oo
nf[ooaT0ooT0o`02oookJP03ooT0oooonf[oE_l000;ooo]Z00?o097ooc?o0?oo07@00ol000001ooX
o`3ooo]ZoookJ_oo00gooo]ZoonR0?nT0?l01_oonfX01?oo^`3oBol0od_o0?ooXP06oookJP;ooo<0
3_l0o``2oooc00Kook/000Co0?mTool0N?oo07Soo`1h0ol05?l4oonJ0003o`3oHooo097oo`2A00;o
o`2A00Co0?nnoonD0?oo01?oo`0C1?l=0?l2oomG00;oog/000Goo`/0ooo=0?ooc@3oold0o`3o1P02
o`3oc@;oo`0000Cooo]ZogL0oomg0?ooo`2f0olDo`02oom;09_ooo]Z003=oookJPkoobP02_oo000@
oolX00?oo`0000?oobP0ool00?oo00002?oo00001?ooXP3oo`00ool00?oo:005oomi00?oo`001_oo
:00Bo`2lo`coogT000?oo`1ho`0Dool05?l00_l05?l4oonJ0003ooo90?ooN@3oogT000_oogT000?o
oo]Zooo90?oob@001OooN@03ool00003oookJ_mg0?ooo`2f00;o5?l00_mY0?l00oooB`3oogT0oook
JP3ooookJV;ooo]Z00?o07[ooookJ_oonfX00_oonfX00ol0oeKooo]ZoookJP02oookJP06o`1Qoooo
nf[o7P3oo`3o>Ooo0>coa`3o0_oonfX02?oco`3ooo]Zo`3o@Ooo@P3ofol0ool=0?l0om;oo`3i0ooo
nfX02ol0oi?ooo]Zool0N_oo04Wo0>_ooookJ_oi0?oooo]ZooT0oomho`3oE_l000;ooo]Z00?o097o
o`3o:ooo07@00ol000001ooXo`3ooo]ZoookJ_oo00gooo]ZoonR0?nT0?l01?oonfX2oonk0003oonR
0?oonf[ooo]Z00Cooo]Z0_ool`000ol0o`co0;coo`2lo`0Eo`2lo`03o`3oN_oo^`3ook/000Cook/0
00?oo`1ho`0Dool05?l00_l05?l4oonJ0003o`3oHooo097oo`2A00?oo`2A0ooo01<3o`d0o`;ooeL0
00?oog/0oookJ_oo2`000oooc@03o`3oc@;oo`0000Cooo]ZogL0oomg0?ooo`2f0_lDo`000omY0?oo
od/0oookJP2HoookJP00cOoonfX>oolX00Woo`002Ooo:0000ooo003oobP0oolX0005oolX00?oo`00
00?oobP0ool00?oo00001ooo00001OooXP3oo`00ool00?oo003oobP000;oogT01_oo0003oolX00?o
0;co1_oo0004oolX01KoogT000?ook/0ool0N?oo07P01?l05?l4oonJ01CoogT000Co0?o=ool00?oo
003oo`000_mg0?l3oaCo0003ofT0ooooB`3oogT000?ooo]Z0_ooN@000ooonf[oogT0oomi003ooook
JU[ooo]Z00?o07[ooookJ_oonfX00_oonfX01Ol0oeKooo]ZoookJ_oonf[o067o00;ooo]Z00Co7P3o
oookJ_oo0>coa`3o0_oonfX02?oco`3ooo]Zool0IOoo@P3ooo]Zool=0?l0om;oo`3i0ooonfX01_l0
oi?oo`1jool0BOoonf[o0>_oooT0o`;ooo]Z00Oon@3ooookJ_oonf[ooo]Zo`2Aoooonf[oo`1d00;o
000000Ooj?l0o`000?oonf[ooo]Zool03OooXP3oY03o00Cooo]Z00?ook/0o`3WooooXP001?oonfX2
oooc0004o`3o3?l0_?oo0;coo`2lo`Sooo]Z2ol05Ol4ool0f`Oo0;co00Go0?mjoonk0?oo^`3ook/0
ool0N004o`0Do`CooiX000?o0?mSo`3o__oo09400_oo0943ool04`?o3@3o0oooE`02ool;00;oold0
00Co0?l6o`3ocOl0olgo0?o=0_oo0003ogL0o`?o5?l000?ood/0oookJ_oonfX0UOoonfX00<kooo]Z
3_oo:007ool000WoobP00_oo0007oolX00?oo`000_oo:008ool00006oonR0?oo003oo`00ool00?oo
:03ook/01?oo0005oolX0003o`2loooo:03oobP000CoobP03_l^o`0@oomi00;o0;co0_oob@02ool0
N0CoogT01OooVP08oomi00;o3@3o1_ooN@03o`3oc@03ool00?ooN@3oogT000;oM`3o0olDo`000omY
0?oood/0oookJP06oomi00;ooo]Z0_ooN@3ooookJUKooo]Z00?o07[ooookJ_oonfX00_oonfX01Ol0
oeKooo]ZoookJ_oonf[o067o00;ooo]Z00?o7P3ooookJ_oo0>`00ooonfX02?oco`3oo`1UoookJ_oo
@P3oo`26o`3od_oonf[oo`3i0_oonfX00ol0oi?ooo]Zool0NP02oookJP04o`3[oooi0?oooo]ZooT0
o`?ooo]Z00?o097ooookJ_oo07@00_l000001ooXo`3o0000oookJ_oo00gooo]ZoonR0?nT0?l00ooo
nfX00ooo^`3o0>OooonR0003oookJP;ooo<00_l0o``00ol0_?oooo]ZoookJP02oookJP?o01Go5?l^
o`06o`0Eo`Go0;co00Co0?mjoonk0?oo^`3oo`1h1?l05?l5oonJ0003o`3o__oo097oo`2A00?oo`0C
1?l=0?l2oomG0005ool;0?ooc@3oold0ooo=0?l0o`H00ol0old2ool000;oM`3o00Gooo]ZoaCo0?lD
o`3oJ@3ooom;002DoookJP00cooonfX=oolX00Woo`001?oo:0000ooo003oobP0ool00003ool000?o
obP000Coo`00oolX0?oo:03oobP00_oo0003oolX00Coo`0000?oobP0ool00?ooXP001?oo00000ooo
^`3oo`00ool0000<oolX00?o;_l000CoobP0ool00?oo003oo`002_oo:00Aoomi0003ooo90?l0_?oo
0;co00;o0;co0_oob@02ool0N0Go01Co1?ooVP000ooob@3oo`2Aool04`03ool04`Co3@3o1?ooN@00
1?ooc@3o0?o=o`3ocOl0old2oomi00;oM`3o00?oogT0oaCo0?lDo`000_mY0?l00oooB`3oogT0oomi
0007oomi0?oooo]ZE_oonfX01Ol0N_oooo]ZoookJ_oonf[o0?mF00Cooo]Z00Go067ooookJ_lN0?oo
0?lioonD0003oookJP07oo?o0?oonf[oo`1Uoom20?oonf[oo`26o`3odP03oookJP09o`3oTooonf[o
o`1jool0BOoonf[o0>_oooT0oooonf[on@3o00Cooo]Z00Go097oool0M?l0003o0000onSo0002o`00
0003ool03OooXP3oY03o00?ooo]Z00?ook/0oookJ_l0iol00ooonfX00oool`3ooo]ZoookJP02o`2l
o`?ooo]Z00?o01Goobko0?l^o`000_l^o`04o`27o`CoNP3o1_m_o`06ogX0o`Oo;_l01?l05Ol4o`2l
o`?ook/000?oo`1ho`0Dool05?l00ol05?l4oonJ00?oo`2A0ooo01<4o`d0o`03oomG0?oo2`3oold0
00;oold000Go0?l6o`3ocOl0olgo0?o=ool00002ogL0o`03oookJ_lDo`3o5?l000;oJ@3o00?ood/0
oookJ_oonfX0SooonfX00<oooo]Z3Ooo:00;ool000?oobP01_oo00001?oo:03oo`00ool00?oo0002
oolX0003ool00?oo:03oobP000;oobP01_oo00000ooo:03oo`00ool00002ool00004oonk0?oo003o
o`00ool000[oobP000?o;_l0oolX0?oo00000_oo000:oolX00?o0?me1?ooN@05o`3oM@SoogT03?oo
b@02ool0N0Co01Co0oooVP03oomi00?oo`0C00CoogT0o`d0ool=0?oo3@3o0oooN@000oooc@3oogT0
oomi0002o`3oc@04oomi0?mg0?ooM`3oogL0o`?o5?l02oooN@001?oonf[oogT0oomi0?ooN@3ooook
JU7ooo]Z00Go07[ooookJ_oonf[ooo]Zo`3oEP03oookJP06o`1Qoooonf[ooo]Zoah0oooonf[ooi@0
0ooonfX01_oco`3ooo]Zool0IOoo@P3ooo]Zo`3odPCooo]Z00Wo0?nCool0N_oo04Wooo]Zo`3[oooi
0?oooo]ZooT0oomho`000ooonfX02_l0TOooo`1do`000?l0003oj?l0o`000?oonf[oo`0=oonR0?nT
0?l3oookJP03oonk0?l0iooooo]Z00;ooo]Z00Cooo<0oookJ_oonf[o0;co0ooonfX3obko00Co08Oo
00?ooo]Zofoo0?m_o`000om_o`04oookJPgo0?me00Cooo]Zofoo0?m_o`3oKol01ol^o`000ol05Ooo
0;coo`2lo`02o`2lo`?ook/00_oo07P4o`0Do`?ooiX00ooo0943ool04`04ool0SOl=0?oo3@3oo`d0
o`;ooeL01?ooc@03o`3oc@?oM`3o0olDo`000omY0?oood/0oom;002>oookJP00d?oonfX;oolX00co
o`000ooo:00;ool000OoobP000?oo`00oolX0?oo:0000ooo:003ool00004oonk0?oo003oo`00ool0
00_oobP000?oo`00oolX0?oo:0000_oo0005oolX00Go0?me2ooonfX9oomi017oolT00_oo07P2o`0D
o`?ooiX00oooN@04ool04`Co3@3o0ooob@001?ooN@3o0?o=o`3ocOl0oldDoomi0?oooo]ZD?oonfX0
0ol0N_oooo]ZoookJP02oookJP05o`3oE_oonf[ooo]ZoookJ_l0HOl00_oonfX00olN0?oooo]ZoonD
0003oookJP06oo?o0?oo06Good80om_o0?oo08Ko0?oB0ooonfX00ol0oi?ooo]Zool0NP02oookJP04
o`3[oooi0?oooo]ZooT0o`?ooo]Z00[o097oool0M?l0003o0000onSo0?l0003oo`0=oookJ_ooXP3o
Y03o0_oonfX00ooo^`3ooo]Zo`3Wo`03oookJP03oooc0?oonf[o0;co00;ooo]Z00?o01Goobko0?l0
Qol00_l0Qol2oookJP?oKol01?oonfX5o`3oM@gooo]Z1ol0ogD01?oonf[oKol0ofoo0?m_o`05obko
00Go0;co0ooo^`02ool0N0;o01Co0oooVP000oooG@3oo`2Aool0T@04ool04`Co3@3o00?ooeL0ool;
0?oo2`000_ooc@03o`3oc@?oM`3o0olDo`001?mY0?oood/0oom;0?ooB`2:oookJP00d?oonfX;oolX
00goo`000_oo:00<ool000coobP00ooo000GoolX00;o0?me4?oonfX8oomi0003oookJ_l0ogGo0?me
00SoogT01?l^o`05o`2lo`?ook/00_oo07P4oonJ00?oogT01?oo01<00ol=0?ooolT0ooo90002ooo9
0003oomi0?oob@3oolT000;o0?o=4oooN@3ooookJToooo]Z00Go07[ooookJ_oonf[ooo]Zo`3oEP04
oookJP05o`1Qoooonf[ooo]Zo`3o>OooU0000ooonfX01_oco`3ooo]Zoom20?oKo`3ooo]Zo`3odP?o
oo]Z00?o0?nCoookJ_oo07X00_oonfX01?l0jooon@3ooookJ_oi0?l3oookJP09o`2Aoooo07Co0000
o`000?oXo`3o0000ool03OooXP3oY03o00?ooo]Z00?ook/0o`3WoooonfX00_oonfX00oool`3ooo]Z
o`2lo`03oookJP03obko0?l0Qooooo]Z00?ooo]Z00CoKol0oookJ_oonf[ooo]Z1?l0ogDIoookJPSo
0?me00?ooo]Zofoo0?l^o`000ol^o`05o`2lo`?ook/00_oo07P4oonJ0003oomM0?oo097oo`2A00Co
o`0C0ol=0?l01OooE`3ooo]Zool;0?oo2`3oold000?o0?o=0omg0?l4oaCo00?ood/0QooonfX00=7o
oo]Z2_oo:00=ool000?oobP03?oo000SoolX00Oooo]Z2?oo02D>ool0C`03ool09OooN@3oogT000co
ogT01?l^o`05o`2lo`;ook/000?ooj80ool0N?ooVP000oooVP03ool0T@03ool04ooob@3oolT000Ko
olT05_ooN@3ooookJTkooo]Z00Go07[ooookJ_oonf[ooo]Zo`3oEP03oookJP03o`1Qoooonf[ooo]Z
00;ooo]Z00Wooi@0oookJ_oonf[ooo]Zoo?o0?oo06Good80om_o0?l0om801?oonfX00ol0oi?ooo]Z
ool0NP02oookJP03ooT0oooonf[on@3o00?ooo]Z00Wo097oool0M?l0003o0000onSo0?l0003oo`0=
oonR0?nT0?l00ooonfX01ooo^`3ooo]ZoookJ_oonf[ooo<0oookJ_l0_?l00ooonfX00ol^o`3o08Oo
oookJP02oookJP;oKol000Cooo]Zo`3oMOl0ogGo0?me2?oonfX7ool09@ooo`1?1?oo02D3oookJPOo
0?me1?l^o`05o`2lo`?ook/000?oo`1hoonJ0?ooVP000_ooVP03ool0T@?oo`0C0ol=0?l00oooE`3o
og/0ool;0002ool;00?o0?o=0omg0?l01?oo0;Ko5?l0oaCo0?lDo`04oom;08?ooo]Z003AoookJP[o
obP03Ooo0003oolX00goo`001?oo:002ool001_oobP00_oonfX8oolX00Koo`1?3_oonfX9ool0C`;o
o`0U2?ooN@000ooUo`3o;_l0obko0002obko00Go0;co00?ook/0oonR0?oo07P00oooVP0;ooo900?o
ogT00_oUo`04oomi00;oolT02_ooN@3ooookJTkooo]Z00Go07[ooookJ_oonf[oob/0o`3oEP03oook
JP05o`1Qoooonf[ooo]ZoookJ_ooU0001OoonfX01?oo@P3ofol0oookJ_l0om83oookJP03o`3oTooo
nf[oo`1j00;ooo]Z00?on@3ooookJ_oi0?l00ooonfX02Ol0TOooo`1do`000?l0003oj?l0ool03Ooo
nf[ooj80oj@0o`02oookJP03oonk0?oonf[ooo]Z00;ooo]Z00?ooo<0oookJ_l0_?l00_oonfX01?l^
o`3o09;ooookJ_oonfX2ofoo0003oookJ_l0ogGo0?me00Oooo]Z1?oo02D2oookJPGoo`1?3ooonfX8
ool0C`Goo`0U0ooonfX3o`3oM@Co;_l01_l0_?l00ooo^`3oo`0coonJ0003oonJ00?oo`2A0_oo01<3
o`d0o`;ooeL00ooo2`04o`3oc@;oM`3o00?oo`2foaCo0?lDo`000_lDo`03oom;083ooo]Z003Boook
JPOoobP000?oo`00oolX0?oo:0003?oo0002oolX00coo`001_oo:002ool001WoobP01?oonfX6oolX
00;oo`1?2?oo:00Ho`3Ho`Koo`1?1oooN@04obko00Ko0;co2ooob@000ol=0?ooolT0oomi0003onGo
00;oolT000?oogT0ooo90?oob@000_oob@02oomi00;o5?l01_ooN@3ooookJTcooo]Z00Go07[ooook
J_oonf[ooo]Zo`3oEP04oookJP05o`1Qoooonf[ooo]ZoookJ_ooU0001?oonfX01?oo06Good80om_o
0?oo08H3oookJP03o`3oTooonf[oo`1j00;ooo]Z00?on@3ooookJ_oi0?l00ooonfX02ol0TOooo`1d
o`000?l0003oj?l0ool03Ooonf[ooj80oj@0oooonf[ook/000Cooo]Z00?ooo<0oookJ_l0_?l00_oo
nfX01Ol^o`3o09;ooookJ_oonf[oKol000;ooo]Z00?o0?meoookJ_oonfX01?oonfX3ool09@;ooo]Z
1?oo04l4oookJP?oi_l06?l0f?l6ool0C`Coo`0U0_oonfX00ol0ogGo;_l0obko0003obko00Go0;co
00?oo`0coonJ0?ooVP000_ooVP001?mN0?ooo`2Aool0TOoo01<3o`d0o`;ooeL000Coog/0ool;0?oo
2`3oo`/00ol0old2ogL0o`03ool0]_mY0?oo5?l000?o5?l00_ooB`1moookJP00dooonfX6oolX00;o
o`0000?oobP0ool00?oo00004Ooo00001?oo:03oo`00ool00?oo0009oolX00;oo`003?oo:0000ooo
003oobP0oolX000KoolX00?o0=So4ooonfX5onKo00Oo0=So0_oo04l9oomi00Go;_l03Ooob@02o`d0
o`CoiOl01_oob@03oomi00?o5?l01OooN@3ooookJT_ooo]Z00Go07[ooookJ_oonf[ooo]Zo`3oEP07
oookJP03oonD0?oonf[ooo]Z00;ooo]Z00Coo`1Uoom20?oKo`3oo`261?oonfX01ol0oi?oo`1joook
J_oonf[on@3ooookJ_oi0?l00ooonfX02?l0TOooo`1do`000?l0003oj?l0ool03OooXP3oY03o0_oo
nfX01ooo^`3ooo]ZoookJ_oonf[ooo<0oookJ_l0_?l00ooonfX00ol^o`3ooo]ZoookJP03oookJP03
o`3oMOoonf[ooo]Z00?ooo]Z0_oo02D2oookJP?oo`1?1?oonfX00ooVo`3o0=Soo`3Ho`04o`3Hoa?o
oo]Z1OoVo`07o`3Ho`Ooo`1?00?oo`0UoookJ_l0ogD00_l0ogD4obko00Go0;co1OooVP000ooo097o
o`0Co`d0o`03o`d0o`03oomG0?ooN`3oo`/000;oo`/01?l0old2ogL0o`;oJ@3o0olDo`02oom;07[o
oo]Z003CoookJP?oobP000Coo`00oookJ_oo:03oobP05Ooo00000ooo:03oo`00oolX000GoolX0003
ool00?oo:03oobP001goobP06ooonfX6oomi00Go0=So0_ooN@05ool0C`;oogT04Ooob@04o`d0o`;o
iOl01_oob@04oomi00Co5?l00_ooN@3ooookJT_ooo]Z00Co07[ooookJ_oonf[o0?mF2?oonfX00ooo
U03ooo]ZoookJP02oookJP04oom20?oKo`3ooo]Zool0QP?ooo]Z00Oo0?nCoookJ_oo07[ooo]ZooT0
oooonf[oN?l000?ooo]Z00So097oool0M?l0003o0000onSo0?oo00gooj80oj@0o`;ooo]Z00?ook/0
oookJ_oonfX01_oonfX00ol^o`3ooo]ZoookJP03oookJP03o`3oMOoonf[ooo]Z00?ooo]Z00?oo`0U
oookJ_oonfX00_oo04l4oookJPCo0=So8_oonfX3onKo00Go0=So0_oVo`05ool0C`Co0?me00?o09;o
ool0fol^o`000_l^o`03o`2lo`03oonR0?oo07SooiX000?ooiX000?oo`2Aool04ol=0?l00_l=0?l0
0ooo08goog/0oomk0003ool;00Co0?o=00?oM`3oofT0oomY0?l00olDo`02oom;07Oooo]Z003Doook
JP04oolX0?oonf[oo`00oookJP;oobP05Ooo00000ooo:03oo`00oolX000FoolX00;oo`000ooo:000
0ooo003oobP0oolX000PoolX01go0?o20_oonfX5o`3Ho`;oi_l00_ooN@0Booo900;ooiX000CoiOl0
o`d0ool=0?oo3@3o1ooob@05oomi0006ofT0oolDo`3o5?l0oaCo0?oo0;Kood/0oooonfY8oookJP05
o`1joooonf[ooo]ZoookJ_l0oeH01ooonfX00oooU03ooo]ZoookJP02oookJP04ool0IOoo@P3ofol0
ool0QP?ooo]Z00?o0?nCoookJ_oo07X01?oonfX03Omho`3ooo]ZoookJ_l0TOooo`1do`000?oXo`3o
0000ool03OooXP3oY03ooookJ_oo^`002?oonfX00ol^o`3ooo]ZoookJP03oookJP03o`3oMOoonf[o
oo]Z00?ooo]Z00Coo`0UoookJ_oo04ooo`1?0ooonfX3o`3Ho`cooo]Z8?l0ol82oookJPKo0=So00?o
i_l0ool0Cooo04l00ooo04l3o`3oM@04o`2Boooo0=_oo`3Kobko00Co0;co0_oo07P4oonJ0003ool0
4ol=0?oo3@3o00;o3@3o00?ooeL0oomk0?ooN`000_oo2`001Oooc@3o0?o=o`3ocOl0olgoM`3o00;o
J@3o0olDo`000ooo0;Kood/0oom;001coookJP00e_oonfX2ool00003oookJ_oo:03oo`0001Koo`00
0ooo:002ool000goobP000Coo`00oolX0?oo:03oobP00ooo0002oolX00;oo`000ooo:0000ooo003o
obP0oolX000JoolX01oooo]Z1Ol0ol82oookJPKo0=So4Ooob@000oooN@3ooiX0oonJ0002oonJ00Co
3@3o1Ooob@03oomi00?oolT000KoJ@3ooaCo0?lDo`3o5?l0ool0]_ooB`3ooookJTKooo]Z00Go07[o
oookJ_oonf[oob/0o`3oEP07oookJP08oonD0?oonf[ooo]ZoookJ_oo06Good80oookJ_oo08H5oook
JP03ool0N_oonf[ooo]Z00;ooo]Z00goN?l0oookJ_oonf[ooo]Zool0M?l0003oj?l0o`000?oo00go
oj80oj@0oooonf[ook/001?ooo]Z00?oo`0UoookJ_oo04l00ooonfX2o`3Ho`[ooo]Z1Ol0ol8Poook
JPGo0?o20ooonfX5o`3Ho`03o`3foooo04ooo`1?00?oo`1?00Coo`0Uo`3oMOl0T_oo09;o0_oo0=/3
o`2lo`03oonk0?oo07Soo`1h00CooiX000?oo`0co`d0ool=0?l00_l=0?l01OooE`3oog/0oookJ_oo
2`3oold000?o0?o=00?oM`3oofT0oomY0?l00olDo`000ooo0;Kood/0oom;001`oookJP00eooonfX2
ool00003oookJ_oo003oo`0001Goo`0000?oobP0ool00?oo00001?oo000:oolX00?oo`0000CoobP0
ool00?oo003oo`000_oo:004ool00003oolX0?oo003oo`0001WoobP09ooonfX6o`3o`P;oogT01ol0
f?l:ooo900GoogT00oooVP000ooo03?o3@3oo`d0o`02o`d0o`;oolT00_ooN@05ooo90003ogL0oomY
0?oo5?l000?o5?l000?ood/0oookJ_oonfX0oooonfY1oookJP05o`1joooonf[ooo]ZoookJ_l0oeH0
2ooonfX01?oo06Good80oookJ_oo08H5oookJP03ool0N_oonf[ooo]Z00;ooo]Z00?oN?l0oookJ_oo
nfX00_oonfX3o`000005ool03OooXP3ooo]ZoookJ_oo^`004_oonfX00ooo02Gooo]Zool0C`03oook
JP03o`3Hoooonf[ooo]Z00Oooo]Z0ol0ol8ZoookJPKo0?o20_oonfX7o`3Ho`?oo`1?0_oo02D00omj
0?oo09;oool0f`04o`2lo`?oo`1h0oooVP02ool0<`Co3@3o00CooeL0oomk0?oonf[oold00ol0old2
ogL0o`03ofT0oolDo`3o5?l000;o5?l00_ooB`1]oookJP00eooonfXRool000SoobP02?oo00000ooo
:03oo`00ool00005ool00003oolX0?oo003oobP000;oobP00ooo0006oolX00;ooo]Z2?oo:00/oook
JP?oogT01_l0ol83oomi00Oo0=So0ooUo`07oomi0003ool0N?ooVP3ooiX000;ooiX000?oo`0co`d0
ool=0?l00ol=0?l5ooo90003o`3ocOmg0?ooM`3o00;oJ@3o0olDo`000oooB`3ooo]ZoookJP3ooook
JSoooo]Z00Go07[ooookJ_oonf[oob/0o`3oEP0;oookJP04oom20?oonf[ooo]Zool0QPCooo]Z00?o
o`1joookJ_oonfX00_oonfX00omho`3ooo]ZoookJP02oookJPCo000000Cooj80oookJ_oonf[ook/0
4OoonfX00ooo02Gooo]Zool0C`03oookJP03o`3Hoooonf[ooo]Z00Gooo]Z0ol0ol8coookJPKo0?o2
0ooonfX7o`3Ho`03ool0Cooo02GoNP3o00;o08Oo00?oo`3Ko`2lool0_?l00_l0_?l00ooo07SooiX0
oonJ0002oonJ00;oo`0c1?l=0?l00oooE`3oog/0ooo=0003o`3oc@;oM`3o0_mY0?l3oaCo00;ood/0
J_oonfX00=Oooo]Z2_oo00000ooonf[oo`00ool00004ool000;oobP04?oo0006oolX00Soo`0000?o
obP0ool00?oo00003ooo0003oolX00Coo`001_oo:00^oookJPWoogT01ol0ol800oooN@3oiOl0onGo
0002o`3Ho`[oogT00_l0_?l00ooo07SooiX0oonJ0002oonJ00;oo`0c1?l=0?l3ooo900?o0?o=00?o
M`3oofT0oomY0?l00olDo`000oooB`3ooo]ZoookJP3ooookJSgooo]Z00Co07[ooookJ_oonf[oob/0
2ooonfX01?oo06Good80oookJ_oo08H4oookJP03ool0N_oonf[ooo]Z00;ooo]Z00?oN?l0oookJ_oo
nfX00_oonfX4o`0000?ooo]Z00?ook/0oookJ_oonfX03_oonfX00ooo02Gooo]Zool0C`03oookJP03
o`3Hoooonf[ooo]Z00Cooo]Z0_l0ol8loookJPOo0?o20_oonfX00ooVo`3o0=Soo`3Ho`04o`3Ho`05
ool09Omj0?oo08Ooo`27ool^o`001?l0_?l4oonJ0003ool0N?oo03?o3@3o00?o3@3o00?oo`2=oook
J_l0old00ol0old00omg0?ooJ@3oofT0o`03oaCo00;ood/0IooonfX00=Oooo]Z2_oo00000ooonf[o
o`00ool00004ool00003oolX0?oo003oo`0000koo`001_oo:00Kool00003oolX0?oo003oo`0000Co
o`000ooo:00foookJPSoogT00ooonfX5o`3o`PgoogT01?l0_?l4oonJ0003ool0N?oo03?o3@3o00?o
3@3o00?oolT0ooo=0?l0old00ol0old00ooob@3oJ@3ooaCo0002oaCo0003oom;0?oonf[ooo]Z0?oo
oo]Z>_oonfX01Ol0N_oooo]ZoookJ_oonf[oob/000[ooo]Z00Coo`1Uoom20?oonf[oo`261?oonfX0
0ooo07[ooo]ZoookJP02oookJP03ogSo0?oonf[ooo]Z00;ooo]Z1?l00002oookJP03oonk0?oonf[o
oo]Z00kooo]Z00?oo`0UoookJ_oo04l00ooonfX00ol0m_oooo]ZoookJP04oookJP03o`3o`_oonf[o
oo]Z04?ooo]Z1ol0ol82oookJPGo0=So00?oo`0UogX0ool0Qol00_l^o`03o`2lo`CooiX000?o01Co
ool0<ol=0?l00ol=0?l00ooo08goold0o`3oc@03o`3oc@03ogL0oomY0?oo5?l000;o5?l00_ooB`1T
oookJP00f?oonfXSool000KoobP07ooo00000ooonf[oobP0oookJP17oookJPooogT00ol^o`03o`2l
o`GooiX000Coo`0co`d0ool=0?oo3@3o0_oo08d00oooc@3o0?o=o`3oc@02o`3oc@06ooo90?lDo`3o
5?l0oaCo0?mY0?oood/0oooonfXioookJP04o`1joooonf[ooo]Zool[00_ooo]Z00?ood80oookJ_oo
08H01?oonfX00ooo07[ooo]ZoookJP02oookJP03ogSo0?oonf[ooo]Z00;ooo]Z1?l00002oookJP03
oonk0?oonf[ooo]Z00gooo]Z00?oo`0UoookJ_oonfX00ooonfX00ol0m_oooo]ZoookJP04oookJP03
o`3o`_oonf[ooo]Z04_ooo]Z1_l0ol800ooonf[o0=Soo`3Ho`03o`3Ho`04ool09Ol0ogGo;_l0obko
00?o0;co1OooVP001?oo03?o3@3oo`d0ool=0?l2ool0S@03ooo=0?l0olgo0?o=00;o0?o=00KoM`3o
oaCo0?lDo`3o5?l0ofT0ooooB`1QoookJP00f?oonfXWool000?oobP07Ooo001:oookJQ7oogT00_l0
f?l01?oob@3o;_l0obko0?l^o`02o`2lo`;oogT01?ooVP04o`d0o`04ool04ooo08goold0o`3oc@;o
olT000Co0?l<oaCo0?lDo`3o5?l00_mY0?oooookJS[ooo]Z00?oob/0oookJ_oonfX02?oonfX00ooo
06Good80oookJP04oookJP03ool0N_oonf[ooo]Z00;ooo]Z00?oN?l0oookJ_oonfX00_oonfX4o`00
00;ooo]Z00?ook/0oookJ_oonfX03?oonfX00ooo02Gooo]ZoookJP03oookJP03o`3foooonf[ooo]Z
05Wooo]Z1Ol0ol800ooVo`3o0=Soo`3Ho`02o`3Ho`04ool0Col0ogGo;_l0obko00?o0;co00?oo`1h
oonJ0?ooVP000_ooVP04o`d0o`03ool04ooo08goold000?o0?o=00CoM`3ooaCo0?lDo`3o5?l00_mY
0?mNoookJP00f?oonfXYool000;oobP01_oo00000ooonf[oo`00ool0000Bool004_ooo]Z3_ooN@05
o`3o`PCo0=So0_oob@06oomi00CooiX01?l=0?l4ooo900;o0?o=1?lDo`02ofT0oooooo]Z@_oonfX0
0ooo@P3ooo]ZoookJP08oookJP03ogSo0?oonf[ooo]Z00;ooo]Z1?l0000@oookJP03ool09Ooonf[o
oo]Z00?ooo]Z00?o0?KooookJ_oonfX0GooonfX5o`3o`PGo0=So00Coo`1?obko0?l^o`3o;_l00_l0
_?l00ooo07SooiX0oonJ0002oonJ00Co3@3o00?oo`0Cool0SOl0old00ol0old4oaCo00;oJ@3oF_oo
nfX00=Wooo]Z2Ooo00001?oonf[oo`00ool00?oo0002oookJQ[oo`0000?oobP0oookJ_oo00001?oo
00000ooonf[oo`00ool0000@ool005Gooo]Z2OooN@02ooo900;o0?o20_ooN@05o`3Ho`GoogT000?o
olT0ool0N?ooVP000oooVP03o`d0o`?oolT01?l0old3oaCo00;oolT000?oJ@3ooookJ_oonfX0oooo
nfY<oookJPGo0000O?oonfX5o`3o`PCo0=So0_oo04l2obko00;o0;co00?oo`1hoonJ0?ooVP000_oo
VP03o`d0o`;oo`0C00?oold0o`3ocOl0old00_l0old4oaCo00;oJ@3oE_oonfX00=Wooo]Z2ooo0004
oookJQ_oo`000ooonfXEool006Kooo]Z1?ooN@04o`3Ho`?oogT000Co;_l0ooo90?oo07Soo`1h1?oo
VP03o`d0o`03ooo90?oo01?oold000?o0?o=1?lDo`03ofT0oooooo]ZB_oonfX4o`0008;ooo]Z1?l0
ol85o`3Ho`04ool0Col^o`3o;_l0o`2lo`;oo`1h1?ooVP03o`d0o`;oo`0C00?oold0o`3ocOl0old0
0_l0old3oaCo00?oJ@3oD_oonfX00=Wooo]Z2ooo0004oookJQ_oo`001?oonfX>ool00003oookJ_oo
003oo`0000;oo`00IooonfX8oomi00Co0=So00?oogT0ool0Cooob@000_oob@02ool0N0CooiX00ol=
0?l2ool04`CoolT00olDo`03ofT0oooooo]ZAooonfX4o`0008Oooo]Z1?l0ol84o`3Ho`04ool0Col^
o`3o;_l0o`2lo`;oo`1h1?ooVP04o`d0o`03ool04ooo2`3o0?o=00;o0?o=1?lDo`02ofT0odoooo]Z
003IoookJPcoo`000ooonfXKool000Cooo]Z3_oo00001?oonf[oo`00ool00?oo001XoookJPcoogT0
1?l0f?l5ooo900;oo`1h1?ooVP04o`d0o`04ool04ooob@3oolT0ooo900Co5?l00omY0?oooookJT?o
oo]Z1?l0002;oookJPCo0?o21?l0f?l01?m_o`3o;_l0obko0?l0_?l2ool0N0CooiX01?l=0?l00ooo
01?o0?o=o`3oc@02o`3oc@Co5?l00_mY0?m;oookJP00f_oonfX2ool00003oookJ_oo003oo`0000Co
o`001OoonfXKool000?ooo]Z3_oo0003oookJP03ool00?oonf[ooo]Z06Kooo]Z4OooN@04o`3Ho`Go
olT00_oo07P4oonJ00Co3@3o00Goo`0Cooo90?oob@3o0?o=oaCo0002ooo900CoJ@3o0_oob@3ooook
JSgooo]Z1?l0002@oookJP?o0?o21?l0f?l00om_o`3o;_l0obko0002o`2lo`03ool0N?ooVP3ooiX0
00;ooiX01?l=0?l00ooo01?o0?o=o`3oc@02o`3oc@?o5?l00omY0?m7oookJP00f_oonfX00ooo003o
oo]ZoookJP03ool000Sooo]Z4Ooo0002oookJPSoo`001OoonfX;ool006gooo]Z2?ooN@06oookJPGo
olT00_l0ol84o`3Ho`GoolT00_oo07P5oonJ00?o3@3o00?oo`0Cooo90?oob@000_oob@02oaCo0004
ooo90?mY0?ooJ@3oooo90?oooo]Z>ooonfX4o`0009Cooo]Z0ol0ol83o`3Ho`04ool0Com_o`3o;_l0
obko00;o0;co00?oo`1hoonJ0?ooVP000oooVP04o`d0o`?o0?o=1?lDo`02ofT0odCooo]Z003Moook
JP03ool00?oonf[ooo]Z00Sooo]Z4Ooo00000ooonf[oo`00ool00007ool000Kooo]Z2_oo0023oook
JP03onGo0?l0ol;o0?o200Co0=So0_oob@000ol^o`3oolT0o`2lo`02ool0N003o`0DooooVP3ooiX0
00;ooiX00ol=0?l3ooo900Co5?l00omY0?l00ooonf[oolT0ooo9003ooookJSGooo]Z1?l0002Hoook
JP;o0?o21?l0f?l2ool0C`;o;_l00_l0_?l00ooo07So01CooonJ0003oonJ00Co3@3o0ol0old4oaCo
00;oJ@3o@?oonfX00>Sooo]Z0ooo0003oookJPcoo`0000?ooo]Zo`000?l000001_oo0007oookJPCo
o`0000Cooo]Zool00?oo003oo`00ROoonfX00ooob@3o0?o2o`3Ho`03o`3Ho`GoolT000?oo`1ho`0D
ool05?l01?ooVP03o`d0o`?oolT01?lDo`04ooo90?oooo]Z<ooonfX4o`0009gooo]Z00?o0?o2o`3H
ool0f?l00_l0f?l2ool0C`?o;_l000?o0;coool0N?l05?l01?ooVP04o`d0o`?o0?o=1?lDo`02ofT0
occooo]Z003boookJPSoo`0000?ooo]Zo`000?l000000_l00002oookJP;oo`002?oonfX3ool000;o
oo]Z00?oo`00oookJ_oonfX0SOoonfX00ol0ol;o0=Soo`3Ho`03o`3Ho`05ool0Com_o`3oolT0ooo9
0?l0_?l00_l05?l5oonJ00;o3@3o0_oob@000ol0olgo5?l0oaCo0003oaCo0003ofT0oooonf[ooo]Z
00;oiOl0oooonfX]oookJPCo0000XOoonfX00ol0ol;o0=Soo`3Ho`03o`3Ho`05ool0Com_o`3o;_l0
obko0?oo^`000_l05?l5oonJ00?o3@3o0ol0old4oaCo0003ofT0oooonf[ooo]Z03Oooo]Z003koook
JPCo00003OoonfX00ooo003ooo]ZoookJP2EoookJP;o0?o21Ol0f?l3ooo90004o`2lool05?oo01Co
o`0Do`CooiX00_l=0?l4ooo900Co5?l00_oUo`02oiCo0?oooo]Z:_oonfX4o`000:Gooo]Z0_l0ol85
o`3Ho`04ool0Com_o`3o;_l0oonk00?o01Co1?ooVP03o`d0o`?o0?o=1?lDo`000omY0?oooo]Zoook
JP0coookJP00nooonfX4o`000:Sooo]Z00CoolT0o`3o`_l0ol;o0?o21?l0f?l3ooo900Co01Co0ooo
VP03o`d0o`04oonD0?oob@3oolT0ooo900CoiOl00_nDo`3ooookJRSooo]Z1?l0002YoookJP?o0?o2
1?l0f?l2ool0C`;o;_l00ol05?l4oonJ00?o3@3o0ol0old4oaCo0003ofT0oooonf[ooo]Z02oooo]Z
003koookJPCo0000Z?oonfX6ooo900;o0?o21Ol0f?l2ooo900?o01Co1?ooVP03o`d0o`KoiOl00_lD
o`03oookJP;oolT0oooonfXQoookJPCo0000[_oonfX2o`3o`PGo0=So0_oo04l01?l^o`3o01Coo`0D
ool05?l3oonJ00Co3@3o0ol0old4oaCo0003oom;0?oonf[ooo]Z02_ooo]Z003koookJPCo0000[Ooo
nfX6ooo900;o0?o21?l0f?l2ooo90003oonR0?l05?oo01Co00CooiX00ooob@04onGo00Co5?l01Ooo
b@3ooookJQgooo]Z1?l0002coookJP;o0?o21?l0f?l2ool0C`03obko0?l05?oo01Co00CooiX01?l=
0?l3o`3oc@Co5?l0:_oonfX00?_ooo]Z1?l0002foookJP03oiCo0?l0ol;o0?o200Go0=So00CoolT0
obko0?l05?oo01Co0oooVP04ooo900;oiOl000?o0?o=ooo90?lDo`000_lDo`02ooo90?oooo]Z7Ooo
nfX4o`000;Oooo]Z0_l0ol85o`3Ho`;oo`1?0_l05?l4oonJ00Co3@3o0ol0old4oaCo02Kooo]Z003k
oookJPCo0000]_oonfX00onDo`3oolT0ooo90003ooo900;o0?o21?l0f?l2onGo0003o`0DooooVP3o
oiX000;ooiX00ooob@000ooUo`3oolT0ooo90003ooo90?oooo]Z7OoonfX4o`000;cooo]Z0_l0ol84
o`3Ho`;oo`1?00?o;_l0o`0DooooVP000_ooVP001?oo07So3@3oo`d0ool=0?l4o`3oc@;o5?l09?oo
nfX00?_ooo]Z1?l0002noookJP;oiOl00_l0ol84o`3Ho`;oiOl000Cooj80oonJ0?ooVP3ooiX01_oo
b@3ooookJQgooo]Z1?l00030oookJP;o0?o21?l0f?l2ool0C`03obko0?ooVP3ooiX000;ooiX01?l=
0?l2o`3ocBCooo]Z003koookJPCo0000__oonfX6onGo00;o0?o21Ol0f?l00ooUo`3ooiX0oonJ0004
oonJ0?oooo]Z7OoonfX4o`000<Cooo]Z0_l0ol85o`3Ho`;oo`1?1_ooVP0ToookJP00nooonfX4o`00
0<Gooo]Z0ooob@03o`3o`PCo0=So0ooob@3ooookJQgooo]Z1?l00039oookJP;o0?o21?l0f?l2ool0
C`;o01Co9?oonfX00?_ooo]Z1Ol00034oookJPOoolT00_l0ol84ooo90?oooo]Z7OoonfX5o`000<co
oo]Z0_l0ol84o`3HobCooo]Z003koookJPCo0000cOoonfX5ooo90?oooo]Z7OoonfX4o`000=7ooo]Z
0_l0ol8ToookJP00nooonfX4o`000<gooo]Z0ooob@02onGo0?oooo]Z7OoonfX4o`000?Oooo]Z003k
oookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goook
JP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000
mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4
o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oo
oo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooo
nf[_oookJPCo0000mooonfX00>;ooo]Z2Ol007l3oookJPGo001o2?oonfX4o`000?oooo]Ze_oonfX9
o`00O`?ooo]Z1Ol007l8oookJPCo0000mooonfX00>;ooo]Z2Ol007l2oookJPOo001o1ooonfX4o`00
0?oooo]Ze_oonfX9o`00O`;ooo]Z1ol007l7oookJPCo0000mooonfX00>;ooo]Z1?l007l7oookJP?o
001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`000?oooo]Ze_oonfX4o`00O`Oooo]Z0ol007l01?oo
nf[o001oo`00Ool007l7oookJPCo0000mooonfX00>?ooo]Z1?l007l5oookJP?o001o0ooonfX3o`00
O`Kooo]Z1?l0003ooookJ]Oooo]Z1?l007l5oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0003goook
JP00i?oonfX5o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX6o`000?oooo]Ze_oonfX5o`00O`?o
oo]Z0ol007l3oookJP?o001o1_oonfX6o`000?Gooo]Z003VoookJPCo001o0_oonfX3o`00O`?ooo]Z
0ol007l6oookJPCo0000oooonf[JoookJPCo001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000
mooonfX00>Oooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0003ooookJ]_ooo]Z0ol0
07l2oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0003goookJP00j?oonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l6oookJPCo0000oooonf[LoookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`Kooo]Z1?l0003goookJP00h_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o1_oonfX4o`000?oooo]Ze_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o1_oonfX4o`000?Oooo]Z003RoookJP?o001o0ooonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007l6oookJPCo0000oooonf[FoookJP?o001o0ooonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJPCo0000mooonfX00>;ooo]Z1?l007l2oookJP?o
001o0_oonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l0003ooookJ]Kooo]Z1?l007l2oook
JP?o001o0_oonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l0003goookJP00hooonfX7o`00
O`?ooo]Z1ol007l7oookJPCo0000oooonf[GoookJPOo001o0ooonfX7o`00O`Oooo]Z1?l0003goook
JP00i?oonfX5o`00O`Gooo]Z1Ol007l8oookJPCo0000oooonf[HoookJPGo001o1OoonfX5o`00O`So
oo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooo
nf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`00
0?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z
1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003k
oookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goook
JP00nooonfX5o`000?oooo]Zk_oonfX5o`000?Kooo]Z003koookJPCo0000oooonf[_oookJPCo0000
mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4
o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oo
oo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooo
nf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`00
0?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z
1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003k
oookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goook
JP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000
mooonfX00?_ooo]Z1Ol0003ooookJ^kooo]Z1Ol0003foookJP00nooonfX4o`000?oooo]ZkooonfX4
o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oo
oo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooo
nf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`00
0?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z
1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003k
oookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goook
JP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000
mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4
o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1Ol0003ooookJ^ko
oo]Z1Ol0003foookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooo
nf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`00
0?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z
1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003k
oookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goook
JP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000
mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4
o`000?Oooo]Z003WoookJP?o001o1?oonfX5o`00O`Sooo]Z1?l0003ooookJ]_ooo]Z0ol007l4oook
JPGo001o2?oonfX4o`000?Oooo]Z003WoookJP?o001o0ooonfX7o`00O`Oooo]Z1?l0003ooookJ]_o
oo]Z0ol007l3oookJPOo001o1ooonfX4o`000?Oooo]Z003WoookJP?o001o0ooonfX3o`00O`04oook
J_l007oo001oo`00O`Oooo]Z1?l0003ooookJ]_ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool0
07oo001o1ooonfX4o`000?Oooo]Z003RoookJPWo001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`Kooo]Z1?l0003ooookJ]Kooo]Z2Ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX4
o`000?Oooo]Z003RoookJPWo001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z1_l0003o
oookJ]Cooo]Z2Ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX6o`000?Gooo]Z003R
oookJP;o001o0ooonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX4o`000?oooo]Ze_oonfX2
o`00O`?ooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0003goookJP00hooonfX2o`00
O`;ooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0003ooookJ]Oooo]Z0_l007l2oook
JP?o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000mooonfX00>?ooo]Z0ol007l01?oonf[o
001oo`00Ool007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0003ooookJ]Oooo]Z0ol007l01?oo
nf[o001oo`00Ool007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0003goookJP00i?oonfX2o`00
O`04oookJ_l007oo001oo`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX4o`000?oooo]Zf?oonfX2
o`00O`04oookJ_l007oo001oo`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX4o`000?Oooo]Z003U
oookJPGo001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000oooonf[IoookJPGo001o0_oonfX3
o`00O`?ooo]Z0ol007l6oookJPCo0000mooonfX00>Gooo]Z1Ol007l3oookJP?o001o00Cooo]Zo`00
Ool007oo001o1ooonfX4o`000?oooo]ZfOoonfX5o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l7oookJPCo0000mooonfX00>Kooo]Z1?l007l3oookJPOo001o1ooonfX4o`000?oooo]Zf_oonfX4
o`00O`?ooo]Z1ol007l7oookJPCo0000mooonfX00>Oooo]Z0ol007l4oookJPGo001o2?oonfX4o`00
0?oooo]ZfooonfX3o`00O`Cooo]Z1Ol007l8oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oo
oo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooo
nf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`00
0?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z
1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003k
oookJPGo0000oooonf[^oookJPGo0000m_oonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goook
JP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000
mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4
o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oo
oo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooo
nf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`00
0?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z
1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003k
oookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goook
JP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPGo0000oooonf[^oookJPGo0000
m_oonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4
o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oo
oo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooo
nf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`00
0?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z
1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003k
oookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goook
JP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000
mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4
o`000?Oooo]Z003koookJPGo0000oooonf[^oookJPGo0000m_oonfX00?_ooo]Z1?l0003ooookJ^oo
oo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooo
nf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`00
0?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z
1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003k
oookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goook
JP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000
mooonfX00>Cooo]Z1Ol007l5oookJPGo001o2?oonfX4o`000?oooo]Zf?oonfX5o`00O`Gooo]Z1Ol0
07l8oookJPCo0000mooonfX00>?ooo]Z1ol007l3oookJPOo001o1ooonfX4o`000?oooo]ZeooonfX7
o`00O`?ooo]Z1ol007l7oookJPCo0000mooonfX00>?ooo]Z0ol007l2oookJP?o001o0_oonfX3o`00
O`04oookJ_l007oo001oo`00O`Oooo]Z1?l0003ooookJ]Oooo]Z0ol007l2oookJP?o001o0_oonfX3
o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l0003goookJP00h_oonfX3o`00O`?ooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX4o`000?oooo]Ze_oonfX3o`00O`?ooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX4o`000?Oooo]Z003RoookJP?o001o0ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJPKo0000oooonf[DoookJP?o001o
0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJPKo0000mOoonfX00>;ooo]Z
1?l007l2oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z1?l0003ooookJ]Ko
oo]Z1?l007l2oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z1?l0003goook
JP00h_oonfX8o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX4o`000?oooo]Ze_oonfX8o`00O`;o
oo]Z0ol007l3oookJP?o001o1_oonfX4o`000?Oooo]Z003RoookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`?ooo]Z0ol007oooookJ^3ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o0ooonfX3o`00Oooooo]Z0_oonfX00>;ooo]Z0ol007l7oookJP?o001o0ooonfX3o`00Oooo
oo]Zh?oonfX3o`00O`Oooo]Z0ol007l3oookJP?o001ooooonfX2oookJP00h_oonfX3o`00O`Oooo]Z
0ol007l3oookJP?o001ooooonf[PoookJP?o001o1ooonfX3o`00O`?ooo]Z0ol007oooookJP;ooo]Z
003SoookJP?o001o0_oonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007oooookJ^;ooo]Z
0ol007l2oookJP?o001o0_oonfX3o`00O`04oookJ_l007oo001oo`00Oooooo]Z0ooonfX00>?ooo]Z
1ol007l3oookJPOo001ooooonf[RoookJPOo001o0ooonfX7o`00Oooooo]Z0ooonfX00>Gooo]Z1?l0
07l5oookJPGo001ooooonf[UoookJPCo001o1OoonfX5o`00Oooooo]Z1?oonfX00?oooo]Zoooonf[o
oookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Z
oooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX0
0?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]Z
jooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooook
J_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooo
nf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oook
JP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooo
nf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oo
oo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003o
oookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_o
oo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[o
oookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Z
oooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX0
0?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]Z
jooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooook
J_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooo
nf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oook
JP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooo
nf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oo
oo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003o
oookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_o
oo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[o
oookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00>Kooo]Z
0ol007l5oookJPGo001ooooonf[VoookJP?o001o1OoonfX5o`00Oooooo]Z1?oonfX00>Kooo]Z0ol0
07l4oookJPOo001ooooonf[UoookJP?o001o1?oonfX7o`00Oooooo]Z0ooonfX00>Kooo]Z0ol007l3
oookJPCo001o00Cooo]Zo`00Ool007oo001ooooonf[UoookJP?o001o0ooonfX4o`00O`04oookJ_l0
07oo001oo`00Oooooo]Z0ooonfX00=Kooo]Z2_l007l6oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol0
07l6oookJPCo0000oooonf[:oookJP[o001o1_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1_oo
nfX4o`000?Oooo]Z003FoookJP[o001o1_oonfX3o`00O`Wooo]Z0ol007l6oookJPKo0000oooonf[8
oookJP[o001o1_oonfX3o`00O`Wooo]Z0ol007l6oookJPKo0000mOoonfX00>Kooo]Z0ol007l9oook
JP?o001o1_oonfX4o`000?oooo]Zf_oonfX3o`00O`Wooo]Z0ol007l6oookJPCo0000mooonfX00>Ko
oo]Z0ol007l4oookJP;o001o0_oonfX4o`00O`Kooo]Z1?l0003ooookJ][ooo]Z0ol007l4oookJP;o
001o0_oonfX4o`00O`Kooo]Z1?l0003goookJP00i_oonfX3o`00O`Cooo]Z1ol007l7oookJPCo0000
oooonf[JoookJP?o001o1?oonfX7o`00O`Oooo]Z1?l0003goookJP00i_oonfX3o`00O`Cooo]Z1_l0
07l8oookJPCo0000oooonf[JoookJP?o001o1?oonfX6o`00O`Sooo]Z1?l0003goookJP00hooonfX6
o`00O`Cooo]Z0_l007l<oookJPCo0000oooonf[GoookJPKo001o1?oonfX2o`00O`cooo]Z1?l0003g
oookJP00hooonfX6o`00O`Cooo]Z0_l007l<oookJPCo0000oooonf[GoookJPKo001o1?oonfX2o`00
O`cooo]Z1?l0003goookJP00iOoonfX4o`00O`Gooo]Z1ol007l6oookJPCo0000oooonf[IoookJPCo
001o1OoonfX7o`00O`Kooo]Z1?l0003goookJP00i_oonfX3o`00O`Gooo]Z1ol007l6oookJPCo0000
oooonf[JoookJP?o001o1OoonfX7o`00O`Kooo]Z1?l0003goookJP00nooonfX4o`000?oooo]Zkooo
nfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooook
J^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000
oooonf[_oookJPCo0000mooonfX00?_ooo]Z1Ol0003ooookJ^kooo]Z1Ol0003foookJP00nooonfX4
o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_o
oo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z
003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003g
oookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo
0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]Zkooo
nfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooook
J^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPGo0000
oooonf[^oookJPGo0000m_oonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4
o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_o
oo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z
003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003g
oookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo
0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]Zkooo
nfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooook
J^oooo]Z1?l0003goookJP00nooonfX5o`000?oooo]Zk_oonfX5o`000?Kooo]Z003koookJPCo0000
oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4
o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_o
oo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z
003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003g
oookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo
0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]Zkooo
nfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1Ol0003ooook
J^kooo]Z1Ol0003foookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000
oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4
o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_o
oo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z
003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003g
oookJP00i_oonfX3o`00O`Gooo]Z1Ol007l8oookJPCo0000oooonf[JoookJP?o001o1OoonfX5o`00
O`Sooo]Z1?l0003goookJP00i_oonfX3o`00O`Cooo]Z1ol007l7oookJPCo0000oooonf[JoookJP?o
001o1?oonfX7o`00O`Oooo]Z1?l0003goookJP00i_oonfX3o`00O`Cooo]Z0ol007l01?oonf[o001o
o`00Ool007l7oookJPCo0000oooonf[JoookJP?o001o1?oonfX3o`00O`04oookJ_l007oo001oo`00
O`Oooo]Z1?l0003goookJP00e_oonfX:o`00O`Kooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Ko
oo]Z1?l0003ooookJ/[ooo]Z2_l007l6oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPCo
0000mooonfX00=Kooo]Z2_l007l6oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPKo0000
oooonf[8oookJP[o001o1_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX6o`000?Gooo]Z
003VoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000oooonf[JoookJP?o001o0ooo
nfX3o`00O`?ooo]Z0ol007l6oookJPCo0000mooonfX00=Gooo]Z00?oo`00oookJ_oonfX03_oonfX3
o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX4o`000?oooo]Zb_oonfX00oooM`3ooo]ZoookJP0=
oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000mooonfX00=Gooo]Z00?oo`00oook
J_oonfX03_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX4o`000?oooo]Zb_oonfX00ooo
M`3ooo]ZoookJP0=oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000mooonfX00=Co
oo]Z00?oo`00oookJ_oonfX03ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX4o`000?oo
oo]ZbOoonfX00oooM`3ooo]ZoookJP0>oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPCo
0000mooonfX00=Cooo]Z00?oo`00oookJ_oonfX03?oonfX6o`00O`?ooo]Z0ol007l3oookJP?o001o
1_oonfX4o`0003Cooo]Z00?oo`00oookJ_oonfX0oooonfZBoookJP03oomg0?oonf[ooo]Z00_ooo]Z
1_l007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0000doookJP03ool04ooonf[ooo]Z0<3ooo]Z
003?oookJP;oo`000_oonfX00ooo003ooo]ZoookJP0=oookJPKo001o1?oonfX3o`00O`04oookJ_l0
07oo001oo`00O`Oooo]Z1?l0000doookJP03ool00?oonf[ooo]Z0?oooo]ZTOoonfX00oooM`3ooo]Z
oookJP0<oookJPKo001o1?oonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l0000doookJP03
ool04ooonf[ooo]Z0<3ooo]Z003?oookJPGoo`004OoonfX4o`00O`Cooo]Z1ol007l7oookJPCo0000
=?oonfX00ooo003ooo]ZoookJP3ooookJY7ooo]Z00?oogL0oookJ_oonfX03_oonfX4o`00O`Cooo]Z
1ol007l7oookJPCo0000=?oonfX00ooo01?ooo]ZoookJP30oookJP00cooonfX7ool0013ooo]Z0ol0
07l5oookJPGo001o2?oonfX4o`0001;ooo]Z00?oo`00oookJ_oonfX07ooonfX00ooo003ooo]Zoook
JP3ooookJY3ooo]Z00?oogL0oookJ_oonfX04?oonfX3o`00O`Gooo]Z1Ol007l8oookJPCo00004ooo
nfX00ooo04kooo]ZoookJP0NoookJP03ool04ooonf[ooo]Z0<3ooo]Z003>oookJPWoo`009?oonfX4
o`0001;ooo]Z00?oo`00oookJ_oonfX07_oonfX00ooo003ooo]Zool0003ooookJY7ooo]Z00?oogL0
oookJ_oonfX09OoonfX4o`0001?ooo]Z00?oo`1>oookJ_oonfX07_oonfX00ooo02coo`0CoookJP30
oookJP00c_oonfX9ool002Cooo]Z1?l0000BoookJP03ool00?oonf[ooo]Z01kooo]Z00?oo`00oook
J_oo0000oooonfZ@oookJP03oomg0?oonf[ooo]Z02Kooo]Z1?l0000CoookJP03ool0C_oonf[ooo]Z
01kooo]Z00?oo`0/ool04ooonfX0`?oonfX00<kooo]Z2?oo000UoookJPCo00004_oonfX00ooo003o
oo]Zool0000NoookJP03ool00?oonf[oo`0004Cooo]Z00?oo`00oookJ_oonfX0oooonfY9oookJP03
oomg0?oonf[ooo]Z02Kooo]Z1?l0000CoookJP03ool0C_oi0?oooo]Z01kooo]Z00?oo`0/ool04ooo
nfX0A?oonfX00olDo`3ooo]ZoookJP1ioookJP00c_oonfX7ool002Kooo]Z1?l00006oookJP03ool0
0?oonf[ooo]Z00Wooo]Z00?oo`00oookJ_oo00007_oonfX00ooo003ooo]Zool00014oookJP03ool0
0?oonf[ooo]Z0?oooo]ZB?oonfX00oooM`3ooo]ZoookJP0WoookJPCo00001_oonfX00ol0olCooo]Z
oookJP0:oookJP03ool0C_oi0?oooo]Z01kooo]Z00?oo`0/ool04ooonfX0A?oonfX00olDo`3ooo]Z
oookJP1ioookJP00c_oonfX6ool002Oooo]Z1?l00006oookJP03ool00?oonf[ooo]Z00Wooo]Z00?o
o`00oookJ_oo00007ooonfX2ool004Gooo]Z00Goo`00oookJ_oonf[ooo]Zool0003ooookJTGooo]Z
00?oogL0oookJ_oonfX09ooonfX4o`0000Kooo]Z00?o0?o4oookJ_oonfX02_oonfX00ooo04kon@3o
oookJP0OoookJP03ool04ooonf[ooo]Z04Cooo]Z00Co5?l0oookJ_oonf[oJ@3oMooonfX00<gooo]Z
1_oo000XoookJPGo00001OoonfX00ooo003ooo]ZoookJP09oookJP03ool00?oonf[oo`0001Oooo]Z
00?oo`00oookJ_oonfX01OoonfX2ool004Gooo]Z00Goo`00oookJ_oonf[ooo]Zool00006oookJP03
ool00?oonf[ooo]Z0?oooo]Z??oonfX00oooM`3ooo]ZoookJP0WoookJPGo00001OoonfX00ol0olCo
oo]ZoookJP0:oookJP03ool0C_oi0?oooo]Z01Oooo]Z00?o0?lToookJ_oonfX01OoonfX00ooo01?o
oo]ZoookJP14oookJP04oaCo0?oonf[ooo]ZofT0o`Kooo]Z00?ood/0oookJ_oonfX0K_oonfX00<go
oo]Z1Ooo000YoookJPCo00001_oonfX00ooo003ooo]ZoookJP09oookJP03ool00?oonf[oo`0001Oo
oo]Z00?oo`00oookJ_oonfX01OoonfX00ooo003ooo]Zool00003ool004;ooo]Z00Goo`00oookJ_oo
nf[ooo]Zool00005oookJP03ool00?oonf[ooo]Z0?oooo]Z>ooonfX00oooM`3ooo]ZoookJP0Xoook
JPCo00001_oonfX00ol0olCooo]ZoookJP0:oookJP03ool0C_oi0?oooo]Z01Oooo]Z00?o0?lToook
J_oonfX01OoonfX00ooo02coo`0CoookJP15oookJP04oaCo0?oonf[ooo]ZofT0o`Gooo]Z00?ood/0
oookJ_oonfX0K_oonfX00<gooo]Z1Ooo000YoookJPCo00001_oonfX00ooo003ooo]ZoookJP05oook
JPWoo`005OoonfX00ooo003ooo]ZoookJP03oookJPSoo`00@_oonfX01Ooo003ooo]ZoookJ_oonf[o
o`0000Kooo]Z00?oo`00oookJ_oonfX0oooonfXjoookJP03oomg0?oonf[ooo]Z02Sooo]Z1?l00006
oookJP03o`3oa?oonf[ooo]Z00[ooo]Z00?oo`1>ooT0oooonfX05ooonfX00ol0obCooo]ZoookJP05
oookJP03ool0;?oo01?ooo]Z04Gooo]Z00Co5?l0oookJ_oonf[oJ@3o1_oonfX00oooB`3ooo]Zoook
JP1]oookJP00cOoonfX4ool002[ooo]Z1?l00006oookJP03ool00?oonf[ooo]Z00Gooo]Z2Ooo000E
oookJP03ool00?oonf[ooo]Z00?ooo]Z2?oo0013oookJP05ool00?oonf[ooo]ZoookJ_oo00001Ooo
nfX00ooo003ooo]ZoookJP3ooookJSWooo]Z00?oogL0oookJ_oonfX0:OoonfX4o`0000Kooo]Z00?o
0?o4oookJ_oonfX02_oonfX00ooo04kon@3ooookJP0GoookJP03o`3o9?oonf[ooo]Z00Gooo]Z00?o
o`0/ool04ooonfX0AOoonfX01OlDo`3ooo]ZoookJ_oonf[oJ@3o00Gooo]Z00?ood/0oookJ_oonfX0
KOoonfX00<gooo]Z0ooo000[oookJPCo000000?ooo]Zool00?oo00001ooo0004oookJP[oo`005?oo
nfX00ooo003ooo]ZoookJP04oookJPOoo`00@ooonfX01Ooo003ooo]ZoookJ_oonf[oo`0000Kooo]Z
00?oo`00oookJ_oonfX0oooonfXhoookJP03oomg0?oonf[ooo]Z02Wooo]Z1?l00005oookJP05o`3o
a?oonf[ooo]ZoookJ_l0och02OoonfX00ooo04kon@3ooookJP0GoookJP03o`3o9?oonf[ooo]Z00Go
oo]Z00?oo`0/ool04ooonfX0A_oonfX01?lDo`3ooo]ZoookJ_mY0?l6oookJP03oom;0?oonf[ooo]Z
06cooo]Z003<oookJP?oo`00;?oonfX4o`000003oookJ_oo003oo`0000Ooo`001OoonfX9ool001Go
oo]Z00?oo`00oookJ_oonfX00ooonfX7ool000;ooo]Z00?oo`00oookJ_oonfX0?ooonfX01Ooo003o
oo]ZoookJ_oonf[oo`0000Gooo]Z00?oo`00oookJ_oonfX0oooonfXgoookJP03oomg0?oonf[ooo]Z
02[ooo]Z1?l00005oookJP05o`3oa?oonf[ooo]ZoookJ_l0och02OoonfX00ooo04kon@3ooookJP0H
oookJP03o`3o9?oonf[ooo]Z00Gooo]Z00?oo`0CoookJ_oonfX00ooonfX00ol0omcooo]ZoookJP0o
oookJP05oaCo0?oonf[ooo]ZoookJ_mY0?l01OoonfX00oooB`3ooo]ZoookJP1/oookJP00c?oonfX2
ool002gooo]Z1?l000000ooonf[oo`00ool00007ool000Gooo]Z2Ooo000EoookJP04ool00?oonf[o
oo]ZoookJPWoo`000_oonfX00ooo003ooo]ZoookJP0ooookJP05ool00?oonf[ooo]ZoookJ_oo0000
1_oonfX00ooo003ooo]ZoookJP3ooookJSKooo]Z00?oogL0oookJ_oonfX0:_oonfX4o`0000Gooo]Z
00Go0?o4oookJ_oonf[ooo]Zo`3o?P08oookJP03ool0C_oonf[on@3o01Wooo]Z00?o0?lToookJ_oo
nfX01OoonfX00ooo01?ooo]ZoookJP03oookJP03o`3og?oonf[ooo]Z043ooo]Z00Co5?l0oookJ_oo
nf[oJ@3o1_oonfX00oooB`3ooo]ZoookJP1[oookJP00c?oonfX00ooo003ooo]ZoookJP0/oookJPCo
00000_oonfX8ool000Gooo]Z2?oo000FoookJP04ool00?oonf[ooo]ZoookJPWoo`000_oonfX00ooo
003ooo]ZoookJP0ooookJP03ool00?oonf[ooo]Z00;ooo]Z00?oo`00oookJ_oonfX00ooonfX00ooo
003ooo]ZoookJP3ooookJSGooo]Z00?oogL0oookJ_oonfX0:ooonfX4o`0000Gooo]Z00Go0?o4oook
J_oonf[ooo]Zo`3o?P07oookJP04onCo0?oo04kooo]ZooT0oaWooo]Z00?o0?lToookJ_oonfX01Ooo
nfX00ooo01?ooo]ZoookJP03oookJP03o`3og?oonf[ooo]Z043ooo]Z00Go5?l0oookJ_oonf[ooo]Z
ofT0o`05oookJP03oom;0?oonf[ooo]Z06_ooo]Z003<oookJP03oomg0?oonf[ooo]Z02cooo]Z1?l0
0002oookJPSoo`001OoonfX8ool001Kooo]Z3Ooo0003oookJP03ool00?oonf[ooo]Z03oooo]Z00Go
o`00oookJ_oonf[ooo]Zool00006oookJP03ool00?oonf[ooo]Z0?oooo]Z=?oonfX00oooM`3ooo]Z
oookJP0[oookJPCo00001OoonfX01Ol0olCooo]ZoookJ_oonf[o0?ln00Oooo]Z00Coi?l0ool0C_oo
nf[on@3o6OoonfX00ol0obCooo]ZoookJP05oookJP03ool0;?oo01?ooo]Z00Cooo]Z00?o0?oLoook
J_oonfX0@?oonfX01?lDo`3ooo]ZoookJ_mY0?l6oookJP03oom;0?oonf[ooo]Z06[ooo]Z003;oook
JP03oomg0?oonf[ooo]Z02[ooo]Z00?oo`00oookJ_oonfX01?l00002oookJP_oo`000ooonfX7ool0
01?ooo]Z4?oo0003oookJP03ool00?oonf[ooo]Z03oooo]Z00Goo`00oookJ_oonf[ooo]Zool00006
oookJP03ool00?oonf[ooo]Z0?oooo]Z<ooonfX00oooM`3ooo]ZoookJP0YoookJP03oa40oooonf[o
oo]Z00Co00001OoonfX01Ol0olCooo]ZoookJ_oonf[o0?ln00Oooo]Z00Coi?l0ool0C_oonf[on@3o
6OoonfX00ol0obCooo]ZoookJP05oookJP03ool0;?oo01?ooo]Z00Cooo]Z00?o0?oLoookJ_oonfX0
@?oonfX01?lDo`3ooo]ZoookJ_mY0?l6oookJP03oom;0?oonf[ooo]Z06[ooo]Z002KoookJP03ool0
0?oonf[ooo]Z02gooo]Z00?oogL0oookJ_oonfX0:_oonfX00ooo003ooo]ZoookJP04o`0000;ooo]Z
2ooo0003oookJPOoo`004ooonfX8ool00003oookJ_oo003oo`0000Coo`001?oonfX00ooo003ooo]Z
oookJP10oookJP05ool00?oonf[ooo]ZoookJ_oo00001_oonfX00ooo003ooo]ZoookJP3ooookJS7o
oo]Z00?oogL0oookJ_oonfX0:_oonfX00olA0?oooo]ZoookJP04o`0000Gooo]Z00Go0?o4oookJ_oo
nf[ooo]Zo`3o?P07oookJP04onCo0?oo04kooo]ZooT0oaWooo]Z00?o0?lToookJ_oonfX01OoonfX0
0ooo02coo`0CoookJP04oookJP03o`3og?oonf[ooo]Z043ooo]Z00Go5?l0oookJ_oonf[ooo]ZofT0
o`06oookJP03oom;0?oonf[ooo]Z06Wooo]Z001joookJP;oo`007ooonfX00ooo003ooo]ZoookJP02
oookJP;oo`00:?oonfX00oooM`3ooo]ZoookJP0[oookJP03ool00?oonf[ooo]Z00Co00000_oonfX:
ool000Cooo]Z1_oo000EoookJPOoo`0000?ooo]Zool00?oo00001?oo0004oookJP03ool00?oonf[o
oo]Z043ooo]Z00Goo`00oookJ_oonf[ooo]Zool00006oookJP03ool00?oonf[ooo]Z0?oooo]Z1_oo
nfX2oonQ02Wooo]Z00?oogL0oookJ_oonfX0:_oonfX00olA0?oooo]ZoookJP04o`0000Gooo]Z00Go
0?o4oookJ_oonf[ooo]Zo`3o?P07oookJP04onCo0?oo04kooo]ZooT0oaWooo]Z00?o0?lToookJ_oo
nfX01OoonfX00ooo02coo`0CoookJP04oookJP03o`3og?oonf[ooo]Z047ooo]Z00Co5?l0oookJ_oo
nf[oJ@3o1_oonfX00oooB`3ooo]ZoookJP1YoookJP00NOoonfX3ool000Kooo]Z0_oo000FoookJP?o
o`0000?ooo]Zool00?oo0000:OoonfX00oooM`3ooo]ZoookJP0WoookJP?oo`0000?ooo]Zool00?oo
nfX00_oonfX4o`0000?ooo]Z2Ooo0005oookJPGoo`002_oonfX00ooo003ooo]ZoookJP08oookJPOo
o`0000?ooo]Zool00?oo00001?oo0004oookJP03ool00?oonf[ooo]Z02kooo]Z00?oo`00oookJ_oo
nfX01OoonfX00ooo003ooo]ZoookJP08oookJP03ool00?oonf[ooo]Z00;oo`001_oonfX00ooo003o
oo]ZoookJP3VoookJP;o9Ol06ooonfX00oooX@3ooo]ZoookJP0XoookJP03oomg0?oonf[ooo]Z02_o
oo]Z00?o4@3ooookJ_oonfX01?l00005oookJP05o`3oa?oonf[ooo]ZoookJ_l0och01ooonfX01?oT
o`3oo`1>oookJ_oi0?l;oookJP03ool0Hooonf[ooo]Z00_ooo]Z00?o0?lToookJ_oonfX01_oonfX0
0ooo01?ooo]ZoookJP03oookJP03o`3og?oonf[ooo]Z02oooo]Z00?oo`00oookJ_oonfX01?oonfX0
0omg0?oooo]ZoookJP08oookJP05oaCo0?oonf[ooo]ZoookJ_mY0?l01_oonfX00oooB`3ooo]Zoook
JP1XoookJP00N?oonfX5ool000?ooo]Z0_oo000GoookJPKoo`000ooonfX2ool001Wooo]Z0_oo0003
oookJP03ool00?oonf[ooo]Z00Cooo]Z00?oogL0oookJ_oonfX09ooonfX7ool00003oookJ_l0003o
000000;o00000ooonfX9ool00003oookJ_oo003oo`0000Ooo`002_oonfX00ooo003ooo]ZoookJP08
oookJPKoo`000ooonfX5ool000Gooo]Z00?oo`00oookJ_oonfX0;OoonfX00ooo003ooo]ZoookJP05
oookJP03ool00?oonf[ooo]Z00Sooo]Z1Ooo0006oookJP03ool00?oonf[ooo]Z0>Cooo]Z0_lUo`0L
oookJP03oonQ0?oonf[ooo]Z00;ooo]Z0_ool@0MoookJP03o`3oYooonf[ooo]Z00Gooo]Z00?oogL0
oookJ_oonfX0:_oonfX01?lA0?oooo]ZoookJ_oonfX4o`0000Gooo]Z00Go0?o4oookJ_oonf[ooo]Z
o`3o?P07oookJP04onCo0?oo04kooo]ZooT0o`_ooo]Z00?oo`1SoookJ_oonfX03?oonfX00ol0obCo
oo]ZoookJP05oookJP03ool04ooonf[ooo]Z00Cooo]Z00?o0?oLoookJ_oonfX0;_oonfX00ooo003o
oo]ZoookJP04oookJP03ogL0oooonf[ooo]Z00Wooo]Z00Co5?l0oookJ_oonf[oJ@3o1_oonfX00ooo
B`3ooo]ZoookJP1XoookJP00MooonfX6ool00003oookJ_oo003oo`0001Wooo]Z1ooo00000ooonf[o
o`00oookJP0JoookJP?oo`000_oonfX00ooo003ooo]ZoookJP03oookJP03oomg0?oonf[ooo]Z02So
oo]Z2Ooo0003o`0000?ooo]Z2?oo0002oookJPSoo`002ooonfX00ooo003ooo]ZoookJP09oookJPGo
o`000ooonfX5ool000Gooo]Z1?oo000]oookJP03ool00?oonf[ooo]Z00Gooo]Z00?oo`00oookJ_oo
nfX01OoonfX8ool000;ooo]Z0_oo0002oookJP03ool00?oonf[ooo]Z0>7ooo]Z0_lUo`0MoookJP03
oonQ0?oonf[ooo]Z00;ooo]Z00?ooo40oookJ_oonfX07OoonfX00ol0ojOooo]ZoookJP04oookJP03
oomg0?oonf[ooo]Z02_ooo]Z00Co4@3ooookJ_oonf[ooo]Z1?l00005oookJP05o`3oa?oonf[ooo]Z
oookJ_l0och01ooonfX01?oTo`3oo`1>oookJ_oi0?l;oookJP03ool0Hooonf[ooo]Z00cooo]Z00?o
0?lToookJ_oonfX01OoonfX00ooo02coo`0CoookJP04oookJP03o`3og?oonf[ooo]Z02oooo]Z00?o
o`00oookJ_oonfX01?oonfX00omg0?oooo]ZoookJP08oookJP05oaCo0?oo0;Kooo]ZoookJ_mY0?l0
1_oonfX00oooB`3ooo]ZoookJP1WoookJP00M_oonfX8ool001[ooo]Z2Ooo000KoookJPKoo`001_oo
nfX00oooM`3ooo]ZoookJP0XoookJPWoo`001?l00002oookJPSoo`000_oonfX8ool000_ooo]Z00?o
o`00oookJ_oonfX00ooonfX00ooo003ooo]ZoookJP03oookJPGoo`001?oonfX4ool00003oookJ_oo
003oo`0000Koo`00;OoonfX00ooo003ooo]ZoookJP05oookJP03ool00?oonf[ooo]Z00Cooo]Z3Ooo
0002oookJP03ool00?oonf[ooo]Z00;oo`00gOoonfX2obGo01gooo]Z0_ooX@04oookJP03oooa0?oo
nf[ooo]Z01gooo]Z00?o0?nWoookJ_oonfX01?oonfX00oooM`3ooo]ZoookJP0/oookJP04oa40oooo
nf[ooo]ZoookJPGo00000ooonfX01Ol0olCooo]ZoookJ_oonf[o0?ln00Sooo]Z00Coi?l0ool0C_oo
nf[on@3o2ooonfX00ooo06?ooo]ZoookJP04oookJP03o`3oL?oonf[ooo]Z00Gooo]Z00?o0?lToook
J_oonfX01OoonfX00ooo02coo`0CoookJP04oookJP03o`3og?oonf[ooo]Z02oooo]Z00?oo`00oook
J_oonfX01?oonfX00omg0?oooo]ZoookJP09oookJP04oaCo0?oonf[ooo]ZofT0o`Kooo]Z00?ood/0
oookJ_oonfX0IooonfX007Gooo]Z2_oo000HoookJP_oo`006_oonfX7ool000Cooo]Z00?oogL0oook
J_oonfX0:OoonfX8ool000Co00000ooonfX8ool000?ooo]Z1ooo000;oookJP03ool00?oonf[ooo]Z
00?ooo]Z00?oo`00oookJ_oonfX00ooonfX5ool000Cooo]Z1?oo00000ooonf[oo`00ool00006ool0
02kooo]Z00?oo`00oookJ_oonfX01OoonfX00ooo003ooo]ZoookJP03oookJPgoo`000ooonfX4ool0
0=[ooo]Z0olUo`0NoookJP03oonQ0?oonf[ooo]Z00?ooo]Z00?ooo40oookJ_oonfX07OoonfX00ol0
ojOooo]ZoookJP05oookJP03oomg0?oonf[ooo]Z02cooo]Z00Co4@3ooookJ_oonf[ooo]Z1?l00004
oookJP05o`3oa?oonf[ooo]ZoookJ_l0och02?oonfX01?oTo`3oo`1>oookJ_oi0?l;oookJP03ool0
Hooonf[ooo]Z00Cooo]Z00?o0?m`oookJ_oonfX01OoonfX00ol0obCooo]ZoookJP05oookJP03ool0
;?oo01?ooo]Z00Cooo]Z00?o0?oLoookJ_oonfX0<?oonfX00ooo003ooo]ZoookJP04oookJP03ogL0
oooonf[ooo]Z00Sooo]Z00Go5?l0ool0]_oonf[ooo]ZofT0o`06oookJP03oom;0?oonf[ooo]Z06Ko
oo]Z001doookJP_oo`005ooonfX=ool001Sooo]Z2Ooo0003oookJP03oomg0?oonf[ooo]Z02Wooo]Z
2?oo0004o`0000Cooo]Z1_oo0004oookJPOoo`002ooonfX00ooo003ooo]ZoookJP03oookJP03ool0
0?oonf[ooo]Z00Cooo]Z1?oo0005oookJP;oo`0000?oo`0CoookJ_oonfX01ooo000^oookJP03ool0
0?oonf[ooo]Z00Gooo]Z00?oo`00oookJ_oonfX01?oonfX=ool00003oookJ_oo003oo`0000?oo`00
f?oonfX2obGo023ooo]Z00?ooj40oookJ_oonfX00_oonfX2oooa01oooo]Z00?o0?nWoookJ_oonfX0
1OoonfX00oooM`3ooo]ZoookJP0]oookJP04oa40oooonf[ooo]ZoookJPCo00001?oonfX01Ol0olCo
oo]ZoookJ_oonf[o0?ln00Sooo]Z00Coi?l0ool0C_oonf[on@3o2ooonfX00ooo06?ooo]ZoookJP04
oookJP03o`3oL?oonf[ooo]Z00Gooo]Z00?o0?lToookJ_oonfX01OoonfX00ooo02coo`0CoookJP04
oookJP03o`3og?oonf[ooo]Z033ooo]Z00?oo`00oookJ_oonfX01?oonfX00omg0?oooo]ZoookJP08
oookJP05oaCo0?oo0;Kooo]ZoookJ_mY0?l01_oonfX00oooB`3ooo]ZoookJP1VoookJP00LooonfX=
ool001Kooo]Z3_oo0002oookJP;oo`004ooonfX7ool000Cooo]Z00?oogL0oookJ_oonfX0:_oonfX7
ool00003oookJ_l0003o000000;o00001?oonfX00ooo003ooo]Zool00003ool000Cooo]Z1?oo0000
0ooo04koo`00oookJP0<oookJPCoo`0000?ooo]Zool00?oonfX01OoonfX4ool000Gooo]Z0_oo0000
0ooo01?ooo]ZoookJP07ool002oooo]Z00?oo`00oookJ_oonfX01OoonfX00ooo003ooo]ZoookJP04
oookJQ?oo`00eOoonfX2obGo027ooo]Z00?ooj40oookJ_oonfX00_oonfX00oool@3ooo]ZoookJP06
oookJP;oo`375ooonfX00ol0ojOooo]ZoookJP04oookJP03oomg0?oonf[ooo]Z02kooo]Z00Co4@3o
oookJ_oonf[ooo]Z1?l00004oookJP05o`3oa?oonf[ooo]ZoookJ_l0och01ooonfX01OoTo`3ooo]Z
ool0C_oonf[on@3o00cooo]Z00?oo`1SoookJ_oonfX00ooonfX00ol0og3ooo]ZoookJP05oookJP03
o`3o9?oonf[ooo]Z00Kooo]Z00?oo`0CoookJ_oonfX01?oonfX00ol0omcooo]ZoookJP0_oookJP03
ool00?oonf[ooo]Z00Gooo]Z00?oM`3ooookJ_oonfX02?oonfX01OlDo`3oo`2foookJ_oonf[oJ@3o
00Kooo]Z00?ood/0oookJ_oonfX0IOoonfX007;ooo]Z2ooo000HoookJPooo`0000?ooo]Zool00?oo
nfX05?oonfX6ool000Gooo]Z00?oogL0oookJ_oonfX0:_oonfX7ool00003oookJ_l0003o000000;o
00001?oonfX00ooo003ooo]Zool00003ool000Cooo]Z1?oo00000ooo04koo`00oookJP08oookJPSo
o`000_oonfX00ooo003ooo]ZoookJP03oookJPCoo`001OoonfX2ool00004oookJ_oo01?ooo]Zoook
JPKoo`00;ooonfX00ooo003ooo]ZoookJP05oookJP03ool00?oonf[ooo]Z00Gooo]Z4_oo003Coook
JP;o9Ol08OoonfX2oonQ00Cooo]Z00?ooo40oookJ_oonfX01_oonfX00ooo0<Oooo]ZoookJP0Foook
JP03o`3oYooonf[ooo]Z00Gooo]Z00?oogL0oookJ_oonfX0;OoonfX00olA0?oooo]ZoookJP02oook
JPCo00001?oonfX01Ol0olCooo]ZoookJ_oonf[o0?ln00Oooo]Z00Goi?l0oookJ_oo04kooo]ZooT0
o`0<oookJP03ool0Hooonf[ooo]Z00?ooo]Z00?o0?m`oookJ_oonfX01OoonfX00ol0obCooo]Zoook
JP06oookJP03ool0;?oo01?ooo]Z00Cooo]Z00?o0?oLoookJ_oonfX0<?oonfX00ooo003ooo]Zoook
JP04oookJP03ogL0oooonf[ooo]Z00Sooo]Z00Go5?l0ool0]_oonf[ooo]ZofT0o`06oookJP03oom;
0?oonf[ooo]Z06Gooo]Z001ZoookJP;oo`001OoonfX7ool001cooo]Z4Ooo000EoookJPKoo`001Ooo
nfX00oooM`3ooo]ZoookJP0[oookJPKoo`000_oonfX4o`0000Cooo]Z00?o0?o4oookJ_oo00000_oo
0005oookJPCoo`0000?oo`1>ooT0oooonfX02?oonfX8ool000;ooo]Z00?oo`00oookJ_oonfX01?oo
nfX3ool000Kooo]Z00?oo`00oookJ_oo01<00_oonfX6ool0033ooo]Z00?oo`00oookJ_oonfX01Ooo
nfX00ooo003ooo]ZoookJP05oookJQ7oo`00dOoonfX2obGo02;ooo]Z00?ooj40oookJ_oonfX00ooo
nfX00oool@3ooo]ZoookJP06oookJP03ool0aooonf[ooo]Z01Kooo]Z00?o0?nWoookJ_oonfX01Ooo
nfX00oooM`3ooo]ZoookJP0^oookJP03oa40oooonf[ooo]Z00;ooo]Z1?l00004oookJP05o`3oa?oo
nf[ooo]ZoookJ_l0och01ooonfX01OoTo`3ooo]Zool0C_oonf[on@3o00cooo]Z00?oo`1SoookJ_oo
nfX00ooonfX00ol0og3ooo]ZoookJP05oookJP03o`3o9?oonf[ooo]Z00Kooo]Z00?oo`0/ool04ooo
nfX01?oonfX00ol0omcooo]ZoookJP0`oookJP03ool00?oonf[ooo]Z00Gooo]Z00?oM`3ooookJ_oo
nfX02?oonfX01OlDo`3oo`2foookJ_oonf[oJ@3o00Kooo]Z00?ood/0oookJ_oonfX0I?oonfX006Wo
oo]Z0ooo0002oookJP;o9Ol01?oo000PoookJP[oo`0000?ooo]Zool00?oo00001?oo000EoookJPGo
o`000_oo:003oookJP03oomg0?oonf[ooo]Z02gooo]Z1Ooo0002oookJPCo00001?oonfX00ol0olCo
oo]ZoookJP02ool000Kooo]Z0ooo00000ooo04kon@3ooookJP09oookJPOoo`000_oonfX5ool000;o
oo]Z0_oo0007oookJP03ool0;?oonf[oo`0C00?ooo]Z1Ooo000`oookJP03ool00?oonf[ooo]Z00Go
oo]Z00?oo`00oookJ_oonfX01_oonfX@ool00<kooo]Z0olUo`02oookJP;oog<07ooonfX00oooX@3o
oo]ZoookJP02oookJP;ooo402?oonfX00ooo0<Oooo]ZoookJP0GoookJP03o`3oYooonf[ooo]Z00Go
oo]Z00?oogL0oookJ_oonfX0;_oonfX00olA0?oooo]ZoookJP02oookJPCo00001?oonfX01Ol0olCo
oo]ZoookJ_oonf[o0?ln00Oooo]Z00Goi?l0oookJ_oo04kooo]ZooT0o`0<oookJP03ool0Hooonf[o
oo]Z00Cooo]Z00?o0?m`oookJ_oonfX01OoonfX00ol0obCooo]ZoookJP05oookJP03ool0;?oo01?o
oo]Z00Cooo]Z00?o0?oLoookJ_oonfX0<OoonfX00ooo003ooo]ZoookJP04oookJP03ogL0oooonf[o
oo]Z00Sooo]Z00Go5?l0ool0]_oonf[ooo]ZofT0o`06oookJP03oom;0?oonf[ooo]Z06Cooo]Z001W
oookJPKoo`0000?o9Ol0oookJ_oo00000_oo000QoookJP;oo`000_oonfX4ool000?ooo]Z2?oo000C
oookJPGoo`0000Cooo]ZoolX0?oo:03oobP00_oonfX00oooM`3ooo]ZoookJP0]oookJPCoo`000ooo
nfX4o`0000Cooo]Z00?o0?o4oookJ_oonfX00_oo0006oookJP?oo`0000?oo`1>ooT0oooonfX02Ooo
nfX>ool000;ooo]Z0_oo0007oookJP03ool0;?oonf[oo`0C00?ooo]Z1Ooo000aoookJP03ool00?oo
nf[ooo]Z00Gooo]Z00?oo`00oookJ_oonfX01OoonfXAool00<[ooo]Z0olUo`02oookJP?oog<08?oo
nfX00oooX@3ooo]ZoookJP02oookJP03oooa0?oonf[ooo]Z00Kooo]Z0_oo0<LIoookJP03o`3oYooo
nf[ooo]Z00Gooo]Z00?oogL0oookJ_oonfX0;ooonfX00olA0?oooo]ZoookJP02oookJPCo00001?oo
nfX01Ol0olCooo]ZoookJ_oonf[o0?ln00Oooo]Z00Goi?l0oookJ_oo04kooo]ZooT0o`0<oookJP03
ool0Hooonf[ooo]Z00Cooo]Z00?o0?m`oookJ_oonfX01OoonfX00ol0obCooo]ZoookJP05oookJP03
ool0;?oo01?ooo]Z00Cooo]Z00?o0?oLoookJ_oonfX0<OoonfX00ooo003ooo]ZoookJP05oookJP03
ogL0oooonf[ooo]Z00Sooo]Z00Go5?l0ool0]_oonf[ooo]ZofT0o`06oookJP03oom;0?oonf[ooo]Z
06?ooo]Z001UoookJP[oo`008_oonfX00oooX@3oo`00oookJP02oookJP?oo`001?oonfX:ool000_o
oo]Z00?oo`00oookJ_oonfX01?oonfX3ool000;ooo]Z1_oo:00`oookJPCoo`000ooonfX4o`0000Co
oo]Z00Co0?o4oookJ_oonf[oo`001ooonfX3ool00003ool0C_oi0?oooo]Z00Wooo]Z3_oo0003oook
JP03ool00?oonf[ooo]Z00Kooo]Z00?oo`0/ool04ooonfX00ooonfX4ool0037ooo]Z00?oo`00oook
J_oonfX01OoonfX00ooo003ooo]ZoookJP06oookJPWoo`0000?ooo]Zool00?oo00001?oo0037oook
JP?o9Ol00_oonfX3oomc027ooo]Z0_ooX@04oookJP03oooa0?oonf[ooo]Z00Kooo]Z00?oo`37oook
J_oonfX06?oonfX00ol0ojOooo]ZoookJP05oookJP03oomg0?oonf[ooo]Z033ooo]Z00?o4@3ooook
J_oonfX00_oonfX4o`0000Cooo]Z00Go0?o4oookJ_oonf[ooo]Zo`3o?P07oookJP05onCo0?oonf[o
o`1>oookJ_oi0?l03?oonfX00ooo06?ooo]ZoookJP04oookJP03o`3oL?oonf[ooo]Z00Gooo]Z00?o
0?lToookJ_oonfX01_oonfX00ooo01?ooo]ZoookJP04oookJP03o`3og?oonf[ooo]Z037ooo]Z00?o
o`00oookJ_oonfX01?oonfX00omg0?oooo]ZoookJP08oookJP05oaCo0?oonf[oo`2foookJ_mY0?l0
1_oonfX00oooB`3ooo]ZoookJP1SoookJP00I?oonfX:ool0027ooo]Z0_ooX@04oookJP;oo`001_oo
nfX8ool000gooo]Z00?oo`00oookJ_oonfX00ooonfX3ool000?ooo]Z1_oo:00`oookJP?oo`001?oo
nfX4o`0000?ooo]Z00Go0?o4oookJ_oonf[ooo]Zool00007oookJP?oo`0000?oo`1>ooT0oooonfX0
2_oonfX=ool000?ooo]Z00?oo`00oookJ_oonfX01_oonfX00ooo02cooo]Zool04`03oookJPCoo`00
<_oonfX00ooo003ooo]ZoookJP02ool000?ooo]Z00?oo`00oookJ_oonfX00_oo0004oookJPSoo`00
0_oonfX5ool00<Cooo]Z0olUo`02oookJP?oog<08_oonfX2oonQ00Gooo]Z00?ooo40oookJ_oonfX0
1_oonfX00ooo0<Oooo]ZoookJP0HoookJP03o`3oYooonf[ooo]Z00Kooo]Z00?oogL0oookJ_oonfX0
<?oonfX00olA0?oooo]ZoookJP02oookJPCo00000ooonfX00ol0olCooo]ZoookJP02oookJP03o`3o
?_oonf[ooo]Z00Gooo]Z00Goi?l0oookJ_oo04kooo]ZooT0o`0<oookJP03ool0Hooonf[ooo]Z00Co
oo]Z00?o0?m`oookJ_oonfX01OoonfX00ol0obCooo]ZoookJP06oookJP03ool0;?oo01?ooo]Z00Co
oo]Z00?o0?oLoookJ_oonfX0<OoonfX00ooo003ooo]ZoookJP05oookJP03ogL0oooonf[ooo]Z00Oo
oo]Z00Go5?l0oookJ_oo0;Kooo]ZofT0o`07oookJP03oom;0?oonf[ooo]Z06;ooo]Z001?oookJP;o
obP04OoonfX<ool001oooo]Z0_ooX@04oookJP03oooa0?oo003ooo]Z00Kooo]Z1_oo0008oookJP03
ool00?oonf[ooo]Z00Cooo]Z0ooo00001?oonf[oo`00ool00?oonfX2ool000?ooo]Z2?oo:00_oook
JP?oo`001?oonfX4o`0000?ooo]Z00Go0?o4oookJ_oonf[ooo]Zo`3o?P07oookJP?oo`0000?oo`1>
ooT0oooonfX02_oonfX=ool000?ooo]Z00?o0?lToookJ_oonfX01_oonfX00ooo02cooo]Zool04`04
oookJP?oo`00<_oonfX5ool000?ooo]Z1Ooo0005oookJPOoo`000ooonfX5ool00<3ooo]Z0olUo`02
oookJP?oog<08ooonfX2oonQ00Gooo]Z0_ool@07oookJP;oo`375_oonfX2ool02`?ooo]Z00?o0?nW
oookJ_oonfX01OoonfX00oooM`3ooo]ZoookJP0aoookJP03oa40oooonf[ooo]Z00;ooo]Z1?l00003
oookJP03o`3oa?oonf[ooo]Z00;ooo]Z00?o0?lnoookJ_oonfX01OoonfX01OoTo`3ooo]Zool0C_oo
nf[on@3o00cooo]Z00?oo`1SoookJ_oonfX01?oonfX00ol0og3ooo]ZoookJP05oookJP03o`3o9?oo
nf[ooo]Z00Kooo]Z00?oo`0/ool04ooonfX01?oonfX00ol0omcooo]ZoookJP0boookJP03ool00?oo
nf[ooo]Z00Cooo]Z00?oM`3ooookJ_oonfX02?oonfX01OlDo`3ooo]Zool0]_oonf[oJ@3o00Kooo]Z
00?ood/0oookJ_oonfX0H_oonfX004gooo]Z1?oo:00>oookJP03obGo0?oo003oo`0000coo`007Ooo
nfX2oonQ00Cooo]Z0_ool@08oookJPGoo`002_oonfX00ooo003ooo]ZoookJP03oookJPGoo`000ooo
nfX00ooo003ooo]ZoookJP02oookJPWoobP0;_oonfX2ool000Gooo]Z1?l00003oookJP05o`3oa?oo
nf[ooo]ZoookJ_l0och02?oonfX2ool00003ool0C_oi0?oooo]Z00[ooo]Z1Ooo00000ooonf[oo`00
ool00004ool000Cooo]Z00?o0?lToookJ_oonfX01_oonfX00ooo02cooo]Zool04`04oookJP?oo`00
<?oonfX7ool000?ooo]Z1Ooo0006oookJPKoo`001?oonfX4ool00;gooo]Z0olUo`02oookJP?oog<0
9?oonfX2oonQ00Gooo]Z0_ool@08oookJP03ool0aooonf[ooo]Z01Gooo]Z00?oo`0;oookJ_oonfX0
0_oonfX00ol0ojOooo]ZoookJP05oookJP03oomg0?oonf[ooo]Z037ooo]Z00?o4@3ooookJ_oonfX0
0ooonfX4o`0000?ooo]Z00?o0?o4oookJ_oonfX00_oonfX00ol0ockooo]ZoookJP05oookJP05onCo
0?oonf[oo`1>oookJ_oi0?l03?oonfX00ooo06?ooo]ZoookJP04oookJP03o`3oL?oonf[ooo]Z00Go
oo]Z00?o0?lToookJ_oonfX01_oonfX00ooo02coo`0CoookJP04oookJP03o`3og?oonf[ooo]Z03;o
oo]Z00?oo`00oookJ_oonfX01OoonfX00omg0?oooo]ZoookJP07oookJP05oaCo0?oonf[oo`2foook
J_mY0?l01ooonfX00oooB`3ooo]ZoookJP1QoookJP00BooonfX6oolX00_ooo]Z0olUo`0@ool001Wo
oo]Z0oooX@04oookJP;ooo402OoonfX4ool000_ooo]Z0ooo00001?oonf[oo`00ool00?oonfX6ool0
0003oookJ_oo003ooo]Z00Cooo]Z1ooo:00`oookJP;oo`001OoonfX4o`0000?ooo]Z00Go0?o4oook
J_oonf[ooo]Zo`3o?P08oookJP04ool00?oonf[oo`1>ooT0o`cooo]Z1?oo00000ooonf[oo`00ool0
0004ool000Gooo]Z00?o0?lToookJ_oonfX01_oonfX00ooo02coo`0CoookJP04oookJP;oo`00;ooo
nfXAool000Kooo]Z00?oo`00oookJ_oo00001?oo0003oookJP?oo`00^_oonfX3obGo00;ooo]Z0ooo
L`0ToookJP?ooj401OoonfX2oooa00Wooo]Z00?oo`37oookJ_oonfX03ooonfX2ol<0o`Cooo]Z00Co
o`0;oookJ_oonf[ooo]Z0_l0ojL7oookJP03oomg0?oonf[ooo]Z03;ooo]Z00?o4@3ooookJ_oonfX0
0ooonfX4o`0000?ooo]Z00?o0?o4oookJ_oonfX00_oonfX00ol0ockooo]ZoookJP05oookJP05onCo
0?oonf[oo`1>oookJ_oi0?l03?oonfX00ooo06?ooo]ZoookJP04oookJP03o`3oL?oonf[ooo]Z00Ko
oo]Z00?o0?lToookJ_oonfX01_oonfX00ooo01?ooo]ZoookJP03oookJP03o`3og?oonf[ooo]Z03;o
oo]Z00?oo`00oookJ_oonfX01OoonfX00omg0?oooo]ZoookJP08oookJP05oaCo0?oonf[oo`2foook
J_mY0?l01_oonfX00oooB`3ooo]ZoookJP1QoookJP00BOoonfX8oolX00Kooo]Z1?oo:003oomc00So
o`008?oonfX2oonQ00Gooo]Z0_ool@0:oookJP;oo`003OoonfX5ool000;ooo]Z2?oo0005oookJPOo
obP0<OoonfX00ooo003ooo]ZoookJP04oookJPCo00000ooonfX01Ol0olCooo]ZoookJ_oonf[o0?ln
00Sooo]Z00Coo`00oookJ_oo04kon@3o3?oonfX4ool00003oookJ_oo003oo`0000Coo`001OoonfX0
0ol0obCooo]ZoookJP06oookJP03ool0;?oonf[oo`0C00Cooo]Z0_oo000_oookJQ7oo`001_oonfX0
0olDo`3ooo]Zool00004ool000Cooo]Z0_oo002eoookJPGo9Ol01OooL`0UoookJP;ooj401_oonfX2
oooa00[ooo]Z00?oo`37oookJ_oonfX03ooonfX00oo30?oooo]ZoookJP03oookJP05ool02ooonf[o
oo]ZoookJ_l0ojL02?oonfX00oooM`3ooo]ZoookJP0coookJP03oa40oooonf[ooo]Z00?ooo]Z1?l0
0003oookJP03o`3oa?oonf[ooo]Z00;ooo]Z00?o0?lnoookJ_oonfX01OoonfX01OoTo`3ooo]Zool0
C_oonf[on@3o00cooo]Z00?oo`1SoookJ_oonfX01?oonfX00ol0og3ooo]ZoookJP06oookJP03o`3o
9?oonf[ooo]Z00Kooo]Z00?oo`0/ool04ooonfX01?oonfX00ol0omcooo]ZoookJP0boookJP03ool0
0?oonf[ooo]Z00Cooo]Z00?oM`3ooookJ_oonfX02?oonfX01OlDo`3ooo]Zool0]_oonf[oJ@3o00Oo
oo]Z00?ood/0oookJ_oonfX0H?oonfX003Wooo]Z0_oo:00<oookJPkoobP01_ooL`0OoookJP;oobP0
2?oonfX2oonQ00Gooo]Z0_ool@0:oookJP03ool0aooo003ooo]Z00gooo]Z1ooo00000ooonf[oo`00
ool00007ool000Cooo]Z1_oo:00boookJP03oa40oooonf[ooo]Z00Cooo]Z1Ol00002oookJP05o`3o
a?oonf[ooo]ZoookJ_l0och02?oonfX01?oTo`3ooo]Zool0C_oi0?l<oookJPCoo`000_oonfX5ool0
00Gooo]Z00?o0?lToookJ_oonfX01_oonfX00ooo02cooo]Zool04`05oookJP03ool00?oonf[ooo]Z
02kooo]Z4?oo0007oookJP03oaCo0?oo003oo`0000?oo`001OoonfX2ool00:kooo]Z1OlUo`06oomc
02Sooo]Z0_ooX@05oookJP?ooo402_oonfX2ool0aa7ooo]Z00?o``3ooookJ_oonfX00ooonfX01?oo
00_ooo]ZoookJ_oonfX2onKo00Oooo]Z00?oogL0oookJ_oonfX0=?oonfX00olA0?oooo]ZoookJP03
oookJPGo00000_oonfX01Ol0olCooo]ZoookJ_oonf[o0?ln00Sooo]Z00Goi?l0oookJ_oo04kooo]Z
ooT0o`0=oookJP03ool0Hooonf[ooo]Z00?ooo]Z00?o0?m`oookJ_oonfX01_oonfX00ol0obCooo]Z
oookJP06oookJP03ool0;?oo01?ooo]Z00Cooo]Z00?o0?oLoookJ_oonfX0<_oonfX00ooo003ooo]Z
oookJP05oookJP03ogL0oooonf[ooo]Z00Sooo]Z00Go5?l0oookJ_oo0;Kooo]ZofT0o`06oookJP03
oom;0?oonf[ooo]Z063ooo]Z000foookJPGoobP02_oonfX;oolX00Goog<09?oonfX3oolX00Kooo]Z
0_ooX@05oookJP;ooo402_oonfX2ool0aa3ooo]Z3ooo0005oookJPGoobP0;ooonfX3ool000;ooo]Z
00?o4@3ooookJ_oonfX01?oonfX4o`0000?ooo]Z00Go0?o4oookJ_oonf[ooo]Zo`3o?P08oookJP04
onCo0?oonf[oo`1>ooT0o`gooo]Z0_oo0003oookJPGoo`001OoonfX00ol0obCooo]ZoookJP06oook
JP03ool0;?oonf[oo`0C00Gooo]Z00?o0?oLoookJ_oonfX0;ooonfX?ool000Kooo]Z0_oo00001?lD
o`3oo`00ool00?mY0?l2ool000Gooo]Z00?oo`00oookJ_oonfX0Y_oonfX5obGo00Koog<0;?oonfX2
oonQ00Gooo]Z0_ool@0;oookJP;oo`374OoonfX2ol<0o`Gooo]Z00Goo`0;oookJ_oonf[ooo]ZonKo
0009oookJP03oomg0?oonf[ooo]Z03Cooo]Z00?o4@3ooookJ_oonfX00ooonfX4o`0000?ooo]Z00Go
0?o4oookJ_oonf[ooo]Zo`3o?P08oookJP05onCo0?oonf[oo`1>oookJ_oi0?l03OoonfX00ooo06?o
oo]ZoookJP03oookJP03o`3oL?oonf[ooo]Z00Kooo]Z00?o0?lToookJ_oonfX01_oonfX00ooo02co
o`0CoookJP04oookJP03o`3og?oonf[ooo]Z03?ooo]Z00?oo`00oookJ_oonfX01?oonfX00omg0?oo
oo]ZoookJP09oookJP04oaCo0?oo0;Kooo]ZofT0o`Oooo]Z00?ood/0oookJ_oonfX0GooonfX003?o
oo]Z2?oo:008oookJPOoobP01_ooL`02oolX02Gooo]Z1Ooo:0001?oonf[oobP0oolX0?oonfX2oolX
00Gooo]Z0_ool@0:oookJP;oo`374OoonfXAool000Cooo]Z1?oo:00`oookJPKoo`001_oonfX4o`00
00?ooo]Z00Go0?o4oookJ_oonf[ooo]Zo`3o?P08oookJP04onCo0?oonf[oo`1>ooT0o`gooo]Z0_oo
0004oookJPCoo`001OoonfX00ol0obCooo]ZoookJP07oookJP03ool0;?oo01?ooo]Z00Cooo]Z00?o
0?oLoookJ_oonfX0<?oonfX6ool00003oookJ_oo003oo`0000Goo`001_oonfX2ool00006oaCo0?oo
003oo`00ool00?mY0?ooo`001OoonfX00oooB`3ooo]ZoookJP2PoookJPGo9Ol01_ooL`0`oookJP;o
oj401OoonfX2oooa00_ooo]Z0_oo0<LBoookJP03ol<0oooonf[ooo]Z00Cooo]Z00Goo`0;oookJ_oo
nf[ooo]ZonKo0009oookJP03oomg0?oonf[ooo]Z03?ooo]Z00?oo`40oa40oooonfX01OoonfX4o`00
00?ooo]Z00Go0?o4oookJ_oonf[ooo]Zo`3o?P08oookJP05onCo0?oonf[oo`1>oookJ_oi0?l03Ooo
nfX00ooo06?ooo]ZoookJP03oookJP03o`3oL?oonf[ooo]Z00Kooo]Z00?o0?lToookJ_oonfX01ooo
nfX00ooo01?ooo]ZoookJP04oookJP03o`3og?oonf[ooo]Z03;ooo]Z00?oo`00oookJ_oonfX01Ooo
nfX00omg0?oooo]ZoookJP08oookJP05oaCo0?oonf[oo`2foookJ_mY0?l01_oonfX00oooB`3ooo]Z
oookJP1OoookJP00<?oonfX;oolX00Go9Ol02?oo:002oomc00SoobP09?oonfX:oolX00Gooo]Z0_oo
l@0:oookJP;oo`374_oonfXCool000;ooo]Z1?oo:00aoookJPSoo`001?oonfX4o`0000?ooo]Z00Go
0?o4oookJ_oonf[ooo]Zo`3o?P08oookJP04onCo0?oonf[oo`1>ooT0o`gooo]Z0_oo0004oookJPCo
o`001_oonfX00ol0obCooo]ZoookJP06oookJP03ool0;?oonf[oo`0C00Gooo]Z00?o0?oLoookJ_oo
nfX0<?oonfX6ool00003oookJ_oo003oo`0000Goo`001_oonfX2ool00005oaCo0?oo003oo`00ool0
0?mY0?l01_oonfX00oooB`3ooo]ZoookJP2@oookJP[o9Ol02_ooL`0coookJP?ooj401OoonfX2oooa
00_ooo]Z0_oo0<LCoookJP03ol<0oooonf[ooo]Z00Cooo]Z00Goo`0;oookJ_oonf[ooo]ZonKo0009
oookJP03oomg0?oonf[ooo]Z03Cooo]Z00?oo`40oa40oooonfX01OoonfX4o`0000?ooo]Z00Go0?o4
oookJ_oonf[ooo]Zo`3o?P08oookJP05onCo0?oonf[oo`1>oookJ_oi0?l03OoonfX00ooo06?ooo]Z
oookJP04oookJP03o`3oL?oonf[ooo]Z00Kooo]Z00?o0?lToookJ_oonfX01_oonfX00ooo02coo`0C
oookJP04oookJP03o`3og?oonf[ooo]Z03?ooo]Z00?oo`00oookJ_oonfX01?oonfX00omg0?oooo]Z
oookJP09oookJP05oaCo0?oo0;Kooo]ZoookJ_mY0?l01_oonfX00oooB`3ooo]ZoookJP1NoookJP00
:_oonfX3obGo01?oobP02ooonfX7oolX02;ooo]Z3?oo:002oookJP?oobP02_oonfX2ool0aa?ooo]Z
1ooo00000ooonf[oo`00ool00008ool000Cooo]Z0_oo:00coookJPSoo`001?oonfX4o`0000;ooo]Z
00Go0?o4oookJ_oonf[ooo]Zo`3o?P09oookJP04onCo0?oonf[oo`1>ooT0o`kooo]Z00?oo`00oook
J_oonfX00ooonfX2ool000Oooo]Z00?o0?lToookJ_oonfX01_oonfX00ooo02cooo]Zool04`05oook
JP03o`3og?oonf[ooo]Z037ooo]Z1Ooo0002oookJPKoo`001ooonfX00ooo003o5?l0ool00002ool0
0003ofT0oooonf[ooo]Z00Gooo]Z00?ood/0oookJ_oonfX0PooonfX9obGo00goog<0>_oonfX3oonQ
00Kooo]Z0_ool@0;oookJP;oo`375?oonfX00oo30?oooo]ZoookJP04oookJP05ool02ooonf[ooo]Z
oookJ_oVo`002OoonfX00oooM`3ooo]ZoookJP0eoookJP03ool10?lA0?oooo]Z00Gooo]Z1?l00002
oookJP03o`3oa?oonf[ooo]Z00;ooo]Z00?o0?lnoookJ_oonfX01_oonfX01OoTo`3ooo]Zool0C_oo
nf[on@3o00gooo]Z00?oo`1SoookJ_oonfX01?oonfX00ol0og3ooo]ZoookJP06oookJP03o`3o9?oo
nf[ooo]Z00Kooo]Z00?oo`0/ool04ooonfX01?oonfX00ol0omcooo]ZoookJP0coookJP03ool00?oo
nf[ooo]Z00Gooo]Z00?oM`3ooookJ_oonfX02?oonfX01OlDo`3ooo]Zool0]_oonf[oJ@3o00Oooo]Z
00?ood/0oookJ_oonfX0GOoonfX002[ooo]Z0_ooL`0@oolX03Oooo]Z3ooo:00;oookJP;oo`375Ooo
nfX5ool000?ooo]Z2_oo0004oookJP03oolX0?oonf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX0:?oo
nfX7ool000Gooo]Z1?l00002oookJP05o`3oa?oonf[ooo]ZoookJ_l0och02OoonfX01?oTo`3ooo]Z
ool0C_oi0?l>oookJP03ool0Hooonf[ooo]Z00?ooo]Z0_oo0007oookJP03o`3o9?oonf[ooo]Z00Ko
oo]Z00?oo`0/oookJ_oo01<01OoonfX00ol0omcooo]ZoookJP0aoookJPGoo`000ooonfX5ool000So
oo]Z00?oo`00oaCo0?oo00000_oo00000omY0?oooo]ZoookJP04oookJP03oom;0?oonf[ooo]Z08?o
oo]Z2OooL`14oookJP?ooj401_oonfX3oooa00_ooo]Z0_oo0<LDoookJP;o``3o1_oonfX00ooo00_o
oo]ZoookJP02onKo00Wooo]Z00?oogL0oookJ_oonfX0=OoonfX00ooo0@3ooo]Zoa40o`06oookJPCo
00000_oonfX00ol0olCooo]ZoookJP02oookJP03o`3o?_oonf[ooo]Z00Kooo]Z00Goi?l0oookJ_oo
04kooo]ZooT0o`0=oookJP03ool0Hooonf[ooo]Z00Cooo]Z00?o0?m`oookJ_oonfX01_oonfX00ol0
obCooo]ZoookJP06oookJP03ool0;?oo01?ooo]Z00Gooo]Z00?o0?oLoookJ_oonfX0<ooonfX00ooo
003ooo]ZoookJP04oookJP03ogL0oooonf[ooo]Z00Wooo]Z00Go5?l0ool0]_oonf[ooo]ZofT0o`06
oookJP03oom;0?oonf[ooo]Z05gooo]Z000`oookJPcoobP0=_oonfX?oolX00;oo`000_oo:006oook
JP;oo`375_oonfX4ool000;ooo]Z00?oobP0oookJ_oo00001_oo00000ooonf[oo`00ool00003ool0
0003oomg0?oo:03ooo]Z00Wooo]Z0_oo0002oookJP;oo`009OoonfX7ool000Gooo]Z1?l00002oook
JP05o`3oa?oonf[ooo]ZoookJ_l0och02OoonfX01?oTo`3ooo]Zool0C_oi0?l>oookJP03ool0Hooo
nf[ooo]Z00?ooo]Z0_oo0007oookJP03o`3o9?oonf[ooo]Z00Kooo]Z00?oo`0/oookJ_oo01<01_oo
nfX00ol0omcooo]ZoookJP0aoookJPCoo`001?oonfX4ool000Wooo]Z00Goo`00oaCo0?oo003oo`00
ofT0o`07oookJP03oom;0?oonf[ooo]Z0<gooo]Z0_ooX@06oookJP?ooo4000Cooo]ZoonR0?ooXP3o
oj802?oonfX2ool0aaGooo]Z00?o``3ooookJ_oonfX01OoonfX01Ooo00_ooo]ZoookJ_oVo`3o0?nW
00Kooo]Z0_l0A?l2oomg03Sooo]Z00?oo`40oa40oooonfX01_oonfX4o`0000;ooo]Z00?o0?o4oook
J_oonfX00_oonfX00ol0ockooo]ZoookJP06oookJP05onCo0?oonf[oo`1>oookJ_oi0?l03OoonfX0
0ooo06?ooo]ZoookJP04oookJP03o`3oL?oonf[ooo]Z00Kooo]Z00?o0?lToookJ_oonfX01_oonfX0
0ooo02coo`0CoookJP05oookJP03o`3og?oonf[ooo]Z03?ooo]Z00?oo`00oookJ_oonfX01OoonfX0
0omg0?oooo]ZoookJP09oookJP05oaCo0?oo0;Kooo]ZoookJ_mY0?l01_oonfX00oooB`3ooo]Zoook
JP1LoookJP00=OoonfX7oolX03Cooo]Z5Ooo:004oookJP;oo`375ooonfX2ool000Cooo]Z00CoobP0
ool02ooo003ooo]Z1?oo0002oookJPGoo`0000?oogL0oookJ_oonfX02OoonfX4ool00004oookJ_oo
003oo`00ool002Cooo]Z1_oo0006oookJP;o00001Ooo:003ool00003o`3o?_oonf[ooo]Z00Oooo]Z
00Coi?l0oookJ_oo:03on@3o3_oonfX00ooo06?ooo]ZoookJP04oookJP03ool00?oonf[ooo]Z00Go
oo]Z00?o0?lToookJ_oonfX01ooonfX00ooo02coo`0CoookJP05oookJP03o`3og?oonf[ooo]Z03;o
oo]Z0ooo0005oookJP?oo`002_oonfX01OlDo`3oo`00ool00?oo003oJ@3o00Oooo]Z00?ood/0oook
J_oonfX0bOoonfX3oonQ00Gooo]Z0oool@04oonR00Wooo]Z0_oo0<LFoookJP03ol<0oooonf[ooo]Z
00Cooo]Z0_oo00/2oookJP03onKo0?l0ojOooo]Z00Gooo]Z00?o04CooookJ_ooM`00>_oonfX00ooo
0@3o4@3ooookJP06oookJPCo00000_oonfX01_l0olCooo]ZoookJ_oonf[o2`3oo`3o?PSooo]Z00Go
i?l0oookJ_oo04kooo]ZooT0o`0=oookJP03ool0Hooonf[ooo]Z00Cooo]Z00?o0?m`oookJ_oonfX0
1_oonfX00ol0obCooo]ZoookJP07oookJP03ool04ooonf[ooo]Z00Cooo]Z00?o0?oLoookJ_oonfX0
<ooonfX00ooo003ooo]ZoookJP05oookJP03ogL0oooonf[ooo]Z00Wooo]Z00Go5?l0oookJ_oo0;Ko
oo]ZofT0o`07oookJP03oom;0?oonf[ooo]Z05_ooo]Z000joookJP;oobP0<ooonfXFoolX00;ooo]Z
0_oo:00GoookJP03ol<0oooo003ooo]Z00Cooo]Z00CoobP0ool02ooo:03oobP00ooo0003oookJPGo
o`0000?oogL0ool00?oo00002OoonfX:ool002?ooo]Z1Ooo0007oookJP;o00002Ooo:004ool000?o
oo]Z2Ooo:00;oookJP03ool0Hooonf[ooo]Z00Cooo]Z00?o0?m`oookJ_oonfX01_oonfX00ol0obCo
oo]ZoookJP06oookJP03ool0;?oonf[oo`0C00Gooo]Z00?o0?oLoookJ_oonfX09OoonfX00ooo003o
oo]ZoookJP0;oookJP?oo`001OoonfX3ool000Wooo]Z00?oo`00oaCo0?oo00000_oo00000omY0?oo
oo]ZoookJP04oookJP03oom;0?oonf[ooo]Z0<Kooo]Z0oooX@05oookJP?ooo400oooXP0;oookJP;o
o`375_oonfX2ol<0o`Kooo]Z00Koo`0;oookJ_oonf[ooo]ZonKo0?l0ojL6oookJP03o`14oooonf[o
ogL000oooo]Z00?oE03ooookJ_oonfX0:OoonfX00ooo0@3o4@3ooookJP06oookJPCo00000_oonfX0
1_l0olCooo]ZoookJ_oonf[o2`3oo`3o?PSooo]Z00Goi?l0oookJ_oo04kooo]ZooT0o`0>oookJP03
ool0Hooonf[ooo]Z00?ooo]Z00?o0?m`oookJ_oonfX01ooonfX00ol0obCooo]ZoookJP06oookJP03
ool0;?oo01?ooo]Z00Gooo]Z00?o0?oLoookJ_oonfX09?oonfX00ol0o`Kooo]ZoookJP0<oookJP03
ool00?oonf[ooo]Z00Gooo]Z00?oM`3ooookJ_oonfX02OoonfX01OlDo`3oo`2foookJ_oonf[oJ@3o
00Kooo]Z00?ood/0oookJ_oonfX0FooonfX006[ooo]Z1?ooX@0IoolX01Oooo]Z0_o30?l6oookJP;o
o`0;0_oo:002ool00003oolX0?oonf[ooo]Z00;ooo]Z1?oo00000oooM`3oo`00ool00002ool000So
oo]Z2ooo000RoookJPGoo`001ooonfX2o`0000WoobP01?oo0003oookJPWoobP03?oonfX00ooo06?o
oo]ZoookJP03oookJP03o`3oL?oonf[ooo]Z00Kooo]Z00?o0?lToookJ_oonfX01_oonfX00ooo02co
oo]ZoolX0005oookJP03o`3og?oonf[ooo]Z02Gooo]Z00?oo`00oookJ_oonfX03?oonfX2ool000Ko
oo]Z0_oo000:oookJP05oaCo0?oo003oo`00ool00?mY0?l01ooonfX00oooB`3ooo]ZoookJP31oook
JPCooj401OoonfX3oooa00;ooj803?oonfX3ool0aaKooo]Z0_o30?l6oookJP;oo`0;0ooonfX00ooV
o`3o0?nWoookJP05oookJP03o`14oooonf[oogL0013ooo]Z00?oE03ooookJ_oonfX0:?oonfX00ooo
0@3o4@3ooookJP07oookJPCo00000_oonfX01Ol0olCooo]ZoookJ_oonf[o0?ln00Wooo]Z00Goi?l0
oookJ_oo04kooo]ZooT0o`0>oookJP03ool0Hooonf[ooo]Z00?ooo]Z00?o0?m`oookJ_oonfX01ooo
nfX00ol0obCooo]ZoookJP06oookJP03ool0;?oo01?ooo]Z00Gooo]Z00?o0?oLoookJ_oonfX09?oo
nfX00ol0o`Kooo]ZoookJP0<oookJP03ool00?oonf[ooo]Z00Gooo]Z00?oM`3ooookJ_oonfX02Ooo
nfX00olDo`3ooo]Zool0]P02oookJP03ofT0oooonf[ooo]Z00Cooo]Z00?ood/0oookJ_oonfX0F_oo
nfX006?ooo]Z1oooX@04oookJP?ooo402?oo:003ool000[oobP05_oonfX2ol<0o`Oooo]Z00Goo`0;
oolX0?oo:03oi_l0ool00002oolX00Cooo]Z1?oo00001?ooM`3oo`00ool00?oo0009oookJPgoo`00
4?oonfX2ool000kooo]Z1Ooo0008oookJP;o00002?oo:0001?l0ockoo`00ool00?oo0004oookJP[o
obP02ooonfX00ooo06?ooo]ZoookJP03oookJP03o`3oL?oonf[ooo]Z00Kooo]Z00?o0?lToookJ_oo
nfX01_oonfX00ooo02cooo]ZoolX0006oookJP03o`3og?oonf[ooo]Z02Gooo]Z00?oo`00oookJ_oo
nfX03?oonfX00ooo003ooo]ZoookJP05oookJP03ool00?oonf[ooo]Z00Wooo]Z00Go5?l0ool00?oo
003ooo]ZofT0o`07oookJP03oom;0?oonf[ooo]Z0;Wooo]Z1oooX@04oookJPGooo400_ooXP0<oook
JP?oo`375ooonfX2ol<0o`Oooo]Z00Coo`0;oookJ_oonf[ooo]Z0_oVo`07oookJP03o`14oooonf[o
ogL0013ooo]Z00?oE03ooookJ_oonfX00ooonfX00ooo06gooo]ZoookJP0SoookJP03ool10?lA0?oo
oo]Z00Oooo]Z1?l00002oookJP05o`3oa?oonf[ooo]ZoookJ_l0och02OoonfX01OoTo`3ooo]Zool0
C_oonf[on@3o00kooo]Z00?oo`1SoookJ_oonfX01?oonfX00ol0og3ooo]ZoookJP06oookJP03o`3o
9?oonf[ooo]Z00Kooo]Z00?oo`0/ool04ooonfX01OoonfX00ol0omcooo]ZoookJP0UoookJP03o`3o
1_oonf[ooo]Z00cooo]Z00?oo`00oookJ_oonfX01OoonfX00omg0?oooo]ZoookJP09oookJP05oaCo
0?oo0;Kooo]ZoookJ_mY0?l01ooonfX00oooB`3ooo]ZoookJP1IoookJP00G?oonfX7oonQ00Kooo]Z
1Oool@02oonR00Soo`000_oonfX<oolX01Cooo]Z0_o30?l7oookJP;oo`0;0_oo:0000ooVo`3oobP0
oolX0003oolX00;ooo]Z0ooo0002oomg00;oo`002ooonfX>ool000oooo]Z1?oo000<oookJPGoo`00
2?oonfX2o`0000WoobP00ooo0005oookJPWoobP02ooonfX00ooo06?ooo]ZoookJP04oookJP03o`3o
L?oonf[ooo]Z00Gooo]Z00?o0?lToookJ_oonfX01ooonfX00ooo02coobP0oookJP05oookJP03o`3o
g?oonf[ooo]Z02Gooo]Z00?oo`00oookJ_oonfX03?oonfX00ooo003ooo]ZoookJP05oookJP03ogL0
oooonf[ooo]Z00[ooo]Z00Co5?l0ool00?oonf[oJ@3o1ooonfX00oooB`3ooo]ZoookJP2boookJPOo
oj401_oonfX5oooa00?ooj803OoonfX3ool0aaSooo]Z0_o30?l7oookJP;oo`0;0_oonfX2onKo0003
o`3oYooonf[ooo]Z00Gooo]Z00?o04Cooomg0?ooM`004?oonfX00omD0?oooo]ZoookJP04oookJP03
ool0KOoonf[ooo]Z02?ooo]Z00?oo`40oa40oooonfX01ooonfX4o`0000;ooo]Z00Go0?o4oookJ_oo
nf[ooo]Zo`3o?P09oookJP05onCo0?oonf[oo`1>oookJ_oi0?l03_oonfX00ooo06?ooo]ZoookJP04
oookJP03o`3oL?oonf[ooo]Z00Kooo]Z00?o0?lToookJ_oonfX01ooonfX00ooo02coo`0CoookJP05
oookJP03o`3og?oonf[ooo]Z02Cooo]Z00?o0?l6oookJ_oonfX03?oonfX00ooo003ooo]ZoookJP05
oookJP03ogL0oooonf[ooo]Z00[ooo]Z00Go5?l0ool0]_oonf[ooo]ZofT0o`06oookJP03oom;0?oo
nf[ooo]Z05Wooo]Z001@oookJP;oobP02_ooX@08oookJPGooo401?ooXP0<oookJPkoobP03?oonfX2
ool000Cooo]Z00?o``3ooookJ_oonfX01OoonfX2ool02`;oobP00_oVo`07oolX00?oo`0000?oogL0
ool00?oo00003?oonfX=ool0017ooo]Z1Ooo000;oookJPCoo`000_oo:007oookJP?o00003?oo:004
oookJPWoobP02ooonfX00ooo06?ooo]ZoookJP04oookJP03o`3oL?oonf[ooo]Z00Gooo]Z00?o0?lT
oookJ_oonfX01ooonfX00ooo:03ooo]ZoolX0005oookJP03o`3og?oonf[ooo]Z02Kooo]Z00?oo`00
oookJ_oonfX03?oonfX00ooo003ooo]ZoookJP05oookJP03ogL0oooonf[ooo]Z00Wooo]Z00Go5?l0
ool00?oo003ooo]ZofT0o`07oookJP03oom;0?oonf[ooo]Z0:Oooo]Z2_ooX@08oookJPGooo400ooo
XP0?oookJP?oo`376_oonfX00oo30?oooo]ZoookJP06oookJP06ool02ooonf[ooo]ZoookJ_oVo`3o
0?nW2?oonfX00ol0A?ooogL0oookJP0@oookJP03oe@0oooonf[ooo]Z00Cooo]Z00?oo`1]oookJ_oo
nfX08ooonfX00ooo0@3ooo]Zoa40o`08oookJPCo00000_oonfX01Ol0olCooo]ZoookJ_oonf[o0?ln
00Wooo]Z00Goi?l0oookJ_oo04kooo]ZooT0o`0>oookJP03ool0Hooonf[ooo]Z00Cooo]Z00?o0?m`
oookJ_oonfX01_oonfX00ol0obCooo]ZoookJP07oookJP03ool0;?oo01?ooo]Z00Gooo]Z00?o0?oL
oookJ_oonfX09OoonfX00ol0o`Kooo]ZoookJP0<oookJP03ool00?oonf[ooo]Z00Gooo]Z00?oM`3o
oookJ_oonfX02OoonfX00olDo`3oo`2foookJP02oookJP03ofT0oooonf[ooo]Z00Cooo]Z00?ood/0
oookJ_oonfX0F?oonfX004Kooo]Z3?ooX@000ooo:03ooo]ZoookJP0:oookJPGooo401?ooXP0?oook
JQ3oobP01ooonfX2oolX00;ooo]Z0ooo0002oookJP;o``3o0_oo:005oookJP03ool02ooonf[oobP0
00;oi_l01ooo:002oookJP;oo`0000?oogL0ool00?oonfX03?oonfX=ool000Wooo]Z0_oo0006oook
JPSoo`002OoonfX4ool000CoobP01OoonfX3o`0000coobP01?oonfX8oolX00cooo]Z00?oo`1Soook
J_oonfX01?oonfX00ol0og3ooo]ZoookJP06oookJP03o`3o9?oonf[ooo]Z00Kooo]Z00CoobP0oook
J_oo:03ooo]Z0ooo:002oookJP03o`3og?oonf[ooo]Z02Gooo]Z00?oo`00oookJ_oonfX03OoonfX0
0ooo003ooo]ZoookJP05oookJP03ogL0oooonf[ooo]Z00Wooo]Z00Go5?l0ool00?oonf[ooo]ZofT0
o`07oookJP03oom;0?oonf[ooo]Z09Wooo]Z3OooX@0=oookJPGooo400oooXP0AoookJP?oo`376ooo
nfX2ol<0o`Sooo]Z00?oo`0;oookJ_oonfX00_oVo`09oookJP03o`14ooooM`3ooo]Z013ooo]Z00?o
E03ooookJ_oonfX01?oonfX00ooo06gooo]ZoookJP0ToookJP03ool10?lA0?oooo]Z00Sooo]Z1?l0
0002oookJP05o`3oa?oonf[ooo]ZoookJ_l0och02OoonfX01OoTo`3ooo]Zool0C_oonf[on@3o00ko
oo]Z00?oo`1SoookJ_oonfX01?oonfX00ol0og3ooo]ZoookJP07oookJP03o`3o9?oonf[ooo]Z00Ko
oo]Z00?oo`0/ool04ooonfX01OoonfX00ol0omcooo]ZoookJP0VoookJP03o`3o1_oonf[ooo]Z00co
oo]Z00?oo`00oookJ_oonfX01OoonfX00omg0?oooo]ZoookJP09oookJP05oaCo0?oo0;Kooo]Zoook
J_mY0?l01ooonfX00oooB`3ooo]ZoookJP1GoookJP00:_oonfXLoonQ00?ooo]Z2_oo:003oookJPWo
oo401?ooXP0AoookJP;oo`372?oo:00?oookJP?oobP01_oo00000oo30?oooo]ZoolX0002oolX00?o
oo]Z0_oo00/00ooonf[oobP0onKo0006oolX00Cooo]Z0_oo00000oooM`3ooo]ZoookJP0=oookJPCo
o`0000?ooo]Zool00?oo00001?oo000:oookJPCoo`001OoonfX9ool000Sooo]Z0ooo0005oolX00Go
oo]Z0ol0000;oolX00Gooo]Z2?oo:00<oookJP03ool0Hooonf[ooo]Z00Cooo]Z00?o0?m`oookJ_oo
nfX01_oonfX00ol0obCooo]ZoookJP07oookJPKoobP00_oonfX00ol0omcooo]ZoookJP0VoookJP03
ool00?oonf[ooo]Z00cooo]Z00?oo`00oookJ_oonfX01OoonfX00omg0?oooo]ZoookJP0:oookJP04
oaCo0?oonf[ooo]ZofT0o`Oooo]Z00?ood/0oookJ_oonfX0OOoonfXLoonQ017ooo]Z2Oool@03oonR
01;ooo]Z1?oo0<LLoookJP;o``3o2?oonfX2ool02`04oookJ_oVo`3oi_l0o`3oY`Wooo]Z00?o04Co
oomg0?oonfX04?oonfX00omD0?oooo]ZoookJP04oookJP03ool0KOoonf[ooo]Z01Kooo]Z00?o0?mk
oookJ_oonfX03?oonfX00ooo0@3o4@3ooookJP08oookJPGo000000?ooo]Zo`3oa?oonfX00_oonfX0
0ol0ockooo]ZoookJP07oookJP05onCo0?oonf[oo`1>oookJ_oi0?l03ooonfX00ooo06?ooo]Zoook
JP03oookJP03o`3oL?oonf[ooo]Z00Oooo]Z00?o0?lToookJ_oonfX01_oonfX00ooo02cooo]Zool0
4`06oookJP03o`3og?oonf[ooo]Z02Gooo]Z00?o0?l6oookJ_oonfX03?oonfX00ooo003ooo]Zoook
JP05oookJP03ogL0oooonf[ooo]Z00[ooo]Z00Go5?l0oookJ_oonf[ooo]ZofT0o`06oookJP03oom;
0?oonf[ooo]Z05Oooo]Z000ZoookJPoooo403?oonfX6oolX00_ooo401_oo:002oonR017ooo]Z1Ooo
0<LGoookJPCoobP02Ooo0004oolX0004oookJ_oo00_ooo]ZoookJP;oi_l01?oo:006oookJP;oo`00
00?oogL0oookJ_oonfX03OoonfX4ool000;ooo]Z1Ooo000;oookJPKoo`000ooonfX9ool000Sooo]Z
0_oo0005oolX00Kooo]Z0ol0000;oolX00Kooo]Z1ooo:00<oookJP03ool0Hooonf[ooo]Z00Cooo]Z
00?o0?m`oookJ_oonfX01_oonfX00ooo:03ooo]ZoookJP05oookJPSoobP00_oonfX00ol0omcooo]Z
oookJP0VoookJP03ool00?oonf[ooo]Z00gooo]Z00?oo`00oookJ_oonfX01OoonfX00omg0?oooo]Z
oookJP09oookJP05oaCo0?oo0;Kooo]ZoookJ_mY0?l01ooonfX00oooB`3ooo]ZoookJP1loookJPoo
oo404_oonfX<oooa00Oooj804_oonfX5ool0aakooo]Z0_o30?l00ooonf[oohh0oon>0006oookJP05
ool02ooonf[oi_l0onKo0?l0ojL02_oonfX00ol0A?ooogL0oookJP0@oookJP03oe@0oooonf[ooo]Z
00Cooo]Z00?oo`1]oookJ_oonfX05ooonfX00ol0og_ooo]ZoookJP0<oookJP03ool10?lA0?oooo]Z
00Sooo]Z1?l00002oookJP05o`3oa?oonf[ooo]Zo`/0ool0och02OoonfX01OoTo`3ooo]Zool0C_oo
nf[on@3o00oooo]Z00?oo`1SoookJ_oonfX01?oonfX00ol0og3ooo]ZoookJP06oookJP03o`3o9?oo
nf[ooo]Z00Oooo]Z00?oo`0/ool04ooonfX01OoonfX00ol0omcooo]ZoookJP0VoookJP03o`3o1_oo
nf[ooo]Z00cooo]Z00?oo`00oookJ_oonfX01OoonfX00omg0?oooo]ZoookJP09oookJP05oaCo0?oo
0;Kooo]ZoookJ_mY0?l01ooonfX00oooB`3ooo]ZoookJP1FoookJP00:_oonfX?oonR01;ooo402?oo
:00GoookJPGoo`376_oonfX4oolX00[oo`001_oo:0000ooonf[oi_l0onKo0003oolX00Oooo]Z00Co
04Coool00?ooM`3oogL04?oonfX2ool000?ooo]Z1?oo000<oookJPSoo`000_oonfX8ool000Wooo]Z
0_oo0004oolX00Oooo]Z0ol0000;oolX00;ooo]Z2ooo:00<oookJP04ool0Hooonf[oo`00oookJP?o
o`0000?o0?m`oookJ_oonfX01_oonfX00ooo:03ooo]ZoookJP05oookJPSoobP00_oonfX00ol0omco
oo]ZoookJP0WoookJP03ool00?oonf[ooo]Z00;oo`002_oonfX00ooo003ooo]ZoookJP06oookJP03
ogL0oooonf[ooo]Z00Wooo]Z00Go5?l0ool0]_oonf[ooo]ZofT0o`07oookJP03oom;0?oonf[ooo]Z
07_ooo]Z3oooXP0Boooa00Gooj806ooonfX5ool0ab3ooo]Z0oo30?l3oon>00Kooo]Z0_oo00/00ooo
nf[oi_l0o`3oY`0:oookJP03o`14ooooM`3oogL0017ooo]Z00?oE03ooookJ_oonfX01?oonfX00ooo
06gooo]ZoookJP0GoookJP03o`3oNooonf[ooo]Z00cooo]Z00?oo`40oa40oooonfX02OoonfX4o`00
0003oookJ_l0olCooo]Z00;ooo]Z00?o2`3oo`3o?_oonfX02?oonfX01OoTo`3ooo]ZoookJ_oo04ko
n@3o00oooo]Z00?oo`1Sond0oooonfX01?oonfX00ol0og3ooo]ZoookJP06oookJP03o`3o9?oonf[o
oo]Z00Oooo]Z00?oo`0/ool04ooonfX01OoonfX00ol0omcooo]ZoookJP0VoookJP03o`3o1_oonf[o
oo]Z00cooo]Z00?oo`00oookJ_oonfX01_oonfX00omg0?oooo]ZoookJP09oookJP05oaCo0?oo0;Ko
oo]ZoookJ_mY0?l01ooonfX00oooB`3ooo]ZoookJP1EoookJP00AooonfX<oolX01;ooo]Z1Ooo0<LN
oookJPCoobP02ooo0006oolX0003onKo0?oo:03oobP000Sooo]Z0_l0A?l2oomg017ooo]Z00?oo`00
oookJ_oonfX00ooonfX3ool000gooo]Z2Ooo00000ooonf[oo`00ool00005ool000[ooo]Z00?oo`00
oolX0?oo:0000ooo:007oookJP?o00002_oo:003oookJP_oobP03?oonfX7ool00003oookJ_l0og3o
oo]Z00Kooo]Z00?oobP0oookJ_oonfX00ooo:002oookJPSoobP00ooonfX00ol0omcooo]ZoookJP0V
oookJP03ool00?oonf[oo`0000;oo`002ooonfX00ooo003ooo]ZoookJP05oookJP03ogL0oooonf[o
oo]Z00Wooo]Z00Go5?l0oookJ_oo0;Kooo]ZofT0o`07oookJP03oom;0?oonf[ooo]Z0;Oooo]Z1Ooo
0<LRoookJP?o``3o00?ooo]Zoon>0?ooSP001_oonfX3ool02`04oookJ_oVo`3oi_l0o`3oY`Wooo]Z
00?o04Cooomg0?ooM`004_oonfX00omD0?oooo]ZoookJP04oookJP03ool0KOoonf[ooo]Z01Sooo]Z
00?o0?mkoookJ_oonfX03?oonfX00ooo0@3o4@3ooookJP09oookJPCo000000?ooo]Zo`3oa?oonfX0
0_oonfX00ol;0?oo0?lnoookJP08oookJP05onCo0?oonf[ooo]Zool0C_oi0?l03ooonfX00ooo06?o
k@3ooookJP04oookJP03o`3oL?oonf[ooo]Z00Kooo]Z00?o0?lToookJ_oonfX01ooonfX00ooo02co
oo]Zool04`06oookJP03o`3og?oonf[ooo]Z02Kooo]Z00?o0?l6oookJ_oonfX03?oonfX00ooo003o
oo]ZoookJP05oookJP03ogL0oooonf[ooo]Z00Wooo]Z00?o5?l0oookJ_oo0;H00_oonfX00omY0?oo
oo]ZoookJP04oookJP03oom;0?oonf[ooo]Z05Gooo]Z000ZoookJPGoo`377OoonfX7oolX00Cooo]Z
3_oo0<LQoookJPGoobP03?oo0006oolX00Wooo]Z0_l0A?l2oomg017ooo]Z00?oE03oool00?oonfX0
1?oonfX3ool000gooo]Z4Ooo000;oookJP03ool10?oo:03oobP000;oobP02?oonfX3o`0000[oobP0
0ooonfX:oolX00_ooo]Z2Ooo00000ooonf[o0?m`oookJP06oookJPCoobP000?oo`00oolX0?oonfX0
2Ooo:003oookJP03o`3og?oonf[ooo]Z02Kooo]Z1Ooo000<oookJP03ool00?oonf[ooo]Z00Gooo]Z
00?oM`3ooookJ_oonfX02OoonfX01OlDo`3oo`2foookJ_oonf[oJ@3o00Oooo]Z00?ood/0oookJ_oo
nfX0N_oonfX5ool0abWooo]Z3_oo0<LToookJP?o``3o00Cooo]Zoon>0?ooSP3oohh01_oonfX2ool0
2`;ooo]Z0_oVo`000ol0ojOooo]ZoookJP07oookJP;o04Co00?oogL0oookJ_oonfX04?oonfX2oe@0
o`Kooo]Z00?oo`1]oookJ_oonfX03ooonfX00ol0odWoBOl0oookJP06oookJP03o`3oNooonf[ooo]Z
00gooo]Z00?oo`40oa40oooonfX02OoonfX4o`000003oookJ_l0olCooo]Z00;ooo]Z00?o2`3oo`3o
?_oonfX02?oonfX01_oTo`3ooo]ZoookJ_oo04kooo]ZooT0o`kooo]Z00?oo`1Sond0oooonfX01?oo
nfX00ol0og3ooo]ZoookJP07oookJP04o`3o9?oonf[ooo]Zo`3o30Kooo]Z00?oo`0/ool04ooonfX0
1OoonfX00ol0omcooo]ZoookJP0VoookJP03o`3o1_oonf[ooo]Z00gooo]Z00?oo`00oookJ_oonfX0
1OoonfX00omg0?oooo]ZoookJP09oookJP05oaCo0?oo0;Kooo]ZoookJ_mY0?l01ooonfX00oooB`3o
oo]ZoookJP1DoookJP00;ooonfXXool0abgooo]Z1Ooo:00?ool000GoobP01ooonfX2o`14o`;oogL0
4_oonfX00omD0?oooo]ZoookJP05oookJP03ool00?oonf[ooo]Z00gooo]Z2Ooo00000ooonf[oo`00
ool00004ool000_ooo]Z00?oo`40oolX0?oo:0000ooo:008oookJPCo00000_oo:0000ooonf[oobP0
oolX0004oolX00Cooo]Z2Ooo:00;oookJPWoo`0000?ooo]Zo`3oL?oonfX01?oonfX6oolX0003ool0
0?oo:03ooo]Z00WoobP00ooonfX00ol0omcooo]ZoookJP0UoookJPOoo`0000?ooo]Zool00?oonfX0
2?oonfX00ooo003ooo]ZoookJP06oookJP03ogL0oooonf[ooo]Z00Wooo]Z00Co5?l0ool0]_oonf[o
J@3o2?oonfX00oooB`3ooo]ZoookJP1noookJRWoo`37;ooonfX3ol<0o`;ooo]Z0_ooSP06oookJP?o
o`0;00Cooo]ZonKo0?oVo`3oi_l02_oonfX2o`14o`;oogL04_oonfX00omD0?oooo]ZoookJP05oook
JP03ool0KOoonf[ooo]Z013ooo]Z00?o0?m9odWo0?oonfX01_oonfX00ol0og_ooo]ZoookJP0<oook
JP03ool10?lA0?oooo]Z00[ooo]Z1?l000000ooonf[o0?o4oookJP02oookJP03o`/0ool0ockooo]Z
00Sooo]Z00Koi?l0oookJ_oonf[oo`1>oookJ_oi0?l>oookJP03ool0Hoo]0?oooo]Z00Gooo]Z00?o
0?m`oookJ_oonfX01_oonfX01?l0obCooo]ZoookJ_l0o``6oookJP03ool0;?oonf[oo`0C00Gooo]Z
00?o0?oLoookJ_oonfX09ooonfX00ol0o`Kooo]ZoookJP03oookJP03o`3ocOoonf[ooo]Z00Kooo]Z
00?oo`00oookJ_oonfX01_oonfX00omg0?oooo]ZoookJP09oookJP05oaCo0?oo0;Kooo]ZoookJ_mY
0?l01ooonfX00oooB`3ooo]ZoookJP1CoookJP00PooonfX5oolX00_oo`002ooo:005oookJP03o`14
oooonf[oogL001?ooo]Z00?oE03ooookJ_oonfX01?oonfX00ooo06goo`00oookJP0?oookJPSoo`00
0_oonfX5ool000cooo]Z00?oo`40oolX0?oo:0000_oo:009oookJPCo00000_oo:002oookJPCoobP0
1OoonfX9oolX00cooo]Z2?oo00000ooonf[o0?m`oookJP04oookJPOoobP000?oo`00oookJ_oo0000
2?oo:004oookJP03o`3og?oonf[ooo]Z02?ooo]Z2?oo00000ooonf[oo`00oookJP09oookJP03ool0
0?oonf[ooo]Z00Gooo]Z00?oM`3ooookJ_oonfX02OoonfX01OlDo`3ooo]Zool0]_oonf[oJ@3o00Oo
oo]Z00?ood/0oookJ_oonfX0dooonfX3ol<0o`;ooo]Z0oooSP06oookJP;oo`0;0_oonfX2onKo0003
o`3oYooonf[ooo]Z00Wooo]Z00?o04Cooomg0?ooM`004ooonfX00omD0?oooo]ZoookJP04oookJP;o
o`1]4_oonfX00ol0odWoBOl0oookJP06oookJP03o`3oNooonf[ooo]Z00gooo]Z00?oo`40oa40oooo
nfX02_oonfX4o`000003oookJ_l0olCooo]Z00;ooo]Z00?o0?lnoookJ_oonfX02?oonfX01_oTo`3o
oo]ZoookJ_oo04kooo]ZooT0o`oooo]Z00?oo`1Sond0oooonfX01?oonfX00ol0og3ooo]ZoookJP06
oookJP04o`3o9?oonf[ooo]Zo`3o30Kooo]Z00?oo`0/oookJ_oo01<01_oonfX00ol0omcooo]Zoook
JP0WoookJP03o`3o1_oonf[ooo]Z00;ooo]Z00?o0?o=oookJ_oonfX01ooonfX00ooo003ooo]Zoook
JP05oookJP03ogL0oooonf[ooo]Z00Wooo]Z00?o5?l0oookJ_oo0;H00_oonfX00omY0?oooo]Zoook
JP04oookJP03oom;0?oonf[ooo]Z05?ooo]Z001_oookJP;oobP03_oonfX3ol<0o`?oobP00_ooSP04
ool000?ooo]Z4?oo:003oookJP;o04Co0_ooM`0CoookJP03oe@0oooonf[ooo]Z00Cooo]Z00?oo`1]
oookJ_oonfX03ooonfX8ool000?ooo]Z1?oo000=oookJP04ool10?oo:03oobP0oolX00[ooo]Z1?l0
0002oolX00;ooo]Z1?oo:005oookJPWoobP03?oonfX8ool00003oookJ_l0og3ooo]Z00Gooo]Z1Ooo
:005ool000SoobP00ooonfX00ooo:03ooo]ZoookJP0SoookJPSoo`000_oonfX00ooo003ooo]Zoook
JP07oookJP03ool00?oonf[ooo]Z00Kooo]Z00?oM`3ooookJ_oonfX02OoonfX01OlDo`3ooo]Zool0
]_oonf[oJ@3o00Oooo]Z00?ood/0oookJ_oonfX0cOoonfX5ol<0o`;ooo]Z0oooSP06oookJP?oo`0;
00Cooo]ZonKo0?oVo`3oi_l03?oonfX2o`14o`03oomg0?oonf[ooo]Z017ooo]Z0_mD0?l6oookJP03
ool0KOoonf[ooo]Z017ooo]Z00?o0?m9odWo0?oonfX01_oonfX00ol0og_ooo]ZoookJP0>oookJP03
ool10?lA0?oooo]Z00[ooo]Z1?l000000ooonf[o0?o4oookJP02oookJP03o`3o?_oonf[ooo]Z00So
oo]Z00Koi?l0oookJ_oonf[oo`1>oookJ_oi0?l?oookJP03ool0Hoo]0?oooo]Z00Cooo]Z00?o0?m`
oookJ_oonfX01ooonfX01?l0obCooo]ZoookJ_l0o``6oookJP03ool0;?oo01?ooo]Z00Gooo]Z00?o
0?oLoookJ_oonfX09ooonfX00ol0o`Kooo]ZoookJP03oookJP03o`3ocOoonf[ooo]Z00Kooo]Z00?o
o`00oookJ_oonfX01_oonfX00omg0?oooo]ZoookJP09oookJP05oaCo0?oonf[oo`2foookJ_mY0?l0
1ooonfX00oooB`3ooo]ZoookJP1BoookJP00K?oonfX5oolX00Oooo]Z1oo30?l2oookJPCoohh01_oo
nfX2ool02a7oobP000?ooo]Zo`14ool0A?l00_ooM`0>oookJP;oobP00ooonfX2oe@0o`Kooo]Z00?o
o`1]oookJ_oonfX04?oonfX7ool000Cooo]Z0ooo000=oookJP03ool10?oo:03oobP000;oobP02_oo
nfX4o`000004oolX0?oonf[ooo]ZoookJPCoobP01_oonfX8oolX00gooo]Z1ooo00000ooonf[o0?m`
oookJP05oookJP?oobP01ooo0008oolX00?ooo]Z00?oobP0oookJ_oonfX09?oonfX7ool000?ooo]Z
00?oo`00oookJ_oonfX01ooonfX00ooo003ooo]ZoookJP06oookJP03ogL0oooonf[ooo]Z00Sooo]Z
00Go5?l0oookJ_oo0;Kooo]ZofT0o`08oookJP03oom;0?oonf[ooo]Z0<Kooo]Z1_o30?l2oookJPGo
ohh01_oonfX3ool02`;ooo]Z0_oVo`000ol0ojOooo]ZoookJP0:oookJP;o04Co0_ooM`0CoookJP03
oe@0oooonf[ooo]Z00Gooo]Z00?oo`1]oookJ_oonfX04OoonfX00ol0odWooo]ZodWo0007oookJP03
o`3oNooonf[ooo]Z00gooo]Z00?oo`40oa40oooonfX02ooonfX4o`000003oookJ_l0olCooo]Z00;o
oo]Z00?o0?lnoookJ_oonfX02?oonfX01_oTo`3ooo]ZoookJ_oo04kooo]ZooT0o`oooo]Z00?oo`1S
ond0oooonfX01?oonfX00ol0og3ooo]ZoookJP07oookJP04o`3o9?oonf[ooo]Zo`3o30Kooo]Z00?o
o`0/oookJ_oo01<01OoonfX00ol0omcooo]ZoookJP0XoookJP03o`3o1_oonf[ooo]Z00?ooo]Z00?o
0?o=oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP06oookJP03ogL0oooonf[ooo]Z00Sooo]Z00?o
5?l0oookJ_oo0;H00_oonfX00omY0?oooo]ZoookJP05oookJP03oom;0?oonf[ooo]Z057ooo]Z000Z
oookJPOo``3o>?oonfX8oolX0003oookJ_o30?oo``3o00Co``3o1?oonfX5oon>00Kooo]Z1?oo00/3
oookJQ7oobP00_ooM`0?oookJP?oobP00_oonfX00omD0?oooo]ZoookJP05oookJP03ool0KOoonf[o
oo]Z00Oooo]Z00?oo`00oookJ_oonfX01_oonfX7ool000Cooo]Z0ooo000;oookJP;oobP000?ooo]Z
ool10?oo:0000_oo:00;oookJPCo000000Co0?o4oookJ_oonf[ooo]Z0ooo:007oookJPOoobP03?oo
nfX2oolX00Ooo`000_oonfX00ol0og3ooo]ZoookJP04oookJP;oobP02?oo0007oolX00Cooo]Z00Co
obP0oookJ_oonf[ooo]Z0_oo:00QoookJPOoo`000_oonfX00ooo003ooo]ZoookJP08oookJP03ool0
0?oonf[ooo]Z00Gooo]Z00?oM`3ooookJ_oonfX02OoonfX01OlDo`3ooo]Zool0]_oonf[oJ@3o00Oo
oo]Z00?ood/0oookJ_oonfX0MooonfX7ol<0od;ooo]Z1_o30?l4oookJPCoohh01ooonfX4ool02`;o
oo]Z0ooVo`0=oookJP;o04Co0_ooM`0CoookJP;oE03o1ooonfX00ooo06gooo]ZoookJP0AoookJP03
o`3oBOoonf[oBOl000Oooo]Z00?o0?mkoookJ_oonfX03_oonfX00ooo0@3o4@3ooookJP0;oookJPCo
000000?ooo]Zo`3oa?oonfX00_oonfX00ol0ockooo]ZoookJP08oookJP06onCo0?oonf[ooo]Zool0
C_oonf[on@3o3ooonfX00ooo06?ok@3ooookJP04oookJP03o`3oL?oonf[ooo]Z00Oooo]Z00Co0?lT
oookJ_oonf[o0?l<1_oonfX00ooo02cooo]Zool04`06oookJP03o`3og?oonf[ooo]Z02Oooo]Z00?o
0?l6oookJ_oonfX00ooonfX00ol0olgooo]ZoookJP07oookJP03ool00?oonf[ooo]Z00Gooo]Z00?o
M`3ooookJ_oonfX02OoonfX00olDo`3ooo]Zool0]P02oookJP03ofT0oooonf[ooo]Z00Cooo]Z00?o
od/0oookJ_oonfX0DOoonfX002[ooo]Z1OooSP02oookJPgo``3o:?oonfX;oolX0003ol<0oooonf[o
oo]Z00Cooo]Z1?ooSP07oookJPCoo`0;0ooonfX00ol0ojOoi_l0onKo0004oolX00Gooo]Z1_oo:003
oomg013ooo]Z1Ooo:0000omD0?oooo]ZoookJP02oolX00;ooo]Z0_oo06d:oookJP03ool00?oonf[o
oo]Z00Kooo]Z1Ooo0006oookJP;oo`003?oonfX7oolX00?o001o2?oonfX4o`000004o`3oa?oonf[o
oo]ZoookJP?oobP01ooonfX4oolX0003ool0C_oonf[oobP000cooo]Z0ooo:006ool000;ooo]Z00?o
0?m`oookJ_oo:0000_oo:002oookJP?oobP01ooo00000ooonf[oobP0oolX0004oolX00Cooo]Z1_oo
:00RoookJPKoo`000ooonfX00ooo003ooo]ZoookJP07oookJP03ool00?oonf[ooo]Z00Kooo]Z00?o
M`3ooookJ_oonfX02OoonfX01?oo:03ooo]Zool0]_mY0?l8oookJP03oom;0?oonf[ooo]Z07Kooo]Z
1OooSP02oookJPgo``3o;OoonfX8ol<0o`Gooo]Z1OooSP06oookJPGoo`0;0_oonfX01?l0ojOoi_l0
onKo0?oVo`0=oookJP;o04Co0oooM`0DoookJP03oe@0oooonf[ooo]Z00Gooo]Z0_oo06dDoookJP03
o`3oBOm9o`3ooo]Z00Oooo]Z00?o0?mkoookJ_oonfX03_oonfX00ooo0@3o4@3oo`00O`03o`00O`So
oo]Z1?l000000ooonf[o0?o4oookJP02oookJP03o`3o?_oonf[ooo]Z00Wooo]Z00Goi?l0oookJ_oo
04kooo]ZooT0o`0?oookJP03ool0Hoo]0?oooo]Z00Gooo]Z00?o0?m`oookJ_oonfX01ooonfX01?l0
obCooo]ZoookJ_l0o``6oookJP03ool0;?oo01?ooo]Z00Gooo]Z00?o0?oLoookJ_oonfX0:?oonfX0
0ol0o`Kooo]ZoookJP03oookJP03o`3ocOoonf[ooo]Z00Kooo]Z00?oo`00oookJ_oonfX01_oonfX0
0omg0?oooo]ZoookJP09oookJP05oaCo0?oonf[oo`2foookJ_mY0?l01ooonfX00oooB`3ooo]Zoook
JP1@oookJP00:_oonfX5ool02a3oohh04Oo30?l?oookJPCo``3o5?oo:0000oooSP3ooo]ZoookJP05
oookJPCoo`0;0_oonfX2o`3oY`Coi_l02OoonfX5oolX00?oogL00ooo:00?oookJPKoobP00_oonfX3
oolX0003oookJ_oo06gooo]Z00[ooo]Z0ooo0006oookJPGoo`001ooonfX00ooo003ooo]ZoookJP0;
oookJPOoobP01?l007l7oookJPCo000000?o0?o4oookJ_oonfX00_oonfX2oolX00Oooo]Z1?oo:000
0ooo04kooo]ZoolX000=oookJP;oobP01Ooo0002oookJPKoobP00ooonfX3oolX00Koo`000_oonfX5
oolX00?ooo]Z1ooo:00SoookJPGoo`001?oonfX00ooo003ooo]ZoookJP07oookJP03ool00?oonf[o
oo]Z00Kooo]Z00?oM`3ooookJ_oonfX02?oonfX01Ooo:03ooo]ZoookJ_oo0;KoJ@3o00Sooo]Z00?o
od/0oookJ_oonfX0MOoonfX5ool02a7oohh04?o30?l@oookJP_o``3o00?ooo]Zoon>0?ooSP002_oo
SP07oookJPCoo`0;0ooonfX00ol0ojOoi_l0onKo0002onKo00gooo]Z0_l0A?l3oomg01Kooo]Z00?o
E03ooookJ_oonfX01OoonfX00ooo06gooo]ZoookJP0CoookJP03o`3oBOm9o`3ooo]Z00Oooo]Z00?o
0?mkoookJ_oonfX03_oonfX00ooo0@3o4@3oo`00O`05o`00O`Oooo]Z1?l000000ooonf[o0?o4oook
JP02oookJP03o`3o?_oonf[ooo]Z00Wooo]Z00Goi?l0oookJ_oo04kooo]ZooT0o`0@oookJP03ool0
Hoo]0?oooo]Z00Cooo]Z00?o0?m`oookJ_oonfX01ooonfX01?l0obCooo]ZoookJ_l0o``6oookJP03
ool0;?oonf[oo`0C00Kooo]Z00?o0?oLoookJ_oonfX09ooonfX00ol0o`Kooo]ZoookJP04oookJP03
o`3ocOoonf[ooo]Z00Kooo]Z00?oo`00oookJ_oonfX01_oonfX00omg0?oooo]ZoookJP08oookJP06
oaCo0?oonf[ooo]Zool0]_oonf[oJ@3o1ooonfX00oooB`3ooo]ZoookJP1?oookJP00:_oonfX5onKo
0003o`3oYooo00_oo`0;00Ooo`0;1_oonfXSoon>013oobP01_oonfX7ool02`;ooo]Z00?o0?nWonKo
0?oVo`000ooVo`0;oookJPCoobP00oooM`07oolX00gooo]Z3Ooo:00;oookJPGoo`001OoonfX4ool0
00Sooo]Z00?o0?mkoookJ_oonfX02_oonfX9oolX00?o001o1ooonfX4o`000003o`3oa?oonf[ooo]Z
00;ooo]Z00?oobP0oookJ_oonfX01ooonfX3oolX0003ool0C_oonf[on@3o00gooo]Z0ooo:004ool0
00SoobP01?oonfX2oolX00Koo`000_oonfX5oolX00;ooo]Z2?oo:00ToookJPGoo`000ooonfX01?oo
003ooo]ZoookJ_oonfX2ool000Cooo]Z00?oo`00oookJ_oonfX01_oonfX00omg0?oooo]ZoookJP09
oookJP05oolX0?oonf[oo`2foookJ_oo:0001ooonfX00oooB`3ooo]ZoookJP1eoookJPKoi_l02Ooo
00/7oookJRcoohh03?oonfX7ool02`?ooo]Z00?o0?nWonKo0?oVo`000_oVo`0>oookJP;o04Co0ooo
M`0GoookJP;oE03o1ooonfX00ooo06gooo]ZoookJP0CoookJP03o`3oBOoonf[oBOl000Sooo]Z00?o
0?mkoookJ_oonfX03_oonfX01Ooo0@3o4@3oo`00Ool007oooo]Z00?o001o1ooonfX4o`000003o`3o
a?oonf[ooo]Z00;ooo]Z00?o0?lnoookJ_oonfX02OoonfX01OoTo`3ooo]Zool0C_oonf[on@3o013o
oo]Z00?oo`1Sond0oooonfX01?oonfX00ol0og3ooo]ZoookJP07oookJP04o`3o9?oonf[ooo]Zo`3o
30Kooo]Z00?oo`0/oookJ_oo01<01_oonfX00ol0omcooo]ZoookJP0XoookJP03o`3o1_oonf[ooo]Z
00?ooo]Z00?o0?o=oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP06oookJP03ogL0oooonf[ooo]Z
00Wooo]Z00?o5?l0oookJ_oo0;H00_oonfX00omY0?oooo]ZoookJP04oookJP03oom;0?oonf[ooo]Z
04oooo]Z000_oookJPWoi_l000?o0?nWool02ooo00/03_oo00/MoookJPcoobP01_oo00/3oookJP?o
0?nW1?oVo`0?oookJP;oobP00oooM`0:oolX00_ooo]Z3ooo:00:oookJPOoo`001?oonfX3ool000So
oo]Z00?o0?mkoookJ_oonfX00ooonfX8o`00O`WoobP000Cooo]Zo`00Ool007oo001o1_oonfX4o`00
0003o`3oa?oonf[ooo]Z00;ooo]Z00?oobP0oookJ_oonfX01ooonfX3oolX0003ool0C_oonf[on@3o
00kooo]Z0_oo:004ool000SoobP01?oonfX3oolX00Goo`000ooonfX4oolX00;ooo]Z2?oo:00Uoook
JPCoo`001?oonfX00ooo003ooo]Zool00002ool000Gooo]Z00?oo`00oookJ_oonfX01_oonfX00omg
0?oooo]ZoookJP09oookJP04oolX0?oonf[oo`2foolX00Sooo]Z00?ood/0oookJ_oonfX0N_oonfX9
onKo013oo`0;9_oonfX9ool02`?ooo]Z1?l0ojL4onKo00oooo]Z0_l0A?l3oomg01Sooo]Z0_mD0?l8
oookJP03ool0KOoonf[ooo]Z01?ooo]Z00?o0?m9oookJ_m9o`002?oonfX00ol0og_ooo]ZoookJP03
oookJP[o001o0_oonfX00ooo0@3o4@3oo`00O`03oookJP?o001o1_oonfX4o`000003o`3oa?oonf[o
oo]Z00;ooo]Z00?o0?lnoookJ_oonfX02OoonfX01OoTo`3ooo]Zool0C_oonf[on@3o013ooo]Z00?o
o`1Sond0oooonfX01?oonfX00ol0og3ooo]ZoookJP07oookJP05o`3o9?oonf[ooo]ZoookJ_l0o``0
1_oonfX00ooo02coo`0CoookJP06oookJP03o`3og?oonf[ooo]Z02Oooo]Z00?o0?l6oookJ_oonfX0
1?oonfX00ol0olgooo]ZoookJP06oookJP03ool00?oonf[ooo]Z00Kooo]Z00?oM`3ooookJ_oonfX0
2OoonfX01OlDo`3ooo]Zool0]_oonf[oJ@3o00Oooo]Z00?ood/0oookJ_oonfX0C_oonfX002[ooo]Z
1?l0A?l:oomi017oi_l08_oo00/7oolX0003o`3oYooVo`3oi_l000Woi_l03ooonfX3o`14o`?oogL0
1Ooo:00BoookJQ7oobP02OoonfX8ool000;ooo]Z00?oo`00oookJ_oo00001?oonfX01Ooo:03ooo]Z
oookJ_oonf[o0?mk00Kooo]Z2?l007l8oolX00;ooo]Z0ol007l4oookJPGoo`0000?o0000o`3oa?l0
00000ooonfX00ol0ockooo]ZoookJP07oookJP?oobP000?oo`1>oookJ_oi0?l03_oonfX3oolX00?o
o`0000?ooo]ZoolX0?oo:0001Ooo:005oookJP;oobP01_oo0003oookJP?oobP00ooonfX8oolX02Go
oo]Z0ooo0004oookJPKoo`001OoonfX00ooo003ooo]ZoookJP06oookJP03ogL0oooonf[ooo]Z00Wo
oo]Z00CoobP0oookJ_oo0;KoobP02?oonfX00ooo:03ooo]ZoookJP1coookJPGo04Co2_oonfX@onKo
02Koo`0;0ooonfX2o`3oY`_oi_l03_oonfX3o`14o`CoogL06OoonfX2oe@0o`Sooo]Z0_oo06d=oook
JP;o1P3o1_oonfX00ol0odWooo]ZodWo0008oookJP03o`3oNooonf[ooo]Z00Cooo]Z2_l007l00ooo
nf[oo`40oa40o`05oookJP?o001o1_oonfX4o`000003o`3oa?l0003ooo]Z00;ooo]Z00?o0?lnoook
J_oonfX02OoonfX01OoTo`3ooo]Zool0C_oonf[on@3o013ooo]Z00?oo`1Sond0oooonfX01OoonfX0
0ol0og3ooo]ZoookJP07oookJP04o`3o9?oonf[ooo]Zo`3o30Kooo]Z00?oo`0/oookJ_oo01<01_oo
nfX00ol0omcooo]ZoookJP0XoookJP03o`3o1_oonf[ooo]Z00?ooo]Z00?o0?o=oookJ_oonfX01ooo
nfX00ooo003ooo]ZoookJP06oookJP03ogL0oooonf[ooo]Z00Wooo]Z00Go5?l0oookJ_oo0;Kooo]Z
ofT0o`07oookJP03oom;0?oonf[ooo]Z04gooo]Z000ZoookJQ3oogT03OoonfX2o`3oYbOoi_l00_oo
:0000ooVo`3ooo]ZoookJP0BoookJPGo04Co1?ooM`08oookJP;oo`003ooonfXBoolX00Sooo]Z2_oo
00000ol0odWooo]ZodWo0005oookJP;oobP00_oonfX00ol0og_ooo]ZoookJP0<oookJPOoobP00ooo
nfX3o`00O`Cooo]Z1Ooo00000ol0olCoo`00ool00002oookJP03o`/0ool0ockooo]Z00Wooo]Z00Go
obP0oookJ_oo04kooo]ZooT0o`0>oookJP?oobP00ooo00000ooonf[oobP0oolX0005oolX00Gooo]Z
0ooo:005ool000?ooo]Z0_oo:0000ooo01?ooo]ZoookJP02oookJPOoobP09_oonfX2ool000?ooo]Z
1ooo0005oookJP03ool00?oonf[ooo]Z00Kooo]Z00?oM`3ooookJ_oonfX02_oonfX01?oo:03ooo]Z
ool0]_oo:007oookJP03oolX0?oonf[ooo]Z07?ooo]Z1_ooM`06o`14oa7ooo]Z0_l0ojL[onKo01Co
oo]Z1?l0A?l4oomg01_ooo]Z0_mD0?l8oookJP;oo`1]3_oonfX00ol60?oooo]ZoookJP05oookJP03
o`3oBOoonf[oBOl000Wooo]Z00?o0?mkoookJ_oonfX03ooonfX00ooo0@3o4@3ooookJP04oookJP?o
001o1_oonfX4o`000006o`3oa?oonf[ooo]ZoookJ_l;0?oo0?ln2ooonfX01OoTo`3ooo]Zool0C_oo
nf[on@3o013ooo]Z00?oo`1Sond0oooonfX01OoonfX00ol0og3ooo]ZoookJP07oookJP04o`3o9?oo
nf[ooo]Zo`3o30Kooo]Z00?oo`0/oookJ_oo01<01ooonfX00ol0omcooo]ZoookJP0XoookJP03o`3o
1_oonf[ooo]Z00?ooo]Z00?o0?o=oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP06oookJP03ogL0
oooonf[ooo]Z00[ooo]Z00Go5?l0oookJ_oo0;Kooo]ZofT0o`06oookJP03oom;0?oonf[ooo]Z04go
oo]Z000/oookJPkoogT00ol0A?lFoookJQ3o0?nW7ooonfX5o`14o`03oookJ_ooM`3oogL000;oogL0
2_oonfX4ool000kooo]Z5?oo:006oookJPOoo`0000KoobP0ool00?oonf[o0?m9oookJ_m9o`05oook
JPCoobP000?o0?mkoookJ_oonfX03OoonfX6oolX0003o`00Oooonf[ooo]Z00Co001o1?oonfX5ool0
0003o`3oa?oo003oo`0000?oobP000?o0?lnoookJ_oonfX02?oonfX01Ooo:03ooo]ZoookJ_oo04ko
n@3o00oooo]Z0ooo:002ool000;ooo]Z1_oo:006oookJP;oobP000?ooo]Zool00?oo00000_oo0004
oookJP;oobP000?oo`0CoookJ_oonfX00_oonfX6oolX02Oooo]Z0_oo00000ooonf[oo`00ool00006
ool000Kooo]Z00?oo`00oookJ_oonfX01_oonfX00omg0?oooo]ZoookJP0:oookJP04oolX0?oo0;Ko
oo]ZoolX00Oooo]Z00?oobP0oookJ_oonfX0N?oonfX9oomg00Co04Co5_oonfX@o`3oYb3ooo]Z1Ol0
A?l4oomg01gooo]Z0_mD0?l8oookJP;oo`1]3ooonfX00ol60?oooo]ZoookJP05oookJP03o`3oBOoo
nf[oBOl000Wooo]Z00?o0?mkoookJ_oonfX04?oonfX01?oo0@3o4@3oo`00Ool007l2oookJPCo001o
1_oonfX4o`000006o`3oa?oonf[ooo]ZoookJ_l;0?oo0?ln2ooonfX01OoTo`3ooo]ZoookJ_oo04ko
n@3o017ooo]Z00?oo`1Sond0oooonfX01?oonfX00ol0og3ooo]ZoookJP07oookJP04o`3o9?oonf[o
oo]Zo`3o30Oooo]Z00?oo`0/oookJ_oo01<01_oonfX00ol0omcooo]ZoookJP0XoookJP03o`3o1_oo
nf[ooo]Z00Cooo]Z00?o0?o=oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP06oookJP03ogL0oooo
nf[ooo]Z00[ooo]Z00Go5?l0ool0]_oonf[ooo]ZofT0o`06oookJP03oom;0?oonf[ooo]Z04cooo]Z
000ZoookJPGoH03o4_ooN@06o`14ocCooo]Z1ol0A?l2oookJPCoogL03?oonfX6ool000gooo]Z1ooo
:0000ooonf[oobP0oolX0008oolX00Sooo]Z1ooo0002oolX0004oookJ_l0odWooo]ZodWo00Kooo]Z
1Ooo:00>oookJPKoobP01ol007l5oookJPGoo`0000?o0?o4ool00?oo:0000ooo:0001?l0ockoobP0
oolX0?oo:007oookJP05onCo0?oonf[ooo]Zool0C_oi0?l03ooonfX3oolX00;oo`000ooonfX5oolX
00Kooo]Z0_oo:0000ooonf[oo`00ool00002ool000Gooo]Z00?oobP0ool04ooonfX00ooonfX6oolX
02Sooo]Z00Coo`00oookJ_oonf[ooo]Z1ooo0005oookJP03ool00?oonf[ooo]Z00Oooo]Z00?oM`3o
oookJ_oonfX02OoonfX01Ooo:03ooo]Zool0]_oonf[oobP000Oooo]Z00?oobP0oookJ_oonfX0LOoo
nfX5of00o`[ooo]Z2OooM`05o`14ocCooo]Z2?l0A?l00ooonf[oogL0oomg0002oomg01oooo]Z0_mD
0?l9oookJP03ool0KOoonf[ooo]Z00gooo]Z0_l60?l7oookJP03o`3oBOoonf[oBOl000[ooo]Z00?o
0?mkoookJ_oonfX03ooonfX00ooo0@3o4@3ooookJP07o`00O`Oooo]Z1?l000001_l0olCooo]Zoook
J_oonf[o2`3oo`3o?P_ooo]Z00Goi?l0oookJ_oonf[oo`1>ooT0o`0AoookJP03ool0Hoo]0?oooo]Z
00Cooo]Z00?o0?m`oookJ_oonfX02?oonfX01?l0obCooo]ZoookJ_l0o``6oookJP03ool0;?oonf[o
o`0C00Kooo]Z00?o0?oLoookJ_oonfX0:OoonfX00ol0o`Kooo]ZoookJP03oookJP03o`3ocOoonf[o
oo]Z00Kooo]Z00?oo`00oookJ_oonfX01ooonfX00omg0?oooo]ZoookJP09oookJP03oaCo0?oonf[o
o`2f00;ooo]Z00?oJ@3ooookJ_oonfX01?oonfX00oooB`3ooo]ZoookJP1;oookJP00;ooonfX3of00
o`OoogT000?ooo]ZoolX0?oo:0000ooo:002oookJPCoogT03?ooM`02o`14oaoooo]Z1ol0A?l;oomg
00kooo]Z2Ooo000:oookJP04oe@0oooo:03oobP0oolX00Gooo]Z1ooo:00<oookJPGoo`0000?ooo]Z
oolX0?oo:0000_oo:0000ooonf[oBOl0oookJP05oookJPOoobP02ooonfX2ool000GoobP000?ooo]Z
o`00Ool007l01?l007l6oookJPGoo`0000?o0?o4ool00?oo:0000ooo:0001?l0ockoobP0oolX0?oo
:007oookJP06onCo0?oonf[ooo]Zool0C_oonf[on@3o3ooonfX3oolX0004ool00?oonf[ooo]Zoook
JPGoobP01ooonfX00ooo:03ooo]ZoookJP03ool000Gooo]Z00?oo`0/oookJ_oo01<01?oonfX5oolX
02Sooo]Z00?o0?l6oookJ_oonfX00_oonfX6ool000Kooo]Z00?oo`00oookJ_oonfX01_oonfX00omg
0?oooo]ZoookJP0:oookJP05oolX0?oonf[oo`2foookJ_oo:0001ooonfX00ooo:03ooo]ZoookJP1e
oookJPSoH03o2ooonfX@oomg0003o`14oooonf[ooo]Z01gooo]Z1ol0A?l;oomg01Gooo]Z0omP0?l9
oookJP;oE03o2OoonfX2ool0K@oooo]Z00?o1P3ooookJ_oonfX01_oonfX00ol0odWooo]ZodWo000:
oookJP03o`3oNooonf[ooo]Z013ooo]Z00?oo`40oa40oooonfX01_l007l8oookJPCo000000Ko0?o4
oookJ_oonf[ooo]Zo`/0ool0och;oookJP06onCo0?oonf[ooo]Zool0C_oonf[on@3o4?oonfX00ooo
06?ok@3ooookJP05oookJP03o`3oL?oonf[ooo]Z00Oooo]Z00Co0?lToookJ_oonf[o0?l<1_oonfX0
1?oo02cooo]ZoookJ_oo01<6oookJP03o`3og?oonf[ooo]Z02Sooo]Z00?o0?l6oookJ_oonfX01?oo
nfX00ol0olgooo]ZoookJP06oookJP03ool00?oonf[ooo]Z00Kooo]Z00?oM`3ooookJ_oonfX02_oo
nfX00olDo`3ooo]Zool0]P02oookJP03ofT0oooonf[ooo]Z00Cooo]Z00?ood/0oookJ_oonfX0B_oo
nfX002[ooo]Z1?mD0?l5oookJP;oobP01?ooN@06oolX01;ooo]Z:?ooM`0GoookJP_oo`001ooonfX3
oe@0o`Sooo]Z1Ooo:00>oookJPCoo`000_oonfX6oolX00Oooo]Z2?oo:00:oookJP;oo`001Ooo:000
0ooonf[o001oo`00O`0:oookJPGoo`0000?o0?o4oookJ_oo:0000ooo:0000ol0ockoobP0oolX0008
oookJP06onCo0?oonf[ooo]Zool0C_oonf[on@3o3ooonfX3oolX0003ond0oooonf[ooo]Z00;ooo]Z
1Ooo:006oookJP03o`3o9?oonf[ooo]Z00?oo`001_oonfX00ooo02coo`0CoookJP04oookJPCoobP0
:OoonfX00ol0o`Kooo]ZoookJP02oookJPKoo`001_oonfX00ooo:03ooo]ZoookJP06oookJP03ogL0
oooonf[ooo]Z00[ooo]Z00CoobP0oookJ_oo0;Kooo]Z0_oo:006oookJP03oolX0?oonf[ooo]Z06oo
oo]Z1?mD0?l9oookJPSoH03o4ooonfXWoomg01cooo]Z1?mP0?l9oookJP?oE03o2OoonfX2ool0KA3o
oo]Z00?o1P3ooookJ_oonfX01_oonfX00ol0odWooo]ZodWo000:oookJP03o`3oNooonf[ooo]Z013o
oo]Z00Coo`40oookJ_lA0?oooo]Z0_l007l<oookJP04o`000?ooB@3o0000o`3oa0Cooo]Z00?o2`3o
o`3o?_oonfX02_oonfX01_oTo`3ooo]ZoookJ_oo04kooo]ZooT0oa3ooo]Z00?oo`1Sond0oooonfX0
1OoonfX00ol0og3ooo]ZoookJP07oookJP04o`3o9?oonf[ooo]Zo`3o30Oooo]Z00?oo`0/oookJ_oo
01<01_oonfX00ol0omcooo]ZoookJP0YoookJP03o`3o1_oonf[ooo]Z00Cooo]Z00?o0?o=oookJ_oo
nfX01_oonfX00ooo003ooo]ZoookJP06oookJP03ogL0oooonf[ooo]Z00[ooo]Z00Go5?l0oookJ_oo
0;Kooo]ZofT0o`07oookJP03oom;0?oonf[ooo]Z04Wooo]Z000ZoookJP?oogT00_oo06d6oe@0o`?o
obP000?oogT0oolX0?oo:0001?oo:008of00ob[ooo]Z1ooo:00FoookJPgoo`001?oonfX3oe@0o`Wo
oo]Z00?oo`1]oolX0?oo:0004OoonfX2ool000Cooo]Z2?oo:005oookJP[oobP02?oonfX3ool000Co
obP00_oonfX2o`00O`[ooo]Z1Ooo00000ol0olCooo]ZoolX0002oolX0004o`3o?_oo:03oobP0oolX
00Sooo]Z00Koi?l0oookJ_oonf[oo`1>oookJ_oi0?l@oookJP;oobP000?ok@3ooookJ_oonfX00_oo
nfX5oolX00Oooo]Z00?o0?lToookJ_oonfX00_oo0006oookJP04ool0;?oonf[oo`0Cool000Cooo]Z
0ooo:0000ooo003ooo]ZoookJP0IoookJP03ool00?oonf[ooo]Z00_ooo]Z00?o0?l6oookJ_oonfX0
0_oonfX5ool000Kooo]Z00?oobP0oookJ_oonfX01ooonfX00ooo:03ooo]ZoookJP0:oookJP03oolX
0?oo0;KoobP000;oobP01ooonfX00ooo:03ooo]ZoookJP1^oookJPKoo`1]1OmD0?l:oookJPSoH03o
BooonfX3of00o`[ooo]Z0omD0?l:oookJP;oo`1]4OoonfX00ol60?oooo]ZoookJP06oookJP03o`3o
BOoonf[oBOl000_ooo]Z00?o0?mkoookJ_oonfX04?oonfX01?oo0@3o4@3ooookJ_oonfX2o`00O`co
oo]Z00Co0000oom90?l0003o0?o41?oonfX00ol;0?oo0?lnoookJP0:oookJP06onCo0?oonf[ooo]Z
ool0C_oonf[on@3o4?oonfX00ooo06?ok@3ooookJP05oookJP03o`3oL?oonf[ooo]Z00Sooo]Z00Co
0?lToookJ_oonf[o0?l<1_oonfX01?oo02cooo]Zool04ol0N_l6oookJP03o`3og?l=0?oooo]Z01_o
oo]Z00?oo`/0oookJ_oonfX02ooonfX00ol0o`Kooo]ZoookJP03oookJP03o`3ocOoonf[ooo]Z00Ko
oo]Z00?oo`00oookJ_oonfX01ooonfX00omg0?oooo]ZoookJP0:oookJP05oaCo0?oo0;Kooo]Zoook
J_mY0?l01ooonfX00oooB`3ooo]ZoookJP18oookJP00:_oonfX4olGo0003oookJ_oo06goo`1]00Go
o`1]1_mD0?l3oolX00Sooo]Z2?mP0?lOoookJP[oobP05?oonfX@ool00003oookJ_mD0?ooE03o00Wo
oo]Z0ooo06dBoookJP03o`H0oooo003ooo]Z00Cooo]Z2_oo:004oookJPSoobP02_oonfX3ool000?o
obP000Coo`00oookJ_oonf[ooo]Z1ol007l4oookJPGoo`0000?o0?o4oookJ_oonfX00_oo:0001?l0
ockoobP0oolX0?oo:008oookJP06onCo0?oonf[ooo]Zool0C_oonf[on@3o4?oonfX2oolX0003oook
J_o]0?oooo]Z00?ooo]Z1?oo:007oookJP05o`3o9?oonf[ooo]ZoookJ_oo00001ooonfX00ooo02co
o`0Cool00002oookJP;oo`000ooo:0001?oo003ooo]ZoookJ_oonfX2ool001Kooo]Z00?oo`00oook
J_oonfX03?oonfX00ol0o`Kooo]ZoookJP02oookJPCoo`001ooonfX00ooo:03ooo]ZoookJP06oook
JP03oolX0?oonf[ooo]Z00_ooo]Z1Ooo:003oookJP;oobP00_oonfX00ooo:03ooo]ZoookJP1]oook
JPGoaOl000?ooo]Zool0KOoo06d01Ooo06d5oe@0o`03o`3oSOoonf[ooo]Z00Sooo]Z2?mP0?looook
JPCoH03o2ooonfX2oe@0o`[ooo]Z0ooo06dAoookJP;o1P3o2?oonfX00ol0odWooo]ZodWo000;oook
JP03o`3oNooonf[ooo]Z017ooo]Z00?oo`40oa40oooonfX00_oonfX7o`00O`Kooo]Z00Co0000oom9
0?l0003o0?o41?oonfX00ol;0?oo0?lnoookJP0:oookJP06onCo0?oonf[ooo]Zool0C_oonf[on@3o
4OoonfX00ooo06?ok@3ooookJP05oookJP03o`3oL?oonf[ooo]Z00Oooo]Z00Co0?lToookJ_oonf[o
0?l<1ooonfX00ooo02cooo]Zool04`06oookJP03o`3og?l=0?oooo]Z01_ooo]Z00?oo`/0oookJ_oo
nfX03?oonfX00ol0o`Kooo]ZoookJP03oookJP03o`3ocOoonf[ooo]Z00Kooo]Z00?oo`00oookJ_oo
nfX01_oonfX00omg0?oooo]ZoookJP0;oookJP05oaCo0?oo0;Kooo]ZoookJ_mY0?l01ooonfX00ooo
B`3ooo]ZoookJP17oookJP00;_oonfX7olGo0003oolX0?oo06goo`1]00Coo`1]2OmD0?l00ooo:03o
oo]ZoookJP07oookJPooH03o3?oonfX2oolX00?oo`002Ooo:00;oookJPSoH03o3ooo0003oe@0o`Wo
oo]Z0_oo06d<oookJP;oobP01OoonfX2o`H0o`Kooo]Z3?oo:002oookJPSoobP02ooonfX2ool000?o
obP00ooo0002oookJPOo001o1OoonfX4ool00003o`3oa?oonf[ooo]Z00;oobP000?o0?lnoolX0?oo
:0002OoonfX01_oTo`3ooo]ZoookJ_oo04kooo]ZooT0oa3ooo]Z0_oo:0000ooonf[ok@3ooookJP03
oookJPCoobP02?oonfX01?l0obCooo]ZoookJ_l0o``7oookJP03ool0;?oonf[oo`0C00Coo`0000Co
oo]ZoolX0?oo:03oobP01Ooo000GoookJP03ool00?oonf[ooo]Z00cooo]Z00?o0?l6oookJ_oonfX0
0_oonfX4ool000Oooo]Z00?oobP0oookJ_oonfX01_oonfX00ooo:03ooo]ZoookJP09oookJPKoobP0
0_oonfX3oolX00?ooo]Z00?oobP0oookJ_oonfX0L?oonfX00ol]0?ooaOl0olGo0005olGo0003oook
J_oo06goo`1]00Coo`1]2?mD0?l00ol0ohgooo]ZoookJP07oookJPooH03o9_oonfX:of00o`cooo]Z
0omD0?l9oookJP?oo`1]4_oonfX2o`H0o`Sooo]Z0_l0odT2odWo00_ooo]Z00?o0?mkoookJ_oonfX0
4OoonfX00ooo0@3ooo]Zoa40o`03oookJPOo001o1_oonfX01?l0003oodT0o`000?l0ol@4oookJP03
o`/0ool0ockooo]Z00[ooo]Z00Koi?l0oookJ_oonf[oo`1>oookJ_oi0?lAoookJP03ool0Hoo]0?oo
oo]Z00Gooo]Z00?o0?m`oookJ_oonfX01ooonfX01?l0obCooo]ZoookJ_l0o``7oookJP04ool0;?oo
nf[oo`0Co`1jo`Kooo]Z00?o0?oLo`d0oooonfX06ooonfX00ooo2`3ooo]ZoookJP0;oookJP03o`3o
1_oonf[ooo]Z00Cooo]Z00?o0?o=oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP06oookJP03ogL0
oooonf[ooo]Z00_ooo]Z00Go5?l0ool0]_oonf[ooo]ZofT0o`07oookJP03oom;0?oonf[ooo]Z04Ko
oo]Z000ZoookJPCo1P3o1OoonfX2obd0o`OoaOl01ooo06d2oookJPSoE03o0ol0ohd>oookJPWoH03o
2?oo000=oolX00OoH03o4_oonfX5oe@0o`[ooo]Z0_oo06d=oookJP?oobP00ooonfX2o`H0o`Oooo]Z
2ooo:004oookJPKoobP03?oonfX3ool000;oobP00ooo000?oookJPCoo`0000?o0?o4oookJ_oonfX0
0_oo:0000ol0ockoobP0oolX000:oookJP05onCo0?oonf[oo`1>oookJ_oi0?l04OoonfX00ooo:03o
oo]Zond0o`05oookJP?oobP02?oonfX01Ol0obCooo]ZoookJ_oonf[o0?l<00Kooo]Z00?oo`0/ool0
0?oo01<01?oo0002oookJP;oobP01Ooo000HoookJP03ool00?oonf[ooo]Z00_ooo]Z00?o0?l6oook
J_oonfX00ooonfX3ool000Sooo]Z00?oobP0oookJ_oonfX01_oonfX00ooo:03ooo]ZoookJP07oook
JPgoobP00ooonfX00ooo:03ooo]ZoookJP1[oookJPCo1P3o1_oonfX2obd0o`OoaOl01ooo06d00ooo
nf[oE03ooe@0o`06oe@0o`?o0?n=3_oonfXVof00oa7ooo]Z1OmD0?l:oookJP;oo`1]5?oonfX00ol6
0?oooo]ZoookJP07oookJP03o`3oBOoonf[oBOl000cooo]Z00?o0?mkoookJ_oonfX04_oonfX00ooo
0@3o4@3ooookJP0@oookJP04o`000?ooB@3o0000o`3oa0Cooo]Z00?o2`3oo`3o?_oonfX02ooonfX0
1OoTo`3ooo]Zool0C_oonf[on@3o017ooo]Z00?oo`1Sond0oooonfX01OoonfX00ol0og3ooo]Zoook
JP08oookJP04o`3o9?oonf[ooo]Zo`3o30Oooo]Z00?oo`0/oookJ_oo01<01_oonfX00ol0omco3@3o
oookJP0LoookJP03ool;0?oonf[ooo]Z00_ooo]Z00?o0?l6oookJ_oonfX00ooonfX00ol0olgooo]Z
oookJP07oookJP03ool00?oonf[ooo]Z00Kooo]Z00?oM`3ooookJ_oonfX02_oonfX00olDo`3ooo]Z
ool0]P02oookJP03ofT0oooonf[ooo]Z00Gooo]Z00?ood/0oookJ_oonfX0AOoonfX002[ooo]Z00Co
BOl0o`3oBOl0odWo0?m91ol60?l3oookJP;oobP00_l]0?l6olGo0003oookJ_oo06goo`1]00Goo`1]
0ooonfX7oe@0o`GoobP00_l0ohd7oookJPgoo`002Ooo:00FoookJPOoE03o3?oonfX3ool0K@gooo]Z
1_oo:0000ooonf[o1P3ooookJP07oookJPWoobP01_oonfX5oolX00kooo]Z0ooo00001?oo:03oo`00
ool00?oo000@oookJP?oo`0000Co0?o4o`000?oonf[ooo]Z0_oo:0000ol0ockoobP0oolX000:oook
JP05onCo0?oonf[oo`1>oookJ_oi0?l04OoonfX01?oo06?ooo]ZoookJ_o]0?l5oookJP;oobP02Ooo
nfX01?l0obCooo]ZoookJ_l0o``6oookJP04ool00?oo02coo`00ool04`Coo`0000?ooo]Zool00?oo
00001_oo000HoookJP04ool00?oonf[ooo]ZoookJP;oo`002?oonfX00ol0o`Kooo]ZoookJP03oook
JP?oo`002?oonfX00ooo:03ooo]ZoookJP06oookJP03oolX0?oonf[ooo]Z00Gooo]Z3_oo:004oook
JP05oolX0?oonf[ooo]ZoookJ_oo:000J?oonfX01?m9o`3o0?m9o`3oBOl0odT7o`H0o`Gooo]Z0ol]
0?l6olGo0003oookJ_oo06goo`1]00Goo`1]0_oonfX:oe@0o`Co0?n=<ooonfX7oe@0o`cooo]Z0ooo
06dDoookJP;o1P3o2OoonfX00ol0odWooo]ZodWo000<oookJP03o`3oNooonf[ooo]Z01;ooo]Z00?o
o`40oookJ_lA0?l04OoonfX01?l0003oodT0o`3oa?l00004oookJP03o`/0ool0ockooo]Z00_ooo]Z
00Goi?l0oookJ_oo04kooo]ZooT0o`0AoookJP03ool0Hooonf[ok@3o00Gooo]Z00?o0?m`oookJ_oo
nfX02?oonfX01?l0obCooo]ZoookJ_l0o``7oookJP04ool0;?oonf[oo`0Co`1jo`Kooo]Z00?o0?oL
o`d0oooonfX07?oonfX00ooo2`3ooo]ZoookJP0;oookJP03o`3o1_oonf[ooo]Z00?ooo]Z00?o0?o=
oookJ_oonfX01ooonfX00ooo003ooo]ZoookJP06oookJP03ogL0oooonf[ooo]Z00[ooo]Z00?o5?l0
ool0]_oonfX00_oonfX00omY0?oooo]ZoookJP05oookJP03oom;0?oonf[ooo]Z04Cooo]Z000Zoook
JPCoBOl01Ol0odT2oookJPOo1P3o0_oo:002oookJP;o;@3o1_o5o`02oookJPSoo`1]1ooo:008oe@0
o`;oo`000ooo:009ool000WoobP02_oonfX<oe@0o`oooo]Z1?oo06d>oookJPSoobP000?o1P3ooook
J_oonfX01_oonfX8oolX00Sooo]Z1?oo:004oookJP03ool00?oonf[ooo]Z00Sooo]Z0ooo00000ooo
0@3oo`00ool0000AoookJP?oo`0000Co0?o4o`000?oonf[ooo]Z0_oo:0000ol0ockoobP0oookJP0:
oookJP05onCo0?oonf[oo`1>oookJ_oi0?l04_oonfX00ooo06?ooo]Zond0o`05oookJP;oobP02Ooo
nfX01Ol0obCooo]ZoookJ_oonf[o0?l<00Gooo]Z00Coo`00ool0;?oo003oo`0C3Ooo000HoookJP03
ool00?oonf[ooo]Z00?oo`002OoonfX00ol0o`Kooo]ZoookJP03oookJP;oo`002?oonfX00ooo:03o
oo]ZoookJP07oookJP03oolX0?oonf[ooo]Z00Kooo]Z3Ooo:004oookJP04oolX0?oonf[oobP0oolX
06Sooo]Z00?oohD0odWo0?m9o`000_m9o`04o`3oB@;ooo]Z1ol60?l5oookJP;o;@3o1_o5o`02oook
JPSoo`1]1?oonfX;oe@0o`Wo0?n=5ooonfX<oe@0o`oooo]Z1?oo06dEoookJP;o1P3o2OoonfX2o`3o
B@;oBOl03?oonfX00ol0og_ooo]ZoookJP0CoookJP03ool10?lA0?oooo]Z017ooo]Z00CoodT0o`00
0?l0olCo00001?oonfX00ol;0?oo0?lnoookJP0;oookJP05onCo0?oonf[oo`1>oookJ_oi0?l04Ooo
nfX00ooo06?ooo]Zond0o`06oookJP03o`3oL?oonf[ooo]Z00Sooo]Z00Co0?lToookJ_oonf[o0?l<
1ooonfX00ooo02cooo]Zool04`06oookJP03o`3og?oonf[o3@3o01cooo]Z00?oo`/0oookJ_oonfX0
3?oonfX00ol0o`Kooo]ZoookJP02oookJP03o`3ocOoonf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX0
1ooonfX00omg0?oooo]ZoookJP0:oookJP05oaCo0?oo0;Kooo]ZoookJ_mY0?l02?oonfX00oooB`3o
oo]ZoookJP13oookJP00:_oonfX4oomi00OoBOl00ol0odT4oookJPKo1P3o1OoonfX00ol]0?ooaOl0
olGo0004olGo00CoobP01ooo06d5oookJPSoobP06_mD0?l3ool000Oooo]Z0ooo0009oookJPOoo`1]
4OoonfX:oolX00Oooo]Z1_oo:00:oookJP?oobP01_oonfX00ooo003ooo]ZoookJP07oookJP?oo`00
00Coo`40ool00?oo003o4@3o4OoonfX2ool00003o`000?l0olCo000000;ooo]Z0_oo:0000ol0ocko
obP0oookJP0:oookJP05onCo0?oonf[oo`1>oookJ_oi0?l04_oonfX00ooo06?ooo]Zond0o`06oook
JP03oolX0?oonf[ooo]Z00Sooo]Z00Co0?lToookJ_oonf[o0?l<1_oonfX01?oo003oo`0/ool00?oo
01<3ool00003oookJ_oo003oo`0000Koo`006OoonfX6ool000Wooo]Z00?o0?l6oookJ_oonfX00ooo
nfX00ooo003ooo]ZoookJP07oookJP03oolX0?oonf[ooo]Z00;ooo]Z00?oobP0oookJ_oonfX00_oo
nfX00ooo:03ooo]ZoookJP06oookJPcoobP01OoonfX4oolX06Oooo]Z0ol0og/00om1o`3oohD0odWo
0006odWo00;o0?m91?oonfX6o`H0o`Gooo]Z0_l]0?l5olGo00;o;@3o0ooonfX7ool0K@Sooo]Z8?mD
0?lDoookJPOoo`1]6?oonfX00ol60?oooo]ZoookJP08oookJP03o`3oBOoonf[oBOl000gooo]Z00?o
0?mkoookJ_oonfX04_oonfX01?l0okkoo`40oookJ_lA0?lBoookJP04oom90?l0003o0?o4o`0000Co
oo]Z00?o2`3oo`3o?_oonfX02ooonfX01OoTo`3ooo]Zool0C_oonf[on@3o01;ooo]Z00?oo`1Sond0
oooonfX01OoonfX00ol0og3ooo]ZoookJP08oookJP04o`3o9?oonf[ooo]Zo`3o30Oooo]Z00Coo`0/
oookJ_oo01?o07[o1_oonfX00ol0omco3@3ooookJP0LoookJP03ool;0?oonf[ooo]Z00_ooo]Z00?o
0?l6oookJ_oonfX00ooonfX00ol0olgooo]ZoookJP07oookJP03ool00?oonf[ooo]Z00Oooo]Z00?o
M`3ooookJ_oonfX02_oonfX01OlDo`3oo`2foookJ_oonf[oJ@3o00Sooo]Z00?ood/0oookJ_oonfX0
@_oonfX002[ooo]Z1_oob@02o`3oN`03od7o0?oonf[oohD000OoBOl000?o0?m9oookJ_oonfX00ooo
nfX6o`H0o`KoogT01_o5o`0BoolX00;oo`1]1ooo0007oookJP;oobP01?oonfX7ool000?ooo]Z1ooo
00000ooonf[oo`1]ool0K@06ool0KAKooo]Z3?oo:006oookJPGoobP03?oonfX00ooo:03ooo]Zoook
JP05oookJP?oo`002?oonfX3ool00003ool10?oo003o4@3o01;ooo]Z0_oo00000ol0003o0?o4o`00
0002oookJP;oobP000?o0?lnoolX0?oonfX02_oonfX01OoTo`3ooo]Zool0C_oonf[on@3o01;ooo]Z
00Coo`1SoookJ_oonf[ok@3o1OoonfX00ol0og3ooo]ZoookJP08oookJP05o`3o9?oonf[ooo]Zoook
J_l0o``01_oonfX00ooo02coo`00ool04`03ool000;ooo]Z1ooo000HoookJPOoo`002_oonfX00ol0
o`Kooo]ZoookJP03oookJP03ool00?oonf[ooo]Z00Oooo]Z00?oobP0oookJ_oonfX00_oo:005oook
JP03oolX0?oonf[ooo]Z00Oooo]Z2ooo:003oookJPKoobP0JOoonfX5o`3oN`04od7o0?oonf[oohD0
oon500KoBOl000?o0?m9oookJ_oonfX00ooonfX6o`H0o`Kooo]Z1_o5o`06obd0o`koo`1]9ooonfX7
ool0KAcooo]Z0ol60?l:oookJP03o`3oBOoonf[oBOl000gooo]Z00?o0?mkoookJ_oonfX04ooonfX0
0ooo0@3ooo]Zoa40o`0CoookJP04oom90?l0003o0?o4o`0000Cooo]Z00?o2`3oo`3o?_oonfX02ooo
nfX01OoTo`3ooo]Zool0C_oonf[on@3o01;ooo]Z00?oo`1SoookJ_o]0?l01OoonfX00ol0og3ooo]Z
oookJP08oookJP05o`3o9?oonf[ooo]ZoookJ_l0o``01ooonfX00ooo02coo`0Co`1jo`06oookJP03
o`3og?oonf[o3@3o01gooo]Z00?oo`/0oookJ_oonfX02ooonfX00ol0o`Kooo]ZoookJP03oookJP03
o`3ocOoonf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX01ooonfX00omg0?oooo]ZoookJP0:oookJP05
oaCo0?oo0;Kooo]ZoookJ_mY0?l01ooonfX00oooB`3ooo]ZoookJP12oookJP00:_oonfX3o`3o4`?o
olT00_oonfX4o`3oN`;o@Ol00_oonfX2oon500OoBOl01OooN@05o`H0o`SoogT000?oaOl0oolX0?oo
:0003_oo:002oookJQ?oo`1]4_oo00000ooo06gooo]ZoookJP0JoookJPkoobP01?oonfX01?l0odWo
obP0odWo0?oo:00=oookJP03o`3oNooo:03ooo]Z00Kooo]Z1Ooo0007oookJP;oo`0000Coo`40ool0
0?oonf[o4@3o4_oonfX2ool00004o`000?l0olCo0000o`0000;ooo]Z00?oobP0o`3o?_oonfX02ooo
nfX00ooTo`3ooo]Zool0CP02oookJP03ooT0oooonf[ooo]Z013ooo]Z00Coo`1SoookJ_o]0?oooo]Z
0_oo00001?oo:03ooo]ZoookJ_l0og09oookJP05o`3o9?oonf[ooo]ZoookJ_l0o``01ooonfX00ooo
02coo`00ool04`03ool000;ooo]Z1ooo0005oookJP03ool00?oonf[ooo]Z00kooo]Z2?oo000:oook
JP03o`3o1_oonf[ooo]Z00?ooo]Z00?o0?o=oookJ_oonfX02?oonfX5oolX00Cooo]Z00CoobP0oook
J_oonf[ooo]Z0_oo:005oookJP[oobP00_oonfX7oolX06Kooo]Z0ol0oa<00ol06oooWOl0oookJP02
oookJPGo0?mk00?o@Ol0oookJ_oonfX00_ooQ@07odWo00Gooo]Z1_l60?l6oookJPSoaOl02_l]0?l2
oookJQ?oo`1]3?oonfX8ool0KAoooo]Z1?l60?l;oookJP;o0?m90_m9o`0<oookJP;o0?mk5OoonfX0
1?l0okkoo`40oookJ_lA0?lCoookJP03oom90?l0003o0?o400;o00000ooonfX00ol;0?oo0?lnoook
JP0;oookJP05onCo0?oonf[oo`1>oookJ_oi0?l04_oonfX00ooo06?ooo]Zond0o`06oookJP03o`3o
L?oonf[ooo]Z00Sooo]Z00Co0?lToookJ_oonf[o0?l<1ooonfX01?oo02cooo]Zool04ol0N_l6oook
JP03o`3og?l=0?oooo]Z00Sooo]Z00?oo`2=oookJ_oonfX04OoonfX00ooo2`3ooo]ZoookJP0<oook
JP03o`3o1_oonf[ooo]Z00;ooo]Z00?o0?o=oookJ_oonfX02?oonfX00ooo003ooo]ZoookJP06oook
JP03ogL0oooonf[ooo]Z00[ooo]Z00?o5?l0oookJ_oo0;H00_oonfX00omY0?oooo]ZoookJP05oook
JP03oom;0?oonf[ooo]Z047ooo]Z000ZoookJP?oolT01Ol0oa<01?ooN@3oWOl0oookJ_oonfX4o`3o
N`?o@Ol00ooonfX3oomi00;oBOl04?ooN@03oolX0003oookJ_oo:03oobP000coobP02?l]0?l6oook
JPKoo`001?oo06d>ool001cooo]Z4?oo:003o`3oB@;oBOl03_oonfX00ol0og_ooo]ZoookJP06oook
JPOoo`001OoonfX3ool00003ool10?oonf[o4@3o01?ooo]Z00?oo`00o`000?l0ol@00_l00003oook
JP03oolX0?l0ockooo]Z00_ooo]Z00Koi?l0oookJ_oonf[oo`1>oookJ_oi0?lBoookJP03ool0Hooo
003oo`0000?oo`0000CoobP0oookJ_oonf[o0?m`2_oonfX01Ol0obCooo]ZoookJ_oonf[o0?l<00Ko
oo]Z00?oo`0/ool00?oo01<00ooo0003oookJPKoo`001OoonfX00ooo003ooo]ZoookJP02oookJP;o
o`003?oonfX7ool000[ooo]Z00?o0?l6oookJ_oonfX00ooonfX00ol0olgooo]ZoookJP07oookJPGo
obP01OoonfX00ooo:03ooo]ZoolX0002oolX00Oooo]Z4_oo:01UoookJP?oo`401Ol0oa<00ol06ooo
WOl0oookJP02oookJPCo0?mk0_m1o`03oookJP?oohD01_m9o`05oookJPKo1P3o2?oonfX;olGo00So
;@3o3?oonfX<ool0KBCooo]Z0ol60?l<oookJP;o0?m90om9o`0=oookJP03o`3oNooonf[ooo]Z01Co
oo]Z00Co0?nnool10?oonf[o4@3o5?oonfX01?ooB@3o0?o4o`000?l00004oookJP03o`/0ool0ocko
oo]Z00_ooo]Z00Goi?l0oookJ_oonf[oo`1>ooT0o`0CoookJP03ool0Hoo]0?oooo]Z00Gooo]Z00?o
0?m`oookJ_oonfX02?oonfX01Ol0obCooo]ZoookJ_oonf[o0?l<00Oooo]Z00?oo`0/ool04ol0N_l0
1ooonfX00ol0omco3@3ooookJP07oookJP03ool0SOoonf[ooo]Z01;ooo]Z00?oo`/0oookJ_oonfX0
2ooonfX00ol0o`Kooo]ZoookJP03oookJP03o`3ocOoonf[ooo]Z00Sooo]Z00?oo`00oookJ_oonfX0
1_oonfX00omg0?oooo]ZoookJP0:oookJP03oaCo0?oonf[oo`2f00;ooo]Z00?oJ@3ooookJ_oonfX0
1OoonfX00oooB`3ooo]ZoookJP10oookJP00:_oonfX7ooo90003onGo0?l0oa?o0?lC00?o0?lC00?o
ogT0oookJ_oonfX01Ol0og/3od7o0003oookJ_ooN@3oogT0013oogT01ol60?l:oolX0003oookJ_oo
:03oobP000?oobP04Oo5o`0Bool001Oooo]Z0_l60?l8oolX00Oooo]Z0_l0odT3odWo00kooo]Z0_l0
og/9oookJPSoo`001?oonfX2ool00004ool10?oonf[ooo]Zoa40oa3ooo]Z1Ooo:0000ol0olCo0000
o`000003oookJP03oolX0?l0ockooo]Z00_ooo]Z00Koi?l0oookJ_oonf[oo`1>oookJ_oi0?lAoook
JPOoo`0000CoobP0oookJ_oonf[o0?m`2_oonfX01Ol0obCooo]ZoookJ_oonf[o0?l<00Kooo]Z00Co
o`0/oookJ_oo003oo`0C0_oo0004oookJPGoo`001_oonfX00ooo003ooo]ZoookJP03ool000gooo]Z
1_oo000;oookJP03o`3o1_oonf[ooo]Z00?ooo]Z00?o0?o=oookJ_oonfX01OoonfX7oolX00Gooo]Z
1Ooo:007oookJPSoobP00_oonfX7oolX06Gooo]Z0olA0?l5ool100Go0?lC00Co01_ooookJ_oonf[o
oo]Z1Ol0og/2od7o00Gooo]Z0_ooQ@06odWo00Gooo]Z2?l60?l;oookJRSoaOl06?oonfX4o`H0o`go
oo]Z0_l0odT2odWo00kooo]Z0_l0og/FoookJP05o`3o__oonf[oo`40oookJ_lA0?l05?oonfX01?oo
B@3o0?o4o`000?l00004oookJP03o`/0ool0ockooo]Z00_ooo]Z00Goi?l0oookJ_oonf[oo`1>ooT0
o`0CoookJP03ool0Hooonf[ok@3o00Kooo]Z00?o0?m`oookJ_oonfX02?oonfX01?l0obCooo]Zoook
J_l0o``7oookJP04ool0;?oonf[oo`0Co`1jo`Kooo]Z00?o0?oLo`d0oooonfX02?oonfX00ooo08go
oo]ZoookJP0BoookJP03ool;0?oonf[ooo]Z00_ooo]Z00?o0?l6oookJ_oonfX00ooonfX00ol0olgo
oo]ZoookJP08oookJP03ool00?oonf[ooo]Z00Kooo]Z00?oM`3ooookJ_oonfX02_oonfX01OlDo`3o
oo]Zool0]_oonf[oJ@3o00Sooo]Z00?ood/0oookJ_oonfX0?ooonfX002[ooo]Z1Ooob@000olA0?oo
0?nnooo90004ooo90003oookJ_l0oa?o0?lC00?o0?lC00?o01_ooookJ_oonfX01Ol0og/00om1o`3o
ogT0oomi000>oomi00;ooo]Z00?oobP0oookJ_oonfX00_oonfX:o`H0oa3ooo]Z5ooo000DoookJPGo
1P3o2ooonfX2ool00004oookJ_l0odWo0?m9o`3oB@;oBOl03ooonfX2o`3oN`[ooo]Z2_oo00000ooo
:03ooo]ZoookJP02ool00003ool10?oonf[o4@3o017ooo]Z1Ooo:0000ol0olCoobP0oolX0003oook
JP03oolX0?l0ockooo]Z00_ooo]Z00Koi?l0oookJ_oonf[oo`1>oookJ_oi0?l@oookJPWoo`000ooo
nfX00ol0og3ooo]ZoookJP08oookJP04o`3o9?oonf[ooo]Zo`3o30Oooo]Z00?oo`0/ool00?oo01<0
0ooo0004oookJPGoo`001_oonfX6ool000gooo]Z1Ooo000<oookJP03o`3o1_oonf[ooo]Z00?ooo]Z
00?o0?o=oookJ_oonfX00ooonfX8oolX00Cooo]Z1_oo:008oookJPSoobP00_oonfX7oolX06Cooo]Z
0ooo2`000ooon03o4@3ooa40o`02o`3o_PCoo`4000?ooo]Zo`3o4ol0oa<00ol0oa<2o`0Ko`;ooo]Z
1Ol0og/3od7o00Gooo]Z00?oohD0o`3oBOm9o`001?m9o`08oookJP_o1P3o>ooonfX5o`H0o`kooo]Z
0_l0odT3odWo00kooo]Z0_l0og/HoookJP04o`3o__oo0@3ooo]Zoa40oaGooo]Z00CoodT0o`3oa?l0
003o00001?oonfX00ol0ockooo]ZoookJP0;oookJP06onCo0?oonf[ooo]Zool0C_oonf[on@3o4_oo
nfX00ooo06?ooo]Zo`3oH`06oookJP03o`3oL?oonf[ooo]Z00Sooo]Z00Co0?lToookJ_oonf[o0?l<
2?oonfX00ooo02coo`0Co`1jo`07oookJP03o`3og?l=0?oooo]Z00Sooo]Z00?oo`2=oookJ_oonfX0
4_oonfX00ooo2`3ooo]ZoookJP0;oookJP03o`3o1_oonf[ooo]Z00?ooo]Z00?o0?o=oookJ_oonfX0
1ooonfX00ooo003ooo]ZoookJP07oookJP03ogL0oooonf[ooo]Z00[ooo]Z00Go5?l0oookJ_oo0;Ko
oo]ZofT0o`08oookJP03oom;0?oonf[ooo]Z03kooo]Z000ZoookJP?oo`@00_oob@02ool;00;oiOl0
00?o4@3oo`3o__l0okh01?oob@02oookJPGo0?lC00?o01_ooookJ_oonfX00ol0og/Boomi00;o0?m9
1ooonfX4oolX00[o1P3o2_oonfX9ool00003oookJ_oo003oo`0000Ooo`004?oonfX4o`H0o`gooo]Z
0ooo0003o`3oB@?oBOl04?oonfX00ol0og_ooo]ZoookJP09oookJPWoo`000_oonfX01Ooo:03ooo]Z
ool00?oo003oo`4000;ooo]Z00?o4@3ooookJ_oonfX03ooonfX5oolX0003o`3oa?oo:03oobP000?o
oo]Z00?o2`3oo`3o?_oonfX03?oonfX01OoTo`3ooo]Zool0C_oonf[on@3o013ooo]Z2Ooo0003oook
JP03o`3oL?oonf[ooo]Z00Sooo]Z00Go0?lToookJ_oonf[ooo]Zo`3o3006oookJP04ool0;?oonf[o
o`00ool04`;oo`001OoonfX4ool000Kooo]Z1_oo000>oookJPGoo`002ooonfX00ol0o`Kooo]Zoook
JP04oookJP03o`3ocOoonf[ooo]Z00Cooo]Z1ooo:002oookJPSoobP02OoonfX00ooo:03ooo]ZoolX
0003oolX0004oookJ_oo:03ooo]ZoookJPKoobP0HooonfX3ool400Coo`/00_oon0000olA0?oo0?nn
o`3o_P05ool10003oookJ_l0oa?o0?lC00?o0?lC0_l06ol2oookJPKo0?mk0om1o`05oookJP03oon5
0?m9o`3oBOl000CoBOl000?o0?m9oookJ_oonfX02_oonfX:o`H0obgooo]Z1?l60?l@oookJP;o0?m9
0om9o`0@oookJP03o`3oNooonf[ooo]Z00_ooo]Z0_oo0=X:oookJP05o`3o__oo0@3ooo]ZoookJ_lA
0?l05?oonfX00oooB@3o0000o`3oa002o`0000Cooo]Z00?o0?lnoookJ_oonfX02ooonfX01_oTo`3o
oo]ZoookJ_oo04kooo]ZooT0oa?ooo]Z00?oo`1So`3oHooonfX01_oonfX00ol0og3ooo]ZoookJP07
oookJP05o`3o9?oonf[ooo]ZoookJ_l0o``01ooonfX01?oo02cooo]Zool04ol0N_l6oookJP03o`3o
g?l=0?oooo]Z00Sooo]Z00?oo`2=oookJ_oonfX04_oonfX00ooo2`3ooo]ZoookJP0<oookJP03o`3o
1_oonf[ooo]Z00?ooo]Z00?o0?o=oookJ_oonfX01ooonfX00ooo003ooo]ZoookJP07oookJP03ogL0
oooonf[ooo]Z00[ooo]Z00Go5?l0oookJ_oo0;Kooo]ZofT0o`08oookJP03oom;0?oonf[ooo]Z03go
oo]Z000ZoookJP?oolT00ooo10000ooUo`3oo`/0ool;0002ool;00?oiOl000Co4@3oo`3o__oob@3o
olT00_oo0@000ooo303ooo]ZoookJP06o`3o4`?ooo]Z0oooN@000ol0og_oogT0oomi000<oomi00Co
BOl00_l0odT3oookJP03oolX0?oonf[ooo]Z00Sooo]Z2Ol60?l4oookJPKoo`001?oonfX6ool000Oo
oo]Z2Ol60?l?oookJP04ool00?l0odWo0?m9o`3oB@CoBOl04OoonfX2o`3oN`Oooo]Z0_oo0002oook
JPOoo`001?oonfX3oolX0005ool00?oonf[oo`40oookJ_lA0?l04_oonfX5oolX0003o`3oa?oo:03o
000000?ooo]Z00?o2`3oo`3o?_oonfX03?oonfX01OoTo`3ooo]Zool0C_oonf[on@3o017ooo]Z2?oo
00001Ooo:03ooo]ZoookJ_oonf[o0?m`00[ooo]Z00Co0?lToookJ_oonf[o0?l<1ooonfX01Ooo02co
oo]Zool00?oo01?oo`0000Gooo]Z00Co0?oLool00?oo003oo`001OoonfX7ool000oooo]Z1?oo0009
oookJP04ool00?oonf[ooo]Zo`3o1PKooo]Z00?o0?o=oookJ_oonfX01?oonfX6oolX0003oookJ_oo
:03oobP000OoobP02_oonfX00ooo:03o5?l0oolX0004oolX00Cooo]Z1?oo:01SoookJP?o0;;o0ooo
10000ol01_ooo`/0ool;0003ool;00?oooP00_l0okh4ool10003ool<0?oonf[o0?lC00Go0?lC00Co
01_ooookJ_oonf[ooo]Z1Ol0og/3od7o00Gooo]Z0_ooQ@06odWo00;o0?m93ooonfX9o`H0oa_ooo]Z
2Ol60?l@oookJP;o0?m91?m9o`0AoookJP;o0?mk3OoonfX00ooo0=[ooo]ZoookJP09oookJP05o`3o
__oonf[oo`40oookJ_lA0?l05OoonfX00oooB@3o0000o`3oa002o`0000Cooo]Z00?o0?lnoookJ_oo
nfX02ooonfX01_oTo`3ooo]ZoookJ_oo04kooo]ZooT0oa?ooo]Z00?oo`1SoookJ_l0of<01_oonfX0
0ol0og3ooo]ZoookJP08oookJP04o`3o9?oonf[ooo]Zo`3o30Sooo]Z00?oo`0/oookJ_oo01<01ooo
nfX00ol0omco3@3ooookJP08oookJP03ool0SOoonf[ooo]Z01;ooo]Z00?oo`/0oookJ_oonfX02?oo
nfX01?ooc@3ooo]ZoookJ_l0o`H6oookJP03o`3ocOoonf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX0
1ooonfX00omg0?oooo]ZoookJP0:oookJP;o5?l000?oo`2foookJ_mY0?l02?oonfX00oooB`3ooo]Z
oookJP0loookJP00:_oonfX6oomi00Coo`@00oooN@02ool;00?oooP000?o0Ol0oa40oooo0@001?oo
0@001?oo303ooo]Zoigo0?nMo`06o`3o4`?oogT000Co0?mkoomi0?ooN@3oogT00_l0og/3oomi00Co
oo]Z0oooQ@07odWo00;o0?m94?oonfXKo`H0oaKooo]Z0ol0odT3odWo00?oo`004?oonfX2o`3oN`So
oo]Z0ooo0002oookJPGoo`001OoonfX5oolX0003ool10?oonf[o4@3o01?ooo]Z1Ooo:0000ol0olCo
obP0o`000003oookJP03o`/0ool0ockooo]Z00cooo]Z00?oi?l0oookJ_oo04h00_oonfX00ooi0?oo
oo]ZoookJP0?oookJPOoo`0000GoobP0oookJ_oonf[ooo]Zo`3oL00:oookJP05o`3o9?oonf[ooo]Z
oookJ_l0o``00_oonfX2oolX00;ooo]Z00Goo`0/oookJ_oonf[oo`0Cool00006oookJP03o`3og?oo
003oo`0000Cooo]Z2Ooo000?oookJP?oo`002OoonfX01Ooo003ooo]ZoookJ_oonf[o0?l600Gooo]Z
00?o0?o=oookJ_oonfX01OoonfX6oolX00;ooo]Z2?oo:00;oookJP03oaCo0?oo:03oobP000?oobP0
1?oonfX4oolX06;ooo]Z0omQ0?l3o`2bo`Goo`@000?oodT0ool;0?oo2`000_oo2`03oooh0003ool=
0?l0okkoo`4000Coo`4000?oo``0oigo0?nMo`001_l0oa<3oookJPKo0?mk0om1o`04oookJP?oohD0
1om9o`02o`3oBA7ooo]Z6ol60?lEoookJP?o0?m90om9o`0CoookJP;o0?mk3OoonfX2ool0fPcooo]Z
00Go0?nnool10?oonf[ooo]Zoa40o`0EoookJP03oom90?l0003o0?o400;o00001?oonfX00ol0ocko
oo]ZoookJP0;oookJP06onCo0?oonf[ooo]Zool0C_oonf[on@3o4ooonfX00ooo06?ooo]Zo`3oH`06
oookJP03o`3oL?oonf[ooo]Z00Sooo]Z00Go0?lToookJ_oonf[ooo]Zo`3o3007oookJP04ool0;?oo
nf[oo`0Co`1jo`Kooo]Z00?o0?oLoookJ_l=0?l02OoonfX00ooo08gooo]ZoookJP0BoookJP03ool;
0?oonf[ooo]Z00Oooo]Z00Goold0oookJ_oonf[ooo]Zo`3o1P06oookJP03o`3ocOoonf[ooo]Z00Oo
oo]Z00?oo`00oookJ_oonfX01ooonfX00omg0?oooo]ZoookJP0;oookJP04oaCo0?oo0;Kooo]ZofT0
o`Sooo]Z00?ood/0oookJ_oonfX0>ooonfX002[ooo]Z2_ooN@04ool40003onGo0?oo2`3oo`/000?o
o`/00_oon002o`7o0003oa40oooo0@3oo`4000?oo`401?ooN@000ol06ooo0?lCo`3o4`04o`3o4`?o
ogT01_l0og/00om1o`3oobP0oolX0006oolX00;oohD01om9o`07o`3oBB3ooo]Z0ooo:00=oookJP?o
0?m91Om9o`07ool000cooo]Z0ol0og/9oookJPWoo`001ooonfX4oolX0003ool10?oo:03o4@3o01Co
oo]Z1Ooo:0000ol0olCo0000o`000003oookJP03o`/0ool0ockooo]Z00cooo]Z00Koi?l0ool00?oo
04koo`00oookJ_oi0?lBoookJPKoo`0000GoobP0oookJ_oonf[ooo]Zo`3oL00;oookJP05o`3o9?oo
nf[ooo]Zo`3o3?oonfX00ooo:003oookJP05ool0;?oonf[ooo]Zool04ooo00001_oonfX00ol0omco
o`00ool00005oookJPOoo`004?oonfX3ool000Wooo]Z00Goo`00oookJ_oonf[ooo]Zo`3o1P05oook
JP03o`3ocOoonf[ooo]Z00Kooo]Z1?oo:003oookJPSoobP02ooonfX01_lDo`3oobP0oolX0?oo:03o
J@3ooolX00Gooo]Z0_oo:01UoookJPCoH@3o00Co4P3oo`2bool0/_oo0?o41?oo10000ol0obcoo`/0
ool;0002ool;00?oooP000?o0Ol0ool=0?l0okh01Ooo0@001?oonf[oWOl0oigo0?nMo`06o`3o4`?o
oo]Z1_l0og/3od7o00?ooo]Z1OooQ@07odWo00Oo0?m9<?oonfX3o`3oB@GoBOl01?ooQ@0@oookJP;o
0?mk3_oonfX00ooo0=[ooo]ZoookJP0;oookJP05o`3o__oo0@3ooo]ZoookJ_lA0?l05_oonfX00ooo
B@3o0000o`3oa002o`0000Cooo]Z00?o0?lnoookJ_oonfX03?oonfX01OoTo`3ooo]Zool0C_oonf[o
n@3o01Cooo]Z00?oo`1So`3oHooonfX01_oonfX00ol0og3ooo]ZoookJP08oookJP04o`3o9?oonf[o
oo]Zo`3o30Sooo]Z00?oo`0/oookJ_oo01<01ooonfX00ol0omco3@3ooookJP08oookJP03ool0SOoo
nf[ooo]Z01;ooo]Z00?oo`/0oookJ_oonfX02?oonfX01Oooc@3ooo]ZoookJ_oonf[o0?l600Kooo]Z
00?o0?o=oookJ_oonfX01ooonfX00ooo003ooo]ZoookJP06oookJP03ogL0oooonf[ooo]Z00cooo]Z
00?o5?l0ool0]_oonfX00_mY0?l7oookJP03oom;0?oonf[ooo]Z03[ooo]Z000ZoookJP03ooo90?oo
N@3oogT000[oogT000?oolT0ool40?oo10000ooo10000ooUo`3oo`/0ool;0002ool;00?oooP00_l1
o`000olA0?ooo`40ool10003ool100CoogT00_l06ol2o`3o4a3oobP01OoonfX4oon500coBOl03?l0
odT:oookJPSoobP01_oonfX4o`3oB@KoBOl03?oo000:oookJP;o0?mk2_oonfX8ool000Wooo]Z1?oo
:0001?oo0@3oobP0oolX0?oo:00DoookJPCoobP000Co0?o4oolX0?l0003o00000ooonfX00ol;0?oo
0?lnoookJP08oookJPCoo`0000Koi?l0ool00?oo04koo`00oookJ_oi0?lCoookJPKoo`001?oonfX0
0ol0og3ooo]ZoookJP08oookJP03o`3o9?oonf[ooo]Z00KoobP00ooonfX01?oo02cooo]Zool04ooo
0006oookJP03o`3og?oonf[oo`0000Kooo]Z1_oo000AoookJP;oo`002_oonfX01Ooo003ooo]Zoook
J_oonf[oobP000Gooo]Z00?o0?o=oookJ_oonfX01_oonfX4oolX00Cooo]Z1_oo:00:oookJP;oobP0
00Go5?l0oolX0?oo:03oobP0ofT0o`07oookJP03oolX0?oonf[ooo]Z05oooo]Z0ooo08<4oookJPCo
H@3o0_lB0?l00ol0/_oo0?o4ool40003ool40003o`3o;?oo2`3oo`/000?oo`/00_oon002o`7o0003
ool=0?l0okkoo`4000?oo`4000?oo``0oookJ_oonfX00_nMo`000ol06ooo0?lCo`3o4`04o`3o4`?o
oo]Z1ol0og/3od7o00Cooo]Z1?ooQ@0<odWo00go0?m96?oonfX3o`3oB@KoBOl01OooQ@0BoookJP;o
0?mk3ooonfX00ooo0=[ooo]ZoookJP0;oookJP05o`3o__oo0@3ooo]ZoookJ_lA0?l05ooonfX00ooo
B@3o0?o4o`000002o`0000?ooo]Z00?o2`3oo`3o?_oonfX03OoonfX01OoTo`3ooo]Zool0C_oonf[o
n@3o01Cooo]Z00?oo`1SoookJ_l0of<01_oonfX00ol0og3ooo]ZoookJP08oookJP05o`3o9?oonf[o
oo]ZoookJ_l0o``02?oonfX00ooo02coo`0Co`1jo`06oookJP03o`3og?oonf[o3@3o00Wooo]Z00?o
o`2=oookJ_oonfX04_oonfX00ooo2`3ooo]ZoookJP08oookJP05ooo=0?oonf[ooo]ZoookJ_l0o`H0
1_oonfX00ol0olgooo]ZoookJP06oookJP03ool00?oonf[ooo]Z00Oooo]Z00?oM`3ooookJ_oonfX0
3?oonfX01OlDo`3oo`2foookJ_oonf[oJ@3o00Oooo]Z00?ood/0oookJ_oonfX0>OoonfX002[ooo]Z
00?oolT0oomi0?ooN@002oooN@001Olco`3o4P3ooa80ool01_oo0?o400Coo`@000?oiOl0ool;0?oo
2`000_oo2`03oooh00;o0Ol000?oogT0o`3o__oo0@001?oo0@05ooo900koobP01Ol0og/2od7o00Co
oo]Z2_ooN@0@odWo00ko0?m92_m9o`02oon5013oo`001ooonfX3o`3oN`_ooo]Z2Ooo0008oookJPCo
obP000?oo`40oolX0?oo:0000ooo:0000ooo003ooo]ZoookJP0@oookJPCoobP000Co0?o4o`000?l0
003o00000ooonfX00ol;0?oo0?lnoookJP03oookJPCoo`0000?ooo]Zool00?oo00000ooo00001OoT
o`3oo`00ool0C_oonf[on@3o01Cooo]Z1Ooo0004oookJP03o`3oL?oonf[ooo]Z00Wooo]Z00?o0?lT
oolX0?oo:0001Ooo:003oookJP04ool0;?oonf[ooo]Zool04`Oooo]Z00?o0?oLo`d0oooonfX01_oo
nfX6ool0017ooo]Z00?oo`00oookJ_oonfX02OoonfX01_oo003ooo]ZoookJ_oo:03ooo]Zool000Co
oo]Z00?o0?o=oookJ_oonfX01_oonfX3oolX00Kooo]Z1Ooo:008oookJPCoobP000Go5?l0oolX0?oo
:03oobP0ofT0o`07oookJP03oolX0?ooB`3ooo]Z05kooo]Z0omFo`04ool0P`Cooo]Z0omQ0?l01Ol0
TOoo4P3ooa80ool0/_oo0?o400Goo`@000?o`?l0ool;0?oo2`000_oo2`02oooh00;o0Ol000?ooo]Z
ool=0?oo0@001?oo0@000ooo303ooo]ZoookJP02oigo00;o01_o1Ol0oa<5oookJPOo0?mk0om1o`07
oookJPKoohD04Om9o`0=o`3oB@[oBOl01OooQ@0EoookJP?o0?mk3ooonfX2ool0fPgooo]Z00?o0?nn
ool10?oonfX00_oonfX00olA0?oooo]ZoookJP0DoookJP03oom90?oonf[o0?o400?o00000ooonfX0
0ol;0?oo0?lnoookJP0=oookJP05onCo0?oonf[ooo]Zool0C_oi0?l05?oonfX00ooo06?ooo]Zo`3o
H`07oookJP03o`3oL?oonf[ooo]Z00Sooo]Z00Co0?lToookJ_oonf[o0?l<2?oonfX00ooo02cooo]Z
ool04`07oookJP03o`3og?l=0?oooo]Z00Wooo]Z00?oo`2=oookJ_oonfX04_oonfX00ooo2`3ooo]Z
oookJP08oookJP05ooo=0?oonf[ooo]ZoookJ_l0o`H01_oonfX00ol0olgooo]ZoookJP06oookJP03
ool00?oonf[ooo]Z00Oooo]Z00?oM`3ooookJ_oonfX03?oonfX01OlDo`3oo`2foookJ_oonf[oJ@3o
00Oooo]Z0_ooB`0ioookJP00:_oonfX3ooT0o`03oomi0?mFo`3oogT000KoogT00_oUo`04oomi0003
oc?o0?lB0?oo4P3o00;o00Ko1?oo10000ol0obcoo`/0ool;0002ool;00?oooP00_l1o`02ooo90003
o`3o__oo0@3oo`4000;oo`400ooob@0<oolX00Gooo]Z0_l0og/@oomi00?oobP00_oonfX7oon500;o
obP03_m9o`06oon500;oo`003OoonfX7ool000Cooo]Z0ol0og/=oookJP[oo`001ooonfX3oolX00;o
o`401?oo:002oookJP03ool00?oonf[ooo]Z013ooo]Z1?oo:0001?l0olCo0000o`000?l00003oook
JP03o`/0ool0ockoo`0000Ooo`000_oonfX4ool00005onCo0?oo003oo`1>oookJ_oi0?l05?oonfX5
ool000Cooo]Z00?o0?m`oookJ_oonfX02OoonfX8oolX00Cooo]Z00Coo`0/ool00?oo003oo`0C1_oo
nfX00ol0omcooo]Zo`d0o`07oookJPGoo`004_oonfX00ooo003ooo]ZoookJP09oookJP03ool00?oo
nf[ooo]Z00;oo`001OoonfX00ol0olgooo]ZoookJP07oookJP;oobP01_oonfX4oolX00[ooo]Z0ooo
:0001OlDo`3oobP0oolX0?oo:03oJ@3o00Sooo]Z00?ood/0oookJ_oonfX0G?oonfX3ooT0o`04oook
J_mFo`3oE_l0oeKo00Coo`230ooonfX4of40o`06o`2AoolB0?oo4P3oo`2bool01_oo0?o41?oo1000
0oo0o`3oo`/0ool;0002ool;00;oooP00_l1o`02oookJP03oa40oooo0@3oo`4000;oo`4000?oo``0
oookJ_oonfX00_oonfX00onMo`3o01_oo`0Ko`05o`3o4`Oooo]Z1_l0og/5od7o00cooo]Z2_ooQ@0=
odWo00KoohD06ooonfX3o`3oNa7ooo]Z00?oo`3JoookJ_oonfX03?oonfX00ol0okkoo`40oookJP02
oookJP03oa40oooonf[ooo]Z01Gooo]Z00?oodT0oookJ_l0ol@00ol00003oookJP03o`/0ool0ocko
oo]Z00gooo]Z00Koi?l0oookJ_oonf[oo`1>oookJ_oi0?lDoookJP03ool0Hooonf[o0?mS00Kooo]Z
00?o0?m`oookJ_oonfX02?oonfX01Ol0obCooo]ZoookJ_oonf[o0?l<00Sooo]Z00?oo`0/oookJ_oo
01<01ooonfX00ol0omco3@3ooookJP09oookJP03ool0SOoonf[ooo]Z01;ooo]Z00?oo`/0oookJ_oo
nfX02?oonfX01Oooc@3ooo]ZoookJ_oonf[o0?l600Gooo]Z00?o0?o=oookJ_oonfX01ooonfX00ooo
003ooo]ZoookJP07oookJP03ogL0oooonf[ooo]Z00cooo]Z00Go5?l0ool0]_oonf[ooo]ZofT0o`08
oookJP03oom;0?oonf[ooo]Z03Kooo]Z000ZoookJP?oogT00ooi0?l9oomi00;ooo]Z00?oobD0oomi
0?ooN@000_ooN@000olco`3o4P3ooa80o`02o`06o`Coo`@000?o0?l/ool;0?oo2`000ooo2`02oooh
00GoolT01?oo0@000ooob@3oobP0oolX000;oolX00Kooo]Z3_ooN@03oolX00cooo]Z3Ooo:0000ooo
nf[oo`00ool00005ool001Gooo]Z0ol0og/>oookJPgoo`001_oonfX2oolX0003ool10?oo:03oobP0
00;oobP00ooonfX3ool0017ooo]Z1?oo:0000ol0olCo0000ool00004ool00003o`/0ool0ockoo`00
00Ooo`000_oonfX4ool00003onCo0?oo003oo`1>00;ooo]Z00?on@3ooookJ_oonfX04_oonfX4ool0
00Gooo]Z00?o0?m`oookJ_oonfX02OoonfX8oolX00;ooo]Z1?oo00000ooo01?o07[ooookJP05oook
JP03o`3og?oonf[o3@3o00Oooo]Z1?oo000CoookJP03ool;0?oonf[ooo]Z00Wooo]Z1Ooo0005oook
JP03o`3ocOoonf[ooo]Z00Oooo]Z00?oobP0oookJ_oonfX01_oonfX3oolX00[ooo]Z0ooo:0001OlD
o`3oobP0oolX0?oo:03oJ@3o00Sooo]Z00?ood/0oookJ_oonfX0G_oonfX3ooT0o`03of/0oomho`3o
E_l000;oE_l01?oo08<3oookJPCoH@3o00Ko<ol0oa80oolB0?oo0;;oo`06ool0ol@4ool40003ol3o
0?oo2`3oo`/000?oo`/00_oon002o`7o0003oookJ_lA0?ooo`4000?oo`400_oo3005oookJP;o01_o
1Ol0oa<8oookJPOo0?mk1om1o`0hoookJP?o0?mk4OoonfX2o`0Ko`03ool0f_oonf[ooo]Z00_ooo]Z
0_l0okh01Ooo0@3ooo]ZoookJ_oonf[o4@3o01Sooo]Z00?oodT0oookJ_l0ol@00ol00003oookJP03
o`/0ool0ockooo]Z00gooo]Z00Koi?l0oookJ_oonf[oo`1>oookJ_oi0?lDoookJP03ool0Hooonf[o
0?mS00Oooo]Z00?o0?m`oookJ_oonfX02?oonfX01Ol0obCooo]ZoookJ_oonf[o0?l<00Gooo]Z00Ko
oi@0oookJ_oonf[oo`0/ool04ol0N_l6oookJP03o`3og?oonf[o3@3o00Wooo]Z00?oo`2=oookJ_oo
nfX04_oonfX00ooo2`3ooo]ZoookJP09oookJP05ooo=0?oonf[ooo]ZoookJ_l0o`H01OoonfX00ol0
olgooo]ZoookJP07oookJP03ool00?oonf[ooo]Z00Oooo]Z00?oM`3ooookJ_oonfX03?oonfX01OlD
o`3oo`2foookJ_oonf[oJ@3o00Sooo]Z00?ood/0oookJ_oonfX0=OoonfX002[ooo]Z0ooi0?l3oook
JP;on@3o0oooN@001?oob@3oE_l0oeKo0?mFo`02oomi00;oo`230_oonfX00ooo9@3oogT0oomi0002
of40o`03oc?o0?lB0?oo4P3o00;o00Ko1?oo1002onGo00Coo`/01ooob@03ool100OoobP000Cooo]Z
o`0Kool06ooo01_o0ooo:003o`3o4`?ooo]Z2oooN@05oolX00Co@Ol02_oonfX9oolX00Soo`004?oo
nfX5o`3oN`Wooo]Z0_oo:005oookJP_oo`002?oonfX2oolX0005ool10?oo:03oobP0oolX0?lA0?l0
0ooonfX5ool0013ooo]Z1?oo:0000ol0olCo0000ool00004ool00003o`3o?_oo003oo`0000Ooo`00
0ooonfX3ool00003onCo0?oo003oo`1>00;ooo]Z00?on@3ooookJ_oonfX04_oonfX01Ooo06?oo`00
ool00?oo003oobP000Cooo]Z00?o0?m`oookJ_oonfX02_oonfX7oolX0003oookJ_oo003oo`0000Co
o`0000?oo`0Co`1joooonfX01OoonfX00ol0omcooo]Zo`d0o`07oookJPCoo`004ooonfX00ooo2`3o
oo]ZoookJP08oookJPGoo`001_oonfX00ol0olgooo]ZoookJP07oookJP03oolX0?oo003ooo]Z00Oo
oo]Z00?oobP0oookJ_oonfX02_oonfX2oolX0005oaCo0?oo:03oobP0oolX0?mY0?l02?oonfX00ooo
B`3ooo]ZoookJP1JoookJP?on@3o0ooonfX4ooT0o`03of/0oomho`3oN?l000;oE_l01?oo08<3oook
JPCoH@3o0_lco`02oa80o`03o`06ool0olCoo`@000?oo`@000?ooo]Zol3o0?oo2`000ooo2`03oooh
0003o`7o0?oonf[ooo]Z00Goo`400_oo3005oookJP;o01_o1_l0oa<9oookJPKo0?mk00?ooo]Zod7o
0?m1o`001_m1o`0[oookJPGo0?mk4OoonfX3o`0Ko`03ool0f_oonf[ooo]Z00cooo]Z00?o0?nnoook
J_oo0@000ooonfX00olA0?oooo]ZoookJP0GoookJP03oom90?oonf[o0?o400?o00000ooonfX00ol;
0?oo0?lnoookJP0=oookJP06onCo0?oonf[ooo]Zool0C_oonf[on@3o5OoonfX00ooo06?ooo]Zo`3o
H`06oookJP03o`3oL?oonf[ooo]Z00Wooo]Z00Co0?lToookJ_oonf[o0?l<1OoonfX01oooU03ooo]Z
oookJ_oonf[oo`0/ool04ol0N_l01_oonfX00ol0omcooo]Zo`d0o`09oookJP03ool0SOoonf[ooo]Z
01;ooo]Z00?oo`/0oookJ_oonfX02OoonfX01Oooc@3ooo]ZoookJ_oonf[o0?l600Gooo]Z00?o0?o=
oookJ_oonfX01ooonfX2ool000Sooo]Z00?oM`3ooookJ_oonfX03?oonfX01OlDo`3oo`2foookJ_oo
nf[oJ@3o00Sooo]Z00?ood/0oookJ_oonfX0=?oonfX002cooo]Z00CoogT0ooT0oooi0?oon@3o0ooo
nfX00ooi0?ooogT0ooT0o`02of/0o`03ooo90?mho`3oE_l000;oE_l00ooo08<3oookJP03oolU0?mQ
0?ooH@3o00;oH@3o00?o<ol0oa80oolB0?l00_l01_l4ool40004o`3oa?oUo`3oiOl0ool;00[oolT0
1Ooo:0000ooo303ooo]ZoookJP03oookJP04oigo0?l06ooo01_oo`0Ko`Ko0?lC1oooN@001?oo:03o
ogT0oomi0?ooN@08o`3oN`Goo`0000?o@Ol0oookJ_oonfX00ooonfX6oolX00Soo`002ooonfX5o`3o
N`_ooo]Z1Ooo:002oookJPWoo`001?oo:008oookJP;oobP000Goo`40oolX0?oo:03ooo]Zoa40o`03
oookJPOoo`003ooonfX3oolX0003oookJ_l0olCo000000Goo`0000?o0?lnool00?oo00001ooo0003
oookJP?oo`0000?oi?l0ool00?oo04h00_oonfX00ooi0?oooo]ZoookJP0CoookJP04ool0Hooo003o
o`00ool000Gooo]Z00?o0?m`oookJ_oonfX02OoonfX00ol0obCoobP0oolX0004oolX00Ooo`0000?o
o`0Co`1joooonfX01OoonfX00ol0omcooo]Zo`d0o`08oookJP?oo`005?oonfX00ooo2`3ooo]Zoook
JP06oookJPOoo`001?oonfX00ooo:03o0?o=oookJP0:oookJP03ool00?oonf[ooo]Z00Kooo]Z00?o
obP0ogL0oooonfX02ooonfX01_oo:03o5?l0oolX0?oo:03ooo]ZofT0o`Sooo]Z00?ood/0oookJ_oo
nfX0G?oonfX3ooT0o`Cooo]Z0ooi0?l2of/0o`;oN?l00_mFo`03ool0P`Cooo]Z1?mQ0?l2oc?o0004
oa80ool01_oo00Koo`3oa0?oo`@000?o0?o4oookJ_oonfX01?oo2`05oooh0003oookJ_lA0?ooo`40
00?oo`4000?o0?nnool<0?oo30001OoonfX00onMo`3o01_oo`0Ko`06o`3o4`Wooo]Z2ol0og/5od7o
01oooo]Z1Ol0og/DoookJP;o01_o0_oonfX00ooo0=[ooo]ZoookJP0<oookJP03o`3o__oonf[oo`40
00?ooo]Z00?o4@3ooookJ_oonfX05ooonfX01?ooB@3ooo]ZoookJ_l0ol@3o`0000?ooo]Z00?o2`3o
o`3o?_oonfX03OoonfX01?oTo`3ooo]ZoookJ_oo04h2oookJP03ooT0oooonf[ooo]Z01;ooo]Z00?o
o`1SoookJ_l0of<01ooonfX00ol0og3ooo]ZoookJP08oookJP05o`3o9?oonf[ooo]ZoookJ_l0o``0
1OoonfX01_ooU03ooo]ZoookJ_oo02coo`0Co`1jo`Kooo]Z00?o0?oLoookJ_l=0?l02_oonfX00ooo
08gooo]ZoookJP0BoookJP03ool;0?oonf[ooo]Z00Wooo]Z00Goold0oookJ_oonf[ooo]Zo`3o1P05
oookJP03o`3ocOoonf[ooo]Z00Sooo]Z00?oo`00oookJ_oonfX01_oonfX2ogL0o`gooo]Z00Go5?l0
ool0]_oonf[ooo]ZofT0o`08oookJP03oom;0?oonf[ooo]Z03?ooo]Z000ZoookJP?o0>_o0ooonfX3
ooT0o`03odSo0?oonf[ooo]Z00Con@3o0_m[0?l4oomi00Coo`230ooonfX00ooo9@3oH@3oof40o`02
of40o`03oc?o0?lB0?oo4P3o00;o00Ko0ooo1002o`3oa003oookJ_oob@3oolT000CoolT01?oon003
oolX00?oo`401?l0okh4oookJP;oWOl000?oo`3Jo`0Kool06ol01_l0oa<01?ooN@3oobP0oolX0?oo
:002oookJPcoo`007ol0og/>oookJPOoobP00_oo00001?l06oooo`00ool00?oo0009oolX00Sooo]Z
00?oobP0ool10?oo:0000_oonfX01?lA0?oooo]ZoookJ_oonfX9ool000kooo]Z0ooo:0000ol0olCo
0000o`000005ool00003o`3o?_oo003ooo]Z00Koo`001OoonfX2ool00006onCo0?oo003oo`00ool0
C_oonf[on@3o5OoonfX01?oo06?ooo]Zool00?oo0006oookJP03o`3oL?oonf[ooo]Z00Wooo]Z00?o
0?lToolX0?oo:0000_oo:009ool00003ool04ol0N_oooo]Z00Gooo]Z00?o0?oLoookJ_l=0?l02?oo
nfX2ool001Gooo]Z00?oo`/0oookJ_oonfX01?oonfX9ool000;ooo]Z0_oo:0000ooonf[o0?o=oook
JP0:oookJP03ool00?oonf[ooo]Z00Oooo]Z00?oM`3ooookJ_oonfX02_oonfX01_oo:03o5?l0oolX
0?oo:03ooo]ZofT0o`Sooo]Z00?ood/0oookJ_oonfX0F?oonfX3o`3[o`?ooo]Z0ooi0?l01?m8o`3o
oo]ZoookJ_oonfX4ooT0o`;oJ`3o00?oN?l0oeKo0?mFo`001?oo08<3oookJP03o`2AoomQ0?ooH@3o
00;oH@3o0_lco`000olB0?oo00Koo`06o`04ool40003o`3oa?oonf[ooo]Z00Goo`/01Ooon0000olA
0?ooo`40ool10002ool100Co0?nn1OoonfX2oigo00;o01_o1_l0oa<>oookJRCo0?mk5ooonfX2o`0K
o`04oookJ_oo0=[oo`3Jool0fPkooo]Z00?o0?nnoookJ_oo0@000ooonfX00olA0?oooo]ZoookJP0H
oookJP04oom90?oonf[ooo]Zo`3oa0Co00000_oonfX00ol;0?oo0?lnoookJP0=oookJP07og?o0?oT
o`3ooo]ZoookJ_oo04kooo]ZooT0o`0EoookJP03ool0Hol0of?ooo]Z00Kooo]Z00?o0?m`oookJ_oo
nfX02OoonfX01?l0obCooo]ZoookJ_l0o``6oookJP06oonD0?oonf[ooo]Zool0;?oo01?o07[o1_oo
nfX00ol0omcooo]Zo`d0o`09oookJP03ool0SOoonf[ooo]Z01?ooo]Z00?oo`/0oookJ_oonfX02Ooo
nfX01Oooc@3ooo]ZoookJ_oonf[o0?l600Gooo]Z00?o0?o=oookJ_oonfX02?oonfX00ooo003ooo]Z
oookJP07oookJP03ogL0oooonf[ooo]Z00_ooo]Z00Go5?l0ool0]_oonf[ooo]ZofT0o`08oookJP03
oom;0?oonf[ooo]Z03;ooo]Z000ZoookJP?oogT00ol0jol00ol0ohcooo]ZoookJP03ooT0o`04odSo
0?oonf[ooo]ZoookJP?on@3o0om[0?l4oomi00?oo`2300GoogT0oookJ_oonf[oogT0oolU0003of40
o`;o<ol00_lB0?l00ol01_ooo`@0ool40002ool400;o0?o40_oob@000oo0o`3oo`/0ool;0002ool;
0003o`7o0?oon03oobP000;oooP000?o4@3oool10?oo0@000ooo0@05o`3o_PGooo]Z0_nMo`02o`0K
o`;o0?lC4?oo0007oookJPgoo`005ooonfX9oolX00;o01_o3_oo:006oookJP;oo`400_oonfX2oa40
o`?ooo]Z2?oo000@oookJP;oobP000Cooo]Zo`3oa?l0003o00001Ooo00001?l0ockoo`00oookJ_oo
nfX5ool000Gooo]Z0_oo00001_oTo`3oo`00ool00?oo04kooo]ZooT0oaGooo]Z00Coo`1SoookJ_oo
nf[oo`001_oonfX00ol0og3ooo]ZoookJP09oookJP03o`3o9?oonf[oobP000CoobP01ooo00000ooo
nf[oo`0Co`1jo`06oookJP03o`3og?oonf[o3@3o00Sooo]Z0_oo000EoookJP03ool;0?oonf[ooo]Z
00Gooo]Z1ooo0005oolX0003oookJ_l0olgooo]Z00[ooo]Z00?oo`00oookJ_oonfX01ooonfX00omg
0?oooo]ZoookJP0;oookJP05oaCo0?oo:03ooo]ZoookJ_mY0?l02?oonfX00oooB`3ooo]ZoookJP1G
oookJP?ooaT00ol0jol00ol0ohcooo]ZoookJP03ooT0o`03odSo0?oonf[ooo]Z00;ooo]Z0ooi0?l3
of/0o`03ogSo0?mFo`3oE_l000?oo`231?oonfX01?oo9@3oH@3oof40oomQ0?l3oc?o0003oa80ool0
1_oo00Ko00Coo`@000Co0?o4oookJ_oonf[o`?l01Ooo2`04oooh0003oa40oooo0@3oo`4000?oo`40
1Ol0okh5oookJP;oWOl00_l06ol7o`3o4coooo]Z0ol06ol3ool0fQ3ooo]Z00?o0?nnool10?oo0@00
0_oonfX2oa40oa_ooo]Z00?oodT0oookJ_l0ol@01?l00003oookJP03o`/0ool0ockooo]Z00gooo]Z
00OoLol0onCo0?oonf[ooo]Zool0C_oonf[on@3o01Gooo]Z00?oo`1SoookJ_l0of<01ooonfX00ol0
og3ooo]ZoookJP08oookJP05o`3o9?oonf[ooo]ZoookJ_l0o``01_oonfX01_ooU03ooo]ZoookJ_oo
02coo`0Co`1jo`Kooo]Z00?o0?oLoookJ_l=0?l02OoonfX00ooo08gooo]ZoookJP0CoookJP03ool;
0?oonf[ooo]Z00Sooo]Z00?oold0oookJ_oonfX00_oonfX00ol0o`Kooo]ZoookJP03oookJP03o`3o
cOoonf[ooo]Z00Sooo]Z00?oo`00oookJ_oonfX01ooonfX00omg0?oooo]ZoookJP0;oookJP05oaCo
0?oo0;Kooo]ZoookJ_mY0?l02?oonfX00oooB`3ooo]ZoookJP0aoookJP00:_oonfX3ool0^`?oogT0
00Coo`3Ao`3[ool0jooo0?n<0_oonfX3ooT0o`04odSo0?oonf[oogT0oomi00Con@3o0om[0?l3oomi
00?oo`231?oonfX00ooUo`3oH@3oof40o`02of40o`?o<ol000?o4P3oo`06oooo10000ooo1003o`3o
a003oookJ_o0o`3oo`/000Coo`/000?o0Ol0oooh0?oon0000_oon0000olA0?ooo`40ool10005ool1
00Co0?nn0ooonfX01?ooN@3ooo]ZoookJ_oo:00>ool000_ooo]Z2Ooo000<oookJP?oobP01OoonfXD
oolX00cooo]Z00?o0?nnool10?oonfX00_oonfX00olA0?oooo]ZoookJP03oookJPKoo`004_oonfX2
oolX0003oookJ_l0olCo000000;o00001?oo00001?l0ockoo`00oookJ_oonfX5ool000Kooo]Z0_oo
00000ooTo`3oo`00ool0CP02oookJP03ooT0oooonf[ooo]Z00Wooo]Z0_oo0008oookJP03ool0Hooo
nf[o0?mS00Oooo]Z00?o0?m`oookJ_oonfX02OoonfX00ol0obCooo]ZoolX0003oolX0003oookJ_oo
003oo`0000Coo`0000?ooo]Zool04ol0N_l01ooonfX00ol0omcooo]Zo`d0o`08oookJP03ool00?oo
nf[ooo]Z01Cooo]Z00?oo`/0oookJ_oonfX01OoonfX7ool000GoobP000?ooo]Zo`3ocOoonfX02_oo
nfX00ooo003ooo]ZoookJP07oookJP03ogL0oooonf[ooo]Z00_ooo]Z00Go5?l0oolX0?oonf[ooo]Z
ofT0o`08oookJP03oom;0?oonf[ooo]Z05Kooo]Z0ooo0;/4oolI00;o0>_o00?o0?n<oookJ_oonfX0
1?oi0?l4oookJPCon@3o0om[0?l2oeKo00?oo`231OoonfX4of40o`?o<ol000?o4P3oo`06ool01_l0
0ooo1003o`3oa003oookJ_o0o`3o`?l000Goo`/01?oon0000olA0?ooo`40ool10005ool100Co0?nn
2?oonfX2o`0Ko`So0?lC=?oonfX3o`0Ko`;oo`3J4_oonfX2o`3o_P05ool10?oonf[ooo]ZoookJ_lA
0?l07?oonfX01?ooB@3ooo]ZoookJ_l0ol@4o`0000?ooo]Z00?o2`3oo`3o?_oonfX03OoonfX01Omc
o`3oi?l0oookJ_oonf[oo`1>00;ooo]Z00?on@3ooookJ_oonfX04_oonfX00ooo06?ooo]Zo`3oH`07
oookJP03o`3oL?oonf[ooo]Z00Wooo]Z00Go0?lToookJ_oonf[ooo]Zo`3o3005oookJP06oonD0?oo
nf[ooo]Zool0;?oo01?o07[o1ooonfX00ol0omcooo]Zo`d0o`09oookJP03ool0SOoonf[ooo]Z01?o
oo]Z00?oo`/0oookJ_oonfX02?oonfX00oooc@3ooo]ZoookJP02oookJP03o`3o1_oonf[ooo]Z00?o
oo]Z00?o0?o=oookJ_oonfX02?oonfX00ooo003ooo]ZoookJP07oookJP03ogL0oooonf[ooo]Z00_o
oo]Z00Go5?l0ool0]_oonf[ooo]ZofT0o`08oookJP03oom;0?oonf[ooo]Z033ooo]Z000ZoookJP?o
o`1j0ooo0;/3oomi0003ool0dOl0jooo0>_o00;o0?n<00CoogT0ooT0oooi0?oon@3o0_m8o`03oomi
00Con@3o0_m[0?l00oooN@3oE_l0oeKo0004ool0P`;ooo]Z0_oUo`000ol0TOooH@3oof40o`02of40
o`?o<ol000?o4P3oo`06oooo10000ooo1003o`3oa003oom90?o0o`3o`?l000Goo`/000?o0Ol0oooh
0?oon0000_oon003oa40o`Koo`401?l0okh4oookJPcoo`001_l06ol7oookJPKoo`001ooonfX8oolX
00?ooo]Z3ooo:004ool000gooo]Z00?o0?nnool10?oo0@000ooonfX00olA0?oooo]ZoookJP03oook
JPGoo`005?oonfX01?oo:03ooo]Zo`3oa?oonfX3o`0000Coo`0000Co0?lnoookJ_oonf[ooo]Z1Ooo
0006oookJP;oo`0000?oi?l0ool00?oo04h00_oonfX00ooi0?oooo]ZoookJP07oookJPCoo`002?oo
nfX01?oo06?ooo]ZoookJ_l0of<7oookJP03o`3oL?oonf[ooo]Z00Sooo]Z00?o0?lToookJ_oonfX0
1?oo:0000ooonf[oo`00ool00004ool00003oookJ_oo01?o07[o00Oooo]Z00?o0?oLo`d0oooonfX0
2?oonfX00ooo08gooo]ZoookJP0DoookJP03ool;0?oonf[ooo]Z00Kooo]Z1Ooo0005oolX00;ooo]Z
00?o0?o=oookJ_oonfX02OoonfX00ooo003ooo]ZoookJP07oookJP03ogL0oooonf[ooo]Z00_ooo]Z
00Co5?l0oolX0?oo0;Kooo]Z0_mY0?l7oookJP03oom;0?oonf[ooo]Z05Gooo]Z0ooo07X3ool0^`04
oiKo0?oo6@3ooaT0oolI00?o0>_o00?o0?n<oookJ_oonfX00ooi0?l00om8o`3ooo]ZoookJP02oook
JP?on@3o0om[0?l2oeKo00Coo`231?oonfX00ol0TOooH@3oof40o`02of40o`Co<ol000?o00Koool4
0?oo10000_oo1003o`3oa004oom90?o0o`3o`?l0ol3o00Goo`/01?oon003oa40o`Koo`401?l0okh:
oookJP03oigo0?l06ooo0?lC00?o0?lC1_l06olSoookJPOo01_o00?oo`3Joigo0?nMo`004_oonfX2
o`3o_P;oo`400_oonfX2oa40o`Gooo]Z0_l1o`0FoookJP04oom90?oonf[ooo]Zo`3oa0Co00000ooo
nfX00ol;0?oo0?lnoookJP04oookJP03o`24oooonf[ooo]Z00Oooo]Z00Coi?l0oookJ_oonf[oo`1>
0_oonfX00ooi0?oooo]ZoookJP0CoookJP03ool0Hooonf[o0?mS00Oooo]Z00?o0?m`oookJ_oonfX0
2?oonfX01Ol0obCooo]ZoookJ_oonf[o0?l<00Kooo]Z00Kooi@0oookJ_oonf[oo`0/ool04ol0N_l7
oookJP03o`3og?l=0?oooo]Z00Sooo]Z00?oo`2=oookJ_oonfX05?oonfX00ooo2`3ooo]ZoookJP08
oookJP03ooo=0?oonf[ooo]Z00;ooo]Z00?o0?l6oookJ_oonfX00ooonfX00ol0olgooo]ZoookJP08
oookJP03ool00?oonf[ooo]Z00Oooo]Z00?oM`3ooookJ_oonfX02ooonfX01?lDo`3oo`2fool0]_oo
nfX2ofT0o`Oooo]Z00?ood/0oookJ_oonfX0;ooonfX002cooo]Z00CoogT0ool0N_oo07[oo`1j0ooo
0;/3oomi0003oolI0?oo0=7o0>_o00?o0?n<0ooi0?l2odSo00CoogT00ooi0?l2of/0o`04ogSo0?mF
o`3oE_l0oeKo00?oo`2300Kooo]ZonGo0?oUo`3oiOl0oookJ_l0TOl4of40o`?o<ol00_lB0?l4ool4
00?o0?o400CoolT0oom90?o0o`3o`?l01Ooo2`000ol1o`3oooP0oooh0002oooh00Co4@3o1_oo0@03
o`3o_P03oomi0?oo003oo`0000Koo`0000?ooo]Zoomi0?ooN@001oooN@0;o`0Ko`;ooo]Z2Ooo:006
o`0Koa3oobP01?oo000;oookJP;o0?nn00?oo`40oookJ_oonfX00_oonfX01?lA0?oooo]ZoookJ_oo
nfX2oolX00Coo`005_oonfX01?ooB@3ooo]Zo`3oa?oonfX3o`0000Coo`0000?o0?lnoookJ_oonfX0
0_oonfX4ool000Oooo]Z00Ooo`00onCo0?oo003ooo]Zool0C_oonf[on@3o00Sooo]Z1Ooo0008oook
JP04ool0Hooonf[ooo]Zo`3oH`Oooo]Z00Co0?m`oookJ_oo003oo`002?oonfX00ol0obCooo]Zoook
JP03oolX00;ooo]Z1Ooo00001?oo02coo`0CoookJ_l0N_l6oookJP03o`3og?oonf[o3@3o00Wooo]Z
00?oo`2=oookJ_oonfX05?oonfX00ooo2`3ooo]ZoookJP06oookJPGoo`001Ooo:002oookJP;oobP0
2_oonfX00ooo003ooo]ZoookJP07oookJP03ogL0oooonf[ooo]Z00_ooo]Z00?o5?l0oookJ_oo0;H0
0_oonfX00omY0?oooo]ZoookJP05oookJP03oom;0?oonf[ooo]Z05Oooo]Z0ooo07X3ool0^`03oiKo
0?oo6@3ooaT000;ooaT00_l0jol2o`3oS005oookJ_oi0?oon@3oooT0oom8o`001?oonfX3ooT0o`?o
J`3o00?oN?l0oeKo0?mFo`000ooo08<5oookJP03o`2AoomQ0?ooH@3o00;oH@3o1?lco`000olB0?oo
o`@0ool40002ool400?o0?o40_ooB@03ol3o00Goo`/01?oon004oa40o`Koo`401?l0okh;oookJP;o
WOl00ooo0=X>o`0Ko`_ooo]Z2_l06ol3ool0fPCoWOl04ooonfX2o`3o_P03oookJ_oo0@3ooo]Z00;o
oo]Z00?o4@3ooookJ_oonfX01?oonfX00ol1o`3ooo]ZoookJP0FoookJP04oom90?oonf[ooo]Zo`3o
a0Co00000ooonfX00ol;0?oo0?lnoookJP04oookJP03o`24oooonf[ooo]Z00Oooo]Z00Coi?l0oook
J_oonf[oo`1>0_oonfX00ooi0?oooo]ZoookJP0CoookJP04ool0Hooonf[ok@3oo`3oH`Oooo]Z00?o
0?m`oookJ_oonfX02?oonfX01Ol0obCooo]ZoookJ_oonf[o0?l<00Kooo]Z00Kooi@0oookJ_oonf[o
o`0CoookJ_l0N_l6oookJP03o`3og?oonf[o3@3o00Wooo]Z00?oo`2=oookJ_oonfX05?oonfX00ooo
2`3ooo]ZoookJP08oookJP03ooo=0?oonf[ooo]Z00;ooo]Z00?o0?l6oookJ_oonfX00ooonfX2o`3o
c@Wooo]Z00?oo`00oookJ_oonfX01ooonfX00omg0?oooo]ZoookJP0;oookJP03oaCo0?oonf[oo`2f
00;ooo]Z00?oJ@3ooookJ_oonfX01OoonfX00oooB`3ooo]ZoookJP0^oookJP00:_oonfX2onoo00;o
oo]Z0_ooN@03ool0NP?oo`2k00CoU_l0oolI0?oo6@3ooaT01?oo:0001?l0ohcon@3oooT0oooi0?l3
odSo00;oogT000?ooo]ZooT0oooi0?l00_oi0?l2of/0o`03oookJ_mFo`3oE_l000Coo`231OoonfX0
1?l0TOooH@3oof40oomQ0?l2oolU00?o<ol000?o4P3oool40?oo10000_oo1003o`3oa0;oodT00oo0
o`04ool;0003o`7o0?ooN@3oooP000?oooP01OlA0?l5ool10003oomi0?oo003oo`0000Coo`002_oo
N@04oookJP;oWOl01Ooo0=X;o`0Ko`Koo`3J1?nMo`000ooo003oobP0oolX0009oolX00Goo`002?oo
nfX2o`3o_P;oo`400ooonfX2oa40o`?ooo]Z0ooo:002ool001Oooo]Z00GoodT0oookJ_oonf[o0?o4
oookJP03o`0000Coo`0000?o0?lnoookJ_oonfX00_oonfX4ool000Oooo]Z00Goo`00onCo0?oo003o
oo]Zool0CP02oookJP03ooT0oooonf[ooo]Z00?ooo]Z2?oo0008oookJP04ool0Hooonf[ooo]Zo`3o
H`Oooo]Z0ooo0008oookJP04o`3o9?oonf[oo`00ool000;oobP00ooonfX5ool00004oookJ_oo01?o
oo]Zo`1jo`Kooo]Z00?o0?oLoookJ_l=0?l02OoonfX00ooo08gooo]ZoookJP0DoookJP03ool;0?oo
nf[ooo]Z00Oooo]Z0ooo0005oolX00Cooo]Z00?oobP0oookJ_oonfX02?oonfX00ooo003ooo]Zoook
JP07oookJP03ogL0oooonf[ooo]Z00_ooo]Z00?o5?l0oookJ_oo0;H00_oonfX00omY0?oooo]Zoook
JP05oookJP03oom;0?oonf[ooo]Z05?ooo]Z0oo_o`03oookJP?oo`1j0ooo0;/2oiKo00?ooaT00_l0
jol2o`3oS004oookJ_oi0?oon@3oooT0o`;oB?l00ooonfX4ooT0o`?oJ`3o0_mFo`04ool0P`Gooo]Z
00Co097oof40oomQ0?ooH@3o0_oo9@03oc?o0003oa80oooo103oo`@000;oo`@00ol0ol@3oom900?o
`?l01?oo2`000ol1o`3oooP0oooh0002oooh00Go4@3o1Ooo0@05o`3o_Q3ooo]Z0_nMo`06ool0fP_o
01_o1_oo0=X6oigo01Kooo]Z0_l0okh00ooonf[oo`40ool10002oookJP;o4@3o1_oonfX00ol1o`3o
oo]ZoookJP0FoookJP05oom90?oonf[ooo]ZoookJ_l0ol@01?l00003oookJP03o`3o?_oonf[ooo]Z
00Cooo]Z00?o08CooookJ_oonfX01ooonfX01omco`3oi?l0oookJ_oonf[oo`1>oookJ_oi0?l05_oo
nfX00ooo06?ooo]Zo`3oH`07oookJP03o`3oL?oonf[ooo]Z00Sooo]Z00Go0?lToookJ_oonf[ooo]Z
o`3o3007oookJP06oonD0?oonf[oo`0/ool04ooonf[o07[o1_oonfX00ol0omcooo]Zo`d0o`09oook
JP03ool0SOoonf[ooo]Z01Cooo]Z00?oo`/0oookJ_oonfX02?oonfX00oooc@3ooo]ZoookJP02oook
JP03o`3o1_oonf[ooo]Z00Cooo]Z00?o0?o=oookJ_oonfX01ooonfX00ooo003ooo]ZoookJP07oook
JP;oM`3o3?oonfX00olDo`3ooo]Zool0]P02oookJP03ofT0oooonf[ooo]Z00Gooo]Z0_ooB`0^oook
JP00:_oonfX2o`3oT`?okol000Cooo]Zoomi0?ooN@3oogT00_oo07X01OooN@3oo`2kool0^ooo0;_o
oo]Z00?ooaT02?oo:003odSo00Cooo]Z0ooi0?l2of/0o`04ogSo0?mFo`3oE_l0oeKo00?oo`231?oo
nfX00ooob@3o097oof40o`02of40o`?oobD00olco`000olB0?ooo`@0ool40002ool400;o0?o40_oo
B@001?oonf[o`?l0ol3o0?o0o`05ool;0003oomi0?oon03oooP000;oooP00_ooN@04oa40o`Coo`40
0ooo000:oomi00gooo]Z3Ooo:0000onMo`3ooo]ZoookJP0;oookJPCoobP01Ooo0005oookJP;o0?nn
0ooo0@02oookJP?o4@3o0ooonfX5oolX01Wooo]Z00KoodT0oookJ_oonf[o0?o4oookJ_l00005oolX
0003ool00?l0ockooo]Z00?ooo]Z00?oo`00oolX0?oo:0000ooo:006oookJP04onCo0?oo003oobP0
ool0CP;ooo]Z00?on@3ooookJ_oonfX00_oonfX9ool000Sooo]Z00Coo`1SoookJ_oonf[o0?mS0_oo
nfX2oolX0003oookJ_oo003oo`0000Coo`002?oonfX4ool000;oobP01?oonfX3ool00004ool0;?oo
nf[oo`0Co`1jo`Cooo]Z00GoobP0oookJ_oonf[o0?oLo`d0o`0:oookJP03ool0SOoonf[ooo]Z01Co
oo]Z00?oo`/0oookJ_oonfX01ooonfX3ool000GoobP01?oonfX00ooo:03ooo]ZoookJP08oookJP03
ool00?oonf[ooo]Z00Oooo]Z00?oM`3ooookJ_oonfX02ooonfX00olDo`3ooo]Zool0]P02oookJP03
ofT0oooonf[ooo]Z00Gooo]Z00?ood/0oookJ_oonfX0D_oonfX3o`3oT`?okol00ooonfX3ool0NP?o
o`2k00?ooo]ZoiKo0?oo6@000_oo6@02o`3[o`;o0?n<00Cooo]ZooT0oooi0?oon@3o0_m8o`04oook
JP?on@3o0om[0?l00omho`3oE_l0oeKo0003ool0P`Gooo]Z00?o097oof40oomQ0?l00_mQ0?l2oolU
00?o<ol000?o4P3oool40?oo10000_oo1002o`3oa0?oodT01?o0o`04ool;0003o`7o0?oon03oooP0
00;oooP000?o0Ol0oookJ_lA0?l00olA0?l5ool100Go0?nn00?oo``0oookJ_oonfX05OoonfX;oigo
01[ooo]Z0ol0okh3ool100;ooo]Z0_lA0?l7oookJP03o`7o0?oonf[ooo]Z01Oooo]Z00GoodT0oook
J_oonf[o0?o4oookJP04o`000004oookJ_m6o`3ooo]Zo`3o?PKooo]Z00?o08CooookJ_oonfX01ooo
nfX01Omco`3oi?l0oookJ_oonf[oo`1>00;ooo]Z00?on@3ooookJ_oonfX04ooonfX01?oo06?ooo]Z
ond0ool0of<7oookJP03o`3oL?oonf[ooo]Z00Sooo]Z00Go0?lToookJ_oonf[ooo]Zo`3o3007oook
JP05oonD0?oonf[oo`0/ool04ol0N_l01ooonfX00ol0omco3@3ooookJP09oookJP03ool0SOoonf[o
oo]Z01Cooo]Z00?oo`/0oookJ_oonfX02?oonfX00oooc@3ooo]ZoookJP02oookJP03o`3o1_oonf[o
oo]Z00Cooo]Z00?o0?o=oookJ_oonfX01ooonfX00ooo003ooo]ZoookJP08oookJP03ogL0oooonf[o
oo]Z00[ooo]Z00?o5?l0oookJ_oo0;H00_oonfX00omY0?oooo]ZoookJP06oookJP03oom;0?oonf[o
oo]Z02_ooo]Z000ZoookJP03o`26oooonf[ooo]Z00;o0?nC0oo_o`03oomi00?oo`1j00GoogT0ool0
^ooo0;_oo`2koolX0003oolI00WoobP00_m8o`04oookJPCon@3o00?oJ`3oogSo0?oonfX00_mFo`04
ool0P`;ooo]Z0ooob@04of40o`?oobD00olco`000olB0?ooo`@0ool40002ool400;o0?o40_ooB@00
0ooonf[o`?l0ol3o0002ol3o00Coo`/000?oogT0oooh0?oon0000_oon003oomi00Co4@3o00?oo`40
ool00?oo0@001?oo0@04oomi00;oo``03_oonfX;oolX00kooo]Z0oooN@05ool000?ooo]Z0ol0okh2
ool100?oogT00_lA0?l4oookJPSoobP06?oonfX01_ooB@3oogT0oomi0?l0olCooo]Zo`0000KoobP0
00?o0?lnoolX0?oo:0002?oo:005oookJP03oolX0?oTo`3oobP000;oobP000?oo`1>oookJ_oi0?l0
1OoonfX8ool000Wooo]Z00Coo`1SoookJ_oonf[o0?mS0ooo:007ool000?ooo]Z0_oo0002oookJPKo
o`0000?oobP0oookJ_oonfX00ooonfX3ool00004ool0;?oonf[oo`0Co`1jo`;ooo]Z0_oo:003oook
JP03o`3og?l=0?oooo]Z00Wooo]Z00?oo`2=oookJ_oonfX05?oonfX00ooo2`3ooo]ZoookJP07oook
JP?oo`001Ooo:004oookJP03oolX0?oonf[ooo]Z00Sooo]Z0_oo0008oookJP03ogL0oooonf[ooo]Z
00_ooo]Z00?o5?l0oookJ_oo0;H00_oonfX00omY0?oooo]ZoookJP05oookJP03oom;0?oonf[ooo]Z
057ooo]Z0_l0Q_l01?oonf[o0?nCo`3oTol0oi<3onoo00?ooo]Z0ooo07X3ool0^`03oookJ_nFo`3o
oaT000;ooaT00_l0jol2o`3oS004oookJ_oi0?oon@3oooT0o`;oB?l01?oonfX4ooT0o`;oJ`3o00?o
N?l0oeKo0?mFo`001?oo08<5oookJP04o`2AoomQ0?ooH@3oof40o`?oobD00olco`000olB0?ooo`@0
ool40002ool400;o0?o40oooB@001?oonf[o`?l0ol3o0?o0o`05ool;00GoooP000?o0Ol0oookJ_lA
0?l00olA0?l7ool100?o0?nn0ooo300coookJP;o0?nn00?ooo]Zool10?oo0@000ooonfX2oa40o`Oo
oo]Z0_l1o`0JoookJP05oom90?oonf[ooo]Zo`3oa?oonfX01?l000001?oonf[oA_l0oookJ_l0och6
oookJP03o`24oooonf[ooo]Z00Sooo]Z00Coi?l0oookJ_oonf[oo`1>0_oonfX00ooi0?oooo]Zoook
JP0DoookJP03ool0Hooonf[o0?mS00Oooo]Z00?o0?m`oookJ_oonfX02OoonfX01OnRo`3ooo]Zoook
J_oonf[o0?l<00Kooo]Z00Kooi@0oookJ_oonf[oo`0/ool04ol0N_l7oookJP03o`3og?l=0?oooo]Z
00Wooo]Z00?oo`2=oookJ_oonfX05?oonfX00ooo2`3ooo]ZoookJP08oookJP03ooo=0?oonf[ooo]Z
00;ooo]Z00?o0?l6oookJ_oonfX01?oonfX00ol0olgooo]ZoookJP07oookJP;oo`002OoonfX00omg
0?oooo]ZoookJP0:oookJP03oaCo0?oonf[oo`2f00;ooo]Z00?oJ@3ooookJ_oonfX01_oonfX00ooo
B`3ooo]ZoookJP0ZoookJP00:_oonfX00ooo203o08Koo`26o`03oookJP;o0?nC0oo_o`03oomi00?o
o`1j00?oogT0ool0^ooo0;/00_oo:003oolI00KoobP00_oi0?l4odSo00Cooo]Z0ooi0?l01?m[0?oo
N?l0oookJ_oonfX2oeKo00?oo`2300?ooo]Zooo90?oob@000ooob@03of40o`CoobD00ooob@000olB
0?ooo`@0ool40002ool400;o0?o40_ooB@02oookJP;o`?l000?oogT0ool;0?oo2`000ooo2`04oooh
0003oomi0?l1o`3o0Ol000;o0Ol01OooN@07ool100Co0?nn00?oo``0oolX0?oo:0004Ooo:00;oook
JPKoogT00ooo0005o`3o_P?oo`401OooN@05oookJPWoobP05ooonfX00oooB@3ooo]Zoomi0003oomi
0003o`000?oo003oo`0000?oo`0000?oobP0o`3o?_oo:0002Ooo:003oookJP?oobP000Goi?l0oolX
0?oo:03oobP0ool0CP02oookJP03ooT0oooonf[ooo]Z00?ooo]Z1ooo000:oookJP03ool0Hooonf[o
obP000;oobP02Ooo00001Ooonf[oo`00ool00?oo003ooo]Z00Ooo`0000?o0?l<oookJ_oonfX01?oo
nfX2ool00004oookJ_oo02cooo]Zool04`GoobP00_oonfX00ol0omcooo]Zo`d0o`04oookJP;oobP0
1?oonfX00ooo08gooo]ZoookJP0DoookJP03ool;0?oonf[ooo]Z00Sooo]Z00?oo`00oookJ_oo:000
0ooo:005oookJP03oolX0?oonf[ooo]Z00?ooo]Z00?oobP0oookJ_oonfX00ooonfX00ooo003ooo]Z
oookJP06oookJP;oM`3o3?oonfX01_lDo`3ooo]Zool0]_oo0;Kooo]ZofT0o`Oooo]Z00?ood/0oook
J_oonfX0D?oonfX2ool800;o08Ko0_oonfX3o`3oT`?okol00ooonfX3ool0NP?oo`2k00?ooo]ZoiKo
0?oo6@000_oo6@02o`3[o`;o0?n<00Cooo]ZooT0oooi0?oon@3o0om8o`04oookJP?on@3o0_m[0?l0
1?mho`3ooo]ZoeKo0?mFo`03ool0P`Kooo]Z1?mQ0?l3oolU00?o<ol000?o4P3oool40?oo10000_oo
1002o`3oa0?oodT00_oonfX3ol3o00Coo`/000?ooo]Zoooh0?oon0000_oon004o`7o0003oookJ_lA
0?oo4@3o00;o4@3o1ooo0@05o`3o_P03ool<0?oonf[ooo]Z02Gooo]Z1Ol0okh3ool100;ooo]Z0olA
0?l7oookJP;o0Ol06ooonfX01_ooB@3ooo]ZoookJ_oonf[o0?o4oookJPCo000000Cooo]ZodKo0?oo
nf[o0?ln1_oonfX00ol0Q?oooo]ZoookJP08oookJP04onCo0?oonf[ooo]Zool0CP;ooo]Z00?on@3o
oookJ_oonfX05OoonfX00ooo06?ooo]Zo`3oH`06oookJP03ool0TOl0og3ooo]Z00Wooo]Z00GoX_l0
o`3o9?oonf[ooo]Zo`3o3007oookJP06oonD0?oonf[ooo]Zool0;?oo01?o07[o1_oonfX00ol0omco
oo]Zo`d0o`0:oookJP03ool0SOoonf[ooo]Z01Cooo]Z00?oo`/0oookJ_oonfX02?oonfX00oooc@3o
oo]ZoookJP02oookJP03o`3o1_oonf[ooo]Z00Cooo]Z00?o0?o=oookJ_oonfX02?oonfX00ooo003o
oo]ZoookJP07oookJP03ogL0oooonf[ooo]Z00[ooo]Z00Ko5?l0oookJ_oo0;Koo`2foookJ_mY0?l8
oookJP03oom;0?oonf[ooo]Z02Wooo]Z000/oookJP04ool80?l0Q_oo08Koo`26o`?ooo]Z00?o0?nC
oomi0?o_o`000_o_o`000oooN@3ooo]ZoookJP03ool0NP03ool0^ooo:03oobP000;oobP00ooo6@03
oolX00;o0?n<0ooi0?l01?o_0?ooB?l0odSo0?m8o`04oookJPCon@3o00?oJ`3ooookJ_oonfX00_mF
o`04ool0P`CoolT000Gooo]Zof40oomQ0?ooH@3oo`2Ao`03oolU00?oolT000?o4P3oo`2boooo1000
0ooo1002o`3oa0;oolT00_oonfX4oomi00Goo`/01Ooon0000ol1o`3oogT0oomi0005oomi00?o4@3o
2Ooo0@07o`3o_PSoobP01ooonfX:oomi00?o0?nn00?oo`00oomi0?oo0@000_oo0@08oomi00?ooo]Z
2ooo:00GoookJP03oom90?oonf[oogT000CoogT02?oo00000ooonf[oobP0oolX0006oolX00;ooo]Z
1Ooo:0001?oTo`3oobP0oolX0?oo04h2oookJP03ooT0oooonf[ooo]Z00Cooo]Z1ooo0009oookJP03
ool0Hooo:03oobP000CoobP05?oo00000ol0o`cooo]ZoookJP04oookJP06ool00?oonf[ooo]Zool0
;?oonf[oo`0C1?oo:003oookJP05o`3og?oonf[oobP0oolX0?oonfX00ooo:005oookJP03ool0SOoo
nf[ooo]Z01Cooo]Z00?oo`/0oookJ_oonfX02?oonfX00ooo003oold0oolX0003oolX00Gooo]Z00?o
obP0oookJ_oonfX00_oonfX00ooo:03ooo]ZoookJP04oookJP03ool00?oonf[ooo]Z00Oooo]Z00?o
M`3ooookJ_oonfX02_oonfX01_lDo`3ooo]ZoookJ_oo0;Kooo]ZofT0o`Oooo]Z00?ood/0oookJ_oo
nfX0D_oonfX01?oo203o08Koo`26ool0Q_l2oookJP?o0?nC0oo_o`03oookJP;oo`1j00Koo`19ool0
^ooo0;_oo`2koookJ_oo0=43oolI00;o0>_o0_l0oh`01?oonf[on@3oooT0oooi0?l3odSo00Cooo]Z
1?oi0?l2of/0o`;ooo]Z00?oE_l0ool0Pooo08<00_oo08<6oookJP?oH@3o0ooo9@03oc?o00;o4P3o
1?oo1002o`3oa0;oodT00ooonfX3ol3o00Goo`/01_oon005o`7o0003oookJ_lA0?oo4@3o00;o4@3o
2_oo0@07o`3o_QCooo]Z2?l0okh00ooonf[oo`40ool10002ool100;ooo]Z0olA0?l8oookJP;o0Ol0
7OoonfX01?ooB@3ooo]ZoookJ_l0ol@2oookJPCo000000Cooo]ZodKo0?oonf[o0?ln1_oonfX00ol0
Q?oooo]ZoookJP08oookJP07og?o0?oTo`3ooo]ZoookJ_oo04kooo]ZooT0o`09oookJP03oonJ0?oo
nf[ooo]Z00_ooo]Z00Coo`1SoookJ_o]0?oo0?mS1OoonfX00ooo097o0?m`oookJP0:oookJP05oj;o
0?l0obCooo]ZoookJ_l0o``01ooonfX01OooU03ooo]Zool0;?oonf[oo`0C00Oooo]Z00Co0?oLoook
J_l=0?oo3@3o2OoonfX00ooo08gooo]ZoookJP0DoookJP03ool;0?oonf[ooo]Z00Sooo]Z0_ooc@03
oookJP03o`3o1_oonf[ooo]Z00Cooo]Z00?o0?o=oookJ_oonfX02?oonfX00ooo003ooo]ZoookJP07
oookJP03ogL0oooonf[ooo]Z00[ooo]Z00Ko5?l0oookJ_oonf[oo`2foookJ_mY0?l8oookJP03oom;
0?oonf[ooo]Z02Sooo]Z000_oookJP04ool80?l0Q_oo08Koo`26o`?ooo]Z0_ooN@02onoo00KoogT0
00?oo`1joolX0?oo:0000ooo:003oolI00;o0>_o0ol0oh`3ooT0o`04onl0oom8o`3oB?l0odSo00Co
oo]Z00Go0?mgooT0oooi0?oon@3oof/0o`03oookJP;oE_l00ooo08<5oookJPCoH@3o1?oo9@03ooo9
0003oa80ool0/_ooo`@000Coo`@00_l0ol@8odCo00Goo`/01?oon003oomi00Ko0Ol000?ooo]Zoa40
oolA0?l01?lA0?l<ool100Oo0?nn3OooN@05ool100coogT03_oo:00FoookJP03oom90?ooN@3oogT0
00CoogT02?oo00000ooonf[oobP0oolX0006oolX00;ooo]Z1Ooo:0001ooTo`3oobP0oolX0?oo:03o
o`1>oookJ_oi0?l01ooonfX6ool000Wooo]Z2?oo:00;ool00003oookJ_oo003oo`0000Koo`0000?o
0?l<oookJ_oonfX01?oonfX01Ooo003ooo]ZoookJ_oo02coo`0C00GoobP00ooonfX00ol0omcooo]Z
oookJP05oolX00Gooo]Z00?oo`2=oookJ_oonfX05?oonfX00ooo2`3ooo]ZoookJP09oookJP04ooo=
0?oonf[oobP0oolX00Kooo]Z0_oo:0001?oonf[oobP0oolX0?oo:006oookJP03ool00?oonf[ooo]Z
00Oooo]Z00?oM`3ooookJ_oonfX02_oonfX01_lDo`3ooo]ZoookJ_oo0;Kooo]ZofT0o`Oooo]Z00?o
od/0oookJ_oonfX0E?oonfX00ooo203o08Koo`26o`03oookJP?o0?nC0_o_o`000omBo`3ooo]Zoook
JP03ool0NP06ool0BOoo0;_oo`2kool0^olk0?ooo`3A0ooo6@02o`3[o`;o0?n<00Cooo]ZooT0oooi
0?oon@3o1?m8o`03oookJP04o`3oMooi0?oon@3oooT0o`;oJ`3o0ooonfX01?mFo`3oo`23ool0Pooo
08<6oookJPCoH@3o0ooo9@03oc?o0003oa80ool0/_ooo`@000Coo`@00_l0ol@2oom900;ooo]Z1?o0
o`05ool;0003oookJ_oon03oooP000GoooP01Ol1o`000ooonf[o4@3ooa40o`05oa40o`coo`403ol0
okh3ool<00Koo`401_lA0?l9oookJP;o0Ol07ooonfX01?ooB@3ooo]ZoookJ_l0ol@2oookJPCo0000
00CoA_l0oookJ_l;0?oo0?ln1_oonfX00ol0Q?oooo]ZoookJP08oookJP05og?o0?oTo`3ooo]Zoook
J_oo04h00_oonfX00ooi0?oooo]ZoookJP06oookJP03oonJ0?oonf[ooo]Z00cooo]Z00?oo`1Soook
J_l0of<01_oonfX00ooo097o0?m`oookJP02oookJP03ool0W?oonf[ooo]Z00Gooo]Z00GoX_l0o`3o
9?oonf[ooo]Zo`3o3007oookJP05oonD0?oonf[oo`0/oookJ_oo01<01ooonfX01?l0omcooo]Zoook
J_l=0?l9oookJP03ool0SOoonf[ooo]Z01Cooo]Z00?oo`/0oookJ_oonfX02OoonfX01Oooc@3ooo]Z
oookJ_oonf[o0?l600Kooo]Z00?o0?o=oookJ_oonfX02?oonfX00ooo003ooo]ZoookJP07oookJP03
ogL0oooonf[ooo]Z00[ooo]Z00Ko5?l0oookJ_oonf[oo`2foookJ_mY0?l8oookJP03oom;0?oonf[o
oo]Z02Oooo]Z000boookJP03ool80?l0Q_oo08Ko00;ooo]Z0oooN@03onoo00GoogT01_oo:0001?lk
0?oooaT0oolI0?oo6@02o`3[o`?o0?n<0ooi0?l01?o_0?ooB?l0odSo0?m8o`04oookJP03o`3oMooi
0?oon@3o00;on@3o0ooonfX00omFo`3oolT0ool0P`03ool0P`Gooo]Z0omQ0?l00ol0TOooobD0oolU
0002oolU00?oolT000?o4P3oo`2bool0/_l01?oo1002o`3oa0SoA?l000?ooo]Zool;0?oo2`000ooo
2`000ooonf[oogT0oooh0006oooh00?o0Ol00ooo:009oa40o`?oo`d01Ooo0@0Poomi00koobP05Ooo
nfX00oooB@3ooo]Zoomi0005oomi00Ooo`000oooN@07oolX00?ooo]Z1?oo:0001OoTo`3oobP0oolX
0?oo:03oo`1>00;ooo]Z00?on@3ooookJ_oonfX01OoonfX5ool000Sooo]Z2Ooo:0000ooonf[oo`00
ool00009ool00003oookJ_oo003oo`0000Goo`0000?ooo]Zo`3o3?oonfX01?oonfX01_ooU03ooo]Z
oolX0?oo:03oo`0/ool04`GoobP00ooonfX00ol0omcoobP0oolX0005oolX00;oo`000ooonfX00ooo
08goo`00oookJP0DoookJP03ool;0?oonf[ooo]Z00Wooo]Z00Coold0oookJ_oonf[oobP01ooonfX5
oolX00Kooo]Z00?oo`00oookJ_oonfX01ooonfX00omg0?oooo]ZoookJP0:oookJP06oaCo0?oonf[o
oo]Zool0]_oonf[oJ@3o1ooonfX00oooB`3ooo]ZoookJP1EoookJP04ool80?l0Q_oo08Koo`26o`?o
oo]Z0_l0oi<3onoo0003oe;o0?oonf[ooo]Z00?oo`1j00Koo`19ool0^ooo0;_oo`2koc/0oooo0=43
oolI00;o0>_o0_l0oh`01Ooonf[on@3oooT0oooi0?ook`3o00?oB?l00ooonfX00ol0ogOon@3oooT0
o`02ooT0o`05of/0oooonf[ooo]ZoookJ_mFo`001?oo08<6oookJP?oH@3o1?oo9@03oc?o0003oa80
ool0/_oo0;;o00Coo`@00_l0ol@3oom90003oookJ_o0o`3o`?l000;o`?l000?ooo]Zool;0?oo2`00
0ooo2`03oookJPKoooP01_l1o`000ooonf[o4@3ooa40o`07oa40o`?oo`d04_oo0@06oa40o`cooo]Z
0ol1o`0PoookJP05oom90?oonf[ooo]ZoookJ_l0ol@00_oonfX4o`000004odKo0?oonf[o2`3oo`3o
?PKooo]Z00?o08CooookJ_oonfX02OoonfX01?oTo`3ooo]ZoookJ_oo04h2oookJP03ooT0oooonf[o
oo]Z00Oooo]Z00?ooiX0oookJ_oonfX03?oonfX00ooo06?ok@3oo`3oH`06oookJP05ool0TOl0og3o
oo]ZoookJ_oo09`02?oonfX01OnRo`3ooo]ZoookJ_oonf[o0?l<00Kooo]Z00Kooi@0oookJ_oonf[o
o`0/oookJ_oo01<7oookJP04o`3og?oonf[ooo]Zo`d0o`Gooo]Z00GoP@3ooookJ_oonf[ooo]Zool0
S@0FoookJP03ool;0?oonf[ooo]Z00Wooo]Z00Goold0oookJ_oonf[ooo]Zo`3o1P06oookJP03o`3o
cOoonf[ooo]Z00Sooo]Z00?oo`00oookJ_oonfX01ooonfX00omg0?oooo]ZoookJP0:oookJP06oaCo
0?oonf[ooo]Zool0]_oonf[oJ@3o2?oonfX00oooB`3ooo]ZoookJP0VoookJP00:_oonfX2ool0n@So
oo]Z00Goo`P0o`26ool0Q_oo08KooookJP04oomi00?okol00oooN@05oolX00;oo`2k00?ooo]ZoolX
0?oo6@000_oo6@02o`3[o`?o0?n<0ooi0?l01?o_0?ooB?l0odSo0?m8o`04oookJP;o0?mg0ooi0?l0
0om[0?oooo]ZoookJP03oeKo00?oo`231OoonfX4of40o`04o`2Aoooo9@3oobD0oolU00?oolT000Co
01cooa80oom4o`3oA?l01?oo1003o`3oa0?oA?l01Oo0o`000ooonf[oo`/0ool;0003ool;00Cooo]Z
1Ooon00:oolX00co4@3o3?ooN@05ool000_oogT01_oo:00MoookJP03oom90?oonf[oogT000GoogT0
1ooo0003oomi00OoobP01?oonfX4oolX0004onCo0?oo:03oobP0ool0CP;ooo]Z00?on@3ooookJ_oo
nfX01_oonfX5ool000Wooo]Z1ooo:002oookJP[oo`000ooonfX6ool00003oookJ_l0o`cooo]Z00Co
oo]Z00Kooi@0oookJ_oonf[oo`0/oolX0?oo01<4oolX00?ooo]Z2?oo:002oookJP05ool00?oonf[o
oo]ZoookJ_oo08d05_oonfX2oolX00[ooo]Z00Goold0oookJ_oonf[oobP0o`3o1P04oookJPKoobP0
1ooonfX00ooo003ooo]ZoookJP07oookJP03ogL0oooonf[ooo]Z00[ooo]Z0_lDo`001?oonf[oo`2f
oookJ_mY0?l7oookJP03oom;0?oonf[ooo]Z04cooo]Z0_oo0?T9oookJP03ool80?l0Q_oo08Ko00Co
oo]Z0_l0oi<3onoo0003oe;o0?oonf[ooo]Z00;oo`1j0_oo04T3ool0^`;oo`3A0_oo6@03o`3[o`;o
0?n<00Gooo]ZooT0oooi0?oon@3oonl0o`03odSo00?ooo]Z0_l0ogL3ooT0o`;oJ`3o0_oonfX2oeKo
00Coo`231OoonfX4of40o`?oobD00olco`001?l07?oo4P3oo`2bool0/_l4ool400?o0?o40oooB@06
ol3o00Goo`/01?oonfX7oooh00Go0Ol01?oonfXCoa40oa3ooo]Z1?l1o`0SoookJP05oom90?oonf[o
oo]ZoookJ_l0ol@00_oonfX4o`000004odKo0?oonf[o2`3oo`3o?PKooo]Z00?o08CooookJ_oonfX0
2OoonfX01omco`3oi?l0oookJ_oonf[oo`1>oookJ_oi0?l02_oonfX00oooVP3ooo]ZoookJP0;oook
JP03ool0Hooonf[o0?mS00Kooo]Z00?oo`2AoookJ_l0og000_oonfX00ooo09cooo]ZoookJP06oook
JP05oj;o0?oonf[ooo]ZoookJ_l0o``01_oonfX01_ooU03ooo]ZoookJ_oo02cooo]Zool04`Oooo]Z
0_l0om`00ooonf[o3@3ooookJP04oookJP05oh40oooonf[ooo]ZoookJ_oo08d05_oonfX2ool;00[o
oo]Z00Coold0oookJ_oonf[ooo]Z0_l0o`H5oookJP;o0?o=2OoonfX00ooo003ooo]ZoookJP07oook
JP;oM`3o2ooonfX2oaCo0004oookJ_oo0;Kooo]ZofT0o`Sooo]Z00?ood/0oookJ_oonfX09OoonfX0
02[ooo]Z0_l0om83ool0n@Sooo]Z00?oo`P0o`26ool0Q_l01_ooN@02onoo00;oogT000?ooo]ZoolX
0?oo:0000_oo07X01_oo04Woo`2kool0^ooo0;_o>`3ooolX00?ooaT00_l0jol3o`3oS0?on@3o00Co
k`3oodSo0?m8o`3oB?l01?oonfX2o`3oM`Con@3o0ooonfX2oeKo00Coo`230ooonfX2ooo900CoH@3o
1?oo9@000ooob@3o<ol0odCo0004odCo00Coo`@01?l0ol@2oom90003oookJ_o0o`3o`?l000Co`?l0
1ooo2`04oookJP03oooh0?oo:03oobP000ooobP01?oonfX3ool000OoogT01ooo0002oookJP?o0Ol0
1?ooN@0SoookJP03oom90?oonf[oogT000CoogT01Ooo:002ool000CoogT000?ooo]ZoolX0?oo:000
1?oo:005oookJP?oobP000Goi?l0oolX0?oo:03ooo]Zool0CP02oookJP03ooT0oooonf[ooo]Z00Ko
oo]Z1?oo000:oookJPOoobP00_oonfX:ool000?ooo]Z1Ooo0002oookJP03o`3o3?oonf[ooo]Z00?o
oo]Z00Kooi@0oookJ_oonf[oo`0/oolX0?oo01<4oolX0003oookJ_oo:03oobP000SoobP00_oonfX0
1Ooo003ooo]Zool00?oo003oo`2=01Oooo]Z00?oobP0oookJ_oonfX02?oonfX01Oooc@3ooo]Zoook
J_oonf[o0?l600;ooo]Z2?oo:007oookJP03ool00?oonf[ooo]Z00Oooo]Z00?oM`3ooookJ_oonfX0
2ooonfX01OlDo`3ooo]Zool0]_oo0;KoJ@3o00Oooo]Z00?ood/0oookJ_oonfX0BooonfX2o`3odP?o
o`3i2?oonfX01?oo203o08Koo`26ool0Q_l4oookJP;o0?nC0_o_o`000omBo`3ooo]ZoookJP03ool0
NP;oo`190ooo0;/01?oo0=7ooaT0oolI0?oo6@03o`3[o`;o0?n<00Gooo]ZooT0oooi0?oon@3oonl0
o`03odSo00?ooo]Z0_l0ogL4ooT0o`03of/0oooonf[ooo]Z00?oE_l01?oo08<5oookJP?oH@3o1?oo
9@03oc?o00;o01co00?o4P3oo`2boooo10000ooo1004o`3oa0?oodT000?ooo]Zol3o0?o0o`000oo0
o`07ool;00Cooo]Z1_oon004o`7o01oooo]Z0ol1o`0WoookJP04oom90?oonf[ooo]Zo`3oa0?ooo]Z
1?l000001?m6o`3ooo]Zo`/0ool0och6oookJP03o`24oooonf[ooo]Z00Wooo]Z00GoLol0onCo0?oo
nf[ooo]Zool0CP02oookJP03ooT0oooonf[ooo]Z00Oooo]Z00?ooiX0oookJ_oonfX03?oonfX00ooo
06?ok@3oo`3oH`06oookJP03ool0TOoonf[o0?m`00;ooo]Z00?oo`2LoookJ_oonfX01_oonfX01OnR
o`3ooo]ZoookJ_oonf[o0?l<00Kooo]Z00Kooi@0oookJ_oonf[oo`0/oookJ_oo01<8oookJP03o`3o
g?oonf[o3@3o00Gooo]Z00GoP@3ooookJ_oonf[ooo]Zool0S@0GoookJP03ool;0?oonf[ooo]Z00So
oo]Z00?oold0oookJ_oonfX00_oonfX00ol0o`Kooo]ZoookJP04oookJP03o`3ocOoonf[ooo]Z00Oo
oo]Z00?oo`00oookJ_oonfX02?oonfX00omg0?oooo]ZoookJP0:oookJP05oaCo0?oonf[oo`2fool0
]_mY0?l02?oonfX00oooB`3ooo]ZoookJP0ToookJP00:_oonfX2ool0[0?o0?oB0_oo0?T8oookJP04
ool80?l0Q_oo08Koo`26o`GoogT00oo_o`001?mBo`3oobP0oookJ_oonfX3ool0NP06ool0BOoo0;_o
o`2kool0^olk0?ooobP00ooo6@05oomi00?on@3o00Cok`3oodSo0?m8o`3oB?l01?oonfX3o`3oM`?o
n@3o0ooonfX3oeKo00Coo`2300?ooo]Zooo90?oob@000_oob@03of40o`03o`2Aoooo9@3oobD000;o
obD01om4o`03ool40003o`06ool0olCo0?o400?o0?o41OoonfX5ol3o0003oookJ_oo2`3oo`/000Co
o`/000?ooo]ZoolX0?oo:0003Ooo:003o`7o00CoobP01Ooo0002oomi00Ooo`000_l1o`0YoookJP03
oom90?oonf[oogT000GoogT02?oo:002oomi00;ooo]Z1Ooo:006oookJP?oobP000Goi?l0oolX0?oo
:03ooo]Zool0CP02oookJP03ooT0oooonf[ooo]Z00Oooo]Z0ooo000;oookJPKoobP01?oonfX8ool0
00Gooo]Z1?oo0002oookJP03o`3o3?oonf[ooo]Z00?ooo]Z00Kooi@0oookJ_oonf[oo`0/oolX0?oo
01<3oolX00?ooo]Z2?oo:003oookJPCoo`0000?oo`2=oookJ_oonfX05OoonfX00ooo:03ooo]Zoook
JP08oookJP05ooo=0?oonf[ooo]ZoookJ_l0o`H02_oo:007oookJP03ool00?oonf[ooo]Z00Oooo]Z
00?oM`3ooookJ_oonfX02ooonfX01?lDo`3ooo]ZoookJ_oo0;H2ofT0o`Kooo]Z00?ood/0oookJ_oo
nfX0B_oonfX2ool0[0?o0?oB0_oo0?T9oookJP03ool80?l0Q_oo08Ko00Gooo]Z00Go0?nConoo0?o_
o`3okol0oe;o0002oookJP?oo`1j0_oo04T3ool0^`04ool0dOoo6@3ooaT0oolI00;o0>_o0_l0oh`2
oookJP?on@3o00Cok`3oodSo0?m8o`3oB?l00ooonfX3o`3oM`?on@3o00?oJ`3ooookJ_oonfX00omF
o`001?oonf[oo`23ool0Pooo08<5oookJP?oH@3o00?o097ooolU0?oo9@000_oo9@03oc?o00;o01co
00?o4P3oo`2boooo10000_oo10000ol01_oo0?o4o`3oa003o`3oa003oom90?oonf[ooo]Z00?ooo]Z
1Oo0o`06ool;00Cooo]Z1Ooon00No`7o02Wooo]Z00GoodT0oookJ_oonf[ooo]Zo`3oa003oookJPCo
000000CoA_l0oookJ_l;0?oo0?ln1ooonfX00ol0Q?oooo]ZoookJP09oookJP07onCo0?oonf[ooo]Z
oookJ_oo04kooo]ZooT0o`0:oookJP03oonJ0?oonf[ooo]Z00cooo]Z00?oo`1Sond0ool0of<01_oo
nfX00ooo097o0?m`oookJP02oookJP03ool0W?oonf[ooo]Z00Gooo]Z00?oX_l0o`3o9?oonfX00_oo
nfX00ol0o`cooo]ZoookJP04oookJP03oonD0?oonf[oo`0/00;ooo]Z00?oo`0CoookJ_oonfX01_oo
nfX00ol0omcooo]Zo`d0o`05oookJP05oh40oooonf[ooo]ZoookJ_oo08d05ooonfX00ooo2`3ooo]Z
oookJP08oookJP;oold00ooonfX00ol0o`Kooo]ZoookJP04oookJP03o`3ocOoonf[ooo]Z00Oooo]Z
00?oo`00oookJ_oonfX02?oonfX00omg0?oooo]ZoookJP0:oookJP;o5?l000Cooo]Zool0]_mY0?oo
J@3o1ooonfX00oooB`3ooo]ZoookJP0SoookJP00:_oonfX2ool0QP?oo`2/0ol0om82ool0n@Sooo]Z
00Coo`P0o`26ool0Q_oo08Ko0oooN@000ooonf[oogT0onoo0002onoo00Cooo]Z0_oo07X2ool0B@?o
o`2k0_oo0=42oolI0003oiKo0?ooN@3oogT000?oogT00ooi0?l5oomi00?ooo]Z0ol0ogL3ooT0o`03
of/0oooonf[ooo]Z00?oE_l000Cooo]Zool0Pooo08?oo`230_oob@03oookJPCoH@3o00?o097ooolU
0?oo9@001_m4o`000olB0?oo0;;oool40003ool40003o`06ool0obco0?o400?o0?o42?m4o`03ol3o
00;ooo]Z1?oo2`000ooo:03oo`/0oolX000AoolX00goo`000ooonfX3ool002Gooo]Z00?oodT0oook
J_ooN@001?ooN@000ooonf[oobP0oolX0006oolX00;oogT00ooonfX4oolX00Oooo]Z0ooo:0001?oT
o`3oobP0oolX0?oo04h3oookJP03ooT0oooonf[ooo]Z00Oooo]Z0_oo000<oookJP03ool0Hooo:03o
obP000?oobP01?oonfX7ool000Cooo]Z1Ooo0003oookJP03o`3o3?oonf[ooo]Z00?ooo]Z00Gooi@0
oookJ_oonf[oo`0/oolX0002ool04`;oobP01?oonfX7oolX0003oookJ_oo003oo`0000Coo`0000?o
o`2=oookJ_oonfX05OoonfX01Ooo:03ooo]ZoookJ_oonf[oobP000Kooo]Z00Koold0oookJ_oonf[o
oo]Zo`3o1_oonfX9oolX00Oooo]Z00?oo`00oookJ_oonfX01ooonfX00omg0?oooo]ZoookJP0;oook
JP;o5?l000Cooo]Zool0]_oonf[oJ@3o1_oonfX00oooB`3ooo]ZoookJP19oookJP;oo`260ooo0:`3
o`3odP;oo`3i2?oonfX01?oo203o08Koo`26ool0Q_l4oookJP;o0?nC0oo_o`03oookJP;oo`1j0ooo
04T3ool0^`04ool0dOoo6@3ooaT0oiKo00;o0>_o0_l0oh`2oookJP?on@3o00Cok`3oodSo0?m8o`3o
B?l01?oonfX2o`3oM`?on@3o00?oJ`3ooookJ_oonfX00omFo`000ooonf[oo`23ool0P`02ool0P`Co
oo]Z1?mQ0?l00ol0TOooobD0oolU0002oolU00?o<ol00_l07?l00olB0?ooo`@0ool40002ool40003
o`06ool0obco0?o400?o0?o400?oodT0oookJ_oonfX01?oonfX4ol3o00;ooo]Z1_oo2`03oookJPSo
ooP0?ooonfX01OooB@3ooo]ZoookJ_oonf[o0?o400?ooo]Z1?l000001?m6o`3ooo]Zo`/0ool0och7
oookJP03o`24oooonf[ooo]Z00Wooo]Z00Goi?l0oookJ_oonf[ooo]Zool0CP02oookJP03ooT0oooo
nf[ooo]Z00Oooo]Z00?ooiX0oookJ_oonfX03?oonfX00ooo06?ooo]Zo`3oH`07oookJP03ool0TOl0
og3ooo]Z00;ooo]Z00?oo`2LoookJ_oonfX01OoonfX00onRo`3o0?lToookJP02oookJP03o`3o3?oo
nf[ooo]Z00Cooo]Z00?ooi@0oookJ_oo02`00_oonfX00ooo01?ooo]ZoookJP06oookJP03o`3og?oo
nf[o3@3o00Gooo]Z00GoP@3ooookJ_oonf[ooo]Zool0S@0GoookJP03ool;0?oonf[ooo]Z00Wooo]Z
00Goold0oookJ_oonf[ooo]Zo`3o1P06oookJP03o`3ocOoonf[ooo]Z00Oooo]Z00?oo`00oookJ_oo
nfX02?oonfX00omg0?oooo]ZoookJP0;oookJP05oaCo0?oonf[oo`2foookJ_mY0?l01ooonfX00ooo
B`3ooo]ZoookJP0RoookJP00:_oonfX2ool=00?oo`260_oo0:`00ooonf[o0?oBo`3odP02ool0n@So
oo]Z00GoogT0ool80?l0Q_oo08Kooomi0003oookJP;oogT00_o_o`001?oom`3ooo]ZoookJ_oonfX3
ool0NP;oo`190_oo0;/00olk0?ooo`3AoolI0002oolI0003oiKo0?ooN@3oogT000?oogT00ooi0?l2
oomi00;oB?l01?oonfX3o`3oM`?on@3o00?oJ`3ooookJ_oonfX00omFo`001?oonf[oo`23ool0Pooo
08<6oookJPCoH@3o00?oolT0odCo0?m4o`000_m4o`04ooo90003oa80ool0/_ooo`@0013oU?l01?o0
o`04oookJP;oo`/04?oo:00Cool002Cooo]Z00?oodT0oookJ_oonfX01?ooN@02oookJPOoobP00ooo
N@02oookJP;oo`000ooo:008oookJP;oobP000Goi?l0oolX0?oo:03ooo]Zool0CP02oookJP04ooT0
oooonf[ooo]ZoookJP;oo`001OoonfX2ool000cooo]Z00?oo`1SoolX0?oo:0000_oo:004oookJPSo
o`000_oonfX7ool000?ooo]Z00?o0?l<oookJ_oonfX00ooonfX02?ooU03ooo]ZoookJ_oo02cooo]Z
oolX0?oo01?oobP01OoonfX7oolX00Ooo`000_oo:004oookJP03oolX0?oonf[ooo]Z00oooo]Z00Co
obP0oookJ_oo:03oobP01ooonfX01?ooc@3ooo]ZoookJ_oonfX2o`3o1P03oookJ_oo:03oobP000Go
obP02?oonfX2ool000Sooo]Z00?oM`3ooookJ_oonfX03?oonfX01OlDo`3ooo]Zool0]_oonf[oJ@3o
057ooo]Z0_oo3@03ool0QP;oo`2/00?ooo]Zo`3od_l0om800ooo0?T8oookJP03ool80?l0Q_oo08Ko
00Gooo]Z0_l0oi<2onoo0003oe;o0?oonf[ooo]Z00?oo`1j0ooo04T2ool0^`05oc/0oooo6@3ooaT0
oolI0?nFo`000_l0jol01?l0ohcoo`d0oookJ_oonfX3ooT0o`04onl0oom8o`3oB?l0odSo00Cooo]Z
0_l0ogL3ooT0o`03of/0oooonf[ooo]Z00?oE_l00_oonfX3ool0P`Gooo]Z1?mQ0?l00ol0TOooobD0
oolU0002oolU00?o<ol000?o01cooa80ool0/_l01?oo10000ol01_oo0?l/o`3oa004o`3oa0Kooo]Z
1?o0o`04oookJPSoo`/00ooonfX>oooh033ooo]Z00?oodT0oookJ_oonfX00_oonfX01?l0olCooo]Z
oookJ_oonfX4o`000004odKo0?oonf[o2`3oo`3o?POooo]Z00?o08CooookJ_oonfX02OoonfX01Omc
o`3oi?l0oookJ_oonf[oo`1>00;ooo]Z00?on@3ooookJ_oonfX02?oonfX00oooVP3ooo]ZoookJP0<
oookJP03ool0Hooonf[o0?mS00Kooo]Z00?oo`2AoookJ_l0og000_oonfX00ooo09cooo]ZoookJP03
oookJP05ok80oooonf[ooo]Zoj;o0?l0ob@00ooonfX00ol0o`cooo]ZoookJP04oookJP03oonD0?oo
nf[oo`0/00;ooo]Z00?oo`0CoookJ_oonfX01_oonfX00ol0omcooo]Zo`d0o`05oookJP04oh40oooo
nf[ooo]ZoookJP;oo`2=5_oonfX00ooo2`3ooo]ZoookJP09oookJP05ooo=0?oonf[ooo]ZoookJ_l0
o`H01_oonfX00ol0olgooo]ZoookJP07oookJP;oo`002OoonfX00omg0?oooo]ZoookJP0;oookJP04
oaCo0?oonf[oo`2foookJP;oJ@3o:_oonfX002[ooo]Z0_l0om<3ool=00;oo`260_oo0:`01Ooonf[o
0?oBo`3od_l0om;oo`3i00Sooo]Z00?oogT0ool80?l0Q_l00_l0Q_l4oookJP05oomi0?o_o`3okol0
onoo0?mBo`000ooonfX2ool0NP;oo`190ooo0;/01?lk0?ooo`3AoolI0?oo6@02oiKo00GoogT00ooi
0?l00oo_0?ooB?l0odSo0005oookJP?o0?mg0ooi0?l00om[0?oooo]ZoookJP03oeKo0004oookJ_oo
08?oo`23ool0P`Oooo]Z0omQ0?l2odCo00?oobD01?oob@000olB0?oo0;;ooiCo000=oiCo00?oogT0
00?ooo]Zol3o0?o0o`000oo0o`02oookJPooobP04ooo0009oookJP?oo`005ooonfX00oooB@3ooo]Z
oookJP05oomi00;ooo]Z1ooo:003oomi00Coo`000ooo:009oookJP;oobP000Coi?l0oolX0?oonf[o
o`1>0_oonfX00ooi0?oooo]ZoookJP03ool000Kooo]Z00?oo`00oookJ_oonfX02ooonfX00ooo06?o
obP0oolX0002oolX00;ooo]Z2Ooo00000ooonf[oo`00ool00006ool00005o`3o9?oonf[ooo]Zoook
J_l0o``01OoonfX00oooU03ooo]ZoookJP02ool0;003oolX0?oo01?oobP000Kooo]Z1Ooo:007ool0
00;ooo]Z00GoobP0oookJ_oonf[ooo]ZoolX000BoookJPCoobP01ooonfX2ooo=00?ooo]Z00?o0?l6
oookJ_oonfX01_oo:009oookJP03ool00?oonf[ooo]Z00Kooo]Z00?oM`3ooookJ_oonfX03?oonfX0
1?lDo`3ooo]Zool0]_oonfX2ofT0odoooo]Z0_l0om<3ool=00;oo`260_oo0:`01?oonf[o0?oBo`3o
d_l0om82ool0n@Sooo]Z00Coo`P0o`26ool0Q_oo08Ko1OoonfX01?l0oi?okol0onoo0?o_o`03oook
JP;oo`1j00?ooo]Zool0BOoo04T00ooo0;/01Olk0?oooaT0oolI0?oo0=7oU_l000;o0>_o00Co0?n<
ool=0?oonf[ooo]Z0_oi0?l2onl0o`;oB?l01OoonfX2o`3oM`?on@3o00?oJ`3ooookJ_oonfX00omF
o`02oookJP?oo`231_oonfX4of40o`04o`2Aoooo9@3oobD0oolU00Co<ol000?o01cooa80ool0/_l0
1Ooo1002o`3o;0Co0?o41_oonfX5ol3o00Oooo]Z2_oo2`0foookJP03oom90?oonf[ooo]Z00;ooo]Z
00?o0?o4oookJ_oonfX00_oonfX4o`000004odKo0?oonf[o2`3oo`3o?POooo]Z00?o08CooookJ_oo
nfX02_oonfX01ooTo`3ooo]ZoookJ_oonf[oo`1>oookJ_oi0?l02ooonfX00oooVP3ooo]ZoookJP0<
oookJP03ool0Hooonf[o0?mS00Kooo]Z00?oo`2AoookJ_l0okh00_oonfX00ooo09cooo]ZoookJP02
oookJP06ok80oooonf[ooo]ZoookJ_nRo`3o0?lT0ooonfX00ol0o`cooo]ZoookJP04oookJP06oonD
0?oonf[oo`0/ool0;?oonf[oo`0C2?oonfX00ol0omcooo]Zo`d0o`05oookJP03oh40oooonf[ooo]Z
00;ooo]Z00?oo`2=oookJ_oonfX05?oonfX2ool;00[ooo]Z00Coold0oookJ_oonf[ooo]Z0_l0o`H5
oookJP03o`3ocOoonf[ooo]Z00Sooo]Z00?oo`00oookJ_oonfX01ooonfX00omg0?oooo]ZoookJP0;
oookJP;o5?l000Coo`2foookJ_oonf[oJ@3o:OoonfX002[ooo]Z0_oKo`03o`3od`;oo`d00_oo08H3
ool0[005oookJ_l0om;o0?oBo`3od_oo0?T01_oonfX01?ooN@3ooo]ZoookJ_oo2002o`26o`Gooo]Z
00CoogT0onoo0?o_o`3okol00ooonfX2ool0NP03oookJ_oo04Woo`1900?oo`2k00CoogT0oolI0?oo
6@3ooaT00_nFo`03oomi0003ool=0?oonf[on@3o00;on@3o0om8o`05oookJP?o0?mg0ooi0?l00om[
0?oooo]ZoookJP02oeKo00;ooo]Z0ooo08<5oookJP;oolT01?mQ0?l01?oob@3oobD0oolU0?oo9@03
ooo900;oA?l03?nDo`0?onGo00[oobP000Cooo]Zool;0?oo2`3oo`/04?oo0005oookJPOoo`005ooo
nfX00oooB@3ooo]ZoookJP04oomi00?ooo]Z1ooo:003oomi00Coo`000ooo:00:oookJP05oolX0?oT
o`3oobP0oookJ_oo04h00ooonfX6ool000Gooo]Z00CooiX0oookJ_oonf[oobP02ooonfX01?oo06?o
oo]ZoolX0?oo:004oookJQ7oo`0000Co0?lToookJ_oonf[ooo]Z0_l0o``4oookJP08oonD0?oonf[o
oo]ZoookJ_oo02coobP0ool04ooo:007oookJPCoobP01ooo0002oookJP03oolX0?oonf[oobP000;o
obP04?oonfX6oolX00Sooo]Z00Goold0oookJ_oonf[ooo]Zo`3o1P03oookJPGoobP02OoonfX00ooo
003ooo]ZoookJP06oookJP;oM`3o3OoonfX2oaCo00;oo`2f00?ooo]ZofT0oooonfX0COoonfX2om_o
00?o0?oC0_oo3@02ool0QP?oo`2/00Cooo]Zo`3od_l0om;o0?oB0_oo0?T8oookJP03ool80?l0Q_oo
08Ko00Kooo]Z00Co0?nConoo0?o_o`3okol00_oonfX2ool0NP;ooo]Z0_oo04T2ool0^`06oc/0oooo
6@3ooaT0oolI0?oo0=7oU_l00_l0jol2ool=0005oookJ_oi0?oon@3oooT0ooo_0?l00om8o`05oook
JP;o0?mg0ooi0?l00om[0?oooo]ZoookJP03oeKo00;ooo]Z0ooo08<7oookJPCoH@3o0ooo9@001_l0
ob_o<ol0oc?o0?lco`3o01cooa80o`;o0;;o00?o00Koool40?oo10000ooo10000ol0obco0?o4o`3o
a002o`3oa0;oodT01OoonfX5ol3o00cooo]Z3?oo2`0ZoookJP03oom90?oonf[ooo]Z00;ooo]Z00?o
0?o4oookJ_oonfX00_oonfX4o`000004odKo0?oonf[o2`3oo`3o?POooo]Z00?o08CooookJ_oonfX0
2_oonfX01OoTo`3ooo]ZoookJ_oonf[oo`1>00;ooo]Z00?on@3ooookJ_oonfX02?oonfX00oooVP3o
oo]ZoookJP0=oookJP03ool0Hol0of?ooo]Z00Kooo]Z00?oo`2AoookJ_l0okh00_oonfX00ooo09co
oo]ZoookJP02oookJP04ok80oooonf[ooo]ZoookJP;oX_l00ooonfX2o`3o30Gooo]Z00Kooi@0oook
J_oonf[oo`0/oookJ_oo01<8oookJP03o`3og?oonf[o3@3o00Gooo]Z00?oP@3ooookJ_oonfX00_oo
nfX00ooo08gooo]ZoookJP02oomk01?ooo]Z00?oo`/0oookJ_oonfX02?oonfX00oooc@3ooo]Zoook
JP02oookJP03o`3o1_oonf[ooo]Z00?ooo]Z00?o0?o=oookJ_oonfX02?oonfX00ooo003ooo]Zoook
JP07oookJP;oM`3o3OoonfX01OlDo`3oo`2fool0]_oonf[oJ@3o02Sooo]Z000ZoookJP;ood800_oK
o`001_oonf[o0?oCo`3odol0om?oo`d0oookJP;oo`260_oo0:`2oookJP;o0?oB00?oo`3ioookJ_oo
nfX01ooonfX01?oo203o08Koo`26ool0Q_l4oookJP;o0?nC1Ooo:003ool0NP03oookJ_oo04Woo`19
00;oo`2k0_ooN@03oolI00;oU_l00_ooN@000ooo3@3ooo]ZoookJP02ooT0o`03onl0oom8o`3oB?l0
00Kooo]Z0ol0ogL2ooT0o`;oJ`3o00Cooo]ZoeKo0?mFo`3oE_l00_oonfX2ool0P`Gooo]Z1?oob@03
of40o`04ooo90?oo9@3oobD0oolU00Co<ol02_nDo`000ol0obcoiOl0onGo000<onGo0003ol3o0?oo
:03o`?l000OoobP01?oonfX3oolX00goo`000_oonfX:ool001Gooo]Z0_ooN@03oookJP?oogT01?oo
nfX6oolX00;oogT01_oo00000ooonf[oobP0oolX000:oookJP03oolX0?oTo`3oobP000;ooo]Z00?o
o`1>oookJ_oo00001_oo0006oookJP03oonJ0?oo:03oobP000cooo]Z00?oo`1Sond0oooo:0001Ooo
nfX2ool00003ool0TOoo003oo`0000;oo`0000?ooo]Zool00?oo00001Ooo00000ooonf[oX_l0o`3o
9004oookJP03o`3o3?oonf[ooo]Z00;ooo]Z00Oooi@0oookJ_oonf[ooo]Zool0;?oonf[oo`0C00So
oo]Z00Co0?oLoolX0?oo:03ooo]Z1ooo0002oookJPGoobP00ooonfX00ooo003ooo]ZoookJP08oook
JPSoobP02?oonfX01Oooc@3ooo]ZoookJ_oonf[o0?l600Cooo]Z0ooo:00:oookJP;oo`002?oonfX0
0omg0?oooo]ZoookJP0<oookJP05oaCo0?oonf[oo`2foookJ_mY0?l0COoonfX2oom200;ofol000Ko
oo]Zo`3odol0om?o0?oCool=0?oonfX2ool0QP;oo`2/0_oonfX2o`3odP;oo`3i2?oonfX01?oo203o
08Koo`26ool0Q_l5oookJP;o0?nC0_o_o`02oookJP?oo`1j0_oonfX01Ooo04Woo`2kool0^ooo0;_o
>`3o00?ooaT000Goo`3AoiKo0?l0jooo0>_oool=0002oookJP;on@3o0_o_0?l2odSo00Kooo]Z0_l0
ogL3ooT0o`03of/0oooonf[ooo]Z00?oE_l00_oonfX2ool0P`Wooo]Z0omQ0?l3oolU0007o`3o:olc
o`3o<ol0oc?o0?oo07Co01cooa80o`02o`2bo`;o00Ko1?oo10000ol0obco0?o4o`3oa002o`3oa0?o
odT01OoonfX8ol3o03Wooo]Z00?oodT0oookJ_oonfX00_oonfX00ol0olCooo]ZoookJP03oookJP?o
000000Goo`@0odKo0?oonf[o2`3oo`3o?P08oookJP03o`24oooonf[ooo]Z00[ooo]Z00Ooi?l0oook
J_oonf[ooo]Zool0C_oonf[on@3o00_ooo]Z00?ooiX0oookJ_oonfX03OoonfX00ooo06?o0?mSoook
JP06oookJP03ool0TOl0og3o0?nn00;ooo]Z00?oo`2LoookJ_oonfX00_oonfX00onb0?oooo]Zoook
JP02oookJP03oj;o0?oonf[ooo]Z00;ooo]Z00?o0?l<oookJ_oonfX00ooonfX01_ooU03ooo]Zoook
J_oo02cooo]Zool04`Sooo]Z00?o0?oLoookJ_l=0?l01OoonfX00on10?oooo]ZoookJP02oookJP05
ool0SOoonf[ooo]ZoookJ_ooN`004ooonfX00ooo2`3ooo]ZoookJP08oookJP03ooo=0?oonf[ooo]Z
00;ooo]Z00?o0?l6oookJ_oonfX00ooonfX00ol0olgooo]ZoookJP08oookJP;oo`002OoonfX00omg
0?oooo]ZoookJP0;oookJP;o5?l000Coo`2foookJ_mY0?ooJ@3o9_oonfX002cooo]Z0_oo@P03om_o
0003oookJ_l0om?o0?oC00;oo`d00_oo08H2ool0[0;ooo]Z0_l0om82ool0n@Sooo]Z0_oo2002o`26
o`Gooo]Z00?o0?nCoolX0?oo:0002?oo:0001?oo04Woo`2kool0^ooo0;/2oomi00;ooaT000?oo`3A
oiKo0?ooN@000_ooN@02oookJP?on@3o0om8o`06oookJP;o0?mg0ooi0?l2of/0o`05oookJ_mFo`3o
E_l0oeKo0?oonfX00ooo08<4oookJPGoolT00omQ0?l01Ooob@3oobD0oolU0?oo9@3o0?l[00;o<ol0
1onDo`000ol01_ooo`@0ool40002ool400_oiOl01_oonfX?oolX01Goo`005?oonfX3oomi00?ooo]Z
0_ooN@05oookJPKoobP02?oo00000ooonf[oobP0oolX000;oookJP03oolX0?oTo`3oobP000;ooo]Z
00?oo`1>ool00?ooN@001_oo0005oookJPCoobP02ooonfX01?oo06?ooo]Zond0oooo:006oookJP03
ool00?oo097oo`0000?oo`0000?oo`2Lool00?oo00001Ooo00000ooonf[oX_l0o`3o9004oookJP03
o`3o3?oonf[ooo]Z00;ooo]Z00Sooi@0oookJ_oonf[ooo]Zool0;?oonf[oo`0Co`1jo`Oooo]Z00?o
0?oLoolX0?oo:0000_oonfX5ool00003oookJ_oo:03oobP000CoobP000Coo`00oookJ_oonf[oo`00
2OoonfX9oolX00Wooo]Z00Coold0oookJ_oonf[ooo]Z0_l0o`H4oookJP;oobP02ooonfX00ooo003o
oo]ZoookJP06oookJP03ogL0oooonf[ooo]Z00cooo]Z00Go5?l0oookJ_oo0;Kooo]ZofT0o`1>oook
JP;ood800ooKo`000ooonf[o0?oCo`3od`02ool=0004oookJ_oo08Koo`2/ool0[0;ooo]Z0_l0om82
ool0n@Sooo]Z0_oo2002o`26o`Kooo]Z00?o0?nConoo0?o_o`000ooonfX2ool0NP;ooo]Z0_oo04T2
ool0^`04oookJ_lk0?oooaT0oolI00;oo`3A0ol0jol2oookJP?on@3o00Cok`3oodSo0?m8o`3oB?l0
1_oonfX2o`3oM`?on@3o00?oJ`3ooookJ_oonfX00omFo`001?oonf[oo`23ool0Pooo08<9oookJP?o
H@3o0ooo9@001?l0ob_o<ol0oc?o0?lco`02ool0M003oookJ_l07?oo4P3o00;o0;;o00?o00Koool4
0?oo10000_oo10000ol0obco0?o4o`3oa002o`3oa0;oodT02_oonfX9ol3o02oooo]Z00?oodT0oook
J_oonfX00ooonfX00ol0olCooo]ZoookJP03oookJP?o000000Goo`@0oookJ_oonf[o2`3oo`3o?P08
oookJP03o`24oooonf[ooo]Z00[ooo]Z00Goi?l0oookJ_oonf[ooo]Zool0CP02oookJP03ooT0oooo
nf[ooo]Z00Wooo]Z00?ooiX0oookJ_oonfX03?oonfX00ooo06?ooo]Zo`3oH`07oookJP03ool0TOl0
og3o0?nn00;ooo]Z00?oo`2LoookJ_oonfX00_oonfX00onb0?oooo]ZoookJP02oookJP03oj;o0?oo
nf[ooo]Z00;ooo]Z00?o0?l<oookJ_oonfX00ooonfX01oooU03ooo]ZoookJ_oo02cooo]Zool04ol0
N_l01ooonfX00ol0omcooo]Zo`d0o`05oookJP03oh40oooonf[ooo]Z00;ooo]Z00?oo`2=oookJ_oo
nfX00_ooE`0CoookJP03ool;0?oonf[ooo]Z00Sooo]Z0_ooc@03oookJP03o`3o1_oonf[ooo]Z00?o
oo]Z00?o0?o=oookJ_oonfX02OoonfX00ooo003ooo]ZoookJP07oookJP03ogL0oooonf[ooo]Z00co
oo]Z00Go5?l0ool0]_oonf[ooo]ZofT0o`0UoookJP00:_oonfX2ool0I@;ooo]Z0_oo@P001?oonf[o
fol0om_o0?oonfX2o`3od`;oo`d00_oo08H3ool0[003oookJ_l0om;o0?oB00;oo`3i2OoonfX01?oo
203o08Koo`26ool0Q_l4oookJPgoobP00_oo0;/00oooN@3o>`3ooolI0002oolI00;oo`0000?oogT0
o`3[oooo3@000_oonfX3ooT0o`?oB?l01_oonfX2o`3oM`?on@3o00?oJ`3ooookJ_oonfX01?ooN@03
ool0P`;ooo]Z1ooob@03of40o`06o`2Aoooo9@3oobD0oolU0?m4o`3o<ol01OnDo`001OooN@3o4P3o
o`2bool0/_oo00Ko00Coo`@01ooUo`02ooo900Oooo]Z00?oobP0ooo90?oob@001Ooob@07oolX01;o
o`004_oonfX5oomi00;ooo]Z0_ooN@06oookJPGoobP02_oo00000ooonf[oobP0oookJP0;oookJP05
onCo0?oo:03oogT0oomi0?oo04h00_ooN@06ool000Cooo]Z1_oo:00;oookJP03ool0Hooonf[o0?mS
00Oooo]Z00?oo`00ool0TOoo00000_oo00000ooonf[oo`2LoookJP06ool00003oookJ_nRo`3o0?lT
00Cooo]Z00?o0?l<oookJ_oonfX00_oonfX02?ooU03ooo]ZoookJ_oonf[oo`0/oolX0?oo01?o07[o
1ooonfX01?l0omcooo]ZoolX0?l=0?l2oookJP?oo`002?oo:004ool00003oookJ_oo003ooo]Z00Oo
oo]Z2?oo:009oookJP03ooo=0?oonf[ooo]Z00;ooo]Z00?o0?l6oookJ_oonfX00ooonfX00ooo:03o
0?o=oookJP09oookJP03ool00?oonf[ooo]Z00Kooo]Z0_mg0?l=oookJP;o5?l000?oo`2foookJ_mY
0?l0BooonfX2ool0I@;ooo]Z0ooo@P02om_o0003oookJ_l0om?o0?oC00;oo`d000?ooo]Zool0Q_oo
0:`00_oo0:`00ooonf[o0?oBo`3odP03ool0n@Sooo]Z00Coo`P0o`26ool0Q_oo08Ko1OoonfX01?l0
oi?okol0onoo0?o_o`02oookJP;oo`1j0ooonfX01Ooo04Woo`2kool0^ooo0;_ooo]Z00?ooaT000Go
o`3AoiKo0?l0jooo0>_oool=0002oookJP?on@3o00Cok`3oodSo0?m8o`3oB?l01OoonfX3o`3oM`?o
n@3o0ooonfX3oeKo0004oookJ_oo08?oo`23ool0P`Wooo]Z0omQ0?l3oolU0003o`3o:olco`3o<ol0
00;o<ol00_oo07@00ooonf[o01cooa80o`02o`2bo`06o`06oooo103oo`@0ool40?l01_oo0?l/1Ol0
ol@@oookJQ;o`?l07OoonfX00oooB@3ooo]ZoookJP02oookJP03o`3oa?oonf[ooo]Z00Cooo]Z0ol0
00001Ooo103ooo]ZoookJ_l;0?oo0?ln00Sooo]Z00?o08CooookJ_oonfX02_oonfX00ooTo`3ooo]Z
oookJP02oookJP03ool0C_oonf[on@3o00_ooo]Z00?ooiX0oookJ_oonfX03OoonfX00ooo06?o0?mS
ond0o`07oookJP03ool0TOl0og3o0?nn00;ooo]Z00?oo`2LoookJ_oonfX00_oonfX00onb0?oooo]Z
oookJP02oookJP03oj;o0?oonf[ooo]Z00;ooo]Z00?o0?l<oookJ_oonfX00ooonfX01oooU03ooo]Z
oookJ_oo02cooo]Zool04ol0N_l01ooonfX01?l0omcooo]Zo`d0ool=0?l4oookJP03oh40oooonf[o
oo]Z00;ooo]Z00Goo`2=oookJ_oonf[ooo]ZoomG000CoookJP03ool;0?oonf[ooo]Z00Wooo]Z00Go
old0oookJ_oonf[ooo]Zo`3o1P05oookJP;o0?o=2_oonfX00ooo003ooo]ZoookJP07oookJP;oM`3o
3OoonfX01OlDo`3oo`2foookJ_oonf[oJ@3o02Cooo]Z000ZoookJP;o0?m10_oo06D2oookJP;ood80
00Cooo]Zom_o0?oKo`3ooo]Z0_l0om<3ool=00;oo`260_oo0:`00ooonf[o0?oBo`3odP02ool0n@Wo
oo]Z0_oo2002o`26o`?ooo]Z3?oo:0000ooo04WoogT0ool0^`02ool0^`04oookJ_lk0?oooaT0oolI
00Goo`000ooonfX2ooT0o`03onl0oom8o`3oB?l000Oooo]Z0_l0ogL2ooT0o`;oJ`3o00?ooo]Zoomi
0?ooN@000oooN@02ool0P`;oogT01Ooob@03oookJP?oH@3o00Go097ooolU0?oo9@3oobD0o`3o:`03
oiCo0003oc?o0?ooN@3oogT000;oolT000Co4P3oo`2bool0/_ooiOl01Ooo10000ooUo`3o0?o4o`3o
a003o`3oa0goolT02Ooo:002oookJPkoo`004?oonfX8oomi0003oookJ_ooN@3ooo]Z00Kooo]Z00?o
0000oolX0?oo:0000_oo:007ool000;oobP000?oo`00oookJ_l0Q?l03OoonfX7oomi00Koo`000_oo
nfX7oolX00cooo]Z00?oo`1SoookJ_l0of<02?oonfX01_oo097oo`00ool00?oo003ooo]Zool0W0;o
oo]Z1?oo0002oookJP03oj;o0?l0obCooo]Z00?ooo]Z00?o0?l<oookJ_oonfX00_oonfX2oolX0006
oookJ_oo:03oobP0oolX0?oo01?o07[o1ooonfX01?l0omcooo]ZoookJ_l=0?l2oookJP03ool00?oo
:03oobP000SoobP01Ooo000:oookJPOoobP02OoonfX00oooc@3ooo]ZoookJP02oookJP03o`3o1_oo
nf[ooo]Z00Cooo]Z00?o0?o=oookJ_oonfX02?oonfX2ool000Sooo]Z00?oM`3ooookJ_oonfX03?oo
nfX00olDo`3oo`2foookJP1;oookJP;o0?m10_oo06D3oookJP;ood800_oKo`000ooonf[o0?oCo`3o
d`03ool=0005oookJ_oo08Koo`2/ool0[?oonfX00ol0om82ool0n@Sooo]Z0_oo2002o`26o`Gooo]Z
0_l0oi<2onoo00;ooo]Z0ooo07X2oookJP;oo`190_oo0;/2oookJP;ooaT000Goo`3AoiKo0?l0jooo
0>_oool=0003oookJP;on@3o0_o_0?l2odSo00Kooo]Z0ol0ogL2ooT0o`04of/0oooonf[ooo]Zoook
JP?oE_l000?ooo]Zool0Pooo08<02_oonfX2of40o`04o`2Aoooo9@3oobD0oolU00;o0?l[0olco`03
ool0M003oookJ_l07?oo4P3o00;o0;;o1Ooo10000ol01_oooo]Zo`3oa004o`3oa0;oodT0=ooonfX0
0oooB@3ooo]ZoookJP02oookJP03o`3oa?oonf[ooo]Z00Gooo]Z0ol000001Ooo103ooo]ZoookJ_l;
0?oo0?ln00Sooo]Z00?o08CooookJ_oonfX02ooonfX01OoTo`3ooo]ZoookJ_oonf[oo`1>00;ooo]Z
00?on@3ooookJ_oonfX02OoonfX00oooVP3ooo]ZoookJP0=oookJP03ool0Hol0of?ok@3o00Oooo]Z
00?oo`2Ao`3oL?l0okh00_oonfX00ooo09cooo]ZoookJP02oookJP03ok80oooonf[ooo]Z00;ooo]Z
00?oX_l0oookJ_oonfX00_oonfX00ol0o`cooo]ZoookJP03oookJP;ooi@000Gooo]Zool0;?oonf[o
o`0Co`1jo`07oookJP04o`3og?oonf[ooo]Zo`d0o`Cooo]Z00?oP@3ooookJ_oonfX00_oonfX2ool0
S@;ooo]Z00?ooeL0oomk0?oonfX04OoonfX2ool;00[ooo]Z00Goold0oookJ_oonf[ooo]Zo`3o1P06
oookJP03o`3ocOoonf[ooo]Z00Sooo]Z0_oo0009oookJP03ogL0oooonf[ooo]Z00_ooo]Z0_lDo`0V
oookJP00:_oonfX2o`00O`?o0?m100?oo`1UoookJ_oonfX00_oo@P001?l007oofol0om_o0?oonfX3
o`3od`;oo`d00_oo08H2ool0[003oookJ_l0om;o0?oB00?oo`3i2?oonfX2ool800;o08Ko0ooonfX9
oolX00;oo`1j0_oonfX2ool0B@?oo`2k00?oo`00oolI0?oo6@002?oo0003ooT0o`?oB?l01Ol007l2
oookJP05o`3oMooi0?oon@3oooT0oom[0?l01_ooN@03ool0P`03oomi0?oob@3oolT000;oogT01Ooo
nfX3of40o`06o`2Aoooo9@3oobD0oolU0?nDo`3o0?l[0olco`000ooo07CoolT0ooo90002ooo90003
oa80oooUo`3oiOl000;oiOl01Ooo10000ooob@3o0?o4o`3oa002o`3oa0WoolT00_oonfX7oolX00Oo
oo]Z2Ooo000?oookJPWoogT000?o0?o4oookJ_oonfX01_oonfX00ol0003oobP0oolX0002oolX00Ko
o`000ooo:0000ooo003ooo]Zo`24o`0<oookJPWoogT01Ooo00000ooonf[oobP0oolX0007oolX00co
oo]Z00Coo`1SoookJ_l0of?ooo]Z1Ol007l2oookJP06ool0TOoo003oo`00oookJ_oo:03oo`2L0_oo
nfX4ool000;ooo]Z00?oX_l0o`3o9?oonfX00ooonfX00ol0o`cooo]ZoookJP03oookJPGoobP000?o
o`0Co`1joooonfX01_oonfX01?l0omcooo]ZoookJ_l=0?l3oookJP03ool00?oo:03oobP000OoobP0
1Ooo0002o`00O`Gooo]Z1?l007l6oolX00Wooo]Z00?oold0oookJ_oonfX00_oonfX00ol0o`Kooo]Z
oookJP04oookJP03o`3ocOoonf[ooo]Z00Wooo]Z00?oo`00oookJ_oonfX01_oonfX00omg0?oooo]Z
oookJP07oookJP?o001o0_oonfX00olDo`3oo`2foookJP05o`00OdKooo]Z00Go001oo`3o@Ol0od7o
0?m1ool0I@03oookJP;ood800_oKo`001?l007oo0?oCo`3odol0om<2ool=0004oookJ_oo08Koo`2/
ool0[0;ooo]Z0_l0om82ool0n@Sooo]Z0_oo2002o`26o`Kooo]Z00?o0?nConoo0?o_o`000ooonfX2
ool0NP;ooo]Z0_oo04T3ool0^`03oookJ_oo6@3ooaT000;oo`3A0ol0jol00ooonf[o001oo`00O`03
ooT0o`04onl0oom8o`3oB?l0odSo00Co001o0_oonfX2o`3oM`?on@3o00CoJ`3ooookJ_oonf[ooo]Z
0omFo`03ool0P`Wooo]Z0omQ0?l00ol0TOooobD0oolU0002oolU0004o`3o:olco`3o<ol0oc?o00Co
o`1d00?ooo]Zo`0LoolB0?l00ol0/_l5ool400;ooo]Z1?l0ol@5oom90003o`00Oooonf[ooo]Z02_o
oo]Z0_ooB@05oookJP03o`3oa?oonf[ooo]Z00Gooo]Z0ol000001Ooo103ooo]ZoookJ_l;0?oo0?ln
00Wooo]Z00?o08CooookJ_oonfX02_oonfX00omco`3oi?l0oookJP02oookJP04ool0C_oonf[ooo]Z
ooT0o`[ooo]Z00?ooiX0oookJ_oonfX03_oonfX01?oo06?o0?mSond0oooonfX5o`00O`04oookJ_oo
097o0?m`o`3o_P;ooo]Z00?oo`2LoookJ_oonfX00_oonfX00onb0?oooo]ZoookJP02oookJP03oj;o
0?oonf[ooo]Z00;ooo]Z00?o0?l<oookJ_oonfX01?oonfX01_ooU03ooo]Zool0;?oonf[oo`0Co`1j
o`Oooo]Z00Co0?oLoookJ_oonf[o3@3o1?oonfX00on10?oooo]ZoookJP03oookJP03ool0SOoonf[o
oo]Z00;ooeL00_oonfX3o`00O`Gooo]Z1Ol007l4oookJP03ool;0?oonf[ooo]Z00Sooo]Z00Coold0
oookJ_oonf[ooo]Z0_l0o`H5oookJP03o`3ocOoonf[ooo]Z00Wooo]Z00?oo`00oookJ_oonfX01ooo
nfX00omg0?oooo]ZoookJP07oookJP?o001o0_oonfX00olDo`3ooo]ZoookJP05o`00Oakooo]Z000Z
oookJP?o001o0_oonfX2o`3o@@03ool0IOl007oo001o00;ood8000?o001oom_o0?oKo`000_oonfX2
o`3od`;oo`d000Gooo]Zool0Q_oo0:coo`2/oookJP03o`3odP;oo`3i2?oonfX2ool800?o08Ko00?o
oo]ZoolX0?oo:0001_oo:002oookJPGoogT00_oo04T00ooo:03oo`00ool00003oolI00Soo`001Ooo
N@04o`00O`?ooo]Z0_l0ogL3ooT0o`03of/0ooooN@3oogT000CoogT00ooo08<2oomi00Sooo]Z0omQ
0?l2o`2Ao`CoobD00olco`05ooo900?oiOl01?ooN@04ool40003oomi0?l0olCo0?o400?o0?o40_oo
N@04ooo900?ooo]Z1?oo:00:oookJPKoo`003OoonfX:oomi0003o`3oa?oonf[ooo]Z00Oooo]Z00Go
0000oolX0?oo:03oobP0oomi0003ool000;oobP00_oo0003oolX00;ooo]Z00?o08CooookJ_oonfX0
2?oonfX:oomi0003ooT0oooo003oo`0000?oo`000_oonfX7oolX00gooo]Z00?oo`1SoookJ_l0of<0
1_l007l2oookJP06ool0TOoo003oo`00oolX0?oonf[oo`2L0ooonfX2ool000?ooo]Z00?oX_l0o`3o
9?oonfX00ooonfX01?l0o`cooo]ZoookJ_oonfX7oolX0003ool04ol0N_oooo]Z00Kooo]Z0_l0om`0
0ooonf[o3@3ooookJP03oookJP03ool00?oo:03oobP000GoobP01_oo00000ol007oooo]ZoookJP02
oookJPOo001o1?oo:00:oookJP03ooo=0?oonf[ooo]Z00;ooo]Z0_l0o`H5oookJP;o0?o=2_oonfX2
ool000Oooo]Z0_mg0?l7oookJP?o001o0ooonfX00olDo`3o001oo`00O`05o`00OdGooo]Z0ol007l0
1?oonf[o0?m1o`3o@Ooo06D3o`00O`;ood800_oKo`02oookJP;o0?oC0_oo3@02oookJP;oo`2/0_oo
nfX2o`3odP?oo`3i1ooonfX2ool800?o08Ko1OoonfX01?l0oi?okol0onoo0?mBo`02oookJP;oo`1j
0ooonfX2ool0B@;oo`2k00Kooo]ZoolI0?oo6@3ooaT0ool0dOnFo`02o`3[o`04ool=0?l007oooo]Z
oookJP;on@3o0_o_0?l2odSo00?o001o0ooonfX3o`3oM`?on@3o1?oonfX3oeKo00?oo`232OoonfX3
of40o`;o097o1?oo9@03oc?o0007oookJ_oo07Coo`1dool0M?oonf[o01cooa80o`04o`2bo`03o`3o
;?oo103oo`@000;oo`@00_oonfX5o`3oa0CoodT0:OoonfX00oooB@3ooo]ZoookJP04oookJP03o`3o
a?oonf[ooo]Z00Kooo]Z0ol000001Ooo103ooo]ZoookJ_l;0?oo0?ln00Wooo]Z00?o08CooookJ_oo
nfX02ooonfX01OoTo`3ooo]ZoookJ_oonf[oo`1>00;ooo]Z00Con@3ooookJ_oonf[oAP3o2?oonfX0
0oooVP3ooo]ZoookJP0>oookJP03ool0Hol0of?ok@3o00Ko001o00Cooo]Zool0TOl0og3o0?nn0_oo
nfX00ooo09cooo]ZoookJP02oookJP03ok80oooonf[ooo]Z00;ooo]Z00?oX_l0oookJ_oonfX00_oo
nfX00ol0o`cooo]ZoookJP04oookJP06oonD0?oonf[oo`0/oookJ_oo01?o07[o1ooonfX2o`3og003
oookJ_l=0?oooo]Z00?ooo]Z0_n10?l4oookJP06ool0SOoonf[ooo]ZoookJ_ooE`3ooo]Z0ol007l4
oookJPOo001o1?oonfX00ooo2`3ooo]ZoookJP08oookJP03ooo=0?oonf[ooo]Z00;ooo]Z00?o0?l6
oookJ_oonfX00ooonfX2o`3oc@[ooo]Z0_oo0008oookJP;oM`3o1ooonfX3o`00O`?ooo]Z00?o5?l0
o`00Ool007l01Ol007lMoookJP00:_oonfX2oo?o0005o`00Oooonf[ooo]ZoookJ_l007l00ol0od40
1Ooonf[o001ooom20?oo@P3ooo]Z00;ofol00_oonfX2o`3od`?oo`d000Goo`26ool0[?oo0:coo`2/
oookJP02o`3odP?oo`3i1ooonfX3ool800;o08Ko2?oo:0000omBo`3ooo]ZoookJP07oomi0004oolX
0?oo003oo`00ool000;ooaT01_oo00000ooo:03ooo]Zoomi0009oomi00?ooo]Z0_l0ogL2ooT0o`03
of/0ooooN@3oogT000GoogT00ooo08<:oookJP?oH@3o0ol0TOl00ooo9@3oobP0oolX0007oolX0003
onGo0?ooN@3oogT000GoogT000?o00Koool40?oo10000ooo10000oooN@3o0?o4o`3oa002o`3oa0;o
olT01OooB@000ooonf[oobP0oookJP0=oookJP;oo`002ooonfX;oomi0003o`3oa?ooN@3ooo]Z00So
oo]Z00Go0000oolX0?oo:03oobP0oomi0002ool000?oobP00_oo0003oolX00;ooo]Z00?o08Cooook
J_oonfX01ooonfX=oomi00Coo`000ooonfX7oolX00gooo]Z00Goo`1So`00Ool0of?o001ooookJP03
o`00O`?ooo]Z00Koo`2AoolX0?oo:03oobP0oookJ_oo09`4oookJP05ool00?oonf[ooo]ZoookJ_nR
o`000_l0ob@2oookJP03oolX0?l0o`cooo]Z00SoobP000Cooo]Zool04ol0N_oo07[o1ooonfX00ol0
omcooo]Zo`d0o`03oookJP;oo`0000?oP@3ooolX0?oo:0001?oo:006ool000Cooo]Z0ol007l01?oo
nf[o001oo`00Ool007l2oookJP?oobP02_oonfX2oolX00Cooo]Z00?o0?l6oookJ_oonfX01?oonfX0
0ol0olgooo]ZoookJP09oookJP03ool00?oonf[ooo]Z00Kooo]Z00?oM`3ooookJ_oonfX01?oonfX3
o`00O`?ooo]Z1?l007l01?oonf[o001oo`00Ool007m4oookJP;olol00_l007l3oookJP?o0?m100?o
001ooookJ_l007l00_oo@P02om_o00;ooo]Z0_l0om<3ool=0005oookJ_oo0:coo`2/ool0[?oonfX0
0_l0om800ooonf[oo`3iool0n@07oookJP?oo`P00_l0Q_l5oookJP04o`3oToo_o`3okol0oe;o00;o
oo]Z0ooo07X2oookJP;oo`190_oo0;/2oookJP;ooaT000Goo`3AoiKo0?l0jooo0>_oo`3oS003oook
JP?on@3o00Cok`3oodSo0?m8o`3oB?l01_oonfX3o`3oM`;on@3o00?oJ`3ooookJ_oonfX00_oonfX3
oeKo00?oo`232OoonfX3of40o`?o097o0ooo9@03oc?o0004oookJ_oo07Coo`1dool0M0;ooo]Z0_l0
7?l4o`2bo`03o`06oooo103oo`@000?oo`@000?ooo]Zo`00Ool0ol@00ol0ol@6oom9027ooo]Z0_oo
B@06oookJP03o`3oa?oonf[ooo]Z00Oooo]Z0_l000001_oo103oA_l0oookJ_oonf[o2`3oo`3o?PWo
oo]Z00?o08CooookJ_oonfX03?oonfX01OoTo`3ooo]ZoookJ_oonf[oo`1>00;ooo]Z00?on@3ooook
J_m60?l02OoonfX00oooVP3ooo]ZoookJP0>oookJP05ool0Hol0of?ok@3oo`00OooonfX00ol007l2
oookJP03ool0TOl0og3o0?nn00;ooo]Z00?oo`2LoookJ_oonfX00_oonfX00onb0?oooo]ZoookJP02
oookJP03oj;o0?l0obCooo]Z00;ooo]Z00?o0?l<oookJ_oonfX01?oonfX01OooU03ooo]Zool0;?oo
nf[oo`0C00;o07[o1ooonfX01?l0omcooo]Zo`d0ool=0?l2oookJP;o0?Wo00?oP@3ooookJ_oonfX0
0_oonfX01Ooo08gooo]ZoookJ_oonf[ooeL000?o001o1?oonfX3o`00O`04oookJ_l007oo001oo`00
O`Gooo]Z00?oo`/0oookJ_oonfX02?oonfX2ooo=00?ooo]Z00?o0?l6oookJ_oonfX01?oonfX00ol0
olgooo]ZoookJP09oookJP03ool00?oonf[ooo]Z00Oooo]Z00?oM`3ooookJ_oonfX01?oonfX3o`00
O`?ooo]Z1?l007l01?oonf[o001oo`00Ool007lMoookJP006_oonfX:o`00O`Kooo]Z0_l0od/2oo?o
00;ooo]Z0ol007l00ooonf[o0?m1o`3o@@02o`00O`?ood800ooKo`001?oonf[o0?oCo`3odooonfX2
ool=00;oo`260_oo0:`01?oonf[o0?oBo`3od_oonfX2ool0n@Sooo]Z0_oo2003o`26o`?oobP000?o
oo]Zo`3oTooo:0000_oo:0000ol007ooogT0oomi0005oomi0003oolX0?oo003oo`0000;oo`000_oo
6@03ool00004oolX0?l0ohco0?n<oolX00googT00_oonfX01Ol0ogOon@3oooT0oooi0?ooJ`3o00Go
ogT000?oE_l0oookJ_oo08<00_oo08<:oookJP?oH@3o0ol0TOl;oolX00OoogT00ol01_l4ool40003
ooo90?l0olCo0?o400;o0?o40ooonfX6oom901Kooo]Z2oooN@001?l0olCoogT0oomi0?ooN@08oook
JP05o`000?oo:03oobP0oomi0?oo00000_oo:0001OooN@3oobP0oolX0?oo:03oo`0000?oobP00_oo
nfX00ol0Q?oooo]ZoookJP06oookJPooogT01?oo0004oookJPKoobP03?oonfX01?l007ooo`1So`00
Ool0of<2oookJP?o001o0_oonfX5oolX0003oookJ_oo09cooo]Z00;ooo]Z00?oobP0ool00?nb0?l0
0_oonfX01_nRo`3ooo]Zo`3o9?oonf[oobP0oookJP[oobP000Cooo]Zool04ooonf[o07[o1ooonfX0
0ol0omcooo]Zo`d0o`04oookJP03ool00?n10?oooo]Z00GoobP01_oo0002oookJP?o001o0ooonfX3
o`00O`?ooo]Z0_oo:00;oookJP03oolX0?oonf[ooo]Z00;ooo]Z00?o0?l6oookJ_oonfX01?oonfX2
o`3oc@[ooo]Z00?oo`00oookJ_oonfX01_oonfX2ogL0o`Cooo]Z0ol007l3oookJP?o001o0ooonfX3
o`00OcCooo]Z2_l007l5oookJP;o0?m;0_oco`03oookJP?o001o0_l0od400ooo06Go001oo`00O`03
oom200;ofol000Cooo]Zo`3odol0om?ooo]Z0_oo3@001Ooonf[oo`26ool0[?oo0:cooo]Z00;o0?oB
00?ooo]Zool0nOoo0?T02?oonfX2ool800?o08Ko1OoonfX3onoo00?o001o0_oo07X2o`00O`;oo`19
0ooo0;/01Ooonf[ooaT0oolI0?oo0=7oU_l000;o0>_o0_l0oh`2o`00O`03oookJ_oi0?oon@3o00;o
k`3o0om8o`06oookJP;o0?mg0ooi0?l00om[0?oooo]ZoookJP02oookJP;oE_l000Cooo]Zool0Pooo
08?oo`232OoonfX3of40o`?o097o0ooo9@04oc?o00;oo`1d0ol007l3o`0Lo`03ooT0ool0/_oo0;;o
00?o00Ko1?oo10000ol007oooo]Zo`3oa002o`3oa0?ooo]Z1oooB@0FoookJPCoodT01_oonfX2o`3o
a0[ooo]Z0_l000001_oo103oA_l0oookJ_oonf[o2`3oo`3o?P[ooo]Z00?o08CooookJ_oonfX02ooo
nfX00ooTo`3ooo]ZoookJP02oookJP06ool0C_oonf[ooo]ZooT0oooonf[oAP3o2OoonfX00oooVP3o
oo]ZoookJP0=oookJP04o`00Oooo06?o0?mSond0o`;ooo]Z0ol007l2oookJP06ool0TOl0og3o0?nn
o`3o__oonf[oo`2L1?oonfX2ok80o`?ooo]Z00?oX_l0o`3o9?oonfX00_oonfX00ol0o`cooo]Zoook
JP04oookJP07oonD0?oonf[oo`0/oookJ_oo01?ooo]Zo`1jo`07oookJP04o`3og?oonf[ooo]Zo`d0
o`?ooo]Z00?o0?Wooh40oon10?l00ooonfX01?oo08gooo]ZoookJ_oonfX2oomG0004o`00Oooonf[o
oo]ZoookJP?o001o0ooonfX3o`00O`Gooo]Z00?oo`/0oookJ_oonfX02OoonfX01Oooc@3ooo]Zoook
J_oonf[o0?l600Kooo]Z0_l0old:oookJP03ool00?oonf[ooo]Z00Oooo]Z0_mg0?l4oookJP?o001o
0ooonfX3o`00O`?ooo]Z0ol007lLoookJP006_oonfX:o`00O`Kooo]Z0_l007l2o`3oB`;olol01_oo
nfX2o`3o@@03o`00Oooonf[ooo]Z00;ood8000Cooo]Zom_o0?oKo`3ooo]Z0_l0om<00ooonf[oo`d0
ool=0002ool0QP;oo`2/00Cooo]Zo`3od_l0om;ooo]Z0_oo0?T8oookJP;oo`P000Cooo]Zo`26ool0
Q_ooobP00ooonfX2o`3oT`;oobP01oooN@000ooo:03oo`00ool00003ool000?ooaT00ooo:0000ol0
jooo0?n<oomi000;oomi00Cooo]Z0_l0ogL2ooT0o`03of/0ooooN@3oogT000;ooo]Z0_mFo`02oook
JP;oo`232ooonfX3of40o`03o`2Aoooo:03oobP000[oobP02OooN@03o`06o`Coo`@000?ooo]Zo`3o
a?l0ol@01?l0ol@3oookJPKoodT03OoonfX2oom900OoogT00ooob@000oooN@3o0?o4oomi0003oomi
00Sooo]Z00Co0000oolX0?oo:03oo`000ooo:0001OooN@3oobP0oolX0?oo:03oo`0000CoobP000?o
oo]Zo`24oooonfX02OoonfX>oomi00?oo`001_oonfX4oolX00kooo]Z00Coo`1SoookJ_l0of?ooo]Z
0ol007l2oookJPKoobP000Gooo]Zool0W?oonf[ooo]ZoolX0002oookJP05ok80oooonf[ooo]Zoj;o
0?oonfX00ooo:0000ooonf[o0?l<oolX0008oolX0004oookJ_oo01?oo`0Co`1jo`Oooo]Z0_l0om`2
o`d0o`?ooo]Z00Coo`00oh40oooo003oo`000ooo:007ool00004oookJ_l007oo001oo`00O`?ooo]Z
0ol007l5oookJP03oolX0?oo2`3ooo]Z00Wooo]Z0_oo:003oookJP03o`3o1_oonf[ooo]Z00Gooo]Z
00?o0?o=oookJ_oonfX02?oonfX2ool000Sooo]Z00CoM`3ooookJ_oonf[ooo]Z0ol007l9oookJP?o
001o=?oonfX:o`00O`Kooo]Z00?o001oo`3oBol0od/00_oco`06oookJP;o0?m100Coo`1Uo`00Oooo
nf[ooo]Z0_oo@P02om_o0004oookJ_l0om?o0?oCoookJP;oo`d000Gooo]Zool0Q_oo0:coo`2/oook
JP03o`3odP?oo`3i1ooonfX2ool80003oookJ_l0Q_oo08Ko00Cooo]Z00Co001oo`3oToo_o`3okol0
0ol007l2ool0NP03o`00Oooonf[ooo]Z00;oo`190_oo0;/01_l007oooaT0oolI0?oo6@3oo`3AoiKo
00;o0>_o00Co0?n<oookJ_oonf[ooo]Z0ooi0?l2onl0o`;oB?l01_oonfX3o`3oM`;on@3o00?oJ`3o
oookJ_oonfX00_oonfX2oeKo00;ooo]Z0_oo08<:oookJP?oH@3o0ol0TOl3oolU0004o`00Oolco`3o
<ol0oc?o00;oo`1d0ol007l4o`0Lo`03oa80ool0/_oo0;;o00?o00Ko1?oo10000ooonf[o0?o4o`3o
a004o`3oa0Cooo]Z1_ooB@0=oookJP?oodT02OoonfX00ol0olCooo]ZoookJP0:oookJP;o000000Ko
o`@0odKo0?oonf[ooo]Zo`/0ool0och:oookJP03o`24oooonf[ooo]Z00cooo]Z00Goi?l0oookJ_oo
nf[ooo]Zool0CP03oookJP03ooT0oooonf[oAP3o00Wooo]Z00?ooiX0oookJ_oonfX03_oonfX01?oo
06?o0?mSond0oooonfX3o`00O`?ooo]Z0_oo09401?l0og3o0?nnoookJ_oo09`5oookJP06ok80oooo
nf[ooo]ZoookJ_nRo`3o0?lT0ooonfX00ol0o`cooo]ZoookJP04oookJP;ooi@000Goo`0/oookJ_oo
01?oo`0Co`1jo`07oookJP;o0?oL00?ooo]Zo`d0oooonfX00_oonfX00ol0nOoooo]Zoh40o`03oook
JP06ool0SOoonf[ooo]Zo`00OoooN`3ooeL00ooonfX3o`00O`?ooo]Z0ol007l6oookJP;oo`/02_oo
nfX2ooo=00;ooo]Z00?o0?l6oookJ_oonfX01OoonfX00ol0olgooo]ZoookJP08oookJP;oo`002Ooo
nfX01?mg0?oooo]ZoookJ_oonfX3o`00O`Wooo]Z0ol007lLoookJP00:_oonfX3o`00O`03oookJ_l0
od_o0?m;00;olol01?oonfX2o`00O`;o0?m10ooonfX2oom20004oookJ_oKo`3ofol0oookJP?o0?oC
0_oo3@02ool0QP;oo`2/00Cooo]Zo`3od_l0om;ooo]Z0ooo0?T7oookJP;oo`P000?oobP0o`26ool0
Q_l01?oonfX2o`3oT`03oolX0?o_o`3oogT000KoogT01_oo00001Ooo:03ooaT0oolI0?oo003oobP0
00;o0>_o00?o0?n<oomi0?ooN@001oooN@000om8o`3ooo]ZoookJP04oookJP03oomi0?l0ogOon@3o
00;on@3o00CoJ`3ooookJ_oonf[ooo]Z0_mFo`02oookJP?oo`232ooonfX2of40o`03oookJ_oo:03o
obP000WoobP02OooN@000olB0?oo0;;oo`2bo`03o`06o`Coo`@00ooonfX6o`3oa0?ooo]Z3OooB@04
oookJPSoolT000?o0?o4oookJ_oonfX02ooonfX00ol0003oobP0oolX0003oolX00?oogT01ooo:002
oookJP03o`24oooonf[ooo]Z00Wooo]Z3_ooN@02ool000;ooo]Z00CoobP0oookJ_oonf[ooo]Z1?oo
:00>oookJP03ool0Hooonf[o0?mS00?o001o00?ooo]ZoolX0?oo:0001_oo:0000ooonf[oo`2LoolX
0002oolX00;ooo]Z00?o/P3ooookJ_oonfX01Ooo:0001?oonf[o0?l<o`3o3?oonfX7oolX0004ool0
;?oonf[oo`0Co`1jo`Sooo]Z00?o0?oLoookJ_l=0?l00ooonfX5ool000;oobP01_oo00001?oonf[o
001oo`00Ool007l3oookJP?o001o1ooonfX00ooo2`3ooo]ZoookJP09oookJP04oolX0?oonf[ooo]Z
oookJP;o0?l600?ooo]ZoolX0?oonfX00ooonfX00ol0olgooo]ZoookJP09oookJP03ool00?oonf[o
oo]Z00Kooo]Z00?oM`3ooookJ_oonfX00ol007l9oookJP?o001oA?oonfX3o`00O`;o0?m;0_oco`05
oookJP04o`00Ool0od7o0?m1ool0I@?ooo]Z0_oo@P02om_o0004oookJ_l0om?o0?oCo`3od`;oo`d0
00Cooo]Zool0Q_oo0:coo`2/0_oonfX2o`3odP03oookJ_oo0?Woo`3i00Oooo]Z0_oo20000ooonf[o
08Koo`26o`05oookJP03o`3oToo_o`3okol000?ooo]Z0ooo07X2oookJP;oo`190_oo0;/01_l007oo
oo]ZoolI0?oo6@3oo`3AoiKo00;o0>_o0_l0oh`3o`00O`;on@3o0_o_0?l3odSo00Kooo]Z0_l0ogL2
ooT0o`03of/0oooonf[ooo]Z00;ooo]Z0_mFo`02oookJP?oo`232_oonfX2of40o`04oookJ_l0TOoo
097oo`3o:`?oobD000?ooo]Zoc?o0?lco`000_lco`000ooo07Cooo]ZoookJP02oookJP?o01co0olB
0?l01?l0/_oo00Koo`06ool01_l4ool400?ooo]Z1_l0ol@4oookJPgoodT02_oonfX2o`3oa0gooo]Z
0_l000001_oo103oA_l0o`000?oonf[o2`3oo`3o?PKooo]Z00?oo`3OoookJ_oonfX00_oonfX00ol0
Q?oooo]ZoookJP0;oookJP03og?o0?oTo`3ooo]Z00;ooo]Z00Ooo`1>oookJ_oonf[ooo]ZooT0oooo
nf[oAP3o00Wooo]Z00?ooiX0oookJ_oonfX03_oonfX00ooo06?o0?mSond0o`03o`00O`Gooo]Z00Go
o`2Ao`3oL?l0okkooo]Zool0W005oookJP04ok80oooonf[ooo]ZoookJP;oX_l00ooonfX2o`3o30Ko
oo]Z00Kooi@0ool0;?oo02cooo]Zool04ol0N_l8oookJP03o`3og?oonf[o3@3o00?ooo]Z0_l0nOl0
1_n10?oooo]ZoookJ_oonf[oo`2=oookJP?o001o00?ooeL0oookJ_oonfX00ol007l3oookJP?o001o
2?oonfX00ooo2`3ooo]ZoookJP09oookJP03ooo=0?oonf[ooo]Z00;o0?l61_oonfX00ol0olgooo]Z
oookJP09oookJP03ool00?oonf[ooo]Z00Oooo]Z00?oM`3ooookJ_oonfX00ol007l9oookJP?o001o
7?oonfX002[ooo]Z0ol007l3oookJP;o0?m;0_oco`000ooonf[o001oo`00O`02o`00O`03oookJ_l0
od7oo`1U00?ooo]Z0_oo@P000ooonf[ofol0om_o0002oookJP;o0?oC00Coo`d0oookJ_oo08Koo`26
0_oo0:`00ooonf[o0?oBo`3odP02oookJP;oo`3i1ooonfX2ool80003oookJ_l0Q_oo08Ko00Cooo]Z
0_l0oi<2onoo00KoogT000?oobP0ool00?oo00000_oo0003oolX00;ooaT000CoU_l0oookJ_l0jooo
0>_o2?ooN@001?o_0?ooB?l0odSo0?m8o`05oookJP03oomi0?l0ogOo0?mg00;on@3o00CoJ`3ooook
J_oonf[ooo]Z0omFo`02oookJP?oo`232_oonfX3of40o`SoobP00olco`07oomi00;oolT00olB0?l2
o`2bo`?o00Ko0ooo1002ooo900Cooo]Z1_l0ol@9oookJPgoolT03_oonfX00ooob@3oobP0ool00002
ool000GoogT01ooo:002oookJP03o`24oooonf[ooo]Z00Wooo]Z3_ooN@001?oo003ooo]ZoookJ_oo
:005oookJP;oobP03?oonfX2o`00O`03oookJ_oo06?o001o00;o0?mS00?o001ooolX0?oo:0003Ooo
:002oookJP03ok80oooonf[oobP000GoobP00_oonfX00ol0o`cooo]ZoookJP05oolX0003oookJ_oo
02cooo]Z00;oo`0C2?oonfX2o`3og003o`d0oooonf[oo`0000Koo`0000?ooo]ZoolX0?oo08d01Ooo
0003o`00O`?ooo]Z0ol007l8oookJP;oo`/02_oonfX2oolX00?ooo]Z00?o0?l6oolX0?oonfX01?oo
nfX2o`3oc@[ooo]Z00?oo`00oookJ_oonfX01_oonfX2ogL0o`?o001o1?oonfX2o`00O`;ooo]Z1?l0
07m4oookJP?o001o0_oonfX2o`3oB`;olol00_oonfX4o`00O`03o`3o@Ooo06Goo`1U00?ooo]Z0_oo
@P02om_o00;ooo]Z0_l0om<2ool=0006oookJ_oo08Koo`2/ool0[?l0=_oooo]Z0_l0om800ooonf[o
o`3iool0n@07oookJP;oo`P000?ooo]Zo`26ool0Q_l01OoonfX01?l0oi?okol0onoo0?mBo`03oook
JP;oo`1j0_oonfX2ool0B@;oo`2k0_oonfX2oolI00;oU_l00_l0jol2o`3oS003o`00Oooonf[ooo]Z
00;on@3o00?ooo]Zonl0ooo_0?l00om8o`05oookJP;o0?mg0ooi0?l4oookJP?oE_l00_oonfX2ool0
P`[ooo]Z0omQ0?l3o`2Ao`04o`3o:ooo9@3oobD0oolU00;ooo]Z0olco`03ool0M0;ooo]Z00?o001o
o`0Lool07?l00olB0?l00ooi0?oo0;;oo`06o`02o`06o`?oo`@01_oonfX6o`3oa1?ooo]Z0_l0ol@?
oookJP;o000000Koo`@0odKo0?oonf[ooo]Zo`/0ool0och6oookJP03ool0gooonf[ooo]Z00;ooo]Z
00?o08CooookJ_oonfX03?oonfX00omco`3oi?l0oookJP02oookJP07ool0C_oonf[ooo]ZoookJ_oi
0?oooo]ZodH0o`09oookJP03oonJ0?oonf[ooo]Z00_ooo]Z0_l007l01_oonf[oo`1So`3oHol0of?o
k@3oo`00O`Kooo]Z00Coo`2Ao`3oL?l0okkooo]Z0_oo09`4oookJP;o/P3o0ooonfX00onRo`3ooo]Z
oookJP02oookJP03o`3o3?oonf[ooo]Z00Cooo]Z00Cooi@0oookJ_oo02cooo]Z0_oo01<8oookJP;o
0?oL0_l=0?l3oookJP03o`3ioon10?ooP@3o00;ooo]Z0_oo08d2o`00O`03oookJ_ooE`3ooo]Z00?o
001o0ooonfX3o`00O`Wooo]Z0_oo2`0:oookJP05ooo=0?oonf[ooo]ZoookJ_l0o`H01_oonfX2o`3o
c@[ooo]Z00?oo`00oookJ_oonfX01ooonfX2ogL0o`?o001o1?oonfX2o`00O`;ooo]Z1?l007lLoook
JP00:_oonfX3o`00O`Cooo]Z00?o001oo`3oBol0od/00_oco`02o`00O`?ooo]Z0_l0od401?oo06Go
oo]ZoookJ_oonfX2oom20003oookJ_oKo`3ofol000;ooo]Z0_l0om<01?oo3@3ooo]ZoookJ_oo08H2
ool0[003oookJ_l0om;o0?oB00;ooo]Z0_oo0?T7oookJP;oo`P000?ooo]Zo`26ool0Q_l01?oonfX2
o`3oT`;okol01OooN@001?oo:03oo`00ool00?oo0004oolX0006o`00Oooo6@3ooaT0oiKo0?oonf[o
0>_o2?ooN@03onl0o`;oB?l01?oonfX01?ooN@3ooo]Zo`3oMol0ogL3ooT0o`Cooo]Z0_mFo`03oook
JP;oo`232ooonfX2of40o`KoobP00_oo9@000ooob@3o<ol0oc?o0004oomi00GoolT000Ko01cooa80
oolB0?oo4P3oooo90?l0/_l3o`06o`Goo`@01ooonfX6o`3oa13oolT03OoonfX00ooob@3oo`00ool4
0002ool000OoogT01_oo:002oookJP03o`24oooonf[ooo]Z00_ooo]Z3OooN@001?oo003oobP0oolX
0?oo:006oookJP03oolX0?oonf[ooo]Z00Wooo]Z1?l007l01?oo06?o001oo`00Ool0of<2oookJPSo
obP000?o0?nnoolX0?oo:0000ooo:002oookJP;o/P3o1_oo:002oookJP04o`3o3?oonf[ooo]Zoook
JPCoobP000Gooo]Zool0;?oo02cooo]Zool04`09oookJP03o`3og?l=0?ooo`0000Ooo`0000?ooo]Z
o`00Oooo08d01Ooo0002o`00O`?ooo]Z0ol007l:oookJP03ool;0?oonf[ooo]Z00Wooo]Z00?oobP0
oookJ_oonfX00ooo:006oookJP03o`3ocOoonf[ooo]Z00Sooo]Z0_oo0008oookJP03ogL0ool007oo
001o00Cooo]Z1ol007m5oookJP?o001o1?oonfX2o`3oB`;olol00ol007l2oookJP;o0?m10_oo06D3
oookJP;ood800_oKo`02oookJP;o0?oC0_oo3@001_oonf[oo`26ool0[?oo0:co03KooookJP;o0?oB
00?ooo]Zool0nOoo0?T01ooonfX2ool80003oookJ_l0Q_oo08Ko00Gooo]Z00Co0?nConoo0?o_o`3o
D_l00ooonfX2ool0NP?o001o00Goo`19ool0^ooo0;_oo`2ko`00O`02oolI00;oU_l00_l0jol2o`3o
S0?ooo]Z0ooi0?l3onl0o`;oB?l01OoonfX3o`3oM`;on@3o00?oJ`3ooookJ_oonfX00_oonfX2oeKo
00;ooo]Z0_oo08<;oookJP?oH@3o0ol0TOl01?l0ob_oobD0oolU0?oo9@02oookJP?o<ol00ooo07@2
o`00O`;ooo]Z00?o01cooa80oolB0?l00_lB0?l01?l0/_oo00Koo`06ool01_l5ool400Oooo]Z4ol0
ol@AoookJP;o000000Koo`@0odKo0?oonf[ooo]Zo`/0ool0och7oookJP05ool0gooonf[ooo]Zoook
J_l0Q?l03ooonfX00omco`3oi?l0oookJP02oookJP07ool0C_oonf[ooo]ZoookJ_oi0?oooo]ZodH0
o`09oookJP03oonJ0?oonf[ooo]Z00[ooo]Z1?l007l01?oo06?o001oo`3oHoo]0?l7oookJP06ool0
TOl0og3o0?nno`3o__oonf[oo`2L1OoonfX01_nb0?oooo]ZoookJ_oonf[oX_l0o`3o90?ooo]Z00?o
0?l<oookJ_oonfX01?oonfX01_ooU03ooo]Zool0;?oo02cooo]Zool04`Wooo]Z00?o0?oLoookJ_l=
0?l00ooonfX00ol0nOoooo]Zoh40o`02oookJP03o`00Oooo08go001o00;ooo]Z0_ooE`02o`00O`?o
oo]Z0ol007l;oookJP03ool;0?oonf[ooo]Z00Sooo]Z0_ooc@02oookJP;o0?l61_oonfX00ol0olgo
oo]ZoookJP08oookJP;oo`002OoonfX00omg0?oo001oo`00O`04oookJPOo001o7OoonfX002[ooo]Z
0ol007l4oookJP?o001o0_l0od/2oo?o00Gooo]Z0_l0od401?oo06Gooo]ZoookJ_oonfX3oom200?o
fol000Cooo]Zo`3odol0om?oo`d00_oonfX01?oo08Koo`2/ool0[?l0=_l2o`3odP;ooo]Z0_oo0?T7
oookJP;oo`P000?ooo]Zo`26ool0Q_l01?oonfX2o`3oT`;okol00_ooN@02oookJP03oomi0?oo003o
obP000KoobP000Kooo]ZoolI0?oo6@3oU_l0o`00Ool0jol4oomi00;ooo]Z00?oogT0ooT0oooonfX0
0_o_0?l2odSo00Oooo]Z0_l0ogL4oomi00;ooo]Z0_mFo`03oookJP?oo`232_oonfX3of40o`?oobP0
0_l0ob/3oolU0004ooo90?lco`3oogT0oomi00WoolT01?lB0?l00ooob@3o0;;oo`2bo`02o`06o`03
oiCo0?oo103oo`@000;oo`@03?nDo`0=ooo900cooo]Z0_oob@001?oo003oo`@0oolX0?oo:008oomi
00GoobP00ooonfX00ol0Q?oooo]ZoookJP0<oookJPCoogT000?ooo]Zoomi0?ooN@001?ooN@000ooo
003oobP0oolX0002oolX00Kooo]Z00?oobP0oonJ0?oonfX02?oonfX5o`00O`;oo`1S00?ooo]Zo`3o
Hoo]0?l00ooonfX6oolX00;o0?nn1ooo:0000onb0?ooobP0oolX0004oolX00;ooo]Z0_l0o``4oook
JP;oobP00_oonfX01?oo02cooo]Zool04ol0N_l7oookJP03ool00?l0omco3@3o00Soo`000_l007l2
ool0S@Coo`0000Co001ooookJ_oonf[ooo]Z0ol007l;oookJP;oo`/02_oonfX6oolX00Kooo]Z00?o
0?o=oookJ_oonfX02OoonfX00ooo003ooo]ZoookJP05oookJP03o`00Oomg0?oo001o00Cooo]Z1_l0
07m6oookJP?o001o1?oonfX2o`00O`;o0?m;0_oco`05oookJP;o0?m10_oo06D3oookJP?ood800_oK
o`000ooonf[o0?oCo`3od`02ool=0006oookJ_oo08Koo`2/ool0[?l0=_oooo]Z0_l0om800ooonf[o
o`3iool0n@07oookJP;oo`P000?ooo]Zo`26ool0Q_l01?oonfX2o`3oT`;okol000CoD_l0oookJ_oo
nf[ooo]Z0ooo07X2oookJP;oo`190_oo0;/00ooonf[ooaT0oolI0002oiKo00?o0>_o00?o0?n<ool=
0?oonfX00_oonfX2ooT0o`03oookJ_o_0?ook`3o00;oB?l01_oonfX2o`3oM`;on@3o00?oJ`3ooook
J_oonfX00_oonfX2oeKo00;ooo]Z0ooo08<;oookJP?oH@3o0ol0TOl01?l0ob_oobD0oolU0?oo9@02
o`00O`;o<ol000Co001oool0M?oo07Coo`1d1OoonfX00ol07?oo4P3ooa80o`02oa80o`?o0;;o0_l0
1_l5ool402Kooo]Z00Co0000ool40?l0003oA_l00_oonfX00ol;0?oooo]Zo`3o?P06oookJP03ool0
gooonf[ooo]Z00;ooo]Z00?o08CooookJ_oonfX03OoonfX00omco`3oi?l0oookJP02oookJP07ool0
C_oonf[ooo]ZoookJ_oi0?oooo]ZodH0o`09oookJP;ooiX02_oonfX5o`00O`;oo`1S0_l0of<7oook
JP;oo`2A00Co0?m`o`3o__oonf[oo`2L1OoonfX01?nb0?oooo]ZoookJ_oonfX2oj;o00?ooo]Z0_l0
o``5oookJP07oonD0?oonf[ooo]Zool0;?oonf[oo`0Co`1jo`08oookJP03o`3og?oonf[o3@3o00?o
oo]Z0_l0nOl2oh40o`;o001o0_oo08d2oookJP03oomk0?ooE`3o001o00?ooo]Z0ol007l<oookJP03
ool;0?oonf[ooo]Z00Wooo]Z00Goold0oookJ_oonf[ooo]Zo`3o1P06oookJP03o`3ocOoonf[ooo]Z
00Wooo]Z00?oo`00oookJ_oonfX01_oonfX00ol007ooM`3oo`00O`04oookJPKo001o7_oonfX002Oo
oo]Z1_l007l4oookJP;o001o0ooonfX2o`3oB`;olol01OoonfX2o`3o@@03ool0IOoonf[ooo]Z00;o
oo]Z0_oo@P001?oonf[ofol0om_o0?oonfX2o`3od`04ool=0?oonf[ooo]Zool0QP;oo`2/00?o03Ko
o`3od_l0om800_oonfX00ooo0?Wooo]ZoookJP06oookJP;oo`P000?ooo]Zo`26oooonfX01?oonfX0
1Ol0oi?oogT0onoo0?o_o`3oD_l000?o001o1Ooo:002ool0B@03oolX0?oo0;_ooo]Z00;ooaT000?o
U_l0oookJ_ooN@000_ooN@02o`3oS0;ooo]Z0_oi0?l00ooonf[ok`3oonl0o`02odSo00Oooo]Z0_l0
ogL7oomi0003oeKo0?oonf[ooo]Z00;ooo]Z0_oo08<9oookJPOoobP000?o097oo`3o:ol0ob/01Ooo
0002oc?o00;oolT00_oo07@6ooo900?o4P3o00Con@3oo`2bool0/_oo0;;o0onDo`03ool400coU?l0
2_oob@0;oookJP;oolT000Coo`00oolX0?oo103oobP02_ooN@05oolX00;ooo]Z00?o08CooookJ_oo
nfX03_oonfX2oomi00?ooo]Z0oooN@03ool000CoobP01ooonfX00oooVP3ooo]ZoookJP06oookJP;o
001o00?ooo]Zool00?oonfX00_oonfX01?oo06?ooo]Zo`3oHol0of<4oookJPGoobP000?o0?m`o`3o
__oo:0000ooo:0001?oonf[oobP0oolX0?nb0?l6oolX00?ooo]Z00?o0?l<oookJ_oonfX00ooonfX0
1Ooo:03ooi@0oookJ_oo02cooo]Z00;oo`0C2?oonfX00ol0omco3@3oool00006ool000?o001o00?o
oo]Zool0SOoonfX00ooo0003oookJP?o001o3OoonfX00ooo2`3ooo]ZoookJP07oookJPOoobP000?o
0?l6oookJ_oonfX00ooonfX2o`3oc@[ooo]Z00Coo`00oookJ_oonf[ooo]Z1Ol007l2ogL0o`?ooo]Z
0_l007m7oookJPKo001o1?oonfX2o`00O`;ooo]Z0_l0od/2oo?o00Gooo]Z0_l0od42ool0I@Cooo]Z
0_oo@P02om_o0004oookJ_l0om?o0?oCool=00;ooo]Z00?oo`26ool0[?oo0:`00_l0=_l2o`3odP03
oookJ_oo0?Wooo]Z00Oooo]Z0_oo20000ooonf[o08KooookJP04oookJP;o0?nC0_o_o`000omBo`3o
001oo`00O`02o`00O`;oo`1j00Cooo]Zo`00Oooo04Woo`190_oo0;/00ooonf[ooaT0oolI0002oiKo
0003oookJ_l0jooo0>_o00;o0?n<0ooonfX2ooT0o`03oookJ_o_0?ook`3o00;oB?l01_oonfX2o`3o
M`;on@3o00?oJ`3ooookJ_oonfX00_oonfX2oeKo00?ooo]Z0_oo08<<oookJP?oH@3o0_l0TOl01?oo
nf[o0?l[oolU0?oo9@02oookJP?o<ol000Cooo]Zool0M?oo07Coo`1d1_oonfX01?l07?oo4P3ooa80
oolB0?l3o`2bo`;oo`0^00?oA_l0o`06oooo10000_oo1003o`3o;23ooo]Z00Co0000ool40?m6o`3o
00000_oonfX00ol;0?oooo]Zo`3o?P03oookJP05ocWo0?oonf[ooo]ZoookJ_oo0=l00ooonfX00ol0
Q?oooo]ZoookJP0>oookJP03og?o0?oTo`3ooo]Z00;ooo]Z00Ooo`1>oookJ_oonf[ooo]ZooT0oooo
nf[oAP3o00[ooo]Z00?ooiX0oookJ_oonfX01ooonfX2o`00O`Gooo]Z00Coo`1SoookJ_l0of?ok@3o
1ooonfX01Ooo097o0?m`o`3o__oonf[oo`2L00Gooo]Z0_nb0?l3oookJP03oj;o0?oonf[ooo]Z00;o
oo]Z00?o0?l<oookJ_oonfX00ooonfX2oonD0003oookJ_oo02coo`0/00;oo`0C2?oonfX2o`3og008
o`d0oooonf[ooo]ZoookJ_l007oo0?Woo`00Oon10?l2o`00O`03oookJ_oo08gooo]Z00;o001o00Co
oeL0oookJ_oonf[ooo]Z0ol007l=oookJP;oo`/02_oonfX2ooo=00;ooo]Z0_l0o`H5oookJP;o0?o=
2_oonfX00ooo003ooo]ZoookJP02oookJPGo001o0_mg0?l3oookJP;o001o8_oonfX002Oooo]Z0ol0
07l2olL0o`03o`00Oooonf[ooo]Z00;ooo]Z0_l007l5oookJP;o0?m;00?olol0oookJ_oonfX01?oo
nfX2o`3o@@03ool0IOoonf[ooo]Z00;ooo]Z0_oo@P001Ooonf[ofol0om_o0?oonf[o0?oC00;oo`d0
0_oonfX01?oo08Koo`2/o`0fool0=_l2o`3odP03oookJ_oo0?Woo`3i00Sooo]Z00Coo`P0oookJ_l0
Q_oo08Ko1?oonfX2o`3oT`04o`00Ooo_o`3okol0oe;o00;o001o00CoobP0oookJ_oo:03oo`1j0_l0
07l2ool0B@;oo`2k00Ko001ooolI0?oo6@3oU_l0oomi0?oonfX2o`3[o`;o0?n<0_oonfX2ooT0o`;o
oo]Z00?ok`3oodSo0?m8o`001ooonfX00ol0ogOoogT0oomi0009oomi00;ooo]Z0ooo08<8oookJPgo
obP01ooo0007ooo90003oookJ_lB0?oo4P3o00;o4P3o0_l0/_l4oiCo017oiOl01Ooob@0:oookJP;o
olT000Coo`00oolX0?oo:03oo`@02OooN@03oolX0004oookJ_oo:03oobP0oolX00?ooo]Z00?o08Co
oookJ_oonfX03_oonfX2oomi00?ooo]Z00?oogT0ool00?oo00000ooo0004oolX00Oooo]Z00?ooiX0
oookJ_oonfX01OoonfX2o`00O`03oookJ_oo003oo`0000?ooo]Z00Coo`1SoookJ_oonf[o0?mS1Ooo
nfX4oolX0003o`3oL?l0okkoobP000;oobP01?oonfX00onb0?ooobP0oolX0003oolX00Cooo]Z00?o
0?l<oookJ_oonfX01?oonfX01oooU03ooo]Zool0;?oo02cooo]Zool04ol0N_l02?oonfX2o`d0o`Ko
o`0000[oP@3oo`00Oooonf[ooo]Zool0SOoonf[o001ooomk0?oo003ooeL00ol007l?oookJP;oo`/0
1_oonfX9oolX0003o`3o1_oonf[ooo]Z00Cooo]Z00?o0?o=oookJ_oonfX02?oonfX2ool00003oook
J_l007oo001o00Co001o00Cooo]ZogL0oooonf[ooo]Z0_l007m7oookJP;o001o0_o70?l2o`00O`Co
oo]Z0_l007l4oookJP;o0?m;0_oco`05oookJP;o0?m10_oo06D4oookJP;ood800_oKo`001?oonf[o
0?oCo`3odooo3@02oookJP03ool0Q_oo0:coo`2/00;o03Ko00Co0?oBoookJ_oo0?Woo`3i2?oonfX2
ool800;o08Ko1OoonfX2o`3oT`;okol000?oD_l0o`00Ool007l00_oonfX2ool0NP;o001o0_oo04T2
ool0^`03o`00Oooo6@3ooaT000;oU_l000?ooo]Zo`3[ool0jol00_l0oh`3oookJP;on@3o0_oonfX0
0oo_0?ooB?l0odSo0006oookJP;o0?mg0_oi0?l00om[0?oooo]ZoookJP02oookJP;oE_l00ooonfX3
ool0P`cooo]Z0omQ0?l2o`2Ao`03o`00Oooo9@3oobD000?ooo]Z0olco`000ooonf[oo`1dool0M007
oookJP04o`0LoolB0?oo4P3ooa80o`?o0;;o0_oo02h00om6o`3o00Koool40002ool400Co0?l/7?oo
nfX01?l0003oo`@0odKo0?l00002oookJP03o`/0oooonf[o0?ln00?ooo]Z00Go>Ol0oookJ_oonf[o
oo]Zool0g`04oookJP03o`24oooonf[ooo]Z00oooo]Z00Coi?l0oookJ_oonf[ooo]Z0_oo04h2oook
JP03ooT0oooonf[oAP3o00[ooo]Z00?ooiX0oookJ_oonfX01_oonfX2o`00O`Kooo]Z00Coo`1Soook
J_l0of?ok@3o1ooonfX01?oo097ooo]Zo`3o__oonfX2ool0W0Gooo]Z00Go/P3ooookJ_oonf[ooo]Z
oj;o0004oookJP03o`3o3?oonf[ooo]Z00Cooo]Z00Oooi@0oookJ_oonf[oo`0/oookJ_oo01?o07[o
00Sooo]Z00Co0?oLo`d0ool=0?oooo]Z0_l007l01?l0nOoo001ooh40ool007l2oookJP;oo`2=0_l0
07l2oomG00?o001o4?oonfX00ooo2`3ooo]ZoookJP09oookJP05ooo=0?oonf[ooo]ZoookJ_l0o`H0
1_oonfX00ol0olgooo]ZoookJP08oookJP;oo`000_oonfX6o`00O`04oookJ_mg0?oooo]ZoookJP;o
001o8_oonfX002Wooo]Z00?o001oool0=ooo03L00_o70?l4oookJPOo001o00Cooo]Zo`3oBol0od_o
lol01_oonfX2o`3o@@03ool0IOoonf[ooo]Z00;ooo]Z0_oo@P000ooonf[ofol0om_o0002o`3od`;o
o`d00_oonfX2ool0[0;o03Ko0_l0om800ooonf[oo`3iool0n@07oookJP;oo`P000?ooo]Zo`26ool0
Q_l01?oonfX2o`3oT`04ooog0?o_o`3okol0oe;o00Cooo]Z00Coo`1jo`00Ool007oo001o0_oo04T2
ool0^`04oookJ_oo6@3ooaT0oiKo00;ooo]Z0_l0jol2o`3oS0;ooo]Z0_oi0?l2oookJP03onl0oom8
o`3oB?l000Oooo]Z3?ooN@03oookJP;oo`231ooonfX00ooo:03ooo]ZoolX000=oolX00Ooo`000ooo
b@04oookJP05o`0LoolB0?oo4P3ooa80ool0/_l01?nDo`0?onGo0003oookJ_oob@3oolT000;oolT0
1_ooN@05oookJP?oobP000?oo`@0oomi0?ooN@001OooN@000ooo:03ooo]ZoookJP03oolX00;ooo]Z
0ooo:002oookJP03o`24oooonf[ooo]Z00oooo]Z00GoLol0oomi0?oonf[ooo]ZoolX0006ool000Co
obP01ooonfX01OooVP3ooo]ZoookJ_oonf[oo`0000?ooo]Z00?o001oool00?oo00000_oo0002o`00
O`06oookJ_oo06?oo`1SoookJ_l0of?ok@3o1_oonfX7oolX00Cooo]Z00?o/P3ooolX0?oo:0000ooo
:004oookJP03o`3o3?oonf[ooo]Z00Cooo]Z0_ooU0000ooonf[oo`0/oookJP02ool04`Sooo]Z00?o
0?oLo`d0oooo00001Ooo00001?n10?oooo]ZoookJ_oonfX2ool0S@;o001o00Coog/0oomG0?l007oo
001o4OoonfX00ooo2`3ooo]ZoookJP02oookJP_oobP00_l0o`H5oookJP;o0?o=2_oonfX00ooo003o
oo]ZoookJP04o`00O`;ooo]Z00?oM`3ooookJ_oonfX01ol007m3oookJP;oo`0g0_o70?l5oookJPOo
001o0_l0od/00ooco`3ooo]ZoookJP04oookJP;o0?m100?oo`1UoookJ_oonfX00ooonfX2oom200;o
fol000Cooo]Zo`3odooo3@3oo`d00_oonfX01?oo08Koo`2/ool0[?l0=_l2o`3odP03oookJ_oo0?Wo
o`3i00Sooo]Z0_oo2002o`26o`Gooo]Z0_l0oi<2onoo0003oe;o0?oonf[ooo]Z00;ooo]Z00?oo`1j
o`00Ool007l00_l007l01?oo04Woo`2kool0^ooonfX2oolI00;oU_l000Gooo]Zo`3[ool0jooo0>_o
o`3oS003oookJP;on@3o0_oonfX00oo_0?ooB?l0oookJP06oookJP;o0?mg0_oi0?l00om[0?oooo]Z
oookJP02oookJP?oE_l00ooonfX3ool0P`cooo]Z0omQ0?l2o`2Ao`?oobD000?o001ooookJ_oonfX0
0_lco`001?oonf[oo`1dool0M?oo07@7oookJP04o`0LoolB0?oo4P3ooa80o`;o0;;o00Gooo]Zool0
;_oo02koo`0^o`06o`04ool400Co0?l/6?oonfX01?l0003oo`@0odKo0?l00002oookJP03o`/0oooo
nf[o0?ln00Cooo]Z00Go>Ol0oookJ_oonf[ooo]Zool0g`04oookJP03o`24oooonf[ooo]Z00oooo]Z
0_oTo`03oookJP06ool0C_oonf[ooo]ZooT0oooonf[oAP3o2_oonfX00oooVP3ooo]ZoookJP06oook
JPOo001o00?ooo]Zool0Hooo06<00_l0of<7oookJP06ool0TOoonf[o0?nno`3o__oonf[oo`2L1Ooo
nfX01?nb0?oooo]ZoookJ_oonfX2oj;o00?ooo]Z00?o0?l<oookJ_oonfX01?oonfX2oonD0003oook
J_oo02coo`0/00;oo`0C2?oonfX00ol0omcooo]Zo`d0o`02oookJP03o`00Ool0nOoo0?Wo00;oP@3o
0ooonfX01Ooo08go001oo`00Ool007oooeL000;o001o4OoonfX2ool;00[ooo]Z00Coold0oookJ_oo
nf[ooo]Z0_l0o`H5oookJP;o0?o=2_oonfX01?oo003ooo]ZoookJ_oonfX4o`00O`;ooo]Z00?oM`3o
oookJ_oonfX01ol007lLoookJP00:_oonfX2o`00O`;oo`0g00Coa`3ooookJ_oonf[ooo]Z1ol007l3
oookJP;oobP000?olol0oookJ_oonfX01?oonfX2o`3o@@03ool0IOoonf[ooo]Z00;ooo]Z00?ood80
oookJ_oonfX00_oKo`02o`3od`04ool=0?oonf[ooo]ZoookJP;oo`2/0_l0=_l2o`3odP03oookJ_oo
0?Woo`3i00Oooo]Z0_oo20000ooonf[o08Koo`26o`04oookJP;o0?nC00CoooL0onoo0?o_o`3oD_l0
0ooonfX2ool0NP?o001o0_oo04T2ool0^`04oookJ_oo6@3ooaT0oiKo00;ooo]Z0_l0jol2o`3oS0;o
oo]Z0_oi0?l2oookJP03onl0oom8o`3oB?l000Kooo]Z2oooN@000omFo`3ooo]ZoookJP02oookJP?o
o`232?oonfX<oolX00Ooo`000_oob@08oookJP04o`0LoolB0?oo4P3oo`2bo`CoU?l03OoUo`04oomi
0003ooo90?ooN@3oogT000CoogT00ooonfX5oolX0003ool40?ooN@3oogT000?oogT00ooo:002oook
JP04ooo90?oo:03oobP0oolX00;ooo]Z0_oo:003oookJP03o`24oooonf[ooo]Z00;oogT03OoonfX0
0omco`3oi?l0oookJP08ool000?oobP02?oonfX00oooVP3ooo]ZoookJP02ool000;ooo]Z00?o001o
ool00?oo00000ooo00002?l007oooo]ZoookJ_oonf[oo`1SoookJ_l0of?ok@3o1ooonfX00ooo:03o
o`2AoolX0003oolX00Cooo]Z1_oo:0001?l0obCooo]ZoookJ_oonfX2o`3o30Kooo]Z00Oooi@0oook
J_oo02coo`0/oookJ_oo01?o07[o00Oooo]Z00Co0?oLo`d0ool=0?oooo]Z1?oo00000on10?oooo]Z
oookJP02oookJP04ool0SOl007oo001oo`00O`;ooeL04_oonfX2ool;00Cooo]Z2Ooo:002oookJP;o
0?l61OoonfX00ol0olgooo]ZoookJP08oookJP;oo`0000Cooo]Zo`00Ool007oo001o0ooonfX00omg
0?oooo]Zo`00O`06o`00OdCooo]Z00Co001oool0=ooo03Ooa`3o1?oonfX7o`00O`;ooo]Z0_l0od/0
0ooco`3ooo]ZoookJP04oookJP;o0?m100?oo`1UoookJ_oonfX00ooonfX01?oo@P3ooo]Zom_o0?oK
o`02o`3od`;oo`d00_oonfX01?oo08Koo`2/ool0[?l0=_l2o`3odP03oookJ_oo0?Woo`3i00Sooo]Z
0_oo2002o`26o`Gooo]Z00Go0?nCooog0?o_o`3okol0oe;o0003oookJP;oo`1j0ol007l01Ooonf[o
o`19ool0^ooo0;_ooo]Z00;ooaT00_nFo`02oookJP;o0>_o00Co0?n<oookJ_oonf[ooo]Z0_oi0?l2
oookJP;oB?l01ooonfX2o`3oM`;on@3o00?oJ`3oogSo0?oonfX00ooonfX2oeKo00Cooo]Z0ooo08<;
oookJP03o`00OomQ0?ooH@3o00;o097o00Co001ooolU0?oo9@3o0?l[0_oonfX3oc?o0003oookJ_oo
07Coo`1d00Sooo]Z00?o01cooa80oolB0?l00ol0/_l3oookJP;oo`0^00?o00Koool40?oo10000_oo
1003o`3o;1;ooo]Z00Oo0?l/oookJ_oonf[oo`@0o`000?m6o`3o000000;ooo]Z00Co2`3ooookJ_oo
nf[o0?ln0ooonfX01Olio`3ooo]ZoookJ_oonf[oo`3O00Gooo]Z00?o08CooookJ_oonfX03ooonfX0
0omco`3oi?l0oookJP02oookJP03ool0C_oonf[ooo]Z00;on@3o0_m60?l9oookJP03oonJ0?oonf[o
oo]Z00Gooo]Z1ol007l3oookJP03ool0Hooonf[o0?mS00Oooo]Z0_oo09401?l0og3o0?nnoookJ_oo
09`5oookJP;o/P3o0_oonfX00ol0obCoX_l0oookJP02oookJP;o0?l<1_oonfX01oooU03ooo]Zoook
J_oo02cooo]Zool04ol0N_l01ooonfX2o`3og0;o3@3o00Kooo]Zo`00Ool007oo0?WooookJ_n10?l3
oookJP;oo`2=0_l007l2oomG01?ooo]Z00?oo`/0oookJ_oonfX02?oonfX2ooo=00?ooo]Z0_l0o`H5
oookJP03o`3ocOoonf[ooo]Z00Sooo]Z0_oo0002oookJP?o001o0ooonfX00omg0?oooo]Zo`00O`06
o`00Oacooo]Z000ZoookJP;oo`3/0_oonfX00ooo03Ooa`3oolL0o`0<oookJPCoobP01_oonfX00ol0
od7oo`1Uool0I@03oookJP;ood800_oonfX01OoKo`3ooo]Zo`3odol0om?oo`d000?ooo]Z0_oo0:`0
0ol0=_oooo]Zo`3odP02oookJP;oo`3i1ooonfX2ool80003oookJ_l0Q_oo08Ko00Cooo]Z0_l0oi<0
0ooom`3okol0onoo0004oookJP;oo`1j0ooonfX2ool0B@03ool0^ooonf[ooo]Z00;ooaT00_oo:000
0ooonf[o0>_oo`3[o`02o`3oS0;ooo]Z0_oi0?l2oookJP03onl0oom8o`3oB?l000Gooo]Z2OooN@02
oookJP?oE_l01?oonfX3oolX00Kooo]Z2_oo:008ool00004oc?o0?oob@3oo`1dool0M0Sooo]Z0ol0
7?l00olB0?ooU?l0oiCo0002oiCo00[oiOl00_oo100:oomi00;ooo]Z1Ooo:0000ooo103oogT0oomi
0002oomi00KoobP00ooob@02oolX00?ooo]Z00?oobP0oookJ_oonfX00_oonfX2o`24o`?oogT03Ooo
nfX00omco`3oo`00ool00008ool000?oobP02?oonfX00oooVP3oo`00ool00002ool00003oookJ_oo
003oo`0000Goo`001?oonfX01Ooo06?ooo]Zo`3oHol0of?ok@3o00Cooo]Z0ooo:0000ooo097oobP0
oolX0002oolX00Cooo]Z1_oo:0000ol0obCooo]ZoookJP02oookJP03o`3o3?oonf[ooo]Z00Cooo]Z
0_ooU0001Ooonf[oo`0/oookJ_oo01?o07[o00Sooo]Z00Co0?oLo`d0oooonf[ooo]Z0ooo0002oolX
00?ooo]Z0_oo08d00ooonf[oobP0oomk0002oomG01;ooo]Z00?oo`/0oookJ_oonfX01?oonfX7oolX
00?ooo]Z00?o0?l6oookJ_oonfX00ooonfX00ol0olgooo]ZoookJP09oookJP03ool00?oonf[ooo]Z
053ooo]Z0_oo0>`2oookJP03ool0=oo70?ooa`3o00gooo]Z00?o0?m;oo?o0?oco`001_oonfX00ol0
od7oo`1Uool0I@04oookJP;ood8000?ooo]Zom_o0?oonfX00_l0om<2ool=00;ooo]Z00Coo`26ool0
[?oo0:co03Ko0_l0om800ooonf[oo`3iool0n@08oookJP;oo`P00_l0Q_l4oookJP;o0?nC00?oooL0
onoo0?o_o`001?oonfX2ool0NPCooo]Z00Coo`19ool0^ooo0;_ooo]Z0_oo6@02oiKo00;ooo]Z0_l0
jol01?l0ohcooo]ZoookJ_oonfX2ooT0o`;ooo]Z0_m8o`08oookJP05o`3oMooi0?oon@3oof/0oomh
o`001?oonfX2oeKo00Gooo]Z0_oo08<<oookJP;oH@3o0_l0TOl01?oonf[oobD0o`3o:ol0ob/3oook
JP;o<ol000?ooo]Zool0M?oo07@02?oonfX3o`0Lo`03oa80ool0/_oo0;;o00;o0;;o0_oonfX2ool0
;P03oookJ_l01_ooo`@000Koo`@00_l0ob`:oookJP;o0?l/0ooonfX01?oo103oA_l0o`000?l00003
oookJP03o`/0oooonf[o0?ln00Cooo]Z00Go>Ol0oookJ_oonf[ooo]Zool0g`05oookJP03o`24oooo
nf[ooo]Z00oooo]Z00?oLol0onCo0?oonfX00_oonfX01ooo04kooo]ZoookJ_oonf[on@3ooookJ_m6
0?l02OoonfX00oooVP3ooo]ZoookJP0?oookJP04ool0Hooonf[o0?mSo`3oH`Oooo]Z00Goo`2Aoook
J_l0okko0?nnool0W006oookJP05ok80oooonf[ooo]ZoookJ_nRo`001?oonfX00ol0o`cooo]Zoook
JP04oookJP;ooi@000Gooo]Zool0;?oo02coo`0Co`1jo`08oookJP03o`3og?oonf[o3@3o00?ooo]Z
00Co0?WooookJ_n10?ooP@3o0ooonfX01?oo08gooo]ZoookJ_oonfX2oomG01;ooo]Z0_oo2`0:oook
JP03ooo=0?oonf[ooo]Z00;ooo]Z00?o0?l6oookJ_oonfX00ooonfX00ol0olgooo]ZoookJP09oook
JP;oo`00:ooonfX002cooo]Z0_oo0>`00ooonf[oo`0gool0=`02olL0o`_ooo]Z1_oo:004oookJP;o
0?m100?oo`1UoookJ_oonfX00_oonfX2oom20005oookJ_oKo`3ofol0oookJ_l0om<00_oo3@02oook
JP04ool0Q_oo0:coo`2/o`0fo`;o0?oB0_oonfX00ooo0?Wooo]ZoookJP06oookJP;oo`P000?ooo]Z
o`26ool0Q_l01?oonfX2o`3oT`04ooog0?oo003oo`00ool000?ooo]Z0_oo07X3oookJP03ool0BOoo
0;_oo`2k00;ooo]Z0_oo6@04oolX0003o`3[ool0ohcooo]Z00;ooo]Z0_oi0?l2oookJP04onl0oooo
:03oobP0oolX00?ooo]Z2?ooN@000omho`3ooo]ZoookJP02oookJP;oE_l01?oonfX5oolX00Cooo]Z
2?oo:007ool000GoogT00_oo07@9oookJP;o01co00Gon@3ooiCo0?nDo`3oU?l0o`2bo`08onGo0003
oomi0?l01_ooo`@000Coo`@01OooN@000ol0obcoobP0oolX0002oolX013oolT000?ooo]ZoolX0?oo
nfX00ooonfX00ooo:03ooo]ZoookJP02oookJPGoogT03_oonfX00ooTo`3oo`00ool00007ool000?o
obP01ooonfX00ooo003ooiX0oonJ000;ool000Cooo]Z00Goo`1SoookJ_oonf[o0?mSond0o`02oook
JPGoobP000?oo`2AoolX0?oo:0000_oo:002oookJPSoobP000?oX_l0o`3o9?oonfX00_oonfX00ol0
o`cooo]ZoookJP05oookJP04oonD0?oonf[oo`0/oookJP;oo`0C00?o07[ooookJ_oonfX01OoonfX0
0ol0omco3@3oo`d0o`03oookJP04ool00?l0nOooobP0oolX00?ooo]Z00Koo`2=oolX0?oo:03ooo]Z
oomk0?ooE`0BoookJP;oo`/01_oonfX6oolX00?ooo]Z0_l0o`H4oookJP;o0?o=2_oonfX2ool005;o
oo]Z0_oo0>`00ooonf[oo`0gool0=`02olL0o`cooo]Z0_l0od/2oo?o00Gooo]Z0_l0od42ool0I@Co
oo]Z0_oo@P02om_o0003oookJ_l0om?o0?oC00;oo`d00_oonfX01?oo08Koo`2/ool0[?l0=_l2o`3o
dP03oookJ_oo0?Wooo]Z00Sooo]Z0_oo2002o`26o`Cooo]Z0_l0oi<00ooom`3okol0onoo0004oook
JP;oo`1j1?oonfX01?oo04Woo`2kool0^ooonfX2oolI00;oU_l00_oonfX00ol0jooo0?n<o`3oS003
oookJP;on@3o0_oonfX2odSo00Sooo]Z00Go0?mgooT0oooi0?ooJ`3oogSo0004oookJP;oE_l01Ooo
nfX2ool0P`cooo]Z0_mQ0?l2o`2Ao`;ooo]Z0_l0ob/3oookJP;o<ol000?ooo]Zool0M?oo07@02Ooo
nfX2o`0Lo`03ooT0oolB0?oo4P3o00Co0;;o0ooo02h5oookJP03o`06oooo103oo`@000;oo`@02?l0
ob`4oookJP03ool40?l0003oA_l000;o00000ooonfX01?l;0?oooo]ZoookJ_l0och3oookJP03ocWo
0?oonf[ooo]Z00;ooo]Z00?oo`3OoookJ_oonfX00ooonfX00ol0Q?oooo]ZoookJP0@oookJP06onCo
0?oonf[ooo]ZoookJ_oo04kooo]Z0_l0ogd01?oi0?oooo]ZodH0oom60?l8oookJP;ooiX04?oonfX0
1?oo06?ooo]ZoookJ_l0of<7oookJP;oo`2A00?o0?m`o`3o__oo09`01_oonfX2ok80o`;ooo]Z0_nR
o`03oookJP03o`3o3?oonf[ooo]Z00Gooo]Z00Cooi@0oookJ_oonf[oo`0/0_oo01<00ol0N_oooo]Z
oookJP05oookJP;o0?oL0_l=0?l2oookJP;o0?Wo00?ooo]Zoh40oooonfX00_oonfX2ool0S@;ooo]Z
00?oog/0oomG0?oonfX04_oonfX00ooo2`3ooo]ZoookJP08oookJP;oold00ooonfX2o`3o1PCooo]Z
0_l0old;oookJP03ool00?oonf[ooo]Z02Sooo]Z000ZoookJP;o0?li0_oonfX2ool0k004oookJ_oo
03Ooo`0golL0o`_ooo]Z2?oo:003oookJP;o0?m100?oo`1UoookJ_oonfX00_oonfX00ooo@P3ooo]Z
oookJP02om_o00;o0?oC0_oo3@02oookJP04ool0Q_oo0:coo`2/o`0fo`;o0?oB00?ooo]Zool0nOoo
0?T02?oonfX3oolX00;o08Ko1?oonfX2o`3oT`03ooog0?oo003oo`0000?oo`0000?ooo]Zool0N_oo
07X00_oonfX2ool0B@;oo`2k0_oonfX00ooo6@3oobP0oolX0004oolX0004o`3oS?oonf[ooo]Zoook
JP;on@3o00?ooo]Zonl0ooo_0?l01Ooo:006oomi00;on@3o0_mho`04oookJP03oeKo0?oonf[ooo]Z
00;ooo]Z1ooo:002oookJPKoobP00_mQ0?l6ool000WoogT02OoonfX2o`0Lo`05ooT0oonDo`3o4P3o
oolX0?l0/_l01_oUo`02ool000;oogT00_l01_l00ooUo`3oo`@0ool4000Hooo900;ooo]Z00CoobP0
oookJ_oonf[ooo]Z0_oo0003oookJPKoogT03_oonfX2onCo0003oookJ_oo003oo`0000Goo`000ooo
:006oookJP?oo`0000?ooiX0ool00?oo00002Ooo0004oookJP;oo`1S00Cooo]Zo`3oHol0of?ok@3o
0_oonfX4oolX00;oo`2A0ooo:0000ooo09coobP0oolX0005oolX0004ool00?oo:03oX_l0o`3o90?o
oo]Z0_l0o``6oookJP;ooi@00_oo02`00ooonf[oo`0Co`1jo`08oookJP03o`3og?l=0?oo3@3o00?o
oo]Z00?o0?WooookJ_oo:0000_oonfX01_oo:03oo`2=oolX0?oo:03ooo]Zoomk00;ooeL04_oonfX0
0ooo2`3ooo]ZoookJP06oookJPCoobP01?oonfX00ol0o`Kooo]ZoookJP03oookJP03o`3ocOoonf[o
oo]Z00Wooo]Z00?oo`00oookJ_oonfX0COoonfX2o`3o>@;ooo]Z0_oo0>`01?oonf[oo`0gool0=oo7
0?l=oookJP;o0?m;0_oco`05oookJP;o0?m10_oo06D4oookJP05oom20?oonf[ofol0om_o0?oonfX0
0_l0om<2ool=0003oookJ_oo08Koo`2600;oo`2/00?ooo]Zo`3od_oonfX00_oo0?T9oookJP;oo`P0
0_l0Q_l4oookJP;o0?nC00?oooL0onoo0?o_o`001?oonfX2ool0NP?ooo]Z0_oo04T2ool0^`04oook
J_oo6@3ooaT0oiKo00;ooo]Z0_l0jol00ol0ohcooo]ZoookJP02oookJP;on@3o00Cooo]Zonl0oom8
o`3oB?l02?oonfX01Ol0ogOon@3oooT0oom[0?ooN?l000Cooo]Z0_mFo`05oookJP;oo`233?oonfX2
of40o`;o097o0_oonfX00ol0ob_ooo]ZoookJP02oookJP;o<ol000?ooo]Zool0M?oo07@02OoonfX3
o`0Lo`;o4P3o0_oonfX3o`2bo`03ool0;_oonf[ooo]Z00Cooo]Z0ol01_l4ool400Kooo]Z0ooo1002
odKo00;o00001?oonfX00ol;0?oooo]Zo`3o?P04oookJP;o>Ol00ooonfX00ooo0=oooo]ZoookJP03
oookJP03o`24oooonf[ooo]Z013ooo]Z0_oTo`02oookJP;oo`1>00?ooo]Zo`3oOOl0ogd00_oonfX0
0om60?oooo]ZoookJP07oookJP03oonJ0?oonf[ooo]Z00Cooo]Z0_mAo`08oookJP;oo`1S00?ooo]Z
o`3oHol0of<01ooonfX01Ooo097o0?m`o`3o__l0okkoo`2L00Kooo]Z0_nb0?l2oookJP04oj;o0?oo
nf[ooo]ZoookJP;o0?l<1_oonfX2oonD0005oookJ_oo02coo`0/ool04ol0N_l02?oonfX01?l0omco
oo]Zo`d0ool=0?l2oookJP;o0?Wo0_n10?l3oookJP04ool0SOoonf[ooo]ZoookJP;ooeL04_oonfX0
0ooo2`3ooo]ZoookJP09oookJP03ooo=0?oonf[ooo]Z00;ooo]Z00?o0?l6oookJ_oonfX00ooonfX2
o`3oc@[ooo]Z0_oo000XoookJP00:_oonfX2oah0o`;o0?li0_oonfX2ool0k004oookJ_oo03Ooa`3o
olL0o`[ooo]Z2_oo:002oookJP;o0?m100Coo`1UoookJ_oonf[ooo]Z0_oo@P02oookJP;ofol00_l0
om<02?oo3@3ooo]ZoookJ_oonf[oo`26ool0[?l0=_oooo]Z0_l0om800ooonf[oo`3iool0n@07oook
JPCoobP000?o08KooookJ_oonfX00ooonfX00ol0oi?oooL0ool00006ool00004ool0N_oonf[ooo]Z
oookJP;oo`190_oo0;/00ooonf[ooaT0oolI0008oolX00;ooo]Z0_oi0?l00ooonf[ok`3ooolX0004
oolX00CoogT000?ooo]Zo`3oMol0ogL00_oi0?l00ooo:03ooo]ZoookJP02oookJP;oE_l00ooonfX>
oolX00;ooo]Z1_oo000<oomi00Sooo]Z0oooN@02oa80o`03oolX0?nDo`3oiOl000;oiOl01?oo:000
0ooo003oogT0oomi0002oomi00;oiOl06?oob@02oookJP03ocWo0?oonf[ooo]Z00?oo`0000?ooo]Z
oomi0?ooN@001_ooN@0>oookJP03og?o0?oTo`3ooo]Z00;ooo]Z1Ooo0003oolX00Cooo]Z1Ooo0002
oonJ00[oo`001OoonfX2ool0H`03oookJ_l0of?o0?mS00Cooo]Z0ooo:0001Ooo097oobP0oolX0?oo
:03oo`2L00KoobP00_oo00001?oo:03oX_l0oj;o0?l0ob@3oookJP03o`3o3?oonf[ooo]Z00Gooo]Z
00Cooi@0oookJ_oo02cooo]Z0_oo01<00ol0N_oooo]ZoookJP05oookJP;o0?oL00Co3@3ooookJ_oo
nf[ooo]Z0_l0nOl4oolX00;oo`2=00GoobP0oookJ_oonf[oog/0oomG000BoookJP;oo`/02?oonfX3
oolX00Cooo]Z0_l0o`H4oookJP;o0?o=2_oonfX2ool004gooo]Z0_lN0?l2o`3o>@;ooo]Z0_oo0>`0
1?oonf[oo`0golL0ooo70?l=oookJP04o`3oBooonf[olol0oo?o00Gooo]Z0_l0od42ool0I@?ooo]Z
0_oo@P001?oonf[ofol0om_o0?oonfX2o`3od`03ool=0?oonf[ooo]Z00;oo`2600Goo`2/o`0fool0
om;o0?oBoookJP02ool0n@Wooo]Z00?oo`P0oookJ_l0Q_l01OoonfX01Ol0oi?oooL0ooog0?o_o`3o
D_l000Cooo]Z00?oo`1joookJ_oonfX00_oonfX2ool0B@;oo`2k00Cooo]ZoolI0?oo6@3oU_l00_oo
nfX2o`3[o`03o`3oS?oonf[ooo]Z00;ooo]Z0_oi0?l00ooonf[ok`3oodSo0009oookJP04o`3oMooi
0?oon@3oof/0o`Gooo]Z00?oE_l0oookJ_oonfX01?oonfX00ooo08?ooo]ZoookJP0;oookJP;oH@3o
0_l0TOl00ooonf[o0?l[o`3o:`04oookJP;o<ol000?ooo]Zool0M?oo07@02_oonfX2o`0Lo`;o4P3o
0ooonfX00ol0/_oooo]ZoookJP08oookJP?o00Ko1ooo10000ooonf[oA_l0odKo0003o`0000Cooo]Z
00?o2`3ooookJ_l0och01_oonfX01?lio`3ooo]ZoookJ_oonfX2ool0g`Cooo]Z00?o08CooookJ_oo
nfX04?oonfX00omco`3oi?l0oookJP02oookJP04ool0C_oonf[ooo]Zo`3oO@;ooo]Z00?oAP3ooook
J_oonfX01ooonfX2oonJ00Kooo]Z0_mAo`08oookJP;oo`1S00?ooo]Zo`3oHoo]0?l01_oonfX2ool0
T@03o`3oL?l0okkoo`2L00Oooo]Z00?o/P3ooookJ_oonfX00_nRo`03oookJP;o0?l<1_oonfX01?oo
U03ooo]ZoookJ_oo02`2ool04`03o`1joooonf[ooo]Z00Gooo]Z0_l0om`00ooonf[o3@3ooookJP02
oookJP04o`3ioooonf[oP@3ooh40o`;ooo]Z0_oo08d2oookJP03oomk0?ooE`3ooo]Z017ooo]Z0_oo
2`0:oookJP03ooo=0?oonf[ooo]Z00;ooo]Z0_l0o`H5oookJP03o`3ocOoonf[ooo]Z00Wooo]Z0_oo
000VoookJP00;?oonfX00olN0?oooo]Zo`3o>@03oookJP04ool0k?oonf[oo`0gool0=`;oa`3o2Ooo
nfX:oolX00?ooo]Z00?o0?m1ool0IOoo06D00ooonfX2oom200;ooo]Z00Gofol0oookJ_l0om?o0?oC
ool=0002oookJP05ool0Q_oo0:coo`2/o`0foooonfX00_l0om800ooonf[oo`3iool0n@06oookJPCo
obP00_l0Q_l01?oo:03ooo]ZoookJ_oonfX2o`3oT`[oo`000_oonfX00ooo04Wooo]Zool00002ool0
00;ooaT02?oo:002oookJP;on@3o00?ooo]ZoolX0?oo:0000ooo:003oomi00;oobP000Cooo]Zo`3o
Mooo:03on@3o1?oo:002oookJP04oeKo0?oonf[ooo]ZoookJPgoobP01?oonfX5ool000ooogT01_oo
nfX3oomi00CoobP000?oiOl0oolX0?oo:0001ooo:002oomi00?oiOl04?oob@000ooUo`3oolT0ooo9
0002ooo900?ooo]Z00?o>Ol0onGo0?oo00001?oo0009oomi00gooo]Z00?oLol0onCo0?oTo`000_oo
nfX2ool0CP?oo`0000Con@3ooookJ_oo:03oAP3o0_oo:007ool000;ooiX02Ooo0006oookJP;oo`1S
00?ooo]Zo`3oHooonfX01OoonfX00ooo:03oo`2Aool0T@02oolX00;oo`2L00?ooo]ZoolX0?oo:000
1?oo00001?oo:03ooo]Zoj;o0?l0ob@3oookJP;o0?l<1_oonfX2oonD00;oo`0/00?ooo]Zool04ooo
01<02?oonfX00ol0omco3@3oo`d0o`03oookJP;o0?Wo1?oo:0001Ooo08goobP0oookJ_oonf[oog/0
00;ooeL04_oonfX00ooo2`3ooo]ZoookJP08oookJP03oolX0?ooc@3ooo]Z00?ooo]Z00?o0?l6oook
J_oonfX00ooonfX2o`3oc@[ooo]Z00?oo`00oookJ_oonfX0C?oonfX2oah0o`05o`3o>Ooonf[ooo]Z
oookJ_oo0>`00_oonfX00ooo03Ooa`3oolL0o`0<oookJP;o0?m;00?ooo]Zoo?o0?oco`001OoonfX0
0ol0od7ooo]Zool0I@04oookJP;ood8000Gooo]Zom_o0?oonf[ooo]Zo`3od`02ool=00;ooo]Z00Co
o`26ool0[?oo0:cooo]Z0_l0om800ooonf[oo`3iool0n@08oookJP;oo`P00_l0Q_l4oookJP;o0?nC
00CoooL0onoo0?o_o`3oD_l00ooonfX2ool0NPCooo]Z00Koo`19oookJ_oo0;_oo`2koookJ_oo6@02
oiKo00;ooo]Z00?o0>_oo`3oS?l0oh`01?oonfX00ooi0?oooo]ZoookJP02odSo00Wooo]Z00Co0?mg
ooT0oom[0?ooJ`3o1?oonfX2oeKo00Gooo]Z0_oo08<=oookJP;oH@3o0ol0TOl2o`3o:`Cooo]Z0_lc
o`001?oonf[oo`1dool0M?oo07@9oookJP;o01co0olB0?l01?oonf[o0;;oo`2bool0/_l;oookJP?o
00Ko1Om6o`04o`0000Gooo]Z00Co2`3ooookJ_l0ocko0?ln1OoonfX00olio`3ooo]ZoookJP02oook
JP03ool0gooonf[ooo]Z00;ooo]Z00?o08CooookJ_oonfX04?oonfX00omco`3oi?l0oookJP02oook
JP;oo`1>00Cooo]Zo`3oOOl0oggooo]Z0_m60?l9oookJP;ooiX01_oonfX2oe7o00Sooo]Z00Coo`1S
oookJ_l0of?ok@3o1ooonfX01Ooo097o0?m`o`3o__l0okkoo`2L00Kooo]Z0_nb0?l2oookJP03oj;o
0?l0obCooo]Z00;ooo]Z00?o0?l<oookJ_oonfX01?oonfX2oonD0003oookJ_oo02coo`0/00;oo`0C
2?oonfX2o`3og0;o3@3o0_oonfX2o`3io`03oookJ_n10?oooo]Z00;ooo]Z00Coo`2=oookJ_oonf[o
oo]Z0_ooE`0BoookJP03ool;0?oonf[ooo]Z00Sooo]Z0_ooc@04oookJP03o`3o1_oonf[ooo]Z00?o
oo]Z0_l0old;oookJP03ool00?oonf[ooo]Z02?ooo]Z000XoookJPGo00000_lN0?l2o`3o>@;o0000
0_oo0>`01?l0003oo`0gool0=oo70?l9o`0000WoobP01?l00002o`3o@@;oo`1U0ol000000ooo@P3o
0000o`000002om_o0004o`000?l0om?oo`d0ool=00;o000000Goo`26ool0[?oo0:co03Koo`000002
o`3odP03o`000?oo0?Wo000000Go00001Ooo:002o`26o`;oobP00_l000000ol0oi?oo`00ool00009
ool00003o`000?oo04Woo`1900Coo`000_oo6@06oolX00Co00000_oi0?l5oolX0003oomi0?oo:03o
obP000?oobP000Co0000oolX0?oi0?oon@3o1Ooo:002oeKo00;o00002ooo:006o`0000Ooo`003_oo
N@05o`0000CoogT03_oo:0000oooN@3oiOl0onGo0002onGo00koolT00ooUo`02ooo900;oiOl000?o
0000onGo0?oo00001_oo00000ooo0=ooogT0oomi0006oomi00ko000000?oLol0onCo0?l000000_l0
00001ooo04ko0000o`000?oo003o0?mmooT0ool000000ooo:0000ol0003oo`00ool00005ool00003
oonJ0?oo003o000000Ooo`001ol000001?oo06?o0000o`3oHol0of<2o`0000;oogT00ol000001?oo
097oobP0oolX0?l00002ool0W0Koo`0000CoobP0o`000?nRo`3oX_l01?l000000ol0o`co0000o`00
0005o`000007oonD0?l0003oo`0/ool0;?l0003oo`0Co`1jo`08o`000004o`3og?l=0?oo0000o`00
00;oobP000?o0?WooolX0?oo:0000_oo:002ool0S@?o000000?oog/0oomG0?l000004Ol00002ool;
00[o00000_ooc@03o`0000;o0?l61Ol000000ol0olgo0000o`000008o`000003ool00?l0003ooo]Z
04Oooo]Z1_l00002oah0o`03o`3o>Ol0003o000000;oo`3/0_l000000ooo03Ooa`3oo`00000<o`00
00;o0?m;00?o0000oo?o0?l000001?l00002o`3o@@;oo`1U1?l000001Ooo@P3o0000om_o0?oKo`3o
000000;o0?oC0_oo3@001_l0003oo`26ool0Q_oo0:co03Koo`0000;o0?oB00?o0000ool0nOl00000
2?l00002ool800;o08Ko1?l00002o`3oT`04ooog0?o_o`3okol0oe;o00?o00000_oo07X3o`0000;o
o`1900?o0000ool0^ol000000_oo6@02oiKo0003o`000?l0jooo0>_o00;o0?n<0ol00002ooT0o`;o
00000_m8o`08o`000005o`3oMooi0?oon@3oof/0oomho`001?l00002oeKo00Go00000_oo08<=o`00
0003of40ool0003o000000;o097o0_l0ob/4o`000004oc?o0?l0003o0000o`0000;oo`1d2Ol00002
o`0Lo`03ooT0oolB0?oo4P3o00;o000000?o0;;oo`000?l000002ol00003o`06o`co000000Co2`3o
o`000?l0003o0?ln1Ol00002ocWo00?o00000_oo0=l3o`0000;o08Co4_l000000ooTo`3oLol0o`00
0002o`000003ool0C_l0003o000000;o0?mm00?o0000odH0oom60?l02?l000000on40?oooiX0o`00
0006o`0000;oDOl01ol00002ool0H`;o0?mS00?ok@3oo`000?l000001?l00002ool0T@04o`3oL?l0
okkoo`2Lool0W0;ooed01?l00002ok80o`03o`000?nRo`3oX_l000?o00000_l0o``6o`000003oonD
0?l0003o000000;oo`0/00?oo`0Co`1jool000001ol000000ol0omco0000o`d0o`03o`0000;o0?Wo
0_n10?l2o`0000;oo`2=0_l000000oooN`3ooeL0o`00000Ao`0000;oo`/02_l00002ooo=00?o0000
0_l0o`H5o`0000;o0?o=2_l000000ooo003o0000oookJP0RoookJP00:?oonfX7o`0000;o7P3o0_l0
ocT2o`0000;oo`3/00Co0000ool0=oo70?ooa`3o2?l00007oolX0003oo?o0?l0003o000000Co0000
00Co0?m1o`000?oo06Goo`1U0_l00002oom200;o00000_oKo`02o`3od`03ool=0?l0003o000000;o
o`2600Koo`2/o`0fool0003o0000o`3od_l00002ool0n@Go00001_oo:0000ol0Q_ooobP0oolX0003
oolX00[oo`000ol000000ooo04Woo`00ool00003ool00003oolI0?oo003oobP000;oobP000?o0>_o
o`3oS?l0oh`01?l000000ooi0?ooobP0oolX0008oolX00;o00000_oo:002ooT0o`OoobP000?o0000
oolX0?oo:0001_oo:009o`0000[oo`002_ooN@06o`0000CoogT03Ooo:003oomi00CoiOl03?oob@04
onGo00;o0?ln0ooUo`09ool00003ool0gooo:03oobP000GoogT03ol00002onCo00;o00000_oo04h2
o`000003o`3oOOoo:03oobP000?oobP00ol00005ool000;ooiX00ol00005ool000Oo00000_oo06<0
0ol0003o0?mSo`000003oomi00?o000000Goo`2Ao`000?oo:03o0?nno`000007ool00003oolX0?l0
003o000000;oX_l00ol00002o`3o30Ko00000_ooU0000ol0003oo`0/o`000002ool04`03o`1jool0
003o000000Go000000?o0?oLo`d0ool=0?l00ooo:002o`3io`CoobP00_oo08d3o`0000;ooeL04_l0
0002ool;00[o000000?oold0o`000?l000000_l000000ol0o`Ko0000o`000003o`0000;o0?o=2_l0
0018oookJPSo000000?o7P3oo`3o>Ol0ocT00_l00002ool0k004o`000?oo03Ooa`3oolL0o`go0000
00Co0?m;o`000?oco`3olol01Ol00002o`3o@@;oo`1U0ol00002oom20004o`000?oKo`3ofol0o`00
00;o0?oC00Coo`d0o`000?l0003oo`260_oo0:`2o`000004o`3od_l0003oo`3iool0n@Wo000000?o
o`P0o`000?l0Q_l01Ol00002o`3oT`03ooog0?o_o`3okol000Co000000?oo`1jo`000?l000000_l0
0002ool0B@;oo`2k00Co0000oolI0?oo6@3oU_l00_l00002o`3[o`03o`3oS?l0003o000000;o0000
0_oi0?l00ol0003ok`3oodSo0009o`000005o`3oMooi0?oon@3oof/0oomho`001?l000000omFo`3o
0000o`000004o`000003ool0Pol0003o000000_o00000_mQ0?l2o`0000;o097o0_l0ob/3o`000003
oc?o0?l0003o000000;o00000_oo07@9o`000004o`0Lool0003on@3ooa80o`;o000000?o0;;oo`00
0?l000003Ol00002o`06o`_o00000_l;0?l00ol0003o0?lno`000005o`000003ocWo0?l0003o0000
00;o00000_oo0=l3o`0000;o08Co4Ol00002onCo0003og?o0?l0003o000000;oo`1>0_l00002o`3o
O@03o`000?m60?oo000000So00000_ooVP07o`0000;oDOl01ol00002ool0H`03o`3oHoo]0?oo0000
00Ko000000Koo`2Ao`3oL?l0okko0?nnool0W?l00002oomM00Co000000?o/P3oo`000?l000000_nR
o`03o`0000;o0?l<1Ol00002oonD00;o000000Coo`0/ool04ooo01?o07[o1ol00002o`3og0;o3@3o
0ol00002o`3io`;oP@3o0_l00002ool0S@;o00000_ooE`0Bo`0000;oo`/02_l000000oooc@3o0000
o`000002o`000003o`3o1_l0003o000000Co00000_l0old:o`0002?ooo]Z000XoookJPWo000000?o
7P3oo`000?l0ocT00ol000001?oo0>co0000oonD0?oo03L2olL0o`Oo00001_oo:0000ol0003olol0
oo?o0005o`0000;o0?m100?o0000ool0IOoo06D00_l000001?oo@P3o0000o`000?l00002om_o00?o
obP00_l000001Ooo08Koo`2/ool0[?l0=_oo000000;o0?oB00?o0000ool0nOl000001?l00006oolX
00;o08Ko1?oo:008ool00003oolX0?oo07[oo`1j00?o00001Ooo0002oolI00?oo`000_l0jol00ol0
ohco0000o`000002o`0000;on@3o2?oo:003o`0000?oobP00_oi0?l>oolX00[o00002ooo0007oomi
0003o`000?oo07Co000000Go00001?ooN@0;oolX0003ool00?ooN@3oogT000;oogT000?oolT0onGo
0?oUo`000_oUo`0>ooo900;oiOl000?o0?lnonGo0?oUo`002_oo0003oolX00GoogT04?l000001?oT
o`3oLol0o`000?l00002ool0CP03o`000?oo:03oobP000GoobP01?l00004ool000;ooiX01Ol00002
ool00003oe7o0?l0003o000000Go00000_oo06<2o`3oH`?oogT00ol00002ool0T@03o`3oL?l0okko
0?nn00Ooo`0000GoobP0ok80ool0003o0000oj;o0004o`0000;o0?l<1_l00002oonD00;oo`0/00Co
0000ool04ol0N_oo07[o1ol000000ol0omco3@3ooolX0003oolX00;o0?Wo1?oo:002ool0S@;o0000
00?oobP0oomG0?ooE`004_l000000ooo2`3o0000o`000008o`0000;oold00ol00002o`3o1PGo0000
0_l0old8o`0004Sooo]Z2Ol00002oah0o`05o`3o>Ol0003o0000o`000?oo0>`00_l000000ooo03Oo
a`3oolL0o`0<o`0000;o0?m;00?o0000oo?o0?oco`001Ol000001?l0od7o0000ool0IOoo06D3o`00
0003oom20?l0003o000000;ofol000Co0000o`3odol0om?oo`d00_l000001?oo08Koo`2/o`0fool0
0002o`3odP03o`000?oo0?Woo`3i00So00000_oo2002o`26o`Go00000_l0oi<00ooom`3okol0onoo
0003o`0000;oo`1j1?l000001Ooo04Wo0000ool0^ooo0;_o000000;ooaT000CoU_l0o`000?l0003o
0>_o0_l0oh`4o`000003ooT0ool0003o000000;oB?l02Ol000001?l0ogOon@3oooT0oom[0?l4o`00
00;oE_l01Ol000000ooo08?o0000o`00000<o`000006of40ool0003o0000o`000?l0TOoo00000_l0
ob/2o`000003oc?o0?l0003o000000?o000000?oo`1do`000?l000001ol00002o`0Lo`05ooT0oolB
0?oo4P3oo`000?l0/_l04?l000001?l01_oo0000o`000?l00003ool0?@Ko000000?o2`3oo`000?l0
och00ol0och3o`000003ocWo0?l0003o000000?o00000_oo0=l3o`0000;o08Co4Ol00002onCo0003
og?o0?l0003o000000;oo`1>00Co0000ooT0ool0oggo00000_m60?l8o`000003oh@0ooooVP3ooiX0
00Oo00000_mAo`07o`000004ool0Hol0of?o0?mSond0o`Ko00000_oo09401_l0og3o0?nno`3o__oo
09co0000oomM00Co00000_nb0?l2o`000003oj;o0?l0003o000000;o000000?o0?l<o`000?l00000
1?l00002oonD0004o`000?oo02coo`0/ool04`;o07[o1ol000000ol0omco0000o`d0o`04o`000003
o`3iool0003oP@3o00?o00000_oo08d01?l0003oog/0oomG0?ooE`0Bo`0000;oo`/02Ol00002ooo=
00?o00000_l0o`H6o`000003o`3ocOl0003o000000Oo00008ooonfX002Sooo]Z2_l00002oah0o`;o
0?li0_l00002ool0k003o`000?oo03Ooo`0g00;oa`3o1_l00004oolX0004o`000?oo:03oobP0o`00
00;olol01Ol000001?l0od7o0000o`000?oo06D2o`0000;ood800ol00006oolX00;oo`2600Koo`2/
o`0fool0=_oo0000o`3od_l00002ool0n@Co00001ooo:002o`26o`03oolX0?l0003oobP000Koo`00
1?oo:0001?oo07[o0000o`000?l00006ool000;ooaT00ooo0002o`3[o`;oobP00ol00002ooT0o`Wo
obP000?o0000oolX0?oo:0000_oo:0000ooi0?ooobP0oolX0004oolX0003oeKo0?oo:03oobP000?o
obP00_oo08<:o`0000[oo`001_ooN@03o`000003ool0M?l0003o000000Co00001?ooN@0:oolX00Go
o`000ooob@04onGo00coolT01?oUo`0:ool000KoobP01?ooN@0@o`0000;oi?l000?oLol0o`000?l0
00002Ooo:006o`0000?oo`000_ooVP06o`0000;oDOl01_l00003oomi00;o0?mS0_ooN@04o`0000;o
o`2A00?o0?m`o`3o__l0okh01_oo00001?l0003o/P3ook80ool00002oj;o00;o00000_oo00000ol0
o`co0000o`000005o`000004oonD0?l0003oo`0/o`0000;oo`0C00?o07[oo`000?l000001Ol00000
0ol0omco3@3oo`d0o`04oolX0003o`3ioooo:03oobP000;oobP000?o0000ool0SOoo08d00_l00000
0ooo:03ooeL0o`000005o`000003oolX0?l0003o000000Wo00000_oo2`0:o`0000;oold00ol00002
o`3o1PGo000000?o0?o=o`000?l000001Ol00018oookJP_o00000_lN0?l00ol0ocWo0000o`000002
ool0k003o`000?ooU03oo`0g00;oa`3o3?l00002o`3oB`03o`000?oco`3olol000Co00000_l0od40
0ol0003oo`1Uo`000002o`0000;ood800_l000001OoKo`3o0000o`000?l0om?oo`d000;o000000Go
o`26ool0[?oo0:co03Koo`000002o`3odP03o`000?oo0?Wo000000So000000Coo`P0o`000?l0Q_oo
08Ko1Ol000001Ol0oi?oooL0ooog0?o_o`3oD_l000?o000000?oo`1jo`000?l000000_l00002ool0
B@04o`000?oo0;_o0000oc/0o`;ooaT000CoU_l0o`000?l0jooo0>_o0_l0oh`3o`0000;on@3o0_l0
0002odSo00So00000_l0ogL00ooi0?ooJ`3oogSo0004o`000003oeKo0?l0003o000000?o00000_oo
08<Ao`000004o`2Aool0003o0000o`3o:`;o00000_lco`04o`0000;oo`1d2Ol000001?l07?oo0000
ooT0oolB0?lBo`000004o`06ool0003oo`0mool0?@;o00001Ooo03d2o`0000Co2`3o00?o0000o`3o
?_l0och00_l00003ocWo00Co00000_oo0=l3o`0000;o08Co4Ol000000ooTo`3oLol0o`000002o`00
0003ool0C_l0003o000000;o0?mm00?o0000odH0oom60?l02?l000000on40?oooiX0oonJ0007o`00
00;oDOl01_l00002ool0H`;o0?mS00?ok@3oo`000?l000001?l00002ool0T@04o`3oL?l0okko0?nn
ool0W0;ooed01?l00002ok80o`03o`000?nRo`3oX_l000?o00000_l0o``6o`0000;ooi@000Go0000
ool0;?oo01?oo`0Co`1jo`07o`0000;o0?oL0_l=0?l3o`0000;o0?Wo0_n10?l3o`000005ool0SOl0
003o0000oomk0?ooE`004ol000000ooo2`3o0000o`000008o`0000;oold00ol00002o`3o1PGo0000
0_l0old7o`0002?ooo]Z000ZoookJP;o07Wo2?oonfX01?lN0?oooo]Zo`3o>Ol0ocT2oookJP03ool0
k?oonf[ooo]Z00;oo`0g00?oa`3ooookJ_oonfX01?oonfX3oolX00?ooo]Z0_oo:0000ooonf[olol0
oookJP04oookJP;o0?m100?ooo]Zool0IOoonfX00_oonfX2oom200;ooo]Z2?oo:002ool0[005o`0f
oooonf[o0?oBo`3od_oonfX00_oo0?T3oookJPSoobP000Co08KooookJ_oonf[oobP01ooo0003oolX
00;oo`1j0_oonfX7ool00006oolI0?oo003oo`00ool00?oo:03o0>_o1?oo:0001?oonf[oobP0ooT0
oooi0?l2oolX0003odSo0?oo:03oobP000?oobP000?ooo]ZoolX0?oo:0000_oo:0000ooi0?ooobP0
oolX0002oolX00?oogT01?oo:002oookJP03ool0Pooonf[ooo]Z00Sooo]Z2?oo0002oookJPGoogT0
00Go<ol0oookJ_oonf[ooo]Zool0M007oookJP?oogT02?oo:008ool000;oolT00ooUo`000oooN@3o
olT0ooo90008ooo900GoiOl02_oo0008oolX00CoogT04?oonfX00ooTo`3oLol0oookJP0:oolX0005
odH0oooonf[ooo]ZoookJ_l000000ooonfX00ooo003oQ03ooonJ0006oookJP03oolX0?mAo`3oDOl0
00Cooo]Z00?oogT0oolX0?oo:0000_ooN@02o`3oH`04oomi0?oonf[ooo]ZoookJP;oo`000_oo0940
0ol0og3o0?nno`3o_P05ool000;ooo]Z0_nb0?l00ooonf[oX_l0o`3o9003ool000;o0?l<1_oonfX2
oonD00;oo`0/00Cooo]Zool04ooo01?o07[o0_oonfX00ol0003ooo]ZoookJP02oookJP04o`3og?l=
0?oo3@3ooookJP;oobP00_l0nOl3oolX00;ooo]Z0_oo08d2oookJP;oobP01?oonfX2oolX00cooo]Z
0_oo2`0:oookJP;oold00ooonfX00ol0o`Kooo]ZoookJP03oookJP;o0?o=0ooonfX00ol0003ooo]Z
oookJP19oookJP;o07Wo2OoonfX00olN0?oo0?lio`3o>@02oookJP06ool0k?oonf[ooo]ZoonD0?oo
03Ooa`3o3OoonfX01?l0od_ooo]ZoookJ_oco`05oookJP;o0?m10_oo06D3oookJP;ood8000Gooo]Z
om_o0?oKo`3ooo]Zo`3od`02ool=00;ooo]Z00?oo`26ool0[?l0=_l00_oonfX01Ol0om;ooo]Zool0
nOoo0?Wo000000Oooo]Z0_oo20000ooonf[o08KooookJP04oookJP;o0?nC00?oooL0onoo0?o_o`00
0ooonfX2ool0NPCooo]Z00Soo`19oookJ_oo0;_oo`2koookJ_lk0?oooaT0oiKo00;ooo]Z00?o0>_o
ool=0?l0oh`01?oonfX2ooT0o`03oookJ_o_0?ooB?l000Wooo]Z00Co0?mgooT0oom[0?ooJ`3o1?oo
nfX2oeKo00Gooo]Z00?oo`23oookJ_oonfX03ooonfX01?l0TOoooo]ZoookJ_l0ob/3oookJP;o<ol0
1?oonfX00ooo07Cooo]ZoookJP07oookJP04o`0Loooonf[on@3ooa80oa3ooo]Z00Co0000o`06ool0
003oo`0m2?oonfX4ool0?@;ooo]Z0_l;0?l01?oonf[o0?lno`3o?_l0och2oookJP?o>Ol00_oo03<0
0ooonf[oo`3OoookJP03oookJP;o08Co4?oonfX2onCo0003og?o0?oonf[ooo]Z00;oo`1>0_oonfX2
o`3oO@03oookJ_m60?ooAP3o00Cooo]Z00?o0000oookJ_oonfX00_n40?l2oonJ00Oooo]Z00?oDOl0
oookJ_oonfX01OoonfX2ool0H`;o0?mS1ooonfX2ool0T@04o`3oL?l0okko0?nnoookJP;ooed01?oo
nfX2ok80o`03oookJ_nRo`3o0?lT00?ooo]Z0_l0o``6oookJP;ooi@00_oo02`2ool04`04o`1joooo
nf[ooo]Zo`0000Cooo]Z00Co0?oLoookJ_l=0?oo3@3o0ooonfX2o`3io`;oP@3o0_oonfX2ool0S@;o
oo]Z0_ooE`0BoookJP;oo`/02_oonfX2ooo=00?ooo]Z00?o0?l6oookJ_oonfX01?oonfX2o`3oc@?o
oo]Z00?o0000oookJ_oonfX08_oonfX002[ooo]Z0_l0HOl00ol0NOoooo]ZoookJP06oookJP;o7P3o
00Cooo]Zo`3o>Ooonf[ooo]Z0_oo0>`00ooonf[ooi@0ool0=`02olL0o`Gooo]Z00?oobP0oookJ_oo
nfX01?oonfX01?oo:03ooo]Zoo?o0?oco`05oookJP;o0?m10_oo06D3oookJP03oom20?oonf[ooo]Z
00[oobP00_l0=_l01Ooonf[o0?oBo`3od_oonf[oo`3i00?ooo]Z1ooo:0001Ooonf[o08Koo`26oooo
nf[oobP000?oo`000_l0oi<00ooo:03oo`00oolX0003oookJP;oo`1j00?ooo]Zool00?oo00001Ooo
0002oolI0003ool00?oonf[oobP000;o0>_o1_oo:0000ooi0?ooobP0oolX0002odSo00?oobP00_oo
nfX4oolX00;on@3o0_oo:004oomi00?oobP00ooonfX00ooo08?ooo]ZoookJP08oookJPOoo`000_oo
N@001?oonf[oogT0oomi0?ooN@02oookJP05oc?o0?oonf[ooo]ZoookJ_oo07@01ooonfX4oomi00Ko
obP02?oo0004oookJP04onGo0?ooN@3oogT0oolX00SoolT01ooUo`07ool000[oobP01OooN@000ol0
Q?oooo]ZoookJP0<oookJP03onCo0?oo:03oobP000_oobP000?oAP3ooookJ_oonfX01OoonfX00on4
0?oooiX0oonJ0004oookJP?oobP000?oDOl0oookJ_oonfX00_ooN@03oolX00?oogT00_l0of<5oook
JP04ool00?oo097oo`2Ao`3oL0;o0?nn1?oo0002oookJP;oo`0000?o/P3oool00?oo00000ooo0000
0ooonf[o0?l<oookJP06oookJP;ooi@00_oo02`01?oonf[oo`0Co`1jool0N_l6oookJP;o0?oL0_l=
0?l2oookJP03oolX0?l0nOoo0?Wo00;oobP00ooonfX2ool0S@05oookJ_oo:03oobP0oolX0?oonfX0
1?oo:0000ooonf[oobP0oolX000:oookJP;oo`/02_oonfX2ooo=00;ooo]Z0_l0o`H5oookJP;o0?o=
COoonfX2o`1Qo`03o`1ioooonf[ooo]Z00Oooo]Z0_lN0?l00ol0ocWooo]ZoookJP02ool0k0;ooo]Z
00?ooi@0olL0ooo70?l03?oonfX2o`3oB`03oookJ_oco`3olol000Gooo]Z00?o0?m1oookJ_oo06D0
1?oonfX00ooo@P3ooo]ZoookJP02om_o00;o0?oC00Coo`d0oookJ_oonf[ooo]Z0_oo0:`01Ol0=_oo
oo]Zo`3od_l0om;ooo]Z00;oo`3i2?oonfX2ool800;o08Ko1OoonfX2o`3oT`03ooog0?o_o`3oD_l0
00?ooo]Z0_oo07X3oookJP;oo`1900Cooo]Zool0^ooo0;_ooo]Z0_oo6@001_nFo`3ooo]Zo`3[ool0
jooo0?n<ool=00Cooo]Z00?on@3ooookJ_oonfX00_m8o`09oookJP;on@3o00?oJ`3oogSo0?oonfX0
0ooonfX2oeKo00Cooo]Z00?oo`23oookJ_oonfX03ooonfX01?l0TOoooo]ZoookJ_l0ob/4oookJP03
oc?o0?oonf[ooo]Z00;ooo]Z00?oo`1doookJ_oonfX01ooonfX00ol07?oooo]ZooT0o`0@oookJP04
o`000?l01_oo0000ool0?@cooo]Z1Ooo03d3o`/0o`?o0?ln0_oonfX2ocWo0004ool0<ooonf[oo`3O
ool0g`Cooo]Z0ol0Q?l?oookJP;oi?l00ooonfX2ool0CP;ooo]Z0_l0ogd01?oonf[oAP3oodH0oom6
0?l6oookJP;oQ03o0_ooVP06oookJP;oDOl01ooonfX2ool0H`;o0?mS1ooonfX2ool0T@04o`3oL?l0
okkoo`2LoookJP;ooed00ooonfX2o`3of`04ok80oonRo`3oX_l0o`3o90?ooo]Z00?o0?l<oookJ_oo
nfX01OoonfX2oonD00;oo`0/00?oo`0Co`1jool0N_l01_oonfX2o`3og003oookJ_l=0?oo3@3o00?o
oo]Z00?o0?WooookJ_n10?l00ooonfX2ool0S@;ooo]Z0_ooE`0BoookJP;oo`/02_oonfX2ooo=00;o
oo]Z0_l0o`H6oookJP03o`3ocOoonf[ooo]Z02Gooo]Z000/oookJP;o067o00?o07WooookJ_oonfX0
1_oonfX01?lN0?oooo]Zo`3o>Ol0ocT2oookJP;oo`3/00?ooo]Zool0=ooo03L00_o70?l;oookJP;o
obP000?ooo]Zoo?o0?oonfX01OoonfX00ol0od7ooo]Zool0I@03oookJP;ood8000?ooo]ZoolX0?oo
:0002_oo:002oookJP04o`3od_oonf[oo`3iool0n@;ooo]Z1Ooo:0001?oonf[oobP0oolX0?oonfX2
o`26o`03oolX0?oo003oobP000;oobP000?o0?nCoolX0?oo:0000_mBo`03oookJP03ool0N_oonf[o
o`0000Ooo`0000?ooaT0oiKo0?oonfX00_oo:0000ol0joooobP0oolX0004oolX0004ooT0oooo:03o
obP0oolX00;oB?l01?oonfX5oolX0003ooT0oom[0?ooogT000CoogT000?oobP0oomi0?oonfX00ooo
nfX2ool000Wooo]Z1Ooo00000ooonf[oogT0oomi0003oomi00Cooo]Z00Go<ol0oookJ_oonf[ooo]Z
ool0M007oookJPCoogT01Ooo:007ool000Gooo]Z00?o0000oomi0?ooN@000_ooN@06ooo900SoiOl0
0_oo0005oomi00coobP00oooN@02oolX0003o`24oooonf[ooo]Z00cooo]Z0ooTo`0:oolX00;oAP3o
1ooonfX01?n40?oooiX0oonJ0?oonfX5oolX00;oDOl000?oogT0oolX0?oo:0000ooo:004oomi00;o
0?mS1_oonfX2ool0T@03o`3oL?l0okko0?nn00?oo`000ooonfX7ool00003oookJ_l0o`co0?l<00Oo
oo]Z0_ooU0001?oo02cooo]Zool04ooo01<2o`1jo`Kooo]Z0_l0om`2o`d0o`?ooo]Z00Co0?WooolX
0?oo:03oP@3o0ooonfX00ooo08gooo]ZoookJP0:oolX00_ooo]Z0_oo2`0:oookJP04ooo=0?oonf[o
oo]ZoookJP;o0?l61OoonfX00ol0olgooo]ZoookJP1<oookJP;o067o00?o07WooookJ_oonfX01ooo
nfX00olN0?oo0?lio`3o>@02oookJP;oo`3/00?ooo]ZoonD0?oo03L00_o70?l<oookJP;o0?m;00?o
oo]Zoo?o0?oonfX01?oonfX2o`3o@@03ool0IOoonf[ooo]Z00;ooo]Z0_oo@P02oookJP03om_o0?oo
nf[o0?oC00;oo`d00_oonfX00ooo08Koo`2/o`0fo`02oookJP;o0?oB00?ooo]Zool0nOoonfX02?oo
nfX01?oo203ooo]Zo`26ool0Q_l5oookJP03o`3oTooom`3oooL000;oD_l00ooonfX00ooo07[ooo]Z
oookJP02oookJP08ool0BOoonf[ooo]Zool0^ooonf[o>`3ooolI0?nFo`02oookJP04o`3[ool0ohco
0?n<ool=00?ooo]Z00Con@3ooookJ_oonf[ok`3o0_m8o`08oookJP04o`3oMooi0?ooJ`3oof/0o`Go
oo]Z00?oE_l0oookJ_oonfX00_oonfX2ool0Pa3ooo]Z00?o097ooookJ_oonfX00_l0ob/3oookJP03
oc?o0?oonf[ooo]Z00;ooo]Z00?oo`1doookJ_oonfX01ooonfX00ol07?oooo]ZooT0o`0?oookJP04
o`000?l01_oo0000o`00017ooo]Z1Ooo03d01_l;0?oo0?lno`3o?_l0ockooo]ZocWo00Coo`0c00?o
o`3OoookJ_oonfX00ooonfX2o`24o`oooo]Z0ooTo`02oookJP;oo`1>0_oonfX2o`3oO@;ooo]Z0_m6
0?l6oookJP;oQ03o0_ooVP06oookJP;oDOl01ooonfX2ool0H`;o0?mS1ooonfX01ooo097o0?m`o`3o
__l0okkoo`2LoookJ_ooG@001?oonfX2o`3of`04oookJ_nRo`3oX_l0o`3o90;ooo]Z0_l0o``7oook
JP03oonD0?oonf[oo`0/00;oo`0C0_l0N_l6oookJP;o0?oL00?ooo]Zo`d0ool=0?l00_oonfX2o`3i
o`;oP@3o0ooonfX2ool0S@04oookJ_ooN`3ooeL0oomG01;ooo]Z0_oo2`0:oookJP04ooo=0?oonf[o
oo]ZoookJP;o0?l61OoonfX2o`3ocBGooo]Z000^oookJP03o`1Qool0NOoooo]Z00Oooo]Z0_lN0?l0
0ooonf[o0?lioookJP02oookJP03ool0k?oonf[ooo]Z00;oobP000?oa`3ooookJ_oonfX02_oonfX0
1?oo:03ooo]Zoo?o0?oco`05oookJP;o0?m100?oo`1UoookJ_oonfX00_oonfX00ooo@P3ooo]ZoolX
000;oolX0006o`0foooonf[o0?oBo`3od_oonf[oo`3i0_oonfX3oolX00Cooo]Z00CoobP0ool80?oo
nf[o08Ko1Ooo:002o`3oT`03oolX0?oonf[oD_l000?ooo]Z0_oo07X7ool00004oookJ_oo6@3ooaT0
oiKo00;oobP00_l0jol5oolX0006ooT0oooo:03oobP0oolX0?o_0?ooB?l01?oonfX4oolX0004o`3o
Mooi0?ooJ`3oof/0o`GoogT00_mFo`02oookJPGoo`001ooonfX4ool000;ooo]Z1OooN@04oookJP05
oc?o0?oonf[ooo]ZoookJ_oo07@01ooonfX4oomi00CoobP01ooo0005oookJP03o`000?ooN@3oogT0
00?oogT01Ooob@06oomi0004oookJ_oo003oo`00ool000GoogT03_oo:0000oooN@3oobP0oolX0002
oolX00;o08Co3OoonfX2ool000;oi?l000?oogT0ool0C_oo:0001Ooo:0000ooonf[oAP3oodH0o`07
oookJP03oh@0ooooVP3ooiX000GoobP000?ooo]Zoe7o0?oo:0001Ooo:004oomi0003ond0ool0of?o
0?mS00Kooo]Z0_oo09400ol0og3o0?nno`3o_P02ool000;ooo]Z0_ooN@06ool000;ooo]Z0_l0o``7
oookJP;ooi@000Coo`0/oookJ_oo01?oo`0C0_l0N_l6oookJP;o0?oL0_l=0?l2oookJP;oobP000?o
oo]Zoh40oon10?l00_oonfX2ool0S@03oookJ_oo:03oobP000SoobP03?oonfX00ooo2`3ooo]Zoook
JP08oookJP;oold00ooonfX00ol0o`Kooo]ZoookJP03oookJP03o`3ocOoonf[ooo]Z04gooo]Z00?o
067oo`1ioooonfX02?oonfX00olN0?oooo]Zo`3o>@03oookJP06ool0k?oonf[ooo]ZoonD0?oo03Oo
a`3o3OoonfX00ol0od_ooo]Zoo?o0006oookJP03o`3o@Ooo06Goo`1U00Cooo]Z00Good80oookJ_oo
nf[ofol0oookJP02o`3od`;oo`d00_oonfX2ool0[005o`0foooonf[ooo]Zo`3od_oonfX00_oo0?T8
oookJP;oo`P000?ooo]Zo`26oooonfX01?oonfX2o`3oT`03ooog0?oonf[oD_l000?ooo]Z0_oo07X3
oookJP;oo`1900Cooo]Zool0^ooonf[ooo]Z0_oo6@001_nFo`3ooo]Zo`3[ool0jooo0?n<ool=00?o
oo]Z0_oi0?l2oookJP03onl0oom8o`3ooo]Z00Sooo]Z00Con@3oo`3oMom[0?ooN?l01?oonfX2oeKo
00Cooo]Z00?oo`23oookJ_oonfX03_oonfX01Ol0TOoooo]ZoookJ_oonf[o0?l[00?ooo]Z00Go<ol0
oookJ_oonf[ooo]Zool0M00:oookJP03o`0Loooi0?oooo]Z00kooo]Z00Co0000o`06ool0003o0000
5_oonfX3ool0?@04o`/0ool0ocko0?lno`3o?P?o>Ol00ooo03<2ool0g`?ooo]Z0ol0Q?l>oookJP03
og?o0?oTo`3oi?l000;ooo]Z0_oo04h2oookJP;o0?mm0_oonfX2odH0o`Kooo]Z0_n40?l2oonJ00Ko
oo]Z00?oDOl0oookJ_oonfX01_oonfX01?oo06?ooo]Zo`3oHol0of<6oookJP;oo`2A00Co0?m`o`3o
__l0okkoo`2L0_ooG@04oookJP;o0?oK00?ooo]Zoj;o0?nRo`000ooonfX2o`3o30Kooo]Z0_ooU002
ool0;0;oo`0C0_l0N_l6oookJP;o0?oL00?ooo]Zo`d0ool=0?l00_oonfX2o`3io`;oP@3o0ooonfX2
ool0S@04oookJ_ooN`3ooeL0oomG01;ooo]Z0_oo2`09oookJP;oold00ooonfX2o`3o1PGooo]Z00?o
0?o=oookJ_oonfX08_oonfX002oooo]Z0_l0HOl9oookJP04oah0oooonf[o0?lio`3o>@;ooo]Z0_oo
0>`3oolX00;oa`3o2ooonfX01?oo:03o0?m;oookJ_oco`06oookJP03o`3o@Ooo06Goo`1U00?ooo]Z
0_oo@P0;oolX0006ool0[?l0=_oooo]ZoookJ_l0om;ooo]Z0_oo0?T00ooonf[oobP0oookJP06oook
JP04ool80?oonf[o08Koo`26o`?oobP00_oonfX00ol0oi?oobP0ooog0002oe;o00?ooo]Z00?oo`1j
ool00?oo00000ooo0004oookJP03oolI0?nFo`3oobP000;oobP000?o0>_ooolX0?oo:0000ooo:002
ooT0o`03oolX0?oonf[ok`3o00;oB?l00ooonfX3oolX00;oogT000?on@3ooomi0?m[0?l00oooN@03
oookJP03oeKo0?oonf[ooo]Z00Koo`001_oonfX3ool000?ooo]Z1_ooN@03oookJP05oc?o0?oonf[o
oo]ZoookJ_oo07@01ooonfX01?ooN@3ooo]Zo`0LooooN@03oolX00Ooo`001OoonfX00ooo:03oogT0
oomi0005oomi00?oolT01oooN@07ool001KoobP00ol0Q?l:oookJP?oo`0000?oogT0onCo0?oTo`00
0_ooN@02ool0CP05oomi0?oo:03oobP0o`3oOOoonfX00_m60?l6oookJP;oobP00oooVP0;oolX00Go
ogT000?ok@3oo`3oHol0of<01_oonfX2ool0T@05o`3oL?l0okko0?nnool00?ooG@000oooN@07ool0
00;ooo]Z0_l0o``7oookJP04oonD0?oo02coo`0/oookJP;oo`0C00?o07[ooookJ_oonfX01OoonfX2
o`3og0;o3@3o0_oonfX2oolX0003oookJ_n10?ooP@3o00;ooo]Z0_oo08d:oolX00cooo]Z0_oo2`0:
oookJP;oold00_oonfX2o`3o1UCooo]Z0_l0HOl00ol0NOoooo]ZoookJP06oookJP;o7P3o0_l0ocT2
oookJP;oo`3/00?ooo]ZoonD0?ooU0000_o70?l<oookJP;o0?m;0_oco`05oookJP;o0?m100?oo`1U
oookJ_oonfX00_oonfX00ooo@P3ooo]ZoookJP02om_o0004oookJ_l0om?ooo]Zool=00;ooo]Z00?o
o`26ool0[?l0=_l00_oonfX2o`3odP03oookJ_oo0?Woo`3i00Sooo]Z00Coo`P0oookJ_l0Q_oo08Ko
1OoonfX00ol0oi?oooL0ooog0002oe;o00?ooo]Z00?oo`1joookJ_oonfX00_oonfX00ooo04Wooo]Z
oookJP03oookJP05oolI0?nFo`3ooo]ZoookJ_l0jol00_l0oh`4oookJP04ooT0oooonf[ooo]Zonl0
o`;oB?l02?oonfX01?oi0?oo0?mgof/0oom[0?l5oookJP03oeKo0?oonf[ooo]Z00;ooo]Z0_oo08<?
oookJP05o`2Aoooonf[ooo]ZoookJ_l0ob/00ooonfX01Olco`3ooo]ZoookJ_oonf[oo`1d00[ooo]Z
00?o01coooT0oooonfX03OoonfX01?l0003o00Koo`000?l00009oookJPko0?l`0_oonfX3ool0?@04
o`/0ool0ocko0?lno`3o?P?o>Ol00_oo03<4ool0g`;ooo]Z0ol0Q?l>oookJP;oi?l000CoLol0oook
J_oo04koo`1>0_oonfX2o`3oO@04ooT0oooonf[oAP3oodH0o`Kooo]Z0_n40?l3oonJ00Cooo]Z0_mA
o`07oookJP;oo`1S00?ok@3oo`3oHol0of<01_oonfX2ool0T@04o`3oL?l0okko0?nnool0W0;ooed0
1?oonfX2o`3of`03oookJ_nRo`3oX_l000?ooo]Z0_l0o``6oookJP;ooi@00_oo02`2ool04`03o`1j
oooonf[ooo]Z00Gooo]Z0_l0om`00ooonf[o3@3ooookJP02oookJP;o0?Wo0_n10?l3oookJP04ool0
SOoonf[ooo]Zoomk00;ooeL04_oonfX2ool;00Wooo]Z0_ooc@03oookJP;o0?l6:?oonfX0037ooo]Z
0_l0HOl8oookJP;o7P3o00?ooo]Zo`3o>OoonfX00_oonfX00ooo0>coobP0oolX0004oolX00_ooo]Z
00Co0?m;oookJ_oco`3olol01OoonfX2o`3o@@03ool0IOoonf[ooo]Z00;ooo]Z2_oo:0001?oonf[o
o`26ool0[?oo0:`2oookJP;o0?oB00?ooo]Zool0nOoonfX02?oonfX01?oo203ooo]ZoookJ_l0Q_l2
oolX00?ooo]Z00Go0?nCoookJ_oom`3ooo]Zoe;o0003oookJP05ool0N_oo003oo`00ool00?oo04T0
1OoonfX2oolI0003oiKo0?oo:03oobP000;o0>_o1Ooo:0001_oi0?oooo]ZoookJ_o_0?oooo]ZodSo
00?ooo]Z00?oobP0oookJ_ooN@000_ooN@02ooT0o`03of/0ooooN@3oogT000Cooo]Z00?oE_l0oook
J_oonfX01ooo0005oookJP03ool00?oonf[ooo]Z00;ooo]Z2?ooN@02oookJP05oc?o0?oonf[ooo]Z
oookJ_oo07@02OoonfX00ol07?ooo`00oolX0008ool000Cooo]Z0ooo:007oomi0003ooo90?ooN@3o
ogT000CoogT00_oonfX@ool000SoobP00ooo03<4oolX0004oiCo0?l0Q?oo08Coo`24o`Oooo]Z1Ooo
00000oooN@3oi?l0onCo0002oomi00?oo`1>00Cooo]Zo`3oOOl0oggo0?mm0_m60?l4oookJPGoobP0
0_ooVP0;oolX00CoogT000Cooo]Zond0ool0of?o0?mS1_oonfX2ool0T@03oomi0?l0okko0?nn00Co
ogT01ooo00000ol0obCooo]ZoookJP02o`3o30Cooo]Z0_ooN@02oonD00;oo`0/00Cooo]Zool04ooo
01?o07[o1ooonfX2o`3og0;o3@3o0_oonfX2oolX0003oookJ_n10?ooP@3o00;oobP00_oo08d9oolX
00gooo]Z0_oo2`0:oookJP;oold00_oonfX2o`3o1UCooo]Z0_l0HOl9oookJP03oah0oooonf[o0?li
00?ooo]Z00Goo`3/oookJ_oonf[ooi@0ool0=`02olL0o`cooo]Z00?o0?m;oookJ_oco`001_oonfX2
o`3o@@04ool0IOoonf[ooo]ZoookJP;ood800_oonfX01?oKo`3ooo]Zo`3odooonfX2ool=00;ooo]Z
0_oo0:`3oookJP;o0?oB00?ooo]Zool0nOoonfX01ooonfX01?oo203ooo]ZoookJ_l0Q_l5oookJP05
o`3oTooonf[oooL0oookJ_mBo`000ooonfX2ool0NP?ooo]Z00?oo`19oookJ_oonfX00ooonfX2oolI
0005oiKo0?oonf[o0>_oo`3[ool0oh`01?oonfX2ooT0o`04oookJ_o_0?oooo]ZodSo00Sooo]Z0_oi
0?l00ol0ogOoJ`3ooookJP04oookJP03oeKo0?oonf[ooo]Z00?ooo]Z00?oo`23oookJ_oonfX03Ooo
nfX01Ol0TOoooo]ZoookJ_oonf[o0?l[00?ooo]Z00Go<ol0oookJ_oonf[ooo]Zool0M00:oookJP03
o`0Loooi0?oooo]Z00cooo]Z00Co0000o`06ool0003o00002?oonfX00ol0oc3ooo]ZoookJP0<oook
JP?o0?l`1ooo=0001?l;0?oo0?lno`3o?_oo:@04ool0<`?oo`3O0_oonfX3o`24o`gooo]Z0_oTo`00
0omco`3ooo]Zool0CP02ool0CP05oookJ_l0oggo0?mmo`3oOOoonfX00_m60?l6oookJP;oQ03o00?o
oo]ZoonJ0?ooVP001?oonfX2oe7o00Oooo]Z0_oo06<00oo]0?oo0?mSo`3oH`06oookJP;oo`2A00Co
0?m`o`3o__l0okkoo`2L0_ooG@04oookJP03o`3ofonb0?oooo]Z00;oX_l00ooonfX2o`3o30Kooo]Z
0_ooU002ool0;0;oo`0C00?o07[ooookJ_oonfX01OoonfX2o`3og0;o3@3o0ooonfX2o`3io`;oP@3o
0_oonfX2ool0S@;ooo]Z00?oog/0oomG0?ooE`004_oonfX2ool;00Wooo]Z0_ooc@03oookJP03o`3o
1_oonf[ooo]Z02Gooo]Z000coookJP03o`1Qoooonf[ooo]Z00Oooo]Z00?o7P3ooookJ_l0ocT00ooo
nfX00ooo0>coobP0oolX0006oolX00Wooo]Z0_l0od/00ooonf[olol0oookJP05oookJP03o`3o@Ooo
06Goo`1U00?ooo]Z2?oo:0001ooo3@3ooo]ZoookJ_oo08Kooo]Zool0[?l0=_l00_oonfX01?l0om;o
oo]Zool0nOoo0?T8oookJP;oo`P000?ooo]Zo`26ool0Q_l01?oonfX2o`3oT`03ooog0?oonf[oD_l0
00Cooo]Z00?oo`00oookJ_oonfX00_oo04T5oookJP03oolI0?nFo`3oobP000;oobP000?o0>_ooolX
0?oo:0000_oo:0001?oonf[on@3ooookJ_oonfX2onl0o`;oo`001?oonfX2oomi00;oobP000?on@3o
ool00?oo00001OoonfX00omFo`3ooo]ZoookJP09ool000Sooo]Z2OooN@000ooonf[o<ol0oookJP02
oookJP;oogT01ooonfX00ol07?ooogT0ool00007ool000Gooo]Z0ooo:00:oomi00Kooo]Z2?oo0000
0ooonf[oo`00ool0000;ool000GoobP01?oo03<2oolX0004oiCo0?oonf[o08Coo`24o`Cooo]Z2?oo
00000oooN@3oi?l0onCo0003oomi00?oo`1>00?ooo]Zo`3oOOl0ogd00_m60?l2oookJPOoobP00_oo
VP0:oolX00;ooo]Z0_ooN@000ooo06?ooo]Zond0o`02o`3oH`Kooo]Z0_oo09400oooN@3o0?nno`3o
_P04oomi00Koo`0000CoX_l0o`3o9?oonf[ooo]Z0ol0o``01Ooonf[oogT0oomi0?ooN@3ooo]Z00;o
oi@00_oo02`01?oonf[oo`0Cool04ooo01<7oookJP;o0?oL0_l=0?l2oookJPOoobP00_oo08d8oolX
00kooo]Z0_oo2`0:oookJP;oold00_oonfX00ol0o`Kooo]ZoookJP1CoookJP03o`1Qool0NOoooo]Z
00Oooo]Z0_lN0?l01?l0ocWooo]ZoookJ_oonfX2ool0k0;ooo]Z0_oo03L00oo70?oooo]ZoookJP0:
oookJP04o`3oBooonf[olol0oo?o00Kooo]Z00?o0?m1ool0IOoonfX00ooonfX00ooo@P3ooo]Zoook
JP02om_o00;o0?oC00Oooo]Zool=0?oonf[ooo]Zool0Q_oo0:co03Ko00?ooo]Z00Co0?oBoookJ_oo
0?Woo`3i1ooonfX2ool80003oookJ_l0Q_oo08Ko00Cooo]Z0_l0oi<2ooog0003oe;o0?oonf[ooo]Z
00;ooo]Z00Coo`1joookJ_oonf[ooo]Z0_oo04T5oookJP07oolI0?nFo`3ooo]ZoookJ_l0jooo0?n<
ool=0004oookJP04ooT0oooonf[ok`3oonl0o`;oB?l02?oonfX00ooi0?oo0?mgof/0o`05oookJP;o
E_l01?oonfX00ooo08?ooo]ZoookJP0=oookJP;o097o0_oonfX01Ol0ob_ooo]ZoookJ_oonf[o<ol0
00?ooo]Z00?oo`1doookJ_oonfX01ooonfX00ol07?oon@3ooookJP0<oookJP04o`000?l01_oo0000
o`0000Gooo]Z0ol0oc0EoookJP?o0?l`00Goo`0moold0?oo=03ooc@0ool0?@02o`3o?P03oolY0?li
o`3oo`0c00Coo`0c00?oo`3OoookJ_oonfX00_l0Q?l=oookJP?oi?l00_oonfX3ool0CP05oookJ_l0
oggo0?mmooT0oom60?l01ooonfX2oh@0o`03oookJ_ooVP3ooiX000Cooo]Z0_mAo`07oookJP;oo`1S
00?ok@3oo`3oHol0of<01_oonfX2ool0T@04o`3oL?l0okko0?nnool0W0?ooed00_oonfX2o`3of`04
ok80oooonf[oX_l0oj;o00?ooo]Z0ol0o``5oookJP;ooi@00_oo02`3ool04`Oooo]Z0_l0om`2o`d0
o`?ooo]Z0_l0nOl2oh40o`;ooo]Z0_oo08d2oookJP03oomk0?ooE`3ooeL001;ooo]Z00?oo`/0oook
J_oonfX02?oonfX2ooo=00;ooo]Z0_l0o`HUoookJP00=?oonfX2o`1Qo`Sooo]Z0_lN0?l2o`3o>@?o
oo]Z2Ooo:009oookJP04o`3oBooonf[olol0oo?o00Gooo]Z0_oo:0001?oo06Gooo]ZoookJ_oonfX8
oolX00;oo`d000Gooo]Zool0Q_oo08Koo`2/o`0fo`02oookJP;o0?oB00?ooo]Zool0nOoonfX02?oo
nfX01?oo203ooo]ZoookJ_l0Q_l5oookJP03o`3oTooom`3oooL000;oD_l00ooonfX01Ooo07[ooo]Z
oookJ_oonf[oo`1900Gooo]Z0_oo6@000ooo003oobP0oolX0002o`3[o`05oolX0?oonf[ooo]Zoook
J_oi0?l00ooonfX4ool000?ooo]Z0_ooN@02oolX0004ooT0oooo003oo`00ool000Cooo]Z00?oE_l0
oookJ_oo00002_oo0007oookJP[oogT00ooonfX3oomi00Oooo]Z00?o01cooomi0?oo00001Ooo0005
oookJPCoobP01oooN@000ol0oc3ooo]ZoookJP0?oookJPgoo`002Ooo:003ool0<`03oolX0?nDo`3o
oo]Z00?o08Co00?ooo]Zool00?oo00001ooo0002oomi00;oi?l00oooN@001?oonf[oo`1>ool0C_oo
04h3o`3oO@03odH0oooo:03oobP000OoobP00_ooVP09oolX00Cooo]Z0ooo06<00ooonf[o0?mSo`3o
H`05oookJP04oomi0?oo097oo`2Aoomi00;o0?nn0oooN@06ool000;oX_l000CoogT0oookJ_oonf[o
oo]Z0_l0o``3oomi00;ooo]Z0_ooU003ool0;003oookJ_oo01?oo`0C00Oooo]Z0_l0om`2o`d0o`;o
oo]Z1ooo:002ool0S@OoobP03ooonfX00ooo2`3ooo]ZoookJP09oookJP04ooo=0?oonf[ooo]Zo`3o
1UGooo]Z0_l0HOl9oookJP03oah0ool0ocWo0?li00?ooo]Z0_oo0>`01?oonf[ooi@0ool0=oo70?l<
oookJP;o0?m;00?ooo]Zoo?o0?oonfX01OoonfX2o`3o@@04ool0IOoonf[ooo]ZoookJP;ood800_oo
nfX01?oKo`3ooo]Zo`3odooonfX2ool=0004oookJ_oo08Koo`2/ool0[0?ooo]Z0_l0om800ooonf[o
o`3ioookJP07oookJP04ool80?oonf[ooo]Zo`26o`Gooo]Z00?o0?nCoookJ_oom`000_mBo`03oook
JP;oo`1j0ooonfX00ooo04Wooo]ZoookJP03oookJP04oolI0?nFo`3oU_l0oookJP;o0>_o00?o0?n<
oookJ_oonfX00_oonfX01_oi0?oooo]ZoookJ_o_0?oooo]ZodSo00Sooo]Z00?on@3oo`3oMom[0?l0
1_oonfX00omFo`3ooo]ZoookJP02oookJP03ool0Pooonf[ooo]Z00kooo]Z00?o097ooookJ_l0ob/0
0ooonfX00olco`3ooo]ZoookJP02oookJP03ool0M?oonf[ooo]Z00Oooo]Z00?o01coooT0oooonfX0
2ooonfX01?l0003o00Koo`000?l00005oookJP03o`3o<?oonf[ooo]Z01[ooo]Z1?oo0<401Ooo=03o
o`0mo`3o?_l0ockoobT000?o>Ol00ooo03<00ooo0=oooo]Zo`24o`02o`24o`gooo]Z0_oTo`000omc
o`3ooo]ZoookJP03ool0CP?o0?mm00?oAP3ooookJ_oonfX01OoonfX3oh@0o`;ooiX01?oonfX3oe7o
00Kooo]Z0ooo06<2o`3oH`Kooo]Z0_oo09400ol0og3o0?nno`3o_P02ool0W0;ooed00_oonfX2o`3o
f`04ok80oooonf[oX_l0oj;o00Cooo]Z0_l0o``5oookJP;ooi@00ooo02`2ool04`Oooo]Z0_l0om`2
o`d0o`?ooo]Z0_l0nOl2oh40o`;ooo]Z0_oo08d2oookJP03oomk0?ooE`3ooeL0017ooo]Z0_oo2`0:
oookJP05ooo=0?oonf[ooo]ZoookJ_l0o`H09?oonfX003Kooo]Z00?o067ooookJ_oonfX01ooonfX0
0olN0?oooo]Zo`3o>@03oookJP_oobP01ooonfX01?l0od_ooo]ZoookJ_oco`04oookJPGoobP00_oo
nfX5oolX0005om_o0?oonf[oobP0oookJ_oo3@000_oonfX01?oo08Koo`2/ool0[?l0=_l2oookJP03
o`3od_oonf[oo`3i00Wooo]Z0_oo20000ooonf[o08Koo`26o`04oookJP;o0?nC00?oooL0oookJ_mB
o`000ooonfX2ool0NP;ooo]Z0_oo04T4oookJP04ool00?oo6@3oo`00ool000;oobP000?o0>_oo`3o
S?oonfX00_oonfX2ooT0o`;ooo]Z1Ooo0002oookJP;oogT00_oo:002ooT0o`;oo`001?oonfX00omF
o`3ooo]Zool0000:ool000Oooo]Z2_ooN@03oookJP?oogT01ooonfX00ol07?ooogT0ool00004ool0
00Gooo]Z1Ooo:007oomi017ooo]Z3Ooo000:oolX00;o>Ol00ooo03<01?nDo`3oo`3OoookJ_l0Q?l;
ool000;oogT00ooTo`001?ooN@3ooo]ZoookJ_oonfX2ool0CP05ooT0ool0oggo0?mmodH0oooonfX0
2?oo:003oonJ00OoobP01_oonfX2ool0H`03oookJ_l0of?o0?mS00?ooo]Z0oooN@03ool0T@05o`3o
__ooN@3oogT0oomi0?ooG@001Ooo00001Ooonf[oX_l0oj;o0?ooN@3ooo]Z00;oogT00_l0o``2oomi
00?ooo]Z0oooU002ool0;004oookJ_oo01?oo`0Co`1jo`Kooo]Z0_l0om`2o`d0o`WoobP00_oo08d6
oolX00oooo]Z0_oo2`0:oookJP;oold0F?oonfX00ol0HOoo07WooookJP07oookJP;o7P3o00?o0?li
oookJ_oonfX00_oonfX01?oo0>cooo]ZoookJ_oo03L2olL0o`cooo]Z00Co0?m;oookJ_oco`3olol0
1_oonfX00ol0od7oo`1UoookJP03oookJP05oom20?oonf[ooo]Zom_o0?oonfX00_l0om<01ooonf[o
o`d0oookJ_oonf[oo`26ool0[?l0=_l00ooonfX00ol0om;ooo]Zool0n@08oookJP;oo`P000?ooo]Z
o`26ool0Q_l01?oonfX2o`3oT`03ooog0?oonf[oD_l000Cooo]Z00Coo`1joookJ_oonf[ooo]Z0_oo
04T4oookJP03oolI0?oonf[oU_l000;ooo]Z00?o0>_oo`3oS?oonfX00ooonfX2ooT0o`04oookJ_o_
0?oooo]ZodSo00Sooo]Z0_oi0?l00om[0?oooo]ZoookJP04oookJP03oeKo0?oonf[ooo]Z01?ooo]Z
00?o097ooookJ_l0ob/00ooonfX00olco`3ooo]ZoookJP02oookJP03ool0M?oonf[ooo]Z00Oooo]Z
00?o01coooT0oooonfX02_oonfX01?l0003o00Koo`000?l00004oookJP03o`3o<?oonf[ooo]Z01oo
oo]Z1Ooo0<400ooo03go0?lnoolY0003ocWo00?oo`0c00?oo`3OoookJ_l0Q?l00_l0Q?l4oookJP?o
0?nI1OoonfX3onCo00?ooo]Z0_oo04h00ooonf[o0?mmo`3oO@02odH0o`Oooo]Z0_n40?l3oonJ00Co
oo]Z0_mAo`07oookJP;oo`1S0_l0of<6oookJP?oo`2A00Co0?nno`3oL?oo09coo`2L0_ooG@02oook
JP;o0?oK00Co/P3ooookJ_nRo`3oX_l01?oonfX2o`3o30Gooo]Z0_ooU0000ooonf[oo`0/ool0;002
ool04`03o`1joooonf[ooo]Z00Cooo]Z0_l0om`2o`d0o`?ooo]Z0ol0nOl3oookJP;oo`2=00?ooo]Z
oomk0?ooN`000_ooE`0AoookJP;oo`/02OoonfX2ooo=02Kooo]Z000goookJP03o`1Qool0NOoooo]Z
00Oooo]Z0_lN0?l2o`3o>@;ooo]Z3?oo:006oookJP;o0?m;00?ooo]Zoo?o0?oco`000ooonfX6oolX
0004oookJ_oo:03oobP0oolX00;ooo]Z0_oKo`02oolX0003ool=0?oonf[ooo]Z00;oo`2600Koo`2/
o`0foooonf[ooo]Zo`3od_oonfX2ool0n@Wooo]Z00Coo`P0oookJ_oonf[o08Ko1OoonfX01?l0oi?o
ooL0oookJ_mBo`04oookJP05ool0N_oonf[ooo]ZoookJ_oo04T01?oonfX00ooo003ooaT0ool00002
ool00003oookJ_l0jooo0?n<00Cooo]Z00?on@3ooookJ_oonfX01_oo00000ooonf[oogT0oolX0002
oolX0003ool00?oi0?ooo`0000;oo`000ooonfX00omFo`3ooo]Zool00009ool000Oooo]Z2_ooN@00
0olco`3ooo]ZoookJP05oomi00Gooo]Z00?o01cooookJ_ooN@000ooo0005oookJPKoobP02?ooN@0@
oookJPSoo`001?oob@0=oolX0003oold0?lio`3o>Ol000?oo`0c3_oo00000ooonf[oogT0oomi0003
onCo0003og?o0?oonf[ooo]Z00?oo`1>0ol0ogd01?m60?oooo]ZoookJ_oonfX6oolX00?ooiX01Ooo
:007oookJP;oo`1S00Cooo]Zo`3oHol0of?ok@3o1_ooN@02ool0T@04o`3o__ooN@3oogT0oomi00;o
oed000Gooo]Zool00?oo003o0?oKoookJP02oj;o00CoogT00_l0o``00oooN@3ooo]ZoookJP03oook
JP;ooi@00_oo02`01?oonf[oo`0Cool04ol0N_l6oookJP;o0?oL0_l=0?l9oolX00;oo`2=1Ooo:00@
oookJP;oo`/02_oonfX00oooc@3ooo]ZoookJP1FoookJP03o`1Qool0NOoooo]Z00Sooo]Z00?o7P3o
o`3o>Ol0ocT00ooonfX2ool0k004oookJ_oo03Ooo`0golL0o`cooo]Z00Co0?m;oookJ_oonf[olol0
1_oonfX00ol0od7oo`1UoookJP03oookJP03oom20?oonf[ooo]Z00;ofol000Cooo]Zo`3odooonf[o
o`d00_oonfX00ooo08Koo`2/o`0fo`03oookJP03o`3od_oonf[oo`3i00Wooo]Z00Coo`P0oookJ_oo
nf[o08Ko1OoonfX01?l0oi?oooL0ooog0?mBo`04oookJP;oo`1j0ooonfX00ooo04Wooo]ZoookJP02
oookJP03oolI0?oonf[oU_l000;ooo]Z00?o0>_oo`3oS?oonfX01?oonfX01Ooi0?oooo]Zonl0oooo
nf[oB?l000Wooo]Z00?on@3oof/0oooonfX01OoonfX00omFo`3ooo]ZoookJP0CoookJP03o`2Aoooo
nf[o0?l[00?ooo]Z00?o<ol0oookJ_oonfX00_oonfX00ooo07Cooo]ZoookJP06oookJP03o`0Loooi
0?oooo]Z00[ooo]Z00Co0000o`06ool0003o00000ooonfX00ol0oc3ooo]ZoookJP0UoookJPCoo`31
0_oo=003ocWo00?oo`0c00?oo`3OoookJ_l0Q?l00_l0Q?l4oookJP?o0?nI1OoonfX3onCo00;ooo]Z
0ooo04h3o`3oO@;oAP3o1_oonfX2oh@0o`03oookJ_ooVP3ooiX000Cooo]Z0_mAo`07oookJP;oo`1S
0_l0of<00oo]0?oooo]ZoookJP04oookJP;oo`2A00Co0?nno`3oL?oo09coo`2L0oooG@001Ooonf[o
0?oKo`3ofonb0?oooo]Z00;oX_l000Co0?lToookJ_oonf[ooo]Z0_l0o``5oookJP;ooi@000?ooo]Z
ool0;?oo02`00_oo01<00ol0N_oooo]ZoookJP04oookJP;o0?oL0_l=0?l4oookJP;o0?Wo0ooonfX2
ool0S@03oookJ_ooN`3oog/000;ooeL04OoonfX2ool;00Wooo]Z0_ooc@0ToookJP00>?oonfX2o`1Q
o`Wooo]Z00Co7P3ooookJ_l0ocWooo]Z3_oo:006oookJP04o`3oBooonf[ooo]Zoo?o00?ooo]Z2?oo
:0000ooonf[ood80oookJP02oookJP03om_o0?oonf[oobP000;oo`d00_oonfX00ooo08Koo`2/o`0f
o`02oookJP04o`3od_oonf[ooo]Zool0n@Wooo]Z00?oo`P0oookJ_oonfX00_l0Q_l4oookJP04o`3o
Tooom`3ooo]Zoe;o00Cooo]Z00Goo`1joookJ_oonf[ooo]Zool0B@04oookJP03ool00?oo6@3oo`00
00?oo`0000?o0>_oo`3oS?oonfX00ooonfX00ooi0?oooo]Zool00006ool000;ooo]Z0_oo:002ool0
0003ooT0oooo003oo`0000;oo`000_oonfX00omFo`3ooo]Zool00007ool000Wooo]Z2?ooN@02oook
JP03oc?o0?oonf[ooo]Z00GoogT01OoonfX01?l07?oooo]Zoomi0?oo0005oookJPOoobP02OooN@0A
oookJP[oolT00_oo:002ool000_oobP00_oo=002ocWo00Coo`0c2ooo0005oookJP?oi?l00_oo:000
1?oonf[oo`1>ool0C_oonfX3o`3oO@03odH0oooonf[ooo]Z00?ooo]Z0_oo:0001?n40?oooo]ZoonJ
0?ooVP02oookJP;oobP000?oDOl0oookJ_oonfX00_oo0003oookJP?oo`1S2OooN@02ool0T@04o`3o
__ooN@3oogT0ool0W0;ooed00_oonfX2o`3of`04ok80oonRo`3oobP0oolX00?oogT00_l0o``00ooo
N@3ooo]ZoookJP03oookJP;ooi@00_oo02`01?oonf[oo`0Cool04ol0N_l4oookJP;oobP00_l0om`2
o`d0o`OoobP00_oonfX2ool0S@CoobP04OoonfX2ool;06;ooo]Z0_l0HOl00ol0NOoooo]ZoookJP06
oookJP;o7P3o00?o0?lioookJ_oonfX00_oonfX01Ooo0>cooo]ZoonD0?oo03Ooa`3o00cooo]Z0_l0
od/00ooonf[olol0oookJP05oookJP;o0?m100Coo`1UoookJ_oonf[ooo]Z0_oo@P02oookJP04om_o
0?oonf[o0?oCoookJP;oo`d00_oonfX2ool0[0?ooo]Z00Co0?oBoookJ_oo0?Woo`3i2?oonfX00ooo
203ooo]ZoookJP02o`26o`Cooo]Z00Co0?nCoookJ_oom`3oD_l01OoonfX01Ooo07[ooo]ZoookJ_oo
nf[oo`1900Cooo]Z00?ooaT0oookJ_nFo`000_oonfX00ol0jooo0?n<oookJP04oookJP05ooT0oooo
nf[ok`3oonl0oom8o`002OoonfX00ooi0?ooJ`3ooookJP04oookJP03oeKo0?oonf[ooo]Z01Cooo]Z
00?o097ooookJ_l0ob/00ooonfX01Olco`3ooo]ZoookJ_oonf[oo`1d00Wooo]Z00?o01coooT0oooo
nfX02OoonfX01?l0003o00Koo`000?l00003oookJP03o`3o<?oonf[ooo]Z01?ooo]Z2_oXo`0<oook
JP?oo`310ooo=002ocWo00Coo`0c00?oo`3Oo`24ool0Q?l00_l0Q?l3oookJP?o0?nI1OoonfX3onCo
00;ooo]Z0ooo04h3o`3oO@;oAP3o1OoonfX2oh@0o`03oookJ_ooVP3ooiX000Cooo]Z0_mAo`07oook
JP;oo`1S0_l0of<00oo]0?oooo]ZoookJP04oookJP;oo`2A00?o0?nno`3oL?oonfX00_oo09`2oomM
0003oookJ_l0om_o0?oK00;o/P3o0_nRo`001?l0obCooo]ZoookJ_oonfX2o`3o30Gooo]Z0oooU002
ool0;0;oo`0C00?o07[ooookJ_oonfX01?oonfX2o`3og0;o3@3o1?oonfX2o`3io`?ooo]Z0_oo08d0
0ooonf[oog/0oomk0002oomG017ooo]Z0_oo2`0]oookJP00>_oonfX00ol0HOoo07WooookJP07oook
JP;o7P3o0_l0ocT>oolX00Kooo]Z0_l0od/00ooonf[olol0oo?o0002oookJPWoobP00_oo@P02oook
JP;ofol000?oobP0o`3odooo3@000_oonfX01Ooo08Koo`2/ool0[?l0=_oooo]Z00;o0?oB00?ooo]Z
ool0nOoonfX02?oonfX2ool800;ooo]Z00?o08KooookJ_oonfX00_oonfX2o`3oT`03ooog0?mBo`3o
D_l000?ooo]Z0_oo07X2oookJP04ool0BOoonf[ooo]ZoookJP;oo`0000?ooaT0ool00?oo00000ooo
00000ol0ohcooo]ZoookJP02oookJP03ooT0oooonf[oo`0000Ooo`0000?ooo]ZoolX0?oo:0000_oo
00000ooi0?ooo`00ool00003ool00003oookJ_mFo`3oo`0000Koo`002ooonfX6oomi00?ooo]Z00?o
<ol0oookJ_oonfX01_ooN@05oookJP03o`0Loooi0?oooo]Z00Gooo]Z1ooo:007oomi00gooo]Z1_oX
o`0:ooo900;oobP01Ooo0009oolX00Coo`310olio`05ool0<`Ooo`000_l0oiT5oookJPCoobP000Go
oo]Zool0C_oo04koo`1>oookJP03o`3oO@03ooo90?oonf[ooo]Z00?ooo]Z0on40?l3oonJ00;ooo]Z
0omAo`02ool000Gooo]Z0_oo06<2o`3oH`OoogT00_oo09401?l0okkoogT0oookJ_oo09`2oolX00;o
oo]Z0_l0om/3oolX0004oj;o0?ooN@3oogT0oomi00;o0?l<1_oonfX2oonD00;oo`0/00Cooo]Zoomi
0?ooN@3o07[o1_oonfX2oomi00;o3@3o1_oo:003oookJP;oo`2=00Coog/0oolX0?oo:03ooeL04Ooo
nfX2ool;06;ooo]Z00?o067oo`1ioooonfX02?oonfX00olN0?oo0?lio`3o>@03oookJP04ool0k?oo
nf[ooo]Zool0=`;oa`3o3?oonfX01?l0od_ooo]Zoo?o0?oco`06oookJP03o`3o@Ooo06Gooo]Z00?o
oo]Z00?ood80oookJ_oonfX00_oKo`02o`3od`07oookJ_oo3@3ooo]ZoookJ_oo08Koo`2/o`0fo`02
oookJP04o`3od_oonf[ooo]Zool0n@Sooo]Z0_oo2002oookJP03o`26oooonf[ooo]Z00;ooo]Z0_l0
oi<2ooog0003oe;o0?oonf[ooo]Z00;ooo]Z00Goo`1joookJ_oonf[ooo]Zool0B@04oookJP03oolI
0?oonf[oU_l000;ooo]Z00?o0>_oo`3oS?oonfX01?oonfX01Ooi0?oooo]ZoookJ_o_0?ooB?l000Wo
oo]Z00?on@3oof/0oooonfX01?oonfX00omFo`3ooo]ZoookJP0CoookJP04o`2Aoooonf[ooo]Zo`3o
:`;ooo]Z00?o<ol0oookJ_oonfX00_oonfX00ooo07Cooo]ZoookJP06oookJP03o`0Loooi0?oooo]Z
00Wooo]Z1Ol000000ooonf[o0?l`oookJP0?oookJPKoj?l02_oonfX:onSo00Gooo]Z1_oo0<43ocWo
00Coo`0c00?oo`3Oo`24ool0Q?l00_l0Q?l2oookJP?o0?nI1OoonfX2onCo0003og?o0?oonf[ooo]Z
00?oo`1>0ol0ogd2odH0o`Cooo]Z0on40?l3oonJ00?ooo]Z0omAo`07oookJP04ool0Hol0of?o0?mS
ond0o`Kooo]Z0_oo09400ol0okko0?m`oookJP02ool0W0;ooed000Gooo]Zo`3ofol0om_o0?oKok80
o`03oj;o00?ooo]Z0_l0o``6oookJP;ooi@00_oo02`2ool04`03o`1joooonf[ooo]Z00Cooo]Z0_l0
om`2o`d0o`Cooo]Z0_l0nOl3oookJP;oo`2=00?ooo]Zoomk0?ooN`000_ooE`0AoookJP;oo`/0:ooo
nfX003_ooo]Z00?o067oo`1ioooonfX02?oonfX00olN0?oooo]Zo`3o>@0=oolX00Sooo]Z00Co0?m;
oookJ_oonf[olol00_oonfX:oolX0007oom20?oonf[ooo]ZoookJ_oKo`3ooo]Zo`3od`02ool=0005
oookJ_oo08Koo`26ool0[?l0=_l00_oonfX01?l0om;ooo]Zool0nOoo0?T9oookJP04ool80?oonf[o
obP0oolX00Gooo]Z00Co0?nCooog0?oonf[oD_l01?oonfX00ooo07[ooo]ZoookJP02ool0B@;ooo]Z
0_oo00000ooo6@3oo`00ool00004ool00004oolX0?oonf[ooo]ZoookJP;on@3o2Ooo0002oolX0003
ool00?oi0?ooo`0000Goo`0000?ooo]ZoeKo0?oo00001?oo000<oookJPGoogT000?o0?l[oookJ_oo
nfX00_oonfX00olco`3ooo]Zoomi0007oomi00?ooo]Z00?o01coooT0oooonfX01?oonfX9oolX00?o
ogT000?oobP0oookJ_oonfX02_oonfX3onSo00Kooo]Z3?oob@08ool000SoU?l00_oo:006ool0`@;o
>Ol01?oo03<4oiCo0004oookJ_l0oiWo0?nIo`3oV@;ooo]Z1_oo:002ooo900?oo`1>00GoolT0o`3o
OOl0oggoolT0odH0o`05oookJP?oQ03o0_ooVP02oookJP05ool00?mAo`3oDOl0oe7o0?oo00001Ooo
nfX2ool0H`?o0?mS1_ooN@02ool0T@04o`3o__l0og3ooo]Zool0W0;oobP000?oogT0oolX0?oo:000
0ooo:002oj;o00?oogT00ol0o``5oookJP;ooi@00_ooN@001?oonf[oogT0oomi0?l0N_l3oookJPCo
ogT000?o0?oLo`d0ool=0?l01Ooo:0001?n10?oooo]ZoookJ_oonfX3ool0S@03oomk0?ooE`3ooeL0
017ooo]Z0_oo2`1QoookJP03o`1Qool0NOoo07Wo00Sooo]Z00?o7P3ooookJ_l0ocT00ooonfX2ool0
k004oookJ_oo03Oooo]ZolL0o`cooo]Z0_l0od/00ooonf[olol0oookJP05oookJP03o`3o@Ooo06Go
o`1U00?ooo]Z0_oo@P02oookJP04om_o0?oonf[o0?oCoookJP;oo`d000Cooo]Zool0Q_oo0:coo`2/
0_oonfX01?l0om;ooo]ZoookJ_oo0?T9oookJP04ool80?oonf[ooo]Zo`26o`Gooo]Z00Co0?nCoook
J_oom`3oD_l01?oonfX2ool0NP;ooo]Z0_oo04T3oookJP03oolI0?oonf[oU_l000;ooo]Z00?o0>_o
o`3oS?oonfX01?oonfX01Ooi0?oooo]ZoookJ_o_0?ooB?l000Sooo]Z00?on@3oo`3oMom[0?l01Ooo
nfX00omFo`3ooo]ZoookJP0CoookJP03o`2Aoooonf[o0?l[00?ooo]Z00?o<ol0oookJ_oonfX00_oo
nfX00ooo07Cooo]ZoookJP05oookJP03o`0Loooi0?oooo]Z00Wooo]Z1?l00002oookJP03o`3o<?oo
nf[ooo]Z00cooo]Z0_oXo`0JoookJPOoj?l01?oonfX5ool0`@;o>Ol01?oo03<01?oo0=oo08Coo`24
ool0Q?l2oookJP?o0?nI1?oonfX3onCo00;oLol000Cooo]Zool0C_oo04koo`1>0_l0ogd3odH0o`Co
oo]Z0on40?l2oonJ00Cooo]Z0omAo`06oookJP05ool0Hol0of?o0?mSo`3oHoo]0?l01OoonfX2ool0
T@05o`3o__l0og3ooo]ZoookJ_oo09`00_ooG@02oookJP;o0?oK00Co/P3ooookJ_nRo`3oX_l00ooo
nfX2o`3o30Kooo]Z0_ooU002ool0;0;oo`0C00?o07[ooookJ_oonfX01?oonfX2o`3og0;o3@3o1?oo
nfX2o`3io`?ooo]Z0ooo08d2oomk00;ooeL04OoonfX2ool;02Wooo]Z000loookJP;o067o2OoonfX2
oah0o`03o`3o>Ooo:03oobP000WoobP02_oonfX2o`3oB`04oookJ_oco`3olol0oookJP[oobP00_oo
@P02oookJP05om_o0?oonf[o0?oCoookJ_oo3@000_oonfX01_oo08Koo`2/oolX0?oo:03ooo]Zo`3o
dP;ooo]Z00?oo`3ioookJ_oonfX01ooonfX00ooo203oobP0oolX0002oolX00Cooo]Z00Co0?nCooog
0?oonf[oD_l01?oonfX01Ooo07[ooo]ZoookJ_oonf[oo`1900;ooo]Z0_oo00000ooo6@3oo`00ool0
0005ool00005oolX0?oonf[ooo]ZoookJ_oi0?l02Ooo0002oolX0003ool00?oi0?ooo`0000Koo`00
00CoE_l0ool00?oo003oo`003_oonfX3oomi0003o`2Aoooonf[o0?l[00Cooo]Z00?o<ol0oookJ_oo
N@001oooN@02oookJP03o`0Loooonf[on@3o00?ooo]Z2_oo:0000oooN@3oobP0oolX000<oookJP03
onSo0?oonf[ooo]Z00Oooo]Z1?oob@08oookJP_oo`001?ooN@000ooXo`3oobP0oolX0003oolX0003
oookJ_l0oc3oo`0m00Coo`310_lio`03ool0<`?oU?l00_oonfX00ol0oiWoobP0oolX0007oolX0003
onCo0?mco`3ooo]Z00?oo`1>0ol0ogd2odH0o`;ooo]Z0_oob@000ooonf[oQ03ooh@0o`03oonJ00?o
o`000omAo`05oookJP?oogT00ol0of<5oomi00?oo`2A00?o0?nnoookJ_oo09`02?oo:003oj;o00;o
ogT000?ooo]Zo`3o3?l0o``01OoonfX3oonD00CoogT00_l0N_l5oomi00;o0?oL0_l=0?l2oookJP;o
obP000?o0?Wooh40oooonfX00ooonfX2ool0S@03oomk0?ooE`3ooeL0017ooo]Z0_oo2`1PoookJP;o
067o00?o07WooookJ_oonfX01_oonfX2oah0o`;o0?li0ooonfX01Ooo0>cooo]Zool0=ooo03Ooa`3o
00gooo]Z00Co0?m;oookJ_oco`3olol01OoonfX00ol0od7ooo]Zool0I@04oookJP06oom20?oonf[o
oo]Zom_o0?oonf[o0?oC0_oonfX01ooo3@3ooo]ZoookJ_oo08Koo`2/o`0foooonfX00_l0om800ooo
nf[oo`3ioookJP08oookJP04ool80?oonf[ooo]Zo`26o`Gooo]Z00Co0?nCoookJ_oom`3oD_l01Ooo
nfX01Ooo07[ooo]ZoookJ_oonf[oo`1900?ooo]Z00?ooaT0oookJ_nFo`000_oonfX00ol0jooo0?n<
oookJP04oookJP05ooT0oooonf[ooo]Zonl0oom8o`002?oonfX00ooi0?ooN?l0of/0o`05oookJP03
oeKo0?oonf[ooo]Z01?ooo]Z00?o097ooookJ_l0ob/00ooonfX01Olco`3ooo]ZoookJ_oonf[oo`1d
00Oooo]Z00?o01cooookJ_oi0?l02OoonfX4o`0000;ooo]Z00?o0?l`oookJ_oonfX02ooonfX00ooX
o`3ooo]ZoookJP0QoookJPGoj?l00_oonfX2o`3o<0Goo`3100Go>Ol0ool0<ooo03?oo`0cool0g`03
o`24o`;ooo]Z0ol0oiT4oookJP?oi?l00_mco`000ooonf[oo`1>ool0CP03o`3oO@?oAP3o1?oonfX2
oh@0o`?ooiX01?oonfX3oe7o00Gooo]Z0_oo06<3o`3oH`03ond0oooonf[ooo]Z00;ooo]Z0ooo0940
1?l0okkooo]ZoookJ_oo09`3oomM0005oookJ_l0om_o0?oKok80oooonfX00_nRo`000ol0obCooo]Z
oookJP02o`3o30Kooo]Z0_ooU002ool0;0?oo`0C00?o07[ooookJ_oonfX00ooonfX2o`3og0;o3@3o
1?oonfX2o`3io`Cooo]Z0_oo08d2oomk00;ooeL04OoonfX2ool;02Oooo]Z000noookJP03o`1Qool0
NOoooo]Z00Sooo]Z00?o7P3ooookJ_oo:0002_oo:00;oookJP04o`3oBooonf[ooo]Zoo?o00[oobP0
0_oonfX00ooo@P3ooo]ZoookJP02om_o0003o`3odooonf[oo`d000;ooo]Z00?oo`26ool0[?oo0:`0
0_oo:0001?l0om;ooo]ZoookJ_oo0?T9oookJP03ool00?oo:03oobP000;oobP01?oonfX00ol0oi?o
o`00ool00002oolX00?ooo]Z00Goo`1joookJ_oonf[ooo]Zool0B@02oookJP;oo`0000?ooaT0ool0
0?oo00001Ooo0002oolX00;ooo]Z00?on@3oool00?oo00001Ooo00000ooonf[oobP0oolX0002ool0
0003ooT0oooo003oo`0000Goo`0000?oE_l0ool00?oonfX03ooonfX01_ooN@3ooo]ZoookJ_l0TOoo
oo]Zo`3o:`Cooo]Z00?o<ol0oomi0?ooN@001oooN@02oookJP03o`0Loooi0?oooo]Z00?ooo]Z0_oo
000:oolX00_ooo]Z00?oj?l0oookJ_oonfX05?oonfX>ool000;oogT01ooo:0000ooXo`3ooo]Zoook
JP02oiCo00Coo`3100Co>Ol0ool0<ooo03?oo`0c0_nDo`000ol0Q?ooobP0oolX0005oolX00;oolT0
0_oo:004ooo900?oo`1>0_l0ogd2odH0o`?oolT00_oonfX3ool000?ooiX00ooo0003oe7o00;ooo]Z
1_ooN@02o`3oH`CoogT00_oonfX2ool0T@03o`3o__l0og3oobP000OoobP00_ooN@02oj;o0003oomi
0?oonf[ooo]Z00;o0?l<1_oonfX2oonD00[oogT00_oonfX00ol0omco3@3oo`d0o`03oookJP;o0?Wo
00?oP@3ooookJ_oonfX00_oonfX2ool0S@04oomk0?ooE`3ooeL0oomG013ooo]Z0_oo2`1PoookJP03
o`1Qool0NOoo07Wo00Sooo]Z00?o7P3ooookJ_l0ocT00ooonfX01Ooo0>cooo]ZoookJ_oo03Ooa`3o
00gooo]Z00Co0?m;oookJ_oonf[olol01OoonfX2o`3o@@03ool0IOoonf[ooo]Z00;ooo]Z00?ood80
oookJ_oonfX00_oKo`001?l0om?ooo]ZoookJ_oo3@02oookJP03ool0Q_oo0:co03Ko00;ooo]Z00Co
0?oBoookJ_oo0?Woo`3i2?oonfX2ool80003oookJ_l0Q_oooo]Z00Cooo]Z00?o0?nCoookJ_oom`00
0_mBo`04oookJP05ool0N_oonf[ooo]ZoookJ_oo04T00ooonfX00ooo6@3ooo]ZoiKo0002oookJP03
o`3[ool0ohcooo]Z00Cooo]Z00Gon@3ooookJ_oonf[ok`3oodSo0008oookJP03ooT0oomho`3ooo]Z
00Gooo]Z00?oE_l0oookJ_oonfX04_oonfX01?l0TOoooo]ZoookJ_l0ob/3oookJP05oc?o0?oonf[o
oo]ZoookJ_oo07@01ooonfX00ol07?oooo]ZooT0o`08oookJPCo00000_oonfX00ol0oc3ooo]Zoook
JP09oookJP;oj?l0:OoonfX4onSo00;ooo]Z0_l0oc000ooo03goo`31ool0`@02ool0`@?oo`0c00Co
o`3Oo`24ool0Q?oo08Co0_oonfX4o`3oV@?ooo]Z0ooTo`02og?o0003oookJ_oo04koo`1>00;o0?mm
00Con@3oodH0oom60?ooAP3o0ooonfX00on40?ooo`2Bool0TP03oonJ00Cooo]Z0omAo`05oookJP;o
o`1S0_l0of<00oo]0?oooo]ZoookJP03oookJP;oo`2A00?o0?nno`3oL?oonfX00_oo09`2oomM0005
oookJ_l0om_o0?oKok80oooonfX00_nRo`000ol0obCooo]ZoookJP03o`3o30Gooo]Z0_ooU0000ooo
nf[oo`0/ool0;002ool04`03o`1joooonf[ooo]Z00Cooo]Z00Co0?oLo`d0ool=0?oo3@3o0ooonfX2
o`3io`Cooo]Z0_oo08d01?oonf[oog/0oomG0?ooE`0AoookJP;oo`/09OoonfX002[ooo]Z0_l0oeHC
oookJP;o067o2OoonfX=oolX00_ooo]Z00Co0?m;oookJ_oonf[olol02?oo:004oookJP;ood800_oo
nfX00ooKo`3o0?oCoookJP02ool=00;ooo]Z00Goo`26ool0[?oo:03oobP0o`3odP02oookJP;oo`3i
1ooonfX2ool000GoobP00ooonfX00ol0oi?oo`00ool00002oolX00?ooo]Z00Koo`1joookJ_oonf[o
oo]Zool0BOoonfX3ool00003oolI0?oo003oo`0000Coo`001?oo:0000ooonf[on@3oool00005ool0
00;ooo]Z0_oo:002ool00003ooT0oooo003oo`0000?oo`000_oonfX00omFo`3ooo]ZoookJP0Boook
JP03o`2Aoooonf[o0?l[00?ooo]Z00?o<ol0oookJ_ooN@002?ooN@000ooonf[oobP0ooT0o`07oook
JPWoobP02_oonfX00ooXo`3ooo]ZoookJP0AoookJP?o1@3o4?oo00000omN0?ooobP0oolX0007oolX
0003onSo0?nDo`3oU?l000CoU?l00ooo0<400ooo=03oo`0cool0<`02ool0<`KoobP01?oob@02oolX
00GoolT00_oo04h2o`3oO@GoolT000?ooo]Zool00?oo00000ooo0003oonJ00;oo`0000?ooo]Zoe7o
0?mAo`002?ooN@03o`3oH`?oogT00_oonfX3ool0T@03o`3o__oo:03oobP000GoobP00_l0om/01?oo
nf[oX_l0oj;o0?l0ob@2oookJP;o0?l<1_oonfX2oonD00WoogT00ooonfX00ol0omco3@3oo`d0o`03
oookJP?o0?Wo1?oonfX2ool0S@;oog/00_ooE`0@oookJP03ool;0?oonf[ooo]Z04Wooo]Z0_l0oeHC
oookJP;o067o00?o07WooookJ_oonfX01_oonfX2oah0o`04o`3o>Ooonf[ooo]ZoookJP;oo`3/00Co
oo]Zool0=oo70?ooa`3o3?oonfX2o`3oB`03oookJ_oco`3ooo]Z00Gooo]Z00?o0?m1ool0IOoonfX0
0ooonfX2oom200;ooo]Z00Cofol0o`3odol0om?ooo]Z0_oo3@001?oonf[oo`26ool0[?oo0:`2oook
JP04o`3od_oonf[ooo]Zool0n@Wooo]Z00?oo`P0oookJ_l0Q_l01OoonfX01Ol0oi?ooo]Zooog0?oo
nf[oD_l000?ooo]Z00?oo`1joookJ_oonfX00_oonfX01ooo04Wooo]ZoookJ_oonf[ooaT0oookJ_nF
o`000_oonfX00ol0jooo0?n<oookJP04oookJP04ooT0oooonf[ooo]Zonl0o`Wooo]Z00?on@3oogSo
0?oonfX01OoonfX00omFo`3ooo]ZoookJP0BoookJP03o`2Aoooonf[o0?l[00?ooo]Z00Go<ol0oook
J_oonf[ooo]Zool0M007oookJP03o`0Loooonf[on@3o00Sooo]Z1?l00002oookJP03o`3o<?oonf[o
oo]Z00Sooo]Z00?oj?l0oookJ_oonfX04OoonfX<o`D0o`coGP3o1?oonfX4onSo00?ooo]Z00?o0?l`
ool0?Ooo0<400_oo0<44ool0<`03ool0gol0Q?oo08Co00?ooo]Z1?l0oiT2oookJP?oi?l00_mco`00
1?oonf[oo`1>o`3oOOl0ogd2ooT0o`?oAP3o0ooonfX3ool0TP?ooiX01?oonfX2oe7o00Kooo]Z00Go
o`1So`3oHol0of?o0?mSond0o`04oookJP?oo`2A00Co0?nnoookJ_oonf[oo`2L0_ooG@001Ooonf[o
0?oKo`3ofol0om_o/P3o00?oX_l00ooonfX2o`3o30Gooo]Z0_ooU0000ooonf[oo`0/ool0;002ool0
4`03o`1joooonf[ooo]Z00Cooo]Z0_l0om`2o`d0o`?ooo]Z0_l0nOl01?n10?oooo]ZoookJ_oonfX2
ool0S@04oookJ_ooN`3ooeL0oomG017ooo]Z00?oo`/0oookJ_oonfX08_oonfX002cooo]Z00?o0?mF
oookJ_oonfX04_oonfX00ol0HOooobP0oookJP06oookJPgoobP03?oonfX2o`3oB`03oookJ_oco`3o
obP000GoobP000?oo`1UoookJ_oonfX01?oonfX01Ooo@P3ooo]ZoookJ_oKo`3o0?oC00;ooo]Z00Go
o`d0oookJ_oonf[oo`26ool0[002oolX00;o0?oB0_oonfX00ooo0?Wooo]ZoookJP05oookJP03ool0
0?oo:03oobP000GoobP00_oonfX01?l0oi?oo`00ool00?oo0002oolX00;ooo]Z00Koo`1joookJ_oo
nf[ooo]Zool0BOoonfX3ool00003oolI0?oo003oo`0000;oo`0000?o0>_oool00?oo00000ooo:000
0ooo003on@3oool00006ool000?oobP00_oo00001?oi0?ooo`00ool00?oo0004oookJP03oeKo0?oo
nf[ooo]Z017ooo]Z00Co097ooookJ_oonf[o0?l[0ooonfX00olco`3oogT0oomi0005oomi00?ooo]Z
00?oobP0ooT0oooonfX01_oonfX9oolX00Sooo]Z0_ooN@0?oookJPGo1@3o0ooonfX=ool000?oogT0
3Ooo:007oiCo00?oo`3100?ooc@0oolY0?oo03<01?oo03<00ooo:03oolT0ooo90004ooo900;oobP0
1ooob@03o`3oO@CoolT01ooo0003oonJ00;ooo]Z0omAo`000ooonf[oogT0oomi0005oomi00?o0?mS
00?oogT0oookJ_oo:0000_oo:002ool0T@;o0?nn1_oo:002o`3of`06oookJ_nRo`3oX_l0oj;o0?l0
obCooo]Z0_l0o``2oolX00Cooo]Z00?ooi@0oomi0?ooN@002?ooN@03oookJP03o`3og?l=0?oo3@3o
00Cooo]Z0_l0nOl01?n10?oooo]ZoookJ_oonfX2ool0S@04oookJ_ooN`3ooeL0oomG05cooo]Z00?o
0?mFoookJ_oonfX04_oonfX00ol0HOoo07Woo`1io`08oookJP03oah0ool0ocWo0?li00?ooo]Z00Go
o`3/oookJ_oo03Ooo`0golL0o`0=oookJP03o`3oBooonf[olol000Kooo]Z00?o0?m1ool0IOoonfX0
1?oonfX01_oo@P3ooo]ZoookJ_oKo`3ooo]Zo`3od`;ooo]Z00Goo`d0oookJ_oo08Kooo]Zool0[002
oookJP04o`3od_oonf[ooo]Zool0n@Wooo]Z00?oo`P0oookJ_l0Q_l01OoonfX2o`3oT`03ooog0?oo
nf[oD_l000?ooo]Z00?oo`1joookJ_oonfX00_oonfX01ooo04Wooo]ZoookJ_oonf[ooaT0oookJ_nF
o`000_oonfX00ol0jooo0?n<oookJP04oookJP04ooT0oooonf[ooo]Zonl0o`Wooo]Z00?on@3oogSo
0?oonfX01OoonfX00omFo`3ooo]ZoookJP0AoookJP04o`2Aoooonf[ooo]Zo`3o:`?ooo]Z00Go<ol0
oookJ_oonf[ooo]Zool0M006oookJP03o`0Loooonf[on@3o00Sooo]Z1?l000000ooonf[o0?l`oook
JP09oookJP03onSo0?oonf[ooo]Z00gooo]Z1Ol50?lCoookJPGo1@3o1OmN0?l3oookJPGoj?l00ooo
nfX3ool0`@03oolY0?oo03?oo`0c00?oo`0c00?o08CooookJ_oonfX00_oonfX3o`3oV@;ooo]Z0ooT
o`02og?o0004oookJ_l0oggo0?mmo`3oO@;on@3o0om60?l3oookJP?oo`2B0oooVP03oookJP?oDOl0
1OoonfX2ool0H`?o0?mS00?ok@3ooookJ_oonfX00_oonfX3ool0T@03o`3o__oonf[oo`2L00;ooed0
0_oonfX2o`3of`05ok80oooonf[oX_l0oj;o0?l0ob@00_oonfX2o`3o30Gooo]Z0oooU002ool0;0;o
o`0C00?o07[ooookJ_oonfX01?oonfX2o`3og0;o3@3o0ooonfX3o`3io`?ooo]Z0_oo08d01?oonf[o
og/0oomG0?ooE`0doookJP00;OoonfX00ol0oeKooo]ZoookJP0AoookJP04oolX0?l0HOooobP0oolX
00Kooo]Z3Ooo:00=oookJP03o`3oBooonf[olol000OoobP000?oo`1UoookJ_oonfX00ooonfX01?oo
@P3ooo]ZoookJ_oKo`02o`3od`05oookJ_oo:03oobP0oookJ_oo08H01?oo:0001?l0om;oobP0oook
J_oo0?T7oookJP03ool00?oo:03oobP000KoobP000?ooo]Zo`3oTooo00000ooo0002oolX0003oook
J_oo07[ooo]Z00;ooo]Z00?oo`19oookJ_oo00000_oo0002oolX0003ool00?oo:03o0>_o00?oo`00
0ooo:0000ooi0?ooo`00ool00006ool000;oobP00ooo00000ooi0?ooo`00oookJP04oookJP03oeKo
0?oonf[ooo]Z01;ooo]Z00?o097ooookJ_l0ob/01?oonfX00olco`3oogT0oomi0003oomi00Cooo]Z
0_oo:0000ooi0?oooo]ZoookJP04oookJPWoobP01ooonfX3oomi00cooo]Z0ol50?l8oookJPSoo`00
0_oonfX6oomi00ooobP02?nDo`05ool0`@;o>Ol01?oo03<5ooo90004oolX0?l0oiWo0?nIooo900;o
ogT01?oob@03o`3oO@;oolT02Ooo0002oonJ00?ooo]Z0omAo`06oookJP;oogT00_l0of<01Oo]0?oo
oo]ZoookJ_oonf[oobP000;oo`2A0_l0okh5oolX0005oookJ_oo:03oobP0oolX0?oonfX00_nRo`00
0ol0obCooo]ZoolX0002oolX00?ooo]Z3?ooN@04oookJP03o`3og?l=0?oo3@3o00Cooo]Z0_l0nOl0
1?n10?oooo]ZoookJ_oonfX2ool0S@04oookJ_ooN`3ooeL0oomG05_ooo]Z0_l0oeHCoookJP03o`1Q
oooonf[o07Wo00Sooo]Z00?o7P3ooookJ_l0ocT00ooonfX01Ooo0>cooo]ZoonD0?oo03Ooa`3o00go
oo]Z00?o0?m;oookJ_oco`001_oonfX2o`3o@@03ool0IOoonf[ooo]Z00;ooo]Z00Kood80oookJ_oo
nf[ofol0oookJ_l0om<2oookJP05ool=0?oonf[oo`26oookJ_oo0:`00_oonfX01?l0om;ooo]Zoook
J_oo0?T9oookJP03ool80?oonf[o08Ko00Kooo]Z00Co0?nCooog0?oonf[oD_l00ooonfX00ooo07[o
oo]ZoookJP02oookJP05ool0BOoonf[ooo]ZoookJ_oo6@000ooonfX00ol0jooooo]Zo`3oS004oook
JP05ooT0oooonf[ooo]ZoookJ_o_0?l02OoonfX00ooi0?ooN?l0oookJP04oookJP03oeKo0?oonf[o
oo]Z01;ooo]Z00?o097ooookJ_l0ob/01?oonfX01?lco`3ooo]ZoookJ_oo07@6oookJP03o`0Loooo
nf[on@3o00Sooo]Z1?l000000ooonf[o0?l`oookJP08oookJP03onSo0?oonf[ooo]Z00_ooo]Z0ol5
0?lOoookJP?o1@3o1OmN0?l3oookJPGoj?l000?ooo]Zool0`Ooo0<400_oo0<400ooo=03o>Ol0ool0
<`03ool0<`04o`24oooonf[ooo]ZoookJPCo0?nI00Cooo]ZonCo0?oTo`3oi?l00_mco`001?oo04ko
0?mmo`3oOOl0ogd2ooT0o`?oAP3o0ooonfX3ool0TP;ooiX01?oonfX3oe7o00Gooo]Z0_oo06<2o`3o
H`03ond0oooonf[ooo]Z00?ooo]Z0_oo09400ol0okkooo]ZoookJP03oomM0005oookJ_l0om_o0?oK
o`3ofooonfX00_nRo`02o`3o9003oookJ_l0o`co0?l<00Kooo]Z0_ooU0001?oonf[oo`0/ool04ooo
01<2o`1jo`Kooo]Z00?o0?oLo`d0ool=0?l01?oonfX2o`3io`?ooo]Z0_oo08d00ooonf[oog/0oomG
0002oomG037ooo]Z000^oookJP03o`3oE_oonf[ooo]Z017ooo]Z00?oobP0o`1Qool0HOl00_oo:005
oookJPWoobP000?ooo]ZoonD0?oo:0000_oo:00<oookJP;oo`0000Colol0oolX0?oo:03oobP00ooo
nfX00ooo:03oo`1UoookJP04oookJP06oom20?oonf[ooo]Zom_o0?oonf[o0?oC2Ooo:0000ol0om;o
obP0oolX0002oolX00Gooo]Z0_oo0008oolX0003ool00?l0oi?oo`0000?oo`000_oo:0001_oonf[o
o`1joookJ_oonf[oo`19oookJP?oo`001Ooo:0000ol0joooo`00ool00002ool000;oobP000?on@3o
ool00?oo00001_oo00000ooo:03ooo]Zool00002ool00003ooT0oomho`3ooo]Z00Cooo]Z00?oE_l0
oookJ_oonfX04OoonfX01?l0TOoooo]ZoookJ_l0ob/3oookJP03oc?o0?ooN@3oogT000;oogT01Ooo
nfX2oolX0003ooT0oooonf[ooo]Z00?ooo]Z2Ooo:006oookJPCoogT02ooonfX2o`D0o`_ooo]Z0ooo
0007oookJPKoogT04?oo:003oeh0o`Cooo]Z1OoXo`05ool0`@03ooo90?oo03?oo`0c00;oo`0c1?oo
b@000ol0oiWoogT0oomi0002oomi00GoolT00ol0ogd00ooob@3oo`00ool00007ool000?ooiX00ooo
nfX3oe7o00Kooo]Z00Goo`1So`3oHol0of?o0?mSond0o`03oookJP?oo`2A0_l0okh3oolX00?ooo]Z
0ooo:0000onRo`3oobP0oolX0004oolX0003oookJ_ooN@3oogT000_oogT01OoonfX00ol0omco3@3o
o`d0o`04oookJP?o0?Wo0ooonfX2ool0S@04oookJ_ooN`3ooeL0oomG05[ooo]Z00?oob/0o`3oE_oo
nfX04_oonfX2o`1Qo`03o`1ioooonf[ooo]Z00Kooo]Z00Co7P3ooookJ_l0ocWo0?li0_oonfX01?oo
0>cooo]ZoookJ_oo03L2olL0o`cooo]Z0_l0od/2oo?o00Kooo]Z00?o0?m1ool0IOoonfX00ooonfX0
1_oo@P3ooo]ZoookJ_oKo`3ooo]Zo`3od`;ooo]Z00Goo`d0oookJ_oo08Kooo]Zool0[002oookJP04
o`3od_oonf[ooo]Zool0n@Wooo]Z00?oo`P0oookJ_l0Q_l01_oonfX01?l0oi?oooL0oookJ_mBo`03
oookJP05ool0N_oonf[ooo]ZoookJ_oo04T01?oonfX01ooo6@3ooo]ZoookJ_oonf[o0>_ooookJ_l0
oh`01?oonfX01Ooi0?oooo]ZoookJ_oonf[ok`3o00Wooo]Z00?on@3oogSo0?oonfX01?oonfX00omF
o`3ooo]ZoookJP0BoookJP03o`2Aoooonf[o0?l[00?ooo]Z00Go<ol0oookJ_oonf[ooo]Zool0M006
oookJP03o`0Loooi0?oooo]Z00Oooo]Z1?l0000:oookJP03onSo0?oonf[ooo]Z00[ooo]Z0_l50?lW
oookJP?o1@3o1OmN0?l3oookJPGoj?l01Ooo0<400olio`3oo`0cool0<`02ool0<`04o`24oooonf[o
oo]ZoookJP?o0?nI00Cooo]ZonCo0?oTo`3oi?l00_mco`000ooo04ko0?mmo`3oO@02o`3oO@04ooT0
oom60?ooAP3oodH0o`?ooo]Z0_oo0983oonJ00Cooo]Z0_mAo`06oookJP05ool0Hol0of?o0?mSo`3o
Hoo]0?l01?oonfX3ool0T@03o`3o__oonf[oo`2L00;ooed00_oonfX3o`3of`?oX_l000Co0?lToook
J_l0o`co0?l<1_oonfX3oonD0005ool0;?oo01?oo`0Cool04ol0N_l01_oonfX00ol0omco3@3oo`d0
o`04oookJP;o0?Wo00?oP@3ooookJ_oonfX00_oo08d00ooonf[oog/0oomk0002oomG02oooo]Z000_
oookJP;o0?mF4_oonfX2oolX0004o`1Qoooo:03oobP0oolX00?ooo]Z2?oo:0001ooonf[oobP0oolX
0?ooU03oobP0ool0=ooo:0002ooonfX4ool00003oolX0?oonf[ooo]Z00?ooo]Z00?oobP0ool0IOoo
nfX01?oonfX01_oo@P3ooo]ZoookJ_oKo`3ooo]Zo`3od`WoobP000?o0?oBoolX0?oo:0000_oo:005
oookJP;oo`002Ooo:0000ol0oi?oo`00ool00003ool000;oobP000Goo`1joookJ_oonf[oo`19oook
JP03ool000GoobP000?o0>_oool00?oo00001?oo00000ooi0?ooo`00ool00004ool000Cooo]Z00Co
o`00oookJ_l0ogOon@3o1_oonfX00omFo`3ooo]ZoookJP0AoookJP04o`2Aoooonf[ooo]Zo`3o:`?o
oo]Z00?o<ol0oomi0?ooN@001_oonfX3oolX00Gooo]Z2Ooo:005oookJPGoogT02OoonfX2o`D0oaOo
oo]Z1?ooN@02oookJPSoobP01_oonfX5oomi00GoGP3o1?oonfX00ooXo`3oolT0ooo90002ooo900Go
o`311?oo03<00ooob@3oogT0oomi0006oomi00CoolT01?l0ogd00om60?ooo`00ool00005ool00004
ool0T_ooVP3ooiX0oonJ00?ooo]Z0omAo`05oookJP;oo`1S0_l0of<00oo]0?oooo]ZoookJP02oook
JP;oo`2A0_l0okh2oolX00;ooed00_oonfX00onb0?ooobP0oolX0005oolX00ooogT000?o07[ooook
J_oonfX01?oonfX2o`d0o`Gooo]Z0_l0nOl3oookJP;oo`2=00Cooo]Zoomk0?ooE`3ooeL0FOoonfX0
0ooo:`3o0?mFo`3oEP0CoookJP03o`1Qool0NOoooo]Z00Oooo]Z00Co7P3ooookJ_oonf[o0?li0_oo
nfX2ool0k004oookJ_oo03Ooo`0golL0o`gooo]Z00?o0?m;oookJ_oco`001_oonfX00ol0od7oo`1U
oookJP03oookJP06oom20?oonf[ooo]Zom_o0?oonf[o0?oC0_oonfX02?oo3@3ooo]Zool0Q_oonf[o
o`2/o`0foooonf[o0?oB0_oonfX00ooo0?Wooo]ZoookJP07oookJP03ool80?oonf[o08Ko00Kooo]Z
00Co0?nCooog0?oonf[oD_l00ooonfX01Ooo07[ooo]ZoookJ_oonf[oo`1900Cooo]Z00OooaT0oook
J_oonf[ooo]Zo`3[oooonf[o0?n<00Cooo]Z00?on@3ooookJ_oonfX02ooonfX00ooi0?oooo]Zoook
JP04oookJP03oeKo0?oonf[ooo]Z017ooo]Z00Co097ooookJ_oonf[o0?l[0ooonfX01?lco`3ooo]Z
oookJ_oo07@6oookJP03o`0Loooi0?oooo]Z00Oooo]Z1?l0000:oookJP03onSo0?oonf[ooo]Z00So
oo]Z0_l50?l^oookJP?o1@3o1OmN0?l3oookJPCoj?l000?ooo]Zool0`Ooo0<400ooo0<44ool0<`03
o`24oooonf[ooo]Z00?o0?nI00?ooo]ZonCo0?oTo`000_oTo`000omco`3oo`1>ool0CP03o`3oO@04
ooT0oom60?ooAP3oodH0o`?ooo]Z0_oo0983oonJ00?ooo]Z0omAo`05oookJP;oo`1S0ol0of<00oo]
0?oooo]ZoookJP02oookJP;oo`2A00?o0?nnoookJ_oo09`00_ooG@03oookJP?o0?oK0onRo`000ol0
obCo0?l<o`3o3007oookJP;ooi@00_oo02`2ool04`03o`1joooonf[ooo]Z00Cooo]Z00?o0?oLo`d0
ool=0?l01?oonfX2o`3io`03oh40oooonf[ooo]Z00?oo`2=00Cooo]Zoomk0?ooE`3ooeL0;OoonfX0
037ooo]Z00?o0?mFoookJ_oonfX03ooonfX3oolX0003o`1Qoooo:03oobP000;oobP00_oonfX9oolX
0006oookJ_oo:03ooo]ZoonD0?oo03OoobP02ooonfX4ool00003oo?o0?oonf[ooo]Z00?ooo]Z00?o
obP0ool0IOoonfX01?oonfX01_oo@P3ooo]ZoookJ_oKo`3ooo]Zo`3od`WoobP000?o0?oBoolX0?oo
:0000ooo:003oookJP;oo`002_oo:0000ol0oi?oo`00ool00004ool00008oolX0?oo07[ooo]Zoook
J_oo04Wooo]Zool00?oonfX6oolX0003o`3[oooo003oo`0000Coo`0000?on@3oool00?oo00000_oo
0008oookJP03ooT0oooo003ooo]Z00Cooo]Z00?oE_l0oookJ_oonfX04OoonfX01?l0TOoooo]Zoook
J_l0ob/3oookJP04oc?o0?ooN@3ooo]Zool0M0Gooo]Z0ooo:005oookJPOoo`000_oo:003oookJPKo
ogT02OoonfX00ol50?oooo]ZoookJP0<oookJPGoobP06_oonfX8oomi00;ooo]Z1OmN0?l9ooo900Co
o`312oooN@06ooo900?o0?mm0om60?l4ooo900;oo`2B0_ooVP04oookJP?oDOl01?oonfX2oomi00?o
0?mS00Cok@3ooookJ_oonf[ooo]Z0ooo0942o`3o_P04ool0W?ooG@3ooed0oomM00[oobP00_l0o``;
oomi00;o07[o1_oonfX2o`d0o`Gooo]Z0_l0nOl3oookJP?oo`2=00Cooo]ZoomG0?ooE`3ooeL0F?oo
nfX00ooo:`3o0?mFoookJP0BoookJP03o`1Qool0NOoooo]Z00Oooo]Z00Co7P3ooookJ_oonf[o0?li
0ooonfX01Ooo0>cooo]ZoonD0?oo03Ooa`3o00gooo]Z00?o0?m;oookJ_oco`001_oonfX00ol0od7o
o`1UoookJP03oookJP05oom20?oonf[ooo]Zom_o0?oonfX00_l0om<02Ooonf[oo`d0oookJ_oo08Ko
oo]Zool0[?l0=_oooo]Zo`3odP02oookJP03ool0nOoonf[ooo]Z00Oooo]Z00?oo`P0oookJ_l0Q_l0
1_oonfX01?l0oi?oooL0oookJ_mBo`03oookJP05ool0N_oonf[ooo]ZoookJ_oo04T01?oonfX01ooo
6@3ooo]ZoookJ_oonf[o0>_ooookJ_l0oh`01?oonfX00ooi0?oooo]ZoookJP0:oookJP03ooT0ool0
ogOooo]Z00Gooo]Z00?oE_l0oookJ_oonfX04OoonfX00ol0TOoooo]Zo`3o:`03oookJP05oc?o0?oo
nf[ooo]ZoookJ_oo07@01OoonfX00ol07?oon@3ooookJP07oookJPCo00002OoonfX00ooXo`3ooo]Z
oookJP08oookJP03o`D0oooonf[ooo]Z03Kooo]Z1OmN0?l2o`D0o`Coj?l000?ooo]Zool0?Ooo0<40
0ooo0<44ool0<`03o`24oooonf[o0?nI00;o0?nI0_oonfX3onCo0003og?o0?oo04koo`1>00Co0?mm
0om60?l3oookJP;oo`2B0_ooVP04oookJP?oDOl01OoonfX2ool0H`?o0?mS00Cok@3ooookJ_oonf[o
oo]Z0ooo09400ol0okkooo]ZoomM0002oomM00;ooo]Z00Co/P3oo`3ofol0om_o0?oK0_nRo`001?l0
obCo0?l<o`3o3?l0o``6oookJP;ooi@000Cooo]Zool0;?oo01?oo`0C0_l0N_l6oookJP;o3@3o1?oo
nfX2o`3io`04oh40oooonf[ooo]ZoookJP;oo`2=00Cooo]Zoomk0?ooE`3ooeL0:ooonfX003;ooo]Z
00?o0?mFoookJ_oonfX03ooonfX3oolX00;o067o1?oo:0000ooonf[oobP0oolX0009oolX0005oook
J_ooU03oo`0goolX0?o70?l02_oonfX5ool000Gooo]Z00?oobP0o`3o@Ooo06D01?oonfX01_oo@P3o
oo]ZoookJ_oKo`3ooo]Zo`3od`WoobP000?o0?oBoolX0?oo:0001?oo:002oookJP;oo`002?oo:002
ool00003o`3oTooo003oo`0000Coo`0000GoobP0ool0N_oonf[ooo]Zool0B@03oookJPKoobP000?o
0>_oool00?oo00001?oo00000ooi0?ooo`00ool00009oookJP03ool00?oi0?ooo`0000Gooo]Z00?o
E_l0oookJ_oonfX04OoonfX01?l0TOoooo]ZoookJ_l0ob/3oookJP03oc?o0?oonf[oo`1d00Gooo]Z
1?oo:003oookJPSoo`000_oo:002oookJPOoogT01ooonfX2oolX00oooo]Z3?oo:00Cool06@_oogT0
1?oonfX5oeh0o`SoolT03OooN@05ooo900;oo`1>1?l0ogd2odH0o`?oolT000?ooo]Zool0T_ooVP00
0_ooVP04oookJP?oDOl000Cooo]Zoomi0?ooN@3oogT00_oo06<3o`3oH`04ond0oooonf[ooo]Zoook
JP?oo`2A0_l0okh01?oo09cooed0oomM0?ooG@09oolX00?o0?l<1OoonfX2oonD00;oogT000?oo`0C
o`1jool0N_l01_oonfX3o`d0o`Cooo]Z0_l0nOl01?n10?oooo]ZoookJ_oonfX2ool0S@04oookJ_oo
N`3ooeL0oomG05Oooo]Z00?oob/0o`3oE_oonfX04_oonfX2o`1Qo`Sooo]Z0_lN0?l00ooonf[o0?li
oookJP02oookJP04ool0k?oonf[ooo]Zool0=`;oa`3o3?oonfX00ol0od_ooo]Zoo?o0006oookJP03
o`3o@Ooo06Goo`1U00?ooo]Z00?ood80oookJ_oonfX00_oKo`002ooonf[o0?oCoookJ_oo3@3ooo]Z
ool0Q_oonf[oo`2/o`0foooonf[o0?oB00;ooo]Z00?oo`3ioookJ_oonfX01ooonfX00ooo203ooo]Z
o`26o`06oookJP04o`3oTooom`3ooo]Zoe;o00?ooo]Z00Goo`1joookJ_oonf[ooo]Zool0B@04oook
JP07oolI0?oonf[ooo]ZoookJ_l0joooo`d0o`3oS004oookJP03ooT0oooonf[ooo]Z00[ooo]Z00?o
n@3oogSo0?oonfX01?oonfX00omFo`3ooo]ZoookJP0BoookJP03o`2Aoooonf[o0?l[00?ooo]Z00Co
<ol0oookJ_oonf[oo`1d1OoonfX00ol07?oon@3ooookJP07oookJPCo00002?oonfX00ooXo`3ooo]Z
oookJP08oookJP03o`D0oooonf[ooo]Z01Gooo]Z6?oo01T?oookJPGoGP3o00?o1@3oonSo0?oXo`00
0_oXo`000ooonf[o0?l`ool0`@03ool0`@?oo`0c0_l0Q?l4o`3oV@03oookJ_oTo`3oi?l000;oi?l0
0ooo04h4o`3oO@;oAP3o0ooonfX01?oo09;ooiX0oonJ0?ooVP04oookJP?oDOl01?oonfX3ool0H`;o
0?mS00?ok@3ooookJ_oonfX00_oonfX3ool0T@03o`3o__oo09cooed000;ooed000?ooo]Zok80oonb
0?l00ol0om/2oj;o0004o`3o9?l0o`co0?l<o`3o30Gooo]Z0oooU0000ooo02coo`0Cool04`02o`1j
o`Kooo]Z0ol=0?l3oookJP?o0?Wo0ooonfX3ool0S@03oomk0?ooE`3ooeL002Wooo]Z000coookJP03
o`3oE_oo:`3ooo]Z00oooo]Z1?oo:0000ol0HOooobP0oolX000?oolX0004oonD0?oo03Oooo]ZolL0
o`Wooo]Z1ooo0005oookJP03o`3o@Ooo06Gooo]Z00?ooo]Z0_oo@P001?oonf[ofol0oookJ_l0om<9
oolX0003o`3od_oo:03oobP000CoobP00_oonfX2ool000KoobP000Goo`00oookJ_oo003oo`00o`3o
T`06ool00005oolX0?oo07[ooo]ZoookJ_oo04T00_oonfX8oolX00Koo`0000?on@3ooookJ_oonfX0
2OoonfX00ooo003on@3oool00004oookJP03oeKo0?oonf[ooo]Z017ooo]Z00Co097ooookJ_oonf[o
0?l[0ooonfX00olco`3ooo]Zool0M005oookJPCoobP00ooonfX8ool000;oobP000?ooo]Zoomi0?oo
N@001OooN@06oookJPCoobP03ooonfX@oolX01Go01Co2?ooN@06oookJPGoGP3o0ooo000?oomi0003
o`3oVOoUo`3ooo]Z00;oi?l01?oo04h3o`3oO@;oAP3o0_oob@02oookJP04oh@0ooooVP3ooiX0oonJ
00Cooo]Z00?oDOl0oomi0?ooN@000oooN@000ooo:03oo`1Sool0H`02o`3oH`03ond0oooonf[ooo]Z
00;ooo]Z0ooo0942o`3o_P04oolX0?ooG@3ooed0oomM00SoobP000Cooo]Zo`3o3?l0o`co0?l<1Ooo
nfX2oonD00?oo`0C0_l0N_l5oookJP04oomi0?l=0?oo3@3oo`d0o`?ooo]Z0ol0nOl2oookJP05oomi
0?oo08goo`2=oookJ_ooN`000_ooE`1FoookJP03ool[0?l0oeKooo]Z01?ooo]Z00?o067oo`1ioooo
nfX01ooonfX00olN0?oooo]Zo`3o>@03oookJP;oo`3/00Cooo]Zool0=ooonf[oa`3o3?oonfX00ol0
od_ooo]Zoo?o0006oookJP03o`3o@Ooonf[oo`1U00?ooo]Z0_oo@P02oookJP0<om_o0?oonf[o0?oC
oookJ_oo3@3ooo]Zool0Q_oonf[oo`2/o`0foooonf[o0?oB0_oonfX00ooo0?Wooo]ZoookJP07oook
JP03ool80?oonf[o08Ko00Kooo]Z00Co0?nCooog0?oonf[oD_l00ooonfX01Ooo07[ooo]ZoookJ_oo
nf[oo`1900Cooo]Z00OooaT0oookJ_oonf[ooo]Zo`3[oooo3@3o0?n<00Cooo]Z00?on@3ooookJ_oo
nfX02_oonfX00ooi0?ooN?l0oookJP04oookJP03oeKo0?oonf[ooo]Z017ooo]Z00?o097ooookJ_l0
ob/00ooonfX01?lco`3ooo]ZoookJ_oo07@5oookJP03o`0Loooonf[on@3o00Oooo]Z1?l00008oook
JP03onSo0?oonf[ooo]Z00Oooo]Z00?o1@3ooookJ_oonfX04OoonfX5ool06@04oookJ_oo00goo`0=
ool03AWo01Co1Ooo01T:oookJPGoGP3o1?oXo`02oookJP?oo`311?oo03<00ooo0=oo08Coo`3oV@02
o`3oV@;ooo]Z0ooTo`04ool0CP?o0?mm0_m60?l3oookJP04oh@0ooooVP3ooiX0oonJ00Cooo]Z0omA
o`04oookJP;oo`1S0ol0of<00oo]0?oooo]ZoookJP02oookJP?oo`2A00?o0?nnool0W?ooG@000_oo
G@000ooonf[o/P3ook80o`03o`3of`03oj;o0?l0obCo0?lT00?o0?l<1OoonfX2oonD0005ool0;?oo
01?oo`0Cool04ol0N_l01_oonfX01?l0omco3@3oo`d0ool=0?l3oookJP;o0?Wo00CoP@3ooookJ_oo
nf[ooo]Z0_oo08d00oooN`3ooeL0oomG000WoookJP00=?oonfX00ol0oeKoob/0oookJP0?oookJPCo
obP000?o067ooolX0?oo:0003ooo:0001?ooU03oo`0goookJ_o70?l9oookJPSoo`001?oonfX00ol0
od7oo`1UoookJP04oookJP05oom20?oonf[ofol0oolX0?l0om<02Ooo:0000ol0om;oobP0oolX0005
oolX00;oo`001_oo:002oookJP;oo`0000?o0?nCool00?oo00000ooo0002oolX0005oookJ_oo07[o
oo]ZoookJ_oo04T00_oonfX9oolX00Goo`0000?on@3ooookJ_oonfX02?oonfX2ool00003ooT0oooo
003ooo]Z00?ooo]Z00?oE_l0oookJ_oonfX04OoonfX00ol0TOoooo]Zo`3o:`03oookJP04oc?o0?oo
nf[ooo]Zool0M0Cooo]Z1Ooo:006oookJPCoo`0000?oobP0ool00?ooN@001oooN@05oookJPCoobP0
1_oonfX:oomi00koobP00_oonfXBohd0o`?oo`0=2?l05?l01?ooN@3oo`0Iool06Ooo01T3oookJPCo
o`000_mN0?lAoomi00?o0?nI0_oob@03onCo00?oo`1>1?l0ogd2odH0o`Cooo]Z0oooN@000ooonf[o
ogT0oomi0006oomi0003oolX0?oonf[oo`1S00?o0?mS00Gok@3ooookJ_oonf[ooo]ZoolX0003ool0
T@;o0?nn00CoogT0oomM0?ooG@3ooed01_oo:0000onRo`3ooo]ZoookJP02o`3o30Gooo]Z0oooU003
ool04`03o`1joooonf[ooo]Z00Cooo]Z00?oogT0o`d0ool=0?l01?oonfX2o`3io`?oogT00ooo08d0
0oooN`3ooeL0oomG001FoookJP03o`3oE_oonf[ooo]Z01;ooo]Z00?o067oo`1ioooonfX01ooonfX0
0olN0?oooo]Zo`3o>@04oookJP05ool0k?oonf[oo`0goookJ_o70?l03?oonfX01?l0od_ooo]Zoo?o
0?oco`05oookJP03o`3o@Ooonf[oo`1U00Cooo]Z00oood80oookJ_oonf[ofol0oookJ_l0om?ooo]Z
ool=0?oonf[oo`26oookJ_oo0:co03KooookJ_l0om800_oonfX00ooo0?Wooo]ZoookJP07oookJP03
ool80?oonf[o08Ko00Gooo]Z00Go0?nCoookJ_oom`3ooo]Zoe;o0003oookJP05ool0N_oonf[ooo]Z
oookJ_oo04T01?oonfX01ooo6@3ooo]ZoookJ_oonf[o0>_oool=0?l0oh`01?oonfX00ooi0?oooo]Z
oookJP09oookJP03o`3oMooi0?oooo]Z00Gooo]Z00?oE_l0oookJ_oonfX04?oonfX00ol0TOoooo]Z
o`3o:`03oookJP05oc?o0?oonf[ooo]ZoookJ_oo07@01OoonfX00ol07?oon@3ooookJP06oookJPCo
00002?oonfX00ooXo`3ooo]ZoookJP06oookJP03o`D0oooonf[ooo]Z00kooo]Z1?oo01T3ool03@Ko
01Co1?oonfXBohd0o`?oo`0=2?l05?l5ool06@Kooo]Z00?o1@3ooeh0oomN0?l00_mN0?l5onSo0004
oookJ_oo0<7oo`31ool0`@?oo`0c0_lio`04o`3oV@03oookJ_oTo`3oi?l000;oi?l00ooo04h3o`3o
O@;oAP3o1?oonfX3oonJ00Cooo]Z0omAo`04oookJP;oo`1S0ol0of<00oo]0?oooo]ZoookJP02oook
JP?oo`2A00?o0?nnool0W?ooG@000_ooG@03ok80o`?o0?oK00?oX_l0o`3o9?oonfX00ol0o``4oook
JP?ooi@000Goo`0/ool04ooo01?oo`0Co`1jo`06oookJP03o`3og?l=0?oo3@3o00?ooo]Z0_l0nOl0
1?n10?oooo]ZoookJ_oonfX2ool0S@04oookJ_ooE`3ooeL0oomG02Cooo]Z000eoookJP03o`3oE_oo
:`3ooo]Z00kooo]Z5ooo:0001?oonf[oo`0gool0=oo70?l9oookJPSoo`001?oonfX00ol0od7oo`1U
oookJP04oookJP04oom20?oonf[ofol0oolX00;oo`002?oo:0000ol0om;oobP0oolX0005oolX00;o
o`000ooo:0000ooo003ooo]ZoolX0002oookJP;oo`0000Co0?nCool00?oo003oo`000_oo:003oook
JP04ool0N_oonf[ooo]Zool0B@;ooo]Z2Ooo:005ool00003ooT0oooonf[ooo]Z00Oooo]Z0_oo0000
0ooi0?ooo`00ool00004oookJP03oolX0?oonf[ooo]Z013ooo]Z00Co097ooookJ_oonf[o0?l[0ooo
nfX00olco`3ooo]Zool0M004oookJPGoobP01_oonfX2ool000?oobP000?oo`00oomi0?ooN@001Ooo
N@04oookJPGoobP01ooonfX:oomi00_oobP01On=0?l>oookJPCoogT02On=0?l2ool03@Go01Co00?o
o`0=ool00?oo00001Ooo000Aoomi00;oo`0c00?o>Ol0o`3oVOl0oiT00_l0oiT2ooo900?oi?l00ooo
04h3o`3oO@;oAP3o1?oonfX:oomi0003oolX0?oonf[ooo]Z00;oo`1S0oooN@000oo]0?oooo]Zoook
JP02oookJP?oo`2A0_l0okh01?oo:03ooed0oomM0?ooG@04oolX0004o`3ofonRo`3oX_l0oookJP?o
0?l<1OoonfX2oonD0004oookJ_oo01?oo`0Cool04`Kooo]Z00CoogT0o`d0ool=0?oo3@3o0_oonfX5
oomi00;ooo]Z0_oo08d00oooN`3ooo]ZoookJP1EoookJP03o`3oE_oonf[ooo]Z01;ooo]Z0_l0HOl8
oookJP03oah0oooonf[o0?li00Cooo]Z00Goo`3/oookJ_oo03Ooo`0golL0o`0<oookJP04o`3oBooo
nf[ooo]Zoo?o00Gooo]Z00?o0?m1oookJ_oo06D01?oonfX03ooo@P3ooo]ZoookJ_oKo`3ooo]Zo`3o
dooonf[oo`d0oookJ_oo08Kooo]Zool0[?l0=_oooo]Zo`3odP02oookJP03ool0nOoonf[ooo]Z00Oo
oo]Z00?oo`P0oookJ_l0Q_l01OoonfX01Ol0oi?ooo]Zooog0?oonf[oD_l000?ooo]Z00Goo`1joook
J_oonf[ooo]Zool0B@04oookJP07oolI0?oonf[ooo]ZoookJ_l0joooo`d0o`3oS004oookJP03ooT0
oooonf[ooo]Z00Wooo]Z00?on@3oogSo0?oonfX01OoonfX00omFo`3ooo]ZoookJP0@oookJP03o`2A
oooonf[o0?l[00?ooo]Z00Co<ol0oookJ_oonf[oo`1d1OoonfX00ol07?oon@3ooookJP06oookJPCo
00001ooonfX00ooXo`3ooo]ZoookJP06oookJP03o`D0oooonf[ooo]Z00gooo]Z0_oo01T3ool03@Co
01Co0ooonfX7ohd0oa;ooo]Z2_n=0?l00ooo00go01Coo`0Do`03o`0Do`04ool03Ooo01Woo`0Iool0
6@Co;P3o0_oonfX00ol50?ooGP3ooeh0o`02oeh0o`03oookJ_oXo`3oj?l000;oj?l000?ooo]Zool0
`Ooo0<401?oo03<2ocWo00?o0?nI0_oonfX3onCo00?oo`1>0ol0ogd2odH0o`Cooo]Z1?ooVP03oook
JP?oDOl00ooonfX3ool0H`?o0?mS00?ok@3ooookJ_oonfX00_oonfX3ool0T@03o`3o__oo09cooed0
00;ooed00onb0?l2o`3of`;oX_l000?o0?lToookJ_l0o``00_l0o``4oookJP;ooi@000Gooo]Zool0
;?oo01?oo`0Co`1jo`06oookJP04o`3og?l=0?oo3@3oo`d0o`;ooo]Z0ol0nOl3oookJP?oo`2=00?o
og/0oookJ_oonfX08_oonfX003Kooo]Z00?o0?mFool[0?oonfX03_oonfX8oolX00;ooo]Z3Ooo:000
1?oonf[ooi@0ool0=oo70?l9oookJPWoo`000ooonfX00ol0od7oo`1UoookJP04oookJP03oom20?oo
nf[ofol000?oo`002?oo:0000ol0om;oobP0oolX0004oolX00?oo`0000GoobP0ool00?oo003ooo]Z
o`26o`02oookJP?oo`0000Go0?nCool00?oo:03oo`00oolX0004oookJP05ool0N_oonf[ooo]Zool0
BOoonfX02_oo:003ool000;ooo]Z00?on@3ooookJ_oonfX01ooonfX2ool00003ooT0oooo003oo`00
00?ooo]Z0_oo:00BoookJP03o`2Aoooonf[o0?l[00?ooo]Z00?oobP0oookJ_oo07@01?oonfX6oolX
00Cooo]Z1Ooo00000ooo:03oo`00oomi0006oomi00;ooo]Z1ooo:007oookJPGoogT01_oo0008oolX
01Gooo]Z1?ooN@09oookJPOoS@3o1_l05?l8ool00003oomi0?mN0?ooGP3o00;oGP3o1OooN@03ool0
`@Coo`0c00?o>Ol0o`3oVOl0oiT00_l0oiT2ooo900?oi?l00_oo04h3o`3oO@;oAP3o0_oonfX;oomi
0004oe7o0?oonf[ooo]ZoookJP;oo`1S0oooN@000oo]0?ooogT0oomi0002oomi00?oo`2A0_l0okh0
1?oo09cooed0oomM0?ooG@02ok80o`?o0?oK00?oX_l0o`3o9?oonfX00ol0o``4oookJP?ooi@000Co
o`0/ool04ooo01?oo`0C1_oonfX01?ooN@3o3@3oo`d0ool=0?l6oomi00;ooo]Z00?oo`2=oookJ_oo
nfX0E_oonfX00ol0oeKooo]ZoookJP0CoookJP03o`1Qoooonf[ooo]Z00Kooo]Z00?o7P3ooookJ_l0
ocT01?oonfX01Ooo0>cooo]ZoonD0?oo03Ooa`3o00cooo]Z00Co0?m;oookJ_oonf[olol01OoonfX0
0ol0od7ooo]Zool0I@04oookJP05oom20?oonf[ooo]Zom_o0?l0om<00_oonfX02?oo3@3ooo]Zool0
Q_oonf[oo`2/o`0foooonf[o0?oB0_oonfX00ooo0?Wooo]ZoookJP07oookJP03ool80?l0Q_oooo]Z
00Gooo]Z00Go0?nCoookJ_oom`3ooo]Zoe;o0003oookJP05ool0N_oonf[ooo]ZoookJ_oo04T01?oo
nfX01ooo6@3ooo]ZoookJ_oonf[o0>_oool=0?l0oh`01?oonfX00ooi0?oooo]ZoookJP09oookJP03
ooT0oomho`3ooo]Z00Cooo]Z00?oE_l0oookJ_oonfX04?oonfX00ol0TOoooo]Zo`3o:`03oookJP04
oc?o0?oonf[ooo]Zool0M0Gooo]Z00?o01coooT0oooonfX01_oonfX5o`0000Kooo]Z00?oj?l0oook
J_oonfX01_oonfX00ol50?oooo]ZoookJP0<oookJP04ool06Ooo00goo`0=oookJP;o01Co0ooonfX4
ohd0ob?ooo]Z1_n=0?l6o`0Do`03ool03Ooo01Wo;P3o00Ko;P3o1OmN0?l4onSo00?oo`311?oo03<2
ocWo00?o0?nI0_oonfX3onCo00;oo`1>0ol0ogd2odH0o`Cooo]Z00?oQ03ooonJ0?ooVP000_ooVP02
oookJP?oDOl00ooonfX3ool0H`?o0?mS00?ok@3ooookJ_oonfX00_oonfX3ool0T@03o`3o__oo09co
oed000;ooed00_nb0?l3o`3of`04oj;o0?l0obCooo]ZoookJP?o0?l<0ooonfX3oonD0005oookJ_oo
01?oo`0Cool04ol0N_l01_oonfX01?l0omco3@3oo`d0ool=0?l2oookJP?o0?Wo0ooonfX00ooo08go
oo]ZoookJP0RoookJP00=ooonfX2o`3oEP03ool[0?oonf[ooo]Z00cooo]Z2?oo:0000ooonf[oobP0
oolX000;oolX0005ool0k?oonf[ooi@0ool0=oo70?l02?oonfX:ool000?ooo]Z00?o0?m1ool0IOoo
nfX01?oonfX00ooo@P3ooo]ZoolX0004ool000OoobP000?o0?oBoolX0?oo:0001?oo:003ool000;o
oo]Z00?oo`00oookJ_l0Q_l00_oonfX3ool00004o`3oTooo:03ooo]Zoe;o00Cooo]Z00Koo`1joook
J_oonf[ooo]Zool0BOoonfX7oolX0004o`3[oooo003oo`00ool000?ooo]Z00?on@3ooookJ_oonfX0
1ooonfX3ool00003ooT0oooo003oo`0000;ooo]Z0ooo:00AoookJP03o`2Aoooonf[o0?l[00?ooo]Z
00CoobP0oookJ_oonf[oo`1d0ooonfX6oolX00Cooo]Z1ooo0006oomi0003oookJ_oo:03oobP000Ko
obP02?oonfX:ool000[oobP01?ooN@07oookJQ?oo`1h2ooonfX5ool000Oo01Co00?oo`00oomi0?oo
N@000oooN@05oeh0o`?oogT01?oo0<43ool0<`;o>Ol01?l0oiT2ool000?oi?l000?oo`1>o`3oOOl0
ogd00_l0ogd=oomi00;oDOl00ooonfX2ool0H`SoogT00_oo0942o`3o_P;oo`2L0oooG@02ok80o`;o
0?oK0_nRo`02oookJP?o0?l<1?oonfX3oonD0004ool0;?oo01?oo`0Co`1jo`Gooo]Z0_ooN@02o`d0
o`GoogT000?o0?WooookJ_oonfX0F?oonfX00ol0oeKoob/0oookJP0CoookJP03o`1Qoooonf[ooo]Z
00Kooo]Z00?o7P3ooookJ_l0ocT01?oonfX01Ooo0>cooo]ZoonD0?oo03Ooa`3o00cooo]Z0_l0od/0
0ooonf[olol0oookJP04oookJP03o`3o@Ooonf[oo`1U00Cooo]Z00Good80oookJ_oonf[ofol0o`3o
d`02oookJP08ool=0?oonf[oo`26oookJ_oo0:co03KooookJ_l0om82oookJP03ool0nOoonf[ooo]Z
00Oooo]Z00?oo`P0o`26oooonfX01OoonfX01?l0oi?ooo]ZoookJ_mBo`03oookJP03ool0N_oonf[o
oo]Z00;ooo]Z00?oo`19oookJ_oonfX00_oonfX01Ooo6@3ooo]ZoookJ_oonf[o0>_o00Gooo]Z00?o
n@3ooookJ_oonfX02OoonfX00ol0ogOon@3oogSo0005oookJP03oeKo0?oonf[ooo]Z00oooo]Z00?o
097ooookJ_l0ob/00ooonfX01?lco`3ooo]ZoookJ_oo07@5oookJP03o`0Loooi0?oooo]Z00Kooo]Z
1?l00007oookJP03onSo0?oonf[ooo]Z00Gooo]Z00?o1@3ooookJ_oonfX02ooonfX2ool06@04ool0
3Ooonf[o01Coo`0Do`;ooo]Z0on=0?l@oookJQ?oo`1h3?oonfX4ohd0o`Oo01Co00?oo`0=ool06Ol^
0?l01?l^0?l5oeh0o`?oj?l00ooo0<43ool0<`;o>Ol01?l0oiT3oookJP;oi?l000?oo`1>o`3oOOl0
ogd00_l0ogd2odH0o`Cooo]Z00Coo`2BoonJ0?ooVP3ooiX00_oonfX3oe7o00?ooo]Z0ooo06<3o`3o
H`03ond0oooonf[ooo]Z00;ooo]Z0_oo09400ol0okkoo`2Lool0W003oomM00;o/P3o0ol0om/01?nR
o`3o0?lToookJ_oonfX3o`3o30?ooo]Z0oooU0001Ooonf[oo`0Cool04ooo01?o07[o00Gooo]Z0_l0
om`2o`d0o`?ooo]Z0ol0nOlUoookJP00>OoonfX00ol0oeKoob/0oookJP0<oookJQGoobP00_oonfX0
1Ooo0>cooo]ZoonD0?oo03Ooa`3o00Sooo]Z2?oo0005oookJP03o`3o@Ooo06Gooo]Z00Cooo]Z00?o
od80oookJ_oo:0001Ooo0004oolX0003oookJ_oo:03o0?oB00KoobP000?oo`00oookJ_oonfX01?oo
nfX01ol0Q_oooo]ZoookJ_oo003ooo]ZoolX0?l0oi<00_oonfX00omBo`3ooo]ZoookJP02oookJP05
ool0N_oonf[ooo]ZoookJ_oo04T01_oo:0001?oo003o0>_oool00?oo0005oookJP03ooT0oooonf[o
oo]Z00Kooo]Z1?oo00000ooi0?ooo`00ool00002oookJP?oobP04?oonfX01?l0TOoooo]ZoookJ_l0
ob/2oookJP;oobP000?ooo]Zool0M?oonfX00_oonfX7oolX00;ooo]Z2?oo0006oomi00WoobP01Ooo
nfX<ool001?oobP00ooo07P00oooN@3ooj80oonR000@oonR00_oo`1h2?oo0004ohd0o`Go01Co1Ooo
00000ol^0?ooGP3ooeh0o`03oeh0o`;oolT00ooo0<44ool0<`;o>Ol01Ol0oiT01?oo003oi?l0onCo
0?oo04h?oomi0004oolX0?mAo`3oDOl0oe7o00?ooo]Z2OooN@03ool0T@;o0?nn0_oo09`3oomM0004
ok80ool0om_o0?oKo`3of`;oX_l00_oonfX2oomi00Gooo]Z0oooU003ool04`03o`1joooonf[ooo]Z
00CoogT00ol=0?l3oomi0003o`3ioooonf[ooo]Z05Sooo]Z00?o0?mFool[0?oonfX04ooonfX00ol0
HOoooo]ZoookJP06oookJP;o7P3o0_l0ocT3oookJP05ool0k?oonf[ooi@0ool0=oo70?l03OoonfX0
0ol0od_ooo]Zoo?o0005oookJP03o`3o@Ooo06Gooo]Z00Cooo]Z00Good80oookJ_oonf[ofol0o`3o
d`02oookJP05ool=0?oonf[oo`26oookJ_oo0:`00_oonfX01?l0om;ooo]ZoookJ_oo0?T:oookJP03
o`26oooonf[ooo]Z00Cooo]Z00Co0?nCoookJ_oonf[oD_l00ooonfX00ooo07[ooo]ZoookJP02oook
JP03ool0BOoonf[ooo]Z00;ooo]Z00GooaT0oookJ_oonf[o0>_oool=0005oookJP03ooT0oooonf[o
oo]Z00Wooo]Z00?o0?mgooT0oooonfX01?oonfX00omFo`3ooo]ZoookJP0@oookJP03o`2Aoooonf[o
0?l[00;ooo]Z00Co<ol0oookJ_oonf[oo`1d1OoonfX00ol07?oooo]ZooT0o`06oookJPCo00001_oo
nfX00ooXo`3ooo]ZoookJP05oookJP03o`D0oooonf[ooo]Z00[ooo]Z0_oo01T2ool03@03oookJ_l0
5?oooo]Z00?oS@3o3?oonfX7ool0N1?ooj802ooo07P7oookJPGoS@3o1Ol05?l2ool03@Go;P3o1OmN
0?l2onSo00;oo`311?oo03<2ocWo0003oolY0?l0oiWo0?nI00;o0?nI0_oonfX00ooTo`3oo`1>ool0
CP04o`3oO@;oAP3o0ooonfX00ooo09;ooiX0oonJ0002oonJ0003oookJ_mAo`3oDOl000;oDOl00_oo
nfX3ool0H`?o0?mS00Cok@3ooookJ_oonf[ooo]Z0ooo09400ol0okkoo`2Lool0W003oomM00;o/P3o
0_l0om/2oj;o0003o`3o9?oonf[ooo]Z00;o0?l<1?oonfX3oonD0003ool0;?oo01?oo`0C00;o07[o
1?oonfX2o`3og0?o3@3o0ooonfX00ol0nOoooo]ZoookJP0RoookJP00>_oonfX00ol0oeKoob/0oook
JP0<oookJP?oobP000?ooo]ZoolX0?oo:0001Ooo:002oookJPKoobP01?oonfX01Ooo0>cooo]ZoonD
0?oo03Ooa`3o00Sooo]Z1_oo0002oolX00Gooo]Z00?o0?m1ool0IOoonfX01?oonfX00ooo@P3oobP0
ool00005ool000?oobP000Co03KooookJ_oo:03o0?oB1?oo:009oookJP03o`26oooonf[ooo]Z00?o
oo]Z00Co0?nCoookJ_oonf[oD_l01?oonfX01?oo07[ooo]ZoookJ_oonfX5oolX0006oookJ_oo003o
o`00o`3[oooonf[oo`d01?oonfX00ooi0?oooo]ZoookJP07oookJP?oo`0000Gon@3oool00?oo003o
o`00oookJP04oolX013ooo]Z00?o097ooookJ_oo:0000_oonfX2oolX0003oookJ_oo07Cooo]Z00;o
oo]Z1ooo:004oookJP03o`000?oo003oo`0000?oo`0000Cooo]Zoomi0?ooN@3oogT02_oo:006oook
JP_oo`004_oo:00;oomi01?ooo]Z1OooXP09ool0N0;ooo]Z1_oo0005o`0Do`;oo`000_l^0?l2ooo9
00GoGP3o00CoolT0ool0`Ooo0<7oo`311?oo03<2ocWo0003ool0gol0oiWo0?nI00;o0?nI4?ooN@02
oonJ0004oookJ_mAo`3oDOl0oe7o00_oogT000Cooo]Zool0TOoo097oo`2A0_l0okh2ool0W0?ooed0
00Oo/P3oo`3ofol0om_o0?oKoj;o0?l0obCooo]Z00?oogT01OoonfX3oonD00?oo`0C1oooN@03o`d0
o`03oomi0?oonf[ooo]Z05Wooo]Z00?o0?mFool[0?oonfX04ooonfX00ol0HOoo07WooookJP07oook
JP03oah0oooonf[o0?li00?ooo]Z00Goo`3/oookJ_ooU03oo`0golL0o`0=oookJP03o`3oBooonf[o
lol000Gooo]Z00?o0?m1ool0IOoonfX01?oonfX01Ooo@P3ooo]ZoookJ_oKo`3o0?oC00;ooo]Z00Go
o`d0oookJ_oo08Kooo]Zool0[002oookJP04o`3od_oonf[ooo]Zool0n@[ooo]Z00?o08KooookJ_oo
nfX01?oonfX01?l0oi?ooo]ZoookJ_mBo`03oookJP03ool0N_oonf[ooo]Z00;ooo]Z00Goo`19oook
J_oonf[ooo]ZoolI0003oookJP03o`3[oooo3@3ooo]Z00Cooo]Z00?on@3ooookJ_oonfX02?oonfX0
0ol0ogOon@3oogSo0005oookJP03oeKo0?oonf[ooo]Z00oooo]Z00?o097ooookJ_l0ob/00ooonfX0
1?lco`3ooo]ZoookJ_oo07@4oookJP03o`0Loooonf[on@3o00Kooo]Z1?l00006oookJP03onSo0?oo
nf[ooo]Z00Cooo]Z00?o1@3ooookJ_oonfX02_oonfX00ooo01Wooo]Zool03@03oookJP;oS@3o2_oo
nfX5ool0N0;ooo]Z0oooXP0KoookJPGooj802Ooo07P4oookJPCoonT01Ol05?l2ool03@Go;P3o1OmN
0?l00ooXo`3oo`31ool0`@04ool0<`;o>Ol000?oobT0o`3oVOl0oiT00_l0oiT00ooonf[oLol0onCo
0002ool0CPCo0?mm0_m60?l2oookJP;oo`2B1?ooVP001?oonf[oDOl0oe7o0?mAo`03oookJP;oo`1S
0ol0of<01?o]0?oooo]ZoookJ_oonfX3ool0T@03o`3o__oo09coo`2L00?ooed000Ko/P3oo`3ofol0
om_o0?oKoj;o0?l0ob@2oookJP?o0?l<1?oonfX3oonD00?oo`0C0_l0N_l4oookJP;o0?oL0ol=0?lU
oookJP00>ooonfX00ol0oeKoob/0oookJP0<oookJP04oolX0?oonf[ooo]ZoookJPOoobP000?ooo]Z
oolX0?oo:0000ooo:0000ooonf[oobP0oookJP03oookJP05ool0k?oonf[ooi@0ool0=oo70?l01ooo
nfX6ool000?oobP01OoonfX00ol0od7oo`1UoookJP04oookJP03oom20?oo:03oo`0000Koo`0000?o
oo]ZoolX0?l0=_l00_oo:0001?l0om;oobP0oolX0?oo:00:oookJP03o`26oooonf[ooo]Z00?ooo]Z
00Co0?nCoookJ_oonf[oD_l01?oonfX00ooo07[ooo]ZoookJP04oolX0008oookJ_oo6@3ooo]Zool0
0?oonf[o0>_ooookJ_oo3@04oookJP03ooT0oooonf[ooo]Z00Kooo]Z1?oo00001?oi0?ooo`00ool0
0?oo0005oolX00oooo]Z00?o097ooookJ_oo:0000_oonfX3oolX0004oookJ_oo07Cooo]ZoookJPSo
obP00ooonfX4o`0000;oo`000_oonfX00oooN@3oobP0oolX0008oolX00Sooo]Z2Ooo0004oolX0003
oookJ_oo:03oobP000[oobP04OooN@0?oj@0o`_ooo]Z0oooXP07ool0N0Koo`001Ol05?l2oomi0004
obh0oooo:03oobP0oolX00KoGP3o0_oo0<45ool0<`03oomi0?l0Q?ooogT000KoogT000?oo`1>o`3o
OOl0ogd00_l0ogd6oolX00?ooiX03_ooN@02oookJP?oo`2A0_l0okh2ool0W0?ooed000?o/P3oo`3o
fol0om/00_nRo`02oookJP?oogT01OoonfX2oonD0004ool0;?oo01?oo`0Cool04`OoogT000?o3@3o
oookJ_oonfX0F_oonfX2o`3oEQCooo]Z00?o067oo`1ioooonfX01ooonfX00olN0?oooo]Zo`3o>@03
oookJP04ool0k?oonf[ooi@0ool0=`;oa`3o3?oonfX00ol0od_olol0oookJP05oookJP03o`3o@Ooo
06Gooo]Z00Cooo]Z00Good80oookJ_oKo`3ooo]Zo`3od`02oookJP05ool=0?oo08Kooo]ZoookJ_oo
0:`00_oonfX01?l0om;ooo]ZoookJ_oo0?T:oookJP03o`26oooonf[ooo]Z00?ooo]Z00Go0?nCoook
J_oonf[ooo]Zoe;o0003oookJP05ool0N_oonf[ooo]ZoookJ_oo04T01?oonfX01_oo6@3ooo]Zoook
J_oonf[o0>_oool=00Cooo]Z00?on@3ooookJ_oonfX02OoonfX00ol0ogOon@3oogSo0004oookJP03
oeKo0?oonf[ooo]Z00oooo]Z00?o097ooookJ_l0ob/00ooonfX01?lco`3ooo]ZoookJ_oo07@5oook
JP03o`0Loooi0?oooo]Z00Gooo]Z1?l00006oookJP03onSo0?oonf[ooo]Z00Cooo]Z00?o1@3ooook
J_oonfX02OoonfX00ooo01Wooo]Zool03@03oookJP03ohd0oooonf[ooo]Z00Sooo]Z0_oo07P3oook
JPCooj802_oonfXEoj@0o`_ooo]Z0_ooXP07ool0N003oonR0?oonf[oonT000?oonT01Ol05?l2ool0
3@Co;P3o00?o1@3ooeh0oomN0?l00omN0?l2ool0`@Goo`0c0_oo:@04o`3oV@;oLol000?oi?l0ool0
C_oo04h00ol0ogd2odH0o`;ooo]Z0ooo0983oonJ0003oookJ_mAo`3oDOl000;oDOl00_oonfX2ool0
H`?o0?mS00Cok@3ooookJ_oonf[ooo]Z0ooo09400ol0okkoo`2Lool0W003oomM0006ok80ool0om_o
0?oKo`3ofonRo`3o0?lT0_oonfX3o`3o30Cooo]Z0_ooU0001?oonf[oo`0Cool04ooo01<2o`1jo`?o
oo]Z0ol0om`00ol=0?oooo]ZoookJP0RoookJP00:_oonfX2o`1joa3ooo]Z00?o0?mFool[0?oonfX0
3ooonfX<oolX0004oookJ_oo:03ooo]ZoolX00Cooo]Z00Goo`3/oookJ_ooU03oo`0golL0o`07oook
JP?oo`000_oonfX00ooo003oobP0oolX0002oolX00Cooo]Z00?o0?m1ool0IOoonfX00ooonfX00ooo
@P3ooo]Zool00008ool00005oolX0?l0=_ooobP0oolX0?l0om800_oonfX00ooo:03ooo]ZoookJP08
oookJP03o`26oooonf[ooo]Z00?ooo]Z00Co0?nCoookJ_oonf[oD_l00ooonfX01?oo07[ooo]Zoook
J_oonfX3oolX00;ooo]Z00OooaT0oookJ_oonf[ooo]Zo`3[oooonf[oo`0000?ooo]Z00?on@3ooook
J_oonfX01_oonfX4ool00003ooT0oooo003oo`0000;oo`001Ooo:00>oookJP05o`2Aoooonf[oobP0
oolX0?oonfX00ooo:0001?oonf[oo`1doookJ_oonfX6oolX00Gooo]Z1?l00004oookJP03onSo0?oo
N@3ooo]Z00SoobP02?oonfX7ool000CoobP00ooonfX:oolX017oogT04OoonfX<oj@0o`Cooo]Z1Ooo
0007ool0N0Coo`001Ol05?l7oolX00GoGP3o0_ooN@03ool0<`SoogT000?oi?l0ool0C_oo04h00ol0
ogd6oolX00?ooiX03?ooN@001?o]0?oooo]ZoookJ_oonfX3ool0T@;o0?nn0_oo09`3oomM00?o0?oK
0_nRo`02oookJP?oogT00_oonfX2oomi00?ooi@000?oo`0/ool04ooo01<01_ooN@1;oookJP;o07[o
4OoonfX00ol0oeKoob/0oookJP0BoookJP03o`1Qool0NOoooo]Z00Oooo]Z00?o7P3ooookJ_l0ocT0
0ooonfX00ooo0>cooo]ZoonD0002ool0=`03olL0oooonf[ooo]Z00[ooo]Z00?o0?m;oo?o0?oonfX0
1OoonfX00ol0od7oo`1UoookJP03oookJP06oom20?oonf[ooo]Zom_o0?oonf[o0?oC0_oonfX01Ooo
3@3oo`26oookJ_oonf[oo`2/00;ooo]Z00Co0?oBoookJ_oonf[oo`3i2_oonfX00ol0Q_oooo]Zoook
JP03oookJP04o`3oTooonf[ooo]Zoe;o00?ooo]Z00?oo`1joookJ_oonfX00_oonfX00ooo04Wooo]Z
oookJP02oookJP06oolI0?oonf[ooo]Zo`3[oooonf[oo`d01?oonfX00ooi0?oooo]ZoookJP09oook
JP03ooT0oomho`3ooo]Z00?ooo]Z00?oE_l0oookJ_oonfX03ooonfX00ol0TOoooo]Zo`3o:`03oook
JP04oc?o0?oonf[ooo]Zool0M0Gooo]Z00?o01coooT0oooonfX01OoonfX4o`0000Gooo]Z00?oj?l0
oookJ_oonfX01?oonfX00ol50?oooo]ZoookJP09oookJP03ool06Ooonf[oo`0=00?ooo]Z00?oS@3o
oookJ_oonfX01ooonfX2ool0N0;ooo]Z0oooXP07oookJPOoY03o5OoonfX;oj@0o`Wooo]Z1ooo07P0
1?ooXP3ooo]ZoooY0?ooj@05o`0Do`03ool03Ol^0?oo;P3o00;o;P3o0_l50?l5oeh0o`;oo`311?oo
03<00ooo:@3o08Coo`3oV@03o`3oV@;oLol00_oo04h4o`3oO@;oAP3o00Cooo]Zool0T_oo09;oo`2B
0oooVP02oookJP?oDOl00ooonfX01Ooo06?o0?mSo`3oHol0of?ok@3o00?ooo]Z0ooo09400ol0okko
o`2Lool0W003oomM0003ok80ool0om_o0?oK00;oX_l00ooonfX3o`3o30?ooo]Z0oooU0000ooonf[o
o`0Cool04`03o`1jo`?ooo]Z00?o0?oLoookJ_oonfX08_oonfX002cooo]Z00?o07[ooookJ_oonfX0
3_oonfX00ol0oeKoob/0oookJP0?oookJP[oobP00ooonfX00ooo:03ooo]ZoolX0004oookJP05ool0
k?oonf[ooi@0oookJ_o70?l01ooonfX00ooo003ooo]ZoookJP02oookJP03ool00?oo:03oobP000?o
obP00ooonfX00ol0od7oo`1UoookJP03oookJP03oom20?oonf[oo`0000Soo`0000GoobP0o`0foooo
:03ooo]Zo`3odP02oookJP03oolX0?oonf[ooo]Z00Sooo]Z00?o08KooookJ_oonfX00ooonfX01?l0
oi?ooo]ZoookJ_mBo`03oookJP03ool0N_oonf[ooo]Z00CoobP00_oonfX01Ooo6@3ooo]ZoookJ_oo
nf[o0>_o00;oo`000ooonfX00ooi0?oooo]ZoookJP06oookJPCoo`0000?on@3oool00?oo00000_oo
0005oolX00kooo]Z00Co097ooolX0?oo:03ooo]Z1?oo:0000ooo07Cooo]ZoookJP02oolX00?oo`00
0_oo:004oookJPCo00001?oonfX01?oXo`3ooo]ZoookJ_oonfX6oolX00Oooo]Z0ooo:005ool000Co
obP01?oonfX8oolX013oogT08?oonfX4oj@0o`Soo`000_oonfX00ooob@3oogT0ool0N006ool0N003
oomi0?ooj@3o01Co00Co01Co1ooo:005oeh0o`CoogT00_oo03<4oomi0004o`3oVOoTo`3oi?l0ool0
CPCo0?mm00GoogT0odH0oom60?ooQ03oool0TP03oonJ00;ooo]Z00?oDOl0oomi0?ooN@001OooN@02
o`3oH`04ond0oooonf[ooo]ZoookJP?oo`2A0_l0okh00ooonf[oo`2LoomM0002oomM00;o0?oK0_nR
o`000ol0obCooo]ZoookJP07oomi00?ooi@00ooo01<2o`1jodkooo]Z00?o07[ooookJ_oonfX03ooo
nfX00ol0oeKoob/0oookJP0BoookJP03o`1Qool0NOoooo]Z00Oooo]Z00?o7P3ooookJ_l0ocT00ooo
nfX01_oo0>cooo]ZoonD0?oonf[oo`0golL0o`cooo]Z00?o0?m;oo?o0?oonfX01OoonfX00ol0od7o
o`1UoookJP03oookJP06oom20?oonf[ooo]Zom_o0?oonf[o0?oC0_oonfX01Ooo3@3oo`26oookJ_oo
nf[oo`2/00;ooo]Z00Co0?oBoookJ_oonf[oo`3i2_oonfX00ol0Q_oooo]ZoookJP03oookJP04o`3o
Tooonf[ooo]Zoe;o00?ooo]Z00?oo`1joookJ_oonfX00_oonfX01Ooo04Wooo]ZoookJ_oonf[ooaT0
00?ooo]Z00?o0>_oool=0?oonfX01?oonfX00ooi0?oooo]ZoookJP09oookJP03ooT0oomho`3ooo]Z
00?ooo]Z00?oE_l0oookJ_oonfX03ooonfX00ol0TOoooo]Zo`3o:`03oookJP03oc?o0?oonf[oo`1d
00Gooo]Z00?o01coooT0oooonfX01OoonfX4o`0000Gooo]Z00?oj?l0oookJ_oonfX01?oonfX00ol5
0?oooo]ZoookJP08oookJP03ool06Ooonf[oo`0=00?ooo]Z00?oS@3ooookJ_oonfX01_oonfX2ool0
N004oookJ_ooXP3ooj80oonR00Oooo]Z0onT0?lWoookJP[oY03o1_oonfX7ool0N003oookJ_ooj@3o
01Co00Go01Co1?l^0?l2o`D0o`GoGP3o00?oo`31ool0<ooo03<00ooo03<00ol0Q?oo0?nIo`3oV@02
o`3oV@04og?o0?oTo`3oo`1>ool0CPCo0?mm0_m60?l00ooonf[oo`2Bool0TP03oonJ00;ooo]Z1?mA
o`02oookJP05ool0Hol0of?o0?mSo`3oHoo]0?l00ooonfX3ool0T@03o`3o__oonf[oo`2L00?ooed0
0ol0om/00onRo`3o0?lToookJP02oookJP?o0?l<0ooonfX3oonD00?oo`0C0ol0N_lUoookJP00;Ooo
nfX00ol0N_oooo]ZoookJP0>oookJP03o`3oE_oo:`3ooo]Z00oooo]Z2Ooo:004oookJP03oolX0?oo
nf[oobP000Cooo]Z00Goo`3/oookJ_ooU03ooo]ZolL0o`0<oookJP03ool00?oo:03oobP000?oobP0
0ooonfX00ol0od7oo`1UoookJP03oookJP03oom20?oonf[oo`0000Soo`0000Oooo]Zo`0foooonf[o
oo]Zo`3od_oonf[oo`3i00_ooo]Z00?o08KooookJ_oonfX00ooonfX00ol0oi?ooo]Zoe;o0004oook
JP03ool0N_oonf[ooo]Z00CoobP000?ooo]ZoolI0?oonfX00_oonfX01?l0joooo`00ool00?oo0003
oookJP03ooT0oooonf[ooo]Z00Gooo]Z1?oo00001?oi0?ooo`00ool00?oonfX7oolX00gooo]Z00?o
097ooolX0?oo:0001Ooo:0001?oo07Cooo]ZoookJ_oonfX4ool000;oobP01?oonfX4o`0000Cooo]Z
00?oj?l0oookJ_oonfX00_oonfX5oolX00Gooo]Z1?oo:0000ooo00goo`00ool00002ool000CoobP0
00?ooo]Zool00?oo00000_oo0006oolX00CoogT00onT0?l9oomi02cooo]Z1onT0?l5oomi0003oonR
0?oo07Soo`1h00Coo`1h00?oonT0o`0Dool05?l00ol05?l4oolX0003o`D0ooooN@3oogT000KoogT0
1?oo03<2oomi00;o0?nI00CoA?l0onCo0?oo04koo`1>0ol0ogd4odH0o`04ool0T_ooVP3ooiX0oonJ
00?ooo]Z0omAo`03oookJP?o0?mS00Cok@3ooookJ_oonf[ooo]Z0ooo0942o`3o_P03oookJ_oo09co
oed000;ooed00_l0om/2oj;o0003o`3o9?ooN@3oogT000OoogT00oooU002ool04`03o`1joooonf[o
oo]Z04cooo]Z00?o07[ooookJ_oonfX03ooonfX00ol0oeKoob/0oookJP0BoookJP03o`1Qool0NOoo
oo]Z00Oooo]Z00?o7P3ooookJ_l0ocT00ooonfX01_oo0>cooo]ZoonD0?oonf[oo`0golL0o`cooo]Z
00?o0?m;oo?o0?oonfX01OoonfX00ol0od7oo`1UoookJP03oookJP0=oom20?oonf[ooo]Zom_o0?oo
nf[o0?oCoookJ_oo3@3ooo]Zool0Q_oonf[oo`2/o`0fo`02oookJP03o`3od_oonf[oo`3i00_ooo]Z
00?o08KooookJ_oonfX00ooonfX01?l0oi?ooo]ZoookJ_mBo`03oookJP05ool0N_oonf[ooo]Zoook
J_oo04T01?oonfX01_oo6@3ooo]ZoookJ_oonf[o0>_oool=00Cooo]Z00?on@3ooookJ_oonfX02Ooo
nfX00ooi0?oooo]ZogSo0003oookJP03oeKo0?oonf[ooo]Z00oooo]Z00?o097ooookJ_l0ob/00ooo
nfX00olco`3ooo]Zool0M006oookJP03ooT0oooonf[ooo]Z00Cooo]Z1?l00004oookJP03onSo0?oo
nf[ooo]Z00Gooo]Z00?o1@3ooookJ_oonfX01ooonfX00ooo01Wooo]Zool03@03oookJP03ohd0oooo
nf[ooo]Z00Gooo]Z0_oo07P00ooonf[ooj80oonR0007oookJP?oY03o=?oonfX7oj@0o`Kooo]Z1_oo
07P2oooY00Go01Co0ol^0?l3o`D0o`CoGP3o0_oo0<44ool0<`06o`24ool0oiWo0?nIo`3oVOoonf[o
Lol00ooo04h3o`3oO@?oAP3o00?ooo]Zool0T_ooVP000_ooVP03oookJP?oDOl00ooonfX3o`3oH`04
ond0oooonf[ooo]ZoookJP?oo`2A00?o0?nnoookJ_oo09`00oooG@03o`3of`03oj;o0?l0obCooo]Z
00;ooo]Z0_l0o``4oookJP?ooi@00ooo01<00ol0N_oooo]ZoookJP0RoookJP00;_oonfX00ol0N_oo
oo]ZoookJP0>oookJP;o0?mF3ooonfX8oolX00Kooo]Z00?oobP0oookJ_oo:0001?oonfX01Ooo0>co
oo]ZoonD0?oonf[oa`3o00cooo]Z00?oo`00oolX0?oo:0001?oo:002oookJP03o`3o@Ooo06Gooo]Z
00?ooo]Z00?ood80ool00?oo00001_oo00001?oo08Koo`2/oookJ_l0=_l2oookJP;oobP000?oo`3i
oookJ_oonfX02OoonfX00ol0Q_oooo]ZoookJP03oookJP03o`3oTooonf[oD_l000Cooo]Z00?oo`1j
oookJ_oo:0001Ooo:0001Ooo6@3ooo]ZoookJ_oonf[o0>_o00?oo`000_oonfX00ooi0?oooo]Zoook
JP05oookJPGoo`0000?on@3oogSo0?oonfX02?oo:00<oookJP03o`2Aoooo:03oobP000KoobP00ooo
nfX5ool00003oolX0?oonf[ooo]Z00;ooo]Z1?l00004oookJP03onSo0?oonf[ooo]Z00;ooo]Z00Co
o`00oolX0?oo:03oobP01OoonfX4oolX0003ool03Ooo003oo`0000;oo`000ooo:008ool000?oobP0
00Cooo]Zoomi0?ooN@3oogT00_nT0?l3oookJPKoogT0=?oonfX2oomi0003oj@0oooo003oo`0000Co
Y03o0ooo:002oonR00Coo`1h00CoobP0oooY0?l05?oo01Co3oooN@04ool0<`Co0?nI00?oA?l0ool0
C_oo04h01?l0ogd3odH0o`05oookJ_ooVP3ooiX0oonJ0?n40?l00_oonfX4oe7o00;ooo]Z1?l0of<0
0oo]0?oooo]ZoookJP03ool0T@;o0?nn00?ooo]Zool0W?ooG@000_ooG@02o`3of`_oogT000Cooo]Z
oonD0?ooU03oo`0CCooonfX00ol0N_oooo]ZoookJP0?oookJP03o`3oE_oo:`3ooo]Z01;ooo]Z00?o
067oo`1ioooonfX01ooonfX00olN0?oooo]Zo`3o>@03oookJP06ool0k?oonf[ooi@0oookJ_oo03Oo
a`3o3?oonfX00ol0od_olol0oookJP05oookJP03o`3o@Ooo06Gooo]Z00?ooo]Z00good80oookJ_oo
nf[ofol0oookJ_l0om?ooo]Zool=0?oonf[oo`26oookJ_oo0:co03Ko00;ooo]Z00?o0?oBoookJ_oo
0?T02ooonfX00ol0Q_oooo]ZoookJP03oookJP04o`3oTooonf[ooo]Zoe;o00?ooo]Z00Goo`1joook
J_oonf[ooo]Zool0B@04oookJP06oolI0?oonf[ooo]ZoookJ_l0joooo`d01?oonfX00ooi0?oooo]Z
oookJP09oookJP03ooT0oomho`3ooo]Z00?ooo]Z00?oE_l0oookJ_oonfX03_oonfX00ol0TOoooo]Z
o`3o:`03oookJP03oc?o0?oonf[oo`1d00Kooo]Z00?on@3ooookJ_oonfX01?oonfX4o`0000Cooo]Z
00?oj?l0oookJ_oonfX01?oonfX00ol50?oooo]ZoookJP07oookJP03ool06Ooonf[oo`0=00?ooo]Z
00?oS@3ooookJ_oonfX01?oonfX2ool0N003oookJ_ooXP3ooj8000Kooo]Z0onT0?lnoookJPOoY03o
1?oonfX00oooXP3oo`1hool0N002ool0N003oookJ_ooj@3oonT000Go01Co0_l^0?l00ooonf[o1@3o
o`D0o`04oeh0o`;oo`311?oo03<4o`3oV@04oookJ_mco`3oo`1>ool0CPCo0?mm0_m60?l00ooonf[o
o`2BoonJ0002oonJ00?ooo]Z1?mAo`02oookJPCo0?mS00?ok@3ooookJ_oonfX00ooo09400ol0okko
oo]Zool0W003oomM00?o0?oK00CoX_l0o`3o9?oonf[ooo]Z0ol0o``4oookJP?ooi@000?oo`0Coook
J_oonfX08_oonfX002oooo]Z00?o07[ooookJ_oonfX03ooonfX00ol0oeKooo]ZoookJP0=oookJPOo
obP01_oonfX01?lN0?oooo]ZoookJ_oo:004oookJP05ool0k?oonf[ooi@0oookJ_o70?l02ooonfX0
0ooo:03oo`00oolX0006oolX0003oookJ_l0od7oo`1U00Cooo]Z00?ood80ool00?oo00001?oo0000
1Ooo3@3ooo]Zool0Q_oo0:co03Ko00;ooo]Z0ooo:0000ooo0?Wooo]ZoookJP09oookJP03o`26oooo
nf[ooo]Z00?ooo]Z00?o0?nCoookJ_mBo`000ooonfX00ooo07[ooo]ZoolX0006oolX0005oolI0?oo
nf[ooo]ZoookJ_l0jol00ooo0002oookJP03ooT0oooonf[ooo]Z00Gooo]Z0ooo00000ooonf[on@3o
ogSo0002oookJPSoobP02ooonfX00ol0TOooobP0oolX0006oolX00?ooo]Z1Ooo0002oolX00?ooo]Z
1?l00003oookJP03onSo0?oonf[ooo]Z00;ooo]Z0ooo00000ooo:03oo`00oookJP02oookJPGoobP0
4?oo00000ooonf[oobP0oookJP02oookJP03oomi0?nT0?ooY03o00Gooo]Z1?ooN@0ioookJPGoo`00
00?ooo]Zoj@0oonT0?l01_nT0?l00oooXP3oo`1hool0N003ool0N003ohd0ooooN@3oogT000_oogT0
00CoGP3ooomi0?ooN@3oogT01?oo03<4o`3oV@03odCo0?oo04koo`1>00?o0?mm1?m60?l3oonJ0004
ool0T_oonf[ooo]ZoookJP?oDOl00ooonfX3o`3oH`03ond0oooonf[ooo]Z00?oo`2A0_l0okh00ooo
nf[oo`2LoomM0002oomM00;o0?oK2_ooN@000ooonf[ooi@0oookJP1?oookJP03o`1joooonf[ooo]Z
00oooo]Z00?o0?mFool[0?oonfX04_oonfX00ol0HOoo07WooookJP06oookJP04oah0oooonf[ooo]Z
o`3o>@?ooo]Z00Koo`3/oookJ_ooU03ooo]Zool0=oo70?l<oookJP03o`3oBooco`3ooo]Z00Gooo]Z
00?o0?m1ool0IOoonfX00ooonfX03ooo@P3ooo]ZoookJ_oKo`3ooo]Zo`3odooonf[oo`d0oookJ_oo
08Kooo]Zool0[?l0=_oooo]Zo`3odP02oookJP03ool0nOoonf[ooo]Z00Wooo]Z00?o08KooookJ_oo
nfX00ooonfX00ol0oi?ooo]Zoe;o0003oookJP03ool0N_oonf[ooo]Z00;ooo]Z00Goo`19oookJ_oo
nf[ooo]ZoolI0003oookJP03o`3[oooo3@3ooo]Z00?ooo]Z00?on@3ooookJ_oonfX02OoonfX00ooi
0?oooo]ZogSo0003oookJP03oeKo0?oonf[ooo]Z00kooo]Z00?o097ooookJ_l0ob/00ooonfX00olc
o`3ooo]Zool0M006oookJP03ooT0oooonf[ooo]Z00Cooo]Z1?l00004oookJP03onSo0?oonf[ooo]Z
00kooo]Z00?oo`0Iool03OoonfX00_oonfX00on=0?oooo]ZoookJP04oookJP04ool0N?oonf[ooj80
oonR00Kooo]Z0_nT0?m8oookJPWoY03o1Ooo07P00ooonf[oonT0oooY0005o`0Do`;o;P3o0_l50?l3
oeh0o`03ool0?Ooo0<7oo`3100Coo`0c1?l0oiT01?oonf[oo`1>ool0C_oo04h3o`3oO@?oAP3o00Go
oo]ZoonJ0?ooVP3ooiX0ool0TP03oookJP?oDOl00_oonfX01Ooo06?o0?mSo`3oHol0of?ok@3o00;o
oo]Z0ooo09400ol0okkooo]Zool0W003oomM00?o0?oK00CoX_l0o`3o9?l0obCooo]Z0ol0o``4oook
JP03oonD0?oonf[ooo]Z02;ooo]Z000`oookJP03o`1joooonf[ooo]Z00oooo]Z00?o0?mFoookJ_oo
nfX03?oonfX5oolX0003oookJ_oo:03ooo]Z00Kooo]Z00Co7P3ooookJ_oonf[oobP01?oonfX01_oo
0>cooo]ZoonD0?oonf[oa`3oool000[ooo]Z2Ooo:0000ooonf[o0?m1ool0I@04oookJPGoo`000_oo
nfX01Ooo3@3ooo]Zool0Q_oo0:co03Ko00;ooo]Z0ooo:0000ooo0?Wooo]ZoookJP09oookJP03o`26
oooonf[ooo]Z00;ooo]Z00Co0?nCoookJ_oonf[oD_l00ooonfX00ooo07[ooo]ZoolX0005oolX0006
oolI0?oonf[ooo]ZoookJ_oo003o0>_o0ooo00000ooonf[on@3ooookJP06oookJP03ool00?oonf[o
oo]Z00;ooo]Z00?on@3oogSo0?oonfX02Ooo:00;oookJP03o`2Aoooo:03oobP000KoobP00_oonfX5
ool000;oobP00ooonfX4o`0000?ooo]Z00?oj?l0oookJ_oonfX00_oonfX4ool000;ooo]Z1Ooo:00A
ool000Gooo]Z0_nT0?l7oookJP03oomi0?oonf[ooo]Z03[ooo]Z2?oo0006oookJPGoY03o00Cooj80
ool0N?oo07Soo`1h3OooN@03oeh0o`03odCo0?oo0<7oolT000Coo`0c1?l0oiT2ool0CPCo0?mm0om6
0?l3oonJ0004ool0T_n40?oooo]ZoookJPCoDOl00_oonfX3o`3oH`03ond0oooonf[ooo]Z00?oo`2A
0_l0okh2oomi00?ooed00ol0om/7oomi05;ooo]Z00?o07[ooookJ_oonfX03ooonfX00ol0oeKoob/0
oookJP0BoookJP03o`1Qoooonf[ooo]Z00Kooo]Z00Co7P3ooookJ_oonf[o0?li0ooonfX01_oo0>co
oo]ZoonD0?oonf[oo`0golL0o`gooo]Z00?olol0oookJ_oonfX01?oonfX00ol0od7oo`1UoookJP03
oookJP0?oom20?oonf[ooo]Zom_o0?oonf[o0?oCoookJ_oo3@3ooo]Zool0Q_oonf[oo`2/o`0foooo
nf[o0?oB00;ooo]Z00?oo`3ioookJ_oonfX02OoonfX00ol0Q_oooo]ZoookJP02oookJP04o`3oTooo
nf[ooo]Zoe;o00?ooo]Z00Goo`1joookJ_oonf[ooo]Zool0B@04oookJP06oolI0?oonf[ooo]Zoook
J_l0joooo`d01?oonfX00ooi0?oooo]ZoookJP09oookJP03ooT0oooonf[oN?l000?ooo]Z00?oE_l0
oookJ_oonfX03_oonfX00ol0TOoooo]Zo`3o:`02oookJP04oc?o0?oonf[ooo]Zool0M0Gooo]Z00?o
n@3ooookJ_oonfX01?oonfX4o`0000?ooo]Z00?oj?l0oookJ_oonfX03_oonfX00ooo01Wooo]Zool0
3@0;oookJP03oonR0?oonf[ooo]Z00Cooo]Z0_nT0?mCoookJPGoY03o1?oo07P01?ooXP3oS@3ooooY
0?ooj@04o`0Do`;o;P3o00?ooo]Zoeh0oomN0?l00_mN0?l00ooo03goo`31ool0`@04ool0<`Co0?nI
00?ooo]Zool0C_oo04h01?l0ogd3odH0o`?ooiX000Coo`2Boh@0oooonf[ooo]Z1?mAo`000ooonf[o
o`1So`3oH`02o`3oH`03ond0oooonf[ooo]Z00?oo`2A0_l0okh01?oo09cooed0oomM0?ooG@04o`3o
f`;oX_l000Co0?lTo`3o3?l0o`co0?l<9_oonfX0037ooo]Z00?o07[ooookJ_oonfX03ooonfX00ol0
oeKooo]ZoookJP0<oookJP?oobP00ooonfX00ooo:03ooo]ZoookJP05oookJP04oah0oooonf[ooo]Z
oolX00Cooo]Z00Koo`3/oookJ_ooU03oo`00olL0oooo000:oookJPWoobP000?ooo]Zool00?oo0000
1?oonfX3ool0000:oookJ_oo003ooo]ZoookJ_oo3@3ooo]Zool0Q_oo0:co03KooookJPCoobP000?o
o`3ioookJ_oonfX02OoonfX00ooo003ooo]ZoookJP02oookJP04o`3oTooonf[ooo]Zoe;o00?ooo]Z
00?oo`1joolX0?oo:0001Ooo:0000ooo6@3ooo]ZoookJP02ool00006oolX0?oo003oo`00ool00?oo
nf[on@3o2ooonfX00ooi0?ooN?l0oookJP07oolX00gooo]Z00?o097ooolX0?oo:0001_oo:002oook
JPKoo`0000CoobP0oookJ_oonf[ooo]Z1?l00003oookJP04onSo0?oonf[ooo]ZoookJPGoo`0000?o
oo]ZoolX0?oo:0000_oo:00Bool000Gooo]Z00?oY03ooookJ_oonfX0:OoonfX4oomi01Oooo]Z2ooo
0009oookJP03oj@0oooo:03oobP000ooogT000?o;P3ooeh0oomN0?l01?oob@000ooo0<7oo`0cool0
<`02ool0<`?o0?nI0ooo04h3o`3oO@03ooT0oom60?ooAP3o00CooiX000Coo`2Boh@0oooonf[ooo]Z
0omAo`02oookJPCo0?mS00?ok@3ooookJ_oo09400_oo0943o`3o_P04ool0W?ooG@3ooed0oomM00?o
0?oK1OooN@1BoookJP03o`1joooonf[ooo]Z00oooo]Z00?o0?mFool[0?oonfX04_oonfX00ol0HOoo
oo]ZoookJP06oookJP04oah0oooonf[ooo]Zo`3o>@?ooo]Z00Koo`3/oookJ_ooU03oo`0goookJ_o7
0?l=oookJP03oo?o0?oonf[ooo]Z00Cooo]Z00?o0?m1ool0IOoonfX00ooonfX03ooo@P3ooo]Zoook
J_oKo`3ooo]Zo`3odooonf[oo`d0oookJ_oo08Kooo]Zool0[?l0=_oooo]Zo`3odP02oookJP03ool0
nOoonf[ooo]Z00Wooo]Z00?o08KooookJ_oonfX00_oonfX01?l0oi?ooo]ZoookJ_mBo`03oookJP05
ool0N_oonf[ooo]ZoookJ_oo04T00ooonfX00ooo6@3ooo]ZoookJP02oookJP03o`3[oooo3@3ooo]Z
00?ooo]Z00?on@3ooookJ_oonfX02?oonfX00ooi0?oooo]ZogSo0003oookJP03oeKo0?oonf[ooo]Z
00kooo]Z00?o097ooookJ_l0ob/00_oonfX01?lco`3ooo]ZoookJ_oo07@5oookJP03ooT0oooonf[o
oo]Z00Cooo]Z1?l00003oookJP03onSo0?oonf[ooo]Z00gooo]Z00?oo`0IoookJ_oo00d02ooonfX0
0oooXP3ooo]ZoookJP04oookJP03oj@0oooonf[ooo]Z05Wooo]Z0onT0?l4ool0N004oonR0?oonf[o
onT0oooY00Go01Co0_l^0?l4oeh0o`03ool0?Ooo0<7oo`3100Coo`0c0ol0oiT01?oonf[oo`1>ool0
C_oo04h3o`3oO@?oAP3o1?ooVP001?oo09;ooo]ZoookJ_oonfX3oe7o0003oookJ_oo06?o0?mS00?o
0?mS00?ok@3ooookJ_oo09400_oo0942o`3o_P03ool0W?ooG@3ooed000;ooed00ol0om/3oj;o00;o
0?l<9?oonfX003;ooo]Z0_l0N_l@oookJP03o`3oE_oonf[ooo]Z00cooo]Z00?oobP0oookJ_oonfX0
0ooonfX00ooo:03ooo]ZoookJP05oookJP03oah0oooonf[o0?li00Gooo]Z00Koo`3/oookJ_ooU03o
o`00olL0oooo0009oookJPSoobP00_oonfX3ool000Cooo]Z00Ooo`00oookJ_oKo`3ooo]Zool00?oo
nf[oo`d000;ooo]Z00Coo`2/oookJ_l0=_oooo]Z1?oo:00;oookJP;oo`000ooonfX01Ol0oi?ooo]Z
oookJ_oonf[oo`0000?ooo]Z00?oo`1joolX0?oo:0001Ooo:0001Ooo6@3ooo]ZoookJ_oo003oobP0
00Coo`0000?on@3ooookJ_oonfX02_oonfX00ooi0?ooN?l0oolX0004oolX00oooo]Z00?o097ooolX
0?oo:0001ooo:007ool000;oobP00_oonfX4o`0000?ooo]Z00?oj?l0oookJ_oonfX01_oo0004oolX
01;oo`001?oonfX2oj@0obcooo]Z2OooN@0@oookJQ3oo`001ooonfX00ooo:03oogT0oomi000?oomi
00;o01Co1_oob@000om4o`3o>Ol0ool0`@04ool0<`?o0?nI0_oo04h01?l0oggoogT0oomi0?ooN@03
odH0o`CooiX000?oQ03ooomi0?ooN@000omAo`02oookJP06ool0Hol0of?o0?mSo`3oHoo]0?oooo]Z
1?oo0942o`3o_P04ool0W?ooG@3ooed0oomM00?o0?oK0_nRo`1CoookJP;o07[o4?oonfX00ol0oeKo
ob/0oookJP0BoookJP03o`1Qoooonf[ooo]Z00Kooo]Z00?o7P3ooookJ_l0ocT01?oonfX01_oo0>co
oo]ZoonD0?oo03Oooo]ZolL0o`gooo]Z00?olol0oookJ_oonfX00ooonfX00ol0od7ooo]Zool0I@04
oookJP03oom20?oonf[ofol000;ooo]Z00co0?oCoookJ_oo3@3ooo]Zool0Q_oo0:cooo]Zo`0foooo
nf[o0?oBoookJ_oo0?T;oookJP03o`26oooonf[ooo]Z00?ooo]Z00Co0?nCoookJ_oonf[oD_l00ooo
nfX01Ooo07[ooo]ZoookJ_oonf[oo`1900?ooo]Z00KooaT0oookJ_oonf[ooo]Zo`3[oooo3@04oook
JP03ooT0oooonf[ooo]Z00Wooo]Z00?on@3ooookJ_mho`000_oonfX00omFo`3ooo]ZoookJP0>oook
JP03o`2Aoooonf[o0?l[00?ooo]Z00?o<ol0oookJ_oo07@01OoonfX00ooi0?oooo]ZoookJP04oook
JPCo00000ooonfX00ooXo`3ooo]ZoookJP0=oookJP03ool06Ooo00gooo]Z00[ooo]Z00?ooj80oook
J_oonfX00ooonfX2oj@0odKooo]Z2Ooo0?/BoookJP;oY03o1Ooo07P01?ooXP3ooo]ZoooY0?ooj@04
o`0Do`;o;P3o1OmN0?l00ooo03goo`31ool0<`03ool0<`?o0?nI00?ooo]Zool0C_oo04h01?l0ogd3
odH0o`CooiX000?oQ03ooookJ_oonfX00omAo`000ooonf[oo`1Sool0H`03o`3oH`03ond0oooonf[o
o`2A00?oo`2A0_l0okh01?oo09cooed0oomM0?ooG@03o`3of`;oX_l09?oonfX003Cooo]Z00?o07[o
oookJ_oonfX03_oonfX00ol0oeKooo]ZoookJP0BoookJP03oolX0?oonf[ooo]Z00Gooo]Z00?o7P3o
oookJ_l0ocT01OoonfX00ooo0>cooo]Zool00004ool000Sooo]Z1_oo:004oookJP?oo`000ooonfX0
2?oo@P3ooo]ZoookJ_oKo`3ooo]Zool00?oonf[oo`d00_oonfX00ooo0:cooo]Zo`0fo`06oolX00[o
oo]Z0_oo0003oookJP03o`3oTooonf[ooo]Z00;oo`000_oonfX00ooo07[oobP0oolX0006oolX0003
ool00?oonf[oo`0000;oobP01?oo00000ooi0?oooo]ZoookJP09oookJP03ooT0oomho`3ooo]Z00?o
obP000?oE_l0oookJ_oonfX03OoonfX00ol0TOooobP0oolX0007oolX00Ooo`000_oo:002oookJPCo
00000ooonfX00ooXo`3ooo]Zool00005ool000;ooo]Z1?oo:00@ool000Cooo]Z00?oY03ooookJ_oo
nfX0;?oonfX>oomi00cooo]Z4?oo0003ool0n`?ooo]Z00?oobP0oomi0?ooN@004OooN@04o`0Do`Co
olT00omN0?l00olio`3oo`31ool0<`03ool0<`?o0?nI0_oo04h4oomi00?oAP3o1?ooVP02oomi00Co
DOl000?ooo]Zool0Hol0of<00ol0of<00oo]0?oooo]Zool0T@02ool0T@?o0?nn0oooG@02o`3ofeGo
oo]Z00?o07[ooookJ_oonfX03_oonfX00ol0oeKoob/0oookJP0BoookJP03o`1Qoooonf[ooo]Z00Ko
oo]Z00?o7P3ooookJ_l0ocT01?oonfX01_oo0>cooo]ZoonD0?oo03Oooo]ZolL0o`gooo]Z00?olol0
oookJ_oonfX00ooonfX00ol0od7ooo]Zool0I@03oookJP04oom20?oonf[ooo]Zom_o00;ooo]Z00co
0?oCoookJ_oo3@3ooo]Zool0Q_oo0:cooo]Zo`0foooonf[o0?oBoookJ_oo0?T;oookJP03o`26oooo
nf[ooo]Z00;ooo]Z00Co0?nCoookJ_oonf[oD_l00ooonfX01Ooo07[ooo]ZoookJ_oonf[oo`1900Co
oo]Z00KooaT0oookJ_oonf[ooo]Zo`3[oooo3@04oookJP03ooT0oooonf[ooo]Z00Sooo]Z00?on@3o
oookJ_mho`000ooonfX00omFo`3ooo]ZoookJP0=oookJP03o`2Aoooonf[o0?l[00?ooo]Z00?o<ol0
oookJ_oo07@01OoonfX00ooi0?oooo]ZoookJP04oookJPCo00000ooonfX00ooXo`3ooo]ZoookJP0<
oookJP03ool06Ooonf[oo`0=00[ooo]Z00?ooj80oookJ_oonfX00ooonfX00onT0?oooo]ZoookJP1?
oookJP_oo`3k2ooonfX3oj@0o`Goo`1h00?ooj80oooY0?ooj@001?l05?l3obh0o`CoGP3o00?oo`0m
ool0`Ooo03<00ooo03<01?oo=03o0?nIo`3oVOoTo`02ool0CPCo0?mm0_m60?l00ooonf[ooiX0oonJ
0002oonJ00;ooo]Z1?mAo`02ool0H`Co0?mS00?ok@3oo`3oL?oo09400_oo0943o`3o_P?ooed00_l0
om/ToookJP00=OoonfX00ol0N_oooo]ZoookJP0>oookJP03o`3oE_oonf[ooo]Z01;ooo]Z00?oobP0
oookJ_oonfX01OoonfX00olN0?oooo]Zo`3o>@05oookJP03ool0k?oonf[oo`0000Coo`001ooonfX6
oolX00Cooo]Z1?oo0003oookJP08oom20?oonf[ooo]Zom_o0?oonf[oo`00oookJ_oo3@02oookJP03
ool0[?oonf[oobP000KoobP02OoonfX3ool000?ooo]Z00?o0?nCoookJ_oo00000_oo0002oookJP03
ool0N_oo:03oobP000CoobP000Cooo]Zool00?oonf[oo`000ooo:003ool00003ooT0oooonf[ooo]Z
00[ooo]Z00?on@3ooookJ_oo:0000_oonfX00omFo`3ooo]ZoookJP0=oookJP03oolX0?l0TOooobP0
00SoobP01ooo0003oookJPGo000000?ooo]ZonSo0?oonfX01ooo0003oookJPCoobP01ooo00000ooo
nf[oo`00ool00004ool000?ooo]Z0_nT0?l_oookJQ3oogT02?oo^`02oookJP_oo`000_oonfX2ool0
00Cooo]Z1_oo0?/5oookJPooogT000?oolT0o`0Dool05?l00ol05?l00ooob@3oA?l0oeh0o`03oeh0
o`03ocWo0?oo0<7oo`0c00?oo`0c0_l0oiT00ooo:03oo`1>ool0CP07oomi00CooiX000?oogT0oook
J_mAo`000_mAo`000ooob@3oo`1Sool0H`04o`3oH`04oookJ_oo097oo`2Aool0T@?o0?nn0_ooG@1F
oookJP03o`1joooonf[ooo]Z00kooo]Z00?o0?mFool[0?oonfX04_oonfX00ol0HOoooo]ZoookJP06
oookJP03oah0oooonf[o0?li00Cooo]Z00Goo`3/oookJ_ooU03oo`0golL0o`0>oookJP03oo?o0?oo
nf[ooo]Z00?ooo]Z00?o0?m1oookJ_oo06D00ooonfX01?oo@P3ooo]ZoookJ_oKo`02oookJP09o`3o
dooonf[oo`d0oookJ_oo08Koo`2/oookJ_l0=_oo0?oB00;ooo]Z00?oo`3ioookJ_oonfX02OoonfX0
0ol0Q_oooo]ZoookJP02oookJP04o`3oTooonf[ooo]Zoe;o00?ooo]Z00Goo`1joookJ_oonf[ooo]Z
ool0B@03oookJP06oolI0?oonf[ooo]ZoookJ_l0joooo`d01?oonfX00ooi0?oooo]ZoookJP09oook
JP03ooT0oomho`3ooo]Z00;ooo]Z00?oE_l0oookJ_oonfX03_oonfX00ol0TOoooo]Zo`3o:`02oook
JP03oc?o0?oonf[oo`1d00Gooo]Z00?on@3ooookJ_oonfX01?oonfX5o`0000;ooo]Z00?oj?l0oook
J_oonfX03?oonfX00ooo01Woo`0=oookJP09oookJP03oonR0?oonf[ooo]Z00?ooo]Z00?oY03ooook
J_oonfX0=_oonfX?oonk01Kooo]Z1_oo0?/:oookJP?oY03o1Ooo07P00oooXP3oonT0o`0Do`04o`0D
o`;o;P3o1?mN0?l00ooo03goo`31ool0<`03ool0<`04oold0?l0oiWooo]ZonCo00;oo`1>1?l0ogd2
odH0o`03oookJ_ooVP3ooiX000;ooiX00_oonfX3oe7o00?oo`1S1?l0of<01?oonf[oo`2Aool0TOoo
0943o`3o_P;ooed09?oonfX003Kooo]Z00?o07[ooookJ_oonfX03_oonfX2oolX01?ooo]Z00?oobP0
oookJ_oonfX01OoonfX00olN0?oooo]Zo`3o>@05oookJP03ool0k?oo003oo`0000Coo`001ooonfX3
oolX00;ooo]Z00?oobP0oookJ_oonfX00_oonfX4ool000?ooo]Z00Cood80oookJ_oonf[ofol00ooo
nfX01Ooo3@3ooo]ZoookJ_oo0:cooo]Z00OoobP02?oonfX4ool000;ooo]Z00?o0?nCoookJ_oonfX0
0ooo0002oookJP03ool0N_oo:03oobP000;oobP00_oonfX2ool00003oookJ_oo003oobP000;oobP0
0ooo00000ooi0?oooo]ZoookJP09oookJP03ooT0oomho`3ooo]Z00?ooo]Z00?oE_l0oookJ_oonfX0
3?oonfX00ooo:03o097ooolX0005oolX0003ool0M?oonf[oo`0000Ooo`000ooonfX4o`0000;ooo]Z
00?oj?l0ool00?oo00001_oo0004oookJP?oobP000?oo`0=ool00?oo00000ooo0003oookJPCoo`00
0ooonfX00onT0?oooo]ZoookJP0UoookJPGoobP00_oonfX3oonk00googT01ooonfX3ool00003oook
J_oo^`3ook/000Wook/01?oonfX5ool000Oooo]Z1Ooo0?/@oomi00?oo`1h0_oob@04o`0Do`;o;P3o
1?mN0?l00ooo03goo`31ool0<`02ool0<`05ocWo0?l0oiWo0?nIoolX0?oo04h02?ooN@04oonJ0003
oh@0oomAo`3oDOl000;oDOl00ooo06<3o`3oH`04ond0oooo097oo`2Aool0T@;o0?nnEooonfX00ol0
N_oooo]ZoookJP0>oookJP03o`3oE_oo:`3ooo]Z01;ooo]Z00?o067ooookJ_oonfX01_oonfX00olN
0?oooo]Zo`3o>@04oookJP05ool0k?oonf[ooi@0ool0=oo70?l03_oonfX00ooco`3ooo]ZoookJP03
oookJP03o`3o@Ooonf[oo`1U00?ooo]Z00Cood80oookJ_oonf[ofol00ooonfX02?oo3@3ooo]Zoook
J_oo08Koo`2/oookJ_l0=_oo0?oB0_oonfX00ooo0?Wooo]ZoookJP08oookJP03o`26oooonf[ooo]Z
00?ooo]Z00?o0?nCoookJ_mBo`001?oonfX01Ooo07[ooo]ZoookJ_oonf[oo`1900?ooo]Z00KooaT0
oookJ_oonf[ooo]Zo`3[oooo3@03oookJP03ooT0oooonf[ooo]Z00Wooo]Z00?on@3ooookJ_mho`00
0ooonfX00omFo`3ooo]ZoookJP0=oookJP03o`2Aoooonf[o0?l[00;ooo]Z00?o<ol0oookJ_oo07@0
1OoonfX00ooi0?oooo]ZoookJP04oookJPCo00000_oonfX00ooXo`3ooo]ZoookJP0<oookJP03ool0
6Ooo00gooo]Z00Wooo]Z00?ooj80oookJ_oonfX00ooonfX00onT0?oooo]ZoookJP0[oookJPcook/0
3ooonfX;oonk017ooo]Z1_oo0?/9oookJP?oY03o1Ooo07P00oooXP3oonT0o`0Do`03o`0Do`;o;P3o
1OmN0?l01?oo0<7oo`0cool0<ooo03<2ocWo0003o`3oVOoo_P3oo`1>00;oo`1>1?l0ogd2odH0o`03
ool0T_ooVP3ooiX000;ooiX000?ooo]Zoe7o0?mAo`000_mAo`03ool0H`?o0?mS00Cok@3oool0TOoo
097oo`2A0_l0okhToookJP00=ooonfX00ol0N_oooo]ZoookJP0=oookJP?oobP04ooonfX00ooo:03o
oo]ZoookJP05oookJP03oah0oooonf[o0?li00Gooo]Z00?oo`3/ool00?oo00001Ooo0006oookJP03
oolX0?oonf[ooo]Z00;ooo]Z00CoobP0oookJ_oonf[ooo]Z1_oo0002oookJP04oom20?oonf[ooo]Z
om_o00?ooo]Z00Coo`d0oookJ_oonf[oo`2/2?oo:008oookJPCoo`000_oonfX00ol0oi?ooo]Zool0
0003ool00005oookJ_oo07[oobP0oolX0?oo04T01?oonfX3ool000CoobP00_oo00000ooi0?ooo`00
oookJP09oookJP03ooT0oomho`3ooo]Z00?ooo]Z00?oE_l0oookJ_oonfX03?oonfX00ooo:03o097o
oolX0003oolX0003ool00?oonf[oo`1d00Cooo]Z0ooo0005oookJPCo00000_oonfX00ooXo`3ooo]Z
oookJP06ool000Cooo]Z00Goo`00oolX0?oo:03oo`0=oookJP03ool000Cooo]Z0ooo0003oookJP03
oj@0oooonf[ooo]Z02Gooo]Z2?oo^`03oolX00WoogT02ol0iol7ool000?o0>Oo1Ooo:008oonk00Co
o`002?oonfX2oomi00;oo`3k1?oo:003oookJP03oolX0?oob@3oolT000KoolT01Ooo07P00ooob@3o
01Coo`0Do`02o`0Do`;o;P3o00GoGP3ooomi0?ooN@3oogT0ool0?@04ool0<`;o>Ol02oooN@04oonJ
0004ooo90?mAo`3oDOl0oe7o00?oo`1S1?l0of<2ool0TESooo]Z00?o07[ooookJ_oonfX03OoonfX0
0ol0oeKooo]Zool[000CoookJP03o`1Qoooonf[ooo]Z00Kooo]Z00?o7P3ooookJ_l0ocT01?oonfX0
1Ooo0>cooo]ZoonD0?oo03Ooa`3o00kooo]Z00?olol0oookJ_oonfX00ooonfX00ol0od7ooo]Zool0
I@03oookJP04oom20?oonf[ooo]Zom_o00?ooo]Z00[oo`d0oookJ_oonf[oo`26ool0[?l0=_oooo]Z
o`3od_oonf[oo`3i2ooonfX00ol0Q_oooo]ZoookJP02oookJP04o`3oTooonf[ooo]Zoe;o00?ooo]Z
00Goo`1joookJ_oonf[ooo]Zool0B@03oookJP07oolI0?oonf[ooo]ZoookJ_l0jooooo]Zool=0003
oookJP03ooT0oooonf[ooo]Z00Wooo]Z00?on@3oogSo0?oonfX00_oonfX00omFo`3ooo]ZoookJP0=
oookJP03o`2Aoooonf[o0?l[00;ooo]Z00?o<ol0oookJ_oo07@01OoonfX00ooi0?oooo]ZoookJP04
oookJPCo00000_oonfX00ooXo`3ooo]ZoookJP0<oookJP03ool06Ooo00gooo]Z00Sooo]Z00?ooj80
oookJ_oonfX00ooonfX00onT0?oooo]ZoookJP0ToookJPSook/00ooonfXSo`3Wo`Wook/03_oonfX6
ool0n`Sooo]Z0onT0?l5ool0N003oonR0?l05?oo01Co00;o01Co0ol^0?l4oeh0o`Coo`0c0_lio`00
0ol0oiWookh0ool0CP02ool0CPCo0?mm00?oAP3oool0T_oo09801?ooVP001?oonf[oDOl0oe7o0?mA
o`03ool0H`Co0?mS0_oo094ToookJP00>?oonfX00ol0N_oooo]ZoookJP0=oookJPCoobP04_oonfX0
0ooo:03ooo]ZoookJP05oookJP03oah0oooonf[o0?li00Gooo]Z2?oo000;oookJP03oolX0?oonf[o
oo]Z00Ooo`000_oonfX01?oo@P3ooo]ZoookJ_oKo`02oookJP05ool=0?oonf[ooo]Zool0[?oo08H0
2?oo:007oookJPGoo`0000?ooo]Zo`3oTooonfX01Ooo00001Ooonf[oo`1joookJ_oonf[oo`1900?o
oo]Z0ooo0005oolX0003ool00?oonf[on@3o00_ooo]Z00?on@3ooookJ_oonfX00_oonfX00omFo`3o
oo]ZoookJP0<oookJP03oolX0?l0TOooobP000?oobP00_oo00000ooo07Cooo]ZoookJP02oookJP?o
o`001OoonfX4o`000003oookJ_oXo`3ooo]Z00Cooo]Z0ooo0004oookJP?oo`0000Goo`0=oookJ_oo
nf[ooo]Zool00005oookJP03oonR0?oo003ooo]Z00;ooo]Z00?oY03ooookJ_oonfX08OoonfX5oonk
0003oookJ_oo:03oobP000OoobP000?oo`00oomi0?ooN@001?ooN@000ooo:03oBol0od_o000Eod_o
00WoobP01?oo0009oonk00?ooo]Z0_ooN@02oolX00?oogT000?ooo]ZoolX0?oo:0000_oo:00=ooo9
00Goo`1h1?l05?l2obh0o`CoogT000?oo`0mool0<ooo03<00_oo03<<oomi0003ool0T_ooVP3ooiX0
00;ooiX01?mAo`03ool0H`;o0?mSFOoonfX00ol0N_oooo]ZoookJP0=oookJP03o`3oE_oonf[oob/0
01?ooo]Z00?o067ooookJ_oonfX01_oonfX00olN0?oooo]Zo`3o>@04oookJP05ool0k?ooU03oo`0g
oookJ_o70?l03_oonfX00ooco`3ooo]ZoookJP03oookJP03o`3o@Ooo06Gooo]Z00?ooo]Z00Cood80
oookJ_oonf[ofol00ooonfX02_oo3@3ooo]ZoookJ_oo0:cooo]Zo`0foooonf[o0?oBoookJ_oo0?T;
oookJP03o`26oooonf[ooo]Z00;ooo]Z00Co0?nCoookJ_oonf[oD_l00ooonfX01Ooo07[ooo]Zoook
J_oonf[oo`1900?ooo]Z00GooaT0oookJ_oonf[ooo]Zo`3[o`04oookJP03ooT0oooonf[ooo]Z00Wo
oo]Z00?on@3oogSo0?oonfX00_oonfX00omFo`3ooo]ZoookJP0=oookJP03o`2Aoooonf[o0?l[00;o
oo]Z00?o<ol0oookJ_oo07@01OoonfX00ooi0?oooo]ZoookJP04oookJPCo00000_oonfX00ooXo`3o
oo]ZoookJP0;oookJP03ool06Ooo00gooo]Z00Sooo]Z00?ooj80oookJ_oonfX00ooonfX00onT0?oo
oo]ZoookJP0PoookJPGook/00ooonfX8o`3Wo`?ooo]Z9Om;o`04o`3Wo`Wook/02ooonfX5ool0n`So
oo]Z0onT0?l5ool0N0Go01Co0_l^0?l4oeh0o`Coo`0c0olio`001?oo_P3oo`1>ool0C_oo04h4o`3o
O@03odH0oooo09;oo`2B00CooiX01?mAo`03ool0H`;o0?mS9?oonfX003Wooo]Z00?o07[ooookJ_oo
nfX03?oonfX6oolX017ooo]Z00?oobP0oookJ_oonfX01OoonfX00olN0?oooo]Zo`3o>@05oookJPSo
o`002ooonfX00ooo:03ooo]ZoookJP07ool000;ooo]Z00Cood80oookJ_oonf[oobP00_oonfX01?oo
3@3ooo]ZoookJ_oo0:`9oolX00Kooo]Z1_oo00000ooonf[o0?nCool00005ool00004ool0N_oonf[o
oo]Zool0B@?ooo]Z1?oo0004oolX00;ooo]Z00?on@3ooookJ_oonfX02OoonfX00ooi0?ooN?l0oook
JP03oookJP03ool00?oonf[ooo]Z00_ooo]Z00CoobP0o`2Aoooo:03oobP00_oonfX2ool00004ool0
M?oonf[ooo]ZoookJPCoo`001OoonfX4o`000003oookJ_oXo`3ooo]Z00Kooo]Z00Coo`00oookJ_oo
nf[ooo]Z0ooo00000ooo00gooo]ZoookJP07oookJP03oonR0?oonf[ooo]Z00;ooo]Z00?oY03ooook
J_oonfX07_oonfX4oonk00Cooo]Z0_l0iol9oolX0003ool00?ooN@3oogT000Woo`001_ooXP02oook
JP_oo`003?oo:00:ool000Wook/000CoobP0oomi0?ooN@3oogT00_oo:008ooo900?oobP000Cooo]Z
ooo90?oob@3oolT00_nT0?l00ooob@3ooj80ool0N002ool0N0Go01Co00?oolT0oomi0?ooN@000ooo
N@04ool0<`WoogT00_l0ogd2ool0TP?ooiX000Cooo]Zoe7o0?mAo`3oDOl00_oo06=JoookJP03o`1j
oooonf[ooo]Z00gooo]Z00?o0?mFoookJ_oo:`004ooonfX00ol0HOoooo]ZoookJP06oookJP03oah0
oooonf[o0?li00Cooo]Z00Goo`3/oonD0?oo03Oooo]ZolL0o`0>oookJP03oo?o0?oonf[ooo]Z00;o
oo]Z00?o0?m1oookJ_oo06D01?oonfX01?oo@P3ooo]ZoookJ_oKo`03oookJP0:ool=0?oonf[oo`26
ool0[?oonf[o03KooookJ_l0om;ooo]Zool0n@[ooo]Z00?o08KooookJ_oonfX00_oonfX01?l0oi?o
oo]ZoookJ_mBo`03oookJP05ool0N_oonf[ooo]ZoookJ_oo04T00ooonfX00ooo6@3ooo]ZoookJP02
oookJP03o`3[oooonf[ooo]Z00;ooo]Z00?on@3ooookJ_oonfX02OoonfX00ooi0?ooN?l0oookJP02
oookJP03oeKo0?oonf[ooo]Z00cooo]Z00?o097ooookJ_l0ob/00_oonfX01?lco`3ooo]ZoookJ_oo
07@4oookJP03ooT0oooonf[ooo]Z00Cooo]Z1?l00002oookJP03onSo0?oonf[ooo]Z00_ooo]Z00?o
o`0Iool03OoonfX01ooonfX00oooXP3ooo]ZoookJP03oookJP03oj@0oooonf[ooo]Z01gooo]Z1?oo
^`04oookJPCo0>Oo1OoonfX6od_o00;ooo]Z3OooXP02oookJPWoo`3K1OoonfX2oonR00[o0?mT0om;
o`04o`3Wo`Wook/01ooonfX5ool0n`Sooo]Z1?nT0?l4ool0N0Go01Co00?o;P3ooeh0oomN0?l00_mN
0?l4ool0<`?o>Ol000Co0?nIool0C_oo04koo`1>1?l0ogd3ool0TP?ooiX000Cooo]Zoe7o0?mAo`3o
DOl00_oo06<ToookJP00>_oonfX00ol0N_oooo]ZoookJP0<oookJPKoobP04?oonfX00ol0HOoo07Wo
oookJP06oookJP03oah0oooonf[o0?li00Cooo]Z2Ooo000;oookJP03oolX0?oonf[oo`0000Ooo`00
0_oonfX01?oo@P3ooo]ZoolX0?oo:002oookJP04ool=0?oonf[ooo]Zool0[0KoobP000?oo`3ioook
J_oonfX01_oonfX6ool00003o`3oTooonf[oo`0000Goo`0000Coo`1joookJ_oonf[oo`190_oonfX5
ool000CoobP00_oonfX00ooi0?oooo]ZoookJP08oookJP03ooT0oomho`3ooo]Z00?ooo]Z00?oo`00
oookJ_oonfX03OoonfX00ol0TOoo0?l[oookJP03ool00004ool0M?oonf[ooo]ZoookJPGoo`001?oo
nfX4o`000003oookJ_oXo`3ooo]Z00Wooo]Z1?oo00000ooo00gooo]ZoookJP07oookJP05oonR0?oo
nf[ooo]ZoookJ_nT0?l07ooonfX2oonk00Gooo]Z0ol0iol2oookJPWoobP04?oo000>o`3oNQ3oobP0
2Ooo0003o`3oI0CoobP02?oo^`0;oolX00Oooo]Z0ooob@001?ooXP3oo`1hool0N?oo07P5o`0Do`Go
ogT01?oo03<01?ooN@3o>Ol0o`3oVOl0oiT3ool0CP?o0?mm00?oAP3oool0T_ooVP000oooVP02oe7o
05_ooo]Z00?o07[ooookJ_oonfX03OoonfX00ol0oeKooo]Zool[000BoookJP03o`1Qool0NOoooo]Z
00Kooo]Z00Co7P3ooookJ_oonf[o0?li0ooonfX01Ooo0>cooo]ZoonD0?oo03Ooa`3o00oooo]Z00?o
lol0oookJ_oonfX00_oonfX00ol0od7ooo]Zool0I@04oookJP03oom20?oonf[ofol000Cooo]Z00Oo
o`d0oookJ_oo08Koo`2/o`0foooonf[o0?oB00;ooo]Z00?oo`3ioookJ_oonfX02?oonfX00ol0Q_oo
oo]ZoookJP02oookJP04o`3oTooonf[ooo]Zoe;o00?ooo]Z00Goo`1joookJ_oonf[ooo]Zool0B@03
oookJP05oolI0?oonf[ooo]ZoookJ_l0jol01?oonfX00ooi0?oooo]ZoookJP09oookJP03ooT0oomh
o`3ooo]Z00;ooo]Z00?oE_l0oookJ_oonfX03OoonfX01Ol0TOoooo]Zo`3o:ooonf[o<ol000;ooo]Z
00?oo`1doookJ_oonfX00_oonfX00ooi0?oooo]ZoookJP04oookJPCo00000_oonfX00ooXo`3ooo]Z
oookJP0:oookJP03ool06Ooo00gooo]Z00Sooo]Z00?ooj80oookJ_oonfX00_oonfX00onT0?oooo]Z
oookJP0LoookJP;ook/01OoonfX3o`3Wo`Cooo]Z1Om;o`08oonR00?ooo]Z7_l0ogX7ool0f`03oook
J_l0ofCo0?mT00[o0?mT1?l0iol7oonk00Gooo]Z1Ooo0?/8oookJPCoY03o1?oo07P5o`0Do`CoGP3o
1?oo03<3ocWo0004o`3oVOoo04koo`1>ool0CP?o0?mm0_m60?l00ooo09;ooiX0oonJ0002oonJ00;o
DOl09?oonfX003_ooo]Z0_oo:00<oookJPSoobP03ooonfX00ol0HOoooo]ZoookJP06oookJP03oah0
oooonf[o0?li00Cooo]Z2_oo0009oookJP03oo?o0?oonf[ooo]Z00Soo`0000Cooo]Zoom20?oonf[o
oo]Z0_oo:002oookJP03ool=0?oonf[oo`2600GoobP000?oo`00oookJ_oo00001ooonfX7ool00003
o`3oTooo003oo`0000Goo`0000?oo`1joookJ_oo04T00ooonfX4ool000GoobP000?ooo]ZooT0oooo
nfX02_oonfX00ooi0?oooo]ZoookJP02oookJP;oo`003_oonfX00ol0TOooo`00oookJP04ool000?o
oo]Z1Ooo0004oookJPCo000000?ooo]ZonSo0?oonfX02?oonfX4ool00003ool03Ooo003ooo]Z00Oo
oo]Z00?ooj80oookJ_oonfX00_oonfX00onT0?oooo]ZoookJP0JoookJP?ook/01?oonfX3o`3Wo`03
oookJ_m;o`3oBol000?oBol02?oo:00Cool000;o0?nG2_oo000@oolX00Go0?mj00?oo`3KoolX0?oo
:0000_oo:0000om;o`3o0?mTo`3oI005o`3oI0GoobP01Ooo^`07oolX0003ool0nooo:03oobP000So
oo]Z0ooob@001?ooXP3oo`1hool0N?oo07P5o`0Do`CoogT01?oo03<2ocWo00;o0?nI0_oo04h3o`3o
O@?oAP3o0_ooVP1LoookJP03o`1joooonf[ooo]Z00gooo]Z00?o0?mFoookJ_oo:`004_oonfX00ol0
HOoo07WooookJP06oookJP04oah0oooonf[ooo]Zo`3o>@?ooo]Z00Goo`3/oookJ_ooU03oo`0golL0
o`0>oookJP03oo?o0?oonf[ooo]Z00?ooo]Z00?o0?m1oookJ_oo06D00ooonfX01?oo@P3ooo]Zoook
J_oKo`04oookJP07ool=0?oonf[oo`26ool0[?l0=_oooo]Zo`3odP02oookJP03ool0nOoonf[ooo]Z
00Sooo]Z00?o08KooookJ_oonfX00_oonfX00ol0oi?ooo]Zoe;o0004oookJP04ool0N_oonf[ooo]Z
ool0B@Cooo]Z00GooaT0oookJ_oonf[ooo]Zo`3[o`04oookJP03ooT0oooonf[ooo]Z00Sooo]Z00?o
n@3oogSo0?oonfX00_oonfX00omFo`3ooo]ZoookJP0=oookJP05o`2Aoooonf[o0?l[oookJ_lco`00
0_oonfX00ooo07Cooo]ZoookJP09oookJPCo00000_oonfX00ooXo`3ooo]ZoookJP0;oookJP03ool0
3Ooonf[ooo]Z00Kooo]Z00?ooj80oookJ_oonfX00ooonfX00onT0?oooo]ZoookJP0IoookJP?ook/0
1?oonfX3o`3Wo`;ooo]Z1Om;o`03oonR00Oooo]Z1_l0ogX3oookJQ_o0?nG3Ol0ogX5ool0f`;oBol0
1ol0of@3o`3Wo`03oookJ_oo^`3ook/000?ook/01OoonfX5ool0n`Sooo]Z1?nT0?l4ool0N0Go01Co
0omN0?l4ool0<`;o>Ol00_l0oiT00ooTo`3oo`1>o`3oO@03o`3oO@?oAP3o0_ooVP0ToookJP00>ooo
nfX3oolX00cooo]Z2Ooo:00>oookJP03o`1Qoooonf[ooo]Z00Kooo]Z00?o7P3ooookJ_l0ocT00ooo
nfX;ool000Wooo]Z00?olol0oookJ_oo00002?oo00000ooonf[ood80oookJP03oolX00;ooo]Z00?o
o`00oookJ_oo:0000_oo:0000ooo003oobP0ool00003ool000Kooo]Z2?oo00000ol0oi?oo`00ool0
0004ool00004ool0N_oonf[ooo]Zool0B@;ooo]Z1Ooo0005oolX0003oookJ_oi0?oooo]Z00Wooo]Z
00?on@3oogSo0?oonfX00_oonfX2ool000kooo]Z00?o097oool00?oonfX01?oo0002oookJPKoo`00
1?oonfX4o`000003oookJ_oXo`3ooo]Z00Oooo]Z1?oo00000ooo00goo`00oookJP07oookJP03oonR
0?oonf[ooo]Z00;ooo]Z00?oY03ooookJ_oonfX06OoonfX2oonk00Gooo]Z00Co0>Ooool00?oo003o
o`000_m;o`02oolX00;ooj8000?ooo]ZoolX0?oo:0001?oo:002oookJQ7oo`001?oonfX8ool000;o
oo]Z3Ooo:003ool000CoobP000?o0?nGo`3oN_l0ogX01ol0ogX3oolX0003od_o0?l0ofCo0?mT00Go
0?mT00?oobP0o`3Wool0iol01Ooo^`03oookJPGoobP00ooo0?/2oookJPGoolT00oooN@04ool0N0Go
01Co0oooN@04ool0<`05ocWo0?l0oiWo0?nIo`3oVOoo04h00ol0ogd2odH0oecooo]Z00?o07[ooook
J_oonfX03_oonfX00ol0oeKooo]Zool[000BoookJP03o`1Qool0NOoooo]Z00Kooo]Z00Co7P3ooook
J_oonf[o0?li0ooonfX01Ooo0>cooo]ZoonD0?oo03Ooa`3o00kooo]Z00?olol0oookJ_oonfX00ooo
nfX00ol0od7oo`1UoookJP03oookJP04oom20?oonf[ooo]Zom_o00Cooo]Z00Coo`d0ool0Q_oonf[o
o`2/0_oonfX00ol0om;ooo]Zool0n@0:oookJP03o`26oooonf[ooo]Z00;ooo]Z00Co0?nCoookJ_oo
nf[oD_l00ooonfX01Ooo07[ooo]ZoookJ_oonf[oo`1900?ooo]Z00GooaT0oookJ_oonf[ooo]Zo`3[
o`04oookJP03ooT0oooonf[ooo]Z00Wooo]Z00?on@3oogSo0?oonfX00_oonfX00omFo`3ooo]Zoook
JP0<oookJP03o`2Aoooonf[o0?l[00;ooo]Z00?o<ol0oookJ_oo07@02ooonfX4o`000003oookJ_oX
o`3ooo]Z00cooo]Z00?oo`0=oookJ_oonfX01ooonfX00oooXP3ooo]ZoookJP02oookJP03oj@0oooo
nf[ooo]Z01Sooo]Z0_oo^`05oookJP;o0>Oo00?ooo]Zod_o0?m;o`000_m;o`03oonR00kooo]Z1ol0
oiLPoookJPSo0?nG2Ol0ogX3ool0f`;oBol01ol0of@2o`3Wo`Kook/01?oonfX6ool0n`Oooo]Z0onT
0?l00oooXP3oo`1hool0N002ool0N0Go01Co0_mN0?l5ool0<`05ocWo0?l0oiWo0?nIog?o0?oo04h0
0ol0ogd2odH0obCooo]Z000loookJP?oobP03?oonfX9oolX00kooo]Z00?o067ooookJ_oonfX01_oo
nfX00olN0?oo0?lioookJP03oookJP_oo`002OoonfX00ooco`3ooo]Zool00005ool000Cooo]Z00?o
od80oolX0?oo:0000_oo:0001Ooonf[oo`00ool00?oo003oobP000?oo`0000?oobP0ool00?oo0000
0_oo0006oookJPooo`0000Goo`1joookJ_oonf[oo`19oookJP06ool000GoobP000?on@3ooookJ_oo
nfX02?oonfX00ooi0?ooN?l0oookJP02oookJP?oo`003OoonfX00ol0TOooo`00ool00004ool000;o
oo]Z1_oo0004oookJPCo000000?ooo]ZonSo0?oonfX01_oonfX5ool00003ool03Ooo003ooo]Z00Ko
oo]Z00?ooj80oookJ_oonfX00_oonfX00onT0?oooo]ZoookJP0HoookJP;ook/00ooonfX6ool000Co
obP01OoonfX4oolX00Cooo]Z3_oo0007oookJP?oo`001ooonfX8oolX00?oo`001_oo:007oookJP03
oomi0?l0oiOoobP000?oobP02Ol0ogX2od_o00;o0?mT1?oo:002o`3Wo`Gook/01Ooo:0000ooonf[o
o`3kool0n`03ool0n`;oolT01oooN@05ool0N0Co01Co00?oogT0oeh0oomN0?l01?oo03<01?lio`3o
0?nIo`3oVOl0oiT2o`3oOEgooo]Z00?o07[ooookJ_oonfX03_oonfX00ol0oeKooo]Zool[000Boook
JP03o`1Qool0NOoooo]Z00Kooo]Z00?o7P3ooookJ_l0ocT01?oonfX01Ooo0>cooi@0oookJ_oo03Oo
a`3o00kooo]Z00?olol0oookJ_oonfX00ooonfX00ol0od7oo`1UoookJP03oookJP03oom20?oonf[o
fol000Cooo]Z00Goo`d0oookJ_oo08Koo`2/o`0fo`02oookJP03o`3od_oonf[oo`3i00[ooo]Z00?o
08KooookJ_oonfX00_oonfX00ol0oi?ooo]Zoe;o0004oookJP05ool0N_oonf[ooo]ZoookJ_oo04T0
0ooonfX01Ooo6@3ooo]ZoookJ_oonf[o0>_o00?ooo]Z00?on@3ooookJ_oonfX02OoonfX00ooi0?oo
N?l0oookJP02oookJP03oeKo0?oonf[ooo]Z00cooo]Z00?o097ooookJ_l0ob/00_oonfX00olco`3o
oo]Zool0M00;oookJPCo000000?ooo]ZonSo0?oonfX03?oonfX00ooo00gooo]ZoookJP06oookJP03
oonR0?oonf[ooo]Z00;ooo]Z00?oY03ooookJ_oonfX05ooonfX2oonk00Cooo]Z0ol0iol3od_o0003
oookJ_ooXP3ooj8004Kooo]Z1?l0oiL9o`3oNP03ool0fom;o`3oBol000Ko0?mT0_l0iol5oonk00Go
oo]Z1_oo0?/6oookJP?oY03o1?oo07P00oooj@3o01Coo`0Do`02o`0Do`;oGP3o00?oo`31ool0<ooo
03<00_oo03<01?lio`3o0?nIo`3oVOl0oiT2o`3oOBCooo]Z000loookJPGoobP02_oonfX:oolX00go
oo]Z00?o067oo`1ioooonfX01ooonfX00olN0?oo0?lioookJP02oookJPWoo`002ooonfX00ooco`3o
oo]Zool00004ool00003ool0IOoonf[ooo]Z00;ooo]Z00?ood80oookJ_oo:0000ooo:0001?oonf[o
o`00ool00?oo08H4ool00003oolX0?oo003oo`0000;oo`001OoonfX6ool000;ooo]Z00?oobP0ool0
0?oo00001?oo00001?oo07[oo`00oookJ_oo04T2oookJPKoo`001_oo:00:oookJP04oolX0?mho`3o
oo]ZoookJP?oo`003OoonfX00ol0TOooo`00ool00005ool00003oookJ_oo003oo`0000Coo`001?oo
nfX4o`000003onSo0?oonf[ooo]Z00Gooo]Z1Ooo00000ooo00goo`00ool00007oookJP05oonR0?oo
nf[ooo]ZoookJ_nT0?l06_oonfX00ooo^`3oo`00ool00008ool000CoobP01_oonfX00ooo:03ooo]Z
oookJP05oookJP_oo`005?oonfX?oolX00_ooo]Z3Ooo:007o`3oNP03od_o0?oo:03oobP000GoobP0
1_oo^`000ooo:03ooo]Zooo90002ooo900Koo`3k1ooob@000onT0?ooo`1hool0N002ool0N0Co01Co
0omN0?l4ool0<`;o0?nIG_oonfX00ol0N_oooo]ZoookJP0>oookJP03o`3oE_oonf[oob/001;ooo]Z
00?o067oo`1ioooonfX01_oonfX00olN0?oooo]Zo`3o>@04oookJP05ool0k?ooU03ooo]Zool0=oo7
0?l03OoonfX00ooco`3ooo]ZoookJP03oookJP03o`3o@Ooonf[oo`1U00?ooo]Z00Cood80oookJ_oo
nf[ofol01?oonfX01Ooo3@3ooo]Zool0Q_oo0:co03Ko00;ooo]Z00?o0?oBool0nOoonfX02_oonfX0
0ol0Q_oooo]ZoookJP02oookJP03o`3oTooonf[oD_l000?ooo]Z00Goo`1joookJ_oonf[ooo]Zool0
B@03oookJP05oolI0?oonf[ooo]ZoookJ_l0jol01?oonfX00ooi0?oooo]ZoookJP09oookJP05ooT0
oooonf[ooo]ZoookJ_mFo`003_oonfX00ol0TOoooo]Zo`3o:`02oookJP03oc?o0?oonf[oo`1d00_o
oo]Z1?l000000ooonf[oj?l0oookJP0;oookJP03ool03Ooonf[ooo]Z00Kooo]Z00?ooj80oookJ_oo
nfX00_oonfX00onT0?oooo]ZoookJP0GoookJP03oonk0?oonf[ooo]Z00;ooo]Z0_l0iol01?oonf[o
Bol0od_o0?oonfX3oonR057ooo]Z1?l0oiL7o`3oNP03ool0fom;o`3o0?mT00Co0?mT00?oBol0o`3W
oooo^`001Ooo^`05oookJPKoo`3k1OoonfX2oj@0o`Goo`1h1?l05?l3oeh0o`Coo`0c0_l0oiTToook
JP00?OoonfX5oolX00[ooo]Z1ooo:00@oookJP03o`1Qool0NOoooo]Z00Oooo]Z00Co7P3oo`3o>Ooo
nf[ooo]Z2?oo0002oolX00_ooo]Z00Colol0ool00?oo003oo`000_oonfX00ooo003oo`1UoookJP03
oookJP03oom20?oo:03oobP000?oobP01ooo00000ol0om;oo`00ool00003ool000Cooo]Z1Ooo0003
oookJP03oolX0?oo003oo`0000Coo`0000Kooo]Zool0N_oonf[ooo]Zool0BOoonfX7ool000;oobP0
0_oonfX00ooo:03ooo]ZoookJP08oookJP04oolX0?mho`3ooo]ZoookJPCoo`003?oonfX00ol0TOoo
o`00ool00005ool00003oookJ_oo003oo`0000Goo`000ooonfX4o`000003onSo0?oonf[ooo]Z00Co
oo]Z1_oo00000ooo00goo`00ool00006oookJP05oonR0?oonf[ooo]ZoookJ_nT0?l06OoonfX2oonk
00[oo`000ooo:00@oookJPWoo`003_oonfXMoooc00Go0?l83?oo:005oookJP?o0?nG1ol0ogX7oolX
00Kook/01?oob@000ooonf[oo`3kool0n`03ool0n`Cooo]Z0onT0?l4ool0N0?o01Co1?mN0?l2ool0
<eoooo]Z00?o07[ooookJ_oonfX03_oonfX00ol0oeKooo]Zool[000BoookJP03o`1Qool0NOoooo]Z
00Kooo]Z00?o7P3ooookJ_l0ocT00ooonfX01Ooo0>cooo]ZoonD0?oo03Ooa`3o00kooo]Z00?olol0
oookJ_oonfX00ooonfX00ol0od7oo`1UoookJP03oookJP04oom20?oonf[ooo]Zom_o00?ooo]Z00Go
o`d0oookJ_oo08Koo`2/o`0fo`02oookJP03o`3od_oonf[oo`3i00[ooo]Z00?o08KooookJ_oonfX0
0_oonfX01?l0oi?ooo]ZoookJ_mBo`03oookJP05ool0N_oonf[ooo]ZoookJ_oo04T00ooonfX01Ooo
6@3ooo]ZoookJ_oonf[o0>_o00?ooo]Z00?on@3ooookJ_oonfX02OoonfX00ooi0?ooN?l0oookJP02
oookJP03oeKo0?oonf[ooo]Z00_ooo]Z00?o097ooookJ_l0ob/00_oonfX00olco`3ooo]Zool0M00;
oookJPCo000000?ooo]ZonSo0?oonfX02ooonfX00ooo00gooo]ZoookJP06oookJP05oonR0?oonf[o
oo]ZoookJ_nT0?l06?oonfX2oonk00?ooo]Z0_l0iol3od_o0003oookJ_ooXP3ooj8002Wooo]Z7_oo
l`06o`3o213ooo]Z0_l0oiL7o`3oNPKo0?mT0_m;o`06oonk00Gooo]Z1Ooo0?/4oookJP;oY03o00?o
oj80ool0N?oo07P00_oo07P3o`0Do`CoGP3o0_oo03<ToookJP00?OoonfX6oolX00Wooo]Z1_oo:00B
oookJP03o`1Qool0NOoooo]Z00Oooo]Z00Co7P3oo`3o>Ooonf[ooo]Z1ooo0003oolX00_ooo]Z00?o
lol0ool00?oonfX00_oonfX00ooo003ooo]Zool0I@04oookJP03oom20?oo:03oobP000;oobP02?oo
00000ol0om;oo`00ool00003ool000Cooo]Z0_oo00000ooonf[oo`00oookJP02oookJP;oobP00ooo
0004oookJP04ool0N_oonf[oo`19oookJPSoo`000ooonfX2oolX00Wooo]Z0_oo:002oookJPGoo`00
2ooonfX00ol0TOooo`00ool0000=ool000?ooo]Z1?l000000ooXo`3ooo]ZoookJP06oookJPCoo`00
00?oo`0=ool00?oo00001OoonfX01OooXP3ooo]ZoookJ_oonf[oY03o01Sooo]Z0_oo^`0;ool000?o
obP04OoonfX7ool000WoobP01oool`07oookJQ;o0?l<1?oonfX9oooc00[o0?l82_oonfX00ol0oiOo
obP0oolX0006o`3oNPOoobP01ooo^`03oookJPGoo`3k1?oonfX2oj@0o`?oo`1h1?l05?l2oeh0of3o
oo]Z00?o07[ooookJ_oonfX03_oonfX00ol0oeKooo]Zool[000AoookJP03o`1Qoooonf[o07Wo00Oo
oo]Z00?o7P3ooookJ_l0ocT00ooonfX01Ooo0>cooo]ZoonD0?oo03Ooa`3o00kooo]Z00?olol0oook
J_oonfX00ooonfX00ol0od7oo`1UoookJP03oookJP03oom20?oonf[ofol000Cooo]Z00Goo`d0oook
J_oo08Koo`2/o`0fo`02oookJP03o`3od_oonf[oo`3i00[ooo]Z00?o08KooookJ_oonfX00_oonfX0
0ol0oi?ooo]Zoe;o0004oookJP04ool0N_oonf[ooo]Zool0B@?ooo]Z00GooaT0oookJ_oonf[ooo]Z
o`3[o`04oookJP03ooT0oooonf[ooo]Z00Sooo]Z00?on@3oogSo0?oonfX00_oonfX00omFo`3ooo]Z
oookJP0;oookJP03o`2Aoooonf[o0?l[00;ooo]Z00?o<ol0oookJ_oo07@02ooonfX4o`000003onSo
0?oonf[ooo]Z00_ooo]Z00?oo`0=oookJ_oonfX01OoonfX01OooXP3ooo]ZoookJ_oonf[oY03o01Oo
oo]Z0_oo^`04oookJP03o`3Woooonf[oBol000;ooo]Z0_ooXP0QoookJP[ooo<000?o0?l8oookJ_oo
nfX01?oonfXBo`3o30Gooo]Z2Oool`0:o`3o20[ooo]Z0_l0oiL6o`3oNPGo0?mT0om;o`06oonk00Co
oo]Z1Ooo0?/4oookJP03oj@0ooooXP3oo`1h00;oo`1h1?l05?l2oeh0obCooo]Z000noookJPOoobP0
2?oonfX7oolX017ooo]Z00?o067oo`1ioooonfX01ooonfX00olN0?oo0?lioookJP08ool000gooo]Z
00?olol0oookJ_oonfX00ooonfX00ooo003oo`1UoookJP03oookJP03oom20?oo:03oobP000?oobP0
1ooo00000ol0om;oo`00ool00004ool000?ooo]Z00Goo`00oookJ_oonf[ooo]Zool00003oookJP;o
obP000?oo`00oookJ_oo00000ooonfX01?oo07[ooo]ZoookJ_oo04T6ool00003oookJ_l0jooooo]Z
00;ooo]Z0ooo:008oookJP;oobP000?oN?l0oookJ_oo00001?oo000;oookJP03ool00?l0TOooo`00
00goo`000ooonfX4o`000003onSo0?oonf[ooo]Z00Sooo]Z00Coo`00ool03Ooo003oo`001_oonfX0
1OooXP3ooo]ZoookJ_oonf[oY03o01Oooo]Z00Cook/0oookJ_oonf[ooo]Z2Ooo0002oolX01?ooo]Z
1ooo000@oolX00Oo0?l<0_oonfX8oolX00Sooo]Z3Ol0o``;oooc00Ko0?l80ooonfX9oolX00Ko0?mj
0_oo:003o`3oI0?oBol01_oo^`02oookJPCoo`3k0_ooN@02oookJP03oj@0ooooXP3oo`1h00;oo`1h
0_l05?mQoookJP03o`1joooonf[ooo]Z00kooo]Z00?o0?mFoookJ_oo:`004OoonfX00ol0HOoooo]Z
o`1io`07oookJP03oah0oooonf[o0?li00?ooo]Z00Goo`3/oookJ_ooU03oo`0golL0o`0=oookJP03
oo?o0?oonf[ooo]Z00Cooo]Z00?o0?m1ool0IOoonfX00_oonfX01?oo@P3ooo]ZoookJ_oKo`04oook
JP09ool=0?oonf[oo`26ool0[?l0=_oooo]Zo`3od_oonf[oo`3i00_ooo]Z00Go08KooookJ_oonf[o
oo]Zo`3oT`02oookJP05oe;o0?oonf[ooo]ZoookJ_oo07X00ooonfX01Ooo04Wooo]ZoookJ_oonf[o
oaT000?ooo]Z00Go0>_ooookJ_oonf[ooo]ZooT0o`0;oookJP05ooT0oooonf[ooo]ZoookJ_mFo`00
3_oonfX00ol0TOoooo]Zo`3o:`03oookJP03ool0M?oonf[ooo]Z00Wooo]Z1?l000000ooXo`3ooo]Z
oookJP0:oookJP03ool03Ooonf[ooo]Z00Kooo]Z00Gooj80oookJ_oonf[ooo]Zoj@0o`0FoookJP03
oonk0?oonf[ooo]Z00;ooo]Z0_l0iol3oookJP;ooj807?oonfX2o`3o20Gooo<01_oonfX;o`3o31;o
oo]Z3_l0o``:oooc00Oo0?l82_oonfX00ol0oiOo0?mjo`3oNP04o`3oNPGo0?mT0om;o`06oonk00?o
oo]Z1?oo0?/4oookJP03oj@0ooooXP3oo`1h00;oo`1h0_l05?lToookJP00?_oonfX8oolX00Oooo]Z
0ooo:0000ooonf[oobP0oolX0002oolX017ooo]Z00?o067oo`1ioooonfX01ooonfX2ool00003oook
J_oo003oo`0000Koo`003OoonfX00ooco`3ooo]ZoookJP03oookJP03ool00?oo06Gooo]Z00?ooo]Z
00?ood80oolX0?oo:0000_oo:008ool00003o`3od_oo003oo`0000Coo`002_oonfX3oolX00Kooo]Z
00Coo`1joookJ_oo04Wooo]Z0ooo0003oookJP04o`3[oooonf[ooo]ZoookJP?oobP02?oonfX3oolX
0003oookJ_oo003oo`0000Coo`002_oonfX00ooo003o097oool00006ool000[ooo]Z1?l000000ooX
o`3ooo]ZoookJP09oookJP03ool03Ooo003oo`0000Gooo]Z00Gooj80oookJ_oonf[ooo]Zoj@0o`0G
oookJP05oonk0?oonf[ooo]ZoookJ_l0iol01ooo0003oolX01Gooo]Z0ooo0003oooc00koobP02ooo
nfX3oolX01[ooo]Z2ol0o``9oooc00SoobP01_oonfX00ol0oiOo0?mjo`3oNP04o`3oNPCo0?mT0om;
o`000ol0iooook/0oonk0003oonk0003oookJ_oo0?_oo`3k00;oo`3k00?oogT0oookJ_oonfX00_oo
nfX2ool0N6;ooo]Z00?o07[ooookJ_oonfX03OoonfX00ol0oeKooo]Zool[000BoookJP03o`1Qoooo
nf[o07Wo00Oooo]Z00?o7P3ooookJ_l0ocT00ooonfX01Ooo0>cooi@0oookJ_oo03Ooa`3o00gooo]Z
00?olol0oookJ_oonfX01?oonfX00ol0od7oo`1UoookJP02oookJP04oom20?oonf[ooo]Zom_o00?o
oo]Z00Goo`d0oookJ_oo08Koo`2/o`0fo`02oookJP03o`3od_oonf[oo`3i00oooo]Z00?o0?nCoook
J_oonfX01?oonfX01?oo07[ooo]ZoookJ_oo04T7oookJP05o`3[oooonf[ooo]ZoookJ_oi0?l02ooo
nfX01Ooi0?oooo]ZoookJ_oonf[oE_l000kooo]Z00?o097ooookJ_l0ob/00ooonfX00ooo07Cooo]Z
oookJP09oookJPCo000000?oj?l0oookJ_oonfX02_oonfX00ooo00gooo]ZoookJP05oookJP05oonR
0?oonf[ooo]ZoookJ_nT0?l05_oonfX01?oo^`3ooo]ZoookJ_oonfX2o`3Wo`?ooo]Z0_ooXP0Koook
JP03o`3o2?ool`3ooo<000;ooo<01?oonfX7o`3o32_ooo]Z2_l0o``;oooc00?o0?l82_oonfX7o`3o
NP?o0?mT0om;o`000ol0iooook/0oonk0004oonk0003oookJ_oo0?_oo`3k00;oo`3k1OoonfX2ool0
N2Cooo]Z000ooookJPSoobP01ooonfX01?oo:03ooo]ZoookJ_oonfX5oolX00oooo]Z00?o067ooook
J_l0NOl01ooonfX<ool000gooo]Z00?olol0oookJ_oonfX00ooonfX00ooo003oo`1UoookJP02oook
JP03oolX0?oo@P3oobP000;oobP02Ooo00000ol0om;oo`00ool00004ool000Wooo]Z1?oo:005oook
JP03ool0N_oonf[ooo]Z00;oo`001_oonfX00ol0jooooo]ZoookJP04oolX00Oooo]Z1?oo:006ool0
00[ooo]Z00?oo`00o`2Aoooo00001_oo000:oookJPCo000000?oj?l0oookJ_oonfX02OoonfX00ooo
00gooo]Zool00005oookJP05oonR0?oonf[ooo]ZoookJ_nT0?l05_oonfX00ooo^`3ooo]ZoookJP02
o`3Wo`;ooo]Z1Ooo0003oolX01Kooo]Z0oool`03ool000_oobP02?oonfXOo`2lo`oooo]Z2Ol0o``2
oookJPCooo<01?ooN@000ol0o`Sooo]ZoookJP03oookJPGoogT01_l0ogX3o`3oI0?oBol000?o0>Oo
oonk0?oo^`000ooo^`05ool0nfGooo]Z00?o07[ooookJ_oonfX03OoonfX00ol0oeKooo]Zool[000B
oookJP03o`1Qoooonf[o07Wo00Kooo]Z00Co7P3ooookJ_oonf[o0?li0ooonfX01?oo0>cooi@0oook
J_o70?l>oookJP03oo?o0?oonf[ooo]Z00Cooo]Z00?o0?m1oookJ_oonfX00_oonfX00ooo@P3ooo]Z
om_o0004oookJP09ool=0?oonf[oo`26ool0[?l0=_oooo]Zo`3od_oonf[oo`3i00oooo]Z00?o0?nC
oookJ_oonfX01?oonfX01Ooo07[ooo]ZoookJ_oonf[oo`1900Kooo]Z00?o0>_ooookJ_oonfX00_oo
nfX00ooi0?oooo]ZoookJP08oookJP03ooT0oomho`3ooo]Z00;ooo]Z00?oE_l0oookJ_oonfX02ooo
nfX00ol0TOoooo]Zo`3o:`03oookJP03ool0M?oonf[ooo]Z00Wooo]Z1?l000000ooXo`3ooo]Zoook
JP0:oookJP03ool03Ooonf[ooo]Z00Cooo]Z00?ooj80oookJ_oonfX00_oonfX00onT0?oooo]Zoook
JP0CoookJP05oonk0?oonf[ooo]ZoookJ_l0iol01?oonfX00oooXP3ooo]ZoookJP0IoookJP?ooo<0
0ooonfX5o`3o30kooo]Z8?l0_?l>oookJPWo0?l<0_oonfX8oooc0003o`3o2?oonf[ooo]Z00Oooo]Z
0_l0oiL6o`3oNP;o0?mT0om;o`02o`3Wo`Gook/01Ooo0?/VoookJP00?ooonfX9oolX00_ooo]Z1Ooo
:00?oookJP04o`1Qoooonf[oo`00ool000Kooo]Z2Ooo00000ooonf[oo`00oookJP0=oookJP03oo?o
0?oonf[ooo]Z00?ooo]Z00?oo`1UoookJ_oonfX00_oonfX00ooo@P3oobP0oolX0002oolX00Soo`00
00?o0?oBool00?oo00001Ooo0008oookJPGoobP01?oonfX01?oo07[ooo]ZoookJ_oo0007oookJP03
o`3[oooonf[ooo]Z00GoobP01_oonfX4oolX00Ooo`002OoonfX00ooo003o097oool00007ool000Wo
oo]Z1?l000000ooXo`3ooo]ZoookJP08oookJP03ool03Ooonf[ooo]Z00Gooo]Z00Gooj80oookJ_oo
nf[ooo]Zoj@0o`0FoookJP04oonk0?oonf[oobP0oolX00?ooo]Z00?ooj80ool00?oo00000_oo0002
oolX01Gooo]Z0oool`03ool000?o0?l<00?oo`00oolX0?oo:0001_oo:003oookJPOo0;co6?oonfX7
ool000oo0;co2OoonfX8o`3o30;ooo]Z3oooN@02o`3oU`Ko0?mj0_l0of@3od_o0003o`3Woooo^`3o
ok/000?ook/00_oo0?]ToookJP03o`1joooonf[ooo]Z00gooo]Z00?o0?mFoookJ_oo:`004_oonfX0
0ol0HOoooo]Zo`1io`06oookJP04oah0oooonf[ooo]Zo`3o>@;ooo]Z00Goo`3/oookJ_ooU03ooo]Z
olL0o`0>oookJP03oo?o0?oonf[ooo]Z00Cooo]Z00Goo`1UoookJ_oonf[ooo]Zoom20002oookJP09
om_o0?oonf[ooo]ZoookJ_oo3@3ooo]Zool0Q_oo0:co03Ko00;ooo]Z00?o0?oBoookJ_oo0?T03_oo
nfX00ol0oi?ooo]ZoookJP05oookJP04ool0N_oonf[ooo]Zool0B@Oooo]Z00Go0>_ooookJ_oonf[o
oo]ZooT0o`0:oookJP03ooT0oomho`3ooo]Z00;ooo]Z00?oE_l0oookJ_oonfX02ooonfX00ol0TOoo
oo]Zo`3o:`03oookJP03ool0M?oonf[ooo]Z00Wooo]Z1?l000000ooXo`3ooo]ZoookJP09oookJP03
ool03Ooonf[ooo]Z00Gooo]Z00Gooj80oookJ_oonf[ooo]Zoj@0o`0EoookJP03oonk0?oonf[ooo]Z
00;o0>Oo0ooonfX2oonR01Wooo]Z0oool`03oookJP?o0?l<3?oonfX7o`2lob3ooo]Z3_l0_?l9oook
JPSo0?l<0_oonfX6oooc0003o`3o2?oonf[ooo]Z00Kooo]Z0ol0oiL6o`3oNP04o`3oI?m;o`3oBol0
od_o00;o0>Oo1Ooo^`02ool0nbCooo]Z0010oookJPOoobP03OoonfX6oolX00kooo]Z00Co067oool0
0?oo003oo`001OoonfX8ool00004oookJ_oo:03ooo]Zool000gooo]Z00?olol0oookJ_oonfX01?oo
nfX01_oo06Gooo]ZoookJ_oonf[oobP0oom200?oobP02Ooo00000ol0om;oo`00ool00005ool000So
oo]Z1?oo:005oookJP04ool0N_oonf[oo`00ool000Kooo]Z00?o0>_ooookJ_oonfX01_oo:005oook
JPGoobP01_oo0009oookJP03ool00?l0TOooo`0000Ooo`002OoonfX3o`000003onSo0?oonf[ooo]Z
00Wooo]Z00?oo`0=oookJ_oonfX01OoonfX01OooXP3ooo]ZoookJ_oonf[oY03o01Gooo]Z00?ook/0
oookJ_oo:0000_oo:0001?oonf[oo`00ool00?oonfX3ool00003oookJ_oo:03ooo]Z01;ooo]Z0ooo
l`03oookJP?o0?l<00Coo`00oookJ_oonf[ooo]Z1Ooo:006o`2loaoooo]Z2_oo000<oookJP_o0;co
1_oonfX7o`3o30googT000?ooo]Zo`3oUol0oiL00_l0oiL5o`3oNP;o0?mT0om;o`000ol0iooook/0
oonk001UoookJP03o`1joooonf[ooo]Z00gooo]Z00?o0?mFoookJ_oo:`004OoonfX00ol0HOoooo]Z
o`1io`07oookJP04oah0oooonf[ooo]Zo`3o>@;ooo]Z00Goo`3/oookJ_ooU03ooo]ZolL0o`0=oook
JP03oo?o0?oonf[ooo]Z00Gooo]Z00Ooo`1UoookJ_oonf[ooo]Zoom20?oonf[ofol000Cooo]Z00Oo
o`d0oookJ_oo08Koo`2/o`0foooonf[o0?oB00;ooo]Z00?oo`3ioookJ_oonfX03?oonfX00ol0oi?o
oo]ZoookJP04oookJP05ool0N_oonf[ooo]ZoookJ_oo04T01_oonfX00ol0jooooo]ZoookJP02oook
JP03ooT0oooonf[ooo]Z00Sooo]Z00?on@3ooookJ_oonfX03ooonfX00ol0TOoooo]Zo`3o:`03oook
JP03ool0M?oonf[ooo]Z00Wooo]Z1?l000000ooXo`3ooo]ZoookJP09oookJP03ool03Ooonf[ooo]Z
00Cooo]Z00Gooj80oookJ_oonf[ooo]Zoj@0o`0EoookJP04oonk0?oonf[ooo]Zo`3Wo`?ooo]Z0_oo
XP0HoookJP?ooo<00ooonfX3o`3o30Wooo]Z1_l0_?leoookJP_o0;co1_oonfX7o`3o3003oookJ_oo
l`3ooo<000Cooo<00_l0o`P6oookJP?o0?nG00?oo`3Ko`3oN_l0ogX00ol0ogX00ol0ofCoBol0od_o
0002od_o0003o`3Woooo^`3ook/002Cooo]Z0010oookJPKoobP03_oonfX7oolX00kooo]Z00Co067o
ool00?oo003oo`001?oonfX6ool00004oookJ_oo003ooo]ZoolX00;ooo]Z00?oo`00oookJ_oonfX0
2ooonfX00ooco`3ooo]ZoookJP04oookJP03ool0IOoonf[ooo]Z00;oobP000?ood80oolX0?oo:000
2Ooo00000ol0om;oo`00ool00006ool000Oooo]Z1Ooo:004oookJP03ool0N_oonf[oo`0000;oo`00
1_oonfX00ol0jooooo]ZoookJP05oolX00Gooo]Z1Ooo:007ool000Sooo]Z00?oo`00oolX0?oo0000
0ooo00000ooonf[oo`1doookJP0:oookJP?o000000?oj?l0oookJ_oonfX02OoonfX00ooo00gooo]Z
oookJP04oookJP03oonR0?oonf[ooo]Z00;ooo]Z00?oY03ooookJ_oonfX04_oonfX00ooo^`3oobP0
oolX0002oolX0004oookJ_oo003oo`00ool000;ooo]Z00?oo`00oookJ_oonfX04OoonfX3oooc00?o
oo]Z0ol0o``00ooonf[oo`00oookJP04oookJP;oobP00ol0_?lUoookJPkoo`004ooonfX9o`2lo`Co
oo]Z1ol0o``8oomi00Cooo]Z1?l0oiL5o`3oNP?o0?mTI_oonfX00ol0N_oooo]ZoookJP0=oookJP03
o`3oE_oonf[oob/0017ooo]Z00?o067ooookJ_l0NOl01ooonfX00olN0?oooo]Zo`3o>@03oookJP05
ool0k?ooU03ooo]ZoookJ_o70?l03OoonfX00ooco`3ooo]ZoookJP04oookJP03ool0IOoonf[ooo]Z
00;ooo]Z00?ood80oookJ_oKo`000ooonfX02_oo3@3ooo]ZoookJ_oo08Koo`2/o`0foooonf[o0?oB
oookJ_oo0?T>oookJP03o`3oTooonf[ooo]Z00Cooo]Z00Goo`1joookJ_oonf[ooo]Zool0B@06oook
JP03o`3[oooonf[ooo]Z00;ooo]Z00?on@3ooookJ_oonfX02?oonfX00ooi0?oooo]ZoookJP0?oook
JP03o`2Aoooonf[ooo]Z00?ooo]Z00?oo`1doookJ_oonfX02OoonfX4o`000003onSo0?oonf[ooo]Z
00Wooo]Z00?oo`0=oookJ_oonfX01?oonfX01OooXP3ooo]ZoookJ_oonf[oY03o01Cooo]Z00Cook/0
oookJ_oonf[o0>Oo0ooonfX00oooXP3ooo]ZoookJP0EoookJP?ooo<00ooonfX3o`3o30Wooo]Z0ol0
_?m6oookJPWo0;co1?oonfX7o`3o30Kooo<00_l0o`P5oookJP?o0?nG00?oo`3Ko`3oN_l0ogX00ol0
ogX3o`3oI2Cooo]Z0011oookJPGoobP03ooonfX7oolX00gooo]Z00?o067oool00?oo00000_oo0004
oookJPKoo`0000Cooo]Zool00?oonf[oobP00_oonfX00ooo003ooo]ZoookJP0;oookJP03oo?o0?oo
nf[ooo]Z00?ooo]Z00Koo`1UoookJ_oonf[ooo]ZoolX0?oo@P02oookJP03oolX0?oo003oo`0000Oo
o`0000?o0?oBool00?oo00000ooo0009oookJPKoobP00ooonfX00ooo07[ooo]Zool00002ool000Ko
oo]Z00?o0>_ooookJ_oonfX01_oo:004oookJPKoobP00ooo000:oookJP;oo`0000?oobP0ool00?oo
00000_oo00000ooonf[oo`1doookJP0:oookJP?o000000?oj?l0oookJ_oonfX02?oonfX00ooo00go
oo]ZoookJP05oookJP05oonR0?oonf[ooo]ZoookJ_nT0?l05?oonfX00ooo^`3oobP0oolX0002oolX
00Coo`005?oonfX3oooc00;ooo]Z0ooo00000ol0o`cooo]ZoookJP07oookJP?o0;co9?oonfXDool0
00Goo`3K5OoonfX8o`2lo`?oogT01ol0o``2oomi00?ooo<00_l0o`P5oomi00;o0?nG00?o0?mjoomi
0?ooN@00IooonfX00ol0N_oooo]ZoookJP0=oookJP03o`3oE_oo:`3ooo]Z017ooo]Z00?o067ooook
J_l0NOl01_oonfX01?lN0?oooo]ZoookJ_l0ocT3oookJP05ool0k?ooU03ooo]ZoookJ_o70?l03Ooo
nfX00ooco`3ooo]ZoookJP04oookJP05ool0IOoonf[ooo]ZoookJ_oo@P000_oonfX02?oKo`3ooo]Z
oookJ_oonf[oo`d0oookJ_oo08Koo`2/0ooonfX00ol0om;ooo]Zool0n@0>oookJP03o`3oTooonf[o
oo]Z00Cooo]Z00Coo`1joookJ_oonf[oo`191ooonfX01Ol0jooooo]ZoookJ_oonf[on@3o00[ooo]Z
00?on@3oogSo0?oonfX03ooonfX00ol0TOoooo]ZoookJP03oookJP03ool0M?oonf[ooo]Z00Wooo]Z
0ol000000ooXo`3ooo]ZoookJP09oookJP03ool03Ooonf[ooo]Z00Cooo]Z00Gooj80oookJ_oonf[o
oo]Zoj@0o`0DoookJP04oonk0?oonf[ooo]Zo`3Wo`?ooo]Z00?ooj80oookJ_oonfX05?oonfX2oooc
00?ooo]Z0ol0o``9oookJP?o0;co9?oonfXIool0faGooo]Z2Ol0_?l2oookJPOo0?l<1Oool`03o`3o
20Gooo]Z0_l0oiL3o`3oNRCooo]Z0011oookJP?oobP00_oonfX00ooo:03ooo]ZoookJP0<oookJPWo
obP03?oonfX00ol0HOooo`00ool00002ool000?ooo]Z1ooo00001?oonf[oo`00oookJ_oo:00?oook
JP03oo?o0?oonf[ooo]Z00Cooo]Z00Soo`1UoookJ_oonf[oobP0oookJ_oo@P3ooo]ZoolX00[oo`00
00?o0?oBool00?oo00003?oonfX6oolX00?ooo]Z00?oo`1joookJ_oo00000_oo0006oookJP03o`3[
oooonf[oobP000KoobP00ooonfX6oolX00gooo]Z0_oo0002oolX00?oo`0000?ooo]ZoolX0?oonfX0
2_oonfX3o`000003onSo0?oonf[ooo]Z00Sooo]Z00?oo`0=oookJ_oonfX01?oonfX00oooXP3ooo]Z
oookJP02oookJP03oj@0oooonf[ooo]Z017ooo]Z00?ook/0oolX0?oo:0000ooo:003ool001?ooo]Z
0_ool`06ool000Wooo]Z0ol0_?l[oookJPgoo`002?oonfX;ool0f`kooo]Z1?ooN@08o`2lo`;ooo]Z
1_l0o``4oooc00Co0?l800?ooo]Zoomi0?ooN@00IooonfX00ol0N_oooo]ZoookJP0>oookJP03o`3o
E_oo:`3ooo]Z017ooo]Z00?o067oo`1ioooonfX01_oonfX01?lN0?oooo]ZoookJ_l0ocT3oookJP03
ool0k?ooU03ooo]Z00kooo]Z00?olol0oookJ_oonfX01OoonfX01ooo06Gooo]ZoookJ_oonf[ood80
oookJ_oKo`000ooonfX01Ooo3@3ooo]ZoookJ_oo08Koo`2/00;ooo]Z00?o0?oBoookJ_oo0?T03_oo
nfX00ol0oi?ooo]ZoookJP04oookJP05ool0N_oonf[ooo]ZoookJ_oo04T01_oonfX00ol0jooooo]Z
oookJP02oookJP03ooT0oooonf[ooo]Z00Oooo]Z00?on@3oogSo0?oonfX03ooonfX00ol0TOoooo]Z
oookJP03oookJP03ool0M?oonf[ooo]Z00Wooo]Z0ol000000ooXo`3ooo]ZoookJP09oookJP03ool0
3Ooonf[ooo]Z00?ooo]Z00?ooj80oookJ_oonfX00_oonfX00onT0?oooo]ZoookJP0AoookJP04oonk
0?oonf[ooo]Zo`3Wo`?ooo]Z00?ooj80oookJ_oonfX04ooonfX2oooc00?ooo]Z0_l0o``9oookJP?o
0;co@?oonfX;ool0fa?ooo]Z2?l0_?l00ooonf[o0?l<o`3o3004o`3o30Cooo<01Ol0o`PWoookJP00
@_oonfX00ooo:03ooo]ZoookJP02oookJP03oolX0?oonf[ooo]Z00cooo]Z2Ooo:00<oookJP03o`1Q
oooo003oo`0000?oo`0000?ooo]Zool00?oo00001_oo00001?oonf[oo`00oookJ_oo:00?oookJP03
oo?o0?oonf[ooo]Z00Cooo]Z00?oobP0oookJ_oonfX00_oonfX00ooo@P3ooo]Zool00007ool00006
oookJ_oo003o0?oBool00?oonf[oo`002ooonfX7oolX00;ooo]Z00?oo`1joookJ_oo00000ooo0005
oookJP03o`3[oooonf[oobP000KoobP00ooonfX7oolX00cooo]Z00Coo`00oolX0?oo:03oobP01?oo
00000ooo:03ooo]ZoookJP09oookJP?o000000?oj?l0oookJ_oonfX02?oonfX00ooo00gooo]Zoook
JP04oookJP05oonR0?oonf[ooo]ZoookJ_nT0?l04_oonfX00ooo:03ook/0oolX0004oolX00Coo`00
4?oonfX:ool000Oooo]Z0ol0_?lToookJROo01Go0ooonfX4ool0f`OoobP00ooonfX;oolX0004oook
J_l0_?oo0;coo`2lo`GoogT01ol0o``2oooc00;oogT0J?oonfX00ol0N_oooo]ZoookJP0>oookJP03
o`3oE_oo:`3ooo]Z017ooo]Z00?o067oo`1ioooonfX01_oonfX00olN0?oooo]Zo`3o>@03oookJP03
ool0k?oonf[ooi@000oooo]Z00?olol0oookJ_oonfX01OoonfX01ooo06Gooo]ZoookJ_oonf[ood80
oookJ_oKo`000ooonfX01?oo3@3ooo]ZoookJ_oo0:`3oookJP03o`3od_oonf[oo`3i00kooo]Z00?o
0?nCoookJ_oonfX01?oonfX01?oo07[ooo]ZoookJ_oo04T6oookJP03o`3[oooonf[ooo]Z00;ooo]Z
00?on@3ooookJ_oonfX01ooonfX00ooi0?ooN?l0oookJP0?oookJP03o`2Aoooonf[ooo]Z00?ooo]Z
00?oo`1doookJ_oonfX02OoonfX3o`000003onSo0?oonf[ooo]Z00Wooo]Z00?oo`0=oookJ_oonfX0
0ooonfX01OooXP3ooo]ZoookJ_oonf[oY03o01?ooo]Z00Cook/0oookJ_oonf[o0>Oo0ooonfX00ooo
XP3ooo]ZoookJP0BoookJP;ooo<00_oonfX3o`3o30Sooo]Z0ol0_?lToookJRSo01Go0_oonfX;ool0
fa3ooo]Z2?l0_?l6o`3o30;ooo<00ol0o`PToookJP00B?oonfX00ooo:03ooo]ZoookJP0;oookJP[o
obP02ooonfX00ooo003o067oool00004ool00003oookJ_oo003oo`0000Ooo`000_oonfX00ooo:03o
oo]ZoookJP0=oookJP03oo?o0?oonf[ooo]Z00?ooo]Z0_oo:003oookJP03oom20?oonf[ooo]Z00;o
o`0000Gooo]Zool00?oo003oobP0oookJP02ool00005oookJ_l0om;ooo]ZoookJ_oo00002_oonfX8
oolX00;ooo]Z00?oo`1jool00?oo00000ooo0005oookJP03o`3[oooo:03oobP000KoobP00_oonfX8
oolX00_ooo]Z00Coo`00oolX0?oo:03oobP01?oonfX00ooo:03ooo]ZoookJP09oookJP;o000000?o
j?l0o`000?oonfX02?oonfX00ooo00gooo]ZoookJP04oookJP03oonR0?oonf[ooo]Z00;ooo]Z00?o
Y03ooookJ_oonfX03_oonfX3oolX0003oonk0?oo:03oobP000?oobP00ooo000>oookJPcoo`001Ooo
nfX3o`2lo`oooo]Z4?oo:008o`0Eo`[ooo]Z1_oo0002oookJQGo;_l03ol05Ol@oolX00Kooo]Z1ooo
N@02o`3o30;oogT0JOoonfX00ol0N_oooo]ZoookJP0>oookJP03o`3oE_oo:`3ooo]Z017ooo]Z00?o
067oo`1ioooonfX01OoonfX01?lN0?oooo]ZoookJ_l0ocT3oookJP03ool0k?oonf[ooi@000oooo]Z
00?olol0oookJ_oonfX01?oonfX01Ooo06Gooo]ZoookJ_oonf[ood8000;ooo]Z00Sofol0oookJ_oo
nf[ooo]Zool=0?oonf[oo`26ool0[0;ooo]Z00Co0?oBoookJ_oonf[oo`3i3OoonfX00ol0oi?ooo]Z
oookJP04oookJP04ool0N_oonf[ooo]Zool0B@Oooo]Z00Go0>_ooookJ_oonf[ooo]ZooT0o`0:oook
JP03ooT0oooonf[ooo]Z00kooo]Z00?o097ooookJ_oonfX00ooonfX00ooo07Cooo]ZoookJP09oook
JP?o000000?oj?l0oookJ_oonfX02?oonfX00ooo00gooo]ZoookJP04oookJP05oonR0?oonf[ooo]Z
oookJ_nT0?l04ooonfX00ooo^`3ooo]Zo`3Wo`03oookJP03oonR0?oonf[ooo]Z01;ooo]Z00?ooo<0
oookJ_oonfX00_l0o``8oookJP?o0;co7?oonfX;o`0Eoa;ooo]Z5Ol^o`000ooonf[o01Goo`0Eo`0=
o`0Eo`_oo`3K2ooonfX7o`2lo`Co0?l<9?oonfX004Wooo]Z00?oobP0oookJ_oonfX02ooonfX7oolX
00kooo]Z00?oo`00o`1Qoooo00003_oo00000ooonf[ooi@0oookJP0>oookJP03oo?o0?oonf[ooo]Z
00?ooo]Z0ooo:003oookJP03oom20?oonf[oo`0000;ooo]Z0_oo0002oolX0004ool00?oonf[ooo]Z
o`3odP;ooo]Z00?oo`00oookJ_oonfX02?oonfX6oolX00Cooo]Z00?oo`1jool00?oo00000ooo0005
oookJP03o`3[oooo:03oobP000OoobP000?ooo]ZoolX0?oo:0001_oo:00<oookJPCoobP00_oonfX3
oolX00[ooo]Z0_l000000ooXo`3o0000oookJP08oookJP03ool03Ooonf[ooo]Z00Cooo]Z00Gooj80
oookJ_oonf[ooo]Zoj@0o`0@oookJP?oobP000?ook/0oolX0?oo:0000ooo:004ool000kooo]Z2ooo
0004oookJP;o0;co4_oonfX>oolX00kooo]Z3_l^o`0Eo`2Bo`oo;_l02Ol05Ol8oolX00?oo`3K2Ooo
nfX4oomi06[ooo]Z00?o07[ooookJ_oonfX03_oonfX00ol0oeKooo]ZoookJP0@oookJP03o`1Qool0
NOoooo]Z00Kooo]Z00Co7P3ooookJ_oonf[o0?li0ooonfX00ooo0>cooi@0oookJP0>oookJP03oo?o
0?oonf[ooo]Z00Gooo]Z00Ooo`1UoookJ_oonf[ooo]Zoom20?oonf[ofol000?ooo]Z00Goo`d0oook
J_oonf[oo`26ool0[002oookJP03o`3od_oonf[oo`3i00gooo]Z00?o0?nCoookJ_oonfX01OoonfX0
1?oo07[ooo]ZoookJ_oo04T6oookJP03o`3[oooonf[ooo]Z00;ooo]Z00?on@3ooookJ_oonfX01ooo
nfX00ooi0?ooN?l0oookJP0>oookJP03o`2Aoooonf[ooo]Z00?ooo]Z00?oo`1doookJ_oonfX02Ooo
nfX3o`000003onSo0?oonf[ooo]Z00Sooo]Z00?oo`0=oookJ_oonfX00ooonfX01OooXP3ooo]Zoook
J_oonf[oY03o01?ooo]Z00?ook/0oookJ_l0iol00ooonfX00oooXP3ooo]ZoookJP0AoookJP;ooo<0
00?ooo]Zo`3o3?l0o``02?oonfX2o`2loa[ooo]Z1Ol05Ol?oookJPko;_l05Ol0T_l?obko0003oook
J_l05Ooo01Go00Oo01Go0_oonfX9ool0f`Wooo]Z1?l0_?lToookJP00BOoonfX00ooo:03ooo]Zoook
JP0;oookJPKoobP03ooonfX00ooo003o067oool0000?ool00003oookJ_ooU03ooo]Z00kooo]Z00?o
lol0oookJ_oonfX00ooonfX3oolX00?ooo]Z00?oobP0oookJ_oKo`000_oonfX01Ooo003ooo]ZoolX
0?oo:03oo`0000;ooo]Z00Co0?oBoookJ_oonf[oo`002_oonfX4oolX00Gooo]Z00?oo`1jool00?oo
00001?oo0004oookJP03o`3[oooo:03oobP000CoobP01?oonfX9oolX00_ooo]Z1?oo:002oookJP?o
obP02_oonfX2o`000003oolX0?l0003ooo]Z00Sooo]Z00?oo`0=oookJ_oonfX01?oonfX01OooXP3o
oo]ZoookJ_oonf[oY03o00oooo]Z0ooo:0000ooo^`3oobP0oolX0003oolX00Coo`003ooonfX00ooo
l`3oo`00ool00007ool000?ooo]Z0_l0_?lDoookJPcoobP01ooonfX9obko0003o`2Bool0Qooo08Oo
027o08Oo00?oobP0o`2Bool0T_l02ol0T_l9obko00So01Go0ooonfX5ool0f`Gooo]Z0oooN@1[oook
JP03o`1joooonf[ooo]Z00kooo]Z00?o0?mFoookJ_oonfX04?oonfX00ol0HOoo07WooookJP06oook
JP03oah0oooonf[o0?li00Cooo]Z00?oo`3/oonD0?oonfX03_oonfX00ooco`3ooo]ZoookJP04oook
JP03ool0IOoonf[ooo]Z00;ooo]Z00?ood80oookJ_oKo`000ooonfX01?oo3@3ooo]Zool0Q_oo0:`2
oookJP04o`3od_oonf[ooo]Zool0n@gooo]Z00?o0?nCoookJ_oonfX01?oonfX01?oo07[ooo]Zoook
J_oo04T6oookJP03o`3[oooonf[ooo]Z00;ooo]Z00?on@3ooookJ_oonfX01ooonfX00ooi0?ooN?l0
oookJP0>oookJP03o`2Aoooonf[ooo]Z00?ooo]Z00?oo`1doookJ_oonfX02OoonfX3o`000003onSo
0?oonf[ooo]Z00Sooo]Z00?oo`0=oookJ_oonfX00ooonfX01OooXP3ooo]ZoookJ_oonf[oY03o01;o
oo]Z00Cook/0oookJ_oonf[o0>Oo0_oonfX00oooXP3ooo]ZoookJP0@oookJP;ooo<00_oonfX00ol0
o`cooo]ZoookJP06oookJP;o0;co5ooonfX5o`0Eo`_ooo]Z2Ol^o`000ol0T_oo08Ooo`27o`0Ro`27
o`go09;o2Ol^o`000ooonf[o01Goo`0Eo`06o`0Eo`?ooo]Z1Ooo0=//oookJP00B_oonfX00ooo:03o
oo]ZoookJP0;oookJP?oobP000?o0?mFoolX0?oonfX03_oonfX2ool00003o`1Qoooo003oo`0000ko
o`0000?ooi@0oookJ_oonfX03_oonfX00ooo003ooo]ZoookJP02oookJPCoobP00_oonfX00ooo:03o
oo]Zom_o0003oookJP05ool00?oo:03oobP0oolX0?oo00000_oonfX00ol0om;ooo]ZoookJP0:oook
JP04oolX0?oonf[ooo]ZoolX00Kooo]Z00?oo`1jool00?oo00001?oo0004oookJP;oobP00_oonfX0
0ooi0?oooo]ZoookJP03oookJPKoobP03_oonfX4oolX00;ooo]Z0ooo:00:oookJP;o000000?oobP0
o`000?oonfX01ooonfX00ooo00gooo]ZoookJP04oookJP05oonR0?oonf[ooo]ZoookJ_nT0?l04Ooo
nfX00ooo:03ook/0oolX0005oolX00?oo`003_oonfX2oolX0003oookJ_oo003oo`0000Goo`000_oo
nfX3o`2loaGooo]Z00?o01GooolX0?oo:0002?oo:002oookJPOo;_l000?o09;oo`27ool0Qol01ol0
QolMoookJPKoobP03ol0Qol4oolX00Co09;o2?l^o`07o`0Eo`03oookJ_oo0=_oo`3K00?oo`3K0ooo
N@1/oookJP03o`1joooonf[ooo]Z00gooo]Z00?o0?mFool[0?oonfX04OoonfX00ol0HOoo07Wooook
JP06oookJP03oah0oooonf[o0?li00Cooo]Z00?oo`3/oonD0?oonfX03_oonfX00ooco`3ooo]Zoook
JP04oookJP07ool0IOoonf[ooo]ZoookJ_oo@P3ooo]Zom_o0003oookJP05ool=0?oonf[ooo]Zool0
Q_oo0:`00_oonfX00ol0om;ooo]ZoookJP0=oookJP03o`3oTooonf[ooo]Z00Cooo]Z00Goo`1joook
J_oonf[ooo]Zool0B@06oookJP05o`3[oooonf[ooo]ZoookJ_oi0?l02OoonfX00ooi0?ooN?l0oook
JP0?oookJP03o`2Aoooonf[ooo]Z00;ooo]Z00?oo`1doookJ_oonfX02OoonfX3o`000003onSo0?oo
nf[ooo]Z00Oooo]Z00?oo`0=oookJ_oonfX01?oonfX01OooXP3ooo]ZoookJ_oonf[oY03o017ooo]Z
00Cook/0oookJ_oonf[o0>Oo5?oonfX2oooc00[ooo]Z0ol0_?lEoookJPCo01Go2_oonfX6obko0003
o`2Bool0Qooo08Oo00Oo08Oo9?oonfXAo`27o`Go09;o2?l^o`000ooonf[o01Goo`0Eo`05o`0Eo`03
oookJ_oo0=_oo`3K00?oo`3K9ooonfX004_ooo]Z00?oobP0oookJ_oonfX02_oonfX3oolX0003oook
J_l0oeKooo]Z00oooo]Z0_oo00000ol0HOooo`00ool0000>ool00003oonD0?oonf[ooo]Z00gooo]Z
00?oo`00oookJ_oonfX00_oonfX5oolX0005oookJ_oo:03oobP0oookJ_oKo`000ooonfX01?oo003o
obP0oolX0?oo:002oookJP03o`3od_oonf[ooo]Z00kooo]Z00?oobP0oookJ_oonfX00ooonfX00ooo
07[oo`00ool00004ool000Cooo]Z00?oo`00oookJ_oonfX00_oonfX00ooi0?oooo]ZoookJP02oook
JP;oobP00_oonfX00ooi0?ooN?l0oookJP0<oookJPKoobP000Cooo]ZoolX0?oo:03oobP00_l007l8
oookJP04o`000?oo:03oobP0o`0000Sooo]Z00?oobP0oookJ_oonfX01?oonfX01OooXP3ooo]Zoook
J_oonf[oY03o017ooo]Z00?ook/0oolX0?oo:0001?oo:004ool000_ooo]Z1Ooo:002oookJPGoo`00
00?ooo]ZoolX0?oo:0005OoonfX3o`0Eo`03oookJ_oo:03oobP000GoobP01Ol^o`04oolX00Co08Oo
2Ooo000=oookJPWoNP3o5ooo:006ogX0o`03oookJ_l0Qooo08Oo00_o08Oo00?o09;oobko0?l^o`00
1Ol^o`06o`0Eo`?oogT0KOoonfX00ol0N_oooo]ZoookJP0=oookJP03o`3oE_oo:`3ooo]Z017ooo]Z
00?o067ooookJ_oonfX01OoonfX00olN0?oooo]Zo`3o>@05oookJP03oonD0?oonf[ooo]Z00gooo]Z
00?olol0oookJ_oonfX01?oonfX00ooo06Gooo]ZoookJP02oookJP03oom20?oonf[ofol000?ooo]Z
00?oo`d0oookJ_oo08H00ooonfX00ol0om;ooo]ZoookJP0>oookJP03o`3oTooonf[ooo]Z00Cooo]Z
00Coo`1joookJ_oonf[oo`191_oonfX00ol0jooooo]ZoookJP02oookJP03ooT0oooonf[ooo]Z00Ko
oo]Z00?on@3oogSo0?oonfX03ooonfX01_l0TOoooo]ZoookJ_oonf[o001oool0M0?o001o2?oonfX3
o`000003onSo0?oonf[ooo]Z00Oooo]Z00?oo`0=oookJ_oonfX00ooonfX01OooXP3ooo]ZoookJ_oo
nf[oY03o017ooo]Z00Cook/0oookJ_oonf[o0>Oo5?oonfX00oool`3ooo]ZoookJP08oookJP;o0;co
5OoonfX3o`0Eo`Wooo]Z1Ol^o`000ol0T_oo08Ooo`27o`04o`27oaKooo]Z9_mj0?l2oookJPgo08Oo
1ol^o`000ooonf[o01Goo`0Eo`04o`0Eo`?oo`3K9?oonfX004cooo]Z00?oobP0oookJ_oonfX02_oo
nfX01Ooo:03ooo]ZoookJ_oonf[o0?mF00oooo]Z5?oo00000oooU03ooo]ZoookJP0<oookJP;oo`00
0ooonfX6oolX0004oookJ_oo:03oobP0om_o00?ooo]Z1Ooo:002oookJP03ool00?oonf[ooo]Z00go
oo]Z00?o0?nCoookJ_oonfX00ooonfX00ooo07[oo`00ool00005ool000?ooo]Z0_oo0003oookJP03
ooT0oooonf[ooo]Z00Kooo]Z00?on@3oogSo0?oonfX03?oonfX;oolX00;o001o1ooonfX01?l0003o
obP0oolX0?l00008oookJP03oolX0?oonf[ooo]Z00Cooo]Z00Cooj80oookJ_oonf[oY03o4_oonfX0
0ooo^`3ooo]ZoolX0004oolX00?oo`002_oonfX6oolX00?ooo]Z0ooo0005oolX01;ooo]Z0ol05Ol4
oookJP;oobP01Ol^o`07oolX00;ooo]Z4Ooo0009ogX0oa3ooo]Z3Ooo:009oookJPgoNP3o00?ooo]Z
o`27ool0Qol01_l0Qol6obko00?oogT0K_oonfX00ol0N_oooo]ZoookJP0=oookJP03o`3oE_oo:`3o
oo]Z017ooo]Z00?o067ooookJ_oonfX01OoonfX00olN0?oooo]Zo`3o>@05oookJP03oonD0?oonf[o
oo]Z00gooo]Z00?olol0oookJ_oonfX01?oonfX01ooo06Gooo]ZoookJ_oonf[ood80oookJ_oKo`00
1_oonfX01Ooo08Kooo]ZoookJ_oonf[o0?oB00oooo]Z00?o0?nCoookJ_oonfX01?oonfX01?oo07[o
oo]ZoookJ_oo04T6oookJP03o`3[oooonf[ooo]Z00;ooo]Z00?on@3ooookJ_oonfX01ooonfX00ooi
0?oooo]ZoookJP0>oookJP03o`2Aoooonf[ooo]Z00;o001o00?oo`1do`00Ool007l00_l007l7oook
JP?o000000?oj?l0oookJ_oonfX01ooonfX00ooo00gooo]ZoookJP03oookJP05oonR0?oonf[ooo]Z
oookJ_nT0?l04OoonfX00ooo^`3ooo]Zo`3Wo`0DoookJP03oooc0?oonf[ooo]Z00Sooo]Z00?o0;co
oookJ_oonfX04_oonfX3o`0Eo`Oooo]Z1Ol^o`02o`2Bo`Co08Oo3_oonfX>ogX0obKooo]Z3Omj0?l2
oookJPOo08Oo1ol^o`03o`0EobCooo]Z001=oookJP03oolX0?oonf[ooo]Z00gooo]Z00?o0?mFoolX
0?oonfX03_oonfX5ool000;ooo]Z00?oo`00oookJ_oonfX01ooo0002oookJP03oonD0?oonf[ooo]Z
00gooo]Z0_oo0003oookJPWoobP000?ofol0oookJ_oonfX01Ooo:002oookJP03ool00?oonf[ooo]Z
00kooo]Z00?o0?nCoookJ_oonfX00ooonfX00ooo:03oo`00ool00005ool000;ooo]Z0_oo0003oook
JP03ooT0oooonf[ooo]Z00Oooo]Z00?on@3oogSo0?oonfX02ooonfX;oolX00;o001o1ooonfX3oolX
0003o`000?oonf[ooo]Z00Gooo]Z0_oo:005oookJP05oonR0?oonf[ooo]ZoookJ_nT0?l04OoonfX0
1?oo^`3ooo]Zo`3WoooonfX3oolX00Coo`002?oonfX7oolX00Cooo]Z1ooo:00@oookJP?o01Go1Ooo
nfX4obko00_oobP00ooonfX?ool001_ooo]Z2?oo:00KoookJPWoNP3o1?oonfX2o`27o`?o;_l0Kooo
nfX00ol0N_oooo]ZoookJP0=oookJP03o`3oE_oonf[ooo]Z013ooo]Z00?o067oo`1ioooonfX01_oo
nfX00olN0?oooo]Zo`3o>@05oookJP03oonD0?oonf[ooo]Z00cooo]Z00?olol0oookJ_oonfX01?oo
nfX00ooo06Gooo]ZoookJP02oookJP03oom20?oonf[ofol000Gooo]Z00Goo`26oookJ_oonf[ooo]Z
o`3odP0@oookJP03o`3oTooonf[ooo]Z00Cooo]Z00Coo`1joookJ_oonf[oo`191_oonfX01Ol0jooo
oo]ZoookJ_oonf[on@3o00Wooo]Z00?on@3oogSo0?oonfX03_oonfX00ol0TOoooo]Zo`00O`02o`00
O`03ool0M?oonf[o001o00;o001o1ooonfX2o`000003onSo0?l0003ooo]Z00Sooo]Z00?oo`0=oook
J_oonfX00ooonfX01?ooXP3ooo]ZoookJ_nT0?lAoookJP03oonk0?oonf[o0>Oo01?ooo]Z0_ool`09
oookJP;o0;co4ooonfX2o`0Eo`Kooo]Z1?l^o`03o`2Bo`Co08Oo2OoonfX9ogX0od7ooo]Z2Omj0?l5
oookJP;o08Oo0ol^o`0ToookJP00C_oonfX00ooo:03ooo]ZoookJP0=oookJP03o`3oE_oo:03ooo]Z
00gooo]Z1_oo0004oookJPGoo`001OoonfX00oooU03ooo]ZoookJP0<oookJP?oo`000_oonfX:oolX
00?ooo]Z1Ooo:0000ooonf[oo`00ool0000?oookJP03o`3oTooonf[ooo]Z00?ooo]Z00?oobP0ool0
0?oo00000ooo0004oookJP?oo`000_oonfX00ooi0?oooo]ZoookJP07oookJP03ooT0oomho`3ooo]Z
00_ooo]Z2ooo:003o`00O`Kooo]Z1?oo:007oookJP;oobP01OoonfX01?ooXP3ooo]ZoookJ_nT0?lA
oookJP04oonk0?oonf[ooo]Zo`3Wo`;ooo]Z00?oobP0oookJ_oo00000_oo0006oookJPWoobP00_oo
nfX9oolX00kooo]Z0ol05Ol6oookJP;o;_l03Ooo:003oookJPkoo`006?oonfX6ofoo00?oobP03_m_
o`0KoookJPKoNP3oLooonfX00ol0N_oooo]ZoookJP0<oookJP03o`3oE_oo:`3ooo]Z017ooo]Z00?o
067ooookJ_oonfX01OoonfX00olN0?oooo]Zo`3o>@05oookJP03oonD0?oonf[ooo]Z00gooo]Z00?o
lol0oookJ_oonfX01?oonfX01ooo06Gooo]ZoookJ_oonf[ood80oookJ_oKo`001_oonfX01Ooo08Ko
oo]ZoookJ_oonf[o0?oB00oooo]Z00?o0?nCoookJ_oonfX01?oonfX01?oo07[ooo]ZoookJ_oo04T6
oookJP05o`3[oooonf[ooo]ZoookJ_oi0?l02OoonfX00ooi0?ooN?l0oookJP0>oookJP03o`2Aoooo
nf[o001o00;o001o00?oo`1doookJ_oonfX00ol007l6oookJP;o000000?oj?l0o`000?oonfX01ooo
nfX00ooo00gooo]ZoookJP04oookJP04oonR0?oonf[ooo]Zoj@0oa3ooo]Z00Cook/0oookJ_oonf[o
0>Oo4_oonfX00oool`3ooo]ZoookJP08oookJP03o`2loooonf[ooo]Z013ooo]Z0ol05Ol5oookJP?o
;_l000?ooo]Zo`2Bool0T_l01?l0Qol9oookJPCoNP3o8OoonfXGofoo01_ooo]Z1omj0?lWoookJP00
CooonfX00ooo:03ooo]ZoookJP0=oookJP03o`3oE_oo:03ooo]Z00cooo]Z1ooo0003oookJPCoo`00
00?ooo]Zool00?oonfX00ooonfX00oooU03ooo]ZoookJP0<oookJPCoo`0000?ooo]ZoolX0?oo:000
2Ooo:002oookJPKoobP00ooo000>oookJP03o`3oTooonf[ooo]Z00?ooo]Z0_oo:002ool000Kooo]Z
0ooo0003oookJP03ooT0oooonf[ooo]Z00Kooo]Z00?on@3oogSo0?oonfX02ooonfX<oolX00;o001o
1_oonfX4oolX00;o00001?oonfX3oolX00Gooo]Z00Cooj80oookJ_oonf[oY03o4?oonfX01?oo^`3o
oo]ZoookJ_l0iol6oookJP03ool00?oonf[ooo]Z00?ooo]Z5Ooo:00=oookJP;oo`000_oonfX5oolX
00;o;_l00ooo:0000ol0QoooobP0oolX0007oolX00Sooo]Z2Ooo000;oookJPooKol05ooonfXAofoo
013ooo]Z0omj0?maoookJP03o`1joooonf[ooo]Z00cooo]Z00?o0?mFool[0?oonfX04OoonfX00ol0
HOoooo]ZoookJP05oookJP03oah0oooonf[o0?li00Gooo]Z00?ooi@0oookJ_oonfX03?oonfX00ooc
o`3ooo]ZoookJP04oookJP03ool0IOoonf[ooo]Z00;ooo]Z00?ood80oookJ_oKo`001OoonfX01Ooo
08Kooo]ZoookJ_oonf[o0?oB00oooo]Z00?o0?nCoookJ_oonfX01?oonfX01?oo07[ooo]ZoookJ_oo
04T6oookJP03o`3[oooonf[ooo]Z00;ooo]Z00?on@3ooookJ_oonfX01_oonfX00ooi0?ooN?l0oook
JP0>oookJP03o`2Aoooonf[ooo]Z00;ooo]Z00?oo`1doookJ_oonfX00ol007l6oookJP;o000000Co
j?l0o`000?l0003o00001_oonfX00ooo00gooo]ZoookJP03oookJP05oonR0?oonf[ooo]ZoookJ_nT
0?l03ooonfX01?oo^`3ooo]ZoookJ_l0iolBoookJP03oooc0?oonf[ooo]Z00Sooo]Z00?o0;cooook
J_oonfX03ooonfX2o`0Eo`Kooo]Z0_l^o`000ooonf[o09;oo`2Bo`03o`27ob?ooo]Z3om_o`0Goook
JQ;oKol04?oonfX3ogX0obCooo]Z001@oookJP03oolX0?oonf[ooo]Z00cooo]Z00?o0?mFoolX0?oo
nfX03OoonfX00ooo003ooo]Zool00004ool000?ooo]Z00?oo`00oookJ_oonfX00_oo0005oookJP03
oonD0?oonf[ooo]Z00_ooo]Z1Ooo00000ooonf[oobP0oolX0008oolX00;ooo]Z1_oo:003ool000oo
oo]Z00?o0?nCoookJ_oonfX00_oonfX3oolX0003oookJ_oo003ooo]Z00Cooo]Z1?oo0002oookJP03
ooT0oooonf[ooo]Z00Kooo]Z00?on@3oogSo0?oonfX02_oonfX=oolX00;o001o1OoonfX5oolX00Ko
oo]Z0ooo:004oookJP04oolX0?oonf[ooo]ZoolX017ooo]Z00?ook/0oookJ_l0iol03?oonfXEoolX
00_ooo]Z1?oo0005oolX00?o;_l00_oo:003o`27o`;ooo]Z1ooo:009oookJPKoo`001OoonfX9ofoo
03Oooo]Z3Om_o`1hoookJP03o`1joooonf[ooo]Z00cooo]Z00?o0?mFool[0?oonfX04?oonfX00ol0
HOoooo]ZoookJP06oookJP03oah0oooonf[o0?li00Cooo]Z00?ooi@0oookJ_oonfX03OoonfX00ooc
o`3ooo]ZoookJP04oookJP07ool0IOoonf[ooo]ZoookJ_oo@P3ooo]Zom_o0006oookJP04ool0Q_oo
nf[ooo]Zo`3odQ3ooo]Z00?o0?nCoookJ_oonfX01?oonfX01?oo07[ooo]ZoookJ_oo04T5oookJP03
o`3[oooonf[ooo]Z00;ooo]Z00?on@3ooookJ_oonfX01_oonfX00ooi0?ooN?l0oookJP0>oookJP03
o`2Aoooonf[ooo]Z00;ooo]Z00?oo`1doookJ_oonfX00ol007l6oookJP;o000000?oj?l0o`000?oo
nfX01ooonfX00ooo00gooo]ZoookJP03oookJP04oonR0?oonf[ooo]Zoj@0oa3ooo]Z00?ook/0oook
J_l0iol04_oonfX00oool`3ooo]ZoookJP07oookJP;o0;co4?oonfX2o`0Eo`Kooo]Z0_l^o`03o`2B
o`;o08Oo7OoonfX9ofoo03Sooo]Z3Om_o`0ZoookJP00D?oonfX00ol0N_oooo]ZoookJP0=oookJP03
o`3oE_oo:03ooo]Z00oooo]Z1Ooo0006oookJP;oo`001OoonfX00oooU03ooo]ZoookJP0:oookJPKo
o`002ooo:0000ooonf[oobP0oolX0005oolX00?oo`003_oonfX00ol0oi?ooo]ZoookJP02oookJP?o
obP01ooonfX4ool000;ooo]Z00?on@3ooookJ_oonfX01_oonfX00ooi0?ooN?l0oookJP0:oookJPgo
obP00_l007l5oookJPGoobP01OoonfX4oolX00Cooo]Z00CoobP0oookJ_oonf[oobP04?oonfX00ooo
^`3ooo]Zool0000=oookJQCoobP02OoonfX6ool000CoobP00_l^o`03oolX00;o08Oo00?oobP0oook
J_oonfX00_oonfX5oolX00Wooo]Z0_oo:004ool000?oobP01?m_o`1=oookJPKoKol0L_oonfX00ol0
N_oooo]ZoookJP0<oookJP03o`3oE_oo:`3ooo]Z017ooo]Z00?o067ooookJ_oonfX01_oonfX00olN
0?oo0?lioookJP04oookJP03oonD0?oonf[ooo]Z00cooo]Z00?olol0oookJ_oonfX01?oonfX00ooo
06Gooo]ZoookJP02oookJP03oom20?oonf[ofol000Gooo]Z00Goo`26oookJ_oonf[ooo]Zo`3odP0?
oookJP03o`3oTooonf[ooo]Z00Cooo]Z00?oo`1joookJ_oonfX01ooonfX01Ol0jooooo]ZoookJ_oo
nf[on@3o00Wooo]Z00?on@3ooookJ_oonfX03OoonfX00ol0TOoooo]ZoookJP02o`00O`03ool0M?oo
nf[o001o00?o001o1_oonfX2o`000003onSo0?l0003ooo]Z00Oooo]Z00?oo`0=oookJ_oonfX00ooo
nfX01?ooXP3ooo]ZoookJ_nT0?l?oookJP03oonk0?oonf[o0>Oo01;ooo]Z00?ooo<0oookJ_oonfX0
1ooonfX00ol0_?oooo]ZoookJP0?oookJP03o`0Eoooonf[ooo]Z00?ooo]Z0ol^o`02o`2Bo`03oook
J_l0Qooo08Oo01Sooo]Z1om_o`1>oookJPKoKol09?oonfX0057ooo]Z00?o07[ooookJ_oonfX03Ooo
nfX00ol0oeKoobP0oookJP0>oookJPKoo`001OoonfX00ooo003ooo]Zool00004oookJP03oonD0?oo
nf[ooo]Z00_ooo]Z1_oo000BoolX00Coo`003OoonfX00ol0oi?ooo]ZoookJP02oookJPCoobP01_oo
nfX5ool00003oookJ_oi0?oooo]Z00Oooo]Z00?on@3ooookJ_mho`002_oonfX=oolX0003o`00Oooo
nf[ooo]Z00?ooo]Z1_oo:005oookJPCoobP00ooonfX2oolX0003oookJ_oo:03oobP000oooo]Z00Co
ok/0oookJ_oo003oo`003_oonfX8oolX0003oookJ_oo:03oobP000SoobP01_oonfX8ool000;ooo]Z
00?oobP0obko0?l^o`000ooo:002o`27o`;oobP01_oonfX2oolX00?ooo]Z2_oo:0000ooo003oobP0
oolX0002oolX01cooo]Z;ol0ogF1oookJP03o`1joooonf[ooo]Z00cooo]Z00?o0?mFool[0?oonfX0
4?oonfX00ol0HOoo07WooookJP06oookJP03oah0oooonf[o0?li00Gooo]Z00?ooi@0oookJ_oonfX0
3?oonfX00ooco`3ooo]ZoookJP04oookJP07ool0IOoonf[ooo]ZoookJ_oo@P3ooo]Zom_o0005oook
JP05ool0Q_oonf[ooo]ZoookJ_l0om804?oonfX00ol0oi?ooo]ZoookJP03oookJP03ool0N_oonf[o
oo]Z00Oooo]Z00Go0>_ooookJ_oonf[ooo]ZooT0o`09oookJP03ooT0oomho`3ooo]Z00gooo]Z00?o
097ooookJ_oonfX00_l007l00ooo07Co001oo`00O`02o`00O`Oooo]Z0_l000000ooXo`3o0000oook
JP06oookJP03ool03Ooonf[ooo]Z00?ooo]Z00Cooj80oookJ_oonf[oY03o3ooonfX01?oo^`3ooo]Z
oookJ_l0iolBoookJP03oooc0?oonf[ooo]Z00Kooo]Z00?o0;cooookJ_oonfX03_oonfX2o`0Eo`Co
oo]Z0_l^o`02o`2Bo`04oookJ_l0Qooo08Ooo`27oaOooo]Z0om_o`0MoookJS3o0?me<_oonfX005;o
oo]Z00?o07[ooookJ_oonfX03?oonfX00ol0oeKooo]ZoolX000>oookJPOoo`001OoonfX2ool000Go
oo]Z00?ooi@0oookJ_oonfX02_oonfX7ool000?oobP000?ooo]ZoolX0?oo:0002ooo:005ool000go
oo]Z00Co0?nCoookJ_oonf[ooo]Z1?oo:006oookJPGoo`000_oonfX00ooi0?oooo]ZoookJP05oook
JP03ooT0oooonf[oN?l000kooo]Z00?o097ooolX0?oo:0001ooo:005oookJPKoobP01?oonfX5oolX
00;ooo]Z1_oo:00?oookJP04oonk0?oo003oo`00ool000oooo]Z1ooo:002oookJPSoobP01?oonfX:
ool000;ooo]Z1?oo:003o`27o`;oobP02?oonfX00ooo:03ooo]ZoookJP02oookJPgoobP04OoonfX=
o`3oMBoooo]Z3Ol0ogEeoookJP03o`1joooonf[ooo]Z00cooo]Z00?o0?mFool[0?oonfX04?oonfX0
0ol0HOoooo]ZoookJP06oookJP03oah0oooonf[o0?li00Cooo]Z00?ooi@0oookJ_oonfX03?oonfX0
0ooco`3ooo]ZoookJP04oookJP03ool0IOoonf[ooo]Z00;ooo]Z00?ood80oookJ_oKo`001OoonfX0
1Ooo08Kooo]ZoookJ_oonf[o0?oB00oooo]Z00?o0?nCoookJ_oonfX01?oonfX00ooo07[ooo]Zoook
JP06oookJP03o`3[oooonf[ooo]Z00;ooo]Z00?on@3ooookJ_oonfX01_oonfX00ooi0?ooN?l0oook
JP0=oookJP03o`2Aoooonf[ooo]Z00;o001o00Coo`1do`00Ool007oo001o2?oonfX01?l0003oj?l0
o`000?l00007oookJP03ool03Ooonf[ooo]Z00?ooo]Z00Cooj80oookJ_oonf[oY03o3ooonfX00ooo
^`3ooo]Zo`3Wo`0BoookJP03oooc0?oonf[ooo]Z00Kooo]Z00?o0;cooookJ_oonfX03OoonfX2o`0E
o`Cooo]Z0_l^o`000ol0T_oooo]ZoookJP02o`27oaOooo]Z0om_o`0CoookJPgo0?me<?oonfX=o`3o
MBGooo]Z001BoookJP03o`1joooonf[ooo]Z00gooo]Z00?o0?mFoookJ_oo:0003_oonfX7ool000Go
oo]Z0_oo0004oookJP03oonD0?oonf[ooo]Z00[ooo]Z2?oo0002oolX0003oookJ_oo:03oobP000Wo
obP00_oonfX5ool000gooo]Z00Co0?nCoookJ_oonf[ooo]Z1Ooo:005oookJPKoo`0000?ooo]ZooT0
oooonfX01_oonfX00ooi0?oooo]ZoolX000>oookJP03o`2Aoooo:03oobP000OoobP01?oonfX7oolX
00Cooo]Z1Ooo:002oookJPKoobP03_oonfX01?oo^`3oo`00ool00?oo000AoookJPGoobP00ooonfX0
0ol0_?ooobP0oolX0004oolX00?ooo]Z2ooo0004oolX0003oookJ_l0Qooo08Oo00CoobP03_oonfX<
oolX00gooo]Z1Ol0ogE9oookJP03o`3oMOoonf[ooo]Z07;ooo]Z00?o07[ooookJ_oonfX03OoonfX0
0ol0oeKoob/0oookJP0@oookJP03o`1Qoooonf[ooo]Z00Kooo]Z00?o7P3oo`3o>OoonfX01?oonfX0
0oooU03ooo]ZoookJP0<oookJP03oo?o0?oonf[ooo]Z00Cooo]Z00Ooo`1UoookJ_oonf[ooo]Zoom2
0?oonf[ofol000Gooo]Z00Goo`26oookJ_oonf[ooo]Zo`3odP0?oookJP03o`3oTooonf[ooo]Z00Co
oo]Z00?oo`1joookJ_oonfX01_oonfX00ol0jooooo]ZoookJP02oookJP03ooT0oooonf[ooo]Z00Ko
oo]Z00?on@3oogSo0?oonfX03OoonfX00ol0TOoooo]ZoookJP02o`00O`03ool0M?oonf[ooo]Z00Wo
oo]Z00Co0000onSo0?l0003o00001ooonfX00ooo00gooo]ZoookJP03oookJP04oonR0?oonf[ooo]Z
oj@0o`kooo]Z00Cook/0oookJ_oonf[o0>Oo4OoonfX00oool`3ooo]ZoookJP06oookJP03o`2loooo
nf[ooo]Z00gooo]Z00?o01GooookJ_oonfX00_oonfX2obko0003o`2Boooonf[ooo]Z00;o08Oo5_oo
nfX3ofoo017ooo]Z1Ol0ogE:oookJP03o`3oMOoonf[ooo]Z02;ooo]Z001CoookJP03o`1joooonf[o
oo]Z00gooo]Z00?o0?mFoookJ_oo:0003OoonfX8ool000Kooo]Z00?oo`00oookJ_oonfX00_oonfX0
0oooU03ooo]ZoookJP09oookJPWoo`0000?ooo]ZoolX0?oo:0002?oo:002oookJP03oolX0?oonf[o
o`0000Goo`003?oonfX00ol0oi?ooo]ZoookJP02oookJPGoobP01?oonfX6ool00003oookJ_oi0?oo
oo]Z00Oooo]Z00?on@3ooolX0?oonfX03OoonfX00ol0TOoooo]ZoookJP02o`00O`03ool0M?oonf[o
oo]Z00Kooo]Z2?oo:002oookJPKoobP000?ooo]ZoolX0?oo:0001Ooo:00>oookJP04oonk0?oo003o
o`00ool0013ooo]Z00?ooo<0oookJ_oo:0000_oo:003oookJP03o`2loooonf[oobP000CoobP01?oo
nfX8ool000KoobP00_oo0005oolX013ooo]Z2Ooo:00;oookJPCo0?mea?oonfX00ol0N_oooo]Zoook
JP0<oookJP03o`3oE_oonf[oob/0013ooo]Z00?o067oo`1ioooonfX02?oonfX00ol0ocWooo]Zoook
JP03oookJP03oonD0?oonf[ooo]Z00cooo]Z00?olol0oookJ_oonfX00ooonfX00ooo06Gooo]Zoook
JP02oookJP03oom20?oonf[ofol000Gooo]Z00Coo`26oookJ_oonf[o0?oB4?oonfX00ol0oi?ooo]Z
oookJP03oookJP03ool0N_oonf[ooo]Z00Kooo]Z00?o0>_ooookJ_oonfX00_oonfX00ooi0?oooo]Z
oookJP06oookJP03ooT0oomho`3ooo]Z00gooo]Z00?o097ooookJ_oonfX00_l007l00ooo07Cooo]Z
oookJP09oookJP04o`000?oXo`3o0000o`0000Oooo]Z00?oo`0=oookJ_oonfX00_oonfX01?ooXP3o
oo]ZoookJ_nT0?l?oookJP03oonk0?oonf[o0>Oo017ooo]Z00?ooo<0oookJ_oonfX01_oonfX00ol0
_?oooo]ZoookJP0<oookJP;o01Go1?oonfX01?l^o`3o09;oo`2BoooonfX2o`27oaGooo]Z0om_o`0@
oookJPCo0?meM?oonfX005Cooo]Z00?o07[ooookJ_oonfX03OoonfX00ol0oeKoob/0oookJP0<oook
JPWoo`001OoonfX00ooo003ooo]ZoookJP03oookJP03oonD0?oonf[ooo]Z00Sooo]Z1ooo0004oook
JPOoobP01?oonfX00ooo:03ooo]Zool00006ool000cooo]Z00Co0?nCoookJ_oonf[ooo]Z1Ooo:004
oookJPOoo`0000?on@3ooookJ_oonfX01_oonfX00ooi0?ooobP0oolX000=oookJP06o`2Aoooonf[o
oo]ZoookJ_l007ooo`1d1Ol007l3oookJPSoobP00_oonfX6oolX0003oookJ_oo:03oobP000GoobP0
3OoonfX00ooo^`3oo`00ool00002ool000oooo]Z00Gooo<0oookJ_oonf[ooo]ZoolX0003oookJP04
o`2loooonf[ooo]ZoookJP?oobP01_oonfX4ool000SoobP00ooo0003oolX00oooo]Z00?oKol0oolX
0?oo:0001ooo:008oookJPGo0?mebOoonfX00ol0N_oooo]ZoookJP0<oookJP03o`3oE_oo:`3ooo]Z
013ooo]Z00?o067ooookJ_oonfX01ooonfX00ol0ocWooo]ZoookJP03oookJP03oonD0?oonf[ooo]Z
00cooo]Z00?olol0oookJ_oonfX01?oonfX01ooo06Gooo]ZoookJ_oonf[ood80oookJ_oKo`001Ooo
nfX01Ooo08Kooo]ZoookJ_oonf[o0?oB00oooo]Z00?o0?nCoookJ_oonfX00ooonfX00ooo07[ooo]Z
oookJP07oookJP05o`3[oooonf[ooo]ZoookJ_oi0?l02OoonfX00ooi0?oooo]ZoookJP0<oookJP06
o`2Aoooonf[ooo]ZoookJ_l007ooo`1d1Ol007l6oookJP04o`000?oXo`3o0000o`0000Oooo]Z00?o
o`0=oookJ_oonfX00_oonfX01?ooXP3ooo]ZoookJ_nT0?l>oookJP04oonk0?oonf[ooo]Zo`3Woa3o
oo]Z00?ooo<0oookJ_oonfX01_oonfX00ol0_?oooo]ZoookJP0<oookJP03o`0Eoooonf[ooo]Z00;o
oo]Z0_l^o`001?l0T_oooo]ZoookJ_l0QolDoookJP?oKol03_oonfX5o`3oMGSooo]Z001DoookJP03
o`1joooonf[ooo]Z00gooo]Z00?o0?mFoookJ_oo:`003OoonfX6ool000Sooo]Z00?oo`00oookJ_oo
nfX00_oonfX00oooU03ooo]ZoookJP09oookJPGoo`001OoonfX5oolX00;ooo]Z00?ofol0oookJ_oo
nfX00_oonfX00ooo:03oo`00ool00005ool000cooo]Z00Co0?nCoookJ_oonf[ooo]Z1_oo:003oook
JPOoo`0000?ooo]ZooT0oooonfX01_oonfX00ooi0?ooobP0oolX000=oookJP06o`2Aoooonf[ooo]Z
oookJ_l007ooo`1d1Ol007l2oookJPWoobP000?ooo]ZoolX0?oo:0003Ooo:00<oookJP03oonk0?oo
003oo`0000?oo`003_oonfX00oool`3ooo]ZoookJP05oookJP03o`2loooonf[ooo]Z00?ooo]Z00?o
obP0oookJ_oonfX01_oonfX:oolX00?oo`000_oonfX00ooo:03ooo]ZoookJP0;oookJP?oKol00ooo
nfX>oolX0003o`3oMOoonf[ooo]Z0<cooo]Z00?o07[ooookJ_oonfX03OoonfX00ol0oeKoob/0oook
JP0?oookJP03o`1Qool0NOoooo]Z00Sooo]Z00?o0?lioookJ_oonfX00ooonfX00oooU03ooo]Zoook
JP0<oookJP03oo?o0?oonf[ooo]Z00?ooo]Z00?oo`1UoookJ_oonfX00_oonfX00ooo@P3ooo]Zom_o
0005oookJP04ool0Q_oonf[ooo]Zo`3odPoooo]Z00?o0?nCoookJ_oonfX01?oonfX00ooo07[ooo]Z
oookJP06oookJP03o`3[oooonf[ooo]Z00;ooo]Z00?on@3ooookJ_oonfX01_oonfX00ooi0?oooo]Z
oookJP0<oookJP06o`2Aoooonf[ooo]ZoookJ_l007ooo`1d1Ol007l6oookJP04o`000?oXo`3o0000
o`0000Kooo]Z00?oo`0=oookJ_oonfX00ooonfX01?ooXP3ooo]ZoookJ_nT0?l=oookJP04oonk0?oo
nf[ooo]Zo`3Woa7ooo]Z00?ooo<0oookJ_oonfX01OoonfX00ol0_?oooo]ZoookJP0@oookJP;o;_l0
0_l0T_l00ooonf[o08Ooo`27o`0BoookJP?oKol03_oonfX3o`3oMGgooo]Z001EoookJP03o`1joooo
nf[ooo]Z00gooo]Z00?o0?mFool[0?oonfX03?oonfX6ool000Wooo]Z00?oo`00oookJ_oonfX00_oo
nfX00oooU03ooo]ZoookJP08oookJP?oo`0000?ooo]Zool00?oonfX01OoonfX01ooo:03ooo]Zoook
J_oonf[oobP0oookJ_oKo`001?oonfX00ooo:03ooo]Zool00006ool000_ooo]Z00Co0?nCoookJ_oo
nf[ooo]Z1_oo:003oookJPWoo`001ooonfX00ooo003oobP0oolX000=oookJP03o`2Aoooonf[ooo]Z
00;ooo]Z00?oo`1doookJ_oonfX02OoonfX00ooXo`3oobP0oolX0002oolX0003oookJ_oo:03oobP0
00coobP03?oonfX00ooo003ook/0ool00003ool000kooo]Z00?ooo<0oookJ_oonfX01OoonfX00ol0
_?oooo]ZoookJP0;oookJP_oobP00ooo000?oookJP;oKol00ooonfX?oolX0=;ooo]Z00?o07[ooook
J_oonfX03?oonfX00ol0oeKoob/0oookJP0@oookJP03o`1Qool0NOoooo]Z00Sooo]Z00?o0?lioook
J_oonfX00ooonfX00oooU03ooo]ZoookJP0;oookJP03oo?o0?oonf[ooo]Z00Cooo]Z00Ooo`1Uoook
J_oonf[ooo]Zoom20?oonf[ofol000Gooo]Z00Goo`26oookJ_oonf[ooo]Zo`3odP0?oookJP03o`3o
Tooonf[ooo]Z00?ooo]Z00?oo`1joookJ_oonfX01_oonfX00ol0jooooo]ZoookJP02oookJP03ooT0
oooonf[ooo]Z00Kooo]Z00?on@3ooookJ_oonfX03OoonfX01Ol0TOoooo]ZoookJ_oonf[oo`1d00_o
oo]Z00Co0000onSo0?l0003o00001_oonfX00ooo00gooo]ZoookJP02oookJP04oonR0?oonf[ooo]Z
oj@0o`kooo]Z00?ook/0oookJ_l0iol04OoonfX00oool`3ooo]ZoookJP05oookJP03o`2loooonf[o
oo]Z013ooo]Z00?o;_l0oookJ_l0T_l00_oonfX00ol0Qooooo]ZoookJP0@oookJP;oKol03_oonfX3
o`3oMH3ooo]Z001EoookJP03o`1joooonf[ooo]Z00kooo]Z00?o0?mFool[0?oonfX02ooonfX3ool0
0003oookJ_oo003ooo]Z00kooo]Z00?ooi@0oookJ_oonfX02?oonfX00ooo003ooo]ZoookJP02oook
JP03ool00?oonf[ooo]Z00?ooo]Z00GoobP0oookJ_oonf[ooo]ZoolX0002oookJP03om_o0?oonf[o
oo]Z00;ooo]Z00?oobP0ool00?oo00001_oo000;oookJP03o`3oTooonf[ooo]Z00OoobP00_oonfX5
ool000?ooo]Z00?oo`00oookJ_oonfX01OoonfX01?oo003oobP0oolX0?oo:00<oookJP03o`2Aoooo
nf[ooo]Z00;ooo]Z00?oo`1doookJ_oonfX02OoonfX01OoXo`3o0000o`000?l0003ooo]Z00ooobP0
2ooonfX00ooo003oobP0ool00004ool000gooo]Z00?ooo<0oookJ_oonfX01OoonfX00ol0_?oooo]Z
oookJP0<oookJP[oobP00ooo000>oookJP;oKol01OoonfX>oolX0=?ooo]Z00?o07[ooookJ_oonfX0
3OoonfX00ol0oeKoob/0oookJP0@oookJP03o`1Qoooonf[ooo]Z00gooo]Z00?ooi@0oookJ_oonfX0
3?oonfX00ooco`3ooo]ZoookJP03oookJP03ool0IOoonf[ooo]Z00;ooo]Z00?ood80oookJ_oKo`00
1OoonfX01?oo08Kooo]ZoookJ_l0om8?oookJP03o`3oTooonf[ooo]Z00?ooo]Z00?oo`1joookJ_oo
nfX01_oonfX00ol0jooooo]ZoookJP02oookJP03ooT0oooonf[ooo]Z00Kooo]Z00?on@3oogSo0?oo
nfX03OoonfX01Ol0TOoooo]ZoookJ_oonf[oo`1d00_ooo]Z00Co0000onSo0?l0003o00001_oonfX0
0ooo00gooo]ZoookJP02oookJP04oonR0?oonf[ooo]Zoj@0o`gooo]Z00Cook/0oookJ_oonf[o0>Oo
4?oonfX00oool`3ooo]ZoookJP05oookJP03o`2loooonf[ooo]Z00oooo]Z0_l^o`02o`2Bo`03oook
J_l0Qooo08Oo013ooo]Z0om_o`0=oookJP?o0?mePooonfX005Kooo]Z00?o07[ooookJ_oonfX03Ooo
nfX00ol0oeKooo]Zool[000<oookJP05ool00?oonf[ooo]ZoookJ_oo00003ooonfX00oooU03ooo]Z
oookJP0<oookJP03ool00?oonf[ooo]Z00Cooo]Z00CoobP0oookJ_oonf[oobP00_oonfX00ooKo`3o
oo]ZoookJP02oookJP03ool0Q_oo003oo`0000?oo`003_oonfX00ol0oi?ooo]ZoookJP08oolX0003
oookJ_oo003oo`0000;ooo]Z00Coo`00oookJ_oonf[ooo]Z0_oo0006oookJP;oo`000_oo:00<oook
JP03o`2Aoooonf[ooo]Z00;ooo]Z00?oo`1doookJ_oonfX02OoonfX01?oXo`3o0000o`000?l00004
oookJPcoobP02_oonfX2ool00003oolX0?oo003oo`0000?oo`003?oonfX00oool`3ooo]ZoookJP05
oookJP03o`2loooonf[ooo]Z00kooo]Z2?oo:003ool000cooo]Z0om_o`08oookJP_oobP0e_oonfX0
0ol0N_oooo]ZoookJP0=oookJP03o`3oE_oo:`3ooo]Z00oooo]Z00?o067ooookJ_oonfX03_oonfX0
0oooU03ooo]ZoookJP0;oookJP03oo?o0?oonf[ooo]Z00Cooo]Z00Ooo`1UoookJ_oonf[ooo]Zoom2
0?oonf[ofol000Gooo]Z00Coo`26oookJ_oonf[o0?oB4?oonfX00ol0oi?ooo]ZoookJP02oookJP03
ool0N_oonf[ooo]Z00Oooo]Z00Go0>_ooookJ_oonf[ooo]ZooT0o`08oookJP03ooT0oomho`3ooo]Z
00gooo]Z00Go097ooookJ_oonf[ooo]Zool0M00;oookJP04onSo0?l0003o0000o`0000Kooo]Z00?o
o`0=oookJ_oonfX00_oonfX01?ooXP3ooo]ZoookJ_nT0?l=oookJP03oonk0?oonf[o0>Oo013ooo]Z
00?ooo<0oookJ_oonfX01OoonfX00ol0_?oooo]ZoookJP0>oookJP;o;_l000Gooo]Zo`2Boooonf[o
oo]Zo`27o`0@oookJP;oKol03_oonfX2o`3oMHKooo]Z001GoookJP03o`1joooonf[ooo]Z00gooo]Z
00?o0?mFool[0?oonfX03ooonfX00ooo003ooo]ZoookJP0>oookJP03oonD0?oonf[ooo]Z00cooo]Z
00?oo`00oookJ_oonfX00ooonfX01Ooo06Gooo]ZoookJ_oonf[oobP000;ooo]Z00?oo`00oookJ_oo
nfX00_oonfX2ool000;ooo]Z00?oo`00oookJ_oonfX03?oonfX00ol0oi?ooo]ZoookJP05oolX00So
oo]Z00Coo`00oookJ_oonf[ooo]Z0_oo0006oookJP;oo`000_oo:00<oookJP03o`2Aoooonf[ooo]Z
00;ooo]Z00?oo`1doookJ_oonfX02OoonfX01?oXo`3o0000o`000?l00004oookJP03ool03Ooonf[o
oo]Z00WoobP02OoonfX2ool000;oobP01?oo000<oookJP03ool00?oonf[ooo]Z00Cooo]Z0_oo000A
oookJP03obko0?oo:03oobP000CoobP00ooo000;oookJP;oKol02ooonfX:oolX03Oooo]Z:?oo02Ei
oookJP03o`1joooonf[ooo]Z00gooo]Z00?o0?mFoookJ_oonfX03ooonfX00ol0HOoooo]ZoookJP0=
oookJP03oonD0?oonf[ooo]Z00cooo]Z00?olol0oookJ_oonfX00ooonfX00ooo06Gooo]ZoookJP02
oookJP03oom20?oonf[ofol000Cooo]Z00Goo`26oookJ_oonf[ooo]Zo`3odP0?oookJP03o`3oTooo
nf[ooo]Z00?ooo]Z00?oo`1joookJ_oonfX01_oonfX01Ol0jooooo]ZoookJ_oonf[on@3o00Sooo]Z
00?on@3oogSo0?oonfX03OoonfX01Ol0TOoooo]ZoookJ_oonf[oo`1d00_ooo]Z00Coj?l0o`000?l0
003o00001OoonfX00ooo00gooo]ZoookJP02oookJP04oonR0?oonf[ooo]Zoj@0o`gooo]Z00Cook/0
oookJ_oonf[o0>Oo3ooonfX00oool`3ooo]ZoookJP05oookJP03o`2loooonf[ooo]Z00kooo]Z00Go
;_l0oookJ_l0T_oo09;ooookJP02o`27o`kooo]Z0om_o`0=oookJP?o0?me>ooonfXYool09BCooo]Z
001GoookJP03o`1joooonf[ooo]Z00kooo]Z00?o0?mFool[0?oonfX03ooonfX00ooo003ooo]Zoook
JP0=oookJP03oonD0?oonf[ooo]Z00cooo]Z00?oo`00oookJ_oonfX01?oonfX01?oo06Gooo]Zoook
J_oo:002oookJP03ool00?oonf[ooo]Z00;ooo]Z00Goo`26oookJ_oonf[ooo]Zool0000?oookJP04
o`3oTooonf[oobP0oolX00;ooo]Z00?oobP0oookJ_oonfX02_oonfX2ool000Kooo]Z0ooo0002oolX
00_ooo]Z00?o097ooookJ_oonfX00_oonfX00ooo07Cooo]ZoookJP09oookJP04onSo0?l0003o0000
o`0000Cooo]Z00?oo`0=oookJ_oo:0002Ooo:008oookJP;oo`000ooo:004ool000_ooo]Z0_oo0005
oookJP?oo`004?oonfX00ol^o`3oo`00oolX0004oolX00?oo`002_oonfX2ool000cooo]Z2Ooo:00a
oookJPSoo`0UXOoonfX00ol0N_oooo]ZoookJP0=oookJP03o`3oE_oo:`3ooo]Z00oooo]Z00?o067o
oookJ_oonfX03_oonfX00oooU03ooo]ZoookJP0;oookJP03oo?o0?oonf[ooo]Z00Cooo]Z00Ooo`1U
oookJ_oonf[ooo]Zoom20?oonf[ofol000Gooo]Z00Coo`26oookJ_oonf[o0?oB3ooonfX00ol0oi?o
oo]ZoookJP03oookJP03ool0N_oonf[ooo]Z00_ooo]Z00?on@3ooookJ_oonfX01OoonfX00ooi0?oo
N?l0oookJP0=oookJP05o`2Aoooonf[ooo]ZoookJ_oo07@02ooonfX01?oXo`3o0000o`000?l00005
oookJP03ool03Ooonf[ooo]Z00;ooo]Z00Cooj80oookJ_oonf[oY03o3OoonfX00ooo^`3ooo]Zo`3W
o`0@oookJP03oooc0?oonf[ooo]Z00Gooo]Z00?o0;cooookJ_oonfX03OoonfX00ol^o`3ooo]Zo`2B
o`02oookJP03o`27oooonf[ooo]Z00cooo]Z0_m_o`0=oookJP?o0?me=ooonfX7ool09Dgooo]Z001H
oookJP03o`1joooonf[ooo]Z00gooo]Z00?o0?mFool[0?oonfX04?oonfX00ooo003ooo]ZoookJP0=
oookJP03ool00?oonf[ooo]Z00cooo]Z00?oo`00oookJ_oonfX00ooonfX01_oo06Gooo]ZoookJ_oo
nf[oobP0oookJP;oo`000ooonfX00ooo08Kooo]ZoookJP02oookJP03ool00?oonf[ooo]Z00cooo]Z
00?oo`00oookJ_oonfX00ooonfX00ooo:03ooo]ZoookJP09oookJPCoo`001?oonfX4ool000;oobP0
2ooonfX00ol0TOoooo]ZoookJP02oookJP03ool0M?oonf[ooo]Z00Sooo]Z00?oj?l0o`000?l00000
0ol00003oookJP03ool03Ooo:03oobP000WoobP02_oonfX3oolX00Coo`002_oonfX3ool000Cooo]Z
0ooo000@oookJP04obko0?oo003oo`00ool000?oobP00ooo0008oookJPGoo`002_oonfX01?l0ogGo
obP0oookJ_oonfX6oolX02_ooo]Z1ooo02FZoookJP03o`1joooonf[ooo]Z00gooo]Z00?o0?mFoook
J_oonfX03ooonfX00ol0HOoooo]ZoookJP0>oookJP03oonD0?oonf[ooo]Z00_ooo]Z00?olol0oook
J_oonfX00ooonfX00ooo06Gooo]ZoookJP02oookJP03oom20?oonf[ofol000Cooo]Z00Goo`26oook
J_oonf[ooo]Zo`3odP0?oookJP03o`3oTooonf[ooo]Z00;ooo]Z00?oo`1joookJ_oonfX02ooonfX0
0ooi0?oooo]ZoookJP06oookJP03ooT0oooonf[ooo]Z00cooo]Z00Go097ooookJ_oonf[ooo]Zool0
M00;oookJP03onSo0?l0003o000000;o00001?oonfX00ooo00gooo]ZoookJP02oookJP04oonR0?oo
nf[ooo]Zoj@0o`gooo]Z00?ook/0oookJ_oonfX03ooonfX00oool`3ooo]ZoookJP05oookJP03o`2l
oooonf[ooo]Z00gooo]Z00?o;_l0oookJ_l0T_l00_oonfX00ol0Qooooo]ZoookJP0<oookJP03ofoo
0?oonf[ooo]Z00_ooo]Z0_l0ogDcoookJPOoo`0UE?oonfX005Wooo]Z00?o07[ooookJ_oonfX03Ooo
nfX00ol0oeKoob/0oookJP0?oookJP03ool00?oonf[ooo]Z00gooo]Z00?oo`00oookJ_oonfX03?oo
nfX00ooo003ooo]ZoookJP03oookJP06ool0IOoonf[ooo]ZoookJ_oo@P3ooo]Z0ooo0003oookJP05
ool0Q_oonf[ooo]ZoookJ_oo00003_oonfX00ooo003ooo]ZoookJP04oookJP03oolX0?oonf[ooo]Z
00Sooo]Z1?oo0004oookJPCoo`000_oo:00;oookJP03o`2Aoooonf[ooo]Z00;ooo]Z00?oo`1doook
J_oonfX02?oonfX00ooXo`3o0000o`000002o`0000Cooo]Z00Coo`0=oookJ_oonf[ooo]Z2?oo:009
oookJP?oobP01Ooo0009oookJP?oo`001?oonfX4ool000oooo]Z00?o;_l0ool00?oo00000ooo0000
1?oo:03oo`00ool00?oo0007oookJPKoo`002OoonfX2o`3oM@Cooo]Z1Ooo:00VoookJPKoo`0U/_oo
nfX00ol0N_oooo]ZoookJP0=oookJP03o`3oE_oonf[ooo]Z00oooo]Z00?o067ooookJ_oonfX03Ooo
nfX00oooU03ooo]ZoookJP0;oookJP03oo?o0?oonf[ooo]Z00?ooo]Z00?oo`1UoookJ_oonfX00_oo
nfX00ooo@P3ooo]Zom_o0004oookJP05ool0Q_oonf[ooo]ZoookJ_l0om803ooonfX00ol0oi?ooo]Z
oookJP03oookJP03ool0N_oonf[ooo]Z00[ooo]Z00?on@3ooookJ_oonfX01_oonfX00ooi0?oooo]Z
oookJP0<oookJP05o`2Aoooonf[ooo]ZoookJ_oo07@02ooonfX01?oXo`3o0000o`000?l00005oook
JP03ool03Ooonf[ooo]Z00;ooo]Z00Cooj80oookJ_oonf[oY03o3?oonfX00ooo^`3ooo]ZoookJP0?
oookJP03oooc0?oonf[ooo]Z00Gooo]Z00?o0;cooookJ_oonfX03OoonfX00ol^o`3ooo]Zo`2Bo`0@
oookJP;oKol03?oonfX2o`3oMBoooo]Z1_oo02EKoookJP00FOoonfX00ol0N_oooo]ZoookJP0>oook
JP03o`3oE_oo:`3ooo]Z00oooo]Z00?oo`00oookJ_oonfX03?oonfX2ool000kooo]Z00?oo`00oook
J_oonfX00ooonfX01Ooo06Gooo]ZoookJ_oonf[ood8000?oo`000ooonfX01Ooo08Kooo]ZoookJ_oo
nf[oo`0000kooo]Z0_oo0005oookJP03oolX0?oonf[ooo]Z00Sooo]Z1Ooo0003oookJPGoo`000_oo
:00:oookJP03ool00?oonf[ooo]Z00;ooo]Z00?oo`1doookJ_oonfX02?oonfX00ooXo`3o0000o`00
0002o`0000Cooo]Z00?oo`0=oookJ_oonfX00_oonfX00oooXP3ooo]Zoj@0o`04oolX00Sooo]Z1?oo
:0001?oonf[oo`00ool00?oo0009oookJPCoo`000ooonfX5ool000gooo]Z00?oo`00obko0?oo0000
1?oo00001?oonf[oo`00ool00?oo0005oookJPSoo`002OoonfX00ol0ogGooo]ZoookJP04oookJP?o
obP08ooonfX5ool09Agooo]Z8?oo04mkoookJP03o`1joooonf[ooo]Z00gooo]Z00?o0?mFool[0?oo
nfX03ooonfX00ol0HOoooo]ZoookJP0>oookJP03oonD0?oonf[ooo]Z00_ooo]Z00?olol0oookJ_oo
nfX00ooonfX00ooo06Gooo]ZoookJP02oookJP03oom20?oKo`3ooo]Z00Cooo]Z00Coo`26oookJ_oo
nf[o0?oB3ooonfX00ol0oi?ooo]ZoookJP03oookJP03ool0N_oonf[ooo]Z00[ooo]Z00?on@3ooook
J_oonfX01_oonfX00ooi0?oooo]ZoookJP0<oookJP05o`2Aoooonf[ooo]ZoookJ_oo07@02ooonfX0
1?oXo`3o0000o`000?l00005oookJP05ool03Ooonf[ooo]ZoookJ_ooXP000_oonfX00onT0?oooo]Z
oookJP0;oookJP03oonk0?oonf[ooo]Z00oooo]Z00?ooo<0oookJ_oonfX01?oonfX00ol0_?oooo]Z
oookJP0=oookJP03obko0?oonf[o09;o013ooo]Z00?oKol0oookJ_oonfX02_oonfX2o`3oMBcooo]Z
1Ooo02DMoookJR3oo`1?9?oonfX005[ooo]Z00?o07[ooookJ_oonfX03OoonfX00ol0oeKoob/0oook
JP0@oookJP03ool00?oonf[ooo]Z00cooo]Z0_oo000CoookJP05ool0IOoonf[ooo]ZoookJ_oo@P00
1?oo0002oookJP03ool0Q_oonf[ooo]Z00;ooo]Z00?oo`00oookJ_oonfX02ooonfX2ool000Gooo]Z
00?oo`1joookJ_oonfX02?oonfX5ool000?ooo]Z1Ooo0002oolX00[ooo]Z00?oo`00oookJ_oonfX0
0_oonfX00ooo07Cooo]ZoookJP08oookJP03onSo0?l0003o000000;o00000ooonfX00ooo00gooo]Z
oookJP03oookJP03oonR0?oonf[oY03o00_ooo]Z1Ooo:003oookJP03ool00?oonf[ooo]Z00Kooo]Z
1Ooo00000ooonf[oo`00ool00004ool000cooo]Z0_oo00000ol^o`3oo`00ool00003ool000?ooo]Z
00?oo`00oookJ_oonfX00_oonfX9ool000Sooo]Z0_l0ogD8oookJP03oolX0?oonf[ooo]Z01gooo]Z
1Ooo02DFoookJPcoo`1?W?oonfX00ol0N_oooo]ZoookJP0=oookJP03o`3oE_oonf[ooo]Z00oooo]Z
00?o067ooookJ_oonfX03OoonfX00oooU03ooo]ZoookJP0AoookJP03ool0IOoonf[ooo]Z00;ooo]Z
00?ood80oookJ_oKo`001?oonfX01Ooo08Kooo]ZoookJ_oonf[o0?oB00oooo]Z00?o0?nCoookJ_oo
nfX00_oonfX00ooo07[ooo]ZoookJP0:oookJP03ooT0oooonf[ooo]Z00Kooo]Z00?on@3ooookJ_oo
nfX03?oonfX01Ol0TOoooo]ZoookJ_oonf[oo`1d00_ooo]Z00Coj?l0o`000?l0003o00001?oonfX0
0ooo00gooo]ZoookJP02oookJP04oonR0?oonf[ooo]Zoj@0o`gooo]Z00?ook/0oookJ_oonfX03_oo
nfX00oool`3ooo]ZoookJP05oookJP03o`2loooonf[ooo]Z00cooo]Z00?o;_l0oookJ_l0T_l03ooo
nfX2ofoo00_ooo]Z0_l0ogDYoookJPGoo`0U5_oonfX<ool0CdCooo]Z001KoookJP03o`1joooonf[o
oo]Z00gooo]Z00?o0?mFool[0?oonfX03ooonfX00ooo003ooo]ZoookJP0<oookJP?oo`004ooonfX0
1?oo06Gooo]ZoookJ_oo@P04ool000?ooo]Z00?oo`26oookJ_oonfX03ooonfX3ool000Cooo]Z00?o
o`1joookJ_oonfX02?oonfX5ool000?ooo]Z1_oo00000ooo:03ooo]ZoookJP08oookJP03ool00?oo
nf[ooo]Z00;ooo]Z00?oo`00oookJ_oonfX02?oonfX00ooXo`3o0000o`000002o`0000?ooo]Z00?o
o`0=oookJ_oonfX00ooonfX00oooXP3ooo]Zoj@0o`0;oookJPGoobP02ooonfX=ool000_ooo]Z0_oo
00000ol^o`3oo`00ool00003ool000Kooo]Z2ooo0007oookJP;o0?me9OoonfX5ool09A?ooo]Z2?oo
04nYoookJP03o`1joooonf[ooo]Z00gooo]Z00?o0?mFoookJ_oonfX03_oonfX00ol0HOoooo]Zoook
JP0>oookJP03oonD0?oonf[ooo]Z017ooo]Z00Ooo`1UoookJ_oonf[ooo]Zoom20?oonf[ofol000Co
oo]Z00?oo`26oookJ_oonfX04OoonfX00ol0oi?ooo]ZoookJP02oookJP03ool0N_oonf[ooo]Z00[o
oo]Z00?on@3ooookJ_oonfX01_oonfX00ooi0?oooo]ZoookJP0<oookJP05o`2Aoooonf[ooo]Zoook
J_oo07@02_oonfX00ooXo`3o0000o`000002o`0000Cooo]Z00?oo`0=oookJ_oonfX00_oonfX01?oo
XP3ooo]ZoookJ_nT0?l<oookJP03oonk0?oonf[ooo]Z00kooo]Z00?ooo<0oookJ_oonfX01OoonfX0
0ol0_?oooo]ZoookJP0<oookJP03obko0?oonf[o09;o00oooo]Z00?oKol0oookJ_oonfX02_oonfX0
0ol0ogGooo]ZoookJP0ToookJPGoo`0U4ooonfX8ool0Ce3ooo]Z001KoookJP03o`1joooonf[ooo]Z
00kooo]Z00?oo`00oookJ_oonfX03ooonfX00ooo003ooo]ZoookJP0;oookJPCoo`004_oonfX01Ooo
06Gooo]ZoookJ_oonf[ood8000Coo`000_oonfX00ooo08Kooo]ZoookJP0?oookJP?oo`001?oonfX0
0ooo07[ooo]ZoookJP08oookJPKoo`000_oonfX6ool000;oobP02?oonfX3ool000?ooo]Z00?oo`00
oookJ_oonfX02?oonfX00ooXo`3o0000o`000002o`0000?ooo]Z00?oo`0=oookJ_oonfX00ooonfX0
0oooXP3ooo]Zoj@0o`0:oookJPKoobP02_oonfX=ool000[ooo]Z0ooo00000ol^o`3oo`00ool00003
ool000Kooo]Z2ooo0006oookJP;o0?me8ooonfX4ool09ACooo]Z1?oo04naoookJP03o`1joooonf[o
oo]Z00gooo]Z00?oob/0o`3oE_oonfX03ooonfX00ol0HOoooo]ZoookJP0=oookJP03oonD0?oonf[o
oo]Z017ooo]Z00?oo`1UoookJ_oonfX00_oonfX00ooo@P3ofol0oookJP04oookJP03ool0Q_oonf[o
oo]Z013ooo]Z00?o0?nCoookJ_oonfX00_oonfX00ooo07[ooo]ZoookJP0;oookJP03ooT0oooonf[o
oo]Z00Gooo]Z00?on@3oogSo0?oonfX03?oonfX01Ol0TOoooo]ZoookJ_oonf[oo`1d00[ooo]Z00?o
j?l0o`000?l000000_l00004oookJP03ool03Ooonf[ooo]Z00;ooo]Z00Cooj80oookJ_oonf[oY03o
3?oonfX00ooo^`3ooo]ZoookJP0>oookJP03oooc0?oonf[ooo]Z00Cooo]Z00?o0;cooookJ_oonfX0
3?oonfX00ol^o`3ooo]Zo`2Bo`0?oookJP03ofoo0?oonf[ooo]Z00Wooo]Z0_l0ogDSoookJPCoo`0U
4ooonfX5ool0CeSooo]Z001LoookJP03o`1joooonf[ooo]Z00gooo]Z00?oo`00ool[0?oonfX04?oo
nfX00ooo003ooo]ZoookJP0:oookJPGoo`004OoonfX01Ooo06Gooo]ZoookJ_oonf[ood8000Goo`00
00?ooo]Zool0Q_oonfX04?oonfX4ool000Cooo]Z00?oo`1joookJ_oonfX01ooonfX6ool000;ooo]Z
1ooo0009oookJP?oo`000_oonfX2ool000[ooo]Z00?oj?l0o`000?l000000_l00003oookJP03ool0
3Ooonf[ooo]Z00;ooo]Z00Cooj80oookJ_oonf[oY03o2OoonfX7oolX00Wooo]Z3_oo0009oookJP?o
o`0000?o;_l0ool00?oo00001?oo0006oookJP_oo`001OoonfX00ol0ogGooo]ZoookJP0PoookJP?o
o`0U4ooonfX5ool0CkKooo]Z00?o07[ooookJ_oonfX03OoonfX00ol0oeKooo]ZoookJP0?oookJP03
o`1Qoooonf[ooo]Z00cooo]Z00?ooi@0oookJ_oonfX04OoonfX00ooo06Gooo]ZoookJP02oookJP03
oom20?oonf[ofol000Cooo]Z00?oo`26oookJ_oonfX04?oonfX00ol0oi?ooo]ZoookJP03oookJP03
ool0N_oonf[ooo]Z00[ooo]Z00?on@3ooookJ_oonfX01OoonfX00ooi0?ooN?l0oookJP0<oookJP05
o`2Aoooonf[ooo]ZoookJ_oo07@02_oonfX00ooXo`3o0000o`000002o`0000Cooo]Z00?oo`0=oook
J_oonfX00_oonfX00oooXP3ooo]Zoj@0o`0=oookJP03oonk0?oonf[ooo]Z00gooo]Z00?ooo<0oook
J_oonfX01?oonfX00ol0_?oooo]ZoookJP0<oookJP03obko0?oonf[o09;o00kooo]Z0_m_o`0:oook
JP;o0?me8_oonfX3ool09A?ooo]Z1?oo04mMoookJP00GOoonfX00ol0N_oooo]ZoookJP0<oookJP;o
o`0000?oob/0oookJ_oonfX06ooonfX5ool001;ooo]Z00Goo`1UoookJ_oonf[ooo]Zoom20004ool0
00;ooo]Z00?oo`26oookJ_oonfX03_oonfX5ool000?ooo]Z00?oo`1joookJ_oonfX01ooonfX?ool0
00Wooo]Z0ooo0002oookJP?oo`002OoonfX00ooo003o0000o`000002o`0000?ooo]Z00?oo`0=oook
J_oonfX00_oonfX00oooXP3ooo]Zoj@0o`0:oookJPOoobP02?oonfX?ool000[ooo]Z2?oo0008oook
JPWoo`001?oonfX2o`3oMB7ooo]Z0_oo02DBoookJPCoo`1?<OoonfX<onKo07oooo]Z00?o07[ooook
J_oonfX03OoonfX00ol0oeKooo]ZoookJP0NoookJP03oonD0?oonf[ooo]Z017ooo]Z00Ooo`1Uoook
J_oonf[ooo]Zoom20?oonf[ofol000Cooo]Z00?oo`26oookJ_oonfX04OoonfX00ol0oi?ooo]Zoook
JP02oookJP03ool0N_oonf[ooo]Z00[ooo]Z00?on@3ooookJ_oonfX01OoonfX00ooi0?ooN?l0oook
JP0<oookJP05o`2Aoooonf[ooo]ZoookJ_oo07@02_oonfX00ooXo`3o0000o`000002o`0000Cooo]Z
00Goo`0=oookJ_oonf[ooo]ZoonR0002oookJP03oj@0oooonf[ooo]Z00[ooo]Z00?ook/0oookJ_oo
nfX03OoonfX00oool`3ooo]ZoookJP05oookJP03o`2loooonf[ooo]Z00_ooo]Z00?o;_l0oookJ_l0
T_l03_oonfX00om_o`3ooo]ZoookJP08oookJP;o0?me8_oonfX2ool09A;ooo]Z1?oo04l`oookJPgo
i_l09?oonfX005gooo]Z00?o07[ooookJ_oonfX03OoonfX2ool001kooo]Z1Ooo000AoookJP05ool0
IOoonf[ooo]ZoookJ_oo@P001Ooo00000ooonf[oo`26oookJP0?oookJPGoo`000ooonfX00ooo07[o
oo]ZoookJP06oookJQ3oo`002OoonfX3ool000;ooo]Z0ooo0009oookJP03ool00?l0003o000000;o
00000_oonfX00ooo00gooo]ZoookJP03oookJP03oonR0?oonf[oY03o00Wooo]Z2?oo:007oookJPoo
o`002_oonfX8ool000[ooo]Z1ooo0003oookJP;oo`008?oonfX3ool09A3ooo]Z1?oo04lBoookJPWo
obP03OoonfX=onKo00?ooo]Z2Ol0f?mooookJP03o`1joooonf[ooo]Z00gooo]Z00?o0?mFoookJ_oo
nfX07_oonfX00oooU03ooo]ZoookJP0AoookJP03ool0IOoonf[ooo]Z00;ooo]Z00?ood80om_o0?oo
nfX01?oonfX00ooo08Kooo]ZoookJP0@oookJP03o`3oTooonf[ooo]Z00;ooo]Z00?oo`1joookJ_oo
nfX02_oonfX00ooi0?oooo]ZoookJP05oookJP03ooT0oomho`3ooo]Z00cooo]Z00Go097ooookJ_oo
nf[ooo]Zool0M00:oookJP03onSo0?l0003o000000;o00000ooonfX00ooo00gooo]ZoookJP02oook
JP04oonR0?oonf[ooo]Zoj@0o`cooo]Z00?ook/0oookJ_oonfX03OoonfX00oool`3ooo]ZoookJP04
oookJP03o`2loooonf[ooo]Z00cooo]Z00?o;_l0o`2BoooonfX03OoonfX00om_o`3ooo]ZoookJP07
oookJP;o0?me8OoonfX3ool09@oooo]Z1Ooo04lWoookJPgoi_l01?oonfX9o`3HobCooo]Z001Noook
JP03o`1joooonf[ooo]Z00cooo]Z0ooo000MoookJPKoo`004OoonfX01?oo06Gooo]ZoookJ_oo@P05
ool000;ooo]Z00?oo`26oookJ_oonfX03OoonfX6ool000;ooo]Z00?oo`1joookJ_oonfX01_oonfXA
ool000Oooo]Z2Ooo0008oookJP;oo`001?l00002oookJP03ool00?oonf[ooo]Z00;ooo]Z00Cooj80
oookJ_oonf[oY03o2?oonfX8oolX00Oooo]Z4?oo0009oookJP?oo`0000?ooo]Zool00?oo00000ooo
000;oookJPGoo`000_oonfX4ool001gooo]Z0ooo02D:oookJPSoobP000?oo`1?oookJ_oonfX05?oo
nfX@oolX00Koi_l01?oonfX<o`3HohWooo]Z00?o07[ooookJ_oonfX03OoonfX00ol0oeKooo]Zoook
JP0NoookJP03oonD0?oonf[ooo]Z017ooo]Z00Ooo`1UoookJ_oonf[ooo]Zoom20?oonf[ofol000Co
oo]Z00?oo`26oookJ_oonfX04?oonfX00ol0oi?ooo]ZoookJP02oookJP03ool0N_oonf[ooo]Z00[o
oo]Z00?on@3ooookJ_oonfX01_oonfX00ooi0?oooo]ZoookJP0;oookJP05o`2Aoooonf[ooo]Zoook
J_oo07@02_oonfX00ooXo`3o0000o`000002o`0000?ooo]Z00?oo`0=oookJ_oonfX00_oonfX00ooo
XP3ooo]Zoj@0o`0=oookJP03oonk0?oonf[ooo]Z00cooo]Z00?ooo<0oookJ_oonfX01?oonfX00ol0
_?oooo]ZoookJP0<oookJP03obko0?oonf[ooo]Z01Oooo]Z00?o0?meoookJ_oonfX07_oonfX3ool0
9@oooo]Z0ooo04lRoookJP[oi_l01?oonfX=o`3Hobgooo]Z001NoookJP03o`1joooonf[ooo]Z00co
oo]Z1?oo000LoookJPOoo`004?oonfX01Ooo06Gooo]ZoookJ_oo003ood8000Goo`0000?ooo]Zool0
Q_oonfX03_oonfX6ool000;ooo]Z00?oo`1joookJ_oonfX01_oonfX=ool00003ogSo0?oonf[ooo]Z
00Sooo]Z2Ooo0008oookJP;oo`001?l00002oookJP03ool00?oonf[ooo]Z00;ooo]Z00Cooj80oook
J_oonf[oY03o2_oonfX6oolX00Wooo]Z1ooo00000ooonf[oo`00ool00003ool000Wooo]Z1?oo0002
oookJP?oo`003OoonfX3ool00003oookJ_oo003oo`0000?oo`007?oonfX2ool09@Gooo]Z3_oo:00I
oookJPkoobP00ooonfX9o`3HoiGooo]Z00?o07[ooookJ_oonfX03OoonfX00ol0oeKooo]ZoookJP0N
oookJP03oonD0?oonf[ooo]Z017ooo]Z00Ooo`1UoookJ_oonf[ooo]Zoom20?oonf[ofol000Cooo]Z
00?oo`26oookJ_oonfX04?oonfX00ol0oi?ooo]ZoookJP02oookJP03ool0N_oonf[ooo]Z00[ooo]Z
00?on@3ooookJ_oonfX01_oonfX00ooi0?oooo]ZoookJP0;oookJP05o`2Aoooonf[ooo]ZoookJ_oo
07@02_oonfX00ooXo`3o0000o`000002o`0000?ooo]Z00?oo`0=oookJ_oonfX00_oonfX00oooXP3o
oo]Zoj@0o`0<oookJP03oonk0?oonf[ooo]Z00cooo]Z00?ooo<0oookJ_oonfX01?oonfX00ol0_?oo
oo]ZoookJP0<oookJP03obko0?oonf[ooo]Z01Oooo]Z00?o0?meoookJ_oonfX07OoonfX2ool09@oo
oo]Z0ooo04lOoookJPKoi_l01OoonfX9o`3Hoc[ooo]Z001OoookJP03o`1joooonf[ooo]Z00_ooo]Z
1Ooo000KoookJPSoo`003ooonfX01Ooo06Gooo]ZoookJ_oo003ood8000Koo`0000?oo`26oookJ_oo
nfX03OoonfX7ool000;ooo]Z00?oo`1joookJ_oonfX01OoonfX5ool000Oooo]Z00?oo`00ogSo0?oo
nfX02OoonfX9ool000Sooo]Z0_oo0004o`000003oookJ_oo003oo`0000Cooo]Z00Cooj80oookJ_oo
nf[oY03o2ooonfX00ooo^`3ooo]ZoolX0002oolX00_ooo]Z1Ooo0002oookJPCoo`002?oonfX5ool0
00?ooo]Z00?oo`00oookJ_oonfX03OoonfX7ool001[ooo]Z0ooo02D7oookJPgoobP06_oonfX8oolX
00Wo0=SoWooonfX00ol0N_oooo]ZoookJP0=oookJP03o`3oE_oonf[ooo]Z01kooo]Z00?ooi@0oook
J_oonfX04?oonfX00ooo06Gooo]ZoookJP02oookJP03oom20?oKo`3ooo]Z00Cooo]Z00?oo`26oook
J_oonfX04?oonfX00ol0oi?ooo]ZoookJP02oookJP03ool0N_oonf[ooo]Z00Wooo]Z00?on@3ooook
J_oonfX01_oonfX00ooi0?oooo]ZoookJP0;oookJP05o`2Aoooonf[ooo]ZoookJ_oo07@02_oonfX0
0ooXo`3o0000o`000002o`0000?ooo]Z00?oo`0=oookJ_oonfX00_oonfX00oooXP3ooo]Zoj@0o`0<
oookJP03oonk0?oonf[ooo]Z02;ooo]Z00?o;_l0oookJ_oonfX05_oonfX00ol0ogGooo]ZoookJP0K
oookJP?oo`0U3ooonfX2ool0Cagooo]Z1OoVo`03oookJPSo0=So@ooonfX0063ooo]Z00?o07[ooook
J_oonfX02ooonfX5ool001[ooo]Z2Ooo000?oookJP05ool0IOoonf[oo`00ool00?oo@P000ooo0003
oookJP03ool0Q_oonf[ooo]Z00cooo]Z1ooo0002oookJP03ool0N_oonf[ooo]Z00[ooo]Z00?oo`00
oookJ_oonfX01?oonfX00ooo003oN?l0oookJP08oookJP_oo`001_oonfX4ool000?o000000?ooo]Z
ool00?oo00001?oonfX00oooXP3ooo]Zoj@0o`0<oookJP05oonk0?oonf[ooo]ZoookJ_oo:0003?oo
nfX3ool000Cooo]Z0ooo0006oookJPKoo`004ooonfX7ool001Wooo]Z0_oo:00:oookJP_oobP04Ooo
nfX@oolX00?o0=So00?o0?KooookJ_oonfX0Y_oonfX00ol0N_oooo]ZoookJP0<oookJP03o`3oE_oo
:`3ooo]Z01kooo]Z00?ooi@0oookJ_oonfX04OoonfX01ooo06Gooo]ZoookJ_oonf[ood80oookJ_oK
o`001?oonfX00ooo08Kooo]ZoookJP0@oookJP03o`3oTooonf[ooo]Z00;ooo]Z00?oo`1joookJ_oo
nfX02_oonfX00ooi0?oooo]ZoookJP05oookJP03ooT0oooonf[ooo]Z00_ooo]Z00Go097ooookJ_oo
nf[ooo]Zool0M009oookJP03onSo0?oonf[o000000?o00000ooonfX01Ooo00gooo]ZoookJ_oonf[o
oj8000;ooo]Z00?oY03ooookJ_oonfX02_oonfX00ooo^`3ooo]ZoookJP0QoookJP03obko0?oonf[o
oo]Z01Kooo]Z00?o0?meoookJ_oonfX06_oonfX2ool09@oooo]Z0ooo04lIoookJPKoi_l00_oonfX6
o`3Hod_ooo]Z001PoookJP03o`1joooonf[ooo]Z00_ooo]Z1_oo000JoookJPKoo`004OoonfX01ooo
06Gooo]Zool00?oo003ood80oookJ_oo00001?oonfX00ooo08Kooo]ZoookJP0<oookJPSoo`0000?o
oo]Zool0N_oonfX02ooonfX00ooo003ooo]ZoookJP05oookJP03ogSo0?oonf[ooo]Z00Oooo]Z2ooo
0006oookJPCoo`000ol000000ooonf[oo`00ool00003oookJP04oonR0?oonf[ooo]Zoj@0o`_ooo]Z
00?ook/0oookJ_oonfX04OoonfX00ooo003ooo]ZoookJP03oookJP03ool00?oonf[ooo]Z00Cooo]Z
1ooo000AoookJPWoo`005_oonfX5oolX00_ooo]Z2?oo:00CoookJQ;oobP0Z_oonfX00ol0N_oooo]Z
oookJP0=oookJP03o`3oE_oonf[ooo]Z01kooo]Z00?ooi@0oookJ_oonfX04?oonfX01ooo06Gooo]Z
oookJ_oonf[ood80oookJ_oKo`001?oonfX00ooo08Kooo]ZoookJP0@oookJP03o`3oTooonf[ooo]Z
00;ooo]Z00?oo`1joookJ_oonfX02_oonfX00ooi0?oooo]ZoookJP05oookJP03ogSo0?oonf[ooo]Z
00_ooo]Z00Go097ooookJ_oonf[ooo]Zool0M009oookJP03onSo0?oonf[o000000?o00000_oonfX0
0ooo00gooo]ZoookJP02oookJP03oonR0?oonf[oY03o00cooo]Z00?ook/0oookJ_oonfX08OoonfX0
0ol^o`3ooo]ZoookJP0EoookJP;o0?me7?oonfX00ooo02Gooo]ZoookJP0<oookJP?oo`1?6?oonfX4
onKo00?ooo]Z1Ol0f?mAoookJP00HOoonfX00ol0N_oooo]ZoookJP0:oookJPOoo`006OoonfX4ool0
01?ooo]Z00Ooo`1UoookJ_oo003ooo]Zoom20?oonf[oo`0000Cooo]Z00?oo`26oookJ_oonfX03?oo
nfX5ool000Cooo]Z00?oo`1joookJ_oonfX02_oonfX00ooo003ooo]ZoookJP05oookJP03ogSo0?oo
nf[ooo]Z00Oooo]Z2ooo0005oookJPGoo`000ol00004ool000;ooo]Z00Coo`00oookJ_oonf[oo`00
2ooonfX00ooo^`3ooo]ZoookJP0MoookJPOoo`004?oonfX:ool001Cooo]Z1ooo:00;oookJPSoobP0
4ooonfX00ooVo`3oobP0oolX000=oolX0:kooo]Z00?o07[ooookJ_oonfX03?oonfX00ol0oeKoob/0
oookJP0NoookJP03oonD0?oonf[ooo]Z013ooo]Z00?oo`1UoookJ_oonfX00_oonfX00ooo@P3ofol0
oookJP04oookJP03ool0Q_oonf[ooo]Z00oooo]Z00?o0?nCoookJ_oonfX00_oonfX00ooo07[ooo]Z
oookJP0:oookJP03ooT0oooonf[ooo]Z00Gooo]Z00?oN?l0oookJ_oonfX02ooonfX01?l0TOoooo]Z
oookJ_oo07@:oookJP03onSo0?oonf[o000000Co000000?ooo]Zool03OoonfX00ooonfX00oooXP3o
oo]Zoj@0o`0<oookJP03oonk0?oonf[ooo]Z023ooo]Z00?o;_l0oookJ_oonfX05OoonfX00ol0ogGo
oo]ZoookJP0JoookJP;oo`0U3OoonfX2ool0CaSooo]Z0ooVo`03oookJPCo0=SoE_oonfX006;ooo]Z
00?oo`00oookJ_oonfX02_oonfX7ool001Sooo]Z00Coo`00oookJ_oonf[oo`005?oonfX01ooo06Go
oo]ZoookJ_oonf[ood80oookJ_oo00001?oonfX00ooo08Kooo]ZoookJP0;oookJP;oo`0000?ooo]Z
ool00?oonfX01?oonfX00ooo07[ooo]ZoookJP0BoookJP03ogSo0?oonf[ooo]Z00Oooo]Z2ooo0005
oookJPGoo`000ol00004ool000;ooo]Z00Coo`00oookJ_oonf[oo`002ooonfX00ooo^`3ooo]Zoook
JP0LoookJPSoo`003ooonfX:ool001;ooo]Z2Ooo:009oookJP?oobP000?ooo]ZoolX0?oo:0000ooo
:00BoookJP?oi_l000?ooo]ZoolX0?oo:0002?oo:002oookJP03oolX0?oonf[ooo]Z0:oooo]Z00?o
07[ooookJ_oonfX03?oonfX00ol0oeKooo]ZoookJP0MoookJP03oonD0?oonf[ooo]Z017ooo]Z00Oo
o`1UoookJ_oonf[ooo]Zoom20?oonf[ofol000Cooo]Z00?oo`26oookJ_oonfX03ooonfX00ol0oi?o
oo]ZoookJP02oookJP03ool0N_oonf[ooo]Z01;ooo]Z00?oN?l0oookJ_oonfX02ooonfX01?l0TOoo
oo]ZoookJ_oo07@:oookJP03onSo0?oonf[o000000?o00000_oonfX00ooo00gooo]ZoookJP02oook
JP03oonR0?oonf[oY03o00cooo]Z00?ook/0oookJ_oonfX08?oonfX00ol^o`3ooo]ZoookJP0Doook
JP03o`3oMOoonf[ooo]Z01Wooo]Z0_oo02D<oookJP?oo`1?5ooonfX3onKo00;ooo]Z1?l0f?mJoook
JP00H_oonfX2ool000_ooo]Z2?oo000KoookJP03ool00?oonf[ooo]Z017ooo]Z00Ooo`1UoookJ_oo
nf[ooo]Zoom20?oonf[oo`0000Cooo]Z00?oo`26oookJ_oonfX03ooonfX00ooo003ooo]ZoookJP03
oookJP03ool0N_oonf[ooo]Z017ooo]Z00?oN?l0oookJ_oonfX01_oonfX<ool000Gooo]Z1Ooo0002
o`0000Goo`0000Cooo]Zool00?oo003ooo]Z0_oo000:oookJP03oonk0?oonf[ooo]Z01cooo]Z2Ooo
000@oookJPSoo`004?oonfX;oolX00Sooo]Z00?oo`1?oolX0?oonfX01?oonfX2oolX017ooo]Z0_oV
o`05oolX0003o`3foooo:03oobP000GoobP0]_oonfX00ol0N_oooo]ZoookJP0<oookJP03o`3oE_oo
:`3ooo]Z01kooo]Z00?ooi@0oookJ_oonfX04?oonfX01ooo06Gooo]ZoookJ_oonf[ood80oookJ_oK
o`001?oonfX00ooo08Kooo]ZoookJP0@oookJP03o`3oTooonf[ooo]Z00;ooo]Z00?oo`1joookJ_oo
nfX04OoonfX00omho`3ooo]ZoookJP0;oookJP04o`2Aoooonf[ooo]Zool0M0[ooo]Z00?oj?l0oook
J_l000000ol00002oookJP03ool03Ooonf[ooo]Z00;ooo]Z00?ooj80oookJ_nT0?l02ooonfX00ooo
^`3ooo]ZoookJP0PoookJP03obko0?oonf[ooo]Z01Cooo]Z00?o0?meoookJ_oonfX06OoonfX00ooo
02Gooo]ZoookJP0:oookJP;oo`1?5ooonfX3onKo00Go0=SoG_oonfX006;ooo]Z0ooo000:oookJPKo
o`007OoonfX00ooo003ooo]ZoookJP0BoookJP06ool0IOoonf[ooo]Zoom20?oonf[oo`001?oonfX0
0ooo08Kooo]ZoookJP0?oookJP03ool00?oonf[ooo]Z00?ooo]Z00?oo`1joookJ_oonfX04OoonfX0
0omho`3ooo]ZoookJP06oookJPgoo`000ooonfX6ool000;o00001Ooo00001?oonf[oo`00ool00?oo
nfX2ool000[ooo]Z00?ook/0oookJ_oonfX06ooonfX9ool001;ooo]Z1ooo000?oookJP_oobP01ooo
nfX2ool0C`Oooo]Z00?oobP0oookJ_oonfX03OoonfX2oolX0004o`3Hoooo:03oobP0o`3fo`Gooo]Z
1_oo:02hoookJP03o`1joooonf[ooo]Z00cooo]Z00?o0?mFool[0?oonfX07OoonfX00oooU03ooo]Z
oookJP0AoookJP06ool0IOoonf[ooo]ZoookJ_oo@P3ofol01OoonfX00ooo08Kooo]ZoookJP0?oook
JP03o`3oTooonf[ooo]Z00;ooo]Z00?oo`1joookJ_oonfX04OoonfX00omho`3ooo]ZoookJP0;oook
JP04o`2Aoooonf[ooo]Zool0M0[ooo]Z00?oj?l0oookJ_l000000ol00002oookJP07ool03Ooonf[o
oo]ZoookJ_ooXP3ooo]Zoj@0o`0<oookJP03oonk0?oonf[ooo]Z01oooo]Z00?o;_l0oookJ_oonfX0
5?oonfX00ol0ogGooo]ZoookJP0HoookJP;oo`0U2ooonfX2ool0CaKooo]Z0ooVo`03o`3Hof?ooo]Z
001SoookJP?oo`002OoonfX5ool00003ool[0?oonf[ooo]Z01cooo]Z00?oo`00oookJ_oonfX04Ooo
nfX01ooo06Gooo]ZoookJ_oonf[ood80oookJ_oo00001?oonfX00ooo003ooo]ZoookJP0>oookJP03
ool00?oonf[ooo]Z00?ooo]Z00?oo`1joookJ_oonfX04OoonfX00omho`3ooo]ZoookJP0:oookJPWo
o`000ooonfX6ool000;o00002ooo000:oookJP03oonk0?oonf[ooo]Z01gooo]Z1ooo000BoookJPKo
o`004?oonfX:oolX00Oooo]Z00?oo`1?oookJ_oonfX03ooonfX7oolX00?o0=So00?oobP0oookJ_oo
nfX01ooonfX3oolX0;[ooo]Z00?o07[ooookJ_oonfX03?oonfX00ol0oeKoob/0oookJP0NoookJP03
oonD0?oonf[ooo]Z013ooo]Z00Ooo`1UoookJ_oonf[ooo]Zoom20?oonf[ofol000Cooo]Z00?oo`26
oookJ_oonfX03ooonfX00ol0oi?ooo]ZoookJP02oookJP03ool0N_oonf[ooo]Z017ooo]Z00?oN?l0
oookJ_oonfX02ooonfX01?l0TOoooo]ZoookJ_oo07@:oookJP03onSo0?oonf[o000000?o00000_oo
nfX01ooo00gooo]ZoookJ_oonf[ooj80oookJ_nT0?l03?oonfX00ooo^`3ooo]ZoookJP0OoookJP03
obko0?oonf[ooo]Z01?ooo]Z00?o0?meoookJ_oonfX06?oonfX00ooo02Gooo]ZoookJP0:oookJP03
ool0Cooonf[ooo]Z01?ooo]Z0ooVo`03o`3HofKooo]Z001SoookJPCoo`002OoonfX2ool00004oook
J_oo003ooo]Zool001gooo]Z00?oo`00oookJ_oonfX04OoonfX01ooo06Gooo]ZoookJ_oonf[ood80
oookJ_oo00001?oonfX00ooo003ooo]ZoookJP0>oookJP03ool00?oonf[ooo]Z00?ooo]Z00?oo`1j
oookJ_oonfX04_oonfX00omho`3ooo]ZoookJP09oookJPWoo`000_oonfXDool000Wooo]Z00?ook/0
oookJ_oonfX07ooonfX5ool001;ooo]Z00?oo`00oookJ_oonfX00ooo000BoookJPSoobP01_oonfX2
ool0C`kooo]Z2Ooo:002o`3Ho`?oobP02_oonfX00ooo:03ooo]ZoookJP0KoookJPWoobP0UooonfX0
0ol0N_oooo]ZoookJP0<oookJP03o`3oE_oo:`3ooo]Z01gooo]Z00?ooi@0oookJ_oonfX04?oonfX0
1ooo06Gooo]ZoookJ_oonf[ood80oookJ_oKo`001?oonfX00ooo08Kooo]ZoookJP0?oookJP03o`3o
Tooonf[ooo]Z00;ooo]Z00?oo`1joookJ_oonfX04_oonfX00omho`3ooo]ZoookJP0:oookJP04o`2A
oooonf[ooo]Zool0M0[ooo]Z00?oj?l0oookJ_l000000ol000000ooonf[oo`0=oookJP03oookJP03
oonR0?oonf[oY03o00_ooo]Z00?ook/0oookJ_oonfX07ooonfX00ol^o`3ooo]ZoookJP0CoookJP03
o`3oMOoonf[ooo]Z01Oooo]Z0_oo02D;oookJP;oo`1?4ooonfX3onKo0003oookJ_l0f?oo0=So06Wo
oo]Z001SoookJPGoo`002?oonfX01?oo003ooo]ZoookJ_oonfX2ool001kooo]Z00?oo`00oookJ_oo
nfX04OoonfX01_oo003ooo]ZoookJ_oonf[ood80ool000Cooo]Z0_oo000@oookJP03ool00?oonf[o
oo]Z00;ooo]Z00?oo`1joookJ_oonfX04_oonfX00omho`3ooo]ZoookJP09oookJP05ool00?oonf[o
oo]ZoookJ_oo00001_oonfXDool000Wooo]Z00?ook/0oookJ_oonfX07_oonfX00ooo003ooo]Zool0
0003ool001Kooo]Z00?oo`00oookJ_oonfX04?oonfX8oolX00Gooo]Z0_oo04l@oookJPKoobP00ol0
f?l3oolX02[ooo]Z4Ooo:009o`3o`XKooo]Z00?o07[ooookJ_oonfX03?oonfX00ol0oeKoob/0oook
JP0NoookJP03oonD0?oonf[ooo]Z013ooo]Z00Koo`1UoookJ_oonf[ooo]Zoom20?oKo`04oookJP03
ool0Q_oonf[ooo]Z013ooo]Z00Go0?nCoookJ_oonf[ooo]Zool0NP0DoookJP03ogSo0?oonf[ooo]Z
00[ooo]Z00Co097ooookJ_oonf[oo`1d2_oonfX00ooXo`3ooo]Zo`000003o`000003oookJ_oo00go
oo]Z00?ooo]Z00?ooj80oookJ_nT0?l02ooonfX00ooo^`3ooo]ZoookJP0NoookJP03obko0?oonf[o
oo]Z02cooo]Z0_oo02D;oookJP;oo`1?4_oonfX3onKo0004oookJ_l0f?oo0=Soo`3HocWooo]Z3_l0
ol8ToookJP00HooonfX6ool000_ooo]Z0ooo000MoookJP03ool00?oonf[ooo]Z017ooo]Z00Ooo`00
oookJ_oonf[ooo]Zoom20?oonf[oo`0000?ooo]Z0_oo000@oookJP03ool00?oonf[ooo]Z00?ooo]Z
00?oo`1joookJ_oonfX04OoonfX00omho`3ooo]ZoookJP0=oookJP03ool00?oonf[ooo]Z00Cooo]Z
5?oo0009oookJP03oonk0?oonf[ooo]Z027ooo]Z0ooo000XoookJP03oolX0?oonf[ooo]Z00GoobP0
1OoonfX00ooo04oooo]ZoookJP0=oookJPCoo`000ooo:002o`3Ho`GoobP0:ooonfX?oolX09;ooo]Z
00?o07[ooookJ_oonfX03?oonfX00ol0oeKoob/0oookJP0MoookJP03oonD0?oonf[ooo]Z013ooo]Z
00Ooo`1UoookJ_oonf[ooo]Zoom20?oonf[ofol000Cooo]Z00?oo`26oookJ_oonfX03ooonfX00ol0
oi?ooo]ZoookJP02oookJP03ool0N_oonf[ooo]Z017ooo]Z00?oN?l0oookJ_oonfX03OoonfX00ooo
07Cooo]ZoookJP07oookJP03onSo0?oonf[ooo]Z00Co000000?ooo]Zool03OoonfX00ooonfX00ooo
XP3ooo]Zoj@0o`0;oookJP03oonk0?oonf[ooo]Z04cooo]Z00?oo`0UoookJ_oonfX02_oonfX00ooo
04oooo]ZoookJP0@oookJP;oi_l00_oonfX2o`3HocOooo]Z1Ol0ol8boookJP00I?oonfX6ool000_o
oo]Z0ooo000LoookJP03ool00?oonf[ooo]Z017ooo]Z0_oo0002oookJP03oom20?oonf[ooo]Z00?o
oo]Z0ooo000EoookJP03ool0N_oonf[ooo]Z017ooo]Z00?oN?l0oookJ_oonfX03OoonfX00ooo003o
oo]ZoookJP03oookJQGoo`002?oonfX00ooo^`3ooo]ZoookJP0SoookJP03ool00?oonf[ooo]Z02Go
oo]Z00?oo`0UoolX0?oonfX00ooonfX3oolX00Cooo]Z0_oo04l;oookJPWoo`000ol0f?l5oolX02ko
oo]Z2ooo:02EoookJP03o`1joooonf[ooo]Z00cooo]Z00?o0?mFool[0?oonfX07OoonfX00oooU03o
oo]ZoookJP0@oookJP05ool0IOoonf[ooo]ZoookJ_oo@P001_oonfX00ooo08Kooo]ZoookJP0Doook
JP03ool0N_oonf[ooo]Z017ooo]Z00?oN?l0oookJ_oonfX03OoonfX00ooo07Cooo]ZoookJP07oook
JP03onSo0?oonf[ooo]Z00Co000000?ooo]Zool03OoonfX00_oonfX00oooXP3ooo]Zoj@0o`0;oook
JP03oonk0?oonf[ooo]Z04_ooo]Z0_oo02D;oookJP;oo`1?4OoonfX2onKo0004oookJ_l0f?oo0=So
o`3HocCooo]Z1Ol0ol8goookJP00I?oonfX7ool000[ooo]Z1?oo000LoookJP03ool00?oonf[ooo]Z
013ooo]Z0_oo0003oookJP03ool00?oonf[ooo]Z00;ooo]Z0ooo000EoookJP03ool00?oonf[ooo]Z
017ooo]Z00?oN?l0oookJ_oonfX05ooonfX01?oo003ooo]ZoookJ_l0000=ool000Sooo]Z00?ook/0
oookJ_oonfX0B_oonfX00ooo02Gooo]ZoookJP05oookJP04oolX0?oonf[ooo]ZoookJP;oo`1?2_oo
nfX:ool000;o0=So1ooo:00/oookJPcoobP0V?oonfX00ol0N_oooo]ZoookJP0<oookJP03o`3oE_oo
:`3ooo]Z01gooo]Z00?ooi@0oookJ_oonfX04?oonfX01Ooo06Gooo]ZoookJ_oonf[ood8000Gooo]Z
00?oo`26oookJ_oonfX05?oonfX00ooo07[ooo]ZoookJP0AoookJP03ogSo0?oonf[ooo]Z01Oooo]Z
00?oj?l0oookJ_oonfX01?l000000ooonf[oo`0=oookJP02oookJP03oonR0?oonf[oY03o00_ooo]Z
00?ook/0oookJ_oonfX0B_oonfX00ooo02Gooo]ZoookJP09oookJP;oo`1?4OoonfX2onKo0003oook
J_l0f?oo0=So03;ooo]Z1Ol0ol8loookJP00I?oonfX8ool000[ooo]Z0ooo000LoookJP03ool00?oo
nf[ooo]Z013ooo]Z0ooo0002oookJP03ool00?oonf[ooo]Z00;ooo]Z1?oo000DoookJP03ool00?oo
nf[ooo]Z017ooo]Z00?oN?l0oookJ_oonfX05ooonfX00ooo003ooo]ZoookJP0>ool000Sooo]Z00?o
ok/0oookJ_oonfX0BOoonfX00ooo02Gooo]ZoookJP09oookJP03ool0Cooonf[ooo]Z00[ooo]Z1ooo
0003o`3Ho`03oolX0?oonf[ooo]Z00GoobP0:?oonfX5oolX00?ooo]Z1ooo:02JoookJP03o`1joooo
nf[ooo]Z00cooo]Z00?o0?mFool[0?oonfX07OoonfX00oooU03ooo]ZoookJP0@oookJP05ool0IOoo
nf[ooo]ZoookJ_oo@P001OoonfX00ooo08Kooo]ZoookJP0DoookJP03ool0N_oonf[ooo]Z017ooo]Z
00?oN?l0oookJ_oonfX05ooonfX00ooXo`3ooo]ZoookJP04o`000003oookJ_oo00gooo]Z00;ooo]Z
00?ooj80oookJ_nT0?l02ooonfX00ooo^`3ooo]ZoookJP19oookJP03ool09Ooonf[ooo]Z00Wooo]Z
00?oo`1?oookJ_oonfX03ooonfX2onKo00?o0=So;ooonfX5o`3o`T7ooo]Z001UoookJPSoo`002Ooo
nfX4ool001cooo]Z00?oo`00oookJ_oonfX03ooonfX3ool000;ooo]Z0_oo0003oookJPGoo`004ooo
nfX2ool001;ooo]Z00?oN?l0oookJ_oonfX05ooonfX00ooo003ooo]ZoookJP03o`000003ool00?oo
nf[oo`0000Soo`001ooonfX00ooo^`3ooo]ZoookJP19oookJP03ool09Ooonf[ooo]Z00Sooo]Z0_oo
04l>oookJPKoo`0000?oobP0ool00?oo00000ooonfX3oolX02Gooo]Z0_l0ol83oolX00Wooo]Z0ooo
:02NoookJP03o`1joooonf[ooo]Z00cooo]Z00?o0?mFoookJ_oonfX07OoonfX00oooU03ooo]Zoook
JP0?oookJP05ool0IOoonf[ooo]ZoookJ_oo@P001_oonfX00ooo08Kooo]ZoookJP0CoookJP03ool0
N_oonf[ooo]Z017ooo]Z00?oN?l0oookJ_oonfX05ooonfX00ooXo`3ooo]ZoookJP04o`000003ool0
3Ooonf[ooo]Z00;ooo]Z00?ooj80oookJ_nT0?l02_oonfX00ooo^`3ooo]ZoookJP19oookJP03ool0
9Ooonf[ooo]Z00Sooo]Z0_oo04l@oookJP;oi_l00_l0f?l]oookJPGo0?o2A_oonfX006Gooo]Z2Ooo
0008oookJPGoo`00;OoonfX4ool00003oookJ_oo003oo`0000?ooo]Z1Ooo000CoookJP;oo`004_oo
nfX00omho`3ooo]ZoookJP0JoookJP?o000000?oo`00oookJ_oo00002?oo0007oookJP03ool00?oo
nf[ooo]Z04Sooo]Z00?oo`0UoookJ_oonfX01ooonfX2ool0013ooo]Z1ooo0006oookJP03oolX0?oo
nf[ooo]Z027ooo]Z0ol0ol8>oookJP03oolX0?oonf[ooo]Z09kooo]Z00?o07[ooookJ_oonfX03?oo
nfX00ol0oeKoob/0oookJP0`oookJP05ool0IOoonf[ooo]ZoookJ_oo@P001OoonfX00ooo08Kooo]Z
oookJP0CoookJP03ool0N_oonf[ooo]Z017ooo]Z00?oN?l0oookJ_oonfX06_oonfX4o`000003ool0
3Ooonf[ooo]Z00;ooo]Z00?ooj80oj@0oooonfX02_oonfX00ooo^`3ooo]ZoookJP18oookJP03ool0
9Ooonf[ooo]Z00Oooo]Z0_oo04l@oookJP;oi_l000?ooo]Zo`3HoooonfX0:ooonfX3o`3o`T_ooo]Z
001UoookJPOoo`002_oonfX6ool002cooo]Z2?oo0002oookJPKoo`004_oonfX2ool001;ooo]Z00?o
N?l0oookJ_oonfX06_oonfX3o`000003ool00?oonf[oo`0000Soo`001ooonfX00ooo003ooo]Zoook
JP17oookJP03ool09Ooonf[ooo]Z00Kooo]Z1?oo000>oookJPSoo`009ooonfX4o`3o`[?ooo]Z00?o
07[ooookJ_oonfX03?oonfX00ol0oeKooo]ZoookJP0_oookJP05ool0IOoonf[ooo]ZoookJ_oo@P00
1OoonfX00ooo08Kooo]ZoookJP0CoookJP03ool0N_oonf[ooo]Z017ooo]Z00?oN?l0oookJ_oonfX0
6_oonfX4o`000007ool03Ooonf[ooo]ZoookJ_ooXP3ooo]Zoj@0o`0;oookJP03oonk0?oonf[ooo]Z
04Oooo]Z00?oo`0UoookJ_oonfX01ooonfX00ooo04oooo]ZoookJP0>oookJP;oi_l000?ooo]Zo`3H
ool0f?l0:_oonfX3o`3o`Tkooo]Z001UoookJPGoo`003?oonfX6ool002cooo]Z2?oo0002oookJPKo
o`004OoonfX4ool0017ooo]Z00?oo`00oookJ_oonfX06_oonfX4o`0000[oo`001_oonfX2ool004So
oo]Z00?oo`0UoookJ_oonfX01OoonfX5ool000cooo]Z2_oo000UoookJP?o0?o2]ooonfX00ol0N_oo
oo]ZoookJP0<oookJP03o`3oE_oo:`3ooo]Z02oooo]Z00Goo`1UoookJ_oonf[ooo]Zoom20005oook
JP03ool0Q_oonf[ooo]Z01Cooo]Z00?oo`1joookJ_oonfX04?oonfX00omho`3ooo]ZoookJP0Joook
JPGo00000ooonfX00oooXP3ooo]Zoj@0o`0;oookJP03oonk0?oonf[ooo]Z04Gooo]Z0_oo02D9oook
JP03ool0Cooonf[ooo]Z00gooo]Z0_oVo`000ooonf[o0?Koo`3Ho`0XoookJPCo0?o2DOoonfX006Ko
oo]Z1?oo000<oookJPOoo`00:ooonfX9ool00003oookJ_oo003oo`0000Goo`004?oonfX4ool0017o
oo]Z00?oo`00oookJ_oonfX06_oonfX4o`0000?ooo]Z1ooo0006oookJP;oo`00AooonfX00ooo02Go
oo]ZoookJP04oookJPKoo`002_oonfX<ool002?ooo]Z0ol0ol:koookJP03o`1joooonf[ooo]Z00co
oo]Z00?o0?mFoookJ_oonfX0;ooonfX01?oo06Gooo]ZoookJ_oo@P06oookJP03ool0Q_oonf[ooo]Z
01?ooo]Z00?oo`1joookJ_oonfX04?oonfX00omho`3ooo]ZoookJP0JoookJPCo00001?oonfX00ooo
XP3ooo]Zoj@0o`0:oookJP03oonk0?oonf[ooo]Z04Gooo]Z00?oo`0UoookJ_oonfX02?oonfX00ooo
04oooo]ZoookJP0=oookJP03onKo0?oonf[ooo]Z00;o0=So9_oonfX3o`3o`UGooo]Z001VoookJP04
ool00?oonf[ooo]Zool000cooo]Z2?oo000ZoookJPWoo`0000?ooo]Zool00?oo00001Ooo000@oook
JPCoo`004OoonfX00ooo003ooo]ZoookJP0JoookJPCo00001?oonfX01?oo003ooo]Zool00?oo0007
oookJP?oo`00A_oonfX00ooo02Gooo]ZoookJP04oookJPOoo`002OoonfX<ool0023ooo]Z1?l0ol:n
oookJP03o`1joooonf[ooo]Z00cooo]Z00?o0?mFool[0?oonfX0;ooonfX01Ooo06Gooo]ZoookJ_oo
nf[ood8000Gooo]Z00?oo`26oookJ_oonfX04ooonfX00ooo07[ooo]ZoookJP0@oookJP03ogSo0?oo
nf[ooo]Z01[ooo]Z1?l00004oookJP03oonR0?oonf[oY03o00[ooo]Z00?ook/0oookJ_oonfX0A?oo
nfX00ooo02Gooo]ZoookJP08oookJP03ool0Cooonf[ooo]Z00oooo]Z00?o0?Koo`3HoooonfX09?oo
nfX3o`3o`USooo]Z001ZoookJP03ool00?oonf[ooo]Z00[ooo]Z2?oo000YoookJQ;oo`003ooonfX5
ool0013ooo]Z0_oo000KoookJPCo00000ooonfX00ooo003ooo]Zool00009oookJP?oo`00AOoonfX0
0ooo02Gooo]ZoookJP03oookJPSoo`002_oonfX:ool001oooo]Z0ol0ol;3oookJP03o`1joooonf[o
oo]Z00cooo]Z00?o0?mFoookJ_oonfX0;_oonfX01Ooo06Gooo]ZoookJ_oonf[ood8000Gooo]Z00?o
o`26oookJ_oonfX04ooonfX00ooo07[ooo]ZoookJP0@oookJP03ogSo0?oonf[ooo]Z01[ooo]Z1?l0
0004oookJP03oonR0?nT0?oooo]Z00[ooo]Z00?ook/0oookJ_oonfX0@ooonfX00ooo02Gooo]Zoook
JP08oookJP03ool0Cooonf[ooo]Z00kooo]Z00?o0?Koo`3Hool0f?l08ooonfX3o`3o`U_ooo]Z001[
oookJP03ool00?oonf[ooo]Z00Wooo]Z1_oo000[oookJPooo`004_oonfX5ool000oooo]Z0ooo000K
oookJPCo00000ooonfX00ooo003ooo]Zool00008oookJPCoo`00A?oonfX00ooo02Gooo]ZoookJP02
oookJPWoo`003?oonfX9ool001_ooo]Z0ooo00000ol0ol;ooo]ZoookJP34oookJP03o`1joooonf[o
oo]Z00cooo]Z00?o0?mFoookJ_oonfX0;_oonfX01Ooo06Gooo]ZoookJ_oonf[ood8000Gooo]Z00?o
o`26oookJ_oonfX04ooonfX00ooo07[ooo]ZoookJP0@oookJP03ogSo0?oonf[ooo]Z01[ooo]Z1?l0
0003oookJP03oonR0?oonf[oY03o00[ooo]Z00?ook/0oookJ_oonfX0@ooonfX00ooo02Gooo]Zoook
JP07oookJP;oo`1?4?oonfX00ol0m_oo0=SooookJP0QoookJP?o0?o2G_oonfX006_ooo]Z00?oo`00
oookJ_oonfX02OoonfX3ool00003oookJ_oo003ooo]Z02_ooo]Z3?oo00000ooonf[oo`00oookJP0B
oookJPGoo`003ooonfX3ool001_ooo]Z1?l00003oookJP03ool00?oonf[ooo]Z00Sooo]Z1?oo0013
oookJP03ool09Ooonf[ooo]Z00;ooo]Z2_oo000<oookJPSoo`006?oonfX5ool00<Wooo]Z00?o07[o
oookJ_oonfX03OoonfX00ol0oeKooo]ZoookJP0^oookJP04ool0IOoonf[ooo]Zoom200Gooo]Z00?o
o`26oookJ_oonfX04ooonfX00ooo07[ooo]ZoookJP0@oookJP03ogSo0?oonf[ooo]Z01[ooo]Z1?l0
0003oookJP03oonR0?oonf[ooo]Z00[ooo]Z00?ook/0oookJ_oonfX0@_oonfX00ooo02Gooo]Zoook
JP07oookJP03ool0Cooonf[ooo]Z00kooo]Z00?o0?Koo`3Hool0f?l08OoonfX2o`3o`V7ooo]Z001/
oookJP03ool00?oonf[ooo]Z00Sooo]Z00Goo`00oookJ_oonf[ooo]Zool0000/oookJP_oo`000ooo
nfX00ooo003ooo]ZoookJP0@oookJPKoo`003_oonfX3ool001_ooo]Z1?l0000=oookJPGoo`00@_oo
nfX00ooo02Gooo]ZoookJP04oookJPSoo`002ooonfX2o`3fo`Ooo`005_oonfX7ool00<_ooo]Z00?o
07[ooookJ_oonfX03?oonfX00ooo:`3ooo]ZoookJP0^oookJP05ool0IOoonf[ooo]ZoookJ_oo@P00
1OoonfX00ooo08Kooo]ZoookJP0BoookJP03ool0N_oonf[ooo]Z013ooo]Z00?oN?l0oookJ_oonfX0
6_oonfX4o`00013ooo]Z00?ook/0oookJ_oonfX0@OoonfX00ooo02Gooo]ZoookJP07oookJP03ool0
Cooonf[ooo]Z00gooo]Z0_l0m_l00ol0f?oooo]ZoookJP0OoookJP;o0?o2HooonfX006cooo]Z00?o
o`00oookJ_oonfX03OoonfX00ooo003ooo]ZoookJP0YoookJP;oo`000_oonfX8ool000;ooo]Z00?o
o`00oookJ_oonfX03ooonfX7ool000kooo]Z1?oo000JoookJPCo00003OoonfX5ool0043ooo]Z0_oo
0008oookJPKoo`002ooonfX00ol0m_ooo`00ool00002oookJPCoo`004ooonfX:ool00<cooo]Z00?o
07[ooookJ_oonfX03OoonfX00ooo:`3ooo]ZoookJP0]oookJP05ool0IOoonf[ooo]ZoookJ_oo@P00
1OoonfX00ooo08Kooo]ZoookJP0BoookJP03ool0N_oonf[ooo]Z013ooo]Z00?oN?l0oookJ_oonfX0
6_oonfX4o`0000oooo]Z00?ook/0oookJ_oonfX0@OoonfX00ooo02Gooo]ZoookJP07oookJP03ool0
Cooonf[ooo]Z00gooo]Z00?o0?Koo`3Hool0f?l08?oonfX2o`3o`VGooo]Z001]oookJP03ool00?oo
nf[ooo]Z00cooo]Z00?oo`00oookJ_oonfX0;OoonfX8ool000;ooo]Z00?oo`00oookJ_oonfX03ooo
nfX7ool000kooo]Z1?oo000JoookJPCo00003?oonfX6ool003oooo]Z0ooo0007oookJP03ool00?oo
nf[oo`0000Coo`002OoonfX3ool000Cooo]Z0ooo000BoookJP_oo`00c_oonfX00ol0N_oooo]Zoook
JP0<oookJP03ool[0?oonf[ooo]Z02kooo]Z00Coo`1UoookJ_oonf[ood801OoonfX00ooo08Kooo]Z
oookJP0CoookJP03ool0N_oonf[ooo]Z00oooo]Z00?oN?l0oookJ_oonfX06_oonfX4o`0000oooo]Z
00?ook/0oookJ_oonfX0@OoonfX00ooo02Gooo]ZoookJP06oookJP03ool0Cooonf[ooo]Z00cooo]Z
0_l0m_l00ol0f?oooo]ZoookJP0NoookJP;o0?o2IooonfX006gooo]Z00?oo`00oookJ_oonfX03Ooo
nfX00ooo003ooo]ZoookJP0/oookJPWoo`0000?ooo]Zool00?oonfX04?oonfX8ool000cooo]Z1Ooo
000JoookJPCo00003?oonfX6ool003kooo]Z0ooo0007oookJP04ool00?oonf[ooo]ZoookJP?oo`00
2?oonfX4ool000Kooo]Z00?oo`00oookJ_oonfX04OoonfX:ool00<oooo]Z00?o07[ooookJ_oonfX0
3OoonfX00ooo:`3ooo]ZoookJP0]oookJP05ool0IOoonf[ooo]ZoookJ_oo@P001?oonfX00ooo08Ko
oo]ZoookJP0CoookJP03ool0N_oonf[ooo]Z00oooo]Z00?oN?l0oookJ_oonfX06_oonfX4o`0000oo
oo]Z00?ook/0oookJ_oonfX0@?oonfX00ooo02Gooo]ZoookJP06oookJP03ool0Cooonf[ooo]Z00co
oo]Z00?o0?KooookJ_l0f?l07ooonfX2o`3o`VWooo]Z001^oookJP03ool00?oonf[ooo]Z00cooo]Z
00?oo`00oookJ_oonfX0;OoonfX5ool000Gooo]Z00?oo`00oookJ_oonfX03_oonfX5ool000oooo]Z
1_oo000IoookJPCo00002ooonfX7ool003cooo]Z1Ooo0006oookJP03ool00?oonf[ooo]Z00?ooo]Z
00?oo`00oookJ_oonfX01_oonfX4ool001cooo]Z2?oo003AoookJP03o`1joooonf[ooo]Z00cooo]Z
00?oob/0oookJ_oonfX0;OoonfX01Ooo06Gooo]ZoookJ_oonf[ood8000Gooo]Z00?oo`26oookJ_oo
nfX04_oonfX00ooo07[ooo]ZoookJP0?oookJP03ogSo0?oonf[ooo]Z01[ooo]Z1?l0000?oookJP03
oonk0?oonf[ooo]Z03oooo]Z00?oo`0UoookJ_oonfX01_oonfX00ooo04oooo]ZoookJP0<oookJP03
o`3foooonf[ooo]Z01oooo]Z00?o0?o2oookJ_oonfX0JOoonfX006kooo]Z00?oo`00oookJ_oonfX0
3?oonfX00ooo003ooo]ZoookJP0]oookJP;oo`0000?ooo]Zool00?oonfX01OoonfX00ooo003ooo]Z
oookJP0BoookJP03ool00?oonf[ooo]Z00gooo]Z1_oo000IoookJPCo00002ooonfX7ool003_ooo]Z
1Ooo0006oookJP03ool00?oonf[ooo]Z00_ooo]Z1Ooo000MoookJPOoo`00d_oonfX00ol0N_oooo]Z
oookJP0<oookJP03ool[0?oonf[ooo]Z02gooo]Z00Goo`1UoookJ_oonf[ooo]Zoom20005oookJP03
ool0Q_oonf[ooo]Z01;ooo]Z00?oo`1joookJ_oonfX03ooonfX00omho`3ooo]ZoookJP0JoookJPCo
00003_oonfX00ooo^`3ooo]ZoookJP0ooookJP03ool09Ooonf[ooo]Z00Kooo]Z00?oo`1?oookJ_oo
nfX03?oonfX00ol0m_oooo]ZoookJP0NoookJP;o0?o2K?oonfX006oooo]Z00?oo`00oookJ_oonfX0
3?oonfX00ooo003ooo]ZoookJP0/oookJP05ool00?oonf[ooo]ZoookJ_oo00001OoonfX00ooo003o
oo]ZoookJP0BoookJP03ool00?oonf[ooo]Z00gooo]Z1_oo000IoookJPCo00002_oonfX8ool003[o
oo]Z1_oo000BoookJPOoo`006ooonfX2ool00003oookJ_oo003oo`0000?oo`00e?oonfX00ol0N_oo
oo]ZoookJP0<oookJP03ool[0?oonf[ooo]Z02gooo]Z00Coo`1UoookJ_oonf[ood801OoonfX00ooo
08Kooo]ZoookJP0BoookJP03ool0N_oonf[ooo]Z00oooo]Z00?oN?l0oookJ_oonfX06_oonfX4o`00
00kooo]Z00?ook/0oookJ_oonfX0?_oonfX00ooo02Gooo]ZoookJP0EoookJP03o`3foooonf[ooo]Z
01gooo]Z0_l0ol9^oookJP00KooonfX00ooo003ooo]ZoookJP0<oookJP03ool00?oonf[ooo]Z02co
oo]Z00Goo`00oookJ_oonf[ooo]Zool00005oookJP03ool00?oonf[ooo]Z01;ooo]Z00?oo`00oook
J_oonfX03OoonfX6ool001Wooo]Z1?l0000=oookJPGoo`00>?oonfX8ool0013ooo]Z2?oo000Joook
JP;oo`001?oonfX3ool00=Gooo]Z00?o07[ooookJ_oonfX03?oonfX00ooo:`3ooo]ZoookJP0]oook
JP05ool0IOoonf[ooo]ZoookJ_oo@P001?oonfX00ooo08Kooo]ZoookJP0BoookJP03ool0N_oonf[o
oo]Z013ooo]Z00?oN?l0oookJ_oonfX06OoonfX4o`0000kooo]Z00?ook/0oookJ_oonfX0?_oonfX0
0ooo02Gooo]ZoookJP0DoookJP03o`3foooonf[ooo]Z01cooo]Z0_l0ol9`oookJP00L?oonfX00ooo
003ooo]ZoookJP0<oookJP03ool00?oonf[ooo]Z02cooo]Z00Coo`00oookJ_oonf[oo`001_oonfX0
0ooo003ooo]ZoookJP0AoookJP03ool00?oonf[ooo]Z00cooo]Z2?oo000HoookJPGo00003?oonfX0
0ooo003ooo]ZoookJP02ool003Oooo]Z2?oo000@oookJPWoo`006?oonfX2ool000Oooo]Z00?oo`00
oookJ_oonfX0eOoonfX00ol0N_oooo]ZoookJP0<oookJP03ool[0?oonf[ooo]Z02cooo]Z00Goo`1U
oookJ_oonf[ooo]Zoom20005oookJP03ool0Q_oonf[ooo]Z017ooo]Z00?oo`1joookJ_oonfX04?oo
nfX00omho`3ooo]ZoookJP0IoookJPGo00003?oonfX00ooo^`3ooo]ZoookJP0noookJP03ool09Ooo
nf[ooo]Z01Cooo]Z00?o0?KooookJ_oonfX06ooonfX2o`3o`W;ooo]Z001`oookJP03ool00?oonf[o
oo]Z00cooo]Z00?oo`00oookJ_oonfX0;?oonfX01?oo003ooo]ZoookJ_oo0006oookJP03ool00?oo
nf[ooo]Z017ooo]Z00?oo`00oookJ_oonfX03?oonfX8ool001Sooo]Z1?l0000=oookJP03ool00?oo
nf[ooo]Z03Sooo]Z2Ooo000>oookJP[oo`006?oonfX00ooo003ooo]ZoookJP3OoookJP03o`1joooo
nf[ooo]Z00cooo]Z00?oob/0oookJ_oonfX0;OoonfX01?oo06Gooo]ZoookJ_oo@P05oookJP03ool0
Q_oonf[ooo]Z017ooo]Z00?oo`1joookJ_oonfX04?oonfX00omho`3ooo]ZoookJP0IoookJPCo0000
3OoonfX00ooo^`3ooo]ZoookJP0moookJP03ool09Ooonf[ooo]Z01Cooo]Z00?o0?KooookJ_oonfX0
6ooonfX00ol0ol;ooo]ZoookJP1boookJP00LOoonfX00ooo003ooo]ZoookJP0<oookJP03ool00?oo
nf[ooo]Z02_ooo]Z00Goo`00oookJ_oonf[ooo]Zool0000JoookJP03ool00?oonf[ooo]Z00_ooo]Z
1Ooo000KoookJPCo00003OoonfX00ooo003ooo]ZoookJP0goookJPWoo`003_oonfX:ool00?cooo]Z
00?o07[ooookJ_oonfX03?oonfX00ooo:`3ooo]ZoookJP0/oookJP04ool0IOoonf[ooo]Zoom201[o
oo]Z00?oo`1joookJ_oonfX03ooonfX00omho`3ooo]ZoookJP0IoookJPCo00003OoonfX00ooo^`3o
oo]ZoookJP0loookJP03ool09Ooonf[ooo]Z01Cooo]Z00?o0?KooookJ_oonfX0TOoonfX0077ooo]Z
00?oo`00oookJ_oonfX03?oonfX00ooo003ooo]ZoookJP0[oookJP05ool00?oonf[ooo]ZoookJ_oo
00006_oonfX00ooo003ooo]ZoookJP0?oookJP03ool00?oonf[ooo]Z01Wooo]Z1?l0000<oookJP03
ool00?oonf[ooo]Z03[ooo]Z1ooo000@oookJPSoo`00o?oonfX00ol0N_oooo]ZoookJP0<oookJP03
ool[0?oonf[ooo]Z02cooo]Z00Goo`1UoookJ_oonf[ooo]Zoom2000IoookJP03ool0N_oonf[ooo]Z
00oooo]Z00?oN?l0oookJ_oonfX06OoonfX4o`0000cooo]Z00?ook/0oookJ_oonfX0??oonfX00ooo
02Gooo]ZoookJP0DoookJP03o`3foooonf[ooo]Z09;ooo]Z001boookJP03ool00?oonf[ooo]Z00_o
oo]Z00?oo`00oookJ_oonfX0;?oonfX01?oo003ooo]ZoookJ_oo000JoookJP03ool00?oonf[ooo]Z
00oooo]Z00?oo`00oookJ_oonfX06OoonfX4o`0000cooo]Z00?oo`00oookJ_oonfX0>ooonfX5ool0
01;ooo]Z1_oo003noookJP03o`1joooonf[ooo]Z00_ooo]Z00?oob/0oookJ_oonfX0;OoonfX01?oo
06Gooo]ZoookJ_oo@P0IoookJP03ool0N_oonf[ooo]Z00oooo]Z00?oN?l0oookJ_oonfX06OoonfX4
o`0000cooo]Z00?ook/0oookJ_oonfX0>ooonfX00ooo02Gooo]ZoookJP0DoookJP03o`3foooonf[o
oo]Z09?ooo]Z0021oookJP03ool00?oonf[ooo]Z02_ooo]Z00Coo`00oookJ_oonf[oo`006_oonfX0
0ooo003ooo]ZoookJP0?oookJP03ool00?oonf[ooo]Z01Wooo]Z1?l0001:oookJPGoo`004OoonfX0
0ooo003ooo]Zool00004ool00?oooo]Z3_oonfX00ooo:`3ooo]ZoookJP0/oookJP04ool0IOoonf[o
oo]Zoom201Wooo]Z00?oo`1joookJ_oonfX03ooonfX00omho`3ooo]ZoookJP0IoookJPCo0000B_oo
nfX00ooo02Gooo]ZoookJP0CoookJP03o`3foooonf[ooo]Z09Cooo]Z0021oookJP03ool00?oonf[o
oo]Z02kooo]Z00?oo`00oookJ_oonfX0:_oonfX00ooo003ooo]ZoookJP0IoookJPCo0000BOoonfX0
0ooo003ooo]ZoookJP03ool0013ooo]Z00Coo`00oookJ_oonf[ooo]Z0ooo003ooookJPoooo]Z00?o
ob/0oookJ_oonfX0;ooonfX00ooo@P3ooo]ZoookJP0YoookJP03ogSo0?oonf[ooo]Z01Wooo]Z1?l0
0019oookJP03ool09Ooonf[ooo]Z01?ooo]Z00?o0?KooookJ_oonfX0UOoonfX008;ooo]Z00?oo`00
oookJ_oonfX0;_oonfX00ooo003ooo]ZoookJP0YoookJP03ool00?oonf[ooo]Z01Wooo]Z1?l00018
oookJP03ool00?oonf[ooo]Z00;ooo]Z00?oo`00oookJ_oonfX03_oonfX00ooo003ooo]ZoookJP03
oookJP03ool00?oonf[ooo]Z0?oooo]Z3ooonfX00ooo:`3ooo]ZoookJP0_oookJP03oom20?oonf[o
oo]Z02Sooo]Z00?oN?l0oookJ_oonfX06OoonfX4o`0004Sooo]Z00?oo`0UoookJ_oonfX04ooonfX0
0ol0m_oooo]ZoookJP2FoookJP00/ooonfX00ooo003ooo]ZoookJP0YoookJP03ool00?oonf[ooo]Z
01Wooo]Z1?l00017oookJP03ool00?oonf[ooo]Z01?ooo]Z00?oo`00oookJ_oonfX0oooonfY8oook
JP03oom20?oonf[ooo]Z02Sooo]Z00?oN?l0oookJ_oonfX06OoonfX4o`0004Oooo]Z00?oo`0Uoook
J_oonfX04ooonfX00ol0m_oooo]ZoookJP2GoookJP00gooonfX00ooo003ooo]ZoookJP0IoookJPCo
0000A_oonfX00ooo003ooo]ZoookJP0CoookJP03ool00?oonf[ooo]Z0?oooo]ZM?oonfX00omho`3o
oo]ZoookJP0IoookJPCo0000A_oonfX00ooo02Gooo]ZoookJP0CoookJP03o`3foooonf[ooo]Z09So
oo]Z003OoookJP03ool00?oonf[ooo]Z00Cooo]Z0ol007l5oookJPGo001o2?oonfX4o`000?oooo]Z
dooonfX00omho`3ooo]ZoookJP04oookJP?o001o1OoonfX5o`00O`Sooo]Z1?l0003goookJP00gooo
nfX00ooo003ooo]ZoookJP04oookJP?o001o1?oonfX7o`00O`Oooo]Z1?l0003ooookJ]?ooo]Z00?o
N?l0oookJ_oonfX01?oonfX3o`00O`Cooo]Z1ol007l7oookJPCo0000mooonfX00>Kooo]Z0ol007l4
oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`000?oooo]Zf_oonfX3o`00O`Cooo]Z0ol0
07l01?oonf[o001oo`00Ool007l7oookJPCo0000mooonfX00>Kooo]Z0ol007l3oookJP?o001o0ooo
nfX3o`00O`Kooo]Z1?l0003ooookJ][ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0
003goookJP00i_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX6o`000?oooo]Zf?oonfX3
o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX6o`000?Gooo]Z003VoookJP?o001o0ooonfX3o`00
O`?ooo]Z0ol007l6oookJPCo0000oooonf[JoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oook
JPCo0000mooonfX00>Kooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0003ooookJ][o
oo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0003goookJP00i_oonfX3o`00O`?ooo]Z
0ol007l3oookJP?o001o1_oonfX4o`000?oooo]Zf_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o
1_oonfX4o`000?Oooo]Z003VoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000oooo
nf[JoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000mooonfX00>?ooo]Z1_l007l3
oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0003ooookJ]Oooo]Z1_l007l3oookJP?o001o0ooonfX3
o`00O`Kooo]Z1?l0003goookJP00hooonfX6o`00O`Cooo]Z0ol007l01?oonf[o001oo`00Ool007l7
oookJPCo0000oooonf[GoookJPKo001o1?oonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l0
003goookJP00iOoonfX4o`00O`Cooo]Z1ol007l7oookJPCo0000oooonf[IoookJPCo001o1?oonfX7
o`00O`Oooo]Z1?l0003goookJP00i_oonfX3o`00O`Gooo]Z1Ol007l8oookJPCo0000oooonf[Joook
JP?o001o1OoonfX5o`00O`Sooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oo
oo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0
003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oook
JPCo0000mooonfX00?_ooo]Z1Ol0003ooookJ^kooo]Z1Ol0003foookJP00nooonfX4o`000?oooo]Z
kooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003o
oookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo
0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooo
nfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX0
0?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oo
oo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0
003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPGo0000oooonf[^oook
JPGo0000m_oonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]Z
kooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003o
oookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo
0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooo
nfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX0
0?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oo
oo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0
003goookJP00nooonfX5o`000?oooo]Zk_oonfX5o`000?Kooo]Z003koookJPCo0000oooonf[_oook
JPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]Z
kooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003o
oookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo
0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooo
nfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX0
0?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oo
oo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1Ol0003ooookJ^kooo]Z1Ol0
003foookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oook
JPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]Z
kooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003o
oookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo
0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooo
nfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003VoookJP?o001o1OoonfX5o`00O`Sooo]Z1?l0003o
oookJ][ooo]Z0ol007l5oookJPGo001o2?oonfX4o`000?Oooo]Z003VoookJP?o001o1?oonfX7o`00
O`Oooo]Z1?l0003ooookJ][ooo]Z0ol007l4oookJPOo001o1ooonfX4o`000?Oooo]Z003VoookJP?o
001o0ooonfX4o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l0003ooookJ][ooo]Z0ol007l3oook
JPCo001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`000?Oooo]Z003VoookJP?o001o0ooonfX3o`00
O`?ooo]Z0ol007l6oookJPCo0000oooonf[JoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oook
JPCo0000mooonfX00>Kooo]Z0ol007l9oookJP?o001o1_oonfX6o`000?oooo]Zf?oonfX3o`00O`Wo
oo]Z0ol007l6oookJPKo0000mOoonfX00>Kooo]Z0ol007l9oookJP?o001o1_oonfX4o`000?oooo]Z
f_oonfX3o`00O`Wooo]Z0ol007l6oookJPCo0000mooonfX00>Kooo]Z0ol007l4oookJP;o001o0_oo
nfX4o`00O`Kooo]Z1?l0003ooookJ][ooo]Z0ol007l4oookJP;o001o0_oonfX4o`00O`Kooo]Z1?l0
003goookJP00i_oonfX3o`00O`Cooo]Z1ol007oooookJ^Gooo]Z0ol007l4oookJPOo001ooooonfX3
oookJP00i_oonfX3o`00O`Cooo]Z1_l007oooookJ^Kooo]Z0ol007l4oookJPKo001ooooonfX4oook
JP00hooonfX6o`00O`Cooo]Z0_l007oooookJ^Oooo]Z1_l007l4oookJP;o001ooooonfX8oookJP00
hooonfX6o`00O`Cooo]Z0_l007oooookJ^Oooo]Z1_l007l4oookJP;o001ooooonfX8oookJP00iOoo
nfX4o`00O`Gooo]Z1ol007oooookJ^?ooo]Z1?l007l5oookJPOo001ooooonfX2oookJP00i_oonfX3
o`00O`Gooo]Z1ol007oooookJ^Cooo]Z0ol007l5oookJPOo001ooooonfX2oookJP00oooonf[ooook
J_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooo
nf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oook
JP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooo
nf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oo
oo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003o
oookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_o
oo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[o
oookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Z
oooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX0
0?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]Z
jooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00\
\>"],
  ImageRangeCache->{{{0, 999}, {999, 0}} -> {-0.0500105, -0.0500105, \
0.00210213, 0.00210213}, {{23.75, 476.812}, {975.188, 522.125}} -> {-71.9892, \
-71.0885, 0.283964, 0.283964}, {{522.125, 975.188}, {975.188, 522.125}} -> \
{-213.51, -71.0885, 0.283964, 0.283964}, {{23.75, 476.812}, {476.812, 23.75}} -> \
{-17.9973, -53.1523, 0.070991, 0.070991}, {{522.125, 975.188}, {476.812, \
23.75}} -> {-53.3774, -53.1523, 0.070991, 0.070991}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
In this next example, the eigenvalues are complex, with a positive \
real part, and the system of equations has an unstable circulation pattern. \
The eigenvectors are complex and and there are no directions along which the \
system will evolve along a straight trajectory.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CritPointPlotPointsMany[\(-0.25\), \(-2.0\), 3, 1.5]\)], "Input",
  CellTags->"mmtag:25:fixed_point__unstable_focus_node_visualization"],

Cell[BoxData[
    \("Unstable"\)], "Print"],

Cell[BoxData[
    \("Circulation"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Eigenvalues = \
"\[InvisibleSpace]\(\(\(0.6250000000000001`\)\(\[InvisibleSpace]\)\) + 
          2.287875652215391`\ \[ImaginaryI]\)\[InvisibleSpace]" and "\
\[InvisibleSpace]\(\(\(0.6250000000000001`\)\(\[InvisibleSpace]\)\) - 
          2.287875652215391`\ \[ImaginaryI]\)\),
      SequenceForm[ "Eigenvalues = ", 
        Complex[ 0.62500000000000011, 2.2878756522153911], " and ", 
        Complex[ 0.62500000000000011, -2.2878756522153911]],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{\(\(0.6250000000000001`\)\(\[InvisibleSpace]\)\) + 
          2.287875652215391`\ \[ImaginaryI], \(\(0.6250000000000001`\)\(\
\[InvisibleSpace]\)\) - 
          2.287875652215391`\ \[ImaginaryI]}, {{\(-0.22592402852876603`\) + 
            0.590726953281576`\ \[ImaginaryI], \(\(0.7745966692414834`\)\(\
\[InvisibleSpace]\)\) + 0.`\ \[ImaginaryI]}, {\(-0.22592402852876603`\) - 
            0.590726953281576`\ \[ImaginaryI], \(\(0.7745966692414834`\)\(\
\[InvisibleSpace]\)\) + 0.`\ \[ImaginaryI]}}}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 1000 1000 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto fill
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto
-15. 3.75 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00833333 0.5 0.00833333 [
[0 .4875 -18.4688 -20 ]
[0 .4875 18.4688 0 ]
[.16667 .4875 -18.4688 -20 ]
[.16667 .4875 18.4688 0 ]
[.33333 .4875 -18.4688 -20 ]
[.33333 .4875 18.4688 0 ]
[.66667 .4875 -12 -20 ]
[.66667 .4875 12 0 ]
[.83333 .4875 -12 -20 ]
[.83333 .4875 12 0 ]
[1 .4875 -12 -20 ]
[1 .4875 12 0 ]
[.4875 0 -36.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .16667 -36.9375 -10 ]
[.4875 .16667 0 10 ]
[.4875 .33333 -36.9375 -10 ]
[.4875 .33333 0 10 ]
[.4875 .66667 -24 -10 ]
[.4875 .66667 0 10 ]
[.4875 .83333 -24 -10 ]
[.4875 .83333 0 10 ]
[.4875 1 -24 -10 ]
[.4875 1 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.16667 .5 m
.16667 .50625 L
s
gsave
.16667 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.33333 .5 m
.33333 .50625 L
s
gsave
.33333 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.66667 .5 m
.66667 .50625 L
s
gsave
.66667 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.83333 .5 m
.83333 .50625 L
s
gsave
.83333 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 .5 m
.04167 .50375 L
s
.08333 .5 m
.08333 .50375 L
s
.125 .5 m
.125 .50375 L
s
.20833 .5 m
.20833 .50375 L
s
.25 .5 m
.25 .50375 L
s
.29167 .5 m
.29167 .50375 L
s
.375 .5 m
.375 .50375 L
s
.41667 .5 m
.41667 .50375 L
s
.45833 .5 m
.45833 .50375 L
s
.54167 .5 m
.54167 .50375 L
s
.58333 .5 m
.58333 .50375 L
s
.625 .5 m
.625 .50375 L
s
.70833 .5 m
.70833 .50375 L
s
.75 .5 m
.75 .50375 L
s
.79167 .5 m
.79167 .50375 L
s
.875 .5 m
.875 .50375 L
s
.91667 .5 m
.91667 .50375 L
s
.95833 .5 m
.95833 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.5 .16667 m
.50625 .16667 L
s
gsave
.4875 .16667 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.5 .33333 m
.50625 .33333 L
s
gsave
.4875 .33333 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.5 .66667 m
.50625 .66667 L
s
gsave
.4875 .66667 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.5 .83333 m
.50625 .83333 L
s
gsave
.4875 .83333 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .04167 m
.50375 .04167 L
s
.5 .08333 m
.50375 .08333 L
s
.5 .125 m
.50375 .125 L
s
.5 .20833 m
.50375 .20833 L
s
.5 .25 m
.50375 .25 L
s
.5 .29167 m
.50375 .29167 L
s
.5 .375 m
.50375 .375 L
s
.5 .41667 m
.50375 .41667 L
s
.5 .45833 m
.50375 .45833 L
s
.5 .54167 m
.50375 .54167 L
s
.5 .58333 m
.50375 .58333 L
s
.5 .625 m
.50375 .625 L
s
.5 .70833 m
.50375 .70833 L
s
.5 .75 m
.50375 .75 L
s
.5 .79167 m
.50375 .79167 L
s
.5 .875 m
.50375 .875 L
s
.5 .91667 m
.50375 .91667 L
s
.5 .95833 m
.50375 .95833 L
s
.01 w
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 .176 r
.5 Mabswid
.49574 .54078 m
.48737 .5447 L
.47864 .54647 L
.47002 .54571 L
.46204 .54212 L
.45526 .53554 L
.45025 .52596 L
.44753 .51356 L
.44759 .4987 L
.45077 .48194 L
.45732 .46403 L
.46729 .44587 L
.48053 .42853 L
.49669 .41314 L
.51521 .40088 L
.53528 .3929 L
.55593 .39024 L
.57598 .39378 L
.59418 .40412 L
.60918 .42155 L
.61967 .44599 L
.62442 .4769 L
.62238 .51331 L
.61277 .55376 L
.59515 .5964 L
.56952 .63897 L
.53633 .67892 L
.49655 .71351 L
.45168 .73998 L
.40372 .75566 L
.35511 .75818 L
.30867 .74565 L
.26746 .71679 L
.23464 .67116 L
.21326 .60925 L
.20614 .53258 L
.2156 .44376 L
.24327 .34646 L
.28995 .24537 L
.35536 .146 L
.43811 .05452 L
s
.43811 .05452 m
.50702 0 L
s
1 0 0 r
.49574 .54078 m
.48737 .5447 L
s
% Start of user PostScript
-0.5111575 4.8939437 -1.5155983 5.3638799 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47864 .54647 m
.47002 .54571 L
s
% Start of user PostScript
-2.5633938 5.5765042 -3.5978297 5.4848756 MAarrowhead1
% End of user PostScript
1 .473 0 r
.45732 .46403 m
.46729 .44587 L
s
% Start of user PostScript
-5.1214098 -4.3169147 -3.9257085 -6.4954627 MAarrowhead1
% End of user PostScript
1 .788 0 r
.59418 .40412 m
.60918 .42155 L
s
% Start of user PostScript
11.301397 -11.505846 13.101568 -9.4134428 MAarrowhead1
% End of user PostScript
.897 1 0 r
.53633 .67892 m
.49655 .71351 L
s
% Start of user PostScript
4.3590036 21.470013 -0.41442556 25.621479 MAarrowhead1
% End of user PostScript
.581 1 0 r
.21326 .60925 m
.20614 .53258 L
s
% Start of user PostScript
-34.408657 13.109747 -35.263098 3.9093321 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
17.265138 -69.454074 30.96363 -72.954196 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
78.923906 23.13107 69.655833 51.101944 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-113.71126 169.22389 -143.10565 155.07126 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-118.3231 -206.06189 -68.258448 -270.11967 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
409.21578 -285.64344 446.75688 -192.9715 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-24.613523 801.8253 -192.46794 897.54005 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1091.5376 98.012278 -1051.5585 -234.88311 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
990.48737 -2262.5181 1412.9356 -2241.0255 MAarrowhead1
% End of user PostScript
.25 1 0 r
.52952 .56822 m
.51348 .58638 L
.4945 .60179 L
.47332 .61319 L
.45092 .61936 L
.42845 .61923 L
.40727 .61197 L
.38879 .59707 L
.37449 .57439 L
.36576 .54426 L
.36388 .50748 L
.36987 .46535 L
.38441 .41968 L
.40779 .37273 L
.43977 .3271 L
.47961 .28572 L
.52597 .2516 L
.57695 .22776 L
.63013 .21697 L
.68263 .22163 L
.73122 .24351 L
.7725 .2836 L
.80303 .34193 L
.81955 .41746 L
.81921 .50796 L
.79979 .61004 L
.7599 .71915 L
.69921 .82972 L
.61855 .93534 L
s
.61855 .93534 m
.55062 1 L
s
1 0 0 r
.52952 .56822 m
.51348 .58638 L
s
% Start of user PostScript
3.5419708 8.1869099 1.6173012 10.365028 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4945 .60179 m
.47332 .61319 L
s
% Start of user PostScript
-0.66008554 12.215026 -3.2013375 13.582885 MAarrowhead1
% End of user PostScript
1 .473 0 r
.36388 .50748 m
.36987 .46535 L
s
% Start of user PostScript
-16.334119 0.8973532 -15.615703 -4.1576948 MAarrowhead1
% End of user PostScript
1 .788 0 r
.63013 .21697 m
.68263 .22163 L
s
% Start of user PostScript
15.615059 -33.963158 21.915026 -33.404167 MAarrowhead1
% End of user PostScript
.897 1 0 r
.7599 .71915 m
.69921 .82972 L
s
% Start of user PostScript
31.188396 26.29793 23.904959 39.565997 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-68.835516 70.070012 -79.79788 57.324029 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-26.535171 -130.77341 2.53883 -156.05501 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
209.56649 -79.818959 214.76495 -23.780302 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-105.19007 423.01606 -188.61996 444.3227 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-480.65649 -140.95543 -424.19498 -311.31245 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
692.63331 -1030.6105 871.64558 -944.38404 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
720.50317 1255.1853 415.5575 1645.305 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2492.4107 1739.4419 -2720.9933 1174.9628 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
150.36854 -4883.7384 1172.7071 -5466.5721 MAarrowhead1
% End of user PostScript
0 .534 1 r
.4653 .5341 m
.46003 .52752 L
.45645 .51842 L
.45498 .50701 L
.456 .49366 L
.45979 .47891 L
.46647 .46346 L
.47605 .44813 L
.48832 .43385 L
.50293 .42162 L
.51931 .41243 L
.53672 .40724 L
.55426 .40689 L
.57089 .41204 L
.58552 .42313 L
.59699 .44028 L
.6042 .46327 L
.60616 .49152 L
.60205 .52403 L
.59131 .55944 L
.57369 .59602 L
.54933 .63174 L
.51878 .66436 L
.48305 .69153 L
.44357 .71088 L
.4022 .72024 L
.36116 .71771 L
.32292 .70187 L
.29016 .67187 L
.26555 .62763 L
.25165 .56988 L
.2507 .50028 L
.2645 .4214 L
.29418 .3367 L
.34008 .25046 L
.40163 .16762 L
.47725 .09357 L
.56428 .03391 L
s
.56428 .03391 m
.64501 0 L
s
.86538 0 m
.94 .03949 L
s
.94 .03949 m
1 .10536 L
s
1 .83989 m
.9602 .93995 L
s
.9602 .93995 m
.92507 1 L
s
1 0 0 r
.4653 .5341 m
.46003 .52752 L
s
% Start of user PostScript
-4.1638503 4.0921155 -4.796063 3.302213 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45645 .51842 m
.45498 .50701 L
s
% Start of user PostScript
-5.2264331 2.2102037 -5.40242 0.84098612 MAarrowhead1
% End of user PostScript
1 .473 0 r
.51931 .41243 m
.53672 .40724 L
s
% Start of user PostScript
2.3174879 -10.508783 4.4065302 -11.131702 MAarrowhead1
% End of user PostScript
1 .788 0 r
.60205 .52403 m
.59131 .55944 L
s
% Start of user PostScript
12.246026 2.8838219 10.95681 7.132811 MAarrowhead1
% End of user PostScript
.897 1 0 r
.36116 .71771 m
.32292 .70187 L
s
% Start of user PostScript
-16.661295 26.12575 -21.249058 24.22383 MAarrowhead1
% End of user PostScript
.581 1 0 r
.34008 .25046 m
.40163 .16762 L
s
% Start of user PostScript
-19.190557 -29.944777 -11.804268 -39.885459 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
61.527768 -45.680027 67.748854 -32.098982 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
0.10495715 120.04951 -25.236895 135.57978 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-167.33862 22.593902 -162.80683 -27.463806 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
141.30464 -345.44573 206.35646 -345.30614 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
335.31168 230.87482 267.9508 366.82766 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-667.82253 743.66914 -787.65577 628.25613 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-346.40809 -1256.8223 -61.907952 -1528.7263 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2108.4355 -958.06936 2193.4524 -414.27867 MAarrowhead1
% End of user PostScript
0 .366 1 r
.57112 .55248 m
.55609 .58177 L
.53571 .61008 L
.5105 .63559 L
.4813 .65642 L
.44932 .67069 L
.41612 .67669 L
.38349 .67294 L
.35347 .65838 L
.32819 .63244 L
.30978 .59514 L
.30028 .54721 L
.30141 .49007 L
.31455 .42593 L
.34049 .35765 L
.37939 .28878 L
.43067 .22334 L
.49291 .16567 L
.56387 .12027 L
.64046 .09147 L
.71887 .0832 L
.79467 .09868 L
.86299 .14016 L
.91876 .20862 L
.95698 .30357 L
.97304 .42288 L
.96302 .56268 L
.92406 .71735 L
.85462 .87965 L
s
.85462 .87965 m
.78012 1 L
s
1 0 0 r
.57112 .55248 m
.55609 .58177 L
s
% Start of user PostScript
8.5339202 6.297614 6.7305428 9.8121453 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53571 .61008 m
.5105 .63559 L
s
% Start of user PostScript
4.2856622 13.209469 1.2596675 16.271373 MAarrowhead1
% End of user PostScript
1 .473 0 r
.30978 .59514 m
.30028 .54721 L
s
% Start of user PostScript
-22.825905 11.416915 -23.966812 5.6647221 MAarrowhead1
% End of user PostScript
1 .788 0 r
.56387 .12027 m
.64046 .09147 L
s
% Start of user PostScript
7.6640064 -45.567233 16.854867 -49.023259 MAarrowhead1
% End of user PostScript
.897 1 0 r
.96302 .56268 m
.92406 .71735 L
s
% Start of user PostScript
55.56251 7.521333 50.88717 26.081656 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-67.845941 117.50057 -88.873352 111.19061 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-93.628189 -119.86566 -63.127409 -164.97881 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
263.64585 -217.97793 294.99671 -162.65417 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
31.429588 510.26595 -78.006974 586.0852 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-743.25719 160.775 -735.88028 -53.763415 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
543.45647 -1523.0829 834.69407 -1547.654 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1560.5486 851.69182 1294.0717 1455.658 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2797.6922 3419.5281 -3363.8844 2975.2863 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1874.8044 -5208.4979 -671.37379 -6474.3626 MAarrowhead1
% End of user PostScript
0 .092 1 r
.41926 .51003 m
.42163 .48576 L
.42899 .45911 L
.44157 .43135 L
.4593 .40399 L
.48182 .37872 L
.50843 .35731 L
.53808 .34156 L
.5694 .33316 L
.60076 .33359 L
.63028 .344 L
.65596 .36511 L
.67576 .39706 L
.68772 .43942 L
.69007 .49102 L
.6814 .55003 L
.66076 .61392 L
.62778 .67951 L
.5828 .74314 L
.52688 .80074 L
.46192 .84807 L
.39057 .88094 L
.31626 .89548 L
.24301 .88836 L
.17533 .85714 L
.118 .80046 L
.07582 .71832 L
.05332 .61222 L
.05446 .4853 L
.08232 .34235 L
.13881 .18978 L
.22435 .03539 L
s
.22435 .03539 m
.2516 0 L
s
1 0 0 r
.41926 .51003 m
.42163 .48576 L
s
% Start of user PostScript
-9.6891134 1.2031654 -9.4045467 -1.7087986 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42899 .45911 m
.44157 .43135 L
s
% Start of user PostScript
-8.5212358 -4.9065792 -7.0121363 -8.237528 MAarrowhead1
% End of user PostScript
1 .473 0 r
.63028 .344 m
.65596 .36511 L
s
% Start of user PostScript
15.633148 -18.719738 18.71504 -16.187266 MAarrowhead1
% End of user PostScript
1 .788 0 r
.5828 .74314 m
.52688 .80074 L
s
% Start of user PostScript
9.9354717 29.176765 3.2256374 36.088427 MAarrowhead1
% End of user PostScript
.897 1 0 r
.07582 .71832 m
.05332 .61222 L
s
% Start of user PostScript
-50.901985 26.198236 -53.602057 13.466112 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
16.062198 -101.47774 36.586026 -109.49257 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
124.77526 14.648998 114.74902 56.040078 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-149.23746 263.45017 -196.54353 250.21457 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-212.90028 -262.73275 -145.61915 -364.04636 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
585.81043 -493.82618 657.47318 -372.1238 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
83.052186 1132.022 -160.47278 1304.4451 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1662.6707 384.52292 -1651.4168 -92.19054 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1181.0734 -3402.5105 1833.5208 -3467.8443 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3520.2677 1833.7187 2937.6225 3184.8411 MAarrowhead1
% End of user PostScript
0 .975 1 r
.56295 .51122 m
.55709 .5326 L
.54704 .55488 L
.53284 .57685 L
.5148 .59717 L
.49347 .61439 L
.46969 .62709 L
.44455 .6339 L
.41937 .63363 L
.39565 .62536 L
.37499 .60851 L
.35904 .58294 L
.34937 .54903 L
.34739 .50767 L
.35426 .46035 L
.37072 .40909 L
.39709 .35643 L
.43311 .30533 L
.47792 .25902 L
.53 .22092 L
.58723 .19439 L
.64688 .18256 L
.70571 .18808 L
.76011 .21293 L
.80624 .25822 L
.84025 .32395 L
.85849 .40894 L
.85778 .51067 L
.83565 .62531 L
.79055 .74775 L
.72211 .87171 L
.63132 .99 L
s
.63132 .99 m
.62076 1 L
s
1 0 0 r
.56295 .51122 m
.55709 .5326 L
s
% Start of user PostScript
7.5544659 1.3461673 6.8505087 3.9114569 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54704 .55488 m
.53284 .57685 L
s
% Start of user PostScript
5.6442799 6.5850451 3.9408384 9.2219081 MAarrowhead1
% End of user PostScript
1 .473 0 r
.37499 .60851 m
.35904 .58294 L
s
% Start of user PostScript
-15.000793 13.021122 -16.915158 9.9532064 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47792 .25902 m
.53 .22092 L
s
% Start of user PostScript
-2.6501477 -28.917548 3.6000843 -33.489435 MAarrowhead1
% End of user PostScript
.897 1 0 r
.85849 .40894 m
.85778 .51067 L
s
% Start of user PostScript
43.018749 -10.927122 42.934032 1.2807387 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-29.195533 87.851793 -46.113744 89.950053 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-92.233917 -44.63089 -77.688656 -79.590695 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
157.40341 -201.04247 191.08472 -177.16566 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
117.5343 291.42706 49.49747 366.25481 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-527.31593 299.90541 -561.30334 171.68762 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
126.68559 -1045.9393 340.38657 -1140.8536 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1326.2011 69.771459 1237.77 498.61316 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1466.5034 2784.1223 -1972.5788 2679.2708 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2364.1382 -2545.3832 -1695.5528 -3622.3779 MAarrowhead1
% End of user PostScript
1 .341 0 r
.50822 .53196 m
.50102 .53869 L
.4928 .544 L
.48391 .54741 L
.4748 .54843 L
.46598 .54671 L
.45801 .54197 L
.45149 .5341 L
.44699 .52314 L
.44505 .50935 L
.44613 .49316 L
.45057 .47522 L
.45855 .45638 L
.47006 .43762 L
.48489 .42009 L
.50259 .40499 L
.5225 .39355 L
.54371 .38693 L
.56515 .38617 L
.58555 .3921 L
.60357 .40526 L
.61781 .42581 L
.62692 .45353 L
.62967 .48771 L
.62506 .52717 L
.61237 .57027 L
.5913 .61491 L
.56197 .65865 L
.52505 .69874 L
.48171 .73233 L
.43369 .75653 L
.38324 .76866 L
.33303 .76637 L
.28609 .7479 L
.24566 .71218 L
.21502 .65906 L
.19729 .58938 L
.19525 .50508 L
.21111 .40926 L
.24632 .3061 L
.30134 .20076 L
.37553 .09924 L
.46703 .0081 L
s
.46703 .0081 m
.47861 0 L
s
1 0 0 r
.50822 .53196 m
.50102 .53869 L
s
% Start of user PostScript
0.98684018 3.8349694 0.12263812 4.6424245 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4928 .544 m
.48391 .54741 L
s
% Start of user PostScript
-0.86394483 5.2805329 -1.9303671 5.6886917 MAarrowhead1
% End of user PostScript
1 .473 0 r
.44613 .49316 m
.45057 .47522 L
s
% Start of user PostScript
-6.4638104 -0.82105124 -5.9312923 -2.9732859 MAarrowhead1
% End of user PostScript
1 .788 0 r
.56515 .38617 m
.58555 .3921 L
s
% Start of user PostScript
7.8176585 -13.659262 10.265916 -12.947686 MAarrowhead1
% End of user PostScript
.897 1 0 r
.5913 .61491 m
.56197 .65865 L
s
% Start of user PostScript
10.955716 13.789337 7.4366418 19.037632 MAarrowhead1
% End of user PostScript
.581 1 0 r
.24566 .71218 m
.21502 .65906 L
s
% Start of user PostScript
-30.520541 25.462175 -34.198006 19.087179 MAarrowhead1
% End of user PostScript
.266 1 0 r
.46703 .0081 m
0 0 rlineto s
.46703 .0081 m
.47861 0 L
s
% Start of user PostScript
-3.9564313 -59.027571 8.7210125 -67.899853 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
86.31108 -19.26847 85.580723 5.5676543 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-62.275552 176.75717 -96.118442 179.85999 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-181.92473 -97.182113 -151.30399 -167.31908 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
323.21417 -398.24727 389.2996 -347.33672 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
221.04204 601.13666 81.889474 748.71185 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1065.6171 573.90957 -1127.515 310.65282 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
300.79425 -2119.66 731.42372 -2298.062 MAarrowhead1
% End of user PostScript
1 .505 0 r
.48686 .42719 m
.50296 .41363 L
.52102 .40342 L
.54024 .39761 L
.55961 .39713 L
.57801 .40272 L
.59421 .41486 L
.60694 .43369 L
.61499 .45898 L
.61726 .49009 L
.61283 .52593 L
.60109 .565 L
.58175 .60539 L
.55497 .64487 L
.52134 .68098 L
.48196 .71109 L
.43841 .73263 L
.39274 .74316 L
.34738 .7406 L
.30509 .72334 L
.26878 .69047 L
.24144 .64186 L
.22587 .57832 L
.22457 .50164 L
.23953 .41466 L
.27202 .32119 L
.32243 .22594 L
.39014 .13435 L
.47341 .05237 L
s
.47341 .05237 m
.54931 0 L
s
.99339 0 m
1 .00717 L
s
1 .99942 m
.99966 1 L
s
1 0 0 r
.48686 .42719 m
.50296 .41363 L
s
% Start of user PostScript
-1.5763262 -8.7374367 0.35528585 -10.364359 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52102 .40342 m
.54024 .39761 L
s
% Start of user PostScript
2.522901 -11.589808 4.8286737 -12.287248 MAarrowhead1
% End of user PostScript
1 .473 0 r
.61283 .52593 m
.60109 .565 L
s
% Start of user PostScript
13.539816 3.1115565 12.130632 7.7995181 MAarrowhead1
% End of user PostScript
1 .788 0 r
.34738 .7406 m
.30509 .72334 L
s
% Start of user PostScript
-18.314377 28.871589 -23.389767 26.800811 MAarrowhead1
% End of user PostScript
.897 1 0 r
.32243 .22594 m
.39014 .13435 L
s
% Start of user PostScript
-21.308722 -32.887156 -13.183734 -43.878213 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
67.813552 -50.654362 74.73511 -35.725559 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
0.54414636 132.25665 -27.398388 149.50176 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-184.79676 25.786738 -179.96854 -29.385529 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
154.88263 -381.32973 226.75302 -381.52398 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
371.27911 252.55826 297.34307 402.69639 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-735.1644 822.86499 -867.96899 696.35688 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-387.19785 -1382.7739 -73.849124 -1683.8495 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2326.0031 -1066.7748 2421.8702 -468.14151 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-915.58417 4661.3975 -1848.4702 4973.2854 MAarrowhead1
% End of user PostScript
1 .089 0 r
.50742 .56852 m
.49255 .57971 L
.47614 .58764 L
.45897 .5914 L
.44196 .59021 L
.42615 .58348 L
.41263 .57088 L
.40253 .55237 L
.39689 .52827 L
.39666 .49928 L
.40255 .46647 L
.41504 .4313 L
.43426 .39553 L
.45996 .36124 L
.49147 .33065 L
.52769 .30609 L
.56707 .28983 L
.6077 .28393 L
.64732 .29013 L
.68342 .30968 L
.7134 .34317 L
.73463 .39048 L
.74471 .45062 L
.74153 .52172 L
.72352 .60098 L
.68979 .68477 L
.64024 .76871 L
.57574 .84779 L
.49813 .91666 L
.4103 .96986 L
s
.4103 .96986 m
.32229 1 L
s
.18533 1 m
.12855 .98587 L
.04665 .931 L
s
.04665 .931 m
0 .86866 L
s
0 .18809 m
.08006 .01053 L
s
.08006 .01053 m
.08686 0 L
s
1 0 0 r
.50742 .56852 m
.49255 .57971 L
s
% Start of user PostScript
0.89031963 8.2221507 -0.89441705 9.5653861 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47614 .58764 m
.45897 .5914 L
s
% Start of user PostScript
-2.8634487 10.517025 -4.9238877 10.968174 MAarrowhead1
% End of user PostScript
1 .473 0 r
.40255 .46647 m
.41504 .4313 L
s
% Start of user PostScript
-11.693799 -4.0230797 -10.194838 -8.2443159 MAarrowhead1
% End of user PostScript
1 .788 0 r
.64732 .29013 m
.68342 .30968 L
s
% Start of user PostScript
17.678115 -25.184196 22.010656 -22.838838 MAarrowhead1
% End of user PostScript
.897 1 0 r
.64024 .76871 m
.57574 .84779 L
s
% Start of user PostScript
16.829089 32.244925 9.0886046 41.734961 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-62.293668 41.174398 -67.521291 26.769266 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
6.9622296 -122.48962 32.426287 -136.09762 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
163.44081 -8.2816844 156.1051 42.38964 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-157.21719 339.96867 -220.22873 334.08462 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-311.25225 -265.14516 -237.99589 -397.90544 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
690.71998 -699.78383 800.01881 -571.45709 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
261.63362 1312.8462 -29.978649 1565.1451 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2098.9472 791.37336 -2149.3108 229.06782 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1064.7847 -4238.2893 1900.0831 -4448.3263 MAarrowhead1
% End of user PostScript
1 .572 0 r
.50614 .56918 m
.4912 .58005 L
.47479 .5876 L
.4577 .59093 L
.44087 .58928 L
.42531 .58208 L
.41214 .56903 L
.40245 .55013 L
.39729 .52572 L
.39757 .49653 L
.404 .46365 L
.41701 .42857 L
.43669 .39308 L
.46278 .35923 L
.49456 .32928 L
.53089 .30552 L
.57022 .29019 L
.61059 .28533 L
.64975 .29263 L
.68519 .31327 L
.71431 .34779 L
.73452 .39599 L
.74344 .45681 L
.73903 .52829 L
.71977 .60761 L
.68484 .69108 L
.63424 .77426 L
.5689 .85216 L
.49075 .91944 L
.40274 .97065 L
s
.40274 .97065 m
.31076 1 L
s
.19699 1 m
.12318 .97927 L
.04297 .92185 L
s
.04297 .92185 m
0 .86091 L
s
0 .19393 m
3e-05 .19383 L
s
3e-05 .19383 m
.09058 0 L
s
1 0 0 r
.50614 .56918 m
.4912 .58005 L
s
% Start of user PostScript
0.73657094 8.3015266 -1.0563729 9.6063364 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47479 .5876 m
.4577 .59093 L
s
% Start of user PostScript
-3.025046 10.511991 -5.0754415 10.911333 MAarrowhead1
% End of user PostScript
1 .473 0 r
.404 .46365 m
.41701 .42857 L
s
% Start of user PostScript
-11.519937 -4.3616779 -9.9591786 -8.5715838 MAarrowhead1
% End of user PostScript
1 .788 0 r
.64975 .29263 m
.68519 .31327 L
s
% Start of user PostScript
17.970272 -24.884015 22.223223 -22.407419 MAarrowhead1
% End of user PostScript
.897 1 0 r
.63424 .77426 m
.5689 .85216 L
s
% Start of user PostScript
16.10928 32.911339 8.2681559 42.259532 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-62.478782 39.79455 -67.404905 25.152694 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
9.0755039 -123.13359 34.55802 -136.15572 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
162.1559 -3.9859859 153.98501 46.833102 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-161.87447 338.08446 -224.22951 330.48282 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-303.81886 -275.22779 -228.84772 -406.93644 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
697.09017 -686.13081 803.15354 -554.025 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
236.03755 1328.7014 -57.498355 1574.9442 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2094.6056 740.84503 -2134.5467 173.39127 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1130.6885 -4238.6348 1962.3971 -4427.8533 MAarrowhead1
% End of user PostScript
0 .862 1 r
.50753 .49164 m
.50888 .49295 L
.50987 .49485 L
.51041 .49731 L
.5104 .50026 L
.50977 .50358 L
.50847 .50714 L
.50649 .51074 L
.50387 .51418 L
.50066 .51724 L
.49698 .51967 L
.493 .52125 L
.4889 .52178 L
.48492 .52108 L
.48131 .51903 L
.47833 .51557 L
.47625 .51072 L
.47531 .50459 L
.47571 .49736 L
.47762 .48933 L
.48111 .48087 L
.4862 .47242 L
.49279 .4645 L
.50068 .45763 L
.50959 .45238 L
.5191 .44926 L
.52875 .44876 L
.53797 .45125 L
.54614 .45697 L
.55266 .46603 L
.5569 .47831 L
.55832 .49353 L
.55644 .51115 L
.55095 .53046 L
.54169 .55052 L
.52871 .57024 L
.51229 .5884 L
.49295 .6037 L
.47146 .61486 L
.4488 .62065 L
.42619 .62002 L
.40496 .61214 L
.38657 .59653 L
.3725 .57309 L
.36417 .54216 L
.36282 .5046 L
.36947 .46177 L
.38479 .41551 L
.40903 .36813 L
.44191 .32231 L
Mistroke
.48264 .28099 L
.52983 .24722 L
.58152 .22403 L
.63523 .21421 L
.68803 .22013 L
.73665 .24353 L
.77762 .28533 L
.8075 .34551 L
.82301 .42291 L
.82133 .51521 L
.80026 .6189 L
.75848 .7293 L
.69572 .84073 L
.61293 .94667 L
Mfstroke
.61293 .94667 m
.55553 1 L
s
1 0 0 r
.50753 .49164 m
.50888 .49295 L
s
% Start of user PostScript
0.90396328 -1.0030498 1.0654139 -0.8463649 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50987 .49485 m
.51041 .49731 L
s
% Start of user PostScript
1.1848238 -0.61834341 1.2494742 -0.32308534 MAarrowhead1
% End of user PostScript
1 .473 0 r
.49698 .51967 m
.493 .52125 L
s
% Start of user PostScript
-0.36197914 2.3604629 -0.84002873 2.5505805 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47571 .49736 m
.47762 .48933 L
s
% Start of user PostScript
-2.9144043 -0.31642279 -2.685651 -1.2798813 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52875 .44876 m
.53797 .45125 L
s
% Start of user PostScript
3.4499213 -6.148669 4.5558401 -5.8502528 MAarrowhead1
% End of user PostScript
.581 1 0 r
.54169 .55052 m
.52871 .57024 L
s
% Start of user PostScript
5.0030963 6.0626892 3.445531 8.4291427 MAarrowhead1
% End of user PostScript
.266 1 0 r
.38657 .59653 m
.3725 .57309 L
s
% Start of user PostScript
-13.61112 11.584002 -15.299419 8.7704996 MAarrowhead1
% End of user PostScript
0 1 .049 r
.48264 .28099 m
.52983 .24722 L
s
% Start of user PostScript
-2.083072 -26.28165 3.5793469 -30.333753 MAarrowhead1
% End of user PostScript
0 1 .364 r
.82301 .42291 m
.82133 .51521 L
s
% Start of user PostScript
38.761406 -9.2509349 38.559545 1.8255575 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-27.134746 79.26841 -42.355996 80.911034 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-82.404948 -41.924597 -68.977104 -73.423496 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
143.48505 -180.00029 173.49902 -157.8133 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
102.59312 266.26621 40.69678 333.11605 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-476.83973 263.99614 -506.05392 147.1221 MAarrowhead1
% End of user PostScript
0 1 .034 r
.47098 .53216 m
.4658 .52712 L
.46198 .5198 L
.45991 .51032 L
.45996 .49896 L
.46241 .48615 L
.46742 .47246 L
.47504 .45859 L
.48517 .44535 L
.49753 .4336 L
.51168 .42424 L
.52702 .41816 L
.54279 .41615 L
.55811 .41887 L
.572 .42679 L
.58345 .44013 L
.59145 .45882 L
.59505 .48246 L
.59347 .51028 L
.58611 .5412 L
.57263 .57378 L
.55302 .60629 L
.52764 .6368 L
.49723 .66321 L
.46294 .6834 L
.42629 .69535 L
.38916 .69723 L
.3537 .6876 L
.32224 .6655 L
.29719 .63059 L
.2809 .58325 L
.27551 .52463 L
.28278 .45675 L
.30398 .3824 L
.3397 .30516 L
.38973 .22927 L
.45299 .15941 L
.52749 .10056 L
.61026 .0577 L
.69748 .03551 L
.78453 .03806 L
.86621 .0685 L
.93692 .12873 L
.99099 .21912 L
s
.99099 .21912 m
1 .25267 L
s
1 .65484 m
.94315 .82606 L
s
.94315 .82606 m
.85403 1 L
s
1 0 0 r
.47098 .53216 m
.4658 .52712 L
s
% Start of user PostScript
-3.4829128 3.8591644 -4.1038063 3.2547547 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46198 .5198 m
.45991 .51032 L
s
% Start of user PostScript
-4.562634 2.3757665 -4.8104542 1.2380599 MAarrowhead1
% End of user PostScript
1 .473 0 r
.51168 .42424 m
.52702 .41816 L
s
% Start of user PostScript
1.4014803 -9.0909064 3.2421938 -9.8207742 MAarrowhead1
% End of user PostScript
1 .788 0 r
.59347 .51028 m
.58611 .5412 L
s
% Start of user PostScript
11.216693 1.2340704 10.332858 4.9442394 MAarrowhead1
% End of user PostScript
.897 1 0 r
.38916 .69723 m
.3537 .6876 L
s
% Start of user PostScript
-13.30038 23.667464 -17.55612 22.512171 MAarrowhead1
% End of user PostScript
.581 1 0 r
.3397 .30516 m
.38973 .22927 L
s
% Start of user PostScript
-19.236305 -23.380262 -13.23289 -32.488021 MAarrowhead1
% End of user PostScript
.266 1 0 r
.93692 .12873 m
.99099 .21912 L
s
% Start of user PostScript
52.430563 -44.552135 58.919206 -33.705391 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
7.9267141 101.25096 -13.882482 116.83068 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-149.22806 35.433953 -148.41265 -7.2329954 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
104.71905 -305.21033 163.31264 -311.45868 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
317.03818 161.92763 265.24395 283.19533 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-552.91086 692.63614 -668.36019 607.0129 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-393.96561 -1026.224 -155.48934 -1283.4155 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1836.313 -1014.4631 1948.3553 -564.09794 MAarrowhead1
% End of user PostScript
0 1 .692 r
.55289 .57665 m
.53378 .60329 L
.5101 .62732 L
.48267 .64695 L
.45262 .66043 L
.42139 .66615 L
.3907 .66271 L
.36243 .64911 L
.33861 .62481 L
.32124 .58983 L
.31222 .54484 L
.31319 .49118 L
.32543 .4309 L
.34972 .36672 L
.3862 .30194 L
.43433 .24034 L
.49278 .18603 L
.55944 .14322 L
.63143 .11598 L
.70517 .10801 L
.7765 .12236 L
.84083 .16115 L
.8934 .2253 L
.92951 .31438 L
.94482 .42639 L
.93563 .5577 L
.89924 .70306 L
.8342 .85566 L
s
.8342 .85566 m
.74511 1 L
s
1 0 0 r
.55289 .57665 m
.53378 .60329 L
s
% Start of user PostScript
6.3473072 9.1981717 4.0533025 12.394917 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5101 .62732 m
.48267 .64695 L
s
% Start of user PostScript
1.2121298 15.278114 -2.079628 17.634071 MAarrowhead1
% End of user PostScript
1 .473 0 r
.31222 .54484 m
.31319 .49118 L
s
% Start of user PostScript
-22.534109 5.3802696 -22.41722 -1.0588126 MAarrowhead1
% End of user PostScript
1 .788 0 r
.63143 .11598 m
.70517 .10801 L
s
% Start of user PostScript
15.771837 -46.082619 24.62086 -47.038482 MAarrowhead1
% End of user PostScript
.897 1 0 r
.89924 .70306 m
.8342 .85566 L
s
% Start of user PostScript
47.909061 24.366719 40.103917 42.678742 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-83.40951 104.64817 -100.85949 91.75216 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-59.655182 -154.78139 -23.673675 -193.64695 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
277.20649 -153.49831 294.1955 -85.558064 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-72.392663 550.61871 -184.57542 598.78008 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-692.27189 -48.642397 -643.53179 -274.07385 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
782.5345 -1455.5791 1046.2385 -1395.7514 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1219.6655 1363.8304 864.04879 1925.9947 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3159.1428 2802.6988 -3575.0671 2164.407 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-642.35443 -6078.7183 676.23737 -7066.7624 MAarrowhead1
% End of user PostScript
.865 1 0 r
.45827 .56759 m
.44632 .5631 L
.43599 .55426 L
.42809 .54099 L
.42344 .52352 L
.42273 .50232 L
.42653 .47816 L
.43523 .45208 L
.44894 .42539 L
.46752 .3996 L
.49052 .37636 L
.51714 .35739 L
.54628 .34441 L
.57655 .33897 L
.60628 .34242 L
.63363 .35572 L
.65665 .3794 L
.6734 .41342 L
.68203 .45714 L
.68096 .50923 L
.66895 .56771 L
.64528 .62993 L
.60978 .6927 L
.56301 .75232 L
.50626 .80484 L
.44157 .84618 L
.37176 .87237 L
.3003 .87984 L
.23124 .86565 L
.169 .82777 L
.11822 .7653 L
.08345 .67869 L
.06889 .56989 L
.0781 .44243 L
.1137 .30144 L
.17707 .15352 L
.26814 .00656 L
s
.26814 .00656 m
.27374 0 L
s
1 0 0 r
.45827 .56759 m
.44632 .5631 L
s
% Start of user PostScript
-5.0080506 8.1107042 -6.441454 7.5723082 MAarrowhead1
% End of user PostScript
1 .158 0 r
.43599 .55426 m
.42809 .54099 L
s
% Start of user PostScript
-7.6815669 6.5106393 -8.6286967 4.9193389 MAarrowhead1
% End of user PostScript
1 .473 0 r
.49052 .37636 m
.51714 .35739 L
s
% Start of user PostScript
-1.1381239 -14.837317 2.0564923 -17.112944 MAarrowhead1
% End of user PostScript
1 .788 0 r
.68203 .45714 m
.68096 .50923 L
s
% Start of user PostScript
21.843662 -5.1434783 21.715173 1.1075967 MAarrowhead1
% End of user PostScript
.897 1 0 r
.37176 .87237 m
.3003 .87984 L
s
% Start of user PostScript
-15.3888 44.684053 -23.963948 45.580635 MAarrowhead1
% End of user PostScript
.581 1 0 r
.1137 .30144 m
.17707 .15352 L
s
% Start of user PostScript
-46.356332 -23.827018 -38.751386 -41.577826 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
81.054499 -101.30313 97.929409 -88.720838 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
57.427069 150.484 22.476343 188.08946 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-268.91964 148.0417 -285.2176 82.020425 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
71.437561 -534.32019 180.23365 -580.67996 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
670.55403 49.684381 622.80103 268.37512 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-761.56216 1410.3935 -1016.8954 1351.372 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1178.3755 -1328.43 -832.52471 -1872.9533 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3067.1975 -2709.8248 3468.6311 -2088.6512 MAarrowhead1
% End of user PostScript
.239 0 1 r
.53729 .55926 m
.52271 .57871 L
.50484 .59606 L
.48429 .61 L
.46195 .61922 L
.43891 .62257 L
.41643 .61905 L
.39595 .60796 L
.37895 .58896 L
.3669 .56212 L
.36119 .52801 L
.36299 .48768 L
.37321 .44272 L
.39234 .39519 L
.42045 .34757 L
.45704 .30271 L
.50106 .26365 L
.55088 .23347 L
.60431 .21517 L
.65862 .21142 L
.71071 .22439 L
.75716 .25551 L
.79447 .30536 L
.81918 .37346 L
.82815 .45816 L
.81874 .55665 L
.78907 .66486 L
.73821 .77766 L
.66638 .88891 L
.57505 .99178 L
s
.57505 .99178 m
.56488 1 L
s
1 0 0 r
.53729 .55926 m
.52271 .57871 L
s
% Start of user PostScript
4.4747369 7.11105 2.7252834 9.4455725 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50484 .59606 m
.48429 .61 L
s
% Start of user PostScript
0.58036642 11.527632 -1.884754 13.199446 MAarrowhead1
% End of user PostScript
1 .473 0 r
.36119 .52801 m
.36299 .48768 L
s
% Start of user PostScript
-16.657347 3.3611824 -16.440949 -1.4781369 MAarrowhead1
% End of user PostScript
1 .788 0 r
.60431 .21517 m
.65862 .21142 L
s
% Start of user PostScript
12.516653 -34.179343 19.034445 -34.62912 MAarrowhead1
% End of user PostScript
.897 1 0 r
.78907 .66486 m
.73821 .77766 L
s
% Start of user PostScript
34.688669 19.783469 28.585551 33.318672 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-63.374855 76.169735 -75.92803 65.939838 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-40.670319 -118.22641 -13.458728 -146.3631 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
206.68302 -107.01609 217.7816 -55.401098 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-64.326968 411.92206 -147.68655 444.7326 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-507.39384 -57.639009 -467.02998 -225.70504 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
604.17912 -1070.9502 796.62096 -1017.9331 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
868.0264 1062.8404 595.47556 1474.8319 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2376.7908 2011.8452 -2669.289 1519.1321 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-348.47041 -4591.3789 639.89059 -5294.3895 MAarrowhead1
% End of user PostScript
1 0 .416 r
.57517 .54207 m
.56211 .5713 L
.54361 .60017 L
.52005 .6269 L
.49215 .64963 L
.46101 .66647 L
.42805 .67561 L
.39498 .6755 L
.36378 .66491 L
.33655 .64308 L
.31543 .6098 L
.30252 .56555 L
.29966 .51149 L
.30837 .44956 L
.32966 .38238 L
.36395 .31327 L
.41092 .2461 L
.46946 .18513 L
.53761 .13481 L
.61259 .09958 L
.69084 .08353 L
.76813 .09018 L
.83972 .12216 L
.90058 .18093 L
.94566 .26655 L
.97016 .3775 L
.96988 .51052 L
.94155 .66063 L
.88311 .82114 L
.79404 .98388 L
s
.79404 .98388 m
.78176 1 L
s
1 0 0 r
.57517 .54207 m
.56211 .5713 L
s
% Start of user PostScript
9.0205457 5.0485533 7.453733 8.5558957 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54361 .60017 m
.52005 .6269 L
s
% Start of user PostScript
5.2337868 12.019991 2.4061332 15.228495 MAarrowhead1
% End of user PostScript
1 .473 0 r
.31543 .6098 m
.30252 .56555 L
s
% Start of user PostScript
-22.147895 13.176344 -23.697805 7.8659111 MAarrowhead1
% End of user PostScript
1 .788 0 r
.53761 .13481 m
.61259 .09958 L
s
% Start of user PostScript
4.5130532 -43.822602 13.510835 -48.050911 MAarrowhead1
% End of user PostScript
.897 1 0 r
.96988 .51052 m
.94155 .66063 L
s
% Start of user PostScript
56.385598 1.2625266 52.985412 19.275473 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-59.977201 118.05392 -81.558715 114.3064 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-102.52354 -103.32067 -75.020146 -149.11405 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
249.783 -233.48129 285.17624 -184.54739 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
67.339404 478.40982 -37.369791 561.48477 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-735.95838 229.87185 -743.56976 26.563651 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
439.66773 -1494.9538 730.73704 -1548.7501 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1628.527 640.06624 1402.9349 1238.2338 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2573.0836 3522.1276 -3173.4121 3162.2346 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2249.6364 -4720.0523 -1128.4585 -6041.5246 MAarrowhead1
% End of user PostScript
0 .188 1 r
.50563 .4386 m
.51828 .43246 L
.53152 .42952 L
.54464 .4304 L
.55685 .43555 L
.56729 .44523 L
.57511 .45946 L
.57949 .478 L
.57972 .50033 L
.57522 .5256 L
.56563 .55272 L
.55086 .5803 L
.53108 .60677 L
.50682 .6304 L
.47892 .64939 L
.44857 .662 L
.41724 .66663 L
.38667 .66194 L
.35879 .64697 L
.33562 .62124 L
.31917 .58485 L
.31131 .53856 L
.31366 .48381 L
.32744 .42273 L
.35333 .35812 L
.39143 .29338 L
.44107 .23233 L
.50083 .17913 L
.56851 .13797 L
.64111 .11292 L
.71495 .10762 L
.78582 .12502 L
.84907 .1671 L
.89993 .23463 L
.93371 .32698 L
.94612 .44194 L
.93358 .57567 L
.89351 .7227 L
.82464 .87602 L
s
.82464 .87602 m
.74483 1 L
s
1 0 0 r
.50563 .4386 m
.51828 .43246 L
s
% Start of user PostScript
0.67595362 -7.368196 2.1934177 -8.105361 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53152 .42952 m
.54464 .4304 L
s
% Start of user PostScript
3.7821219 -8.4573026 5.3568069 -8.3517404 MAarrowhead1
% End of user PostScript
1 .473 0 r
.56563 .55272 m
.55086 .5803 L
s
% Start of user PostScript
7.8760484 6.326549 6.1031268 9.6365532 MAarrowhead1
% End of user PostScript
1 .788 0 r
.35879 .64697 m
.33562 .62124 L
s
% Start of user PostScript
-16.945021 17.63626 -19.725339 14.548624 MAarrowhead1
% End of user PostScript
.897 1 0 r
.44107 .23233 m
.50083 .17913 L
s
% Start of user PostScript
-7.0716576 -32.119882 0.1001491 -38.50487 MAarrowhead1
% End of user PostScript
.581 1 0 r
.93371 .32698 m
.94612 .44194 L
s
% Start of user PostScript
52.044871 -20.762783 53.534292 -6.9671991 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-24.81388 104.87887 -45.569113 110.56223 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-120.4769 -32.301884 -106.96398 -74.611023 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
169.39004 -257.75879 214.37494 -237.40881 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
184.16447 305.90263 109.36953 403.6921 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-616.27663 441.82815 -675.27216 303.76874 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
20.83817 -1205.3729 274.06968 -1354.3762 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1657.5818 -181.11334 1603.6819 320.24703 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1459.1709 3429.7883 -2101.9193 3410.6062 MAarrowhead1
% End of user PostScript
1 0 .964 r
.50724 .4993 m
.50699 .50151 L
.50628 .50391 L
.50511 .50641 L
.50347 .50885 L
.50141 .51109 L
.49899 .51297 L
.49631 .51432 L
.49349 .51501 L
.49069 .51488 L
.48806 .51385 L
.4858 .51186 L
.48409 .5089 L
.48309 .50501 L
.48298 .50031 L
.48386 .49496 L
.48582 .4892 L
.48889 .48331 L
.49302 .47764 L
.49813 .47255 L
.50403 .46841 L
.51047 .46561 L
.51715 .46448 L
.52369 .46533 L
.52969 .46835 L
.53472 .47367 L
.53835 .48126 L
.54017 .49098 L
.53984 .50253 L
.5371 .51547 L
.53177 .52921 L
.52384 .54304 L
.51343 .55614 L
.50083 .56764 L
.48651 .57664 L
.47109 .58226 L
.45533 .58373 L
.44015 .5804 L
.42651 .57183 L
.41543 .55783 L
.40793 .53852 L
.40491 .51435 L
.40717 .4861 L
.41526 .45492 L
.42949 .42227 L
.44981 .38992 L
.47583 .35982 L
.50676 .33407 L
.5414 .31479 L
.57819 .30399 L
Mistroke
.61521 .30344 L
.65029 .31454 L
.68108 .33817 L
.70517 .37461 L
.72023 .42337 L
.72416 .4832 L
.71525 .55199 L
.69232 .62684 L
.65486 .7041 L
.60318 .77947 L
.53846 .84821 L
.46284 .90533 L
.37936 .94589 L
.29196 .96526 L
.20533 .95946 L
.12474 .92549 L
.0558 .86162 L
.00416 .76768 L
Mfstroke
.00416 .76768 m
0 .75006 L
s
0 .35029 m
.00343 .33102 L
.06669 .15201 L
s
.06669 .15201 m
.1481 0 L
s
1 0 0 r
.50724 .4993 m
.50699 .50151 L
s
% Start of user PostScript
0.8692079 -0.083603938 0.83854437 0.18076856 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50628 .50391 m
.50511 .50641 L
s
% Start of user PostScript
0.75379015 0.46956144 0.6127976 0.76880362 MAarrowhead1
% End of user PostScript
1 .473 0 r
.48806 .51385 m
.4858 .51186 L
s
% Start of user PostScript
-1.4323972 1.6625726 -1.7036691 1.4237386 MAarrowhead1
% End of user PostScript
1 .788 0 r
.49302 .47764 m
.49813 .47255 L
s
% Start of user PostScript
-0.83702222 -2.6831501 -0.22423392 -3.2944904 MAarrowhead1
% End of user PostScript
.897 1 0 r
.53835 .48126 m
.54017 .49098 L
s
% Start of user PostScript
4.6018876 -2.2490516 4.8207834 -1.0825611 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48651 .57664 m
.47109 .58226 L
s
% Start of user PostScript
-1.618525 9.1965443 -3.4694703 9.871339 MAarrowhead1
% End of user PostScript
.266 1 0 r
.40717 .4861 m
.41526 .45492 L
s
% Start of user PostScript
-11.139748 -1.6679002 -10.168631 -5.4097132 MAarrowhead1
% End of user PostScript
0 1 .049 r
.61521 .30344 m
.65029 .31454 L
s
% Start of user PostScript
13.825263 -23.587542 18.034965 -22.25577 MAarrowhead1
% End of user PostScript
0 1 .364 r
.65486 .7041 m
.60318 .77947 L
s
% Start of user PostScript
18.583027 24.491909 12.381311 33.536362 MAarrowhead1
% End of user PostScript
0 1 .679 r
.0558 .86162 m
.00416 .76768 L
s
% Start of user PostScript
-53.304586 43.394288 -59.500294 32.12139 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-5.4113856 -103.29305 16.688991 -118.3401 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
149.47561 -30.558733 147.61754 12.815918 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-111.76588 306.63622 -170.26876 310.83783 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-311.74857 -176.38634 -257.19686 -297.84597 MAarrowhead1
% End of user PostScript
0 .676 1 r
.58253 .45323 m
.58781 .47331 L
.58857 .49767 L
.58413 .52541 L
.5741 .55532 L
.5583 .58592 L
.53693 .61547 L
.51051 .64206 L
.47994 .66373 L
.4465 .67851 L
.4118 .68462 L
.37774 .68054 L
.34643 .66514 L
.32012 .63784 L
.30102 .59869 L
.29125 .54844 L
.29263 .48861 L
.30656 .42149 L
.33388 .35012 L
.37475 .27818 L
.42852 .2099 L
.49372 .14982 L
.56797 .10263 L
.64806 .07285 L
.72998 .06458 L
.80909 .08118 L
.8803 .12496 L
.93832 .19694 L
.97792 .29657 L
.99429 .42161 L
.98336 .56796 L
.94216 .72975 L
.86909 .89939 L
s
.86909 .89939 m
.80648 1 L
s
1 0 0 r
.58253 .45323 m
.58781 .47331 L
s
% Start of user PostScript
9.9034795 -5.6128187 10.537641 -3.2022297 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58857 .49767 m
.58413 .52541 L
s
% Start of user PostScript
10.627811 -0.27970448 10.096181 3.048631 MAarrowhead1
% End of user PostScript
1 .473 0 r
.4118 .68462 m
.37774 .68054 L
s
% Start of user PostScript
-10.583651 22.154851 -14.671147 21.664331 MAarrowhead1
% End of user PostScript
1 .788 0 r
.33388 .35012 m
.37475 .27818 L
s
% Start of user PostScript
-19.934258 -17.985531 -15.030593 -26.617842 MAarrowhead1
% End of user PostScript
.897 1 0 r
.8803 .12496 m
.93832 .19694 L
s
% Start of user PostScript
45.636286 -45.005062 52.598122 -36.367647 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
15.572779 86.969798 -3.6473717 103.12649 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-137.22886 48.748834 -139.89037 11.599272 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
73.782015 -277.65619 128.27979 -290.14134 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
310.59765 102.41969 271.7203 213.96671 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-463.36578 668.08757 -578.61086 607.64264 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-452.22505 -843.69339 -249.03333 -1095.7655 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1642.1992 -1102.1775 1783.5415 -724.58578 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-160.23607 3225.98 -832.16219 3591.6919 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-4328.3799 266.43599 -4144.0526 -1069.4038 MAarrowhead1
% End of user PostScript
.625 0 1 r
.43594 .55866 m
.42712 .54595 L
.42147 .52881 L
.41976 .50767 L
.4226 .48326 L
.43043 .4566 L
.44346 .42897 L
.46159 .4019 L
.48443 .37708 L
.51124 .35628 L
.54094 .34129 L
.57216 .33376 L
.60324 .33515 L
.63229 .34655 L
.65732 .36862 L
.67631 .40146 L
.6873 .44456 L
.6886 .4967 L
.67881 .55597 L
.65706 .6198 L
.62305 .68499 L
.57717 .74782 L
.52058 .80424 L
.45522 .85003 L
.38384 .88104 L
.30988 .89346 L
.23741 .88406 L
.17094 .85051 L
.11526 .79159 L
.0751 .70743 L
.05494 .5997 L
.05863 .47168 L
.08914 .3283 L
.14821 .17607 L
.23613 .02289 L
s
.23613 .02289 m
.25432 0 L
s
1 0 0 r
.43594 .55866 m
.42712 .54595 L
s
% Start of user PostScript
-7.6871029 7.0389632 -8.7454259 5.5141109 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42147 .52881 m
.41976 .50767 L
s
% Start of user PostScript
-9.423116 3.4573844 -9.6290775 0.92062145 MAarrowhead1
% End of user PostScript
1 .473 0 r
.54094 .34129 m
.57216 .33376 L
s
% Start of user PostScript
4.9132535 -19.045372 8.6596481 -19.948529 MAarrowhead1
% End of user PostScript
1 .788 0 r
.67881 .55597 m
.65706 .6198 L
s
% Start of user PostScript
21.457442 6.7166832 18.847373 14.376506 MAarrowhead1
% End of user PostScript
.897 1 0 r
.23741 .88406 m
.17094 .85051 L
s
% Start of user PostScript
-31.511357 46.087513 -39.48666 42.061354 MAarrowhead1
% End of user PostScript
.581 1 0 r
.23613 .02289 m
0 0 rlineto s
.23613 .02289 m
.25432 0 L
s
% Start of user PostScript
-31.664724 -57.253787 -17.821691 -74.668698 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
112.44917 -76.834799 122.41531 -51.155316 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-9.07278 220.64403 -55.134677 246.25453 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-297.9918 22.165482 -286.10829 -69.308358 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
276.80167 -618.52749 391.95592 -610.74544 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
575.81596 463.10159 446.07798 705.16866 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1239.6391 1289.4887 -1442.8859 1063.5151 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-516.33631 -2349.9135 8.3008852 -2816.7173 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3806.5753 -1516.8653 3915.1468 -507.62943 MAarrowhead1
% End of user PostScript
1 .012 0 r
.41678 .50646 m
.42004 .48095 L
.42851 .45317 L
.44236 .4245 L
.4615 .3965 L
.48548 .37096 L
.51352 .3497 L
.54449 .33458 L
.57693 .32731 L
.6091 .32938 L
.63905 .34189 L
.66469 .3655 L
.68392 .40027 L
.69475 .44562 L
.6954 .50025 L
.68449 .56214 L
.66112 .62856 L
.62503 .69617 L
.57668 .76107 L
.51733 .81905 L
.44903 .86572 L
.37468 .89679 L
.2979 .90834 L
.22296 .89707 L
.15455 .86063 L
.09764 .79782 L
.05715 .70889 L
.03768 .59566 L
.04318 .46166 L
.07666 .31209 L
.13985 .15382 L
s
.13985 .15382 m
.23006 0 L
s
1 0 0 r
.41678 .50646 m
.42004 .48095 L
s
% Start of user PostScript
-9.9863563 0.77479954 -9.5948647 -2.2865598 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42851 .45317 m
.44236 .4245 L
s
% Start of user PostScript
-8.5790421 -5.6191718 -6.9163397 -9.060408 MAarrowhead1
% End of user PostScript
1 .473 0 r
.63905 .34189 m
.66469 .3655 L
s
% Start of user PostScript
16.685482 -18.973337 19.76241 -16.140464 MAarrowhead1
% End of user PostScript
1 .788 0 r
.57668 .76107 m
.51733 .81905 L
s
% Start of user PostScript
9.2021955 31.32837 2.079026 38.285646 MAarrowhead1
% End of user PostScript
.897 1 0 r
.05715 .70889 m
.03768 .59566 L
s
% Start of user PostScript
-53.142081 25.067056 -55.478923 11.479762 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
19.950858 -106.36928 41.290909 -113.78453 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
127.57417 21.862739 115.86994 65.071081 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-162.17617 270.64301 -210.28117 254.23993 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-209.56069 -288.4278 -137.04231 -392.00114 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
618.15576 -491.63705 687.55885 -359.41252 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
46.605939 1200.0161 -209.24337 1369.6787 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1719.7562 321.0405 -1691.932 -181.93937 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1328.4463 -3533.6233 2000.374 -3569.2286 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3550.746 2117.2201 2906.5749 3514.5878 MAarrowhead1
% End of user PostScript
0 .557 1 r
.54817 .54631 m
.53572 .56754 L
.51948 .58757 L
.49992 .60504 L
.47775 .61857 L
.45397 .62684 L
.42976 .62864 L
.40651 .623 L
.38575 .60929 L
.36903 .58722 L
.3579 .55702 L
.35377 .5194 L
.3578 .47561 L
.37085 .42745 L
.39334 .3772 L
.42518 .32758 L
.46573 .28164 L
.51372 .2426 L
.56728 .21371 L
.62396 .19806 L
.68079 .19832 L
.73441 .21661 L
.78119 .25424 L
.81743 .31153 L
.83957 .38769 L
.8444 .48069 L
.82933 .58723 L
.79262 .70274 L
.73357 .82155 L
.65273 .937 L
s
.65273 .937 m
.59216 1 L
s
1 0 0 r
.54817 .54631 m
.53572 .56754 L
s
% Start of user PostScript
5.7805163 5.5576378 4.2863338 8.1050023 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51948 .58757 m
.49992 .60504 L
s
% Start of user PostScript
2.337581 10.50819 -0.010050357 12.604687 MAarrowhead1
% End of user PostScript
1 .473 0 r
.3579 .55702 m
.35377 .5194 L
s
% Start of user PostScript
-17.051589 6.8429091 -17.548087 2.3282364 MAarrowhead1
% End of user PostScript
1 .788 0 r
.56728 .21371 m
.62396 .19806 L
s
% Start of user PostScript
8.073628 -34.354202 14.875253 -36.233078 MAarrowhead1
% End of user PostScript
.897 1 0 r
.82933 .58723 m
.79262 .70274 L
s
% Start of user PostScript
39.519699 10.467107 35.114273 24.32903 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-55.385132 84.527887 -70.146309 77.906236 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-60.562752 -99.973984 -36.097713 -132.05183 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
201.79626 -145.1798 221.22073 -100.03831 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6.1188969 394.5982 -89.057368 443.59934 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-543.36173 60.758907 -525.98634 -103.40963 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
476.38662 -1124.039 687.13496 -1118.3302 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1073.9261 785.92134 848.37478 1227.3474 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2203.6324 2390.4644 -2585.6604 2001.4434 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1054.6781 -4158.9953 -118.32132 -5029.7539 MAarrowhead1
% End of user PostScript
1 0 .473 r
.46203 .50168 m
.46378 .48987 L
.46793 .4771 L
.47455 .46399 L
.48356 .45129 L
.49476 .4398 L
.50775 .43037 L
.52202 .42383 L
.53687 .42097 L
.5515 .42244 L
.56501 .42873 L
.57644 .44011 L
.58483 .45658 L
.58928 .47782 L
.589 .50322 L
.58337 .53181 L
.57202 .56231 L
.55487 .59316 L
.53216 .62255 L
.50451 .64855 L
.47291 .66915 L
.43871 .68241 L
.40362 .68656 L
.3696 .68013 L
.33884 .6621 L
.31358 .63201 L
.29608 .59004 L
.28841 .53711 L
.29234 .47491 L
.30918 .40594 L
.33963 .33338 L
.38371 .26111 L
.44059 .19346 L
.50859 .13508 L
.58513 .09069 L
.66678 .0648 L
.74936 .06142 L
.82806 .08374 L
.89768 .13386 L
.95285 .21249 L
.98836 .31873 L
.99947 .44993 L
.98228 .60158 L
.93404 .76737 L
.85349 .93929 L
s
.85349 .93929 m
.81303 1 L
s
1 0 0 r
.46203 .50168 m
.46378 .48987 L
s
% Start of user PostScript
-4.5566561 0.20122151 -4.3458786 -1.215302 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46793 .4771 m
.47455 .46399 L
s
% Start of user PostScript
-3.8478632 -2.7479571 -3.0540645 -4.3208041 MAarrowhead1
% End of user PostScript
1 .473 0 r
.56501 .42873 m
.57644 .44011 L
s
% Start of user PostScript
7.8008768 -8.5523309 9.1722675 -7.1868199 MAarrowhead1
% End of user PostScript
1 .788 0 r
.53216 .62255 m
.50451 .64855 L
s
% Start of user PostScript
3.8590338 14.706091 0.54089291 17.826135 MAarrowhead1
% End of user PostScript
.897 1 0 r
.29608 .59004 m
.28841 .53711 L
s
% Start of user PostScript
-24.470219 10.804406 -25.390473 4.4526046 MAarrowhead1
% End of user PostScript
.581 1 0 r
.58513 .09069 m
.66678 .0648 L
s
% Start of user PostScript
10.215004 -49.117213 20.013298 -52.223934 MAarrowhead1
% End of user PostScript
.266 1 0 r
.98228 .60158 m
.93404 .76737 L
s
% Start of user PostScript
57.873749 12.190045 52.084643 32.084714 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-76.735876 123.20009 -98.472076 114.81159 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-92.388763 -137.37906 -58.260727 -184.36063 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
286.76249 -218.65225 316.9709 -156.0975 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
8.5008408 558.44285 -109.82898 633.22266 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-786.69406 121.84413 -768.68684 -111.47062 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
642.53643 -1621.1008 948.95381 -1626.9592 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1594.7879 1040.4526 1286.5708 1679.6248 MAarrowhead1
% End of user PostScript
0 1 .69 r
.57062 .4521 m
.57681 .46827 L
.57924 .48849 L
.57726 .51209 L
.57042 .53811 L
.55846 .56532 L
.54143 .59226 L
.51965 .61728 L
.49381 .63864 L
.4649 .65458 L
.43422 .66342 L
.40339 .66369 L
.37421 .65424 L
.34865 .63433 L
.32871 .60376 L
.31633 .56293 L
.31326 .51291 L
.32092 .45546 L
.34027 .39302 L
.37172 .32864 L
.41502 .26591 L
.46915 .20879 L
.53232 .16143 L
.60198 .12796 L
.67483 .11221 L
.74695 .1175 L
.81395 .1463 L
.87115 .20003 L
.91383 .2788 L
.93752 .38125 L
.93826 .50443 L
.91297 .64374 L
.85968 .79303 L
.77785 .94472 L
s
.77785 .94472 m
.73629 1 L
s
1 0 0 r
.57062 .4521 m
.57681 .46827 L
s
% Start of user PostScript
8.4748622 -5.7484602 9.2170479 -3.8076378 MAarrowhead1
% End of user PostScript
1 .158 0 r
.57924 .48849 m
.57726 .51209 L
s
% Start of user PostScript
9.5083817 -1.3813235 9.2714592 1.4504281 MAarrowhead1
% End of user PostScript
1 .473 0 r
.43422 .66342 m
.40339 .66369 L
s
% Start of user PostScript
-7.893266 19.610468 -11.593302 19.643191 MAarrowhead1
% End of user PostScript
1 .788 0 r
.34027 .39302 m
.37172 .32864 L
s
% Start of user PostScript
-19.167746 -12.838146 -15.393018 -20.563332 MAarrowhead1
% End of user PostScript
.897 1 0 r
.81395 .1463 m
.87115 .20003 L
s
% Start of user PostScript
37.674494 -42.444061 44.538331 -35.996512 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
20.225879 70.81082 4.1574179 86.3546 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-119.52358 55.459882 -124.58544 24.781593 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
46.152644 -239.40994 94.114238 -255.70455 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
285.84772 51.815938 259.02563 148.9955 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-367.31974 606.94076 -474.99794 569.00771 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-466.21503 -654.40008 -302.19546 -886.4653 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1392.9563 -1096.1296 1546.8744 -796.65995 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
88.684082 2706.3101 -487.40178 3083.739 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3861.4859 689.7036 -3792.4361 -443.69261 MAarrowhead1
% End of user PostScript
.085 0 1 r
.56773 .56594 m
.55005 .59589 L
.52703 .62412 L
.49933 .64869 L
.46799 .66768 L
.43438 .67919 L
.40021 .68155 L
.36744 .67339 L
.33821 .65381 L
.31474 .62245 L
.2992 .57961 L
.29356 .52632 L
.29948 .46436 L
.31814 .39628 L
.35014 .32532 L
.39533 .25533 L
.45279 .19061 L
.52071 .13573 L
.59643 .09526 L
.67649 .07354 L
.75669 .07436 L
.83225 .10067 L
.89806 .15431 L
.9489 .2357 L
.97973 .34368 L
.98606 .47537 L
.96424 .62606 L
.91183 .7893 L
.82789 .95702 L
s
.82789 .95702 m
.79762 1 L
s
1 0 0 r
.56773 .56594 m
.55005 .59589 L
s
% Start of user PostScript
8.1274297 7.9128782 6.0057481 11.507239 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52703 .62412 m
.49933 .64869 L
s
% Start of user PostScript
3.2434057 14.893932 -0.080163724 17.843335 MAarrowhead1
% End of user PostScript
1 .473 0 r
.2992 .57961 m
.29356 .52632 L
s
% Start of user PostScript
-24.096244 9.5530504 -24.773188 3.1581025 MAarrowhead1
% End of user PostScript
1 .788 0 r
.59643 .09526 m
.67649 .07354 L
s
% Start of user PostScript
11.572024 -48.569012 21.179203 -51.175374 MAarrowhead1
% End of user PostScript
.897 1 0 r
.96424 .62606 m
.91183 .7893 L
s
% Start of user PostScript
55.708967 15.127732 49.420184 34.71632 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-78.592955 119.22426 -99.386859 109.73463 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-84.932948 -142.00046 -50.243952 -187.21832 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
285.50197 -203.93453 312.67432 -139.87893 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-10.69961 558.55205 -127.98537 627.26767 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-767.02158 81.744829 -741.64489 -150.51858 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
678.08323 -1587.4685 975.42704 -1577.7323 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1511.2354 1120.9965 1190.6634 1744.1159 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3121.9204 3366.6799 -3658.9396 2812.9752 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1466.4186 -5895.8277 -140.62629 -7121.1364 MAarrowhead1
% End of user PostScript
.724 1 0 r
.53357 .55782 m
.5195 .57591 L
.5024 .59188 L
.48288 .6045 L
.46177 .61257 L
.44014 .615 L
.4192 .61089 L
.40028 .59963 L
.3848 .58092 L
.37412 .5549 L
.36953 .52214 L
.37211 .4837 L
.38266 .44111 L
.40161 .39636 L
.42895 .35183 L
.46417 .31021 L
.50622 .27437 L
.55349 .24721 L
.60387 .23151 L
.65476 .22973 L
.7032 .24384 L
.74596 .2751 L
.77976 .32393 L
.80137 .38976 L
.80789 .47094 L
.79691 .56465 L
.76676 .66699 L
.71669 .773 L
.64703 .87684 L
.55933 .97203 L
s
.55933 .97203 m
.52322 1 L
s
1 0 0 r
.53357 .55782 m
.5195 .57591 L
s
% Start of user PostScript
4.0285964 6.9378491 2.3404914 9.1087788 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5024 .59188 m
.48288 .6045 L
s
% Start of user PostScript
0.28803903 11.025548 -2.0548718 12.540007 MAarrowhead1
% End of user PostScript
1 .473 0 r
.36953 .52214 m
.37211 .4837 L
s
% Start of user PostScript
-15.656109 2.6567823 -15.346696 -1.9565058 MAarrowhead1
% End of user PostScript
1 .788 0 r
.60387 .23151 m
.65476 .22973 L
s
% Start of user PostScript
12.464106 -32.218526 18.570995 -32.431819 MAarrowhead1
% End of user PostScript
.897 1 0 r
.76676 .66699 m
.71669 .773 L
s
% Start of user PostScript
32.011484 20.039124 26.003201 32.759814 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-60.966776 70.623365 -72.483242 60.439817 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-35.430522 -114.22841 -9.3539064 -140.19025 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
195.70365 -95.322314 204.94449 -45.673522 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-69.28025 391.15993 -147.98278 419.72226 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-473.35768 -71.858575 -431.88446 -230.98538 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
588.84458 -1002.4814 767.68855 -945.48012 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
788.48152 1043.5597 524.42065 1427.8809 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2267.802 1842.0415 -2530.521 1361.911 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-224.4635 -4395.2928 715.62231 -5033.7341 MAarrowhead1
% End of user PostScript
0 1 .875 r
.55168 .46267 m
.55668 .47421 L
.55897 .48883 L
.55805 .50606 L
.55355 .52522 L
.54525 .54542 L
.53315 .56561 L
.51746 .58458 L
.49864 .60102 L
.4774 .61363 L
.45467 .62115 L
.43162 .62243 L
.40958 .61659 L
.39 .60302 L
.37437 .5815 L
.36416 .55225 L
.36068 .51599 L
.36505 .47395 L
.37805 .42786 L
.40005 .37994 L
.43094 .3328 L
.47007 .28936 L
.51619 .25269 L
.56748 .22589 L
.62158 .21186 L
.67563 .21316 L
.72641 .23173 L
.77044 .26877 L
.80421 .32454 L
.82434 .39819 L
.8278 .48773 L
.81217 .58991 L
.77584 .70034 L
.71823 .81353 L
.63993 .92308 L
s
.63993 .92308 m
.56446 1 L
s
1 0 0 r
.55168 .46267 m
.55668 .47421 L
s
% Start of user PostScript
6.2012167 -4.479246 6.8019014 -3.0943494 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55897 .48883 m
.55805 .50606 L
s
% Start of user PostScript
7.0769245 -1.3405197 6.9665232 0.72677376 MAarrowhead1
% End of user PostScript
1 .473 0 r
.45467 .62115 m
.43162 .62243 L
s
% Start of user PostScript
-5.4396112 14.537504 -8.2053831 14.692117 MAarrowhead1
% End of user PostScript
1 .788 0 r
.37805 .42786 m
.40005 .37994 L
s
% Start of user PostScript
-14.634466 -8.6566836 -11.994167 -14.406992 MAarrowhead1
% End of user PostScript
.897 1 0 r
.72641 .23173 m
.77044 .26877 L
s
% Start of user PostScript
27.169033 -32.192369 32.453147 -27.747151 MAarrowhead1
% End of user PostScript
.581 1 0 r
.63993 .92308 m
0 0 rlineto s
.63993 .92308 m
.56446 1 L
s
% Start of user PostScript
16.792116 50.77018 5.1439984 62.639914 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-88.061372 44.549844 -92.569284 22.423172 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
28.865515 -175.70254 64.342654 -189.24582 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
214.9517 27.567862 197.18726 99.173745 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-260.34132 454.28308 -341.74719 430.50976 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-364.01714 -459.31899 -246.84858 -633.84869 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1015.6863 -846.22664 1137.8307 -633.92955 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
130.10026 1964.5748 -291.74679 2259.3651 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2871.0031 638.00018 -2846.0894 -188.51357 MAarrowhead1
% End of user PostScript
0 1 .871 r
.51541 .54057 m
.50599 .55068 L
.49496 .55912 L
.48276 .56515 L
.46997 .56811 L
.45727 .56739 L
.44542 .56256 L
.43525 .55336 L
.42759 .53975 L
.42322 .52196 L
.42285 .50049 L
.42704 .47613 L
.43613 .44995 L
.45025 .42327 L
.4692 .39761 L
.49252 .37465 L
.5194 .3561 L
.54869 .34366 L
.57898 .33889 L
.60859 .3431 L
.63567 .35722 L
.65826 .38174 L
.67442 .41657 L
.68234 .46102 L
.68043 .51371 L
.66751 .57259 L
.64288 .635 L
.60645 .69765 L
.55882 .75687 L
.50134 .80865 L
.43613 .84891 L
.36604 .87373 L
.29461 .87957 L
.22592 .86355 L
.16443 .82371 L
.11476 .75927 L
.08145 .67078 L
.06867 .56032 L
.07991 .43157 L
.1177 .28974 L
.18332 .14158 L
s
.18332 .14158 m
.27342 0 L
s
1 0 0 r
.51541 .54057 m
.50599 .55068 L
s
% Start of user PostScript
1.8486622 4.8678428 0.71857852 6.0814569 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49496 .55912 m
.48276 .56515 L
s
% Start of user PostScript
-0.60482757 7.0939849 -2.0683733 7.8182686 MAarrowhead1
% End of user PostScript
1 .473 0 r
.42285 .50049 m
.42704 .47613 L
s
% Start of user PostScript
-9.2575087 0.058366073 -8.7553235 -2.8647457 MAarrowhead1
% End of user PostScript
1 .788 0 r
.57898 .33889 m
.60859 .3431 L
s
% Start of user PostScript
9.477132 -19.332835 13.030549 -18.828315 MAarrowhead1
% End of user PostScript
.897 1 0 r
.64288 .635 m
.60645 .69765 L
s
% Start of user PostScript
17.145648 16.199404 12.773921 23.718356 MAarrowhead1
% End of user PostScript
.581 1 0 r
.16443 .82371 m
.11476 .75927 L
s
% Start of user PostScript
-40.268934 38.845321 -46.229079 31.111894 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-12.534019 -76.90267 4.3926159 -90.797831 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
120.0677 -40.523004 121.94695 -7.7442804 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-67.521682 243.33079 -115.12313 253.36675 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-269.24584 -95.736125 -234.07723 -193.32964 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
411.35949 -580.43663 510.9965 -525.14055 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
383.82317 751.36163 203.9193 969.86073 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1442.9547 942.04199 -1561.5744 606.85339 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
177.58524 -2839.5011 766.98216 -3149.8306 MAarrowhead1
% End of user PostScript
0 1 .181 r
.49356 .43129 m
.50842 .42039 L
.52475 .41278 L
.54179 .40935 L
.5586 .41088 L
.57415 .41793 L
.58735 .4308 L
.5971 .44952 L
.60235 .47374 L
.60221 .50276 L
.59594 .53547 L
.58313 .57042 L
.56364 .60583 L
.53777 .63963 L
.5062 .66962 L
.47006 .69348 L
.43089 .70898 L
.39063 .71408 L
.35153 .70709 L
.31608 .68682 L
.28687 .65271 L
.26649 .60495 L
.25731 .54458 L
.26139 .47351 L
.28025 .39455 L
.31471 .31137 L
.36482 .22837 L
.42966 .15051 L
.50733 .08312 L
.5949 .03163 L
.68848 .00121 L
s
.68848 .00121 m
.71283 0 L
s
.79614 0 m
.87379 .02117 L
.95407 .07769 L
s
.95407 .07769 m
1 .14183 L
s
1 .80132 m
.90892 .99805 L
s
.90892 .99805 m
.90763 1 L
s
1 0 0 r
.49356 .43129 m
.50842 .42039 L
s
% Start of user PostScript
-0.77247417 -8.2446227 1.0104557 -9.5534527 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52475 .41278 m
.54179 .40935 L
s
% Start of user PostScript
2.9705198 -10.466817 5.0144119 -10.877589 MAarrowhead1
% End of user PostScript
1 .473 0 r
.59594 .53547 m
.58313 .57042 L
s
% Start of user PostScript
11.513307 4.2561641 9.9751856 8.4503506 MAarrowhead1
% End of user PostScript
1 .788 0 r
.35153 .70709 m
.31608 .68682 L
s
% Start of user PostScript
-17.816445 24.850496 -22.070872 22.418271 MAarrowhead1
% End of user PostScript
.897 1 0 r
.36482 .22837 m
.42966 .15051 L
s
% Start of user PostScript
-16.221416 -32.596162 -8.4405768 -41.939168 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
62.155518 -39.970118 67.13666 -25.453261 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-8.4971638 122.4254 -33.862362 135.5392 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-161.76652 5.0624462 -153.84446 -45.494419 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
159.97292 -337.07023 222.21959 -329.93964 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
304.36939 271.4435 230.16631 402.83792 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-692.38703 686.57584 -798.80572 556.01635 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-241.5135 -1318.7912 50.235226 -1565.4882 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2086.4545 -750.44007 2128.8736 -186.80531 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1108.9064 4219.8147 -1937.8537 4413.4993 MAarrowhead1
% End of user PostScript
0 .454 1 r
.51203 .47602 m
.51642 .47673 L
.52042 .47893 L
.52373 .48267 L
.52607 .48795 L
.52716 .49465 L
.52678 .50256 L
.52476 .51137 L
.52098 .52067 L
.51545 .52998 L
.50827 .53874 L
.49963 .54636 L
.48987 .55223 L
.47941 .55576 L
.46878 .55644 L
.45861 .55384 L
.44954 .54769 L
.44228 .53788 L
.4375 .52449 L
.4358 .50787 L
.43771 .48856 L
.44359 .46737 L
.45361 .44529 L
.46773 .42355 L
.48566 .40346 L
.50683 .38646 L
.53041 .37397 L
.55532 .36732 L
.58025 .36771 L
.60371 .37604 L
.62411 .39287 L
.63982 .41833 L
.64928 .45204 L
.65111 .49311 L
.64416 .54006 L
.6277 .59087 L
.60142 .64303 L
.5656 .6936 L
.5211 .73935 L
.46941 .77693 L
.41267 .803 L
.35357 .81446 L
.29535 .8087 L
.24157 .78376 L
.19604 .73858 L
.16259 .67316 L
.14479 .58869 L
.14582 .4877 L
.1681 .37398 L
.21314 .25265 L
Mistroke
.28129 .1299 L
.37155 .01289 L
Mfstroke
.37155 .01289 m
.38524 0 L
s
1 0 0 r
.51203 .47602 m
.51642 .47673 L
s
% Start of user PostScript
1.4436892 -2.8774328 1.9707254 -2.7918489 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52042 .47893 m
.52373 .48267 L
s
% Start of user PostScript
2.4504084 -2.5283734 2.8478266 -2.0790331 MAarrowhead1
% End of user PostScript
1 .473 0 r
.50827 .53874 m
.49963 .54636 L
s
% Start of user PostScript
0.99198902 4.6489346 -0.044283634 5.5630934 MAarrowhead1
% End of user PostScript
1 .788 0 r
.4375 .52449 m
.4358 .50787 L
s
% Start of user PostScript
-7.5002507 2.9392363 -7.7037257 0.94430709 MAarrowhead1
% End of user PostScript
.897 1 0 r
.53041 .37397 m
.55532 .36732 L
s
% Start of user PostScript
3.6496687 -15.124085 6.6387157 -15.921061 MAarrowhead1
% End of user PostScript
.581 1 0 r
.64416 .54006 m
.6277 .59087 L
s
% Start of user PostScript
17.299707 4.807244 15.323692 10.904367 MAarrowhead1
% End of user PostScript
.266 1 0 r
.29535 .8087 m
.24157 .78376 L
s
% Start of user PostScript
-24.5586 37.043981 -31.01171 34.051436 MAarrowhead1
% End of user PostScript
0 1 .049 r
.28129 .1299 m
.37155 .01289 L
s
% Start of user PostScript
-26.245753 -44.411405 -15.414228 -58.453027 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
88.964471 -63.118234 97.340983 -43.102639 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-3.9320027 174.12884 -40.462744 195.36216 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-238.50353 24.237809 -230.36355 -48.136336 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
212.49287 -493.83956 304.90626 -490.31991 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
468.52356 351.96643 368.20324 545.72168 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-974.04657 1044.5863 -1140.3683 871.07713 MAarrowhead1
% End of user PostScript
0 1 .797 r
.41758 .4699 m
.42852 .43992 L
.44517 .40954 L
.46731 .3805 L
.49435 .35473 L
.52532 .33418 L
.55891 .32079 L
.59345 .31631 L
.62703 .32218 L
.6575 .33944 L
.68263 .36857 L
.70022 .40942 L
.70821 .46111 L
.70484 .522 L
.68881 .58969 L
.65939 .66104 L
.61655 .73229 L
.56105 .79917 L
.49451 .85711 L
.41945 .90147 L
.3392 .9278 L
.25785 .93212 L
.18011 .91124 L
.1111 .86306 L
.05609 .78682 L
.02023 .68331 L
.0082 .5551 L
.02391 .40652 L
.0701 .24374 L
.14807 .07456 L
s
.14807 .07456 m
.19709 0 L
s
1 0 0 r
.41758 .4699 m
.42852 .43992 L
s
% Start of user PostScript
-9.8898358 -3.6123817 -8.5778096 -7.2095214 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44517 .40954 m
.46731 .3805 L
s
% Start of user PostScript
-6.5795382 -10.855664 -3.9228191 -14.33989 MAarrowhead1
% End of user PostScript
1 .473 0 r
.68263 .36857 m
.70022 .40942 L
s
% Start of user PostScript
21.915471 -15.771308 24.025956 -10.869434 MAarrowhead1
% End of user PostScript
1 .788 0 r
.49451 .85711 m
.41945 .90147 L
s
% Start of user PostScript
-0.65826122 42.853304 -9.6657137 48.176798 MAarrowhead1
% End of user PostScript
.897 1 0 r
.0082 .5551 m
.02391 .40652 L
s
% Start of user PostScript
-59.015453 6.6114674 -57.130886 -11.217567 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
51.723985 -122.08151 74.614194 -121.46661 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
116.65551 85.324786 92.164668 133.26885 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-239.30589 259.65622 -280.80554 217.41795 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-114.61905 -451.6393 -12.932027 -546.22577 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
747.48328 -323.674 774.25075 -128.82617 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-320.89988 1501.5526 -619.96258 1593.799 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1760.3478 -390.66902 -1580.0639 -998.37265 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2361.7764 -3751.0871 3022.1698 -3487.6436 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2786.7555 4235.8495 1737.9155 5664.8522 MAarrowhead1
% End of user PostScript
.471 1 0 r
.5289 .57099 m
.51231 .5893 L
.49278 .60473 L
.47108 .61596 L
.44821 .62177 L
.42539 .6211 L
.40398 .61311 L
.38545 .59731 L
.37128 .57361 L
.36289 .54236 L
.36157 .50443 L
.36833 .46118 L
.38384 .41448 L
.40835 .36667 L
.44158 .32045 L
.48272 .27878 L
.53037 .24475 L
.58255 .22141 L
.63676 .21158 L
.69003 .21764 L
.73906 .24135 L
.78036 .28364 L
.81044 .34446 L
.82601 .42266 L
.82421 .51588 L
.80284 .62057 L
.76057 .732 L
.69712 .84444 L
.61348 .95131 L
s
.61348 .95131 m
.56097 1 L
s
1 0 0 r
.5289 .57099 m
.51231 .5893 L
s
% Start of user PostScript
3.4676192 8.5186745 1.477064 10.716083 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49278 .60473 m
.47108 .61596 L
s
% Start of user PostScript
-0.86661754 12.567002 -3.4706746 13.914916 MAarrowhead1
% End of user PostScript
1 .473 0 r
.36157 .50443 m
.36833 .46118 L
s
% Start of user PostScript
-16.611181 0.53140195 -15.800134 -4.6585955 MAarrowhead1
% End of user PostScript
1 .788 0 r
.63676 .21158 m
.69003 .21764 L
s
% Start of user PostScript
16.410901 -34.610288 22.803212 -33.882894 MAarrowhead1
% End of user PostScript
.897 1 0 r
.76057 .732 m
.69712 .84444 L
s
% Start of user PostScript
31.268143 27.840244 23.654774 41.332651 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-71.066315 70.524098 -82.000531 57.13053 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-24.864405 -135.35006 5.0826281 -160.69355 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
214.21675 -77.180854 218.6 -19.329517 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-113.66639 433.22453 -198.77966 453.16562 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-486.12514 -156.76422 -426.02331 -330.89318 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
720.30154 -1044.9837 900.80952 -951.85378 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
711.95762 1310.3196 395.85098 1704.8513 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2560.3901 1731.8617 -2783.5949 1144.8838 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
231.11705 -5027.1953 1279.2439 -5602.9851 MAarrowhead1
% End of user PostScript
0 1 .603 r
.46191 .57855 m
.44745 .57664 L
.4342 .5699 L
.4231 .55809 L
.41512 .54124 L
.41113 .5197 L
.41191 .49411 L
.41805 .46546 L
.4299 .43506 L
.4475 .40448 L
.47058 .37553 L
.49848 .35015 L
.53019 .33033 L
.56432 .31798 L
.59916 .31485 L
.63272 .32234 L
.66284 .34142 L
.68726 .3725 L
.70376 .41532 L
.71031 .46889 L
.70519 .53146 L
.68714 .60047 L
.65554 .67269 L
.61045 .74422 L
.55277 .81071 L
.48426 .86752 L
.40757 .90998 L
.32619 .93365 L
.24433 .9346 L
.16681 .90977 L
.09885 .85719 L
.04576 .7763 L
.0127 .66817 L
.00429 .53562 L
.02432 .38329 L
.07539 .21763 L
.15858 .04677 L
s
.15858 .04677 m
.19076 0 L
s
1 0 0 r
.46191 .57855 m
.44745 .57664 L
s
% Start of user PostScript
-4.5702998 9.426422 -6.3057095 9.196449 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4342 .5699 m
.4231 .55809 L
s
% Start of user PostScript
-7.8961357 8.3874111 -9.2274265 6.9704548 MAarrowhead1
% End of user PostScript
1 .473 0 r
.47058 .37553 m
.49848 .35015 L
s
% Start of user PostScript
-3.5309434 -14.935873 -0.18254196 -17.981716 MAarrowhead1
% End of user PostScript
1 .788 0 r
.70376 .41532 m
.71031 .46889 L
s
% Start of user PostScript
24.451553 -10.161682 25.2372 -3.7328215 MAarrowhead1
% End of user PostScript
.897 1 0 r
.40757 .90998 m
.32619 .93365 L
s
% Start of user PostScript
-11.091052 49.198 -20.857708 52.037819 MAarrowhead1
% End of user PostScript
.581 1 0 r
.02432 .38329 m
.07539 .21763 L
s
% Start of user PostScript
-57.08176 -14.005505 -50.953524 -33.883811 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
78.447098 -121.88358 99.810348 -112.78341 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
88.788001 141.20005 54.053677 187.53498 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-288.36736 211.84055 -317.049 147.89843 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
2.6449782 -563.06582 121.33101 -634.91397 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
781.62577 -99.41638 759.16694 135.18907 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-668.54548 1614.6906 -972.16451 1611.4878 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1559.0039 -1095.9937 -1241.0538 -1731.0074 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3136.4123 -3461.8328 3692.7079 -2915.8236 MAarrowhead1
% End of user PostScript
1 .563 0 r
.43912 .48912 m
.4448 .46844 L
.45453 .44689 L
.46827 .42564 L
.48572 .40599 L
.50636 .38934 L
.52936 .37706 L
.55367 .37049 L
.57802 .37076 L
.60096 .37878 L
.62093 .39509 L
.63635 .41983 L
.64569 .45265 L
.64759 .49266 L
.64094 .53843 L
.625 .58801 L
.59947 .63894 L
.56462 .68837 L
.52128 .73314 L
.47089 .76997 L
.41553 .79561 L
.35784 .80703 L
.30095 .80166 L
.24834 .77758 L
.20375 .73375 L
.17088 .67014 L
.15327 .58791 L
.15398 .4895 L
.17543 .3786 L
.21909 .26018 L
.28531 .14029 L
.37316 .0259 L
s
.37316 .0259 m
.40053 0 L
s
1 0 0 r
.43912 .48912 m
.4448 .46844 L
s
% Start of user PostScript
-7.3056541 -1.306098 -6.6239815 -3.7874489 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45453 .44689 m
.46827 .42564 L
s
% Start of user PostScript
-5.4565139 -6.3733174 -3.8081922 -8.9234077 MAarrowhead1
% End of user PostScript
1 .473 0 r
.62093 .39509 m
.63635 .41983 L
s
% Start of user PostScript
14.511985 -12.58932 16.362385 -9.6204061 MAarrowhead1
% End of user PostScript
1 .788 0 r
.52128 .73314 m
.47089 .76997 L
s
% Start of user PostScript
2.5533415 27.976653 -3.4929378 32.396435 MAarrowhead1
% End of user PostScript
.897 1 0 r
.15327 .58791 m
.15398 .4895 L
s
% Start of user PostScript
-41.608119 10.549482 -41.522101 -1.2605655 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
28.265105 -84.974642 44.627814 -86.99604 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
89.186688 43.222985 75.107916 77.036384 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-152.2959 194.41284 -184.86191 171.29709 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-113.57268 -281.99046 -47.747589 -354.34592 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
510.08024 -289.86877 542.90736 -165.81165 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-122.87078 1011.7957 -329.57788 1103.51 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1282.5774 -68.163974 -1196.91 -482.98825 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1419.2225 -2692.6704 1908.625 -2590.9812 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2285.5626 2463.6335 1638.5971 3505.2007 MAarrowhead1
% End of user PostScript
.899 1 0 r
.52237 .48093 m
.52515 .48555 L
.5268 .49165 L
.52707 .49905 L
.52577 .5075 L
.52275 .51663 L
.51798 .52598 L
.5115 .53502 L
.50347 .54318 L
.49416 .54986 L
.48397 .55444 L
.47337 .5564 L
.46294 .55524 L
.45335 .55065 L
.44525 .54241 L
.43934 .53056 L
.43626 .5153 L
.43658 .4971 L
.44071 .47664 L
.44894 .45486 L
.4613 .43287 L
.47762 .41195 L
.49745 .3935 L
.52007 .37895 L
.5445 .36967 L
.56953 .36694 L
.59375 .37177 L
.6156 .38489 L
.63347 .40663 L
.64576 .43683 L
.65099 .47482 L
.64791 .51937 L
.6356 .56869 L
.61357 .62048 L
.58183 .67199 L
.54098 .7201 L
.49226 .76148 L
.4375 .79279 L
.37918 .8108 L
.32031 .81267 L
.2643 .79615 L
.2149 .75976 L
.17593 .70304 L
.15109 .62666 L
.14375 .53255 L
.15668 .42398 L
.1918 .30548 L
.24998 .1828 L
.33082 .06271 L
s
.33082 .06271 m
.38879 0 L
s
1 0 0 r
.52237 .48093 m
.52515 .48555 L
s
% Start of user PostScript
2.6840858 -2.2883433 3.0178595 -1.7340426 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5268 .49165 m
.52707 .49905 L
s
% Start of user PostScript
3.2160998 -1.0025254 3.2489385 -0.11382055 MAarrowhead1
% End of user PostScript
1 .473 0 r
.48397 .55444 m
.47337 .5564 L
s
% Start of user PostScript
-1.9241149 6.5332436 -3.1959964 6.7674956 MAarrowhead1
% End of user PostScript
1 .788 0 r
.44071 .47664 m
.44894 .45486 L
s
% Start of user PostScript
-7.1142176 -2.8028159 -6.1273075 -5.4167733 MAarrowhead1
% End of user PostScript
.897 1 0 r
.59375 .37177 m
.6156 .38489 L
s
% Start of user PostScript
11.249827 -15.387656 13.872107 -13.812675 MAarrowhead1
% End of user PostScript
.581 1 0 r
.58183 .67199 m
.54098 .7201 L
s
% Start of user PostScript
9.819651 20.638774 4.9181661 26.411612 MAarrowhead1
% End of user PostScript
.266 1 0 r
.17593 .70304 m
.15109 .62666 L
s
% Start of user PostScript
-38.888886 24.364933 -41.869696 15.199132 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6.2124084 -76.717865 22.058174 -84.65462 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
100.45446 -1.3175981 95.14959 30.313146 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-101.88444 209.65564 -140.46909 204.4663 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-186.85622 -173.81396 -139.78852 -255.4044 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
435.05495 -422.83419 500.11361 -339.69215 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
139.81556 830.24732 -43.175675 981.68428 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1300.9039 446.88674 -1322.9176 92.748128 MAarrowhead1
% End of user PostScript
0 .45 1 r
.54628 .52239 m
.53898 .53993 L
.52839 .55742 L
.51469 .57382 L
.4983 .588 L
.47982 .59883 L
.46008 .60519 L
.4401 .60614 L
.42103 .60088 L
.40413 .5889 L
.3907 .57003 L
.38199 .54446 L
.37917 .51285 L
.38317 .47625 L
.39468 .4362 L
.41399 .39462 L
.44101 .35379 L
.47515 .31625 L
.51531 .28466 L
.55991 .26171 L
.60687 .24991 L
.65371 .25146 L
.69762 .26803 L
.73559 .30065 L
.76457 .3495 L
.78163 .41382 L
.78417 .49185 L
.77009 .58076 L
.73804 .67669 L
.68752 .77485 L
.61909 .8697 L
.53445 .95512 L
s
.53445 .95512 m
.47133 1 L
s
1 0 0 r
.54628 .52239 m
.53898 .53993 L
s
% Start of user PostScript
5.5537342 2.6863093 4.6781391 4.7912253 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52839 .55742 m
.51469 .57382 L
s
% Start of user PostScript
3.4069719 6.8906755 1.7633707 8.8587281 MAarrowhead1
% End of user PostScript
1 .473 0 r
.3907 .57003 m
.38199 .54446 L
s
% Start of user PostScript
-13.116505 8.4031932 -14.160995 5.3356638 MAarrowhead1
% End of user PostScript
1 .788 0 r
.51531 .28466 m
.55991 .26171 L
s
% Start of user PostScript
1.8371363 -25.840978 7.18868 -28.595176 MAarrowhead1
% End of user PostScript
.897 1 0 r
.78417 .49185 m
.77009 .58076 L
s
% Start of user PostScript
34.099904 -0.97746491 32.411029 9.6913497 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-33.846748 71.07012 -46.964747 69.529622 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-64.054458 -57.477415 -48.364109 -85.174801 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
146.20329 -144.55535 168.58566 -116.9323 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
50.411327 278.55219 -11.17782 330.46884 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-440.0762 157.25129 -448.80547 38.235901 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
235.32873 -890.23811 410.13148 -930.65992 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
997.13283 325.80234 872.9559 683.52174 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1483.3921 2144.2475 -1853.4856 1951.4489 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1455.348 -2699.9311 -804.65351 -3509.1808 MAarrowhead1
% End of user PostScript
.88 1 0 r
.56728 .48007 m
.56775 .49879 L
.56424 .52008 L
.55643 .54301 L
.54422 .56643 L
.52774 .589 L
.50741 .60927 L
.48394 .62572 L
.4583 .63687 L
.43173 .64134 L
.4057 .63797 L
.38182 .62593 L
.36181 .60477 L
.34738 .57455 L
.34013 .53586 L
.34144 .48988 L
.35239 .43838 L
.3736 .38369 L
.40517 .32867 L
.4466 .27653 L
.49673 .23078 L
.55373 .19499 L
.61512 .17263 L
.67781 .16681 L
.73825 .18009 L
.79252 .21421 L
.83658 .26992 L
.86643 .34677 L
.8784 .443 L
.8694 .55543 L
.83717 .67952 L
.78055 .80944 L
.69965 .93819 L
s
.69965 .93819 m
.6462 1 L
s
1 0 0 r
.56728 .48007 m
.56775 .49879 L
s
% Start of user PostScript
8.073787 -2.3921242 8.1299206 -0.14500474 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56424 .52008 m
.55643 .54301 L
s
% Start of user PostScript
7.7086879 2.4099628 6.7716492 5.1613984 MAarrowhead1
% End of user PostScript
1 .473 0 r
.4057 .63797 m
.38182 .62593 L
s
% Start of user PostScript
-11.316373 16.556592 -14.181654 15.111441 MAarrowhead1
% End of user PostScript
1 .788 0 r
.40517 .32867 m
.4466 .27653 L
s
% Start of user PostScript
-11.379283 -20.559959 -6.407752 -26.816354 MAarrowhead1
% End of user PostScript
.897 1 0 r
.83658 .26992 m
.86643 .34677 L
s
% Start of user PostScript
40.389425 -27.609119 43.971513 -18.38708 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-3.2425384 79.248619 -19.787466 88.452236 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-107.04624 7.9948663 -102.78423 -24.860674 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
99.388983 -222.18476 140.75656 -219.40279 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
206.886 166.26452 160.2984 253.22123 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-445.21937 463.27969 -518.249 382.14096 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-185.66176 -843.94788 2.7689234 -1011.6669 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1367.3254 -545.23658 1406.404 -182.76679 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-652.25174 2755.4283 -1197.5249 2904.64 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3164.8871 -849.33917 -2809.7426 -1960.8865 MAarrowhead1
% End of user PostScript
0 .099 1 r
.56517 .56608 m
.5476 .59524 L
.52485 .62261 L
.4976 .6463 L
.46685 .66443 L
.43399 .67516 L
.4007 .67687 L
.36889 .66827 L
.34066 .64848 L
.31818 .61721 L
.30355 .57478 L
.29868 .52224 L
.30518 .46138 L
.32415 .39472 L
.35615 .32547 L
.40098 .2574 L
.45768 .19473 L
.52446 .14193 L
.59867 .10345 L
.67688 .08349 L
.75495 .08572 L
.82821 .11295 L
.89166 .16688 L
.94019 .24787 L
.96894 .35467 L
.97355 .48437 L
.95053 .63226 L
.89758 .79196 L
.81386 .95551 L
s
.81386 .95551 m
.78191 1 L
s
1 0 0 r
.56517 .56608 m
.5476 .59524 L
s
% Start of user PostScript
7.8200658 7.9299937 5.7118543 11.429262 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52485 .62261 m
.4976 .6463 L
s
% Start of user PostScript
2.9823025 14.712851 -0.28853919 17.556221 MAarrowhead1
% End of user PostScript
1 .473 0 r
.30355 .57478 m
.29868 .52224 L
s
% Start of user PostScript
-23.574406 8.9737214 -24.158086 2.6691869 MAarrowhead1
% End of user PostScript
1 .788 0 r
.59867 .10345 m
.67688 .08349 L
s
% Start of user PostScript
11.840233 -47.586596 21.225171 -49.981232 MAarrowhead1
% End of user PostScript
.897 1 0 r
.95053 .63226 m
.89758 .79196 L
s
% Start of user PostScript
54.063522 15.871262 47.709269 35.034933 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-77.929768 115.92465 -98.064161 106.21903 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-81.021308 -141.22969 -46.712376 -185.10975 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
280.38949 -195.61744 306.09069 -132.10665 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-17.006738 549.41957 -132.01459 614.95964 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-747.78779 66.863891 -720.33948 -161.23164 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
678.95352 -1550.0527 968.35249 -1535.211 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1458.2162 1129.7885 1138.7353 1737.2585 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3079.425 3257.5339 -3595.7711 2703.1925 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1358.2539 -5827.3753 -52.919662 -7009.6059 MAarrowhead1
% End of user PostScript
1 0 .916 r
.52522 .55196 m
.51285 .56665 L
.49807 .57932 L
.48144 .58895 L
.4637 .59455 L
.44576 .59527 L
.42867 .5904 L
.41356 .57948 L
.40159 .56238 L
.39389 .53928 L
.3915 .51076 L
.39526 .4778 L
.40577 .44177 L
.42329 .40443 L
.44773 .3678 L
.47853 .33419 L
.51472 .30599 L
.55484 .2856 L
.59704 .27529 L
.63907 .277 L
.67841 .29224 L
.71234 .3219 L
.73812 .36613 L
.75314 .42424 L
.75506 .49459 L
.74203 .57464 L
.71282 .66089 L
.66704 .74904 L
.6052 .83406 L
.52885 .91049 L
.44061 .97261 L
s
.44061 .97261 m
.37804 1 L
s
.10682 1 m
.05613 .97469 L
s
.05613 .97469 m
0 .91579 L
s
0 .12454 m
.02313 .0646 L
s
.02313 .0646 m
.06005 0 L
s
1 0 0 r
.52522 .55196 m
.51285 .56665 L
s
% Start of user PostScript
3.0263091 6.2346233 1.5423214 7.9974807 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49807 .57932 m
.48144 .58895 L
s
% Start of user PostScript
-0.23123568 9.5181177 -2.2271491 10.673598 MAarrowhead1
% End of user PostScript
1 .473 0 r
.3915 .51076 m
.39526 .4778 L
s
% Start of user PostScript
-13.020088 1.2907975 -12.56889 -2.6643396 MAarrowhead1
% End of user PostScript
1 .788 0 r
.59704 .27529 m
.63907 .277 L
s
% Start of user PostScript
11.645229 -26.965107 16.688913 -26.759473 MAarrowhead1
% End of user PostScript
.897 1 0 r
.71282 .66089 m
.66704 .74904 L
s
% Start of user PostScript
25.538911 19.307189 20.044825 29.884374 MAarrowhead1
% End of user PostScript
.581 1 0 r
.05613 .97469 m
0 0 rlineto s
.05613 .97469 m
0 .91579 L
s
% Start of user PostScript
-53.264208 56.962401 -62.325662 47.453776 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-24.353602 -100.67988 -1.7519769 -121.38613 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
165.3934 -69.651763 170.90111 -26.284494 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-73.744084 332.61062 -139.8419 352.20177 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-387.18892 -92.098135 -346.2332 -226.55923 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
528.06871 -826.20256 673.08741 -765.6855 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
605.67473 949.42205 371.6411 1263.72 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1947.9181 1442.5185 -2144.0973 1012.0797 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1.7940358 -3801.3525 803.95618 -4291.4964 MAarrowhead1
% End of user PostScript
1 0 .959 r
.57996 .51879 m
.57155 .54653 L
.55775 .57518 L
.53868 .60317 L
.51475 .62873 L
.48676 .65002 L
.45584 .6652 L
.42343 .67254 L
.39127 .67058 L
.36131 .65818 L
.33564 .63469 L
.31635 .60004 L
.30544 .55482 L
.30468 .5003 L
.31547 .43851 L
.33871 .37216 L
.37465 .3046 L
.42286 .23969 L
.48208 .18166 L
.55026 .1349 L
.62452 .10368 L
.70124 .09194 L
.77618 .10297 L
.84462 .13915 L
.90162 .20166 L
.94227 .29029 L
.96194 .40323 L
.95669 .53697 L
.92351 .68632 L
.86065 .84445 L
s
.86065 .84445 m
.76971 1 L
s
1 0 0 r
.57996 .51879 m
.57155 .54653 L
s
% Start of user PostScript
9.595027 2.2547244 8.5859141 5.5832782 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55775 .57518 m
.53868 .60317 L
s
% Start of user PostScript
6.9304051 9.0220564 4.6411622 12.380658 MAarrowhead1
% End of user PostScript
1 .473 0 r
.33564 .63469 m
.31635 .60004 L
s
% Start of user PostScript
-19.723509 16.162706 -22.038419 12.005266 MAarrowhead1
% End of user PostScript
1 .788 0 r
.48208 .18166 m
.55026 .1349 L
s
% Start of user PostScript
-2.1501753 -38.200215 6.0313436 -43.812114 MAarrowhead1
% End of user PostScript
.897 1 0 r
.96194 .40323 m
.95669 .53697 L
s
% Start of user PostScript
55.433379 -11.612507 54.803344 4.4369734 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-41.058969 113.66462 -62.765552 115.33942 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-115.94239 -64.608786 -95.863225 -109.6529 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
209.71199 -254.30515 251.72705 -220.74464 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
137.72085 390.79968 47.589881 484.84576 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-686.58579 360.60641 -724.53221 189.80443 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
206.5756 -1367.4229 483.6845 -1478.5463 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1691.5442 176.78542 1560.2236 735.09798 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1992.7941 3567.4578 -2634.9401 3397.1184 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2911.9344 -3499.0796 -2011.63 -4872.6015 MAarrowhead1
% End of user PostScript
0 1 .201 r
.50736 .45527 m
.51639 .45182 L
.52564 .45079 L
.5346 .45256 L
.54269 .45739 L
.54931 .4654 L
.55388 .47655 L
.55583 .49057 L
.55472 .50703 L
.55019 .52526 L
.54207 .54441 L
.53036 .56346 L
.51528 .58127 L
.49728 .59659 L
.47704 .6082 L
.45548 .6149 L
.43371 .61564 L
.41299 .60958 L
.3947 .59619 L
.38025 .57527 L
.37102 .54707 L
.36825 .51232 L
.37298 .4722 L
.3859 .4284 L
.40736 .38304 L
.43719 .33861 L
.47474 .29789 L
.5188 .26381 L
.5676 .23927 L
.61887 .22701 L
.66988 .2294 L
.71755 .24825 L
.75859 .28462 L
.78967 .33868 L
.80762 .40955 L
.80961 .49526 L
.79341 .59266 L
.75754 .69751 L
.70155 .80453 L
.62608 .90765 L
s
.62608 .90765 m
.53322 1 L
s
1 0 0 r
.50736 .45527 m
.51639 .45182 L
s
% Start of user PostScript
0.88263836 -5.367759 1.9664305 -5.7812599 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52564 .45079 m
.5346 .45256 L
s
% Start of user PostScript
3.0772567 -5.9050435 4.1524707 -5.6931522 MAarrowhead1
% End of user PostScript
1 .473 0 r
.54207 .54441 m
.53036 .56346 L
s
% Start of user PostScript
5.0485019 5.3294069 3.6431697 7.6155759 MAarrowhead1
% End of user PostScript
1 .788 0 r
.3947 .59619 m
.38025 .57527 L
s
% Start of user PostScript
-12.636531 11.54221 -14.370175 9.0318379 MAarrowhead1
% End of user PostScript
.897 1 0 r
.47474 .29789 m
.5188 .26381 L
s
% Start of user PostScript
-3.0311241 -24.253021 2.2558496 -28.343375 MAarrowhead1
% End of user PostScript
.581 1 0 r
.80762 .40955 m
.80961 .49526 L
s
% Start of user PostScript
36.914373 -10.853813 37.153447 -0.56894874 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-22.994846 75.110264 -37.568618 77.526685 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-80.887079 -34.049198 -69.205668 -64.05096 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
130.94732 -175.36088 160.67897 -156.54405 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
109.07564 240.93312 52.165489 306.56491 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-448.24371 272.81996 -480.90941 166.1376 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
82.77335 -885.7648 265.11056 -973.90355 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1148.4159 7.8691388 1082.9298 372.43855 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1196.7085 2401.1001 -1636.9427 2332.2135 MAarrowhead1
% End of user PostScript
.407 0 1 r
.43353 .51163 m
.43477 .49209 L
.44007 .47042 L
.44964 .44763 L
.46349 .42493 L
.48136 .40368 L
.50272 .38535 L
.52677 .37141 L
.55242 .36328 L
.57836 .36223 L
.60308 .36925 L
.62495 .38501 L
.64227 .40972 L
.65342 .4431 L
.6569 .48432 L
.65149 .53197 L
.63632 .58405 L
.61101 .63806 L
.5757 .69102 L
.53118 .73965 L
.47887 .78045 L
.42085 .80997 L
.35984 .82492 L
.29905 .8225 L
.24216 .80051 L
.19307 .75768 L
.15574 .69378 L
.13398 .60981 L
.13115 .50812 L
.14993 .3924 L
.1921 .26768 L
.25824 .14022 L
.34761 .01725 L
s
.34761 .01725 m
.36482 0 L
s
1 0 0 r
.43353 .51163 m
.43477 .49209 L
s
% Start of user PostScript
-7.9760701 1.3961074 -7.8274286 -0.94865247 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44007 .47042 m
.44964 .44763 L
s
% Start of user PostScript
-7.192195 -3.5490391 -6.0434634 -6.2840108 MAarrowhead1
% End of user PostScript
1 .473 0 r
.60308 .36925 m
.62495 .38501 L
s
% Start of user PostScript
12.369837 -15.68967 14.993609 -13.799116 MAarrowhead1
% End of user PostScript
1 .788 0 r
.5757 .69102 m
.53118 .73965 L
s
% Start of user PostScript
9.0839443 22.922763 3.7413201 28.757535 MAarrowhead1
% End of user PostScript
.897 1 0 r
.15574 .69378 m
.13398 .60981 L
s
% Start of user PostScript
-41.310884 23.253347 -43.922491 13.177322 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
10.261588 -81.985844 26.9941 -89.320789 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
103.61201 6.1613919 96.553237 39.757174 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-115.56294 217.6473 -155.074 209.15941 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-183.86556 -200.90594 -131.24641 -285.0469 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
469.70649 -421.6345 532.58614 -327.36797 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
102.36645 902.87586 -93.871476 1051.8331 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1363.4098 382.17259 -1368.2919 -0.10736459 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
875.35873 -2777.6381 1412.9196 -2859.088 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2965.4662 1311.3854 2523.8917 2419.4471 MAarrowhead1
% End of user PostScript
0 1 .204 r
.461 .52532 m
.45782 .51624 L
.45674 .50499 L
.45809 .49194 L
.46212 .47763 L
.46895 .46275 L
.47853 .44811 L
.49068 .43461 L
.505 .42322 L
.52092 .41489 L
.53772 .41053 L
.55451 .41092 L
.57028 .41668 L
.58396 .42817 L
.59445 .44547 L
.60071 .46833 L
.6018 .49613 L
.59696 .52786 L
.58569 .56214 L
.56781 .59729 L
.54351 .63132 L
.51338 .66204 L
.47843 .6872 L
.44013 .70453 L
.40029 .71198 L
.36109 .70778 L
.32496 .69063 L
.29446 .65982 L
.27215 .61539 L
.26046 .55815 L
.2615 .48983 L
.2769 .41301 L
.30766 .33116 L
.35398 .24847 L
.41518 .16978 L
.48959 .1003 L
.57452 .04541 L
.66632 .01031 L
s
.66632 .01031 m
.75823 0 L
s
.76168 0 m
.85153 .01762 L
.93379 .06663 L
s
.93379 .06663 m
1 .14663 L
s
1 .78084 m
.92796 .95093 L
s
.92796 .95093 m
.89782 1 L
s
1 0 0 r
.461 .52532 m
.45782 .51624 L
s
% Start of user PostScript
-4.680464 3.0388037 -5.0616672 1.9493864 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45674 .50499 m
.45809 .49194 L
s
% Start of user PostScript
-5.1917666 0.5986601 -5.0295696 -0.96761529 MAarrowhead1
% End of user PostScript
1 .473 0 r
.53772 .41053 m
.55451 .41092 L
s
% Start of user PostScript
4.5265921 -10.736703 6.5409611 -10.689709 MAarrowhead1
% End of user PostScript
1 .788 0 r
.58569 .56214 m
.56781 .59729 L
s
% Start of user PostScript
10.282607 7.4573013 8.1372955 11.675116 MAarrowhead1
% End of user PostScript
.897 1 0 r
.32496 .69063 m
.29446 .65982 L
s
% Start of user PostScript
-21.004958 22.875551 -24.665372 19.178995 MAarrowhead1
% End of user PostScript
.581 1 0 r
.41518 .16978 m
.48959 .1003 L
s
% Start of user PostScript
-10.178135 -39.626697 -1.2493933 -47.964147 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
65.709404 -28.652923 68.104578 -11.550091 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-27.931547 131.96058 -54.229008 140.15293 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-154.98301 -33.768862 -139.24274 -87.190957 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
207.06132 -330.13326 265.22695 -307.20042 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
246.08704 371.12838 154.08498 496.94057 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-771.07224 583.37301 -851.33726 414.58185 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-16.507878 -1502.4399 301.49416 -1701.614 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2109.9595 -314.51529 2059.0719 312.83342 MAarrowhead1
% End of user PostScript
.065 0 1 r
.49356 .50146 m
.49361 .49961 L
.49404 .49753 L
.4949 .49533 L
.49616 .49311 L
.49783 .49101 L
.49985 .48916 L
.50215 .48771 L
.50462 .48681 L
.50715 .48657 L
.50958 .4871 L
.51178 .48846 L
.51356 .4907 L
.51476 .49379 L
.51525 .49767 L
.5149 .50219 L
.51361 .50719 L
.51133 .51243 L
.50808 .51762 L
.50391 .52245 L
.49896 .52659 L
.4934 .52969 L
.4875 .53144 L
.48156 .53154 L
.47593 .52977 L
.47098 .526 L
.46711 .52017 L
.46468 .51236 L
.46404 .50277 L
.46545 .49175 L
.46911 .47974 L
.4751 .46735 L
.48338 .45525 L
.49374 .44421 L
.50587 .43503 L
.51925 .4285 L
.53327 .42537 L
.54717 .42627 L
.56011 .43168 L
.57119 .44189 L
.5795 .45693 L
.58417 .47653 L
.58444 .50015 L
.57972 .5269 L
.56961 .55561 L
.55401 .58482 L
.5331 .61287 L
.50744 .63792 L
.47792 .65808 L
.44579 .6715 L
Mistroke
.41261 .67647 L
.38022 .67159 L
.35066 .65582 L
.32608 .62866 L
.30859 .59021 L
.30019 .54126 L
.30259 .48333 L
.31708 .41869 L
.3444 .35028 L
.38465 .2817 L
.43713 .217 L
.50035 .16057 L
.57197 .11686 L
.64883 .09018 L
.72705 .0844 L
.80214 .10262 L
.86921 .14697 L
.9232 .21828 L
.95913 .31589 L
.97247 .43747 L
.95941 .57897 L
.91721 .7346 L
.84451 .89696 L
Mfstroke
.84451 .89696 m
.77836 1 L
s
1 0 0 r
.49356 .50146 m
.49361 .49961 L
s
% Start of user PostScript
-0.77327327 0.17522745 -0.7672783 -0.046947493 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49404 .49753 m
.4949 .49533 L
s
% Start of user PostScript
-0.71472729 -0.2959049 -0.61255532 -0.56036386 MAarrowhead1
% End of user PostScript
1 .473 0 r
.50958 .4871 m
.51178 .48846 L
s
% Start of user PostScript
1.1501592 -1.5485843 1.4130601 -1.3843837 MAarrowhead1
% End of user PostScript
1 .788 0 r
.50808 .51762 m
.50391 .52245 L
s
% Start of user PostScript
0.96964797 2.114654 0.46946783 2.6945931 MAarrowhead1
% End of user PostScript
.897 1 0 r
.46711 .52017 m
.46468 .51236 L
s
% Start of user PostScript
-3.9469034 2.4202201 -4.2383257 1.4831736 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50587 .43503 m
.51925 .4285 L
s
% Start of user PostScript
0.70381017 -7.7960422 2.3100215 -8.5796187 MAarrowhead1
% End of user PostScript
.266 1 0 r
.58444 .50015 m
.57972 .5269 L
s
% Start of user PostScript
10.133282 0.017611602 9.5663891 3.2277745 MAarrowhead1
% End of user PostScript
0 1 .049 r
.41261 .67647 m
.38022 .67159 L
s
% Start of user PostScript
-10.487211 21.176938 -14.373682 20.59071 MAarrowhead1
% End of user PostScript
0 1 .364 r
.3444 .35028 m
.38465 .2817 L
s
% Start of user PostScript
-18.67159 -17.96628 -13.842163 -26.196383 MAarrowhead1
% End of user PostScript
0 1 .679 r
.86921 .14697 m
.9232 .21828 L
s
% Start of user PostScript
44.305756 -42.363108 50.783964 -33.805852 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
13.26629 84.682037 -5.3428503 99.813242 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-131.66051 43.502998 -133.52439 7.4390249 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
75.340174 -266.99876 127.50214 -277.61489 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
294.14293 107.6618 255.07375 214.67645 MAarrowhead1
% End of user PostScript
.072 0 1 r
.47712 .48571 m
.48141 .47662 L
.48737 .46772 L
.49489 .45955 L
.50371 .45272 L
.51348 .44779 L
.52375 .44531 L
.53397 .44577 L
.54353 .44953 L
.55176 .45679 L
.558 .4676 L
.56162 .48178 L
.56204 .49894 L
.55881 .51844 L
.55165 .53944 L
.54046 .56088 L
.52536 .58155 L
.50674 .60011 L
.48524 .61516 L
.46176 .62536 L
.43743 .62943 L
.41359 .62633 L
.39173 .61528 L
.37342 .59589 L
.36021 .5682 L
.35359 .53275 L
.35482 .49062 L
.36486 .44345 L
.38431 .39337 L
.41324 .34299 L
.4512 .29525 L
.49712 .25337 L
.54933 .22062 L
.60555 .20018 L
.66296 .19489 L
.7183 .20709 L
.76798 .23839 L
.8083 .28945 L
.8356 .35987 L
.84652 .44802 L
.83824 .55101 L
.80867 .66467 L
.75676 .78365 L
.68263 .90155 L
s
.68263 .90155 m
.59742 1 L
s
1 0 0 r
.47712 .48571 m
.48141 .47662 L
s
% Start of user PostScript
-2.7456144 -1.7147653 -2.2311267 -2.8053003 MAarrowhead1
% End of user PostScript
1 .158 0 r
.48737 .46772 m
.49489 .45955 L
s
% Start of user PostScript
-1.5150791 -3.8737401 -0.61333674 -4.8534244 MAarrowhead1
% End of user PostScript
1 .473 0 r
.558 .4676 m
.56162 .48178 L
s
% Start of user PostScript
6.9604902 -3.8877622 7.3941464 -2.1861487 MAarrowhead1
% End of user PostScript
1 .788 0 r
.48524 .61516 m
.46176 .62536 L
s
% Start of user PostScript
-1.7710559 13.819463 -4.5891744 15.042738 MAarrowhead1
% End of user PostScript
.897 1 0 r
.35482 .49062 m
.36486 .44345 L
s
% Start of user PostScript
-17.422034 -1.1250054 -16.216343 -6.7855178 MAarrowhead1
% End of user PostScript
.581 1 0 r
.66296 .19489 m
.7183 .20709 L
s
% Start of user PostScript
19.555505 -36.613296 26.195777 -35.148982 MAarrowhead1
% End of user PostScript
.266 1 0 r
.75676 .78365 m
.68263 .90155 L
s
% Start of user PostScript
30.811531 34.037628 21.915604 48.185498 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-79.227882 70.725057 -89.750916 54.773725 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-16.717472 -152.36634 16.368003 -177.32736 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
229.50884 -63.329166 230.11885 1.1512798 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-148.75112 467.75925 -239.20292 481.05162 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-498.00717 -223.63782 -423.13153 -410.16089 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
825.72544 -1082.2752 1008.2445 -960.58514 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
655.05417 1523.6543 297.08653 1927.7112 MAarrowhead1
% End of user PostScript
0 .167 1 r
.52383 .44994 m
.53307 .45102 L
.54157 .45516 L
.54872 .46253 L
.55392 .47312 L
.5566 .48672 L
.55625 .50293 L
.55251 .52111 L
.54514 .54046 L
.53409 .55997 L
.51954 .5785 L
.50188 .59482 L
.48177 .60766 L
.46006 .61578 L
.43784 .61809 L
.41638 .61365 L
.39704 .60185 L
.38126 .58241 L
.37047 .55546 L
.36597 .52161 L
.36886 .48197 L
.37995 .43812 L
.39968 .39213 L
.42802 .34645 L
.46443 .30384 L
.5078 .26726 L
.55649 .23968 L
.60829 .22396 L
.66053 .22261 L
.71015 .23762 L
.75384 .27028 L
.78822 .32098 L
.80998 .38911 L
.81616 .47293 L
.8043 .56952 L
.77271 .67482 L
.72066 .78372 L
.64852 .8902 L
.55791 .98759 L
s
.55791 .98759 m
.54171 1 L
s
1 0 0 r
.52383 .44994 m
.53307 .45102 L
s
% Start of user PostScript
2.8593883 -6.0075927 3.9683535 -5.8779099 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54157 .45516 m
.54872 .46253 L
s
% Start of user PostScript
4.9883167 -5.3804218 5.8466006 -4.4958242 MAarrowhead1
% End of user PostScript
1 .473 0 r
.51954 .5785 m
.50188 .59482 L
s
% Start of user PostScript
2.3445166 9.4203756 0.22607916 11.378643 MAarrowhead1
% End of user PostScript
1 .788 0 r
.37047 .55546 m
.36597 .52161 L
s
% Start of user PostScript
-15.543413 6.6546564 -16.084 2.5931253 MAarrowhead1
% End of user PostScript
.897 1 0 r
.55649 .23968 m
.60829 .22396 L
s
% Start of user PostScript
6.7786644 -31.237929 12.994581 -33.124475 MAarrowhead1
% End of user PostScript
.581 1 0 r
.8043 .56952 m
.77271 .67482 L
s
% Start of user PostScript
36.515756 8.3420644 32.725762 20.978711 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-49.323335 77.855038 -63.013127 72.290978 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-57.526247 -88.551433 -35.640655 -118.19349 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
182.74931 -136.70606 201.444 -96.500394 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
1.7431859 356.37862 -73.566129 402.93493 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-498.23909 70.063564 -485.33519 -78.619385 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
416.83573 -1028.0203 610.62931 -1028.7686 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1001.6578 679.38455 802.60709 1084.1799 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1980.608 2219.6024 -2338.9711 1879.1278 MAarrowhead1
% End of user PostScript
0 .652 1 r
.46158 .58247 m
.44631 .58095 L
.43221 .57441 L
.42028 .56255 L
.4115 .54539 L
.40684 .52323 L
.40712 .49674 L
.41297 .46692 L
.42479 .43509 L
.44267 .4029 L
.46635 .37222 L
.49518 .34507 L
.52815 .32355 L
.56382 .30968 L
.60044 .30532 L
.63595 .31198 L
.66807 .33075 L
.69445 .36211 L
.71275 .40586 L
.72079 .46106 L
.71674 .52593 L
.69922 .59789 L
.66749 .67359 L
.62155 .74902 L
.56223 .81965 L
.49132 .88061 L
.41147 .92699 L
.32628 .95409 L
.2401 .95771 L
.15794 .93452 L
.08525 .88233 L
.02761 .80038 L
s
.02761 .80038 m
0 .71803 L
s
0 .38289 m
.04682 .22164 L
.13075 .04224 L
s
.13075 .04224 m
.15887 0 L
s
1 0 0 r
.46158 .58247 m
.44631 .58095 L
s
% Start of user PostScript
-4.6102989 9.8962191 -6.4426346 9.7142291 MAarrowhead1
% End of user PostScript
1 .158 0 r
.43221 .57441 m
.42028 .56255 L
s
% Start of user PostScript
-8.1347266 8.9286845 -9.566991 7.5060699 MAarrowhead1
% End of user PostScript
1 .473 0 r
.46635 .37222 m
.49518 .34507 L
s
% Start of user PostScript
-4.0385965 -15.333531 -0.578057 -18.591415 MAarrowhead1
% End of user PostScript
1 .788 0 r
.71275 .40586 m
.72079 .46106 L
s
% Start of user PostScript
25.52965 -11.296546 26.494888 -4.672891 MAarrowhead1
% End of user PostScript
.897 1 0 r
.41147 .92699 m
.32628 .95409 L
s
% Start of user PostScript
-10.623316 51.239187 -20.846753 54.490571 MAarrowhead1
% End of user PostScript
.581 1 0 r
0 .38289 m
.04682 .22164 L
s
% Start of user PostScript
-60.408096 -12.647731 -54.381545 -33.40378 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
79.990167 -128.58095 102.68111 -119.85685 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
96.524285 143.17608 60.942969 192.21516 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-299.10775 228.37392 -330.68178 163.166 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-9.2966783 -582.42657 114.13905 -660.55434 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
820.92534 -127.97708 802.30999 115.38255 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-669.33717 1691.4846 -989.11929 1697.9444 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1665.1613 -1083.3352 -1343.9828 -1750.3211 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3228.3872 -3681.2912 3825.8869 -3134.4952 MAarrowhead1
% End of user PostScript
1 .182 0 r
.43555 .46036 m
.4475 .43485 L
.46417 .40981 L
.48519 .38683 L
.5099 .36753 L
.53731 .35357 L
.56614 .34647 L
.59486 .34759 L
.62176 .35795 L
.64497 .37816 L
.66263 .40832 L
.67294 .44797 L
.67431 .496 L
.66546 .55066 L
.64558 .60958 L
.61436 .66981 L
.57216 .72793 L
.52005 .7802 L
.4598 .82272 L
.39392 .85166 L
.3256 .86347 L
.25859 .85518 L
.19704 .82461 L
.14537 .7706 L
.10797 .69327 L
.08897 .59412 L
.09195 .47615 L
.11966 .34389 L
.17375 .20334 L
.25449 .06176 L
s
.25449 .06176 m
.3033 0 L
s
1 0 0 r
.43555 .46036 m
.4475 .43485 L
s
% Start of user PostScript
-7.7336684 -4.7563156 -6.300052 -7.8185471 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46417 .40981 m
.48519 .38683 L
s
% Start of user PostScript
-4.2998385 -10.822239 -1.7768722 -13.580467 MAarrowhead1
% End of user PostScript
1 .473 0 r
.66263 .40832 m
.67294 .44797 L
s
% Start of user PostScript
19.515105 -11.001609 20.752368 -6.2439038 MAarrowhead1
% End of user PostScript
1 .788 0 r
.4598 .82272 m
.39392 .85166 L
s
% Start of user PostScript
-4.8241102 38.726668 -12.729126 42.19868 MAarrowhead1
% End of user PostScript
.897 1 0 r
.09195 .47615 m
.11966 .34389 L
s
% Start of user PostScript
-48.96574 -2.8622553 -45.64031 -18.732807 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
54.54459 -102.84816 73.218911 -98.857545 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
86.950961 94.803159 62.110632 134.56722 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-221.83924 199.35466 -251.5832 154.86154 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-48.652759 -426.38132 44.037463 -496.82435 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
644.18804 -181.12884 646.61269 -0.58016229 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-412.81383 1312.2828 -666.82353 1350.9995 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1401.7912 -618.00042 -1193.4573 -1141.5419 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2308.2395 -3044.247 2822.4323 -2706.5065 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1857.3967 4255.7228 856.01336 5393.0843 MAarrowhead1
% End of user PostScript
.096 0 1 r
.54127 .48856 m
.54139 .50014 L
.53906 .51327 L
.53409 .52734 L
.52643 .54167 L
.51616 .55541 L
.50357 .56768 L
.48909 .57755 L
.47333 .5841 L
.45706 .58652 L
.44119 .58409 L
.42671 .57633 L
.41467 .56298 L
.40612 .5441 L
.40203 .52007 L
.40324 .49165 L
.41038 .45994 L
.42382 .4264 L
.44358 .39279 L
.46934 .36108 L
.50037 .33345 L
.5355 .31206 L
.57319 .29904 L
.61153 .29627 L
.64833 .30527 L
.68118 .32709 L
.7076 .36213 L
.72516 .41005 L
.73163 .46972 L
.72515 .53914 L
.70437 .61547 L
.66865 .69507 L
.6181 .77364 L
.55379 .84636 L
.4777 .90809 L
.39281 .95372 L
.30302 .97835 L
.21301 .97775 L
.12813 .94856 L
.05413 .88875 L
s
.05413 .88875 m
0 .80276 L
s
0 .29364 m
.03703 .17755 L
s
.03703 .17755 m
.12552 0 L
s
1 0 0 r
.54127 .48856 m
.54139 .50014 L
s
% Start of user PostScript
4.9525221 -1.3732525 4.9670966 0.017294159 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53906 .51327 m
.53409 .52734 L
s
% Start of user PostScript
4.6873911 1.5919586 4.0909034 3.2813483 MAarrowhead1
% End of user PostScript
1 .473 0 r
.44119 .58409 m
.42671 .57633 L
s
% Start of user PostScript
-7.0573764 10.091085 -8.7948371 9.1595798 MAarrowhead1
% End of user PostScript
1 .788 0 r
.44358 .39279 m
.46934 .36108 L
s
% Start of user PostScript
-6.770204 -12.865745 -3.6786679 -16.669809 MAarrowhead1
% End of user PostScript
.897 1 0 r
.7076 .36213 m
.72516 .41005 L
s
% Start of user PostScript
24.912399 -16.544343 27.019471 -10.793522 MAarrowhead1
% End of user PostScript
.581 1 0 r
.4777 .90809 m
.39281 .95372 L
s
% Start of user PostScript
-2.6757637 48.971357 -12.862283 54.445944 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-65.454883 3.5361344 -62.563395 -16.728419 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
62.656709 -136.10997 87.89997 -133.84503 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
124.9092 105.55429 95.690287 158.72263 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-276.00781 280.67279 -319.90315 229.52881 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-106.0004 -524.41151 10.565941 -625.66365 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
839.95695 -319.22834 860.64678 -94.532263 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-422.57238 1695.6064 -756.93881 1780.7166 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1925.6893 -566.94799 -1699.0132 -1249.7494 MAarrowhead1
% End of user PostScript
0 1 .271 r
.43146 .53604 m
.42766 .51899 L
.42767 .49855 L
.432 .47546 L
.44096 .45077 L
.45463 .42572 L
.47283 .40177 L
.49507 .38049 L
.52057 .3635 L
.54823 .35239 L
.5767 .3486 L
.60439 .35334 L
.62954 .36746 L
.65032 .39135 L
.66489 .42492 L
.67157 .46742 L
.66891 .51753 L
.65583 .57327 L
.6317 .63206 L
.59651 .6908 L
.55088 .74598 L
.49614 .79384 L
.43434 .83055 L
.36823 .85244 L
.30117 .85622 L
.23704 .83926 L
.18006 .79981 L
.13457 .73723 L
.10481 .65216 L
.09466 .5467 L
.10733 .42441 L
.14511 .29035 L
.20908 .15093 L
.29892 .01378 L
s
.29892 .01378 m
.31132 0 L
s
1 0 0 r
.43146 .53604 m
.42766 .51899 L
s
% Start of user PostScript
-8.2250388 4.3247307 -8.6806359 2.2792073 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42767 .49855 m
.432 .47546 L
s
% Start of user PostScript
-8.679212 -0.17459848 -8.1600003 -2.9447122 MAarrowhead1
% End of user PostScript
1 .473 0 r
.5767 .3486 m
.60439 .35334 L
s
% Start of user PostScript
9.204559 -18.167895 12.527268 -17.599282 MAarrowhead1
% End of user PostScript
1 .788 0 r
.6317 .63206 m
.59651 .6908 L
s
% Start of user PostScript
15.804306 15.846978 11.581505 22.895808 MAarrowhead1
% End of user PostScript
.897 1 0 r
.18006 .79981 m
.13457 .73723 L
s
% Start of user PostScript
-38.393057 35.976881 -43.852083 28.467016 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-10.475107 -73.517609 5.6226951 -86.324007 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
113.22643 -35.589973 114.4448 -4.3401876 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-67.329796 229.95526 -112.11905 238.32534 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-250.81171 -97.828081 -216.22611 -189.85596 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
395.24025 -542.30811 487.72622 -487.19293 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
347.35295 724.78653 175.08456 928.30973 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1368.2795 860.88387 -1473.9213 538.85855 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
213.53684 -2698.5923 771.19739 -2979.3509 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3538.6898 -56.769676 3354.0016 1056.1438 MAarrowhead1
% End of user PostScript
1 0 .078 r
.56547 .48665 m
.56465 .50565 L
.55986 .52684 L
.55087 .54926 L
.53765 .57172 L
.52042 .5929 L
.49968 .61136 L
.47619 .62563 L
.451 .63431 L
.42538 .63614 L
.4008 .63009 L
.37886 .61548 L
.36122 .59203 L
.34951 .55998 L
.34521 .52008 L
.34958 .47367 L
.36349 .42265 L
.3874 .36946 L
.42121 .31696 L
.46422 .26839 L
.51509 .22716 L
.57183 .19672 L
.63185 .18031 L
.69199 .18078 L
.74869 .20035 L
.79811 .2404 L
.83633 .30126 L
.85958 .38207 L
.86448 .48068 L
.8483 .59357 L
.8092 .71591 L
.74645 .84167 L
.66064 .96379 L
s
.66064 .96379 m
.62571 1 L
s
1 0 0 r
.56547 .48665 m
.56465 .50565 L
s
% Start of user PostScript
7.8563292 -1.6023823 7.7578762 0.67784343 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55986 .52684 m
.55087 .54926 L
s
% Start of user PostScript
7.1836614 3.2212535 6.1045821 5.9112102 MAarrowhead1
% End of user PostScript
1 .473 0 r
.4008 .63009 m
.37886 .61548 L
s
% Start of user PostScript
-11.904417 15.610747 -14.537399 13.857342 MAarrowhead1
% End of user PostScript
1 .788 0 r
.42121 .31696 m
.46422 .26839 L
s
% Start of user PostScript
-9.4545524 -21.96497 -4.2934698 -27.793425 MAarrowhead1
% End of user PostScript
.897 1 0 r
.83633 .30126 m
.85958 .38207 L
s
% Start of user PostScript
40.359324 -23.849228 43.149574 -14.151358 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-8.4490282 79.886485 -24.839215 87.524226 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-102.55905 -2.7652939 -96.27554 -35.589345 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
109.74496 -214.81419 148.98145 -207.80236 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
185.9261 189.27721 135.64663 272.56933 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-455.63506 423.77269 -519.74801 334.23676 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-119.87381 -873.07487 71.047727 -1023.7274 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1339.9731 -413.20025 1352.7061 -42.344946 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-807.93839 2722.884 -1337.6906 2818.609 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2958.8051 -1180.7145 -2545.1784 -2269.7993 MAarrowhead1
% End of user PostScript
.658 0 1 r
.43691 .57618 m
.42434 .56604 L
.4146 .55061 L
.40867 .53011 L
.40739 .50509 L
.41146 .47642 L
.42136 .44535 L
.43726 .4134 L
.45903 .38237 L
.48613 .35421 L
.51767 .331 L
.55235 .31478 L
.58854 .30744 L
.62425 .31061 L
.65732 .3255 L
.6854 .35277 L
.70617 .39246 L
.71741 .44385 L
.71718 .50542 L
.70396 .57487 L
.67683 .64911 L
.63553 .72433 L
.58065 .7962 L
.51366 .85997 L
.43693 .91076 L
.35375 .94381 L
.26821 .95481 L
.18511 .94014 L
.10972 .89727 L
.04757 .825 L
.00412 .72373 L
s
.00412 .72373 m
0 .69688 L
s
0 .41502 m
.03277 .27712 L
.10577 .10044 L
s
.10577 .10044 m
.16627 0 L
s
1 0 0 r
.43691 .57618 m
.42434 .56604 L
s
% Start of user PostScript
-7.5710971 9.141383 -9.0795755 7.9246534 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4146 .55061 m
.40867 .53011 L
s
% Start of user PostScript
-10.247431 6.0733192 -10.959663 3.6132909 MAarrowhead1
% End of user PostScript
1 .473 0 r
.51767 .331 m
.55235 .31478 L
s
% Start of user PostScript
2.1203388 -20.280239 6.2825689 -22.226955 MAarrowhead1
% End of user PostScript
1 .788 0 r
.71718 .50542 m
.70396 .57487 L
s
% Start of user PostScript
26.061327 0.65069089 24.475594 8.9849126 MAarrowhead1
% End of user PostScript
.897 1 0 r
.26821 .95481 m
.18511 .94014 L
s
% Start of user PostScript
-27.814905 54.576836 -37.787286 52.816739 MAarrowhead1
% End of user PostScript
.581 1 0 r
.10577 .10044 m
0 0 rlineto s
.10577 .10044 m
.16627 0 L
s
% Start of user PostScript
-47.307053 -47.947767 -34.558671 -69.113262 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
115.63659 -107.78526 131.95756 -85.092094 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
30.750514 221.5357 -17.712822 259.86815 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-340.35171 105.54308 -343.71053 11.422492 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
204.39266 -691.49947 338.97165 -716.05977 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
752.22947 298.20143 647.48857 574.82889 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1192.0795 1627.3738 -1469.2789 1460.0733 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1036.1195 -2187.5625 -516.85798 -2797.9562 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4117.098 -2572.702 4431.2422 -1601.4607 MAarrowhead1
% End of user PostScript
1 .422 0 r
.53697 .48672 m
.53772 .49671 L
.53632 .50823 L
.53256 .52079 L
.52637 .53378 L
.51777 .54649 L
.50697 .55812 L
.49432 .56783 L
.48032 .57478 L
.46563 .57821 L
.45104 .57742 L
.43742 .57192 L
.42572 .56139 L
.41689 .5458 L
.41184 .5254 L
.41138 .50077 L
.41614 .47282 L
.42654 .44276 L
.4427 .41212 L
.46443 .38264 L
.49118 .35623 L
.52201 .33488 L
.55564 .32053 L
.59042 .31498 L
.62444 .31972 L
.65558 .33584 L
.68158 .3639 L
.70021 .40381 L
.70938 .45477 L
.70729 .51522 L
.69256 .58281 L
.66438 .65445 L
.62265 .72643 L
.56804 .79448 L
.50211 .85404 L
.42728 .90041 L
.34681 .92908 L
.26477 .93597 L
.18583 .91778 L
.11512 .87226 L
.05795 .79847 L
.01953 .69706 L
.00464 .5704 L
.01731 .42267 L
.06046 .25988 L
.13556 .08974 L
s
.13556 .08974 m
.19252 0 L
s
1 0 0 r
.53697 .48672 m
.53772 .49671 L
s
% Start of user PostScript
4.4368977 -1.5934372 4.5265981 -0.39454499 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53632 .50823 m
.53256 .52079 L
s
% Start of user PostScript
4.3582913 0.9875072 3.9076613 2.494686 MAarrowhead1
% End of user PostScript
1 .473 0 r
.45104 .57742 m
.43742 .57192 L
s
% Start of user PostScript
-5.8755716 9.2907695 -7.5098094 8.6300759 MAarrowhead1
% End of user PostScript
1 .788 0 r
.4427 .41212 m
.46443 .38264 L
s
% Start of user PostScript
-6.8755766 -10.545506 -4.2678624 -14.083411 MAarrowhead1
% End of user PostScript
.897 1 0 r
.68158 .3639 m
.70021 .40381 L
s
% Start of user PostScript
21.789079 -16.332079 24.024938 -11.542606 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50211 .85404 m
.42728 .90041 L
s
% Start of user PostScript
0.25339826 42.484691 -8.726927 48.049206 MAarrowhead1
% End of user PostScript
.266 1 0 r
.00464 .5704 m
.01731 .42267 L
s
% Start of user PostScript
-59.443266 8.4476933 -57.922452 -9.2797376 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
49.607822 -122.6332 72.732073 -122.75943 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
119.60897 80.800207 95.908882 129.09517 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-236.05257 264.98425 -278.85749 224.46366 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-125.40012 -443.84841 -24.758155 -540.84212 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
747.76201 -344.74916 778.96183 -152.53366 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-291.82974 1498.2071 -591.80201 1599.2244 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1785.7025 -330.55003 -1616.6974 -938.51952 MAarrowhead1
% End of user PostScript
0 .983 1 r
.47669 .57316 m
.46255 .57522 L
.44875 .57308 L
.43618 .56629 L
.42573 .55464 L
.41833 .53818 L
.41481 .51726 L
.4159 .49252 L
.42216 .46493 L
.43388 .43576 L
.45112 .40654 L
.47356 .37899 L
.50057 .355 L
.53114 .33647 L
.56392 .32521 L
.59725 .32288 L
.62923 .33081 L
.65775 .34988 L
.68067 .38044 L
.69586 .4222 L
.7014 .47416 L
.69566 .53458 L
.67749 .60098 L
.64631 .6702 L
.60226 .73849 L
.54624 .80165 L
.48001 .85523 L
.40615 .89476 L
.32805 .91601 L
.24981 .91527 L
.17608 .88968 L
.11184 .83744 L
.0622 .75812 L
.03205 .65284 L
.0258 .52444 L
.047 .37747 L
.09804 .21825 L
.17984 .05463 L
s
.17984 .05463 m
.21828 0 L
s
1 0 0 r
.47669 .57316 m
.46255 .57522 L
s
% Start of user PostScript
-2.7972032 8.7791201 -4.4945454 9.0268963 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44875 .57308 m
.43618 .56629 L
s
% Start of user PostScript
-6.1498469 8.7693306 -7.6587936 7.9544978 MAarrowhead1
% End of user PostScript
1 .473 0 r
.45112 .40654 m
.47356 .37899 L
s
% Start of user PostScript
-5.8660156 -11.215793 -3.1729478 -14.520629 MAarrowhead1
% End of user PostScript
1 .788 0 r
.68067 .38044 m
.69586 .4222 L
s
% Start of user PostScript
21.680419 -14.347512 23.50348 -9.3362519 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48001 .85523 m
.40615 .89476 L
s
% Start of user PostScript
-2.3989323 42.627523 -11.261994 47.370828 MAarrowhead1
% End of user PostScript
.581 1 0 r
.0258 .52444 m
.047 .37747 L
s
% Start of user PostScript
-56.903684 2.9322266 -54.359992 -14.703235 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
54.668792 -118.35466 76.6088 -116.32644 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
108.42344 92.17261 82.944904 138.39463 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-240.34532 243.73147 -278.42634 199.10843 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-91.362481 -456.77923 10.116781 -544.66688 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
730.63071 -276.03699 748.28117 -80.374769 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-369.85835 1475.2174 -660.64214 1548.5655 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1673.1126 -497.87684 -1475.0511 -1091.8038 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2421.0471 -3588.7889 3043.894 -3285.6312 MAarrowhead1
% End of user PostScript
.304 0 1 r
.43279 .54372 m
.4273 .52809 L
.42541 .5087 L
.42772 .48621 L
.43465 .46155 L
.4464 .4359 L
.4629 .41065 L
.48382 .38737 L
.50849 .36771 L
.53594 .35332 L
.5649 .34577 L
.59384 .3464 L
.62104 .35628 L
.64465 .37605 L
.66277 .40584 L
.67359 .44521 L
.67551 .49309 L
.66721 .54776 L
.64784 .60686 L
.61707 .66745 L
.57523 .72613 L
.52332 .77914 L
.46312 .82255 L
.39709 .85251 L
.32841 .86544 L
.26082 .8583 L
.1985 .82883 L
.14586 .77584 L
.10732 .69933 L
.08708 .60076 L
.08876 .48305 L
.1152 .35067 L
.1681 .20958 L
.24784 .06702 L
s
.24784 .06702 m
.29988 0 L
s
1 0 0 r
.43279 .54372 m
.4273 .52809 L
s
% Start of user PostScript
-8.0651504 5.246431 -8.7241552 3.3705046 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42541 .5087 m
.42772 .48621 L
s
% Start of user PostScript
-8.9506271 1.0437962 -8.6734688 -1.6549582 MAarrowhead1
% End of user PostScript
1 .473 0 r
.5649 .34577 m
.59384 .3464 L
s
% Start of user PostScript
7.78756 -18.507939 11.260786 -18.431801 MAarrowhead1
% End of user PostScript
1 .788 0 r
.64784 .60686 m
.61707 .66745 L
s
% Start of user PostScript
17.741052 12.822758 14.048863 20.094311 MAarrowhead1
% End of user PostScript
.897 1 0 r
.1985 .82883 m
.14586 .77584 L
s
% Start of user PostScript
-36.179989 39.460094 -42.497131 33.100463 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-17.612267 -68.244174 -2.2307431 -82.629239 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
113.24964 -49.52033 117.40667 -20.061449 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-47.948625 227.40745 -93.277321 241.58412 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-267.27376 -57.805668 -240.21984 -149.87849 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
356.48577 -569.24653 456.81086 -529.87729 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
424.8927 638.7877 266.46464 855.75614 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1328.5425 1006.8761 -1467.2039 716.27632 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-30.86068 -2588.3514 517.11677 -2932.248 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3637.4651 -546.89575 3550.7266 534.01717 MAarrowhead1
% End of user PostScript
0 1 .021 r
.44694 .53181 m
.44317 .51912 L
.4423 .5036 L
.44475 .48579 L
.45081 .46647 L
.46062 .44657 L
.47409 .42721 L
.49089 .40961 L
.51047 .39506 L
.53204 .38483 L
.55457 .3801 L
.57684 .3819 L
.59749 .39098 L
.61508 .40777 L
.62815 .43229 L
.63532 .46412 L
.63537 .50233 L
.62736 .54548 L
.61068 .59167 L
.58518 .63854 L
.55121 .68339 L
.50966 .72328 L
.462 .75516 L
.41026 .77607 L
.35698 .7833 L
.30514 .77459 L
.25802 .74835 L
.21906 .70381 L
.19166 .64118 L
.179 .5618 L
.1838 .46815 L
.20809 .36394 L
.25303 .25397 L
.31868 .14402 L
.40388 .04067 L
s
.40388 .04067 m
.45025 0 L
s
1 0 0 r
.44694 .53181 m
.44317 .51912 L
s
% Start of user PostScript
-6.3673384 3.8171799 -6.8190639 2.2942289 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4423 .5036 m
.44475 .48579 L
s
% Start of user PostScript
-6.9242706 0.43167946 -6.6305458 -1.7046094 MAarrowhead1
% End of user PostScript
1 .473 0 r
.55457 .3801 m
.57684 .3819 L
s
% Start of user PostScript
6.5480192 -14.387919 9.2206198 -14.172334 MAarrowhead1
% End of user PostScript
1 .788 0 r
.61068 .59167 m
.58518 .63854 L
s
% Start of user PostScript
13.281655 11.000599 10.221865 16.625222 MAarrowhead1
% End of user PostScript
.897 1 0 r
.25802 .74835 m
.21906 .70381 L
s
% Start of user PostScript
-29.037345 29.802501 -33.713252 24.457327 MAarrowhead1
% End of user PostScript
.581 1 0 r
.40388 .04067 m
0 0 rlineto s
.40388 .04067 m
.45025 0 L
s
% Start of user PostScript
-11.53396 -55.119469 0.73982787 -65.886075 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
88.690899 -34.373454 91.016132 -10.733835 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-43.691325 178.9146 -79.022386 188.17912 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-204.11839 -57.947974 -180.54442 -130.04609 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
291.47568 -437.30889 367.56886 -401.48821 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
308.22549 527.53836 179.7602 693.21246 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1053.1114 742.36369 -1151.2559 504.81141 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
53.223588 -2062.1329 485.47136 -2311.4821 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2817.6195 -273.12474 2718.6671 583.59071 MAarrowhead1
% End of user PostScript
.517 0 1 r
.56779 .51342 m
.56119 .53662 L
.55006 .56072 L
.53447 .58441 L
.51474 .60621 L
.4915 .62459 L
.46568 .63798 L
.43847 .64493 L
.4113 .64416 L
.38581 .63469 L
.36373 .61593 L
.34683 .58775 L
.33683 .55059 L
.33522 .50547 L
.34322 .45401 L
.36164 .39844 L
.39077 .34153 L
.43028 .28649 L
.47922 .23686 L
.53591 .19631 L
.598 .16848 L
.66252 .15671 L
.72594 .16384 L
.78433 .19197 L
.83353 .24222 L
.8694 .31453 L
.88801 .40753 L
.88596 .51843 L
.86063 .64299 L
.81041 .77561 L
.73499 .90945 L
s
.73499 .90945 m
.6642 1 L
s
1 0 0 r
.56779 .51342 m
.56119 .53662 L
s
% Start of user PostScript
8.1353155 1.6109843 7.3431878 4.3943382 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55006 .56072 m
.53447 .58441 L
s
% Start of user PostScript
6.0076671 7.2862282 4.1360474 10.128643 MAarrowhead1
% End of user PostScript
1 .473 0 r
.36373 .61593 m
.34683 .58775 L
s
% Start of user PostScript
-16.352748 13.91111 -18.379804 10.530094 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47922 .23686 m
.53591 .19631 L
s
% Start of user PostScript
-2.494009 -31.576606 4.30873 -36.442318 MAarrowhead1
% End of user PostScript
.897 1 0 r
.88801 .40753 m
.88596 .51843 L
s
% Start of user PostScript
46.561631 -11.096458 46.315749 2.2111127 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-32.617694 95.223141 -50.901409 97.189607 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-98.96888 -50.407695 -82.830137 -88.245304 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
172.40446 -216.19196 208.4493 -189.52189 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
123.14902 319.94845 48.780805 400.23544 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-572.84377 316.95322 -607.89876 176.52338 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
149.94559 -1137.8932 381.76037 -1237.3142 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1430.2776 101.23543 1329.4219 567.08625 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1617.7927 3007.4561 -2162.5938 2883.5409 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2519.0374 -2819.8802 -1783.9116 -3981.3458 MAarrowhead1
% End of user PostScript
0 .662 1 r
.49506 .42709 m
.51072 .41612 L
.52783 .40868 L
.54555 .4057 L
.56292 .40795 L
.57885 .41599 L
.5922 .43011 L
.60183 .45027 L
.60666 .47609 L
.60578 .50676 L
.59847 .54112 L
.58432 .57761 L
.56326 .61432 L
.53562 .6491 L
.50217 .67962 L
.46414 .7035 L
.42318 .71841 L
.38136 .72229 L
.34104 .71343 L
.30483 .69066 L
.27544 .65348 L
.25553 .60221 L
.24754 .53801 L
.25355 .463 L
.27506 .3802 L
.31284 .29353 L
.36682 .20763 L
.43593 .12772 L
.51806 .05938 L
.61004 .00822 L
s
.61004 .00822 m
.63807 0 L
s
.87498 0 m
.89913 .00765 L
.98086 .07045 L
s
.98086 .07045 m
1 .09943 L
s
1 .85866 m
.93144 1 L
s
1 0 0 r
.49506 .42709 m
.51072 .41612 L
s
% Start of user PostScript
-0.5930567 -8.7487229 1.2862902 -10.065829 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52783 .40868 m
.54555 .4057 L
s
% Start of user PostScript
3.3391594 -10.958013 5.466229 -11.315493 MAarrowhead1
% End of user PostScript
1 .473 0 r
.59847 .54112 m
.58432 .57761 L
s
% Start of user PostScript
11.816927 4.9348942 10.118688 9.3128139 MAarrowhead1
% End of user PostScript
1 .788 0 r
.34104 .71343 m
.30483 .69066 L
s
% Start of user PostScript
-19.075413 25.611415 -23.420459 22.878865 MAarrowhead1
% End of user PostScript
.897 1 0 r
.36682 .20763 m
.43593 .12772 L
s
% Start of user PostScript
-15.981491 -35.084977 -7.6887315 -44.673308 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
65.37474 -39.932653 70.169061 -24.391852 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-11.87322 129.159 -38.47189 142.07328 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-167.6607 -0.73688269 -158.18713 -53.908293 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
174.13722 -350.46707 238.42405 -340.58187 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
308.4066 298.54316 228.25987 434.7139 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-734.3056 700.06245 -841.24088 557.97379 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-217.01931 -1403.8671 91.323079 -1653.7923 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2179.6758 -715.11534 2209.4588 -117.40953 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1254.3657 4421.1858 -2117.7275 4594.8171 MAarrowhead1
% End of user PostScript
0 .017 1 r
.49636 .48942 m
.49879 .4869 L
.50162 .48483 L
.50473 .48338 L
.50798 .48274 L
.51118 .48304 L
.51414 .48438 L
.51665 .48684 L
.5185 .49042 L
.51949 .49503 L
.51946 .50056 L
.51826 .5068 L
.51581 .51345 L
.51209 .52019 L
.50716 .52663 L
.50114 .53233 L
.49425 .53687 L
.48679 .53981 L
.47912 .54076 L
.47168 .53941 L
.46494 .53554 L
.45939 .52903 L
.45552 .51992 L
.45379 .5084 L
.45458 .49486 L
.45819 .47982 L
.46477 .46398 L
.47433 .44817 L
.4867 .43336 L
.5015 .42055 L
.51819 .41076 L
.53601 .405 L
.55406 .40414 L
.57128 .40888 L
.58655 .41968 L
.59869 .43671 L
.60657 .45978 L
.60913 .48833 L
.60553 .52137 L
.59515 .55754 L
.57772 .59509 L
.55334 .63197 L
.52252 .66589 L
.48626 .69443 L
.44599 .71518 L
.40358 .72586 L
.36127 .72449 L
.3216 .70955 L
.28729 .68012 L
.2611 .63604 L
Mistroke
.24567 .57797 L
.24335 .50753 L
.25602 .42725 L
.28494 .34062 L
.33052 .25196 L
.39229 .1663 L
.4687 .08912 L
.55716 .02617 L
Mfstroke
.55716 .02617 m
.61599 0 L
s
.90116 0 m
.94407 .02091 L
s
.94407 .02091 m
1 .07853 L
s
1 .88568 m
.98231 .93212 L
s
.98231 .93212 m
.94388 1 L
s
1 0 0 r
.49636 .48942 m
.49879 .4869 L
s
% Start of user PostScript
-0.43717901 -1.2694716 -0.14496453 -1.5717437 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50162 .48483 m
.50473 .48338 L
s
% Start of user PostScript
0.19480303 -1.8205295 0.56819274 -1.9938707 MAarrowhead1
% End of user PostScript
1 .473 0 r
.51946 .50056 m
.51826 .5068 L
s
% Start of user PostScript
2.3348818 0.067737336 2.1908207 0.81563416 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47912 .54076 m
.47168 .53941 L
s
% Start of user PostScript
-2.5051391 4.8913979 -3.3982234 4.7297714 MAarrowhead1
% End of user PostScript
.897 1 0 r
.46477 .46398 m
.47433 .44817 L
s
% Start of user PostScript
-4.2271977 -4.3228794 -3.0799351 -6.219117 MAarrowhead1
% End of user PostScript
.581 1 0 r
.58655 .41968 m
.59869 .43671 L
s
% Start of user PostScript
10.386426 -9.6384874 11.843349 -7.5946808 MAarrowhead1
% End of user PostScript
.266 1 0 r
.52252 .66589 m
.48626 .69443 L
s
% Start of user PostScript
2.7024658 19.906201 -1.6488614 23.331387 MAarrowhead1
% End of user PostScript
0 1 .049 r
.24567 .57797 m
.24335 .50753 L
s
% Start of user PostScript
-30.519865 9.3569247 -30.798413 0.90313582 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
18.477658 -62.027824 30.541479 -64.185454 MAarrowhead1
% End of user PostScript
0 1 .679 r
1 .88568 m
.98231 .93212 L
s
% Start of user PostScript
67.327125 27.04874 57.876756 51.854152 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-107.19487 145.7224 -131.99151 130.59889 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-92.313489 -196.82595 -45.643583 -251.45761 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
369.49492 -229.57456 397.41044 -142.23918 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-61.70603 729.27793 -212.1881 803.88526 MAarrowhead1
% End of user PostScript
.509 1 0 r
.57924 .49234 m
.57645 .51644 L
.56873 .54276 L
.55589 .57004 L
.538 .59677 L
.51546 .6213 L
.48901 .64185 L
.45968 .65668 L
.42885 .66414 L
.39817 .66281 L
.36946 .65159 L
.34473 .62983 L
.32596 .59744 L
.31506 .55492 L
.31375 .50346 L
.32337 .44495 L
.34481 .38193 L
.37835 .31756 L
.42361 .2555 L
.47946 .19975 L
.54397 .15449 L
.61444 .12381 L
.68748 .11148 L
.75905 .12067 L
.82471 .15372 L
.87975 .21181 L
.91946 .29482 L
.93945 .40112 L
.9359 .52748 L
.90587 .66902 L
.84765 .81932 L
.76093 .9706 L
s
.76093 .9706 m
.73759 1 L
s
1 0 0 r
.57924 .49234 m
.57645 .51644 L
s
% Start of user PostScript
9.5086296 -0.91895374 9.1741118 1.9725631 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56873 .54276 m
.55589 .57004 L
s
% Start of user PostScript
8.2479411 5.1314441 6.7065735 8.4049036 MAarrowhead1
% End of user PostScript
1 .473 0 r
.36946 .65159 m
.34473 .62983 L
s
% Start of user PostScript
-15.664208 18.190594 -18.632701 15.579983 MAarrowhead1
% End of user PostScript
1 .788 0 r
.42361 .2555 m
.47946 .19975 L
s
% Start of user PostScript
-9.1662985 -29.340288 -2.4647016 -36.029561 MAarrowhead1
% End of user PostScript
.897 1 0 r
.91946 .29482 m
.93945 .40112 L
s
% Start of user PostScript
50.335597 -24.621514 52.734385 -11.865153 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-17.673791 100.58813 -37.920302 107.97794 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-121.87204 -18.182251 -111.26148 -59.110365 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
151.16173 -258.04237 197.21956 -243.49953 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
203.38034 267.76144 135.56701 366.71047 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-582.98605 474.87136 -650.80542 351.61623 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-59.564096 -1129.6531 182.15555 -1294.3349 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1635.1193 -335.00268 1614.9456 139.38135 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1221.6087 3354.1709 -1861.6013 3400.4324 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3411.0773 -1927.4272 -2814.7237 -3256.0799 MAarrowhead1
% End of user PostScript
.919 1 0 r
.44087 .58142 m
.42697 .57321 L
.41557 .55955 L
.4077 .54051 L
.40428 .51652 L
.40612 .48835 L
.41379 .45712 L
.42763 .42429 L
.44763 .39161 L
.47342 .36104 L
.50422 .33469 L
.53888 .31469 L
.57582 .30307 L
.61317 .30165 L
.64874 .31188 L
.68018 .33468 L
.70505 .37038 L
.72102 .41856 L
.72592 .47801 L
.718 .54669 L
.69603 .62173 L
.65945 .69951 L
.60848 .77574 L
.54426 .84567 L
.46885 .90431 L
.38525 .94664 L
.29737 .96796 L
.20987 .96423 L
.12802 .9323 L
.05745 .87035 L
.00389 .77806 L
s
.00389 .77806 m
0 .76292 L
s
0 .33261 m
.05734 .16381 L
s
.05734 .16381 m
.14263 0 L
s
1 0 0 r
.44087 .58142 m
.42697 .57321 L
s
% Start of user PostScript
-7.0961929 9.7708702 -8.763916 8.7857405 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41557 .55955 m
.4077 .54051 L
s
% Start of user PostScript
-10.131044 7.1454912 -11.076023 4.8607129 MAarrowhead1
% End of user PostScript
1 .473 0 r
.50422 .33469 m
.53888 .31469 L
s
% Start of user PostScript
0.50662154 -19.837217 4.6650389 -22.237598 MAarrowhead1
% End of user PostScript
1 .788 0 r
.72592 .47801 m
.718 .54669 L
s
% Start of user PostScript
27.110367 -2.6386279 26.160531 5.6030739 MAarrowhead1
% End of user PostScript
.897 1 0 r
.29737 .96796 m
.20987 .96423 L
s
% Start of user PostScript
-24.315989 56.155765 -34.816056 55.70714 MAarrowhead1
% End of user PostScript
.581 1 0 r
.05734 .16381 m
0 0 rlineto s
.05734 .16381 m
.14263 0 L
s
% Start of user PostScript
-53.119171 -40.342448 -41.652845 -62.366122 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
111.04334 -118.51231 129.8835 -98.657965 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
50.43596 209.93876 3.3260627 253.00599 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-344.5224 144.51473 -355.87424 54.104623 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
154.411 -692.95072 292.07409 -733.52104 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
805.85746 193.49347 720.23433 473.5813 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1101.5914 1719.9151 -1403.3504 1593.2064 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1258.46 -1981.2386 -770.38544 -2635.3845 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4059.2546 -2998.8318 4466.5467 -2100.9106 MAarrowhead1
% End of user PostScript
1 .506 0 r
.42212 .45681 m
.43556 .42657 L
.45464 .3967 L
.47896 .369 L
.50778 .34543 L
.53997 .32794 L
.57406 .31838 L
.60827 .31838 L
.64059 .32921 L
.66882 .35167 L
.69074 .38596 L
.70421 .43162 L
.70729 .48744 L
.69842 .55144 L
.67653 .6209 L
.64121 .69239 L
.59276 .76193 L
.53232 .8251 L
.46192 .8773 L
.3844 .91395 L
.30347 .93079 L
.22347 .92418 L
.14932 .8914 L
.0862 .83091 L
.03936 .74263 L
.01376 .62813 L
.01374 .49074 L
.04272 .33561 L
.10283 .16963 L
.19462 .00125 L
s
.19462 .00125 m
.19557 0 L
s
1 0 0 r
.42212 .45681 m
.43556 .42657 L
s
% Start of user PostScript
-9.3460583 -5.1833477 -7.7327068 -8.8111379 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45464 .3967 m
.47896 .369 L
s
% Start of user PostScript
-5.4433881 -12.396497 -2.5246253 -15.719957 MAarrowhead1
% End of user PostScript
1 .473 0 r
.69074 .38596 m
.70421 .43162 L
s
% Start of user PostScript
22.888786 -13.684482 24.50476 -8.2051 MAarrowhead1
% End of user PostScript
1 .788 0 r
.46192 .8773 m
.3844 .91395 L
s
% Start of user PostScript
-4.5701869 45.276 -13.871528 49.673841 MAarrowhead1
% End of user PostScript
.897 1 0 r
.01374 .49074 m
.04272 .33561 L
s
% Start of user PostScript
-58.351207 -1.1110267 -54.873752 -19.726668 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
61.795664 -122.13286 84.136958 -118.33621 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
106.32797 106.36015 77.971662 153.75026 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-257.94513 241.99719 -294.68199 191.57871 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-70.7747 -493.87754 37.389825 -580.0367 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
761.05204 -239.9328 769.39212 -29.979465 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-451.56209 1545.5123 -752.64053 1602.0697 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1686.6745 -655.4967 -1454.5942 -1274.0639 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2654.616 -3646.5036 3276.6624 -3276.8554 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2338.7108 4867.2347 1181.5201 6235.9049 MAarrowhead1
% End of user PostScript
0 .881 1 r
.55484 .41674 m
.56936 .42335 L
.58168 .43542 L
.59077 .45294 L
.59566 .4756 L
.59549 .50273 L
.58961 .53332 L
.5776 .56598 L
.55936 .59907 L
.53515 .63065 L
.50563 .65864 L
.47183 .6809 L
.43522 .69534 L
.3976 .70004 L
.36107 .69345 L
.32796 .67444 L
.30071 .6425 L
.28171 .5978 L
.2732 .54132 L
.27709 .47486 L
.29478 .40105 L
.32707 .32331 L
.37397 .24575 L
.43463 .17304 L
.50727 .11014 L
.58914 .06211 L
.67661 .0338 L
.76518 .02953 L
.84973 .05275 L
.92469 .10573 L
.98429 .18927 L
s
.98429 .18927 m
1 .23526 L
s
1 .66725 m
.96707 .78213 L
.88157 .96641 L
s
.88157 .96641 m
.85937 1 L
s
1 0 0 r
.55484 .41674 m
.56936 .42335 L
s
% Start of user PostScript
6.5805684 -9.9910549 8.3234175 -9.1975797 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58168 .43542 m
.59077 .45294 L
s
% Start of user PostScript
9.8019445 -7.7499426 10.892781 -5.6473751 MAarrowhead1
% End of user PostScript
1 .473 0 r
.50563 .65864 m
.47183 .6809 L
s
% Start of user PostScript
0.67518335 19.036902 -3.3800113 21.708094 MAarrowhead1
% End of user PostScript
1 .788 0 r
.2732 .54132 m
.27709 .47486 L
s
% Start of user PostScript
-27.215739 4.9588669 -26.749725 -3.0166758 MAarrowhead1
% End of user PostScript
.897 1 0 r
.67661 .0338 m
.76518 .02953 L
s
% Start of user PostScript
21.192669 -55.943501 31.821523 -56.456224 MAarrowhead1
% End of user PostScript
.581 1 0 r
.96707 .78213 m
.88157 .96641 L
s
% Start of user PostScript
56.048333 33.855782 45.788201 55.969384 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-105.03173 123.42387 -125.24256 106.10665 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-63.484847 -196.46199 -18.493959 -241.9204 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
339.22216 -169.26881 356.09284 -83.732075 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-114.45577 677.26218 -251.02844 728.45589 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-825.25717 -112.93037 -755.55843 -388.75977 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1009.3965 -1745.4359 1321.6654 -1651.2078 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1389.2026 1783.8393 935.52223 2453.8923 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3919.2678 3235.2298 -4384.2309 2412.1404 MAarrowhead1
% End of user PostScript
1 0 .976 r
.45645 .58031 m
.44192 .5769 L
.42892 .56844 L
.41843 .55477 L
.4114 .53601 L
.40873 .51261 L
.41114 .48535 L
.41917 .45532 L
.43309 .42397 L
.45285 .39297 L
.47806 .36423 L
.50793 .33976 L
.54131 .32158 L
.57667 .31163 L
.61216 .31159 L
.64569 .32277 L
.675 .34601 L
.69777 .38154 L
.71178 .42885 L
.71503 .48671 L
.70588 .55307 L
.68324 .62509 L
.64665 .69925 L
.59645 .7714 L
.53381 .83697 L
.46082 .89117 L
.38044 .92926 L
.29649 .94683 L
.2135 .94008 L
.13655 .90619 L
.07102 .84357 L
.02235 .75212 L
s
.02235 .75212 m
0 .65264 L
s
0 .46713 m
.02548 .33019 L
.08769 .15805 L
s
.08769 .15805 m
.17373 0 L
s
1 0 0 r
.45645 .58031 m
.44192 .5769 L
s
% Start of user PostScript
-5.2261061 9.6377371 -6.9696655 9.2274341 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42892 .56844 m
.41843 .55477 L
s
% Start of user PostScript
-8.5297304 8.2122077 -9.7888319 6.5720578 MAarrowhead1
% End of user PostScript
1 .473 0 r
.47806 .36423 m
.50793 .33976 L
s
% Start of user PostScript
-2.6326927 -16.292434 0.95208401 -19.229035 MAarrowhead1
% End of user PostScript
1 .788 0 r
.71178 .42885 m
.71503 .48671 L
s
% Start of user PostScript
25.413807 -8.5376057 25.803219 -1.594475 MAarrowhead1
% End of user PostScript
.897 1 0 r
.38044 .92926 m
.29649 .94683 L
s
% Start of user PostScript
-14.346941 51.511337 -24.420866 53.619066 MAarrowhead1
% End of user PostScript
.581 1 0 r
.02548 .33019 m
.08769 .15805 L
s
% Start of user PostScript
-56.942537 -20.377582 -49.477234 -41.034377 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
87.179721 -122.78028 108.24689 -111.03138 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
81.020635 159.27988 42.902313 205.4898 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-305.5329 198.98019 -330.5464 127.94386 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
38.283118 -601.33038 163.06409 -666.8361 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
798.13211 -32.081588 760.54514 216.44143 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-779.38647 1661.7306 -1086.7729 1629.5112 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1510.0871 -1318.8305 -1147.8267 -1967.1244 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3396.3195 -3401.1522 3925.3637 -2765.0312 MAarrowhead1
% End of user PostScript
.128 1 0 r
.47915 .47367 m
.48587 .46367 L
.49432 .4545 L
.50424 .44683 L
.51522 .44131 L
.52676 .43855 L
.53825 .43909 L
.54898 .44334 L
.55821 .45152 L
.56521 .4637 L
.56925 .47965 L
.56969 .49895 L
.56604 .52087 L
.55797 .54447 L
.54536 .56856 L
.52837 .59177 L
.50742 .6126 L
.48325 .62949 L
.45685 .6409 L
.42951 .64543 L
.40274 .64188 L
.3782 .62941 L
.35766 .60756 L
.34287 .57638 L
.33548 .5365 L
.33692 .48912 L
.34828 .4361 L
.3702 .37982 L
.40278 .32321 L
.44549 .26961 L
.49714 .22262 L
.55584 .18591 L
.61903 .16304 L
.68353 .15722 L
.74567 .17107 L
.80143 .20638 L
.84665 .26391 L
.87721 .34317 L
.88934 .44233 L
.87988 .55814 L
.84649 .68591 L
.788 .8196 L
.70454 .95202 L
s
.70454 .95202 m
.66294 1 L
s
1 0 0 r
.47915 .47367 m
.48587 .46367 L
s
% Start of user PostScript
-2.5020481 -3.1601317 -1.6960576 -4.3601417 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49432 .4545 m
.50424 .44683 L
s
% Start of user PostScript
-0.68160374 -5.4599074 0.50857159 -6.3804951 MAarrowhead1
% End of user PostScript
1 .473 0 r
.56925 .47965 m
.56969 .49895 L
s
% Start of user PostScript
8.3094697 -2.4418288 8.3629948 -0.12651567 MAarrowhead1
% End of user PostScript
1 .788 0 r
.45685 .6409 m
.42951 .64543 L
s
% Start of user PostScript
-5.1780865 16.907667 -8.4586075 17.451032 MAarrowhead1
% End of user PostScript
.897 1 0 r
.34828 .4361 m
.3702 .37982 L
s
% Start of user PostScript
-18.206155 -7.6684771 -15.57591 -14.421907 MAarrowhead1
% End of user PostScript
.581 1 0 r
.74567 .17107 m
.80143 .20638 L
s
% Start of user PostScript
29.480242 -39.47129 36.172097 -35.23404 MAarrowhead1
% End of user PostScript
.266 1 0 r
.70454 .95202 m
0 0 rlineto s
.70454 .95202 m
.66294 1 L
s
% Start of user PostScript
24.545394 54.242857 11.733477 69.015327 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-100.90416 61.397673 -108.25398 37.38023 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
18.656566 -199.39768 59.701861 -219.23158 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
258.50009 1.8198447 243.74939 83.888046 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-269.43805 540.47927 -368.52974 524.95317 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-474.69694 -462.26166 -350.7561 -672.20909 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1134.0631 -1078.0423 1298.5524 -858.19553 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
330.79721 2168.7196 -145.28798 2553.3973 MAarrowhead1
% End of user PostScript
1 0 .575 r
.55358 .54198 m
.54174 .56437 L
.52584 .58589 L
.50628 .60516 L
.48373 .62072 L
.45916 .63115 L
.43375 .63516 L
.40891 .63163 L
.38619 .61979 L
.36724 .59922 L
.35368 .57 L
.34703 .53271 L
.34863 .48851 L
.35947 .43911 L
.38013 .38676 L
.41069 .3342 L
.45064 .28452 L
.49886 .24108 L
.55357 .2073 L
.61237 .18647 L
.67229 .18157 L
.72992 .19501 L
.78151 .22842 L
.82318 .28248 L
.85112 .35671 L
.86185 .44937 L
.85242 .55738 L
.82073 .67636 L
.76568 .80066 L
.68746 .92357 L
s
.68746 .92357 m
.62056 1 L
s
1 0 0 r
.55358 .54198 m
.54174 .56437 L
s
% Start of user PostScript
6.4298648 5.0380598 5.0092486 7.7239167 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52584 .58589 m
.50628 .60516 L
s
% Start of user PostScript
3.1007453 10.306764 0.75321004 12.618853 MAarrowhead1
% End of user PostScript
1 .473 0 r
.35368 .57 m
.34703 .53271 L
s
% Start of user PostScript
-17.558971 8.4000117 -18.355891 3.9257216 MAarrowhead1
% End of user PostScript
1 .788 0 r
.55357 .2073 m
.61237 .18647 L
s
% Start of user PostScript
6.4284431 -35.124176 13.484002 -37.623262 MAarrowhead1
% End of user PostScript
.897 1 0 r
.85242 .55738 m
.82073 .67636 L
s
% Start of user PostScript
42.290945 6.8859602 38.48729 21.16289 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-53.257886 89.651003 -69.218504 84.364111 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-69.895704 -94.574232 -46.051567 -128.90956 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
203.91068 -163.67476 227.12094 -120.2514 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
17.461626 395.56926 -66.992315 452.16063 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-569.06146 110.21177 -560.69462 -55.708707 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
434.03339 -1168.522 656.52358 -1181.9633 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1179.6215 689.13291 968.62281 1151.5246 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2177.9362 2593.2774 -2604.1953 2238.5718 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1363.7302 -4067.5028 -429.50644 -5024.2873 MAarrowhead1
% End of user PostScript
.855 1 0 r
.55167 .55304 m
.53761 .57624 L
.51942 .59799 L
.49767 .61679 L
.47315 .63112 L
.44697 .63955 L
.42046 .64078 L
.39517 .63377 L
.37277 .61785 L
.35497 .59279 L
.34344 .55885 L
.33973 .51689 L
.34507 .46833 L
.36036 .41519 L
.38602 .36004 L
.42189 .30589 L
.4672 .25611 L
.52049 .21424 L
.57966 .18384 L
.64196 .16825 L
.70408 .17037 L
.76231 .19242 L
.81265 .23576 L
.85104 .30062 L
.87361 .38601 L
.8769 .48957 L
.85816 .60753 L
.81556 .7348 L
.74847 .865 L
.65762 .99078 L
s
.65762 .99078 m
.64847 1 L
s
1 0 0 r
.55167 .55304 m
.53761 .57624 L
s
% Start of user PostScript
6.2004659 6.3645533 4.5126473 9.1490249 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51942 .59799 m
.49767 .61679 L
s
% Start of user PostScript
2.3309795 11.758628 -0.28018546 14.014453 MAarrowhead1
% End of user PostScript
1 .473 0 r
.34344 .55885 m
.33973 .51689 L
s
% Start of user PostScript
-18.786647 7.0621694 -19.23299 2.0265342 MAarrowhead1
% End of user PostScript
1 .788 0 r
.57966 .18384 m
.64196 .16825 L
s
% Start of user PostScript
9.5596542 -37.938767 17.0352 -39.80994 MAarrowhead1
% End of user PostScript
.897 1 0 r
.85816 .60753 m
.81556 .7348 L
s
% Start of user PostScript
42.978706 12.904098 37.866721 28.175626 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-62.351334 92.209739 -78.346579 84.374441 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-64.071008 -113.09825 -36.641162 -147.98089 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
223.70079 -154.95643 243.97121 -104.14269 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-15.116515 438.54593 -106.82994 490.37185 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-595.29129 50.14913 -572.79066 -131.82833 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
544.78375 -1234.524 775.04827 -1221.4252 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1157.2125 908.24625 901.21617 1391.829 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2460.0261 2587.2914 -2869.3441 2142.5121 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1064.1321 -4658.0497 -21.926252 -5596.2236 MAarrowhead1
% End of user PostScript
0 1 .117 r
.46479 .47862 m
.47126 .46471 L
.4803 .45105 L
.49173 .4385 L
.50516 .42794 L
.52009 .42027 L
.5358 .41634 L
.55146 .41687 L
.56615 .42243 L
.57884 .43336 L
.58852 .44972 L
.59421 .47125 L
.59505 .49736 L
.59032 .52711 L
.57958 .5592 L
.56266 .59204 L
.53976 .62375 L
.51143 .65232 L
.47865 .6756 L
.44278 .6915 L
.40554 .69811 L
.36898 .69378 L
.33536 .67732 L
.30709 .64809 L
.28656 .60613 L
.27602 .55227 L
.27744 .48811 L
.29232 .41612 L
.32156 .33955 L
.36534 .26235 L
.42298 .18904 L
.49289 .12452 L
.57253 .0738 L
.65845 .04174 L
.74636 .03274 L
.83128 .05042 L
.90775 .09725 L
.97009 .17434 L
s
.97009 .17434 m
1 .24931 L
s
1 .64625 m
.97476 .74567 L
.89653 .92768 L
s
.89653 .92768 m
.85159 1 L
s
1 0 0 r
.46479 .47862 m
.47126 .46471 L
s
% Start of user PostScript
-4.2257183 -2.5659028 -3.4493415 -4.2348661 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4803 .45105 m
.49173 .4385 L
s
% Start of user PostScript
-2.3638846 -5.8734966 -0.9929269 -7.3800331 MAarrowhead1
% End of user PostScript
1 .473 0 r
.58852 .44972 m
.59421 .47125 L
s
% Start of user PostScript
10.62257 -6.0340658 11.305669 -3.4502128 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47865 .6756 m
.44278 .6915 L
s
% Start of user PostScript
-2.5623522 21.071413 -6.8669911 22.980333 MAarrowhead1
% End of user PostScript
.897 1 0 r
.27744 .48811 m
.29232 .41612 L
s
% Start of user PostScript
-26.707059 -1.4268275 -24.921638 -10.065659 MAarrowhead1
% End of user PostScript
.581 1 0 r
.74636 .03274 m
.83128 .05042 L
s
% Start of user PostScript
29.562794 -56.070759 39.75332 -53.950182 MAarrowhead1
% End of user PostScript
.266 1 0 r
.89653 .92768 m
0 0 rlineto s
.89653 .92768 m
.85159 1 L
s
% Start of user PostScript
47.583397 51.321576 34.107626 73.010073 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-120.62167 108.99149 -136.92016 84.875908 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-27.283678 -231.72729 23.137879 -270.27786 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
350.96917 -100.19856 352.60996 -2.0268886 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-222.80022 714.68092 -361.24854 736.40642 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-765.51555 -332.34382 -652.83063 -617.58466 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1253.3582 -1661.4987 1534.3538 -1479.2043 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1020.3852 2309.2452 476.31743 2930.3658 MAarrowhead1
% End of user PostScript
1 .024 0 r
.5119 .55933 m
.49871 .57075 L
.48385 .57948 L
.46798 .58463 L
.4519 .58542 L
.43654 .58121 L
.42293 .57161 L
.4121 .55645 L
.40507 .53591 L
.40277 .5105 L
.40596 .48107 L
.41518 .44886 L
.43068 .4154 L
.45239 .38254 L
.47983 .35231 L
.51212 .32685 L
.54799 .30834 L
.58577 .29879 L
.62347 .29996 L
.65882 .31323 L
.68941 .3394 L
.71278 .37863 L
.72657 .43032 L
.72868 .49305 L
.71744 .56455 L
.69174 .64171 L
.65117 .7207 L
.59619 .79705 L
.52815 .86585 L
.44938 .92199 L
.36313 .96044 L
.27357 .97654 L
.18558 .96638 L
.10462 .92705 L
.03647 .85701 L
s
.03647 .85701 m
0 .78297 L
s
0 .29963 m
.06996 .11568 L
s
.06996 .11568 m
.13536 0 L
s
1 0 0 r
.5119 .55933 m
.49871 .57075 L
s
% Start of user PostScript
1.4275055 7.1195441 -0.15438513 8.4905021 MAarrowhead1
% End of user PostScript
1 .158 0 r
.48385 .57948 m
.46798 .58463 L
s
% Start of user PostScript
-1.937695 9.5376569 -3.8428924 10.155446 MAarrowhead1
% End of user PostScript
1 .473 0 r
.40596 .48107 m
.41518 .44886 L
s
% Start of user PostScript
-11.285376 -2.2712351 -10.178834 -6.1370334 MAarrowhead1
% End of user PostScript
1 .788 0 r
.62347 .29996 m
.65882 .31323 L
s
% Start of user PostScript
14.816077 -24.004283 19.058664 -22.412646 MAarrowhead1
% End of user PostScript
.897 1 0 r
.65117 .7207 m
.59619 .79705 L
s
% Start of user PostScript
18.14053 26.484561 11.542865 35.646161 MAarrowhead1
% End of user PostScript
.581 1 0 r
.03647 .85701 m
0 0 rlineto s
.03647 .85701 m
0 .78297 L
s
% Start of user PostScript
-55.62349 42.841071 -61.573566 30.762664 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2.2464649 -108.24154 20.722377 -122.92547 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
153.10112 -24.867871 149.84052 20.389132 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-123.43667 315.27243 -183.11356 316.89425 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-311.72873 -199.16304 -252.37118 -323.5566 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
599.29815 -688.48182 711.29267 -587.63749 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
340.28342 1123.9252 84.171138 1376.7348 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1916.9847 920.50268 -2004.7135 432.47008 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
697.02877 -3834.0089 1467.444 -4108.2782 MAarrowhead1
% End of user PostScript
.438 0 1 r
.50085 .48191 m
.50462 .47985 L
.50861 .47871 L
.51263 .47869 L
.51642 .47993 L
.51975 .48254 L
.52233 .48654 L
.52393 .49187 L
.52432 .4984 L
.5233 .50589 L
.52077 .51403 L
.51665 .52241 L
.51099 .53058 L
.50393 .53801 L
.49569 .54416 L
.48661 .54849 L
.47712 .55051 L
.46773 .54979 L
.45902 .546 L
.45158 .53897 L
.44605 .52867 L
.443 .5153 L
.44294 .49922 L
.44627 .48106 L
.45326 .46161 L
.46396 .44185 L
.47823 .42294 L
.4957 .4061 L
.51576 .39262 L
.53755 .38374 L
.56 .38062 L
.58186 .38421 L
.60174 .39517 L
.61821 .41385 L
.62983 .44015 L
.63524 .47352 L
.63331 .51292 L
.62318 .55679 L
.60435 .60311 L
.57678 .64946 L
.54097 .69306 L
.49795 .73095 L
.44932 .76012 L
.39724 .77765 L
.34436 .78097 L
.29371 .76796 L
.24862 .73725 L
.21252 .6883 L
.18876 .6216 L
.18039 .53877 L
Mistroke
.18997 .44259 L
.21932 .33704 L
.26931 .22715 L
.33972 .1189 L
.42906 .01896 L
Mfstroke
.42906 .01896 m
.4527 0 L
s
1 0 0 r
.50085 .48191 m
.50462 .47985 L
s
% Start of user PostScript
0.1016863 -2.1702308 0.55405436 -2.4181924 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50861 .47871 m
.51263 .47869 L
s
% Start of user PostScript
1.0336126 -2.5549571 1.5153823 -2.557563 MAarrowhead1
% End of user PostScript
1 .473 0 r
.52077 .51403 m
.51665 .52241 L
s
% Start of user PostScript
2.4918711 1.6835623 1.9980709 2.689742 MAarrowhead1
% End of user PostScript
1 .788 0 r
.45902 .546 m
.45158 .53897 L
s
% Start of user PostScript
-4.9180931 5.5205838 -5.8098604 4.6763102 MAarrowhead1
% End of user PostScript
.897 1 0 r
.47823 .42294 m
.4957 .4061 L
s
% Start of user PostScript
-2.6122702 -9.2475191 -0.51543256 -11.268235 MAarrowhead1
% End of user PostScript
.581 1 0 r
.62983 .44015 m
.63524 .47352 L
s
% Start of user PostScript
15.579079 -7.1819151 16.22896 -3.1771563 MAarrowhead1
% End of user PostScript
.266 1 0 r
.44932 .76012 m
.39724 .77765 L
s
% Start of user PostScript
-6.081013 31.214185 -12.330692 33.318521 MAarrowhead1
% End of user PostScript
0 1 .049 r
.18997 .44259 m
.21932 .33704 L
s
% Start of user PostScript
-37.20301 -6.888736 -33.68154 -19.555338 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
48.008427 -79.020197 62.017199 -74.022806 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
60.506977 85.586751 39.081411 115.78971 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-181.6971 142.38179 -201.64811 103.2419 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-10.735956 -353.12217 64.385887 -402.10496 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
502.98792 -88.247173 493.65768 59.591813 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-396.40896 1034.554 -592.71673 1042.6123 MAarrowhead1
% End of user PostScript
0 1 .574 r
.52784 .50867 m
.52446 .5186 L
.51918 .52875 L
.51205 .53853 L
.50324 .54732 L
.49308 .55445 L
.48197 .55929 L
.47046 .56124 L
.45918 .55979 L
.44883 .55459 L
.44015 .54543 L
.43389 .53235 L
.43074 .5156 L
.43129 .49568 L
.43602 .47338 L
.4452 .44969 L
.45886 .42584 L
.4768 .40325 L
.49851 .38341 L
.5232 .36789 L
.54979 .35818 L
.57695 .35563 L
.60314 .36135 L
.62667 .37611 L
.64578 .40022 L
.65874 .43349 L
.66395 .47515 L
.66008 .52384 L
.64615 .5776 L
.62165 .63388 L
.58664 .68968 L
.54179 .74159 L
.48848 .78601 L
.42876 .81928 L
.36534 .83795 L
.3015 .83894 L
.241 .81986 L
.18789 .77915 L
.14632 .71638 L
.12031 .63235 L
.11348 .52924 L
.12879 .41065 L
.16828 .2816 L
.23281 .1484 L
.32186 .01842 L
s
.32186 .01842 m
.33919 0 L
s
1 0 0 r
.52784 .50867 m
.52446 .5186 L
s
% Start of user PostScript
3.3409861 1.0403418 2.9357442 2.232293 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51918 .52875 m
.51205 .53853 L
s
% Start of user PostScript
2.3014673 3.4498244 1.4454859 4.6237327 MAarrowhead1
% End of user PostScript
1 .473 0 r
.44015 .54543 m
.43389 .53235 L
s
% Start of user PostScript
-7.181922 5.4519245 -7.9333826 3.8821283 MAarrowhead1
% End of user PostScript
1 .788 0 r
.49851 .38341 m
.5232 .36789 L
s
% Start of user PostScript
-0.17920931 -13.990623 2.7834215 -15.853387 MAarrowhead1
% End of user PostScript
.897 1 0 r
.66395 .47515 m
.66008 .52384 L
s
% Start of user PostScript
19.674122 -2.9820056 19.210038 2.8612807 MAarrowhead1
% End of user PostScript
.581 1 0 r
.36534 .83795 m
.3015 .83894 L
s
% Start of user PostScript
-16.15969 40.553615 -23.820281 40.672963 MAarrowhead1
% End of user PostScript
.266 1 0 r
.16828 .2816 m
.23281 .1484 L
s
% Start of user PostScript
-39.806638 -26.20763 -32.063283 -42.192313 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
77.608115 -88.061137 91.879888 -74.860467 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
42.539237 145.75074 9.4148663 178.03216 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-246.95438 116.05116 -257.72162 52.8538 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
93.321458 -494.38577 192.47329 -528.66268 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
592.32968 102.85404 537.70288 303.64493 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-754.86093 1256.8521 -978.16228 1180.1316 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-971.40981 -1343.0444 -633.97718 -1823.9352 MAarrowhead1
% End of user PostScript
.476 0 1 r
.42621 .5478 m
.42022 .53061 L
.4182 .5093 L
.42078 .48461 L
.42843 .45754 L
.44137 .42941 L
.45953 .40173 L
.48251 .37624 L
.50961 .35472 L
.53973 .33901 L
.5715 .33081 L
.60323 .3316 L
.63304 .34255 L
.65887 .36433 L
.67867 .39712 L
.69046 .4404 L
.69245 .493 L
.68323 .55302 L
.66186 .61787 L
.62799 .68432 L
.58198 .74863 L
.52495 .80668 L
.45884 .85417 L
.38638 .88686 L
.31105 .90082 L
.23696 .89275 L
.16869 .86018 L
.11109 .80179 L
.06901 .71763 L
.04703 .60929 L
.04914 .48 L
.07842 .33469 L
.13674 .17989 L
.22449 .02357 L
s
.22449 .02357 m
.24285 0 L
s
1 0 0 r
.42621 .5478 m
.42022 .53061 L
s
% Start of user PostScript
-8.8546879 5.7356061 -9.5730514 3.672883 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4182 .5093 m
.42078 .48461 L
s
% Start of user PostScript
-9.8161601 1.1164736 -9.5062365 -1.8469005 MAarrowhead1
% End of user PostScript
1 .473 0 r
.5715 .33081 m
.60323 .3316 L
s
% Start of user PostScript
8.5799879 -20.302938 12.388002 -20.207656 MAarrowhead1
% End of user PostScript
1 .788 0 r
.66186 .61787 m
.62799 .68432 L
s
% Start of user PostScript
19.423319 14.144001 15.358791 22.118666 MAarrowhead1
% End of user PostScript
.897 1 0 r
.16869 .86018 m
.11109 .80179 L
s
% Start of user PostScript
-39.757445 43.221469 -46.669588 36.214875 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-19.158155 -75.018289 -2.2610635 -90.767198 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
124.2822 -54.013036 128.77424 -21.641541 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-53.08142 249.62281 -102.81332 265.04234 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-292.92035 -64.390272 -263.05142 -165.43202 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
392.13846 -624.06272 502.05084 -580.48307 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
464.44061 703.06803 290.24847 940.85402 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1458.9192 1101.4926 -1610.3031 781.83338 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-28.047655 -2843.1411 573.54591 -3219.0377 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3989.4855 -588.5051 3891.9643 598.47547 MAarrowhead1
% End of user PostScript
0 1 .326 r
.53064 .41865 m
.54611 .41785 L
.56088 .42184 L
.57399 .43102 L
.58444 .44554 L
.59124 .46524 L
.5935 .48964 L
.59049 .5179 L
.58168 .54886 L
.56683 .58103 L
.54602 .61264 L
.51969 .64175 L
.48868 .66628 L
.45421 .68417 L
.41789 .69344 L
.38163 .69242 L
.3476 .67979 L
.31812 .65475 L
.29557 .61715 L
.28221 .56756 L
.28006 .50733 L
.29073 .43865 L
.31531 .36448 L
.35417 .28852 L
.40691 .21506 L
.47222 .14881 L
.54788 .09468 L
.63076 .05751 L
.71688 .04179 L
.80153 .0513 L
.87947 .08883 L
.94516 .15588 L
.99304 .25238 L
s
.99304 .25238 m
1 .28713 L
s
1 .59916 m
.98138 .69076 L
.91436 .86777 L
s
.91436 .86777 m
.83987 1 L
s
1 0 0 r
.53064 .41865 m
.54611 .41785 L
s
% Start of user PostScript
3.6767613 -9.7619251 5.5326379 -9.858129 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56088 .42184 m
.57399 .43102 L
s
% Start of user PostScript
7.3056741 -9.3792375 8.8791023 -8.2772371 MAarrowhead1
% End of user PostScript
1 .473 0 r
.54602 .61264 m
.51969 .64175 L
s
% Start of user PostScript
5.5222236 13.51724 2.3625506 17.010332 MAarrowhead1
% End of user PostScript
1 .788 0 r
.29557 .61715 m
.28221 .56756 L
s
% Start of user PostScript
-24.531391 14.058092 -26.134923 8.1069399 MAarrowhead1
% End of user PostScript
.897 1 0 r
.54788 .09468 m
.63076 .05751 L
s
% Start of user PostScript
5.7457442 -48.638616 15.69142 -53.098387 MAarrowhead1
% End of user PostScript
.581 1 0 r
1 .59916 m
.98138 .69076 L
s
% Start of user PostScript
61.821597 2.9406548 57.765133 22.891101 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-67.927555 129.7253 -91.530415 124.96757 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-110.5731 -117.75777 -79.575435 -167.96306 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
278.20527 -252.99173 316.13649 -197.57878 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
65.171491 534.16228 -51.183575 623.74794 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-811.38376 235.733 -816.04021 9.304016 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
509.38029 -1651.464 829.6061 -1703.3951 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1774.5687 756.56169 1516.2741 1415.9999 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2886.152 3848.9963 -3538.0656 3432.1904 MAarrowhead1
% End of user PostScript
1 .746 0 r
.451 .54018 m
.44524 .52985 L
.44199 .51637 L
.44176 .50012 L
.44497 .48169 L
.45189 .46191 L
.4626 .44176 L
.47697 .42241 L
.49463 .4051 L
.51495 .39115 L
.5371 .38183 L
.55997 .37832 L
.58232 .3816 L
.60273 .39238 L
.61974 .41101 L
.63186 .43742 L
.63774 .47109 L
.63619 .51096 L
.62631 .55549 L
.60758 .60264 L
.57994 .64994 L
.54385 .6946 L
.50034 .7336 L
.45102 .76387 L
.39805 .78243 L
.34412 .78661 L
.29229 .77426 L
.24595 .74391 L
.2086 .69497 L
.18364 .62789 L
.17423 .54425 L
.183 .44684 L
.21184 .33962 L
.2617 .2277 L
.33241 .1171 L
.42253 .01462 L
s
.42253 .01462 m
.44044 0 L
s
1 0 0 r
.451 .54018 m
.44524 .52985 L
s
% Start of user PostScript
-5.8800478 4.8210847 -6.5707259 3.581988 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44199 .51637 m
.44176 .50012 L
s
% Start of user PostScript
-6.9615114 1.9642901 -6.9891689 0.01405473 MAarrowhead1
% End of user PostScript
1 .473 0 r
.5371 .38183 m
.55997 .37832 L
s
% Start of user PostScript
4.4515275 -14.18009 7.1967828 -14.601361 MAarrowhead1
% End of user PostScript
1 .788 0 r
.62631 .55549 m
.60758 .60264 L
s
% Start of user PostScript
15.156787 6.6586811 12.909129 12.31642 MAarrowhead1
% End of user PostScript
.897 1 0 r
.29229 .77426 m
.24595 .74391 L
s
% Start of user PostScript
-24.925092 32.911381 -30.485664 29.269343 MAarrowhead1
% End of user PostScript
.581 1 0 r
.33241 .1171 m
.42253 .01462 L
s
% Start of user PostScript
-20.110591 -45.947423 -9.2958683 -58.245122 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
84.769566 -50.584995 90.734123 -30.279478 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-17.059675 167.69944 -51.503919 183.94698 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-215.9929 -4.3909719 -203.06199 -73.334591 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
229.13071 -452.13902 311.81867 -437.96926 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
393.25559 394.50352 288.14112 569.92227 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-955.58653 895.24068 -1091.4154 708.29651 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-260.43072 -1829.8602 140.22866 -2148.5191 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2817.9113 -885.21994 2848.1232 -107.42673 MAarrowhead1
% End of user PostScript
.382 0 1 r
.50764 .47359 m
.51279 .4726 L
.51786 .47312 L
.52255 .4753 L
.52651 .47925 L
.52941 .48496 L
.53095 .49233 L
.53085 .50114 L
.52889 .51105 L
.52496 .52163 L
.51901 .53232 L
.51113 .54251 L
.50154 .55152 L
.49058 .55865 L
.47873 .56324 L
.46656 .56467 L
.45477 .56244 L
.44411 .55618 L
.43536 .54574 L
.4293 .53118 L
.42665 .51282 L
.42802 .49125 L
.43387 .46733 L
.44444 .44218 L
.45973 .41713 L
.47945 .39368 L
.50303 .37345 L
.52957 .35808 L
.55788 .34912 L
.58651 .34797 L
.61379 .35573 L
.63791 .37312 L
.65702 .4004 L
.66932 .43725 L
.67315 .48275 L
.66717 .53534 L
.65042 .59282 L
.62247 .65242 L
.58349 .71087 L
.53435 .76452 L
.47661 .80954 L
.41259 .84209 L
.34525 .85858 L
.27817 .85588 L
.21539 .8316 L
.16123 .7843 L
.12005 .71376 L
.09606 .62107 L
.09295 .50883 L
.11371 .38111 L
Mistroke
.16027 .24347 L
.23329 .10281 L
Mfstroke
.23329 .10281 m
.30803 0 L
s
1 0 0 r
.50764 .47359 m
.51279 .4726 L
s
% Start of user PostScript
0.91738349 -3.1690768 1.5352205 -3.2877533 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51786 .47312 m
.52255 .4753 L
s
% Start of user PostScript
2.1437664 -3.2261611 2.7054924 -2.9639709 MAarrowhead1
% End of user PostScript
1 .473 0 r
.51901 .53232 m
.51113 .54251 L
s
% Start of user PostScript
2.2806246 3.8781488 1.3354052 5.1007507 MAarrowhead1
% End of user PostScript
1 .788 0 r
.43536 .54574 m
.4293 .53118 L
s
% Start of user PostScript
-7.7570623 5.4882037 -8.4842149 3.7410187 MAarrowhead1
% End of user PostScript
.897 1 0 r
.50303 .37345 m
.52957 .35808 L
s
% Start of user PostScript
0.36408945 -15.185626 3.5487266 -17.03066 MAarrowhead1
% End of user PostScript
.581 1 0 r
.67315 .48275 m
.66717 .53534 L
s
% Start of user PostScript
20.777815 -2.0694964 20.059809 4.2409802 MAarrowhead1
% End of user PostScript
.266 1 0 r
.34525 .85858 m
.27817 .85588 L
s
% Start of user PostScript
-18.570395 43.02987 -26.619611 42.70572 MAarrowhead1
% End of user PostScript
0 1 .049 r
.16027 .24347 m
.23329 .10281 L
s
% Start of user PostScript
-40.76702 -30.783317 -32.004608 -47.662698 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
84.973697 -90.920679 99.439611 -75.757425 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
38.9176 160.60829 2.8588762 193.66115 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-263.91174 111.25281 -272.72386 42.067853 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
117.51419 -530.71275 222.98815 -562.02038 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
617.95441 146.63459 552.66374 361.18907 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-842.3054 1318.5551 -1073.7691 1222.1175 MAarrowhead1
% End of user PostScript
0 .637 1 r
.5138 .545 m
.50354 .55518 L
.49169 .56342 L
.47877 .56898 L
.46539 .57116 L
.4523 .56939 L
.4403 .56325 L
.43027 .55252 L
.42306 .53722 L
.41948 .51767 L
.42023 .49446 L
.42583 .46849 L
.4366 .44095 L
.45259 .41326 L
.47353 .38705 L
.49884 .36409 L
.52759 .34618 L
.55852 .33505 L
.59008 .33228 L
.62047 .33915 L
.64772 .35652 L
.66979 .38476 L
.68467 .42364 L
.69053 .47224 L
.6858 .52897 L
.66935 .59153 L
.64062 .65696 L
.59968 .72174 L
.54735 .78192 L
.48522 .8333 L
.4157 .87165 L
.34195 .89293 L
.2678 .89362 L
.19763 .87093 L
.13616 .82309 L
.08819 .74962 L
.0584 .65147 L
.05097 .53123 L
.06934 .39311 L
.11583 .24298 L
.19142 .08818 L
s
.19142 .08818 m
.25226 0 L
s
1 0 0 r
.5138 .545 m
.50354 .55518 L
s
% Start of user PostScript
1.6559709 5.4003227 0.42421846 6.6216738 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49169 .56342 m
.47877 .56898 L
s
% Start of user PostScript
-0.99683885 7.6107522 -2.5476597 8.2776459 MAarrowhead1
% End of user PostScript
1 .473 0 r
.42023 .49446 m
.42583 .46849 L
s
% Start of user PostScript
-9.572617 -0.66443373 -8.9003747 -3.7806046 MAarrowhead1
% End of user PostScript
1 .788 0 r
.59008 .33228 m
.62047 .33915 L
s
% Start of user PostScript
10.809351 -20.125973 14.456116 -19.302098 MAarrowhead1
% End of user PostScript
.897 1 0 r
.64062 .65696 m
.59968 .72174 L
s
% Start of user PostScript
16.874973 18.835274 11.961998 26.6088 MAarrowhead1
% End of user PostScript
.581 1 0 r
.13616 .82309 m
.08819 .74962 L
s
% Start of user PostScript
-43.661255 38.771009 -49.417183 29.954083 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-8.9279086 -84.00483 9.2971957 -97.675215 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
126.23775 -34.311665 126.46321 1.2221246 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-82.544764 257.38087 -132.2765 264.47469 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-273.30633 -124.50847 -231.83975 -227.1016 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
455.63215 -594.28362 555.73098 -526.75965 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
357.40037 841.2893 159.98608 1063.0324 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1540.9432 903.59167 -1646.0022 532.41938 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
332.32071 -3051.4159 957.84178 -3340.1168 MAarrowhead1
% End of user PostScript
.095 0 1 r
.48919 .49604 m
.49062 .4921 L
.49281 .48812 L
.49572 .48431 L
.49927 .48093 L
.50333 .47823 L
.50774 .47648 L
.51228 .47589 L
.51668 .47667 L
.52068 .47894 L
.52397 .48277 L
.52628 .48813 L
.52732 .49492 L
.52688 .50291 L
.52477 .5118 L
.5209 .52116 L
.51528 .53051 L
.50799 .53928 L
.49925 .54688 L
.4894 .5527 L
.47887 .55615 L
.46819 .5567 L
.45799 .55395 L
.44894 .54762 L
.44173 .53761 L
.43703 .52401 L
.43546 .50718 L
.43753 .48768 L
.44361 .46631 L
.45385 .44411 L
.46821 .42228 L
.48638 .40219 L
.50778 .38525 L
.53156 .3729 L
.55663 .36649 L
.58166 .36718 L
.60516 .37589 L
.62551 .39315 L
.64108 .41909 L
.65031 .45331 L
.65181 .49487 L
.64446 .54227 L
.62751 .59345 L
.6007 .64588 L
.56432 .69659 L
.51925 .74233 L
.46704 .77971 L
.40984 .80538 L
.3504 .81626 L
.29197 .80973 L
Mistroke
.23816 .78386 L
.19281 .73761 L
.15973 .67103 L
.14255 .58539 L
.14439 .48326 L
.16769 .36852 L
.21391 .24635 L
.28334 .12304 L
.37494 .00579 L
Mfstroke
.37494 .00579 m
.38117 0 L
s
1 0 0 r
.48919 .49604 m
.49062 .4921 L
s
% Start of user PostScript
-1.297486 -0.47531493 -1.1250623 -0.94741741 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49281 .48812 m
.49572 .48431 L
s
% Start of user PostScript
-0.86258578 -1.4258789 -0.51371933 -1.8830123 MAarrowhead1
% End of user PostScript
1 .473 0 r
.52397 .48277 m
.52628 .48813 L
s
% Start of user PostScript
2.8768899 -2.0681394 3.1534748 -1.424377 MAarrowhead1
% End of user PostScript
1 .788 0 r
.49925 .54688 m
.4894 .5527 L
s
% Start of user PostScript
-0.08946673 5.625852 -1.2718104 6.3237639 MAarrowhead1
% End of user PostScript
.897 1 0 r
.43546 .50718 m
.43753 .48768 L
s
% Start of user PostScript
-7.7444973 0.86159311 -7.4959186 -1.4788576 MAarrowhead1
% End of user PostScript
.581 1 0 r
.55663 .36649 m
.58166 .36718 L
s
% Start of user PostScript
6.7960341 -16.02167 9.799648 -15.938469 MAarrowhead1
% End of user PostScript
.266 1 0 r
.62751 .59345 m
.6007 .64588 L
s
% Start of user PostScript
15.301409 11.214335 12.08426 17.505942 MAarrowhead1
% End of user PostScript
0 1 .049 r
.23816 .78386 m
.19281 .73761 L
s
% Start of user PostScript
-31.420492 34.062647 -36.863039 28.512978 MAarrowhead1
% End of user PostScript
0 1 .364 r
.37494 .00579 m
0 0 rlineto s
.37494 .00579 m
.38117 0 L
s
% Start of user PostScript
-15.007776 -59.305093 -1.6575627 -71.711721 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
98.108255 -42.412156 101.60664 -16.828994 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-42.216808 197.09408 -81.466532 209.17216 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-230.96505 -51.47869 -207.26435 -131.24053 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
310.18325 -492.19969 396.82122 -457.54254 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
365.37328 556.39767 227.64124 743.88845 MAarrowhead1
% End of user PostScript
1 .322 0 r
.49454 .51997 m
.49063 .52082 L
.48675 .52053 L
.48316 .51899 L
.48008 .51611 L
.47779 .51189 L
.47652 .50639 L
.47647 .49978 L
.47783 .49231 L
.48068 .48429 L
.48507 .47615 L
.49093 .46835 L
.49812 .46139 L
.50637 .45581 L
.51534 .45212 L
.5246 .4508 L
.53361 .45223 L
.54182 .45671 L
.54864 .46436 L
.55346 .47516 L
.55573 .48887 L
.55498 .50508 L
.55085 .52314 L
.54314 .54222 L
.53183 .56133 L
.51712 .57933 L
.49943 .59498 L
.47941 .60707 L
.45796 .61437 L
.43616 .61583 L
.41526 .61057 L
.39664 .59802 L
.3817 .57795 L
.37182 .55056 L
.36828 .51651 L
.37211 .47694 L
.38409 .43348 L
.40457 .38819 L
.43347 .34355 L
.47018 .30229 L
.51357 .26733 L
.56192 .24159 L
.61301 .22784 L
.66417 .22848 L
.71235 .2454 L
.75428 .27976 L
.78663 .33182 L
.80619 .40085 L
.8101 .48498 L
.79603 .58121 L
Mistroke
.76244 .68541 L
.70873 .79243 L
.63541 .89625 L
.54426 .99027 L
Mfstroke
.54426 .99027 m
.53093 1 L
s
1 0 0 r
.49454 .51997 m
.49063 .52082 L
s
% Start of user PostScript
-0.6555831 2.3960374 -1.124823 2.4978013 MAarrowhead1
% End of user PostScript
1 .158 0 r
.48675 .52053 m
.48316 .51899 L
s
% Start of user PostScript
-1.5894609 2.4641545 -2.0211747 2.2790741 MAarrowhead1
% End of user PostScript
1 .473 0 r
.48507 .47615 m
.49093 .46835 L
s
% Start of user PostScript
-1.7914653 -2.8619398 -1.0878991 -3.7985076 MAarrowhead1
% End of user PostScript
1 .788 0 r
.54864 .46436 m
.55346 .47516 L
s
% Start of user PostScript
5.8364121 -4.2766982 6.4146245 -2.981141 MAarrowhead1
% End of user PostScript
.897 1 0 r
.49943 .59498 m
.47941 .60707 L
s
% Start of user PostScript
-0.068646039 11.398194 -2.4703791 12.847842 MAarrowhead1
% End of user PostScript
.581 1 0 r
.36828 .51651 m
.37211 .47694 L
s
% Start of user PostScript
-15.80693 1.9809362 -15.3465 -2.7673412 MAarrowhead1
% End of user PostScript
.266 1 0 r
.61301 .22784 m
.66417 .22848 L
s
% Start of user PostScript
13.56129 -32.659631 19.700294 -32.58253 MAarrowhead1
% End of user PostScript
0 1 .049 r
.76244 .68541 m
.70873 .79243 L
s
% Start of user PostScript
31.493098 22.249495 25.047135 35.091414 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-63.51061 69.952153 -74.744042 58.87666 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-31.868993 -119.6689 -4.8421215 -145.20556 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
199.60499 -88.894427 207.27243 -37.180819 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-82.262531 400.50988 -162.21682 426.16938 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-472.97797 -97.242635 -426.16863 -259.52603 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
623.81279 -1006.419 801.54436 -938.85616 MAarrowhead1
% End of user PostScript
1 0 .32 r
.54356 .42296 m
.5574 .4268 L
.56966 .43552 L
.57939 .44925 L
.58569 .46783 L
.58772 .49081 L
.58478 .51739 L
.5764 .54647 L
.56235 .57666 L
.5427 .60629 L
.5179 .63353 L
.48872 .65643 L
.45633 .67305 L
.42224 .68157 L
.38824 .68039 L
.35638 .6683 L
.32884 .64456 L
.30785 .60904 L
.29551 .56228 L
.29373 .50559 L
.30402 .44101 L
.32736 .37136 L
.3641 .3001 L
.41385 .23127 L
.47535 .16931 L
.54651 .11881 L
.62437 .08433 L
.70519 .07005 L
.78452 .0795 L
.85745 .11529 L
.91878 .17879 L
.9633 .26989 L
.98611 .38686 L
.98297 .52614 L
.95061 .68241 L
.88707 .84861 L
s
.88707 .84861 m
.80115 1 L
s
1 0 0 r
.54356 .42296 m
.5574 .4268 L
s
% Start of user PostScript
5.2270395 -9.2450092 6.8876633 -8.7837141 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56966 .43552 m
.57939 .44925 L
s
% Start of user PostScript
8.3586401 -7.7371678 9.5269947 -6.0898576 MAarrowhead1
% End of user PostScript
1 .473 0 r
.5179 .63353 m
.48872 .65643 L
s
% Start of user PostScript
2.1476089 16.023475 -1.3534455 18.771793 MAarrowhead1
% End of user PostScript
1 .788 0 r
.29551 .56228 m
.29373 .50559 L
s
% Start of user PostScript
-24.538292 7.4738872 -24.751868 0.67060381 MAarrowhead1
% End of user PostScript
.897 1 0 r
.62437 .08433 m
.70519 .07005 L
s
% Start of user PostScript
14.924737 -49.880188 24.622303 -51.594441 MAarrowhead1
% End of user PostScript
.581 1 0 r
.95061 .68241 m
.88707 .84861 L
s
% Start of user PostScript
54.073751 21.888907 46.448926 41.832627 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-86.322973 117.06758 -106.23211 104.85246 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-73.947383 -158.55441 -36.375278 -202.4315 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
297.21914 -184.06531 319.54696 -113.73552 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-50.475701 586.73845 -171.49947 646.50072 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-765.21648 3.8853733 -723.50814 -237.85737 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
784.6785 -1598.208 1078.3646 -1556.1133 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1416.1354 1341.7275 1054.2642 1963.2349 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3331.2095 3209.1061 -3823.3417 2568.8059 MAarrowhead1
% End of user PostScript
1 0 .53 r
.45273 .41996 m
.47225 .39467 L
.49602 .37228 L
.52319 .35454 L
.5526 .3431 L
.58279 .3395 L
.61206 .34499 L
.63855 .36046 L
.6603 .38631 L
.67538 .42238 L
.68202 .46788 L
.67868 .52135 L
.66424 .58068 L
.63809 .64309 L
.60022 .70527 L
.55133 .7635 L
.49286 .81376 L
.42704 .852 L
.35681 .87435 L
.28576 .87734 L
.21803 .85823 L
.1581 .81521 L
.11058 .74766 L
.07995 .65636 L
.0703 .54357 L
.08499 .41316 L
.12638 .27057 L
.19556 .12268 L
s
.19556 .12268 m
.2772 0 L
s
1 0 0 r
.45273 .41996 m
.47225 .39467 L
s
% Start of user PostScript
-5.6725954 -9.604328 -3.3303713 -12.63991 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49602 .37228 m
.52319 .35454 L
s
% Start of user PostScript
-0.47767181 -15.325875 2.7833469 -17.45549 MAarrowhead1
% End of user PostScript
1 .473 0 r
.68202 .46788 m
.67868 .52135 L
s
% Start of user PostScript
21.842308 -3.8545096 21.441862 2.5625281 MAarrowhead1
% End of user PostScript
1 .788 0 r
.35681 .87435 m
.28576 .87734 L
s
% Start of user PostScript
-17.182948 44.921458 -25.708487 45.280714 MAarrowhead1
% End of user PostScript
.897 1 0 r
.12638 .27057 m
.19556 .12268 L
s
% Start of user PostScript
-44.83457 -27.531674 -36.532344 -45.278967 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
84.643894 -98.813854 100.79396 -84.773926 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
50.253401 158.44805 14.020581 194.81061 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-272.60679 134.53653 -285.84961 65.60465 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
94.05741 -544.54161 203.75356 -585.0601 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
661.43743 95.043873 604.61815 316.70398 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-815.33548 1399.7983 -1065.4441 1322.386 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1108.0949 -1442.765 -742.02011 -1979.7989 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3153.9021 -2584.2819 3524.0216 -1919.454 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
343.50846 6108.4758 -964.75465 7005.7558 MAarrowhead1
% End of user PostScript
0 1 .563 r
.43261 .53267 m
.42946 .51556 L
.4301 .49524 L
.43499 .47249 L
.44441 .44836 L
.4584 .4241 L
.47673 .40113 L
.49889 .381 L
.52406 .36528 L
.55116 .35551 L
.57881 .35305 L
.60544 .35903 L
.62933 .37421 L
.64869 .39892 L
.66176 .43294 L
.66692 .47549 L
.66282 .52517 L
.64846 .57997 L
.62333 .63729 L
.5875 .69405 L
.54168 .7468 L
.48728 .79185 L
.42639 .8255 L
.36179 .84422 L
.29682 .8449 L
.23532 .8251 L
.18142 .78328 L
.13934 .719 L
.11317 .6331 L
.10658 .52782 L
.12257 .40686 L
.1632 .27536 L
.22933 .13974 L
.3204 .00755 L
s
.3204 .00755 m
.32755 0 L
s
1 0 0 r
.43261 .53267 m
.42946 .51556 L
s
% Start of user PostScript
-8.0865193 3.9207977 -8.4645664 1.8669821 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4301 .49524 m
.43499 .47249 L
s
% Start of user PostScript
-8.3881523 -0.57163617 -7.8013234 -3.3008623 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57881 .35305 m
.60544 .35903 L
s
% Start of user PostScript
9.4571158 -17.63372 12.653053 -16.916199 MAarrowhead1
% End of user PostScript
1 .788 0 r
.62333 .63729 m
.5875 .69405 L
s
% Start of user PostScript
14.799429 16.474257 10.50009 23.285949 MAarrowhead1
% End of user PostScript
.897 1 0 r
.18142 .78328 m
.13934 .719 L
s
% Start of user PostScript
-38.229321 33.994084 -43.278986 26.280096 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-7.8821069 -73.545031 8.0773718 -85.534105 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
110.58734 -30.176968 110.80999 0.93611952 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-72.145293 225.44971 -115.71604 231.71372 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-239.56339 -108.72988 -203.30216 -198.60418 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
398.81261 -520.83642 486.56852 -461.81859 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
313.75418 736.25289 140.93317 930.61991 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1349.5613 792.81578 -1441.8779 467.92924 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
289.02977 -2672.1667 836.91764 -2925.6154 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3423.9318 105.89917 3211.2908 1203.4824 MAarrowhead1
% End of user PostScript
0 .832 1 r
.5087 .48255 m
.5119 .48305 L
.51481 .48463 L
.51723 .48733 L
.51895 .49115 L
.51976 .49601 L
.51951 .50175 L
.51805 .50815 L
.51533 .51492 L
.51133 .5217 L
.50612 .52809 L
.49985 .53365 L
.49276 .53795 L
.48515 .54055 L
.47742 .54109 L
.47 .53924 L
.46339 .53481 L
.45808 .52772 L
.45456 .51802 L
.45328 .50596 L
.45462 .49194 L
.45884 .47654 L
.46608 .46048 L
.4763 .44464 L
.48931 .42999 L
.50468 .41756 L
.52181 .4084 L
.53993 .40348 L
.55808 .40367 L
.57519 .40962 L
.59008 .42175 L
.60159 .44017 L
.60857 .46461 L
.61001 .49441 L
.60507 .52851 L
.59322 .56545 L
.57422 .60341 L
.54827 .64026 L
.51599 .67364 L
.47845 .70112 L
.4372 .72026 L
.39421 .72882 L
.3518 .72486 L
.31258 .70697 L
.27931 .67436 L
.25478 .62701 L
.2416 .56577 L
.24208 .49246 L
.25801 .40984 L
.29049 .32159 L
Mistroke
.33978 .23224 L
.4052 .14695 L
.48498 .07137 L
.57627 .01128 L
Mfstroke
.57627 .01128 m
.60492 0 L
s
.91448 0 m
.96485 .02897 L
s
.96485 .02897 m
1 .07023 L
s
1 .898 m
.96688 .97768 L
s
.96688 .97768 m
.95337 1 L
s
1 0 0 r
.5087 .48255 m
.5119 .48305 L
s
% Start of user PostScript
1.0436258 -2.0941631 1.42759 -2.0341158 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51481 .48463 m
.51723 .48733 L
s
% Start of user PostScript
1.7775419 -1.8447656 2.0680829 -1.5201884 MAarrowhead1
% End of user PostScript
1 .473 0 r
.50612 .52809 m
.49985 .53365 L
s
% Start of user PostScript
0.73445507 3.3703785 -0.017669979 4.0379627 MAarrowhead1
% End of user PostScript
1 .788 0 r
.45456 .51802 m
.45328 .50596 L
s
% Start of user PostScript
-5.453303 2.1628202 -5.606681 0.71566588 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52181 .4084 m
.53993 .40348 L
s
% Start of user PostScript
2.6177381 -10.991662 4.7920035 -11.581866 MAarrowhead1
% End of user PostScript
.581 1 0 r
.60507 .52851 m
.59322 .56545 L
s
% Start of user PostScript
12.608672 3.4212015 11.185889 7.854363 MAarrowhead1
% End of user PostScript
.266 1 0 r
.3518 .72486 m
.31258 .70697 L
s
% Start of user PostScript
-17.784304 26.98366 -22.490714 24.836977 MAarrowhead1
% End of user PostScript
0 1 .049 r
.33978 .23224 m
.4052 .14695 L
s
% Start of user PostScript
-19.226121 -32.131428 -11.37637 -42.365641 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
64.610516 -46.161882 70.761967 -31.667134 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-2.4067716 126.40115 -28.949522 141.95621 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-173.59316 18.529411 -167.85596 -34.032972 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
153.42437 -359.27222 220.72064 -357.08073 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
342.05842 253.62223 269.52182 394.64732 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-706.47598 762.00619 -828.03095 636.72379 MAarrowhead1
% End of user PostScript
1 0 .864 r
.41946 .49331 m
.42535 .46696 L
.43647 .43906 L
.45287 .41108 L
.47425 .38468 L
.50002 .36165 L
.52922 .34379 L
.56056 .33288 L
.59247 .33047 L
.6231 .33786 L
.65048 .3559 L
.67253 .38494 L
.68722 .42471 L
.69271 .47425 L
.68743 .53194 L
.67028 .5954 L
.64068 .66161 L
.59875 .72701 L
.54535 .78758 L
.48214 .83906 L
.41158 .87717 L
.33689 .89787 L
.26199 .8976 L
.1913 .87357 L
.12962 .82407 L
.08181 .74866 L
.05257 .64837 L
.04613 .52588 L
.06589 .38554 L
.11417 .23333 L
.1919 .07677 L
s
.1919 .07677 m
.2456 0 L
s
1 0 0 r
.41946 .49331 m
.42535 .46696 L
s
% Start of user PostScript
-9.6642248 -0.80226685 -8.957802 -3.9652307 MAarrowhead1
% End of user PostScript
1 .158 0 r
.43647 .43906 m
.45287 .41108 L
s
% Start of user PostScript
-7.6231078 -7.3128655 -5.6560853 -10.670119 MAarrowhead1
% End of user PostScript
1 .473 0 r
.65048 .3559 m
.67253 .38494 L
s
% Start of user PostScript
18.057807 -17.291564 20.703534 -13.807157 MAarrowhead1
% End of user PostScript
1 .788 0 r
.54535 .78758 m
.48214 .83906 L
s
% Start of user PostScript
5.4425335 34.509311 -2.1430122 40.687017 MAarrowhead1
% End of user PostScript
.897 1 0 r
.05257 .64837 m
.04613 .52588 L
s
% Start of user PostScript
-53.691291 17.804039 -54.464777 3.1053081 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
30.635381 -108.87054 51.9095 -113.22627 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
120.0266 43.722045 104.12852 87.362847 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-184.8335 258.94634 -229.21074 233.86073 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-169.87326 -337.95067 -89.108961 -435.35302 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
646.16413 -417.9395 698.45699 -267.33485 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-84.974352 1272.2756 -348.76096 1409.6118 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1684.557 59.568958 -1603.5064 -466.02096 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1656.3356 -3508.8066 2304.8028 -3437.4086 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3177.6283 2806.9754 2408.6235 4175.265 MAarrowhead1
% End of user PostScript
0 .467 1 r
.44146 .57571 m
.42873 .56695 L
.41856 .55303 L
.41189 .5341 L
.40959 .51061 L
.41238 .48336 L
.42076 .45347 L
.43499 .42238 L
.45498 .39178 L
.48032 .36356 L
.51021 .33972 L
.54347 .32226 L
.57857 .31307 L
.61365 .31382 L
.64663 .32576 L
.67525 .34968 L
.69723 .38576 L
.71038 .43345 L
.71273 .49146 L
.70271 .5577 L
.67927 .62933 L
.64201 .70277 L
.59133 .7739 L
.52844 .83817 L
.45549 .89083 L
.37548 .92719 L
.29225 .94292 L
.21031 .93433 L
.13475 .89869 L
.07091 .83453 L
.02415 .74188 L
s
.02415 .74188 m
0 .62463 L
s
0 .5901 m
.00152 .47984 L
.03348 .31944 L
.09751 .14844 L
s
.09751 .14844 m
.18047 0 L
s
1 0 0 r
.44146 .57571 m
.42873 .56695 L
s
% Start of user PostScript
-7.0253599 9.0854787 -8.5523703 8.0342962 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41856 .55303 m
.41189 .5341 L
s
% Start of user PostScript
-9.7726659 6.3640129 -10.572634 4.0918061 MAarrowhead1
% End of user PostScript
1 .473 0 r
.51021 .33972 m
.54347 .32226 L
s
% Start of user PostScript
1.2252014 -19.23403 5.2163819 -21.329066 MAarrowhead1
% End of user PostScript
1 .788 0 r
.71273 .49146 m
.70271 .5577 L
s
% Start of user PostScript
25.528183 -1.024723 24.325671 6.9244443 MAarrowhead1
% End of user PostScript
.897 1 0 r
.29225 .94292 m
.21031 .93433 L
s
% Start of user PostScript
-24.93056 53.150563 -34.762235 52.119445 MAarrowhead1
% End of user PostScript
.581 1 0 r
.09751 .14844 m
0 0 rlineto s
.09751 .14844 m
.18047 0 L
s
% Start of user PostScript
-48.298342 -42.186709 -36.710718 -62.922328 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
108.63488 -108.78284 125.55553 -88.434976 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
39.369456 206.71961 -6.4460087 245.86796 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-328.61184 120.79111 -335.84116 32.35535 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
171.0305 -664.12692 301.68678 -695.71518 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
748.54585 233.59232 657.6452 500.71335 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1098.2749 1607.6351 -1376.5219 1467.4822 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1105.4771 -1995.2353 -622.95085 -2602.7582 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3920.7962 -2681.7802 4268.8708 -1786.7628 MAarrowhead1
% End of user PostScript
1 .791 0 r
.56034 .47161 m
.56298 .48704 L
.56221 .50531 L
.55763 .52569 L
.54901 .54725 L
.53631 .56886 L
.51976 .58925 L
.49983 .60702 L
.47725 .62079 L
.45302 .62918 L
.42837 .63098 L
.40471 .62521 L
.38358 .61121 L
.36658 .58871 L
.35527 .55793 L
.35109 .51959 L
.35523 .47498 L
.36856 .42592 L
.3915 .37475 L
.42396 .32423 L
.46528 .27747 L
.51418 .23775 L
.56874 .20838 L
.62646 .1925 L
.68433 .19284 L
.73891 .21154 L
.78651 .24994 L
.82336 .30836 L
.84584 .38598 L
.85068 .48075 L
.83525 .58928 L
.79778 .70693 L
.73756 .82791 L
.65515 .94544 L
s
.65515 .94544 m
.60263 1 L
s
1 0 0 r
.56034 .47161 m
.56298 .48704 L
s
% Start of user PostScript
7.2406222 -3.4071518 7.5572784 -1.5548156 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56221 .50531 m
.55763 .52569 L
s
% Start of user PostScript
7.4654069 0.63688003 6.9160918 3.0824152 MAarrowhead1
% End of user PostScript
1 .473 0 r
.42837 .63098 m
.40471 .62521 L
s
% Start of user PostScript
-8.5952607 15.717788 -11.434746 15.02578 MAarrowhead1
% End of user PostScript
1 .788 0 r
.3915 .37475 m
.42396 .32423 L
s
% Start of user PostScript
-13.020387 -15.030485 -9.1246242 -21.092611 MAarrowhead1
% End of user PostScript
.897 1 0 r
.78651 .24994 m
.82336 .30836 L
s
% Start of user PostScript
34.381259 -30.00766 38.803466 -22.997249 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
6.3021241 66.247424 -8.0294103 76.794284 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-98.790356 25.515455 -98.684844 -2.4648138 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
66.458367 -201.66852 105.32624 -206.66296 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
212.30772 101.27924 179.13371 181.56344 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-360.29215 462.49663 -437.8765 408.1422 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-272.25885 -666.63702 -116.43619 -838.88125 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1209.7415 -693.13574 1288.7917 -399.64435 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-283.52026 2398.5891 -773.97674 2618.4661 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3048.5238 -145.37581 -2848.4154 -1129.2123 MAarrowhead1
% End of user PostScript
.919 0 1 r
.47947 .42149 m
.49718 .40486 L
.51741 .39168 L
.5393 .38321 L
.56177 .38058 L
.58354 .38472 L
.60322 .39628 L
.61938 .41557 L
.63056 .44246 L
.63545 .47637 L
.63291 .5162 L
.6221 .56036 L
.60258 .60681 L
.57434 .65307 L
.5379 .69636 L
.49435 .7337 L
.44534 .76209 L
.39307 .77862 L
.34021 .78073 L
.28984 .76639 L
.2453 .73424 L
.21002 .68385 L
.18734 .61579 L
.18028 .53176 L
.19135 .43464 L
.22229 .32849 L
.27392 .21844 L
.34591 .11053 L
.43667 .01147 L
s
.43667 .01147 m
.45138 0 L
s
1 0 0 r
.47947 .42149 m
.49718 .40486 L
s
% Start of user PostScript
-2.4639813 -9.420762 -0.33882279 -11.416898 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51741 .39168 m
.5393 .38321 L
s
% Start of user PostScript
2.0895035 -12.997953 4.7165469 -14.014369 MAarrowhead1
% End of user PostScript
1 .473 0 r
.63291 .5162 m
.6221 .56036 L
s
% Start of user PostScript
15.948862 1.9435182 14.652302 7.24333 MAarrowhead1
% End of user PostScript
1 .788 0 r
.34021 .78073 m
.28984 .76639 L
s
% Start of user PostScript
-19.174643 33.687633 -25.218631 31.966218 MAarrowhead1
% End of user PostScript
.897 1 0 r
.27392 .21844 m
.34591 .11053 L
s
% Start of user PostScript
-27.129293 -33.78709 -18.490888 -46.736934 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
75.076946 -62.984266 84.197009 -47.347746 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
10.220336 145.1356 -20.978028 167.10643 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-212.72801 48.405646 -211.1211 -12.688959 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
152.21344 -435.47686 235.65973 -443.50587 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
449.46259 236.88911 374.48828 409.75504 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-794.06205 983.31025 -957.45469 858.86862 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-549.88762 -1475.938 -207.83516 -1840.5427 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2623.7599 -1424.0815 2778.4869 -777.31167 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-725.28799 5216.9711 -1786.0019 5660.8193 MAarrowhead1
% End of user PostScript
.025 0 1 r
.56488 .43911 m
.57412 .45179 L
.58017 .46903 L
.58225 .49042 L
.5797 .51522 L
.57206 .54242 L
.55911 .57071 L
.5409 .59854 L
.51783 .62421 L
.49062 .64589 L
.46036 .66175 L
.42842 .67009 L
.3965 .66938 L
.36651 .65848 L
.34048 .63668 L
.3205 .60383 L
.30856 .5604 L
.30645 .5076 L
.31561 .44731 L
.33698 .38213 L
.37091 .31531 L
.41706 .2506 L
.47431 .19215 L
.54071 .14428 L
.61352 .11125 L
.68925 .097 L
.76379 .10489 L
.83251 .13739 L
.89056 .19584 L
.93304 .28022 L
.95536 .38894 L
.95349 .51876 L
.92433 .66474 L
.86598 .82034 L
.77803 .97755 L
s
.77803 .97755 m
.76059 1 L
s
1 0 0 r
.56488 .43911 m
.57412 .45179 L
s
% Start of user PostScript
7.7851305 -7.3062381 8.8944129 -5.7848554 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58017 .46903 m
.58225 .49042 L
s
% Start of user PostScript
9.6209624 -3.7159142 9.87049 -1.1498923 MAarrowhead1
% End of user PostScript
1 .473 0 r
.46036 .66175 m
.42842 .67009 L
s
% Start of user PostScript
-4.7573965 19.410591 -8.5895312 20.410233 MAarrowhead1
% End of user PostScript
1 .788 0 r
.31561 .44731 m
.33698 .38213 L
s
% Start of user PostScript
-22.12712 -6.3229485 -19.562928 -14.143944 MAarrowhead1
% End of user PostScript
.897 1 0 r
.76379 .10489 m
.83251 .13739 L
s
% Start of user PostScript
31.654327 -47.413431 39.901514 -43.513174 MAarrowhead1
% End of user PostScript
.581 1 0 r
.77803 .97755 m
0 0 rlineto s
.77803 .97755 m
.76059 1 L
s
% Start of user PostScript
33.364125 57.305402 19.415752 75.264955 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-114.27571 80.395346 -124.89178 54.597261 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5.9988183 -223.79701 52.896982 -250.78765 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
305.55782 -29.176221 294.73341 63.787785 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-274.8476 633.03018 -393.17119 627.73885 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-598.03594 -456.31556 -468.49521 -704.54079 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1253.1284 -1334.6529 1465.1572 -1110.2392 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
565.32284 2369.6819 33.791081 2854.5453 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3884.6917 1622.9078 -4011.3017 602.63156 MAarrowhead1
% End of user PostScript
0 .907 1 r
.56407 .5583 m
.54821 .58611 L
.52735 .61248 L
.5021 .63566 L
.47335 .65384 L
.44236 .66526 L
.41069 .66835 L
.38012 .6618 L
.35264 .64474 L
.33028 .61678 L
.31507 .57812 L
.30886 .52966 L
.31322 .47298 L
.3293 .41037 L
.35771 .34476 L
.39838 .27967 L
.45053 .21906 L
.51257 .16713 L
.58212 .12814 L
.65603 .10614 L
.73049 .10469 L
.80111 .12662 L
.86317 .17374 L
.91184 .2466 L
.94243 .34426 L
.95071 .46422 L
.93321 .60228 L
.88755 .75263 L
.8127 .90793 L
s
.8127 .90793 m
.74987 1 L
s
1 0 0 r
.56407 .5583 m
.54821 .58611 L
s
% Start of user PostScript
7.688446 6.9957147 5.7847257 10.332711 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52735 .61248 m
.5021 .63566 L
s
% Start of user PostScript
3.282547 13.497817 0.25144736 16.279388 MAarrowhead1
% End of user PostScript
1 .473 0 r
.31507 .57812 m
.30886 .52966 L
s
% Start of user PostScript
-22.191855 9.3746316 -22.936984 3.5595238 MAarrowhead1
% End of user PostScript
1 .788 0 r
.58212 .12814 m
.65603 .10614 L
s
% Start of user PostScript
9.8542683 -44.623012 18.724126 -47.263779 MAarrowhead1
% End of user PostScript
.897 1 0 r
.93321 .60228 m
.88755 .75263 L
s
% Start of user PostScript
51.98574 12.273903 46.506172 30.315432 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-70.773284 110.91263 -90.247641 102.82553 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-81.428612 -127.21024 -50.0558 -169.40948 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
261.28079 -193.85559 287.67215 -136.16661 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
0.26884891 509.81998 -107.34178 575.71712 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-710.46229 95.581014 -691.14906 -116.99134 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
600.41145 -1466.7082 876.58599 -1465.9717 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1423.2116 981.20718 1137.0337 1558.4156 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2836.3072 3156.6991 -3344.8842 2666.3047 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1468.8105 -5338.1701 -260.57693 -6492.2487 MAarrowhead1
% End of user PostScript
.152 0 1 r
.47104 .51025 m
.47048 .50241 L
.47162 .49337 L
.47459 .48353 L
.47948 .47336 L
.48624 .46343 L
.49472 .45435 L
.50465 .44679 L
.51562 .44139 L
.52712 .43877 L
.53854 .43946 L
.54917 .44384 L
.55829 .45216 L
.56515 .46443 L
.56903 .48047 L
.56932 .4998 L
.56551 .52172 L
.55729 .54526 L
.54455 .56924 L
.52746 .59228 L
.50646 .61288 L
.48228 .6295 L
.45593 .64061 L
.4287 .64481 L
.40211 .64093 L
.3778 .62813 L
.35755 .60599 L
.3431 .57458 L
.33608 .53454 L
.3379 .4871 L
.34963 .43412 L
.37189 .37802 L
.40476 .32172 L
.44768 .26855 L
.49943 .22211 L
.55811 .18606 L
.62114 .16393 L
.68533 .15889 L
.74702 .17353 L
.80219 .20958 L
.84669 .26776 L
.87644 .34753 L
.88769 .44702 L
.87733 .56291 L
.84308 .69048 L
.78381 .82368 L
.69973 .95531 L
s
.69973 .95531 m
.66046 1 L
s
1 0 0 r
.47104 .51025 m
.47048 .50241 L
s
% Start of user PostScript
-3.4754745 1.2303057 -3.5419702 0.28889462 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47162 .49337 m
.47459 .48353 L
s
% Start of user PostScript
-3.4060888 -0.79509254 -3.0489876 -1.9759944 MAarrowhead1
% End of user PostScript
1 .473 0 r
.53854 .43946 m
.54917 .44384 L
s
% Start of user PostScript
4.6243807 -7.2652651 5.9006804 -6.7391907 MAarrowhead1
% End of user PostScript
1 .788 0 r
.54455 .56924 m
.52746 .59228 L
s
% Start of user PostScript
5.3458898 8.3086321 3.295275 11.07353 MAarrowhead1
% End of user PostScript
.897 1 0 r
.35755 .60599 m
.3431 .57458 L
s
% Start of user PostScript
-17.093679 12.718869 -18.827938 8.9493928 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49943 .22211 m
.55811 .18606 L
s
% Start of user PostScript
-0.068189705 -33.346999 6.973365 -37.673309 MAarrowhead1
% End of user PostScript
.266 1 0 r
.88769 .44702 m
.87733 .56291 L
s
% Start of user PostScript
46.523134 -6.3576319 45.27928 7.5494809 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-39.179181 96.025913 -57.267651 96.018841 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-93.312374 -63.968408 -74.626062 -101.76588 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
185.4543 -206.90001 218.81284 -174.89928 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
96.731201 348.94812 17.710932 424.61556 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-585.96406 267.15767 -609.78069 116.14629 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
232.85811 -1174.589 467.80939 -1252.4994 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1395.7876 267.64316 1261.729 744.05687 MAarrowhead1
% End of user PostScript
1 0 .988 r
.54152 .48333 m
.54274 .49432 L
.54156 .50712 L
.53775 .52119 L
.53117 .53588 L
.52187 .55038 L
.51002 .56381 L
.496 .57522 L
.48035 .58366 L
.46378 .58824 L
.44717 .58816 L
.4315 .58282 L
.41783 .57183 L
.40724 .55509 L
.40077 .53283 L
.39935 .50566 L
.40375 .47453 L
.41448 .44077 L
.43173 .40605 L
.45535 .37231 L
.48478 .34169 L
.51904 .31644 L
.55672 .29877 L
.59604 .29075 L
.63486 .29414 L
.67081 .31026 L
.70136 .33984 L
.72397 .38291 L
.73623 .4387 L
.73604 .50557 L
.72175 .58102 L
.69233 .66167 L
.64752 .74343 L
.58794 .82155 L
.51519 .8909 L
.43185 .94617 L
.34148 .98219 L
.24852 .99425 L
.15819 .97845 L
.07621 .932 L
.00859 .85361 L
s
.00859 .85361 m
0 .83365 L
s
0 .23918 m
.07115 .06665 L
s
.07115 .06665 m
.11124 0 L
s
1 0 0 r
.54152 .48333 m
.54274 .49432 L
s
% Start of user PostScript
4.9829877 -2.0003655 5.1282189 -0.68112759 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54156 .50712 m
.53775 .52119 L
s
% Start of user PostScript
4.9869581 0.85438488 4.5294838 2.5433959 MAarrowhead1
% End of user PostScript
1 .473 0 r
.44717 .58816 m
.4315 .58282 L
s
% Start of user PostScript
-6.3392332 10.579568 -8.2196986 9.9384625 MAarrowhead1
% End of user PostScript
1 .788 0 r
.43173 .40605 m
.45535 .37231 L
s
% Start of user PostScript
-8.192153 -11.274131 -5.3574939 -15.322881 MAarrowhead1
% End of user PostScript
.897 1 0 r
.70136 .33984 m
.72397 .38291 L
s
% Start of user PostScript
24.163435 -19.218886 26.876585 -14.050418 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51519 .8909 m
.43185 .94617 L
s
% Start of user PostScript
1.8232144 46.907908 -8.1778605 53.540366 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-67.2257 12.55224 -66.138612 -7.1090225 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
51.925557 -138.12972 78.191481 -139.52266 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
138.80271 82.75494 113.62336 137.3784 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-258.5932 305.45421 -308.68643 263.02216 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-158.50187 -483.4047 -47.671998 -595.9837 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
837.04212 -421.28823 879.43333 -210.68968 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-277.39228 1670.4941 -614.5275 1798.3222 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2040.6069 -268.27222 -1870.5785 -948.89735 MAarrowhead1
% End of user PostScript
.571 1 0 r
.47239 .52638 m
.46835 .52105 L
.46567 .51374 L
.46468 .50465 L
.46566 .49407 L
.46882 .48243 L
.47426 .47029 L
.48196 .45831 L
.49176 .44722 L
.50336 .4378 L
.5163 .43083 L
.52999 .42706 L
.54372 .42714 L
.55666 .43157 L
.56796 .44068 L
.5767 .45453 L
.58203 .47295 L
.58318 .49542 L
.57953 .52116 L
.57064 .54907 L
.55636 .57777 L
.53681 .60565 L
.51247 .63094 L
.48414 .65179 L
.45299 .66636 L
.42049 .67296 L
.38841 .67011 L
.35871 .65675 L
.33348 .63225 L
.31482 .59661 L
.30473 .55046 L
.30493 .49515 L
.31679 .43277 L
.34116 .3661 L
.37825 .29853 L
.42754 .23398 L
.48771 .1767 L
.55662 .13107 L
.63133 .10137 L
.70816 .09149 L
.78281 .10466 L
.85053 .14315 L
.90636 .20805 L
.94539 .29901 L
.96305 .41406 L
.95546 .54955 L
.91969 .70013 L
.85412 .85882 L
s
.85412 .85882 m
.7691 1 L
s
1 0 0 r
.47239 .52638 m
.46835 .52105 L
s
% Start of user PostScript
-3.3135589 3.1658069 -3.7975339 2.5255049 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46567 .51374 m
.46468 .50465 L
s
% Start of user PostScript
-4.1194777 1.6493353 -4.2386164 0.55814437 MAarrowhead1
% End of user PostScript
1 .473 0 r
.5163 .43083 m
.52999 .42706 L
s
% Start of user PostScript
1.9558451 -8.3003151 3.5988972 -8.7526313 MAarrowhead1
% End of user PostScript
1 .788 0 r
.57953 .52116 m
.57064 .54907 L
s
% Start of user PostScript
9.5430055 2.5397734 8.4766251 5.8886554 MAarrowhead1
% End of user PostScript
.897 1 0 r
.38841 .67011 m
.35871 .65675 L
s
% Start of user PostScript
-13.391145 20.413622 -16.955129 18.809561 MAarrowhead1
% End of user PostScript
.581 1 0 r
.37825 .29853 m
.42754 .23398 L
s
% Start of user PostScript
-14.609951 -24.176363 -8.6956412 -31.922327 MAarrowhead1
% End of user PostScript
.266 1 0 r
.90636 .20805 m
.94539 .29901 L
s
% Start of user PostScript
48.7628 -35.033672 53.446448 -24.119303 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1.5456204 95.361149 -21.585349 107.18191 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-131.24324 14.543626 -127.01853 -25.126581 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
115.25005 -271.52425 166.14904 -270.09031 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
259.23978 190.21068 204.68877 296.83219 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-532.63224 577.1368 -624.83288 483.02348 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-254.01158 -1005.378 -27.712977 -1215.5734 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1662.7709 -718.14167 1721.9206 -284.4629 MAarrowhead1
% End of user PostScript
0 1 .359 r
.47264 .47925 m
.47853 .46791 L
.4865 .45697 L
.49633 .44714 L
.50769 .43916 L
.5201 .43374 L
.53297 .43155 L
.54558 .43315 L
.55716 .43895 L
.56686 .44917 L
.57388 .46377 L
.57742 .48248 L
.57681 .50473 L
.57154 .52966 L
.56131 .55613 L
.54605 .58279 L
.52602 .60805 L
.50177 .63024 L
.47419 .64761 L
.44447 .6585 L
.4141 .66138 L
.38482 .65502 L
.35851 .63857 L
.33712 .61166 L
.32261 .57451 L
.31674 .52798 L
.32102 .47358 L
.33655 .41351 L
.36389 .3506 L
.40298 .28822 L
.45307 .23017 L
.51262 .18048 L
.57936 .14323 L
.65024 .1223 L
.7216 .1211 L
.78925 .14234 L
.84866 .18774 L
.89518 .25781 L
.92433 .35165 L
.93206 .46683 L
.91505 .59932 L
.87102 .74353 L
.799 .89243 L
s
.799 .89243 m
.72539 1 L
s
1 0 0 r
.47264 .47925 m
.47853 .46791 L
s
% Start of user PostScript
-3.2837788 -2.489835 -2.5758059 -3.8507894 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4865 .45697 m
.49633 .44714 L
s
% Start of user PostScript
-1.6199554 -5.1633051 -0.44022628 -6.3426584 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57388 .46377 m
.57742 .48248 L
s
% Start of user PostScript
8.8651536 -4.3472495 9.2899277 -2.1019922 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47419 .64761 m
.44447 .6585 L
s
% Start of user PostScript
-3.0975621 17.713649 -6.6638116 19.019688 MAarrowhead1
% End of user PostScript
.897 1 0 r
.32102 .47358 m
.33655 .41351 L
s
% Start of user PostScript
-21.477051 -3.1709705 -19.614202 -10.379289 MAarrowhead1
% End of user PostScript
.581 1 0 r
.7216 .1211 m
.78925 .14234 L
s
% Start of user PostScript
26.592387 -45.467643 34.71025 -42.918662 MAarrowhead1
% End of user PostScript
.266 1 0 r
.799 .89243 m
0 0 rlineto s
.799 .89243 m
.72539 1 L
s
% Start of user PostScript
35.880106 47.091051 23.947604 64.528529 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-102.64478 83.748796 -114.61499 62.065605 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-10.681589 -198.86898 31.882647 -227.92219 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
288.05542 -59.384162 284.57902 24.139612 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-214.69628 590.82854 -327.45639 599.13155 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-601.35523 -338.49386 -496.49587 -572.56043 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1092.4287 -1319.6292 1310.218 -1144.1488 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
710.31816 2036.6974 241.00321 2524.4773 MAarrowhead1
% End of user PostScript
0 1 .302 r
.57019 .54397 m
.557 .57187 L
.53867 .59919 L
.51559 .62424 L
.4885 .64521 L
.45849 .66031 L
.42696 .66787 L
.3956 .66642 L
.36628 .65485 L
.34103 .63251 L
.3219 .59929 L
.31084 .55572 L
.3096 .50303 L
.31954 .44315 L
.34157 .37868 L
.37598 .31286 L
.42236 .24944 L
.47956 .19252 L
.54559 .14636 L
.61769 .11514 L
.69237 .10271 L
.76553 .11232 L
.83259 .14634 L
.88874 .20597 L
.92919 .29108 L
.94943 .39998 L
.94556 .52934 L
.91461 .67418 L
.8548 .82792 L
.76588 .98257 L
s
.76588 .98257 m
.752 1 L
s
1 0 0 r
.57019 .54397 m
.557 .57187 L
s
% Start of user PostScript
8.4222945 5.2769355 6.8405315 8.6243713 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53867 .59919 m
.51559 .62424 L
s
% Start of user PostScript
4.6402135 11.903185 1.8702003 14.908704 MAarrowhead1
% End of user PostScript
1 .473 0 r
.3219 .59929 m
.31084 .55572 L
s
% Start of user PostScript
-21.372315 11.914293 -22.698978 6.6864687 MAarrowhead1
% End of user PostScript
1 .788 0 r
.54559 .14636 m
.61769 .11514 L
s
% Start of user PostScript
5.4703123 -42.437233 14.122516 -46.183668 MAarrowhead1
% End of user PostScript
.897 1 0 r
.94556 .52934 m
.91461 .67418 L
s
% Start of user PostScript
53.467389 3.5209373 49.752758 20.901603 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-60.110122 112.37719 -80.486195 107.85479 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-94.478556 -104.65642 -67.14037 -148.07544 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
243.33723 -216.92012 275.59353 -167.88889 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
50.924823 468.02791 -50.681037 544.56631 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-704.54811 193.63836 -706.25822 -4.4036398 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
457.71008 -1436.0747 735.35042 -1476.5587 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1527.8789 688.73979 1297.6081 1261.3284 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2536.9665 3320.8935 -3096.8326 2946.4569 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2006.6062 -4682.0908 -906.94678 -5921.7267 MAarrowhead1
% End of user PostScript
0 1 .308 r
.51609 .50983 m
.51312 .51619 L
.50898 .52244 L
.50374 .52818 L
.49759 .533 L
.49076 .53649 L
.48357 .53828 L
.4764 .53802 L
.46969 .53546 L
.46389 .53044 L
.45948 .52294 L
.45689 .51307 L
.45652 .50111 L
.45871 .48749 L
.46364 .4728 L
.4714 .45778 L
.4819 .44328 L
.49488 .43023 L
.50989 .4196 L
.52631 .41235 L
.54334 .40936 L
.56006 .41139 L
.57543 .41896 L
.58834 .43238 L
.5977 .45161 L
.60248 .4763 L
.60179 .50568 L
.59493 .53864 L
.5815 .57368 L
.56142 .60899 L
.53501 .6425 L
.50299 .67198 L
.46653 .69513 L
.42721 .70972 L
.38699 .71375 L
.34816 .70556 L
.31322 .68403 L
.28476 .64866 L
.26535 .59971 L
.25734 .5383 L
.26275 .46642 L
.28302 .38698 L
.31893 .3037 L
.37042 .22104 L
.4365 .14401 L
.51516 .07795 L
.60338 .02827 L
.6972 .0001 L
s
.6972 .0001 m
.70186 0 L
s
.79825 0 m
.88147 .02555 L
.9604 .08507 L
s
.9604 .08507 m
1 .14396 L
s
1 .79489 m
.99275 .81887 L
s
.99275 .81887 m
.90577 1 L
s
1 0 0 r
.51609 .50983 m
.51312 .51619 L
s
% Start of user PostScript
1.9310144 1.1796417 1.5747355 1.9432208 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50898 .52244 m
.50374 .52818 L
s
% Start of user PostScript
1.0771068 2.6925822 0.44898478 3.3811436 MAarrowhead1
% End of user PostScript
1 .473 0 r
.45948 .52294 m
.45689 .51307 L
s
% Start of user PostScript
-4.8629155 2.7524702 -5.1735489 1.5683318 MAarrowhead1
% End of user PostScript
1 .788 0 r
.50989 .4196 m
.52631 .41235 L
s
% Start of user PostScript
1.1867705 -9.6481401 3.157019 -10.517911 MAarrowhead1
% End of user PostScript
.897 1 0 r
.60179 .50568 m
.59493 .53864 L
s
% Start of user PostScript
12.214615 0.6815746 11.391921 4.6363344 MAarrowhead1
% End of user PostScript
.581 1 0 r
.38699 .71375 m
.34816 .70556 L
s
% Start of user PostScript
-13.561108 25.649664 -18.220694 24.667713 MAarrowhead1
% End of user PostScript
.266 1 0 r
.31893 .3037 m
.37042 .22104 L
s
% Start of user PostScript
-21.728328 -23.555619 -15.549407 -33.474914 MAarrowhead1
% End of user PostScript
0 1 .049 r
.9604 .08507 m
0 0 rlineto s
.9604 .08507 m
1 .14396 L
s
% Start of user PostScript
55.247866 -49.791941 62.685775 -38.729724 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
12.316935 106.16118 -10.772539 123.76457 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-160.60098 45.522548 -161.28265 0.55760339 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
102.40813 -327.09393 165.74861 -336.89877 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
349.9083 153.02032 298.16711 283.54386 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-574.44148 759.65866 -702.83908 675.87132 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-465.09818 -1058.721 -215.8102 -1342.626 MAarrowhead1
% End of user PostScript
.192 1 0 r
.55754 .56163 m
.54134 .5878 L
.52051 .61222 L
.49569 .63319 L
.46782 .64902 L
.43815 .65807 L
.40823 .6589 L
.3798 .65036 L
.35474 .63172 L
.33502 .60274 L
.3225 .56377 L
.31891 .51581 L
.32564 .46053 L
.34366 .40023 L
.3734 .33786 L
.41466 .27686 L
.46649 .22103 L
.52723 .17442 L
.59443 .14101 L
.66495 .12456 L
.73502 .12831 L
.8004 .15473 L
.85657 .20526 L
.89896 .28009 L
.9232 .378 L
.92543 .49622 L
.90258 .63041 L
.85268 .77469 L
.77511 .92179 L
s
.77511 .92179 m
.71748 1 L
s
1 0 0 r
.55754 .56163 m
.54134 .5878 L
s
% Start of user PostScript
6.904847 7.3951151 4.9603847 10.535606 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52051 .61222 m
.49569 .63319 L
s
% Start of user PostScript
2.4612001 13.465942 -0.51752459 15.983385 MAarrowhead1
% End of user PostScript
1 .473 0 r
.3225 .56377 m
.31891 .51581 L
s
% Start of user PostScript
-21.299406 7.6524731 -21.730679 1.897576 MAarrowhead1
% End of user PostScript
1 .788 0 r
.59443 .14101 m
.66495 .12456 L
s
% Start of user PostScript
11.331795 -43.079199 19.793721 -45.052938 MAarrowhead1
% End of user PostScript
.897 1 0 r
.90258 .63041 m
.85268 .77469 L
s
% Start of user PostScript
48.309637 15.648951 42.322084 32.962419 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-71.679164 103.86038 -89.614824 94.576146 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-70.669438 -130.41747 -39.217712 -169.6247 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
254.63958 -171.97188 276.78156 -113.56036 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-23.358306 500.02172 -127.58792 557.17437 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-672.41802 44.385512 -644.41454 -162.75195 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
632.44638 -1396.7558 892.07731 -1376.8479 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1292.6909 1061.1823 996.88848 1607.3957 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2812.9499 2898.8795 -3268.4131 2382.5978 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1133.7817 -5337.4165 55.673001 -6385.3379 MAarrowhead1
% End of user PostScript
.886 0 1 r
.45468 .42911 m
.47216 .40562 L
.49362 .38462 L
.51833 .36771 L
.54523 .35643 L
.57302 .35222 L
.60015 .35625 L
.62492 .3694 L
.64554 .39209 L
.66023 .42423 L
.66731 .46517 L
.66536 .51364 L
.65329 .56775 L
.63047 .62503 L
.59684 .68247 L
.55295 .73668 L
.50005 .78399 L
.44011 .82067 L
.37577 .84311 L
.31026 .84807 L
.24734 .83294 L
.19112 .79593 L
.14583 .73635 L
.11564 .65474 L
.10434 .55304 L
.11513 .43463 L
.15032 .30436 L
.21104 .1684 L
.29708 .03412 L
s
.29708 .03412 m
.32715 0 L
s
1 0 0 r
.45468 .42911 m
.47216 .40562 L
s
% Start of user PostScript
-5.4386214 -8.5062407 -3.3411482 -11.326003 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49362 .38462 m
.51833 .36771 L
s
% Start of user PostScript
-0.76514521 -13.845769 2.1994792 -15.875324 MAarrowhead1
% End of user PostScript
1 .473 0 r
.66731 .46517 m
.66536 .51364 L
s
% Start of user PostScript
20.077322 -4.1793306 19.843521 1.6370354 MAarrowhead1
% End of user PostScript
1 .788 0 r
.37577 .84311 m
.31026 .84807 L
s
% Start of user PostScript
-14.90811 41.172952 -22.768969 41.768463 MAarrowhead1
% End of user PostScript
.897 1 0 r
.15032 .30436 m
.21104 .1684 L
s
% Start of user PostScript
-41.961646 -23.477002 -34.674812 -39.791402 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
76.029382 -92.055132 91.231814 -79.869822 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
49.732968 141.70756 17.062092 175.74436 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-248.74976 130.32902 -262.4305 68.406406 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
75.285988 -495.47616 175.6703 -535.60331 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
612.47034 64.965407 564.72045 267.24123 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-722.87703 1291.8748 -955.34734 1229.8004 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1053.2203 -1269.6861 -726.72291 -1767.0059 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2856.143 -2437.3624 3211.8041 -1847.8303 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
446.28617 5513.6859 -742.16072 6366.7215 MAarrowhead1
% End of user PostScript
.231 1 0 r
.4212 .55084 m
.41485 .53246 L
.41274 .5097 L
.41554 .48332 L
.42375 .45443 L
.43761 .42441 L
.45703 .3949 L
.4816 .36773 L
.51054 .34483 L
.5427 .32814 L
.5766 .31947 L
.61044 .32041 L
.6422 .33219 L
.66972 .35554 L
.69077 .39062 L
.70325 .4369 L
.70528 .49309 L
.69532 .55719 L
.6724 .6264 L
.63614 .69729 L
.58694 .76586 L
.526 .8277 L
.45539 .87824 L
.37805 .91294 L
.29767 .92764 L
.21867 .91879 L
.14592 .88379 L
.0846 .82124 L
.03989 .73121 L
.01666 .6154 L
.01917 .47728 L
.05069 .32214 L
.1132 .15694 L
s
.1132 .15694 m
.20158 0 L
s
1 0 0 r
.4212 .55084 m
.41485 .53246 L
s
% Start of user PostScript
-9.4554917 6.1009137 -10.217561 3.8951515 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41274 .5097 m
.41554 .48332 L
s
% Start of user PostScript
-10.471759 1.1634022 -10.135303 -2.0014567 MAarrowhead1
% End of user PostScript
1 .473 0 r
.5766 .31947 m
.61044 .32041 L
s
% Start of user PostScript
9.191526 -21.664076 13.252816 -21.550907 MAarrowhead1
% End of user PostScript
1 .788 0 r
.6724 .6264 m
.63614 .69729 L
s
% Start of user PostScript
20.687982 15.168133 16.337029 23.675356 MAarrowhead1
% End of user PostScript
.897 1 0 r
.14592 .88379 m
.0846 .82124 L
s
% Start of user PostScript
-42.489845 46.054878 -49.848111 38.549051 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-20.283905 -80.199597 -2.2307509 -96.973733 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
132.66216 -57.33099 137.38872 -22.734964 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-57.111838 266.51448 -110.18467 282.83863 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-312.2892 -69.663658 -280.23088 -177.51773 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
419.4828 -665.51708 536.62427 -618.63234 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
493.95378 752.47829 307.69353 1005.9856 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1558.2207 1172.3698 -1719.0442 830.42419 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-24.250899 -3037.4233 618.13423 -3437.1977 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4256.2025 -616.78166 4149.8257 650.98325 MAarrowhead1
% End of user PostScript
1 0 .425 r
.50127 .55347 m
.48991 .56078 L
.47765 .56543 L
.46508 .5668 L
.45293 .56437 L
.44196 .55777 L
.43299 .54686 L
.42683 .53169 L
.4242 .51262 L
.42575 .49025 L
.43194 .46549 L
.443 .43949 L
.45894 .41363 L
.47945 .38949 L
.50391 .36872 L
.5314 .35301 L
.56068 .34397 L
.59024 .34304 L
.61835 .35135 L
.64314 .36962 L
.6627 .39811 L
.67516 .43646 L
.67884 .48371 L
.67234 .53822 L
.65469 .59771 L
.62547 .6593 L
.58488 .71958 L
.53382 .7748 L
.47395 .82098 L
.40765 .85417 L
.33804 .87065 L
.26882 .86723 L
.20416 .84145 L
.14854 .79187 L
.10648 .71828 L
.08228 .62189 L
.07977 .50538 L
.10199 .37305 L
.1509 .23066 L
.22715 .08538 L
s
.22715 .08538 m
.28981 0 L
s
1 0 0 r
.50127 .55347 m
.48991 .56078 L
s
% Start of user PostScript
0.15242725 6.4164768 -1.2102187 7.2930257 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47765 .56543 m
.46508 .5668 L
s
% Start of user PostScript
-2.6821255 7.8513549 -4.1900618 8.0157971 MAarrowhead1
% End of user PostScript
1 .473 0 r
.43194 .46549 m
.443 .43949 L
s
% Start of user PostScript
-8.16771 -4.1410243 -6.839826 -7.261233 MAarrowhead1
% End of user PostScript
1 .788 0 r
.61835 .35135 m
.64314 .36962 L
s
% Start of user PostScript
14.201704 -17.838358 17.177139 -15.645261 MAarrowhead1
% End of user PostScript
.897 1 0 r
.58488 .71958 m
.53382 .7748 L
s
% Start of user PostScript
10.185674 26.35001 4.058511 32.975976 MAarrowhead1
% End of user PostScript
.581 1 0 r
.10648 .71828 m
.08228 .62189 L
s
% Start of user PostScript
-47.22262 26.194194 -50.126326 14.626322 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
12.268862 -93.790403 31.381127 -102.01374 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
117.98336 8.155514 109.70502 46.558249 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-133.17929 248.04814 -178.12727 237.90785 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-208.02526 -232.04953 -147.49064 -327.859 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
538.03489 -477.92106 608.99613 -369.28979 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
110.22473 1035.1586 -114.36773 1203.6797 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1555.7947 423.24717 -1558.6533 -14.633747 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1016.7801 -3171.9741 1629.7044 -3259.5587 MAarrowhead1
% End of user PostScript
.702 1 0 r
.48949 .4878 m
.49265 .4829 L
.49667 .47837 L
.50142 .47453 L
.50672 .47169 L
.51232 .47016 L
.51793 .4702 L
.52322 .47203 L
.52783 .47578 L
.5314 .48146 L
.53357 .48901 L
.53402 .49822 L
.53251 .50876 L
.52885 .52018 L
.52299 .53192 L
.51498 .54331 L
.505 .55365 L
.4934 .56216 L
.48065 .56809 L
.46736 .57076 L
.45424 .56956 L
.4421 .56405 L
.4318 .55399 L
.4242 .53937 L
.4201 .52045 L
.42023 .4978 L
.42512 .47226 L
.43514 .44498 L
.45036 .41734 L
.47056 .39096 L
.49521 .36756 L
.52342 .34895 L
.554 .33687 L
.58543 .3329 L
.61595 .33838 L
.64361 .35422 L
.6664 .38086 L
.68229 .41816 L
.68943 .4653 L
.68623 .52079 L
.67149 .58243 L
.64456 .64736 L
.60543 .71215 L
.5548 .77291 L
.49415 .82549 L
.42579 .86565 L
.35274 .88936 L
.27875 .893 L
.20811 .8737 L
.14546 .82953 L
Mistroke
.09562 .75983 L
.06326 .66536 L
.05263 .54845 L
.06727 .41308 L
.10966 .26487 L
.18098 .11094 L
Mfstroke
.18098 .11094 m
.25423 0 L
s
1 0 0 r
.48949 .4878 m
.49265 .4829 L
s
% Start of user PostScript
-1.260605 -1.4634562 -0.88168736 -2.0514413 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49667 .47837 m
.50142 .47453 L
s
% Start of user PostScript
-0.3997366 -2.5953747 0.17022406 -3.0569529 MAarrowhead1
% End of user PostScript
1 .473 0 r
.53357 .48901 m
.53402 .49822 L
s
% Start of user PostScript
4.0281154 -1.3189769 4.0826108 -0.21406299 MAarrowhead1
% End of user PostScript
1 .788 0 r
.48065 .56809 m
.46736 .57076 L
s
% Start of user PostScript
-2.3217057 8.1709837 -3.9171295 8.4907844 MAarrowhead1
% End of user PostScript
.897 1 0 r
.42512 .47226 m
.43514 .44498 L
s
% Start of user PostScript
-8.9850921 -3.3283496 -7.7832926 -6.6024094 MAarrowhead1
% End of user PostScript
.581 1 0 r
.61595 .33838 m
.64361 .35422 L
s
% Start of user PostScript
13.913591 -19.394826 17.233526 -17.493859 MAarrowhead1
% End of user PostScript
.266 1 0 r
.60543 .71215 m
.5548 .77291 L
s
% Start of user PostScript
12.651329 25.457903 6.5754086 32.749259 MAarrowhead1
% End of user PostScript
0 1 .049 r
.09562 .75983 m
.06326 .66536 L
s
% Start of user PostScript
-48.52571 31.17995 -52.40922 19.843165 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
6.6690985 -95.583994 26.471111 -105.81158 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
126.26364 -3.8795689 120.06508 35.590858 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-124.96373 263.10685 -173.5464 257.51126 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-237.48481 -212.07639 -179.52819 -314.63355 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
540.62926 -535.75472 623.65191 -433.76783 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
188.10894 1029.8006 -39.68131 1222.2859 MAarrowhead1
% End of user PostScript
0 1 .107 r
.56079 .50837 m
.55564 .52869 L
.5465 .55001 L
.53336 .57118 L
.51648 .59093 L
.49637 .60789 L
.47381 .62067 L
.4498 .62795 L
.42558 .62858 L
.40258 .62162 L
.38233 .60648 L
.3664 .58297 L
.35631 .55139 L
.35345 .51253 L
.35895 .46776 L
.3736 .41895 L
.39773 .36847 L
.43117 .31911 L
.47317 .27397 L
.52237 .2363 L
.57678 .20934 L
.63385 .19613 L
.69054 .19927 L
.74342 .22077 L
.78882 .26179 L
.82305 .32247 L
.84256 .40182 L
.84424 .49759 L
.82562 .60625 L
.7851 .72305 L
.72218 .8421 L
.63763 .95659 L
s
.63763 .95659 m
.59359 1 L
s
1 0 0 r
.56079 .50837 m
.55564 .52869 L
s
% Start of user PostScript
7.2945417 1.0039198 6.6772603 3.442745 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5465 .55001 m
.53336 .57118 L
s
% Start of user PostScript
5.5795802 6.0009825 4.0029987 8.5419677 MAarrowhead1
% End of user PostScript
1 .473 0 r
.38233 .60648 m
.3664 .58297 L
s
% Start of user PostScript
-14.120385 12.777074 -16.032174 9.9563655 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47317 .27397 m
.52237 .2363 L
s
% Start of user PostScript
-3.219214 -27.123406 2.6839976 -31.643838 MAarrowhead1
% End of user PostScript
.897 1 0 r
.84256 .40182 m
.84424 .49759 L
s
% Start of user PostScript
41.107054 -11.781807 41.308961 -0.28946032 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-26.031111 83.697981 -42.248544 86.261791 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-89.714898 -38.79296 -76.541711 -72.201708 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
146.67021 -194.69088 179.60756 -173.39195 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
119.76856 270.18366 56.090905 342.97643 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-500.03054 300.61464 -535.68406 181.12612 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
97.52529 -988.79389 300.78656 -1085.5625 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1276.705 19.491193 1201.6362 426.17333 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1345.3575 2671.3284 -1834.3611 2590.2676 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2332.099 -2313.2691 -1714.2811 -3350.1579 MAarrowhead1
% End of user PostScript
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00833333 0.5 0.00833333 [
[0 .4875 -18.4688 -20 ]
[0 .4875 18.4688 0 ]
[.16667 .4875 -18.4688 -20 ]
[.16667 .4875 18.4688 0 ]
[.33333 .4875 -18.4688 -20 ]
[.33333 .4875 18.4688 0 ]
[.66667 .4875 -12 -20 ]
[.66667 .4875 12 0 ]
[.83333 .4875 -12 -20 ]
[.83333 .4875 12 0 ]
[1 .4875 -12 -20 ]
[1 .4875 12 0 ]
[.4875 0 -36.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .16667 -36.9375 -10 ]
[.4875 .16667 0 10 ]
[.4875 .33333 -36.9375 -10 ]
[.4875 .33333 0 10 ]
[.4875 .66667 -24 -10 ]
[.4875 .66667 0 10 ]
[.4875 .83333 -24 -10 ]
[.4875 .83333 0 10 ]
[.4875 1 -24 -10 ]
[.4875 1 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.16667 .5 m
.16667 .50625 L
s
gsave
.16667 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.33333 .5 m
.33333 .50625 L
s
gsave
.33333 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.66667 .5 m
.66667 .50625 L
s
gsave
.66667 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.83333 .5 m
.83333 .50625 L
s
gsave
.83333 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 .5 m
.04167 .50375 L
s
.08333 .5 m
.08333 .50375 L
s
.125 .5 m
.125 .50375 L
s
.20833 .5 m
.20833 .50375 L
s
.25 .5 m
.25 .50375 L
s
.29167 .5 m
.29167 .50375 L
s
.375 .5 m
.375 .50375 L
s
.41667 .5 m
.41667 .50375 L
s
.45833 .5 m
.45833 .50375 L
s
.54167 .5 m
.54167 .50375 L
s
.58333 .5 m
.58333 .50375 L
s
.625 .5 m
.625 .50375 L
s
.70833 .5 m
.70833 .50375 L
s
.75 .5 m
.75 .50375 L
s
.79167 .5 m
.79167 .50375 L
s
.875 .5 m
.875 .50375 L
s
.91667 .5 m
.91667 .50375 L
s
.95833 .5 m
.95833 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.5 .16667 m
.50625 .16667 L
s
gsave
.4875 .16667 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.5 .33333 m
.50625 .33333 L
s
gsave
.4875 .33333 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.5 .66667 m
.50625 .66667 L
s
gsave
.4875 .66667 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.5 .83333 m
.50625 .83333 L
s
gsave
.4875 .83333 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .04167 m
.50375 .04167 L
s
.5 .08333 m
.50375 .08333 L
s
.5 .125 m
.50375 .125 L
s
.5 .20833 m
.50375 .20833 L
s
.5 .25 m
.50375 .25 L
s
.5 .29167 m
.50375 .29167 L
s
.5 .375 m
.50375 .375 L
s
.5 .41667 m
.50375 .41667 L
s
.5 .45833 m
.50375 .45833 L
s
.5 .54167 m
.50375 .54167 L
s
.5 .58333 m
.50375 .58333 L
s
.5 .625 m
.50375 .625 L
s
.5 .70833 m
.50375 .70833 L
s
.5 .75 m
.50375 .75 L
s
.5 .79167 m
.50375 .79167 L
s
.5 .875 m
.50375 .875 L
s
.5 .91667 m
.50375 .91667 L
s
.5 .95833 m
.50375 .95833 L
s
.01 w
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 .176 r
.5 Mabswid
.49574 .54078 m
.48737 .5447 L
.47864 .54647 L
.47002 .54571 L
.46204 .54212 L
.45526 .53554 L
.45025 .52596 L
.44753 .51356 L
.44759 .4987 L
.45077 .48194 L
.45732 .46403 L
.46729 .44587 L
.48053 .42853 L
.49669 .41314 L
.51521 .40088 L
.53528 .3929 L
.55593 .39024 L
.57598 .39378 L
.59418 .40412 L
.60918 .42155 L
.61967 .44599 L
.62442 .4769 L
.62238 .51331 L
.61277 .55376 L
.59515 .5964 L
.56952 .63897 L
.53633 .67892 L
.49655 .71351 L
.45168 .73998 L
.40372 .75566 L
.35511 .75818 L
.30867 .74565 L
.26746 .71679 L
.23464 .67116 L
.21326 .60925 L
.20614 .53258 L
.2156 .44376 L
.24327 .34646 L
.28995 .24537 L
.35536 .146 L
.43811 .05452 L
s
.43811 .05452 m
.50702 0 L
s
.25 1 0 r
.52952 .56822 m
.51348 .58638 L
.4945 .60179 L
.47332 .61319 L
.45092 .61936 L
.42845 .61923 L
.40727 .61197 L
.38879 .59707 L
.37449 .57439 L
.36576 .54426 L
.36388 .50748 L
.36987 .46535 L
.38441 .41968 L
.40779 .37273 L
.43977 .3271 L
.47961 .28572 L
.52597 .2516 L
.57695 .22776 L
.63013 .21697 L
.68263 .22163 L
.73122 .24351 L
.7725 .2836 L
.80303 .34193 L
.81955 .41746 L
.81921 .50796 L
.79979 .61004 L
.7599 .71915 L
.69921 .82972 L
.61855 .93534 L
s
.61855 .93534 m
.55062 1 L
s
0 .534 1 r
.4653 .5341 m
.46003 .52752 L
.45645 .51842 L
.45498 .50701 L
.456 .49366 L
.45979 .47891 L
.46647 .46346 L
.47605 .44813 L
.48832 .43385 L
.50293 .42162 L
.51931 .41243 L
.53672 .40724 L
.55426 .40689 L
.57089 .41204 L
.58552 .42313 L
.59699 .44028 L
.6042 .46327 L
.60616 .49152 L
.60205 .52403 L
.59131 .55944 L
.57369 .59602 L
.54933 .63174 L
.51878 .66436 L
.48305 .69153 L
.44357 .71088 L
.4022 .72024 L
.36116 .71771 L
.32292 .70187 L
.29016 .67187 L
.26555 .62763 L
.25165 .56988 L
.2507 .50028 L
.2645 .4214 L
.29418 .3367 L
.34008 .25046 L
.40163 .16762 L
.47725 .09357 L
.56428 .03391 L
s
.56428 .03391 m
.64501 0 L
s
.86538 0 m
.94 .03949 L
s
.94 .03949 m
1 .10536 L
s
1 .83989 m
.9602 .93995 L
s
.9602 .93995 m
.92507 1 L
s
0 .366 1 r
.57112 .55248 m
.55609 .58177 L
.53571 .61008 L
.5105 .63559 L
.4813 .65642 L
.44932 .67069 L
.41612 .67669 L
.38349 .67294 L
.35347 .65838 L
.32819 .63244 L
.30978 .59514 L
.30028 .54721 L
.30141 .49007 L
.31455 .42593 L
.34049 .35765 L
.37939 .28878 L
.43067 .22334 L
.49291 .16567 L
.56387 .12027 L
.64046 .09147 L
.71887 .0832 L
.79467 .09868 L
.86299 .14016 L
.91876 .20862 L
.95698 .30357 L
.97304 .42288 L
.96302 .56268 L
.92406 .71735 L
.85462 .87965 L
s
.85462 .87965 m
.78012 1 L
s
0 .092 1 r
.41926 .51003 m
.42163 .48576 L
.42899 .45911 L
.44157 .43135 L
.4593 .40399 L
.48182 .37872 L
.50843 .35731 L
.53808 .34156 L
.5694 .33316 L
.60076 .33359 L
.63028 .344 L
.65596 .36511 L
.67576 .39706 L
.68772 .43942 L
.69007 .49102 L
.6814 .55003 L
.66076 .61392 L
.62778 .67951 L
.5828 .74314 L
.52688 .80074 L
.46192 .84807 L
.39057 .88094 L
.31626 .89548 L
.24301 .88836 L
.17533 .85714 L
.118 .80046 L
.07582 .71832 L
.05332 .61222 L
.05446 .4853 L
.08232 .34235 L
.13881 .18978 L
.22435 .03539 L
s
.22435 .03539 m
.2516 0 L
s
0 .975 1 r
.56295 .51122 m
.55709 .5326 L
.54704 .55488 L
.53284 .57685 L
.5148 .59717 L
.49347 .61439 L
.46969 .62709 L
.44455 .6339 L
.41937 .63363 L
.39565 .62536 L
.37499 .60851 L
.35904 .58294 L
.34937 .54903 L
.34739 .50767 L
.35426 .46035 L
.37072 .40909 L
.39709 .35643 L
.43311 .30533 L
.47792 .25902 L
.53 .22092 L
.58723 .19439 L
.64688 .18256 L
.70571 .18808 L
.76011 .21293 L
.80624 .25822 L
.84025 .32395 L
.85849 .40894 L
.85778 .51067 L
.83565 .62531 L
.79055 .74775 L
.72211 .87171 L
.63132 .99 L
s
.63132 .99 m
.62076 1 L
s
1 .341 0 r
.50822 .53196 m
.50102 .53869 L
.4928 .544 L
.48391 .54741 L
.4748 .54843 L
.46598 .54671 L
.45801 .54197 L
.45149 .5341 L
.44699 .52314 L
.44505 .50935 L
.44613 .49316 L
.45057 .47522 L
.45855 .45638 L
.47006 .43762 L
.48489 .42009 L
.50259 .40499 L
.5225 .39355 L
.54371 .38693 L
.56515 .38617 L
.58555 .3921 L
.60357 .40526 L
.61781 .42581 L
.62692 .45353 L
.62967 .48771 L
.62506 .52717 L
.61237 .57027 L
.5913 .61491 L
.56197 .65865 L
.52505 .69874 L
.48171 .73233 L
.43369 .75653 L
.38324 .76866 L
.33303 .76637 L
.28609 .7479 L
.24566 .71218 L
.21502 .65906 L
.19729 .58938 L
.19525 .50508 L
.21111 .40926 L
.24632 .3061 L
.30134 .20076 L
.37553 .09924 L
.46703 .0081 L
s
.46703 .0081 m
.47861 0 L
s
1 .505 0 r
.48686 .42719 m
.50296 .41363 L
.52102 .40342 L
.54024 .39761 L
.55961 .39713 L
.57801 .40272 L
.59421 .41486 L
.60694 .43369 L
.61499 .45898 L
.61726 .49009 L
.61283 .52593 L
.60109 .565 L
.58175 .60539 L
.55497 .64487 L
.52134 .68098 L
.48196 .71109 L
.43841 .73263 L
.39274 .74316 L
.34738 .7406 L
.30509 .72334 L
.26878 .69047 L
.24144 .64186 L
.22587 .57832 L
.22457 .50164 L
.23953 .41466 L
.27202 .32119 L
.32243 .22594 L
.39014 .13435 L
.47341 .05237 L
s
.47341 .05237 m
.54931 0 L
s
.99339 0 m
1 .00717 L
s
1 .99942 m
.99966 1 L
s
1 .089 0 r
.50742 .56852 m
.49255 .57971 L
.47614 .58764 L
.45897 .5914 L
.44196 .59021 L
.42615 .58348 L
.41263 .57088 L
.40253 .55237 L
.39689 .52827 L
.39666 .49928 L
.40255 .46647 L
.41504 .4313 L
.43426 .39553 L
.45996 .36124 L
.49147 .33065 L
.52769 .30609 L
.56707 .28983 L
.6077 .28393 L
.64732 .29013 L
.68342 .30968 L
.7134 .34317 L
.73463 .39048 L
.74471 .45062 L
.74153 .52172 L
.72352 .60098 L
.68979 .68477 L
.64024 .76871 L
.57574 .84779 L
.49813 .91666 L
.4103 .96986 L
s
.4103 .96986 m
.32229 1 L
s
.18533 1 m
.12855 .98587 L
.04665 .931 L
s
.04665 .931 m
0 .86866 L
s
0 .18809 m
.08006 .01053 L
s
.08006 .01053 m
.08686 0 L
s
1 .572 0 r
.50614 .56918 m
.4912 .58005 L
.47479 .5876 L
.4577 .59093 L
.44087 .58928 L
.42531 .58208 L
.41214 .56903 L
.40245 .55013 L
.39729 .52572 L
.39757 .49653 L
.404 .46365 L
.41701 .42857 L
.43669 .39308 L
.46278 .35923 L
.49456 .32928 L
.53089 .30552 L
.57022 .29019 L
.61059 .28533 L
.64975 .29263 L
.68519 .31327 L
.71431 .34779 L
.73452 .39599 L
.74344 .45681 L
.73903 .52829 L
.71977 .60761 L
.68484 .69108 L
.63424 .77426 L
.5689 .85216 L
.49075 .91944 L
.40274 .97065 L
s
.40274 .97065 m
.31076 1 L
s
.19699 1 m
.12318 .97927 L
.04297 .92185 L
s
.04297 .92185 m
0 .86091 L
s
0 .19393 m
3e-05 .19383 L
s
3e-05 .19383 m
.09058 0 L
s
0 .862 1 r
.50753 .49164 m
.50888 .49295 L
.50987 .49485 L
.51041 .49731 L
.5104 .50026 L
.50977 .50358 L
.50847 .50714 L
.50649 .51074 L
.50387 .51418 L
.50066 .51724 L
.49698 .51967 L
.493 .52125 L
.4889 .52178 L
.48492 .52108 L
.48131 .51903 L
.47833 .51557 L
.47625 .51072 L
.47531 .50459 L
.47571 .49736 L
.47762 .48933 L
.48111 .48087 L
.4862 .47242 L
.49279 .4645 L
.50068 .45763 L
.50959 .45238 L
.5191 .44926 L
.52875 .44876 L
.53797 .45125 L
.54614 .45697 L
.55266 .46603 L
.5569 .47831 L
.55832 .49353 L
.55644 .51115 L
.55095 .53046 L
.54169 .55052 L
.52871 .57024 L
.51229 .5884 L
.49295 .6037 L
.47146 .61486 L
.4488 .62065 L
.42619 .62002 L
.40496 .61214 L
.38657 .59653 L
.3725 .57309 L
.36417 .54216 L
.36282 .5046 L
.36947 .46177 L
.38479 .41551 L
.40903 .36813 L
.44191 .32231 L
Mistroke
.48264 .28099 L
.52983 .24722 L
.58152 .22403 L
.63523 .21421 L
.68803 .22013 L
.73665 .24353 L
.77762 .28533 L
.8075 .34551 L
.82301 .42291 L
.82133 .51521 L
.80026 .6189 L
.75848 .7293 L
.69572 .84073 L
.61293 .94667 L
Mfstroke
.61293 .94667 m
.55553 1 L
s
0 1 .034 r
.47098 .53216 m
.4658 .52712 L
.46198 .5198 L
.45991 .51032 L
.45996 .49896 L
.46241 .48615 L
.46742 .47246 L
.47504 .45859 L
.48517 .44535 L
.49753 .4336 L
.51168 .42424 L
.52702 .41816 L
.54279 .41615 L
.55811 .41887 L
.572 .42679 L
.58345 .44013 L
.59145 .45882 L
.59505 .48246 L
.59347 .51028 L
.58611 .5412 L
.57263 .57378 L
.55302 .60629 L
.52764 .6368 L
.49723 .66321 L
.46294 .6834 L
.42629 .69535 L
.38916 .69723 L
.3537 .6876 L
.32224 .6655 L
.29719 .63059 L
.2809 .58325 L
.27551 .52463 L
.28278 .45675 L
.30398 .3824 L
.3397 .30516 L
.38973 .22927 L
.45299 .15941 L
.52749 .10056 L
.61026 .0577 L
.69748 .03551 L
.78453 .03806 L
.86621 .0685 L
.93692 .12873 L
.99099 .21912 L
s
.99099 .21912 m
1 .25267 L
s
1 .65484 m
.94315 .82606 L
s
.94315 .82606 m
.85403 1 L
s
0 1 .692 r
.55289 .57665 m
.53378 .60329 L
.5101 .62732 L
.48267 .64695 L
.45262 .66043 L
.42139 .66615 L
.3907 .66271 L
.36243 .64911 L
.33861 .62481 L
.32124 .58983 L
.31222 .54484 L
.31319 .49118 L
.32543 .4309 L
.34972 .36672 L
.3862 .30194 L
.43433 .24034 L
.49278 .18603 L
.55944 .14322 L
.63143 .11598 L
.70517 .10801 L
.7765 .12236 L
.84083 .16115 L
.8934 .2253 L
.92951 .31438 L
.94482 .42639 L
.93563 .5577 L
.89924 .70306 L
.8342 .85566 L
s
.8342 .85566 m
.74511 1 L
s
.865 1 0 r
.45827 .56759 m
.44632 .5631 L
.43599 .55426 L
.42809 .54099 L
.42344 .52352 L
.42273 .50232 L
.42653 .47816 L
.43523 .45208 L
.44894 .42539 L
.46752 .3996 L
.49052 .37636 L
.51714 .35739 L
.54628 .34441 L
.57655 .33897 L
.60628 .34242 L
.63363 .35572 L
.65665 .3794 L
.6734 .41342 L
.68203 .45714 L
.68096 .50923 L
.66895 .56771 L
.64528 .62993 L
.60978 .6927 L
.56301 .75232 L
.50626 .80484 L
.44157 .84618 L
.37176 .87237 L
.3003 .87984 L
.23124 .86565 L
.169 .82777 L
.11822 .7653 L
.08345 .67869 L
.06889 .56989 L
.0781 .44243 L
.1137 .30144 L
.17707 .15352 L
.26814 .00656 L
s
.26814 .00656 m
.27374 0 L
s
.239 0 1 r
.53729 .55926 m
.52271 .57871 L
.50484 .59606 L
.48429 .61 L
.46195 .61922 L
.43891 .62257 L
.41643 .61905 L
.39595 .60796 L
.37895 .58896 L
.3669 .56212 L
.36119 .52801 L
.36299 .48768 L
.37321 .44272 L
.39234 .39519 L
.42045 .34757 L
.45704 .30271 L
.50106 .26365 L
.55088 .23347 L
.60431 .21517 L
.65862 .21142 L
.71071 .22439 L
.75716 .25551 L
.79447 .30536 L
.81918 .37346 L
.82815 .45816 L
.81874 .55665 L
.78907 .66486 L
.73821 .77766 L
.66638 .88891 L
.57505 .99178 L
s
.57505 .99178 m
.56488 1 L
s
1 0 .416 r
.57517 .54207 m
.56211 .5713 L
.54361 .60017 L
.52005 .6269 L
.49215 .64963 L
.46101 .66647 L
.42805 .67561 L
.39498 .6755 L
.36378 .66491 L
.33655 .64308 L
.31543 .6098 L
.30252 .56555 L
.29966 .51149 L
.30837 .44956 L
.32966 .38238 L
.36395 .31327 L
.41092 .2461 L
.46946 .18513 L
.53761 .13481 L
.61259 .09958 L
.69084 .08353 L
.76813 .09018 L
.83972 .12216 L
.90058 .18093 L
.94566 .26655 L
.97016 .3775 L
.96988 .51052 L
.94155 .66063 L
.88311 .82114 L
.79404 .98388 L
s
.79404 .98388 m
.78176 1 L
s
0 .188 1 r
.50563 .4386 m
.51828 .43246 L
.53152 .42952 L
.54464 .4304 L
.55685 .43555 L
.56729 .44523 L
.57511 .45946 L
.57949 .478 L
.57972 .50033 L
.57522 .5256 L
.56563 .55272 L
.55086 .5803 L
.53108 .60677 L
.50682 .6304 L
.47892 .64939 L
.44857 .662 L
.41724 .66663 L
.38667 .66194 L
.35879 .64697 L
.33562 .62124 L
.31917 .58485 L
.31131 .53856 L
.31366 .48381 L
.32744 .42273 L
.35333 .35812 L
.39143 .29338 L
.44107 .23233 L
.50083 .17913 L
.56851 .13797 L
.64111 .11292 L
.71495 .10762 L
.78582 .12502 L
.84907 .1671 L
.89993 .23463 L
.93371 .32698 L
.94612 .44194 L
.93358 .57567 L
.89351 .7227 L
.82464 .87602 L
s
.82464 .87602 m
.74483 1 L
s
1 0 .964 r
.50724 .4993 m
.50699 .50151 L
.50628 .50391 L
.50511 .50641 L
.50347 .50885 L
.50141 .51109 L
.49899 .51297 L
.49631 .51432 L
.49349 .51501 L
.49069 .51488 L
.48806 .51385 L
.4858 .51186 L
.48409 .5089 L
.48309 .50501 L
.48298 .50031 L
.48386 .49496 L
.48582 .4892 L
.48889 .48331 L
.49302 .47764 L
.49813 .47255 L
.50403 .46841 L
.51047 .46561 L
.51715 .46448 L
.52369 .46533 L
.52969 .46835 L
.53472 .47367 L
.53835 .48126 L
.54017 .49098 L
.53984 .50253 L
.5371 .51547 L
.53177 .52921 L
.52384 .54304 L
.51343 .55614 L
.50083 .56764 L
.48651 .57664 L
.47109 .58226 L
.45533 .58373 L
.44015 .5804 L
.42651 .57183 L
.41543 .55783 L
.40793 .53852 L
.40491 .51435 L
.40717 .4861 L
.41526 .45492 L
.42949 .42227 L
.44981 .38992 L
.47583 .35982 L
.50676 .33407 L
.5414 .31479 L
.57819 .30399 L
Mistroke
.61521 .30344 L
.65029 .31454 L
.68108 .33817 L
.70517 .37461 L
.72023 .42337 L
.72416 .4832 L
.71525 .55199 L
.69232 .62684 L
.65486 .7041 L
.60318 .77947 L
.53846 .84821 L
.46284 .90533 L
.37936 .94589 L
.29196 .96526 L
.20533 .95946 L
.12474 .92549 L
.0558 .86162 L
.00416 .76768 L
Mfstroke
.00416 .76768 m
0 .75006 L
s
0 .35029 m
.00343 .33102 L
.06669 .15201 L
s
.06669 .15201 m
.1481 0 L
s
0 .676 1 r
.58253 .45323 m
.58781 .47331 L
.58857 .49767 L
.58413 .52541 L
.5741 .55532 L
.5583 .58592 L
.53693 .61547 L
.51051 .64206 L
.47994 .66373 L
.4465 .67851 L
.4118 .68462 L
.37774 .68054 L
.34643 .66514 L
.32012 .63784 L
.30102 .59869 L
.29125 .54844 L
.29263 .48861 L
.30656 .42149 L
.33388 .35012 L
.37475 .27818 L
.42852 .2099 L
.49372 .14982 L
.56797 .10263 L
.64806 .07285 L
.72998 .06458 L
.80909 .08118 L
.8803 .12496 L
.93832 .19694 L
.97792 .29657 L
.99429 .42161 L
.98336 .56796 L
.94216 .72975 L
.86909 .89939 L
s
.86909 .89939 m
.80648 1 L
s
.625 0 1 r
.43594 .55866 m
.42712 .54595 L
.42147 .52881 L
.41976 .50767 L
.4226 .48326 L
.43043 .4566 L
.44346 .42897 L
.46159 .4019 L
.48443 .37708 L
.51124 .35628 L
.54094 .34129 L
.57216 .33376 L
.60324 .33515 L
.63229 .34655 L
.65732 .36862 L
.67631 .40146 L
.6873 .44456 L
.6886 .4967 L
.67881 .55597 L
.65706 .6198 L
.62305 .68499 L
.57717 .74782 L
.52058 .80424 L
.45522 .85003 L
.38384 .88104 L
.30988 .89346 L
.23741 .88406 L
.17094 .85051 L
.11526 .79159 L
.0751 .70743 L
.05494 .5997 L
.05863 .47168 L
.08914 .3283 L
.14821 .17607 L
.23613 .02289 L
s
.23613 .02289 m
.25432 0 L
s
1 .012 0 r
.41678 .50646 m
.42004 .48095 L
.42851 .45317 L
.44236 .4245 L
.4615 .3965 L
.48548 .37096 L
.51352 .3497 L
.54449 .33458 L
.57693 .32731 L
.6091 .32938 L
.63905 .34189 L
.66469 .3655 L
.68392 .40027 L
.69475 .44562 L
.6954 .50025 L
.68449 .56214 L
.66112 .62856 L
.62503 .69617 L
.57668 .76107 L
.51733 .81905 L
.44903 .86572 L
.37468 .89679 L
.2979 .90834 L
.22296 .89707 L
.15455 .86063 L
.09764 .79782 L
.05715 .70889 L
.03768 .59566 L
.04318 .46166 L
.07666 .31209 L
.13985 .15382 L
s
.13985 .15382 m
.23006 0 L
s
0 .557 1 r
.54817 .54631 m
.53572 .56754 L
.51948 .58757 L
.49992 .60504 L
.47775 .61857 L
.45397 .62684 L
.42976 .62864 L
.40651 .623 L
.38575 .60929 L
.36903 .58722 L
.3579 .55702 L
.35377 .5194 L
.3578 .47561 L
.37085 .42745 L
.39334 .3772 L
.42518 .32758 L
.46573 .28164 L
.51372 .2426 L
.56728 .21371 L
.62396 .19806 L
.68079 .19832 L
.73441 .21661 L
.78119 .25424 L
.81743 .31153 L
.83957 .38769 L
.8444 .48069 L
.82933 .58723 L
.79262 .70274 L
.73357 .82155 L
.65273 .937 L
s
.65273 .937 m
.59216 1 L
s
1 0 .473 r
.46203 .50168 m
.46378 .48987 L
.46793 .4771 L
.47455 .46399 L
.48356 .45129 L
.49476 .4398 L
.50775 .43037 L
.52202 .42383 L
.53687 .42097 L
.5515 .42244 L
.56501 .42873 L
.57644 .44011 L
.58483 .45658 L
.58928 .47782 L
.589 .50322 L
.58337 .53181 L
.57202 .56231 L
.55487 .59316 L
.53216 .62255 L
.50451 .64855 L
.47291 .66915 L
.43871 .68241 L
.40362 .68656 L
.3696 .68013 L
.33884 .6621 L
.31358 .63201 L
.29608 .59004 L
.28841 .53711 L
.29234 .47491 L
.30918 .40594 L
.33963 .33338 L
.38371 .26111 L
.44059 .19346 L
.50859 .13508 L
.58513 .09069 L
.66678 .0648 L
.74936 .06142 L
.82806 .08374 L
.89768 .13386 L
.95285 .21249 L
.98836 .31873 L
.99947 .44993 L
.98228 .60158 L
.93404 .76737 L
.85349 .93929 L
s
.85349 .93929 m
.81303 1 L
s
0 1 .69 r
.57062 .4521 m
.57681 .46827 L
.57924 .48849 L
.57726 .51209 L
.57042 .53811 L
.55846 .56532 L
.54143 .59226 L
.51965 .61728 L
.49381 .63864 L
.4649 .65458 L
.43422 .66342 L
.40339 .66369 L
.37421 .65424 L
.34865 .63433 L
.32871 .60376 L
.31633 .56293 L
.31326 .51291 L
.32092 .45546 L
.34027 .39302 L
.37172 .32864 L
.41502 .26591 L
.46915 .20879 L
.53232 .16143 L
.60198 .12796 L
.67483 .11221 L
.74695 .1175 L
.81395 .1463 L
.87115 .20003 L
.91383 .2788 L
.93752 .38125 L
.93826 .50443 L
.91297 .64374 L
.85968 .79303 L
.77785 .94472 L
s
.77785 .94472 m
.73629 1 L
s
.085 0 1 r
.56773 .56594 m
.55005 .59589 L
.52703 .62412 L
.49933 .64869 L
.46799 .66768 L
.43438 .67919 L
.40021 .68155 L
.36744 .67339 L
.33821 .65381 L
.31474 .62245 L
.2992 .57961 L
.29356 .52632 L
.29948 .46436 L
.31814 .39628 L
.35014 .32532 L
.39533 .25533 L
.45279 .19061 L
.52071 .13573 L
.59643 .09526 L
.67649 .07354 L
.75669 .07436 L
.83225 .10067 L
.89806 .15431 L
.9489 .2357 L
.97973 .34368 L
.98606 .47537 L
.96424 .62606 L
.91183 .7893 L
.82789 .95702 L
s
.82789 .95702 m
.79762 1 L
s
.724 1 0 r
.53357 .55782 m
.5195 .57591 L
.5024 .59188 L
.48288 .6045 L
.46177 .61257 L
.44014 .615 L
.4192 .61089 L
.40028 .59963 L
.3848 .58092 L
.37412 .5549 L
.36953 .52214 L
.37211 .4837 L
.38266 .44111 L
.40161 .39636 L
.42895 .35183 L
.46417 .31021 L
.50622 .27437 L
.55349 .24721 L
.60387 .23151 L
.65476 .22973 L
.7032 .24384 L
.74596 .2751 L
.77976 .32393 L
.80137 .38976 L
.80789 .47094 L
.79691 .56465 L
.76676 .66699 L
.71669 .773 L
.64703 .87684 L
.55933 .97203 L
s
.55933 .97203 m
.52322 1 L
s
0 1 .875 r
.55168 .46267 m
.55668 .47421 L
.55897 .48883 L
.55805 .50606 L
.55355 .52522 L
.54525 .54542 L
.53315 .56561 L
.51746 .58458 L
.49864 .60102 L
.4774 .61363 L
.45467 .62115 L
.43162 .62243 L
.40958 .61659 L
.39 .60302 L
.37437 .5815 L
.36416 .55225 L
.36068 .51599 L
.36505 .47395 L
.37805 .42786 L
.40005 .37994 L
.43094 .3328 L
.47007 .28936 L
.51619 .25269 L
.56748 .22589 L
.62158 .21186 L
.67563 .21316 L
.72641 .23173 L
.77044 .26877 L
.80421 .32454 L
.82434 .39819 L
.8278 .48773 L
.81217 .58991 L
.77584 .70034 L
.71823 .81353 L
.63993 .92308 L
s
.63993 .92308 m
.56446 1 L
s
0 1 .871 r
.51541 .54057 m
.50599 .55068 L
.49496 .55912 L
.48276 .56515 L
.46997 .56811 L
.45727 .56739 L
.44542 .56256 L
.43525 .55336 L
.42759 .53975 L
.42322 .52196 L
.42285 .50049 L
.42704 .47613 L
.43613 .44995 L
.45025 .42327 L
.4692 .39761 L
.49252 .37465 L
.5194 .3561 L
.54869 .34366 L
.57898 .33889 L
.60859 .3431 L
.63567 .35722 L
.65826 .38174 L
.67442 .41657 L
.68234 .46102 L
.68043 .51371 L
.66751 .57259 L
.64288 .635 L
.60645 .69765 L
.55882 .75687 L
.50134 .80865 L
.43613 .84891 L
.36604 .87373 L
.29461 .87957 L
.22592 .86355 L
.16443 .82371 L
.11476 .75927 L
.08145 .67078 L
.06867 .56032 L
.07991 .43157 L
.1177 .28974 L
.18332 .14158 L
s
.18332 .14158 m
.27342 0 L
s
0 1 .181 r
.49356 .43129 m
.50842 .42039 L
.52475 .41278 L
.54179 .40935 L
.5586 .41088 L
.57415 .41793 L
.58735 .4308 L
.5971 .44952 L
.60235 .47374 L
.60221 .50276 L
.59594 .53547 L
.58313 .57042 L
.56364 .60583 L
.53777 .63963 L
.5062 .66962 L
.47006 .69348 L
.43089 .70898 L
.39063 .71408 L
.35153 .70709 L
.31608 .68682 L
.28687 .65271 L
.26649 .60495 L
.25731 .54458 L
.26139 .47351 L
.28025 .39455 L
.31471 .31137 L
.36482 .22837 L
.42966 .15051 L
.50733 .08312 L
.5949 .03163 L
.68848 .00121 L
s
.68848 .00121 m
.71283 0 L
s
.79614 0 m
.87379 .02117 L
.95407 .07769 L
s
.95407 .07769 m
1 .14183 L
s
1 .80132 m
.90892 .99805 L
s
.90892 .99805 m
.90763 1 L
s
0 .454 1 r
.51203 .47602 m
.51642 .47673 L
.52042 .47893 L
.52373 .48267 L
.52607 .48795 L
.52716 .49465 L
.52678 .50256 L
.52476 .51137 L
.52098 .52067 L
.51545 .52998 L
.50827 .53874 L
.49963 .54636 L
.48987 .55223 L
.47941 .55576 L
.46878 .55644 L
.45861 .55384 L
.44954 .54769 L
.44228 .53788 L
.4375 .52449 L
.4358 .50787 L
.43771 .48856 L
.44359 .46737 L
.45361 .44529 L
.46773 .42355 L
.48566 .40346 L
.50683 .38646 L
.53041 .37397 L
.55532 .36732 L
.58025 .36771 L
.60371 .37604 L
.62411 .39287 L
.63982 .41833 L
.64928 .45204 L
.65111 .49311 L
.64416 .54006 L
.6277 .59087 L
.60142 .64303 L
.5656 .6936 L
.5211 .73935 L
.46941 .77693 L
.41267 .803 L
.35357 .81446 L
.29535 .8087 L
.24157 .78376 L
.19604 .73858 L
.16259 .67316 L
.14479 .58869 L
.14582 .4877 L
.1681 .37398 L
.21314 .25265 L
Mistroke
.28129 .1299 L
.37155 .01289 L
Mfstroke
.37155 .01289 m
.38524 0 L
s
0 1 .797 r
.41758 .4699 m
.42852 .43992 L
.44517 .40954 L
.46731 .3805 L
.49435 .35473 L
.52532 .33418 L
.55891 .32079 L
.59345 .31631 L
.62703 .32218 L
.6575 .33944 L
.68263 .36857 L
.70022 .40942 L
.70821 .46111 L
.70484 .522 L
.68881 .58969 L
.65939 .66104 L
.61655 .73229 L
.56105 .79917 L
.49451 .85711 L
.41945 .90147 L
.3392 .9278 L
.25785 .93212 L
.18011 .91124 L
.1111 .86306 L
.05609 .78682 L
.02023 .68331 L
.0082 .5551 L
.02391 .40652 L
.0701 .24374 L
.14807 .07456 L
s
.14807 .07456 m
.19709 0 L
s
.471 1 0 r
.5289 .57099 m
.51231 .5893 L
.49278 .60473 L
.47108 .61596 L
.44821 .62177 L
.42539 .6211 L
.40398 .61311 L
.38545 .59731 L
.37128 .57361 L
.36289 .54236 L
.36157 .50443 L
.36833 .46118 L
.38384 .41448 L
.40835 .36667 L
.44158 .32045 L
.48272 .27878 L
.53037 .24475 L
.58255 .22141 L
.63676 .21158 L
.69003 .21764 L
.73906 .24135 L
.78036 .28364 L
.81044 .34446 L
.82601 .42266 L
.82421 .51588 L
.80284 .62057 L
.76057 .732 L
.69712 .84444 L
.61348 .95131 L
s
.61348 .95131 m
.56097 1 L
s
0 1 .603 r
.46191 .57855 m
.44745 .57664 L
.4342 .5699 L
.4231 .55809 L
.41512 .54124 L
.41113 .5197 L
.41191 .49411 L
.41805 .46546 L
.4299 .43506 L
.4475 .40448 L
.47058 .37553 L
.49848 .35015 L
.53019 .33033 L
.56432 .31798 L
.59916 .31485 L
.63272 .32234 L
.66284 .34142 L
.68726 .3725 L
.70376 .41532 L
.71031 .46889 L
.70519 .53146 L
.68714 .60047 L
.65554 .67269 L
.61045 .74422 L
.55277 .81071 L
.48426 .86752 L
.40757 .90998 L
.32619 .93365 L
.24433 .9346 L
.16681 .90977 L
.09885 .85719 L
.04576 .7763 L
.0127 .66817 L
.00429 .53562 L
.02432 .38329 L
.07539 .21763 L
.15858 .04677 L
s
.15858 .04677 m
.19076 0 L
s
1 .563 0 r
.43912 .48912 m
.4448 .46844 L
.45453 .44689 L
.46827 .42564 L
.48572 .40599 L
.50636 .38934 L
.52936 .37706 L
.55367 .37049 L
.57802 .37076 L
.60096 .37878 L
.62093 .39509 L
.63635 .41983 L
.64569 .45265 L
.64759 .49266 L
.64094 .53843 L
.625 .58801 L
.59947 .63894 L
.56462 .68837 L
.52128 .73314 L
.47089 .76997 L
.41553 .79561 L
.35784 .80703 L
.30095 .80166 L
.24834 .77758 L
.20375 .73375 L
.17088 .67014 L
.15327 .58791 L
.15398 .4895 L
.17543 .3786 L
.21909 .26018 L
.28531 .14029 L
.37316 .0259 L
s
.37316 .0259 m
.40053 0 L
s
.899 1 0 r
.52237 .48093 m
.52515 .48555 L
.5268 .49165 L
.52707 .49905 L
.52577 .5075 L
.52275 .51663 L
.51798 .52598 L
.5115 .53502 L
.50347 .54318 L
.49416 .54986 L
.48397 .55444 L
.47337 .5564 L
.46294 .55524 L
.45335 .55065 L
.44525 .54241 L
.43934 .53056 L
.43626 .5153 L
.43658 .4971 L
.44071 .47664 L
.44894 .45486 L
.4613 .43287 L
.47762 .41195 L
.49745 .3935 L
.52007 .37895 L
.5445 .36967 L
.56953 .36694 L
.59375 .37177 L
.6156 .38489 L
.63347 .40663 L
.64576 .43683 L
.65099 .47482 L
.64791 .51937 L
.6356 .56869 L
.61357 .62048 L
.58183 .67199 L
.54098 .7201 L
.49226 .76148 L
.4375 .79279 L
.37918 .8108 L
.32031 .81267 L
.2643 .79615 L
.2149 .75976 L
.17593 .70304 L
.15109 .62666 L
.14375 .53255 L
.15668 .42398 L
.1918 .30548 L
.24998 .1828 L
.33082 .06271 L
s
.33082 .06271 m
.38879 0 L
s
0 .45 1 r
.54628 .52239 m
.53898 .53993 L
.52839 .55742 L
.51469 .57382 L
.4983 .588 L
.47982 .59883 L
.46008 .60519 L
.4401 .60614 L
.42103 .60088 L
.40413 .5889 L
.3907 .57003 L
.38199 .54446 L
.37917 .51285 L
.38317 .47625 L
.39468 .4362 L
.41399 .39462 L
.44101 .35379 L
.47515 .31625 L
.51531 .28466 L
.55991 .26171 L
.60687 .24991 L
.65371 .25146 L
.69762 .26803 L
.73559 .30065 L
.76457 .3495 L
.78163 .41382 L
.78417 .49185 L
.77009 .58076 L
.73804 .67669 L
.68752 .77485 L
.61909 .8697 L
.53445 .95512 L
s
.53445 .95512 m
.47133 1 L
s
.88 1 0 r
.56728 .48007 m
.56775 .49879 L
.56424 .52008 L
.55643 .54301 L
.54422 .56643 L
.52774 .589 L
.50741 .60927 L
.48394 .62572 L
.4583 .63687 L
.43173 .64134 L
.4057 .63797 L
.38182 .62593 L
.36181 .60477 L
.34738 .57455 L
.34013 .53586 L
.34144 .48988 L
.35239 .43838 L
.3736 .38369 L
.40517 .32867 L
.4466 .27653 L
.49673 .23078 L
.55373 .19499 L
.61512 .17263 L
.67781 .16681 L
.73825 .18009 L
.79252 .21421 L
.83658 .26992 L
.86643 .34677 L
.8784 .443 L
.8694 .55543 L
.83717 .67952 L
.78055 .80944 L
.69965 .93819 L
s
.69965 .93819 m
.6462 1 L
s
0 .099 1 r
.56517 .56608 m
.5476 .59524 L
.52485 .62261 L
.4976 .6463 L
.46685 .66443 L
.43399 .67516 L
.4007 .67687 L
.36889 .66827 L
.34066 .64848 L
.31818 .61721 L
.30355 .57478 L
.29868 .52224 L
.30518 .46138 L
.32415 .39472 L
.35615 .32547 L
.40098 .2574 L
.45768 .19473 L
.52446 .14193 L
.59867 .10345 L
.67688 .08349 L
.75495 .08572 L
.82821 .11295 L
.89166 .16688 L
.94019 .24787 L
.96894 .35467 L
.97355 .48437 L
.95053 .63226 L
.89758 .79196 L
.81386 .95551 L
s
.81386 .95551 m
.78191 1 L
s
1 0 .916 r
.52522 .55196 m
.51285 .56665 L
.49807 .57932 L
.48144 .58895 L
.4637 .59455 L
.44576 .59527 L
.42867 .5904 L
.41356 .57948 L
.40159 .56238 L
.39389 .53928 L
.3915 .51076 L
.39526 .4778 L
.40577 .44177 L
.42329 .40443 L
.44773 .3678 L
.47853 .33419 L
.51472 .30599 L
.55484 .2856 L
.59704 .27529 L
.63907 .277 L
.67841 .29224 L
.71234 .3219 L
.73812 .36613 L
.75314 .42424 L
.75506 .49459 L
.74203 .57464 L
.71282 .66089 L
.66704 .74904 L
.6052 .83406 L
.52885 .91049 L
.44061 .97261 L
s
.44061 .97261 m
.37804 1 L
s
.10682 1 m
.05613 .97469 L
s
.05613 .97469 m
0 .91579 L
s
0 .12454 m
.02313 .0646 L
s
.02313 .0646 m
.06005 0 L
s
1 0 .959 r
.57996 .51879 m
.57155 .54653 L
.55775 .57518 L
.53868 .60317 L
.51475 .62873 L
.48676 .65002 L
.45584 .6652 L
.42343 .67254 L
.39127 .67058 L
.36131 .65818 L
.33564 .63469 L
.31635 .60004 L
.30544 .55482 L
.30468 .5003 L
.31547 .43851 L
.33871 .37216 L
.37465 .3046 L
.42286 .23969 L
.48208 .18166 L
.55026 .1349 L
.62452 .10368 L
.70124 .09194 L
.77618 .10297 L
.84462 .13915 L
.90162 .20166 L
.94227 .29029 L
.96194 .40323 L
.95669 .53697 L
.92351 .68632 L
.86065 .84445 L
s
.86065 .84445 m
.76971 1 L
s
0 1 .201 r
.50736 .45527 m
.51639 .45182 L
.52564 .45079 L
.5346 .45256 L
.54269 .45739 L
.54931 .4654 L
.55388 .47655 L
.55583 .49057 L
.55472 .50703 L
.55019 .52526 L
.54207 .54441 L
.53036 .56346 L
.51528 .58127 L
.49728 .59659 L
.47704 .6082 L
.45548 .6149 L
.43371 .61564 L
.41299 .60958 L
.3947 .59619 L
.38025 .57527 L
.37102 .54707 L
.36825 .51232 L
.37298 .4722 L
.3859 .4284 L
.40736 .38304 L
.43719 .33861 L
.47474 .29789 L
.5188 .26381 L
.5676 .23927 L
.61887 .22701 L
.66988 .2294 L
.71755 .24825 L
.75859 .28462 L
.78967 .33868 L
.80762 .40955 L
.80961 .49526 L
.79341 .59266 L
.75754 .69751 L
.70155 .80453 L
.62608 .90765 L
s
.62608 .90765 m
.53322 1 L
s
.407 0 1 r
.43353 .51163 m
.43477 .49209 L
.44007 .47042 L
.44964 .44763 L
.46349 .42493 L
.48136 .40368 L
.50272 .38535 L
.52677 .37141 L
.55242 .36328 L
.57836 .36223 L
.60308 .36925 L
.62495 .38501 L
.64227 .40972 L
.65342 .4431 L
.6569 .48432 L
.65149 .53197 L
.63632 .58405 L
.61101 .63806 L
.5757 .69102 L
.53118 .73965 L
.47887 .78045 L
.42085 .80997 L
.35984 .82492 L
.29905 .8225 L
.24216 .80051 L
.19307 .75768 L
.15574 .69378 L
.13398 .60981 L
.13115 .50812 L
.14993 .3924 L
.1921 .26768 L
.25824 .14022 L
.34761 .01725 L
s
.34761 .01725 m
.36482 0 L
s
0 1 .204 r
.461 .52532 m
.45782 .51624 L
.45674 .50499 L
.45809 .49194 L
.46212 .47763 L
.46895 .46275 L
.47853 .44811 L
.49068 .43461 L
.505 .42322 L
.52092 .41489 L
.53772 .41053 L
.55451 .41092 L
.57028 .41668 L
.58396 .42817 L
.59445 .44547 L
.60071 .46833 L
.6018 .49613 L
.59696 .52786 L
.58569 .56214 L
.56781 .59729 L
.54351 .63132 L
.51338 .66204 L
.47843 .6872 L
.44013 .70453 L
.40029 .71198 L
.36109 .70778 L
.32496 .69063 L
.29446 .65982 L
.27215 .61539 L
.26046 .55815 L
.2615 .48983 L
.2769 .41301 L
.30766 .33116 L
.35398 .24847 L
.41518 .16978 L
.48959 .1003 L
.57452 .04541 L
.66632 .01031 L
s
.66632 .01031 m
.75823 0 L
s
.76168 0 m
.85153 .01762 L
.93379 .06663 L
s
.93379 .06663 m
1 .14663 L
s
1 .78084 m
.92796 .95093 L
s
.92796 .95093 m
.89782 1 L
s
.065 0 1 r
.49356 .50146 m
.49361 .49961 L
.49404 .49753 L
.4949 .49533 L
.49616 .49311 L
.49783 .49101 L
.49985 .48916 L
.50215 .48771 L
.50462 .48681 L
.50715 .48657 L
.50958 .4871 L
.51178 .48846 L
.51356 .4907 L
.51476 .49379 L
.51525 .49767 L
.5149 .50219 L
.51361 .50719 L
.51133 .51243 L
.50808 .51762 L
.50391 .52245 L
.49896 .52659 L
.4934 .52969 L
.4875 .53144 L
.48156 .53154 L
.47593 .52977 L
.47098 .526 L
.46711 .52017 L
.46468 .51236 L
.46404 .50277 L
.46545 .49175 L
.46911 .47974 L
.4751 .46735 L
.48338 .45525 L
.49374 .44421 L
.50587 .43503 L
.51925 .4285 L
.53327 .42537 L
.54717 .42627 L
.56011 .43168 L
.57119 .44189 L
.5795 .45693 L
.58417 .47653 L
.58444 .50015 L
.57972 .5269 L
.56961 .55561 L
.55401 .58482 L
.5331 .61287 L
.50744 .63792 L
.47792 .65808 L
.44579 .6715 L
Mistroke
.41261 .67647 L
.38022 .67159 L
.35066 .65582 L
.32608 .62866 L
.30859 .59021 L
.30019 .54126 L
.30259 .48333 L
.31708 .41869 L
.3444 .35028 L
.38465 .2817 L
.43713 .217 L
.50035 .16057 L
.57197 .11686 L
.64883 .09018 L
.72705 .0844 L
.80214 .10262 L
.86921 .14697 L
.9232 .21828 L
.95913 .31589 L
.97247 .43747 L
.95941 .57897 L
.91721 .7346 L
.84451 .89696 L
Mfstroke
.84451 .89696 m
.77836 1 L
s
.072 0 1 r
.47712 .48571 m
.48141 .47662 L
.48737 .46772 L
.49489 .45955 L
.50371 .45272 L
.51348 .44779 L
.52375 .44531 L
.53397 .44577 L
.54353 .44953 L
.55176 .45679 L
.558 .4676 L
.56162 .48178 L
.56204 .49894 L
.55881 .51844 L
.55165 .53944 L
.54046 .56088 L
.52536 .58155 L
.50674 .60011 L
.48524 .61516 L
.46176 .62536 L
.43743 .62943 L
.41359 .62633 L
.39173 .61528 L
.37342 .59589 L
.36021 .5682 L
.35359 .53275 L
.35482 .49062 L
.36486 .44345 L
.38431 .39337 L
.41324 .34299 L
.4512 .29525 L
.49712 .25337 L
.54933 .22062 L
.60555 .20018 L
.66296 .19489 L
.7183 .20709 L
.76798 .23839 L
.8083 .28945 L
.8356 .35987 L
.84652 .44802 L
.83824 .55101 L
.80867 .66467 L
.75676 .78365 L
.68263 .90155 L
s
.68263 .90155 m
.59742 1 L
s
0 .167 1 r
.52383 .44994 m
.53307 .45102 L
.54157 .45516 L
.54872 .46253 L
.55392 .47312 L
.5566 .48672 L
.55625 .50293 L
.55251 .52111 L
.54514 .54046 L
.53409 .55997 L
.51954 .5785 L
.50188 .59482 L
.48177 .60766 L
.46006 .61578 L
.43784 .61809 L
.41638 .61365 L
.39704 .60185 L
.38126 .58241 L
.37047 .55546 L
.36597 .52161 L
.36886 .48197 L
.37995 .43812 L
.39968 .39213 L
.42802 .34645 L
.46443 .30384 L
.5078 .26726 L
.55649 .23968 L
.60829 .22396 L
.66053 .22261 L
.71015 .23762 L
.75384 .27028 L
.78822 .32098 L
.80998 .38911 L
.81616 .47293 L
.8043 .56952 L
.77271 .67482 L
.72066 .78372 L
.64852 .8902 L
.55791 .98759 L
s
.55791 .98759 m
.54171 1 L
s
0 .652 1 r
.46158 .58247 m
.44631 .58095 L
.43221 .57441 L
.42028 .56255 L
.4115 .54539 L
.40684 .52323 L
.40712 .49674 L
.41297 .46692 L
.42479 .43509 L
.44267 .4029 L
.46635 .37222 L
.49518 .34507 L
.52815 .32355 L
.56382 .30968 L
.60044 .30532 L
.63595 .31198 L
.66807 .33075 L
.69445 .36211 L
.71275 .40586 L
.72079 .46106 L
.71674 .52593 L
.69922 .59789 L
.66749 .67359 L
.62155 .74902 L
.56223 .81965 L
.49132 .88061 L
.41147 .92699 L
.32628 .95409 L
.2401 .95771 L
.15794 .93452 L
.08525 .88233 L
.02761 .80038 L
s
.02761 .80038 m
0 .71803 L
s
0 .38289 m
.04682 .22164 L
.13075 .04224 L
s
.13075 .04224 m
.15887 0 L
s
1 .182 0 r
.43555 .46036 m
.4475 .43485 L
.46417 .40981 L
.48519 .38683 L
.5099 .36753 L
.53731 .35357 L
.56614 .34647 L
.59486 .34759 L
.62176 .35795 L
.64497 .37816 L
.66263 .40832 L
.67294 .44797 L
.67431 .496 L
.66546 .55066 L
.64558 .60958 L
.61436 .66981 L
.57216 .72793 L
.52005 .7802 L
.4598 .82272 L
.39392 .85166 L
.3256 .86347 L
.25859 .85518 L
.19704 .82461 L
.14537 .7706 L
.10797 .69327 L
.08897 .59412 L
.09195 .47615 L
.11966 .34389 L
.17375 .20334 L
.25449 .06176 L
s
.25449 .06176 m
.3033 0 L
s
.096 0 1 r
.54127 .48856 m
.54139 .50014 L
.53906 .51327 L
.53409 .52734 L
.52643 .54167 L
.51616 .55541 L
.50357 .56768 L
.48909 .57755 L
.47333 .5841 L
.45706 .58652 L
.44119 .58409 L
.42671 .57633 L
.41467 .56298 L
.40612 .5441 L
.40203 .52007 L
.40324 .49165 L
.41038 .45994 L
.42382 .4264 L
.44358 .39279 L
.46934 .36108 L
.50037 .33345 L
.5355 .31206 L
.57319 .29904 L
.61153 .29627 L
.64833 .30527 L
.68118 .32709 L
.7076 .36213 L
.72516 .41005 L
.73163 .46972 L
.72515 .53914 L
.70437 .61547 L
.66865 .69507 L
.6181 .77364 L
.55379 .84636 L
.4777 .90809 L
.39281 .95372 L
.30302 .97835 L
.21301 .97775 L
.12813 .94856 L
.05413 .88875 L
s
.05413 .88875 m
0 .80276 L
s
0 .29364 m
.03703 .17755 L
s
.03703 .17755 m
.12552 0 L
s
0 1 .271 r
.43146 .53604 m
.42766 .51899 L
.42767 .49855 L
.432 .47546 L
.44096 .45077 L
.45463 .42572 L
.47283 .40177 L
.49507 .38049 L
.52057 .3635 L
.54823 .35239 L
.5767 .3486 L
.60439 .35334 L
.62954 .36746 L
.65032 .39135 L
.66489 .42492 L
.67157 .46742 L
.66891 .51753 L
.65583 .57327 L
.6317 .63206 L
.59651 .6908 L
.55088 .74598 L
.49614 .79384 L
.43434 .83055 L
.36823 .85244 L
.30117 .85622 L
.23704 .83926 L
.18006 .79981 L
.13457 .73723 L
.10481 .65216 L
.09466 .5467 L
.10733 .42441 L
.14511 .29035 L
.20908 .15093 L
.29892 .01378 L
s
.29892 .01378 m
.31132 0 L
s
1 0 .078 r
.56547 .48665 m
.56465 .50565 L
.55986 .52684 L
.55087 .54926 L
.53765 .57172 L
.52042 .5929 L
.49968 .61136 L
.47619 .62563 L
.451 .63431 L
.42538 .63614 L
.4008 .63009 L
.37886 .61548 L
.36122 .59203 L
.34951 .55998 L
.34521 .52008 L
.34958 .47367 L
.36349 .42265 L
.3874 .36946 L
.42121 .31696 L
.46422 .26839 L
.51509 .22716 L
.57183 .19672 L
.63185 .18031 L
.69199 .18078 L
.74869 .20035 L
.79811 .2404 L
.83633 .30126 L
.85958 .38207 L
.86448 .48068 L
.8483 .59357 L
.8092 .71591 L
.74645 .84167 L
.66064 .96379 L
s
.66064 .96379 m
.62571 1 L
s
.658 0 1 r
.43691 .57618 m
.42434 .56604 L
.4146 .55061 L
.40867 .53011 L
.40739 .50509 L
.41146 .47642 L
.42136 .44535 L
.43726 .4134 L
.45903 .38237 L
.48613 .35421 L
.51767 .331 L
.55235 .31478 L
.58854 .30744 L
.62425 .31061 L
.65732 .3255 L
.6854 .35277 L
.70617 .39246 L
.71741 .44385 L
.71718 .50542 L
.70396 .57487 L
.67683 .64911 L
.63553 .72433 L
.58065 .7962 L
.51366 .85997 L
.43693 .91076 L
.35375 .94381 L
.26821 .95481 L
.18511 .94014 L
.10972 .89727 L
.04757 .825 L
.00412 .72373 L
s
.00412 .72373 m
0 .69688 L
s
0 .41502 m
.03277 .27712 L
.10577 .10044 L
s
.10577 .10044 m
.16627 0 L
s
1 .422 0 r
.53697 .48672 m
.53772 .49671 L
.53632 .50823 L
.53256 .52079 L
.52637 .53378 L
.51777 .54649 L
.50697 .55812 L
.49432 .56783 L
.48032 .57478 L
.46563 .57821 L
.45104 .57742 L
.43742 .57192 L
.42572 .56139 L
.41689 .5458 L
.41184 .5254 L
.41138 .50077 L
.41614 .47282 L
.42654 .44276 L
.4427 .41212 L
.46443 .38264 L
.49118 .35623 L
.52201 .33488 L
.55564 .32053 L
.59042 .31498 L
.62444 .31972 L
.65558 .33584 L
.68158 .3639 L
.70021 .40381 L
.70938 .45477 L
.70729 .51522 L
.69256 .58281 L
.66438 .65445 L
.62265 .72643 L
.56804 .79448 L
.50211 .85404 L
.42728 .90041 L
.34681 .92908 L
.26477 .93597 L
.18583 .91778 L
.11512 .87226 L
.05795 .79847 L
.01953 .69706 L
.00464 .5704 L
.01731 .42267 L
.06046 .25988 L
.13556 .08974 L
s
.13556 .08974 m
.19252 0 L
s
0 .983 1 r
.47669 .57316 m
.46255 .57522 L
.44875 .57308 L
.43618 .56629 L
.42573 .55464 L
.41833 .53818 L
.41481 .51726 L
.4159 .49252 L
.42216 .46493 L
.43388 .43576 L
.45112 .40654 L
.47356 .37899 L
.50057 .355 L
.53114 .33647 L
.56392 .32521 L
.59725 .32288 L
.62923 .33081 L
.65775 .34988 L
.68067 .38044 L
.69586 .4222 L
.7014 .47416 L
.69566 .53458 L
.67749 .60098 L
.64631 .6702 L
.60226 .73849 L
.54624 .80165 L
.48001 .85523 L
.40615 .89476 L
.32805 .91601 L
.24981 .91527 L
.17608 .88968 L
.11184 .83744 L
.0622 .75812 L
.03205 .65284 L
.0258 .52444 L
.047 .37747 L
.09804 .21825 L
.17984 .05463 L
s
.17984 .05463 m
.21828 0 L
s
.304 0 1 r
.43279 .54372 m
.4273 .52809 L
.42541 .5087 L
.42772 .48621 L
.43465 .46155 L
.4464 .4359 L
.4629 .41065 L
.48382 .38737 L
.50849 .36771 L
.53594 .35332 L
.5649 .34577 L
.59384 .3464 L
.62104 .35628 L
.64465 .37605 L
.66277 .40584 L
.67359 .44521 L
.67551 .49309 L
.66721 .54776 L
.64784 .60686 L
.61707 .66745 L
.57523 .72613 L
.52332 .77914 L
.46312 .82255 L
.39709 .85251 L
.32841 .86544 L
.26082 .8583 L
.1985 .82883 L
.14586 .77584 L
.10732 .69933 L
.08708 .60076 L
.08876 .48305 L
.1152 .35067 L
.1681 .20958 L
.24784 .06702 L
s
.24784 .06702 m
.29988 0 L
s
0 1 .021 r
.44694 .53181 m
.44317 .51912 L
.4423 .5036 L
.44475 .48579 L
.45081 .46647 L
.46062 .44657 L
.47409 .42721 L
.49089 .40961 L
.51047 .39506 L
.53204 .38483 L
.55457 .3801 L
.57684 .3819 L
.59749 .39098 L
.61508 .40777 L
.62815 .43229 L
.63532 .46412 L
.63537 .50233 L
.62736 .54548 L
.61068 .59167 L
.58518 .63854 L
.55121 .68339 L
.50966 .72328 L
.462 .75516 L
.41026 .77607 L
.35698 .7833 L
.30514 .77459 L
.25802 .74835 L
.21906 .70381 L
.19166 .64118 L
.179 .5618 L
.1838 .46815 L
.20809 .36394 L
.25303 .25397 L
.31868 .14402 L
.40388 .04067 L
s
.40388 .04067 m
.45025 0 L
s
.517 0 1 r
.56779 .51342 m
.56119 .53662 L
.55006 .56072 L
.53447 .58441 L
.51474 .60621 L
.4915 .62459 L
.46568 .63798 L
.43847 .64493 L
.4113 .64416 L
.38581 .63469 L
.36373 .61593 L
.34683 .58775 L
.33683 .55059 L
.33522 .50547 L
.34322 .45401 L
.36164 .39844 L
.39077 .34153 L
.43028 .28649 L
.47922 .23686 L
.53591 .19631 L
.598 .16848 L
.66252 .15671 L
.72594 .16384 L
.78433 .19197 L
.83353 .24222 L
.8694 .31453 L
.88801 .40753 L
.88596 .51843 L
.86063 .64299 L
.81041 .77561 L
.73499 .90945 L
s
.73499 .90945 m
.6642 1 L
s
0 .662 1 r
.49506 .42709 m
.51072 .41612 L
.52783 .40868 L
.54555 .4057 L
.56292 .40795 L
.57885 .41599 L
.5922 .43011 L
.60183 .45027 L
.60666 .47609 L
.60578 .50676 L
.59847 .54112 L
.58432 .57761 L
.56326 .61432 L
.53562 .6491 L
.50217 .67962 L
.46414 .7035 L
.42318 .71841 L
.38136 .72229 L
.34104 .71343 L
.30483 .69066 L
.27544 .65348 L
.25553 .60221 L
.24754 .53801 L
.25355 .463 L
.27506 .3802 L
.31284 .29353 L
.36682 .20763 L
.43593 .12772 L
.51806 .05938 L
.61004 .00822 L
s
.61004 .00822 m
.63807 0 L
s
.87498 0 m
.89913 .00765 L
.98086 .07045 L
s
.98086 .07045 m
1 .09943 L
s
1 .85866 m
.93144 1 L
s
0 .017 1 r
.49636 .48942 m
.49879 .4869 L
.50162 .48483 L
.50473 .48338 L
.50798 .48274 L
.51118 .48304 L
.51414 .48438 L
.51665 .48684 L
.5185 .49042 L
.51949 .49503 L
.51946 .50056 L
.51826 .5068 L
.51581 .51345 L
.51209 .52019 L
.50716 .52663 L
.50114 .53233 L
.49425 .53687 L
.48679 .53981 L
.47912 .54076 L
.47168 .53941 L
.46494 .53554 L
.45939 .52903 L
.45552 .51992 L
.45379 .5084 L
.45458 .49486 L
.45819 .47982 L
.46477 .46398 L
.47433 .44817 L
.4867 .43336 L
.5015 .42055 L
.51819 .41076 L
.53601 .405 L
.55406 .40414 L
.57128 .40888 L
.58655 .41968 L
.59869 .43671 L
.60657 .45978 L
.60913 .48833 L
.60553 .52137 L
.59515 .55754 L
.57772 .59509 L
.55334 .63197 L
.52252 .66589 L
.48626 .69443 L
.44599 .71518 L
.40358 .72586 L
.36127 .72449 L
.3216 .70955 L
.28729 .68012 L
.2611 .63604 L
Mistroke
.24567 .57797 L
.24335 .50753 L
.25602 .42725 L
.28494 .34062 L
.33052 .25196 L
.39229 .1663 L
.4687 .08912 L
.55716 .02617 L
Mfstroke
.55716 .02617 m
.61599 0 L
s
.90116 0 m
.94407 .02091 L
s
.94407 .02091 m
1 .07853 L
s
1 .88568 m
.98231 .93212 L
s
.98231 .93212 m
.94388 1 L
s
.509 1 0 r
.57924 .49234 m
.57645 .51644 L
.56873 .54276 L
.55589 .57004 L
.538 .59677 L
.51546 .6213 L
.48901 .64185 L
.45968 .65668 L
.42885 .66414 L
.39817 .66281 L
.36946 .65159 L
.34473 .62983 L
.32596 .59744 L
.31506 .55492 L
.31375 .50346 L
.32337 .44495 L
.34481 .38193 L
.37835 .31756 L
.42361 .2555 L
.47946 .19975 L
.54397 .15449 L
.61444 .12381 L
.68748 .11148 L
.75905 .12067 L
.82471 .15372 L
.87975 .21181 L
.91946 .29482 L
.93945 .40112 L
.9359 .52748 L
.90587 .66902 L
.84765 .81932 L
.76093 .9706 L
s
.76093 .9706 m
.73759 1 L
s
.919 1 0 r
.44087 .58142 m
.42697 .57321 L
.41557 .55955 L
.4077 .54051 L
.40428 .51652 L
.40612 .48835 L
.41379 .45712 L
.42763 .42429 L
.44763 .39161 L
.47342 .36104 L
.50422 .33469 L
.53888 .31469 L
.57582 .30307 L
.61317 .30165 L
.64874 .31188 L
.68018 .33468 L
.70505 .37038 L
.72102 .41856 L
.72592 .47801 L
.718 .54669 L
.69603 .62173 L
.65945 .69951 L
.60848 .77574 L
.54426 .84567 L
.46885 .90431 L
.38525 .94664 L
.29737 .96796 L
.20987 .96423 L
.12802 .9323 L
.05745 .87035 L
.00389 .77806 L
s
.00389 .77806 m
0 .76292 L
s
0 .33261 m
.05734 .16381 L
s
.05734 .16381 m
.14263 0 L
s
1 .506 0 r
.42212 .45681 m
.43556 .42657 L
.45464 .3967 L
.47896 .369 L
.50778 .34543 L
.53997 .32794 L
.57406 .31838 L
.60827 .31838 L
.64059 .32921 L
.66882 .35167 L
.69074 .38596 L
.70421 .43162 L
.70729 .48744 L
.69842 .55144 L
.67653 .6209 L
.64121 .69239 L
.59276 .76193 L
.53232 .8251 L
.46192 .8773 L
.3844 .91395 L
.30347 .93079 L
.22347 .92418 L
.14932 .8914 L
.0862 .83091 L
.03936 .74263 L
.01376 .62813 L
.01374 .49074 L
.04272 .33561 L
.10283 .16963 L
.19462 .00125 L
s
.19462 .00125 m
.19557 0 L
s
0 .881 1 r
.55484 .41674 m
.56936 .42335 L
.58168 .43542 L
.59077 .45294 L
.59566 .4756 L
.59549 .50273 L
.58961 .53332 L
.5776 .56598 L
.55936 .59907 L
.53515 .63065 L
.50563 .65864 L
.47183 .6809 L
.43522 .69534 L
.3976 .70004 L
.36107 .69345 L
.32796 .67444 L
.30071 .6425 L
.28171 .5978 L
.2732 .54132 L
.27709 .47486 L
.29478 .40105 L
.32707 .32331 L
.37397 .24575 L
.43463 .17304 L
.50727 .11014 L
.58914 .06211 L
.67661 .0338 L
.76518 .02953 L
.84973 .05275 L
.92469 .10573 L
.98429 .18927 L
s
.98429 .18927 m
1 .23526 L
s
1 .66725 m
.96707 .78213 L
.88157 .96641 L
s
.88157 .96641 m
.85937 1 L
s
1 0 .976 r
.45645 .58031 m
.44192 .5769 L
.42892 .56844 L
.41843 .55477 L
.4114 .53601 L
.40873 .51261 L
.41114 .48535 L
.41917 .45532 L
.43309 .42397 L
.45285 .39297 L
.47806 .36423 L
.50793 .33976 L
.54131 .32158 L
.57667 .31163 L
.61216 .31159 L
.64569 .32277 L
.675 .34601 L
.69777 .38154 L
.71178 .42885 L
.71503 .48671 L
.70588 .55307 L
.68324 .62509 L
.64665 .69925 L
.59645 .7714 L
.53381 .83697 L
.46082 .89117 L
.38044 .92926 L
.29649 .94683 L
.2135 .94008 L
.13655 .90619 L
.07102 .84357 L
.02235 .75212 L
s
.02235 .75212 m
0 .65264 L
s
0 .46713 m
.02548 .33019 L
.08769 .15805 L
s
.08769 .15805 m
.17373 0 L
s
.128 1 0 r
.47915 .47367 m
.48587 .46367 L
.49432 .4545 L
.50424 .44683 L
.51522 .44131 L
.52676 .43855 L
.53825 .43909 L
.54898 .44334 L
.55821 .45152 L
.56521 .4637 L
.56925 .47965 L
.56969 .49895 L
.56604 .52087 L
.55797 .54447 L
.54536 .56856 L
.52837 .59177 L
.50742 .6126 L
.48325 .62949 L
.45685 .6409 L
.42951 .64543 L
.40274 .64188 L
.3782 .62941 L
.35766 .60756 L
.34287 .57638 L
.33548 .5365 L
.33692 .48912 L
.34828 .4361 L
.3702 .37982 L
.40278 .32321 L
.44549 .26961 L
.49714 .22262 L
.55584 .18591 L
.61903 .16304 L
.68353 .15722 L
.74567 .17107 L
.80143 .20638 L
.84665 .26391 L
.87721 .34317 L
.88934 .44233 L
.87988 .55814 L
.84649 .68591 L
.788 .8196 L
.70454 .95202 L
s
.70454 .95202 m
.66294 1 L
s
1 0 .575 r
.55358 .54198 m
.54174 .56437 L
.52584 .58589 L
.50628 .60516 L
.48373 .62072 L
.45916 .63115 L
.43375 .63516 L
.40891 .63163 L
.38619 .61979 L
.36724 .59922 L
.35368 .57 L
.34703 .53271 L
.34863 .48851 L
.35947 .43911 L
.38013 .38676 L
.41069 .3342 L
.45064 .28452 L
.49886 .24108 L
.55357 .2073 L
.61237 .18647 L
.67229 .18157 L
.72992 .19501 L
.78151 .22842 L
.82318 .28248 L
.85112 .35671 L
.86185 .44937 L
.85242 .55738 L
.82073 .67636 L
.76568 .80066 L
.68746 .92357 L
s
.68746 .92357 m
.62056 1 L
s
.855 1 0 r
.55167 .55304 m
.53761 .57624 L
.51942 .59799 L
.49767 .61679 L
.47315 .63112 L
.44697 .63955 L
.42046 .64078 L
.39517 .63377 L
.37277 .61785 L
.35497 .59279 L
.34344 .55885 L
.33973 .51689 L
.34507 .46833 L
.36036 .41519 L
.38602 .36004 L
.42189 .30589 L
.4672 .25611 L
.52049 .21424 L
.57966 .18384 L
.64196 .16825 L
.70408 .17037 L
.76231 .19242 L
.81265 .23576 L
.85104 .30062 L
.87361 .38601 L
.8769 .48957 L
.85816 .60753 L
.81556 .7348 L
.74847 .865 L
.65762 .99078 L
s
.65762 .99078 m
.64847 1 L
s
0 1 .117 r
.46479 .47862 m
.47126 .46471 L
.4803 .45105 L
.49173 .4385 L
.50516 .42794 L
.52009 .42027 L
.5358 .41634 L
.55146 .41687 L
.56615 .42243 L
.57884 .43336 L
.58852 .44972 L
.59421 .47125 L
.59505 .49736 L
.59032 .52711 L
.57958 .5592 L
.56266 .59204 L
.53976 .62375 L
.51143 .65232 L
.47865 .6756 L
.44278 .6915 L
.40554 .69811 L
.36898 .69378 L
.33536 .67732 L
.30709 .64809 L
.28656 .60613 L
.27602 .55227 L
.27744 .48811 L
.29232 .41612 L
.32156 .33955 L
.36534 .26235 L
.42298 .18904 L
.49289 .12452 L
.57253 .0738 L
.65845 .04174 L
.74636 .03274 L
.83128 .05042 L
.90775 .09725 L
.97009 .17434 L
s
.97009 .17434 m
1 .24931 L
s
1 .64625 m
.97476 .74567 L
.89653 .92768 L
s
.89653 .92768 m
.85159 1 L
s
1 .024 0 r
.5119 .55933 m
.49871 .57075 L
.48385 .57948 L
.46798 .58463 L
.4519 .58542 L
.43654 .58121 L
.42293 .57161 L
.4121 .55645 L
.40507 .53591 L
.40277 .5105 L
.40596 .48107 L
.41518 .44886 L
.43068 .4154 L
.45239 .38254 L
.47983 .35231 L
.51212 .32685 L
.54799 .30834 L
.58577 .29879 L
.62347 .29996 L
.65882 .31323 L
.68941 .3394 L
.71278 .37863 L
.72657 .43032 L
.72868 .49305 L
.71744 .56455 L
.69174 .64171 L
.65117 .7207 L
.59619 .79705 L
.52815 .86585 L
.44938 .92199 L
.36313 .96044 L
.27357 .97654 L
.18558 .96638 L
.10462 .92705 L
.03647 .85701 L
s
.03647 .85701 m
0 .78297 L
s
0 .29963 m
.06996 .11568 L
s
.06996 .11568 m
.13536 0 L
s
.438 0 1 r
.50085 .48191 m
.50462 .47985 L
.50861 .47871 L
.51263 .47869 L
.51642 .47993 L
.51975 .48254 L
.52233 .48654 L
.52393 .49187 L
.52432 .4984 L
.5233 .50589 L
.52077 .51403 L
.51665 .52241 L
.51099 .53058 L
.50393 .53801 L
.49569 .54416 L
.48661 .54849 L
.47712 .55051 L
.46773 .54979 L
.45902 .546 L
.45158 .53897 L
.44605 .52867 L
.443 .5153 L
.44294 .49922 L
.44627 .48106 L
.45326 .46161 L
.46396 .44185 L
.47823 .42294 L
.4957 .4061 L
.51576 .39262 L
.53755 .38374 L
.56 .38062 L
.58186 .38421 L
.60174 .39517 L
.61821 .41385 L
.62983 .44015 L
.63524 .47352 L
.63331 .51292 L
.62318 .55679 L
.60435 .60311 L
.57678 .64946 L
.54097 .69306 L
.49795 .73095 L
.44932 .76012 L
.39724 .77765 L
.34436 .78097 L
.29371 .76796 L
.24862 .73725 L
.21252 .6883 L
.18876 .6216 L
.18039 .53877 L
Mistroke
.18997 .44259 L
.21932 .33704 L
.26931 .22715 L
.33972 .1189 L
.42906 .01896 L
Mfstroke
.42906 .01896 m
.4527 0 L
s
0 1 .574 r
.52784 .50867 m
.52446 .5186 L
.51918 .52875 L
.51205 .53853 L
.50324 .54732 L
.49308 .55445 L
.48197 .55929 L
.47046 .56124 L
.45918 .55979 L
.44883 .55459 L
.44015 .54543 L
.43389 .53235 L
.43074 .5156 L
.43129 .49568 L
.43602 .47338 L
.4452 .44969 L
.45886 .42584 L
.4768 .40325 L
.49851 .38341 L
.5232 .36789 L
.54979 .35818 L
.57695 .35563 L
.60314 .36135 L
.62667 .37611 L
.64578 .40022 L
.65874 .43349 L
.66395 .47515 L
.66008 .52384 L
.64615 .5776 L
.62165 .63388 L
.58664 .68968 L
.54179 .74159 L
.48848 .78601 L
.42876 .81928 L
.36534 .83795 L
.3015 .83894 L
.241 .81986 L
.18789 .77915 L
.14632 .71638 L
.12031 .63235 L
.11348 .52924 L
.12879 .41065 L
.16828 .2816 L
.23281 .1484 L
.32186 .01842 L
s
.32186 .01842 m
.33919 0 L
s
.476 0 1 r
.42621 .5478 m
.42022 .53061 L
.4182 .5093 L
.42078 .48461 L
.42843 .45754 L
.44137 .42941 L
.45953 .40173 L
.48251 .37624 L
.50961 .35472 L
.53973 .33901 L
.5715 .33081 L
.60323 .3316 L
.63304 .34255 L
.65887 .36433 L
.67867 .39712 L
.69046 .4404 L
.69245 .493 L
.68323 .55302 L
.66186 .61787 L
.62799 .68432 L
.58198 .74863 L
.52495 .80668 L
.45884 .85417 L
.38638 .88686 L
.31105 .90082 L
.23696 .89275 L
.16869 .86018 L
.11109 .80179 L
.06901 .71763 L
.04703 .60929 L
.04914 .48 L
.07842 .33469 L
.13674 .17989 L
.22449 .02357 L
s
.22449 .02357 m
.24285 0 L
s
0 1 .326 r
.53064 .41865 m
.54611 .41785 L
.56088 .42184 L
.57399 .43102 L
.58444 .44554 L
.59124 .46524 L
.5935 .48964 L
.59049 .5179 L
.58168 .54886 L
.56683 .58103 L
.54602 .61264 L
.51969 .64175 L
.48868 .66628 L
.45421 .68417 L
.41789 .69344 L
.38163 .69242 L
.3476 .67979 L
.31812 .65475 L
.29557 .61715 L
.28221 .56756 L
.28006 .50733 L
.29073 .43865 L
.31531 .36448 L
.35417 .28852 L
.40691 .21506 L
.47222 .14881 L
.54788 .09468 L
.63076 .05751 L
.71688 .04179 L
.80153 .0513 L
.87947 .08883 L
.94516 .15588 L
.99304 .25238 L
s
.99304 .25238 m
1 .28713 L
s
1 .59916 m
.98138 .69076 L
.91436 .86777 L
s
.91436 .86777 m
.83987 1 L
s
1 .746 0 r
.451 .54018 m
.44524 .52985 L
.44199 .51637 L
.44176 .50012 L
.44497 .48169 L
.45189 .46191 L
.4626 .44176 L
.47697 .42241 L
.49463 .4051 L
.51495 .39115 L
.5371 .38183 L
.55997 .37832 L
.58232 .3816 L
.60273 .39238 L
.61974 .41101 L
.63186 .43742 L
.63774 .47109 L
.63619 .51096 L
.62631 .55549 L
.60758 .60264 L
.57994 .64994 L
.54385 .6946 L
.50034 .7336 L
.45102 .76387 L
.39805 .78243 L
.34412 .78661 L
.29229 .77426 L
.24595 .74391 L
.2086 .69497 L
.18364 .62789 L
.17423 .54425 L
.183 .44684 L
.21184 .33962 L
.2617 .2277 L
.33241 .1171 L
.42253 .01462 L
s
.42253 .01462 m
.44044 0 L
s
.382 0 1 r
.50764 .47359 m
.51279 .4726 L
.51786 .47312 L
.52255 .4753 L
.52651 .47925 L
.52941 .48496 L
.53095 .49233 L
.53085 .50114 L
.52889 .51105 L
.52496 .52163 L
.51901 .53232 L
.51113 .54251 L
.50154 .55152 L
.49058 .55865 L
.47873 .56324 L
.46656 .56467 L
.45477 .56244 L
.44411 .55618 L
.43536 .54574 L
.4293 .53118 L
.42665 .51282 L
.42802 .49125 L
.43387 .46733 L
.44444 .44218 L
.45973 .41713 L
.47945 .39368 L
.50303 .37345 L
.52957 .35808 L
.55788 .34912 L
.58651 .34797 L
.61379 .35573 L
.63791 .37312 L
.65702 .4004 L
.66932 .43725 L
.67315 .48275 L
.66717 .53534 L
.65042 .59282 L
.62247 .65242 L
.58349 .71087 L
.53435 .76452 L
.47661 .80954 L
.41259 .84209 L
.34525 .85858 L
.27817 .85588 L
.21539 .8316 L
.16123 .7843 L
.12005 .71376 L
.09606 .62107 L
.09295 .50883 L
.11371 .38111 L
Mistroke
.16027 .24347 L
.23329 .10281 L
Mfstroke
.23329 .10281 m
.30803 0 L
s
0 .637 1 r
.5138 .545 m
.50354 .55518 L
.49169 .56342 L
.47877 .56898 L
.46539 .57116 L
.4523 .56939 L
.4403 .56325 L
.43027 .55252 L
.42306 .53722 L
.41948 .51767 L
.42023 .49446 L
.42583 .46849 L
.4366 .44095 L
.45259 .41326 L
.47353 .38705 L
.49884 .36409 L
.52759 .34618 L
.55852 .33505 L
.59008 .33228 L
.62047 .33915 L
.64772 .35652 L
.66979 .38476 L
.68467 .42364 L
.69053 .47224 L
.6858 .52897 L
.66935 .59153 L
.64062 .65696 L
.59968 .72174 L
.54735 .78192 L
.48522 .8333 L
.4157 .87165 L
.34195 .89293 L
.2678 .89362 L
.19763 .87093 L
.13616 .82309 L
.08819 .74962 L
.0584 .65147 L
.05097 .53123 L
.06934 .39311 L
.11583 .24298 L
.19142 .08818 L
s
.19142 .08818 m
.25226 0 L
s
.095 0 1 r
.48919 .49604 m
.49062 .4921 L
.49281 .48812 L
.49572 .48431 L
.49927 .48093 L
.50333 .47823 L
.50774 .47648 L
.51228 .47589 L
.51668 .47667 L
.52068 .47894 L
.52397 .48277 L
.52628 .48813 L
.52732 .49492 L
.52688 .50291 L
.52477 .5118 L
.5209 .52116 L
.51528 .53051 L
.50799 .53928 L
.49925 .54688 L
.4894 .5527 L
.47887 .55615 L
.46819 .5567 L
.45799 .55395 L
.44894 .54762 L
.44173 .53761 L
.43703 .52401 L
.43546 .50718 L
.43753 .48768 L
.44361 .46631 L
.45385 .44411 L
.46821 .42228 L
.48638 .40219 L
.50778 .38525 L
.53156 .3729 L
.55663 .36649 L
.58166 .36718 L
.60516 .37589 L
.62551 .39315 L
.64108 .41909 L
.65031 .45331 L
.65181 .49487 L
.64446 .54227 L
.62751 .59345 L
.6007 .64588 L
.56432 .69659 L
.51925 .74233 L
.46704 .77971 L
.40984 .80538 L
.3504 .81626 L
.29197 .80973 L
Mistroke
.23816 .78386 L
.19281 .73761 L
.15973 .67103 L
.14255 .58539 L
.14439 .48326 L
.16769 .36852 L
.21391 .24635 L
.28334 .12304 L
.37494 .00579 L
Mfstroke
.37494 .00579 m
.38117 0 L
s
1 .322 0 r
.49454 .51997 m
.49063 .52082 L
.48675 .52053 L
.48316 .51899 L
.48008 .51611 L
.47779 .51189 L
.47652 .50639 L
.47647 .49978 L
.47783 .49231 L
.48068 .48429 L
.48507 .47615 L
.49093 .46835 L
.49812 .46139 L
.50637 .45581 L
.51534 .45212 L
.5246 .4508 L
.53361 .45223 L
.54182 .45671 L
.54864 .46436 L
.55346 .47516 L
.55573 .48887 L
.55498 .50508 L
.55085 .52314 L
.54314 .54222 L
.53183 .56133 L
.51712 .57933 L
.49943 .59498 L
.47941 .60707 L
.45796 .61437 L
.43616 .61583 L
.41526 .61057 L
.39664 .59802 L
.3817 .57795 L
.37182 .55056 L
.36828 .51651 L
.37211 .47694 L
.38409 .43348 L
.40457 .38819 L
.43347 .34355 L
.47018 .30229 L
.51357 .26733 L
.56192 .24159 L
.61301 .22784 L
.66417 .22848 L
.71235 .2454 L
.75428 .27976 L
.78663 .33182 L
.80619 .40085 L
.8101 .48498 L
.79603 .58121 L
Mistroke
.76244 .68541 L
.70873 .79243 L
.63541 .89625 L
.54426 .99027 L
Mfstroke
.54426 .99027 m
.53093 1 L
s
1 0 .32 r
.54356 .42296 m
.5574 .4268 L
.56966 .43552 L
.57939 .44925 L
.58569 .46783 L
.58772 .49081 L
.58478 .51739 L
.5764 .54647 L
.56235 .57666 L
.5427 .60629 L
.5179 .63353 L
.48872 .65643 L
.45633 .67305 L
.42224 .68157 L
.38824 .68039 L
.35638 .6683 L
.32884 .64456 L
.30785 .60904 L
.29551 .56228 L
.29373 .50559 L
.30402 .44101 L
.32736 .37136 L
.3641 .3001 L
.41385 .23127 L
.47535 .16931 L
.54651 .11881 L
.62437 .08433 L
.70519 .07005 L
.78452 .0795 L
.85745 .11529 L
.91878 .17879 L
.9633 .26989 L
.98611 .38686 L
.98297 .52614 L
.95061 .68241 L
.88707 .84861 L
s
.88707 .84861 m
.80115 1 L
s
1 0 .53 r
.45273 .41996 m
.47225 .39467 L
.49602 .37228 L
.52319 .35454 L
.5526 .3431 L
.58279 .3395 L
.61206 .34499 L
.63855 .36046 L
.6603 .38631 L
.67538 .42238 L
.68202 .46788 L
.67868 .52135 L
.66424 .58068 L
.63809 .64309 L
.60022 .70527 L
.55133 .7635 L
.49286 .81376 L
.42704 .852 L
.35681 .87435 L
.28576 .87734 L
.21803 .85823 L
.1581 .81521 L
.11058 .74766 L
.07995 .65636 L
.0703 .54357 L
.08499 .41316 L
.12638 .27057 L
.19556 .12268 L
s
.19556 .12268 m
.2772 0 L
s
0 1 .563 r
.43261 .53267 m
.42946 .51556 L
.4301 .49524 L
.43499 .47249 L
.44441 .44836 L
.4584 .4241 L
.47673 .40113 L
.49889 .381 L
.52406 .36528 L
.55116 .35551 L
.57881 .35305 L
.60544 .35903 L
.62933 .37421 L
.64869 .39892 L
.66176 .43294 L
.66692 .47549 L
.66282 .52517 L
.64846 .57997 L
.62333 .63729 L
.5875 .69405 L
.54168 .7468 L
.48728 .79185 L
.42639 .8255 L
.36179 .84422 L
.29682 .8449 L
.23532 .8251 L
.18142 .78328 L
.13934 .719 L
.11317 .6331 L
.10658 .52782 L
.12257 .40686 L
.1632 .27536 L
.22933 .13974 L
.3204 .00755 L
s
.3204 .00755 m
.32755 0 L
s
0 .832 1 r
.5087 .48255 m
.5119 .48305 L
.51481 .48463 L
.51723 .48733 L
.51895 .49115 L
.51976 .49601 L
.51951 .50175 L
.51805 .50815 L
.51533 .51492 L
.51133 .5217 L
.50612 .52809 L
.49985 .53365 L
.49276 .53795 L
.48515 .54055 L
.47742 .54109 L
.47 .53924 L
.46339 .53481 L
.45808 .52772 L
.45456 .51802 L
.45328 .50596 L
.45462 .49194 L
.45884 .47654 L
.46608 .46048 L
.4763 .44464 L
.48931 .42999 L
.50468 .41756 L
.52181 .4084 L
.53993 .40348 L
.55808 .40367 L
.57519 .40962 L
.59008 .42175 L
.60159 .44017 L
.60857 .46461 L
.61001 .49441 L
.60507 .52851 L
.59322 .56545 L
.57422 .60341 L
.54827 .64026 L
.51599 .67364 L
.47845 .70112 L
.4372 .72026 L
.39421 .72882 L
.3518 .72486 L
.31258 .70697 L
.27931 .67436 L
.25478 .62701 L
.2416 .56577 L
.24208 .49246 L
.25801 .40984 L
.29049 .32159 L
Mistroke
.33978 .23224 L
.4052 .14695 L
.48498 .07137 L
.57627 .01128 L
Mfstroke
.57627 .01128 m
.60492 0 L
s
.91448 0 m
.96485 .02897 L
s
.96485 .02897 m
1 .07023 L
s
1 .898 m
.96688 .97768 L
s
.96688 .97768 m
.95337 1 L
s
1 0 .864 r
.41946 .49331 m
.42535 .46696 L
.43647 .43906 L
.45287 .41108 L
.47425 .38468 L
.50002 .36165 L
.52922 .34379 L
.56056 .33288 L
.59247 .33047 L
.6231 .33786 L
.65048 .3559 L
.67253 .38494 L
.68722 .42471 L
.69271 .47425 L
.68743 .53194 L
.67028 .5954 L
.64068 .66161 L
.59875 .72701 L
.54535 .78758 L
.48214 .83906 L
.41158 .87717 L
.33689 .89787 L
.26199 .8976 L
.1913 .87357 L
.12962 .82407 L
.08181 .74866 L
.05257 .64837 L
.04613 .52588 L
.06589 .38554 L
.11417 .23333 L
.1919 .07677 L
s
.1919 .07677 m
.2456 0 L
s
0 .467 1 r
.44146 .57571 m
.42873 .56695 L
.41856 .55303 L
.41189 .5341 L
.40959 .51061 L
.41238 .48336 L
.42076 .45347 L
.43499 .42238 L
.45498 .39178 L
.48032 .36356 L
.51021 .33972 L
.54347 .32226 L
.57857 .31307 L
.61365 .31382 L
.64663 .32576 L
.67525 .34968 L
.69723 .38576 L
.71038 .43345 L
.71273 .49146 L
.70271 .5577 L
.67927 .62933 L
.64201 .70277 L
.59133 .7739 L
.52844 .83817 L
.45549 .89083 L
.37548 .92719 L
.29225 .94292 L
.21031 .93433 L
.13475 .89869 L
.07091 .83453 L
.02415 .74188 L
s
.02415 .74188 m
0 .62463 L
s
0 .5901 m
.00152 .47984 L
.03348 .31944 L
.09751 .14844 L
s
.09751 .14844 m
.18047 0 L
s
1 .791 0 r
.56034 .47161 m
.56298 .48704 L
.56221 .50531 L
.55763 .52569 L
.54901 .54725 L
.53631 .56886 L
.51976 .58925 L
.49983 .60702 L
.47725 .62079 L
.45302 .62918 L
.42837 .63098 L
.40471 .62521 L
.38358 .61121 L
.36658 .58871 L
.35527 .55793 L
.35109 .51959 L
.35523 .47498 L
.36856 .42592 L
.3915 .37475 L
.42396 .32423 L
.46528 .27747 L
.51418 .23775 L
.56874 .20838 L
.62646 .1925 L
.68433 .19284 L
.73891 .21154 L
.78651 .24994 L
.82336 .30836 L
.84584 .38598 L
.85068 .48075 L
.83525 .58928 L
.79778 .70693 L
.73756 .82791 L
.65515 .94544 L
s
.65515 .94544 m
.60263 1 L
s
.919 0 1 r
.47947 .42149 m
.49718 .40486 L
.51741 .39168 L
.5393 .38321 L
.56177 .38058 L
.58354 .38472 L
.60322 .39628 L
.61938 .41557 L
.63056 .44246 L
.63545 .47637 L
.63291 .5162 L
.6221 .56036 L
.60258 .60681 L
.57434 .65307 L
.5379 .69636 L
.49435 .7337 L
.44534 .76209 L
.39307 .77862 L
.34021 .78073 L
.28984 .76639 L
.2453 .73424 L
.21002 .68385 L
.18734 .61579 L
.18028 .53176 L
.19135 .43464 L
.22229 .32849 L
.27392 .21844 L
.34591 .11053 L
.43667 .01147 L
s
.43667 .01147 m
.45138 0 L
s
.025 0 1 r
.56488 .43911 m
.57412 .45179 L
.58017 .46903 L
.58225 .49042 L
.5797 .51522 L
.57206 .54242 L
.55911 .57071 L
.5409 .59854 L
.51783 .62421 L
.49062 .64589 L
.46036 .66175 L
.42842 .67009 L
.3965 .66938 L
.36651 .65848 L
.34048 .63668 L
.3205 .60383 L
.30856 .5604 L
.30645 .5076 L
.31561 .44731 L
.33698 .38213 L
.37091 .31531 L
.41706 .2506 L
.47431 .19215 L
.54071 .14428 L
.61352 .11125 L
.68925 .097 L
.76379 .10489 L
.83251 .13739 L
.89056 .19584 L
.93304 .28022 L
.95536 .38894 L
.95349 .51876 L
.92433 .66474 L
.86598 .82034 L
.77803 .97755 L
s
.77803 .97755 m
.76059 1 L
s
0 .907 1 r
.56407 .5583 m
.54821 .58611 L
.52735 .61248 L
.5021 .63566 L
.47335 .65384 L
.44236 .66526 L
.41069 .66835 L
.38012 .6618 L
.35264 .64474 L
.33028 .61678 L
.31507 .57812 L
.30886 .52966 L
.31322 .47298 L
.3293 .41037 L
.35771 .34476 L
.39838 .27967 L
.45053 .21906 L
.51257 .16713 L
.58212 .12814 L
.65603 .10614 L
.73049 .10469 L
.80111 .12662 L
.86317 .17374 L
.91184 .2466 L
.94243 .34426 L
.95071 .46422 L
.93321 .60228 L
.88755 .75263 L
.8127 .90793 L
s
.8127 .90793 m
.74987 1 L
s
.152 0 1 r
.47104 .51025 m
.47048 .50241 L
.47162 .49337 L
.47459 .48353 L
.47948 .47336 L
.48624 .46343 L
.49472 .45435 L
.50465 .44679 L
.51562 .44139 L
.52712 .43877 L
.53854 .43946 L
.54917 .44384 L
.55829 .45216 L
.56515 .46443 L
.56903 .48047 L
.56932 .4998 L
.56551 .52172 L
.55729 .54526 L
.54455 .56924 L
.52746 .59228 L
.50646 .61288 L
.48228 .6295 L
.45593 .64061 L
.4287 .64481 L
.40211 .64093 L
.3778 .62813 L
.35755 .60599 L
.3431 .57458 L
.33608 .53454 L
.3379 .4871 L
.34963 .43412 L
.37189 .37802 L
.40476 .32172 L
.44768 .26855 L
.49943 .22211 L
.55811 .18606 L
.62114 .16393 L
.68533 .15889 L
.74702 .17353 L
.80219 .20958 L
.84669 .26776 L
.87644 .34753 L
.88769 .44702 L
.87733 .56291 L
.84308 .69048 L
.78381 .82368 L
.69973 .95531 L
s
.69973 .95531 m
.66046 1 L
s
1 0 .988 r
.54152 .48333 m
.54274 .49432 L
.54156 .50712 L
.53775 .52119 L
.53117 .53588 L
.52187 .55038 L
.51002 .56381 L
.496 .57522 L
.48035 .58366 L
.46378 .58824 L
.44717 .58816 L
.4315 .58282 L
.41783 .57183 L
.40724 .55509 L
.40077 .53283 L
.39935 .50566 L
.40375 .47453 L
.41448 .44077 L
.43173 .40605 L
.45535 .37231 L
.48478 .34169 L
.51904 .31644 L
.55672 .29877 L
.59604 .29075 L
.63486 .29414 L
.67081 .31026 L
.70136 .33984 L
.72397 .38291 L
.73623 .4387 L
.73604 .50557 L
.72175 .58102 L
.69233 .66167 L
.64752 .74343 L
.58794 .82155 L
.51519 .8909 L
.43185 .94617 L
.34148 .98219 L
.24852 .99425 L
.15819 .97845 L
.07621 .932 L
.00859 .85361 L
s
.00859 .85361 m
0 .83365 L
s
0 .23918 m
.07115 .06665 L
s
.07115 .06665 m
.11124 0 L
s
.571 1 0 r
.47239 .52638 m
.46835 .52105 L
.46567 .51374 L
.46468 .50465 L
.46566 .49407 L
.46882 .48243 L
.47426 .47029 L
.48196 .45831 L
.49176 .44722 L
.50336 .4378 L
.5163 .43083 L
.52999 .42706 L
.54372 .42714 L
.55666 .43157 L
.56796 .44068 L
.5767 .45453 L
.58203 .47295 L
.58318 .49542 L
.57953 .52116 L
.57064 .54907 L
.55636 .57777 L
.53681 .60565 L
.51247 .63094 L
.48414 .65179 L
.45299 .66636 L
.42049 .67296 L
.38841 .67011 L
.35871 .65675 L
.33348 .63225 L
.31482 .59661 L
.30473 .55046 L
.30493 .49515 L
.31679 .43277 L
.34116 .3661 L
.37825 .29853 L
.42754 .23398 L
.48771 .1767 L
.55662 .13107 L
.63133 .10137 L
.70816 .09149 L
.78281 .10466 L
.85053 .14315 L
.90636 .20805 L
.94539 .29901 L
.96305 .41406 L
.95546 .54955 L
.91969 .70013 L
.85412 .85882 L
s
.85412 .85882 m
.7691 1 L
s
0 1 .359 r
.47264 .47925 m
.47853 .46791 L
.4865 .45697 L
.49633 .44714 L
.50769 .43916 L
.5201 .43374 L
.53297 .43155 L
.54558 .43315 L
.55716 .43895 L
.56686 .44917 L
.57388 .46377 L
.57742 .48248 L
.57681 .50473 L
.57154 .52966 L
.56131 .55613 L
.54605 .58279 L
.52602 .60805 L
.50177 .63024 L
.47419 .64761 L
.44447 .6585 L
.4141 .66138 L
.38482 .65502 L
.35851 .63857 L
.33712 .61166 L
.32261 .57451 L
.31674 .52798 L
.32102 .47358 L
.33655 .41351 L
.36389 .3506 L
.40298 .28822 L
.45307 .23017 L
.51262 .18048 L
.57936 .14323 L
.65024 .1223 L
.7216 .1211 L
.78925 .14234 L
.84866 .18774 L
.89518 .25781 L
.92433 .35165 L
.93206 .46683 L
.91505 .59932 L
.87102 .74353 L
.799 .89243 L
s
.799 .89243 m
.72539 1 L
s
0 1 .302 r
.57019 .54397 m
.557 .57187 L
.53867 .59919 L
.51559 .62424 L
.4885 .64521 L
.45849 .66031 L
.42696 .66787 L
.3956 .66642 L
.36628 .65485 L
.34103 .63251 L
.3219 .59929 L
.31084 .55572 L
.3096 .50303 L
.31954 .44315 L
.34157 .37868 L
.37598 .31286 L
.42236 .24944 L
.47956 .19252 L
.54559 .14636 L
.61769 .11514 L
.69237 .10271 L
.76553 .11232 L
.83259 .14634 L
.88874 .20597 L
.92919 .29108 L
.94943 .39998 L
.94556 .52934 L
.91461 .67418 L
.8548 .82792 L
.76588 .98257 L
s
.76588 .98257 m
.752 1 L
s
0 1 .308 r
.51609 .50983 m
.51312 .51619 L
.50898 .52244 L
.50374 .52818 L
.49759 .533 L
.49076 .53649 L
.48357 .53828 L
.4764 .53802 L
.46969 .53546 L
.46389 .53044 L
.45948 .52294 L
.45689 .51307 L
.45652 .50111 L
.45871 .48749 L
.46364 .4728 L
.4714 .45778 L
.4819 .44328 L
.49488 .43023 L
.50989 .4196 L
.52631 .41235 L
.54334 .40936 L
.56006 .41139 L
.57543 .41896 L
.58834 .43238 L
.5977 .45161 L
.60248 .4763 L
.60179 .50568 L
.59493 .53864 L
.5815 .57368 L
.56142 .60899 L
.53501 .6425 L
.50299 .67198 L
.46653 .69513 L
.42721 .70972 L
.38699 .71375 L
.34816 .70556 L
.31322 .68403 L
.28476 .64866 L
.26535 .59971 L
.25734 .5383 L
.26275 .46642 L
.28302 .38698 L
.31893 .3037 L
.37042 .22104 L
.4365 .14401 L
.51516 .07795 L
.60338 .02827 L
.6972 .0001 L
s
.6972 .0001 m
.70186 0 L
s
.79825 0 m
.88147 .02555 L
.9604 .08507 L
s
.9604 .08507 m
1 .14396 L
s
1 .79489 m
.99275 .81887 L
s
.99275 .81887 m
.90577 1 L
s
.192 1 0 r
.55754 .56163 m
.54134 .5878 L
.52051 .61222 L
.49569 .63319 L
.46782 .64902 L
.43815 .65807 L
.40823 .6589 L
.3798 .65036 L
.35474 .63172 L
.33502 .60274 L
.3225 .56377 L
.31891 .51581 L
.32564 .46053 L
.34366 .40023 L
.3734 .33786 L
.41466 .27686 L
.46649 .22103 L
.52723 .17442 L
.59443 .14101 L
.66495 .12456 L
.73502 .12831 L
.8004 .15473 L
.85657 .20526 L
.89896 .28009 L
.9232 .378 L
.92543 .49622 L
.90258 .63041 L
.85268 .77469 L
.77511 .92179 L
s
.77511 .92179 m
.71748 1 L
s
.886 0 1 r
.45468 .42911 m
.47216 .40562 L
.49362 .38462 L
.51833 .36771 L
.54523 .35643 L
.57302 .35222 L
.60015 .35625 L
.62492 .3694 L
.64554 .39209 L
.66023 .42423 L
.66731 .46517 L
.66536 .51364 L
.65329 .56775 L
.63047 .62503 L
.59684 .68247 L
.55295 .73668 L
.50005 .78399 L
.44011 .82067 L
.37577 .84311 L
.31026 .84807 L
.24734 .83294 L
.19112 .79593 L
.14583 .73635 L
.11564 .65474 L
.10434 .55304 L
.11513 .43463 L
.15032 .30436 L
.21104 .1684 L
.29708 .03412 L
s
.29708 .03412 m
.32715 0 L
s
.231 1 0 r
.4212 .55084 m
.41485 .53246 L
.41274 .5097 L
.41554 .48332 L
.42375 .45443 L
.43761 .42441 L
.45703 .3949 L
.4816 .36773 L
.51054 .34483 L
.5427 .32814 L
.5766 .31947 L
.61044 .32041 L
.6422 .33219 L
.66972 .35554 L
.69077 .39062 L
.70325 .4369 L
.70528 .49309 L
.69532 .55719 L
.6724 .6264 L
.63614 .69729 L
.58694 .76586 L
.526 .8277 L
.45539 .87824 L
.37805 .91294 L
.29767 .92764 L
.21867 .91879 L
.14592 .88379 L
.0846 .82124 L
.03989 .73121 L
.01666 .6154 L
.01917 .47728 L
.05069 .32214 L
.1132 .15694 L
s
.1132 .15694 m
.20158 0 L
s
1 0 .425 r
.50127 .55347 m
.48991 .56078 L
.47765 .56543 L
.46508 .5668 L
.45293 .56437 L
.44196 .55777 L
.43299 .54686 L
.42683 .53169 L
.4242 .51262 L
.42575 .49025 L
.43194 .46549 L
.443 .43949 L
.45894 .41363 L
.47945 .38949 L
.50391 .36872 L
.5314 .35301 L
.56068 .34397 L
.59024 .34304 L
.61835 .35135 L
.64314 .36962 L
.6627 .39811 L
.67516 .43646 L
.67884 .48371 L
.67234 .53822 L
.65469 .59771 L
.62547 .6593 L
.58488 .71958 L
.53382 .7748 L
.47395 .82098 L
.40765 .85417 L
.33804 .87065 L
.26882 .86723 L
.20416 .84145 L
.14854 .79187 L
.10648 .71828 L
.08228 .62189 L
.07977 .50538 L
.10199 .37305 L
.1509 .23066 L
.22715 .08538 L
s
.22715 .08538 m
.28981 0 L
s
.702 1 0 r
.48949 .4878 m
.49265 .4829 L
.49667 .47837 L
.50142 .47453 L
.50672 .47169 L
.51232 .47016 L
.51793 .4702 L
.52322 .47203 L
.52783 .47578 L
.5314 .48146 L
.53357 .48901 L
.53402 .49822 L
.53251 .50876 L
.52885 .52018 L
.52299 .53192 L
.51498 .54331 L
.505 .55365 L
.4934 .56216 L
.48065 .56809 L
.46736 .57076 L
.45424 .56956 L
.4421 .56405 L
.4318 .55399 L
.4242 .53937 L
.4201 .52045 L
.42023 .4978 L
.42512 .47226 L
.43514 .44498 L
.45036 .41734 L
.47056 .39096 L
.49521 .36756 L
.52342 .34895 L
.554 .33687 L
.58543 .3329 L
.61595 .33838 L
.64361 .35422 L
.6664 .38086 L
.68229 .41816 L
.68943 .4653 L
.68623 .52079 L
.67149 .58243 L
.64456 .64736 L
.60543 .71215 L
.5548 .77291 L
.49415 .82549 L
.42579 .86565 L
.35274 .88936 L
.27875 .893 L
.20811 .8737 L
.14546 .82953 L
Mistroke
.09562 .75983 L
.06326 .66536 L
.05263 .54845 L
.06727 .41308 L
.10966 .26487 L
.18098 .11094 L
Mfstroke
.18098 .11094 m
.25423 0 L
s
0 1 .107 r
.56079 .50837 m
.55564 .52869 L
.5465 .55001 L
.53336 .57118 L
.51648 .59093 L
.49637 .60789 L
.47381 .62067 L
.4498 .62795 L
.42558 .62858 L
.40258 .62162 L
.38233 .60648 L
.3664 .58297 L
.35631 .55139 L
.35345 .51253 L
.35895 .46776 L
.3736 .41895 L
.39773 .36847 L
.43117 .31911 L
.47317 .27397 L
.52237 .2363 L
.57678 .20934 L
.63385 .19613 L
.69054 .19927 L
.74342 .22077 L
.78882 .26179 L
.82305 .32247 L
.84256 .40182 L
.84424 .49759 L
.82562 .60625 L
.7851 .72305 L
.72218 .8421 L
.63763 .95659 L
s
.63763 .95659 m
.59359 1 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0333333 0.5 0.0333333 [
[0 .4875 -18.4688 -20 ]
[0 .4875 18.4688 0 ]
[.16667 .4875 -18.4688 -20 ]
[.16667 .4875 18.4688 0 ]
[.33333 .4875 -13.4688 -20 ]
[.33333 .4875 13.4688 0 ]
[.66667 .4875 -7 -20 ]
[.66667 .4875 7 0 ]
[.83333 .4875 -12 -20 ]
[.83333 .4875 12 0 ]
[1 .4875 -12 -20 ]
[1 .4875 12 0 ]
[.4875 0 -36.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .16667 -36.9375 -10 ]
[.4875 .16667 0 10 ]
[.4875 .33333 -26.9375 -10 ]
[.4875 .33333 0 10 ]
[.4875 .66667 -14 -10 ]
[.4875 .66667 0 10 ]
[.4875 .83333 -24 -10 ]
[.4875 .83333 0 10 ]
[.4875 1 -24 -10 ]
[.4875 1 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.16667 .5 m
.16667 .50625 L
s
gsave
.16667 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.33333 .5 m
.33333 .50625 L
s
gsave
.33333 .4875 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.66667 .5 m
.66667 .50625 L
s
gsave
.66667 .4875 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.83333 .5 m
.83333 .50625 L
s
gsave
.83333 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.5 .16667 m
.50625 .16667 L
s
gsave
.4875 .16667 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 .33333 m
.50625 .33333 L
s
gsave
.4875 .33333 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .66667 m
.50625 .66667 L
s
gsave
.4875 .66667 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .83333 m
.50625 .83333 L
s
gsave
.4875 .83333 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.01 w
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 .176 r
.5 Mabswid
.48296 .66313 m
.44948 .6788 L
.41455 .68588 L
.38007 .68283 L
.34815 .66846 L
.32104 .64214 L
.30099 .60384 L
.29013 .55424 L
.29035 .4948 L
.3031 .42776 L
.32929 .3561 L
.36914 .28348 L
.42211 .21411 L
.48678 .15255 L
.56084 .10351 L
.64114 .07159 L
.72371 .06096 L
.80393 .07511 L
.87671 .11647 L
.93672 .18622 L
.97867 .28396 L
.99766 .40761 L
.9895 .55323 L
.95106 .71506 L
.88061 .88561 L
s
.88061 .88561 m
.81172 1 L
s
1 0 0 r
.48296 .66313 m
.44948 .6788 L
s
% Start of user PostScript
-0.5111575 4.8939437 -1.5155983 5.3638799 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41455 .68588 m
.38007 .68283 L
s
% Start of user PostScript
-2.5633938 5.5765042 -3.5978297 5.4848756 MAarrowhead1
% End of user PostScript
1 .473 0 r
.32929 .3561 m
.36914 .28348 L
s
% Start of user PostScript
-5.1214098 -4.3169147 -3.9257085 -6.4954627 MAarrowhead1
% End of user PostScript
1 .788 0 r
.87671 .11647 m
.93672 .18622 L
s
% Start of user PostScript
11.301397 -11.505846 13.101568 -9.4134428 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
4.3590036 21.470013 -0.41442556 25.621479 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-34.408657 13.109747 -35.263098 3.9093321 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
17.265138 -69.454074 30.96363 -72.954196 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
78.923906 23.13107 69.655833 51.101944 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-113.71126 169.22389 -143.10565 155.07126 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-118.3231 -206.06189 -68.258448 -270.11967 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
409.21578 -285.64344 446.75688 -192.9715 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-24.613523 801.8253 -192.46794 897.54005 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1091.5376 98.012278 -1051.5585 -234.88311 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
990.48737 -2262.5181 1412.9356 -2241.0255 MAarrowhead1
% End of user PostScript
.25 1 0 r
.61807 .7729 m
.55391 .8455 L
.478 .90717 L
.39329 .95276 L
.30367 .97743 L
.21382 .9769 L
.12907 .94787 L
.05517 .88826 L
s
.05517 .88826 m
0 .80081 L
s
0 .29697 m
.03765 .17874 L
s
.03765 .17874 m
.12662 0 L
s
1 0 0 r
.61807 .7729 m
.55391 .8455 L
s
% Start of user PostScript
3.5419708 8.1869099 1.6173012 10.365028 MAarrowhead1
% End of user PostScript
1 .158 0 r
.478 .90717 m
.39329 .95276 L
s
% Start of user PostScript
-0.66008554 12.215026 -3.2013375 13.582885 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-16.334119 0.8973532 -15.615703 -4.1576948 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
15.615059 -33.963158 21.915026 -33.404167 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
31.188396 26.29793 23.904959 39.565997 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-68.835516 70.070012 -79.79788 57.324029 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-26.535171 -130.77341 2.53883 -156.05501 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
209.56649 -79.818959 214.76495 -23.780302 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-105.19007 423.01606 -188.61996 444.3227 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-480.65649 -140.95543 -424.19498 -311.31245 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
692.63331 -1030.6105 871.64558 -944.38404 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
720.50317 1255.1853 415.5575 1645.305 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2492.4107 1739.4419 -2720.9933 1174.9628 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
150.36854 -4883.7384 1172.7071 -5466.5721 MAarrowhead1
% End of user PostScript
0 .534 1 r
.3612 .6364 m
.34013 .61007 L
.32579 .57367 L
.31992 .52803 L
.32401 .47464 L
.33914 .41566 L
.36588 .35385 L
.40418 .29252 L
.45329 .23541 L
.51173 .18647 L
.57725 .14971 L
.64688 .12894 L
.71703 .12754 L
.78357 .14817 L
.84207 .19252 L
.88795 .26112 L
.9168 .35309 L
.92464 .46608 L
.9082 .59613 L
.86523 .73776 L
.79475 .88407 L
s
.79475 .88407 m
.7157 1 L
s
1 0 0 r
.3612 .6364 m
.34013 .61007 L
s
% Start of user PostScript
-4.1638503 4.0921155 -4.796063 3.302213 MAarrowhead1
% End of user PostScript
1 .158 0 r
.32579 .57367 m
.31992 .52803 L
s
% Start of user PostScript
-5.2264331 2.2102037 -5.40242 0.84098612 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57725 .14971 m
.64688 .12894 L
s
% Start of user PostScript
2.3174879 -10.508783 4.4065302 -11.131702 MAarrowhead1
% End of user PostScript
1 .788 0 r
.9082 .59613 m
.86523 .73776 L
s
% Start of user PostScript
12.246026 2.8838219 10.95681 7.132811 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-16.661295 26.12575 -21.249058 24.22383 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-19.190557 -29.944777 -11.804268 -39.885459 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
61.527768 -45.680027 67.748854 -32.098982 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
0.10495715 120.04951 -25.236895 135.57978 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-167.33862 22.593902 -162.80683 -27.463806 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
141.30464 -345.44573 206.35646 -345.30614 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
335.31168 230.87482 267.9508 366.82766 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-667.82253 743.66914 -787.65577 628.25613 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-346.40809 -1256.8223 -61.907952 -1528.7263 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2108.4355 -958.06936 2193.4524 -414.27867 MAarrowhead1
% End of user PostScript
0 .366 1 r
.78446 .70992 m
.72435 .82707 L
.64286 .94032 L
s
.64286 .94032 m
.58387 1 L
s
1 0 0 r
.78446 .70992 m
.72435 .82707 L
s
% Start of user PostScript
8.5339202 6.297614 6.7305428 9.8121453 MAarrowhead1
% End of user PostScript
1 .158 0 r
.64286 .94032 m
0 0 rlineto s
.64286 .94032 m
.58387 1 L
s
% Start of user PostScript
4.2856622 13.209469 1.2596675 16.271373 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-22.825905 11.416915 -23.966812 5.6647221 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
7.6640064 -45.567233 16.854867 -49.023259 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
55.56251 7.521333 50.88717 26.081656 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-67.845941 117.50057 -88.873352 111.19061 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-93.628189 -119.86566 -63.127409 -164.97881 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
263.64585 -217.97793 294.99671 -162.65417 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
31.429588 510.26595 -78.006974 586.0852 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-743.25719 160.775 -735.88028 -53.763415 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
543.45647 -1523.0829 834.69407 -1547.654 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1560.5486 851.69182 1294.0717 1455.658 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2797.6922 3419.5281 -3363.8844 2975.2863 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1874.8044 -5208.4979 -671.37379 -6474.3626 MAarrowhead1
% End of user PostScript
0 .092 1 r
.17703 .54011 m
.18652 .44304 L
.21596 .33645 L
.26626 .22542 L
.3372 .11598 L
.4273 .01487 L
s
.4273 .01487 m
.44577 0 L
s
1 0 0 r
.17703 .54011 m
.18652 .44304 L
s
% Start of user PostScript
-9.6891134 1.2031654 -9.4045467 -1.7087986 MAarrowhead1
% End of user PostScript
1 .158 0 r
.21596 .33645 m
.26626 .22542 L
s
% Start of user PostScript
-8.5212358 -4.9065792 -7.0121363 -8.237528 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
15.633148 -18.719738 18.71504 -16.187266 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
9.9354717 29.176765 3.2256374 36.088427 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-50.901985 26.198236 -53.602057 13.466112 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
16.062198 -101.47774 36.586026 -109.49257 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
124.77526 14.648998 114.74902 56.040078 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-149.23746 263.45017 -196.54353 250.21457 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-212.90028 -262.73275 -145.61915 -364.04636 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
585.81043 -493.82618 657.47318 -372.1238 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
83.052186 1132.022 -160.47278 1304.4451 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1662.6707 384.52292 -1651.4168 -92.19054 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1181.0734 -3402.5105 1833.5208 -3467.8443 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3520.2677 1833.7187 2937.6225 3184.8411 MAarrowhead1
% End of user PostScript
0 .975 1 r
.75182 .54487 m
.72835 .63038 L
.68814 .7195 L
.63136 .8074 L
.55919 .88866 L
.47387 .95757 L
s
.47387 .95757 m
.39442 1 L
s
.08084 1 m
0 .93406 L
s
0 .10223 m
.05119 0 L
s
1 0 0 r
.75182 .54487 m
.72835 .63038 L
s
% Start of user PostScript
7.5544659 1.3461673 6.8505087 3.9114569 MAarrowhead1
% End of user PostScript
1 .158 0 r
.68814 .7195 m
.63136 .8074 L
s
% Start of user PostScript
5.6442799 6.5850451 3.9408384 9.2219081 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-15.000793 13.021122 -16.915158 9.9532064 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-2.6501477 -28.917548 3.6000843 -33.489435 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
43.018749 -10.927122 42.934032 1.2807387 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-29.195533 87.851793 -46.113744 89.950053 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-92.233917 -44.63089 -77.688656 -79.590695 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
157.40341 -201.04247 191.08472 -177.16566 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
117.5343 291.42706 49.49747 366.25481 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-527.31593 299.90541 -561.30334 171.68762 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
126.68559 -1045.9393 340.38657 -1140.8536 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1326.2011 69.771459 1237.77 498.61316 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1466.5034 2784.1223 -1972.5788 2679.2708 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2364.1382 -2545.3832 -1695.5528 -3622.3779 MAarrowhead1
% End of user PostScript
1 .341 0 r
.53289 .62783 m
.50409 .65475 L
.4712 .67602 L
.43565 .68962 L
.39921 .69373 L
.36393 .68683 L
.33206 .66787 L
.30596 .63638 L
.28796 .59256 L
.28021 .53738 L
.28454 .47263 L
.30229 .40089 L
.3342 .32551 L
.38024 .25049 L
.43955 .18037 L
.51037 .11997 L
.58999 .0742 L
.67485 .04772 L
.76059 .04469 L
.8422 .06841 L
.91426 .12103 L
.97122 .20325 L
s
.97122 .20325 m
1 .29081 L
s
1 .60945 m
.94949 .78107 L
.86519 .95964 L
s
.86519 .95964 m
.83813 1 L
s
1 0 0 r
.53289 .62783 m
.50409 .65475 L
s
% Start of user PostScript
0.98684018 3.8349694 0.12263812 4.6424245 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4712 .67602 m
.43565 .68962 L
s
% Start of user PostScript
-0.86394483 5.2805329 -1.9303671 5.6886917 MAarrowhead1
% End of user PostScript
1 .473 0 r
.28454 .47263 m
.30229 .40089 L
s
% Start of user PostScript
-6.4638104 -0.82105124 -5.9312923 -2.9732859 MAarrowhead1
% End of user PostScript
1 .788 0 r
.76059 .04469 m
.8422 .06841 L
s
% Start of user PostScript
7.8176585 -13.659262 10.265916 -12.947686 MAarrowhead1
% End of user PostScript
.897 1 0 r
.86519 .95964 m
0 0 rlineto s
.86519 .95964 m
.83813 1 L
s
% Start of user PostScript
10.955716 13.789337 7.4366418 19.037632 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-30.520541 25.462175 -34.198006 19.087179 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3.9564313 -59.027571 8.7210125 -67.899853 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
86.31108 -19.26847 85.580723 5.5676543 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-62.275552 176.75717 -96.118442 179.85999 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-181.92473 -97.182113 -151.30399 -167.31908 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
323.21417 -398.24727 389.2996 -347.33672 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
221.04204 601.13666 81.889474 748.71185 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1065.6171 573.90957 -1127.515 310.65282 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
300.79425 -2119.66 731.42372 -2298.062 MAarrowhead1
% End of user PostScript
1 .505 0 r
.44746 .20875 m
.51184 .15452 L
.5841 .11367 L
.66096 .09043 L
.73845 .08851 L
.81204 .11087 L
.87682 .15943 L
.92776 .23475 L
.95996 .33593 L
.96903 .46036 L
.95133 .60372 L
.90435 .75998 L
.82701 .92155 L
s
.82701 .92155 m
.7738 1 L
s
1 0 0 r
.44746 .20875 m
.51184 .15452 L
s
% Start of user PostScript
-1.5763262 -8.7374367 0.35528585 -10.364359 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5841 .11367 m
.66096 .09043 L
s
% Start of user PostScript
2.522901 -11.589808 4.8286737 -12.287248 MAarrowhead1
% End of user PostScript
1 .473 0 r
.95133 .60372 m
.90435 .75998 L
s
% Start of user PostScript
13.539816 3.1115565 12.130632 7.7995181 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-18.314377 28.871589 -23.389767 26.800811 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-21.308722 -32.887156 -13.183734 -43.878213 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
67.813552 -50.654362 74.73511 -35.725559 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
0.54414636 132.25665 -27.398388 149.50176 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-184.79676 25.786738 -179.96854 -29.385529 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
154.88263 -381.32973 226.75302 -381.52398 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
371.27911 252.55826 297.34307 402.69639 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-735.1644 822.86499 -867.96899 696.35688 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-387.19785 -1382.7739 -73.849124 -1683.8495 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2326.0031 -1066.7748 2421.8702 -468.14151 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-915.58417 4661.3975 -1848.4702 4973.2854 MAarrowhead1
% End of user PostScript
1 .089 0 r
.52968 .77407 m
.47019 .81885 L
.40455 .85057 L
.33587 .86561 L
.26783 .86084 L
.20458 .83393 L
.15053 .78351 L
.11011 .70948 L
.08757 .61309 L
.08663 .49713 L
.11021 .3659 L
.16017 .22519 L
.23706 .08214 L
s
.23706 .08214 m
.29861 0 L
s
1 0 0 r
.52968 .77407 m
.47019 .81885 L
s
% Start of user PostScript
0.89031963 8.2221507 -0.89441705 9.5653861 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40455 .85057 m
.33587 .86561 L
s
% Start of user PostScript
-2.8634487 10.517025 -4.9238877 10.968174 MAarrowhead1
% End of user PostScript
1 .473 0 r
.11021 .3659 m
.16017 .22519 L
s
% Start of user PostScript
-11.693799 -4.0230797 -10.194838 -8.2443159 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
17.678115 -25.184196 22.010656 -22.838838 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
16.829089 32.244925 9.0886046 41.734961 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-62.293668 41.174398 -67.521291 26.769266 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
6.9622296 -122.48962 32.426287 -136.09762 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
163.44081 -8.2816844 156.1051 42.38964 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-157.21719 339.96867 -220.22873 334.08462 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-311.25225 -265.14516 -237.99589 -397.90544 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
690.71998 -699.78383 800.01881 -571.45709 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
261.63362 1312.8462 -29.978649 1565.1451 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2098.9472 791.37336 -2149.3108 229.06782 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1064.7847 -4238.2893 1900.0831 -4448.3263 MAarrowhead1
% End of user PostScript
1 .572 0 r
.52455 .77672 m
.46479 .82021 L
.39917 .8504 L
.33082 .86371 L
.26346 .8571 L
.20124 .82832 L
.14855 .77613 L
.10981 .70051 L
.08918 .60288 L
.0903 .4861 L
.116 .35461 L
.16803 .21428 L
.24678 .0723 L
s
.24678 .0723 m
.30251 0 L
s
1 0 0 r
.52455 .77672 m
.46479 .82021 L
s
% Start of user PostScript
0.73657094 8.3015266 -1.0563729 9.6063364 MAarrowhead1
% End of user PostScript
1 .158 0 r
.39917 .8504 m
.33082 .86371 L
s
% Start of user PostScript
-3.025046 10.511991 -5.0754415 10.911333 MAarrowhead1
% End of user PostScript
1 .473 0 r
.116 .35461 m
.16803 .21428 L
s
% Start of user PostScript
-11.519937 -4.3616779 -9.9591786 -8.5715838 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
17.970272 -24.884015 22.223223 -22.407419 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
16.10928 32.911339 8.2681559 42.259532 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-62.478782 39.79455 -67.404905 25.152694 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
9.0755039 -123.13359 34.55802 -136.15572 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
162.1559 -3.9859859 153.98501 46.833102 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-161.87447 338.08446 -224.22951 330.48282 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-303.81886 -275.22779 -228.84772 -406.93644 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
697.09017 -686.13081 803.15354 -554.025 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
236.03755 1328.7014 -57.498355 1574.9442 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2094.6056 740.84503 -2134.5467 173.39127 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1130.6885 -4238.6348 1962.3971 -4427.8533 MAarrowhead1
% End of user PostScript
0 .862 1 r
.53013 .46657 m
.53551 .47179 L
.53949 .47939 L
.54165 .48923 L
.54161 .50103 L
.53908 .51433 L
.53388 .52855 L
.52597 .54296 L
.51546 .55673 L
.50263 .56895 L
.48793 .57868 L
.472 .58502 L
.45561 .58713 L
.43969 .58433 L
.42525 .57612 L
.41334 .56228 L
.40501 .54288 L
.40124 .51835 L
.40285 .48945 L
.41048 .45734 L
.42446 .42349 L
.4448 .3897 L
.47115 .35799 L
.50272 .33052 L
.53834 .30951 L
.57641 .29705 L
.615 .29504 L
.65186 .30499 L
.68458 .32789 L
.71064 .36411 L
.72761 .41325 L
.73327 .4741 L
.72577 .54461 L
.70381 .62184 L
.66677 .70209 L
.61485 .78097 L
.54917 .8536 L
.47181 .91481 L
.38583 .95944 L
.29522 .9826 L
.20475 .98007 L
.11984 .94858 L
.0463 .88613 L
s
.0463 .88613 m
0 .80898 L
s
0 .2803 m
.03917 .16205 L
s
.03917 .16205 m
.12206 0 L
s
1 0 0 r
.53013 .46657 m
.53551 .47179 L
s
% Start of user PostScript
0.90396328 -1.0030498 1.0654139 -0.8463649 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53949 .47939 m
.54165 .48923 L
s
% Start of user PostScript
1.1848238 -0.61834341 1.2494742 -0.32308534 MAarrowhead1
% End of user PostScript
1 .473 0 r
.48793 .57868 m
.472 .58502 L
s
% Start of user PostScript
-0.36197914 2.3604629 -0.84002873 2.5505805 MAarrowhead1
% End of user PostScript
1 .788 0 r
.40285 .48945 m
.41048 .45734 L
s
% Start of user PostScript
-2.9144043 -0.31642279 -2.685651 -1.2798813 MAarrowhead1
% End of user PostScript
.897 1 0 r
.615 .29504 m
.65186 .30499 L
s
% Start of user PostScript
3.4499213 -6.148669 4.5558401 -5.8502528 MAarrowhead1
% End of user PostScript
.581 1 0 r
.66677 .70209 m
.61485 .78097 L
s
% Start of user PostScript
5.0030963 6.0626892 3.445531 8.4291427 MAarrowhead1
% End of user PostScript
.266 1 0 r
.0463 .88613 m
0 0 rlineto s
.0463 .88613 m
0 .80898 L
s
% Start of user PostScript
-13.61112 11.584002 -15.299419 8.7704996 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2.083072 -26.28165 3.5793469 -30.333753 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
38.761406 -9.2509349 38.559545 1.8255575 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-27.134746 79.26841 -42.355996 80.911034 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-82.404948 -41.924597 -68.977104 -73.423496 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
143.48505 -180.00029 173.49902 -157.8133 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
102.59312 266.26621 40.69678 333.11605 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-476.83973 263.99614 -506.05392 147.1221 MAarrowhead1
% End of user PostScript
0 1 .034 r
.3839 .62864 m
.36321 .60849 L
.34791 .57919 L
.33965 .54127 L
.33985 .49583 L
.34963 .4446 L
.36968 .38985 L
.40017 .33437 L
.44068 .28139 L
.49011 .23439 L
.54672 .19697 L
.60807 .17264 L
.67115 .1646 L
.73243 .17548 L
.788 .20717 L
.83379 .26054 L
.86578 .3353 L
.88021 .42983 L
.87389 .54114 L
.84443 .66481 L
.7905 .79512 L
.71208 .92518 L
s
.71208 .92518 m
.64983 1 L
s
1 0 0 r
.3839 .62864 m
.36321 .60849 L
s
% Start of user PostScript
-3.4829128 3.8591644 -4.1038063 3.2547547 MAarrowhead1
% End of user PostScript
1 .158 0 r
.34791 .57919 m
.33965 .54127 L
s
% Start of user PostScript
-4.562634 2.3757665 -4.8104542 1.2380599 MAarrowhead1
% End of user PostScript
1 .473 0 r
.54672 .19697 m
.60807 .17264 L
s
% Start of user PostScript
1.4014803 -9.0909064 3.2421938 -9.8207742 MAarrowhead1
% End of user PostScript
1 .788 0 r
.87389 .54114 m
.84443 .66481 L
s
% Start of user PostScript
11.216693 1.2340704 10.332858 4.9442394 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-13.30038 23.667464 -17.55612 22.512171 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-19.236305 -23.380262 -13.23289 -32.488021 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
52.430563 -44.552135 58.919206 -33.705391 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
7.9267141 101.25096 -13.882482 116.83068 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-149.22806 35.433953 -148.41265 -7.2329954 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
104.71905 -305.21033 163.31264 -311.45868 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
317.03818 161.92763 265.24395 283.19533 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-552.91086 692.63614 -668.36019 607.0129 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-393.96561 -1026.224 -155.48934 -1283.4155 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1836.313 -1014.4631 1948.3553 -564.09794 MAarrowhead1
% End of user PostScript
0 1 .692 r
.71158 .80661 m
.63511 .91316 L
s
.63511 .91316 m
.54954 1 L
s
1 0 0 r
.71158 .80661 m
.63511 .91316 L
s
% Start of user PostScript
6.3473072 9.1981717 4.0533025 12.394917 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
1.2121298 15.278114 -2.079628 17.634071 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-22.534109 5.3802696 -22.41722 -1.0588126 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
15.771837 -46.082619 24.62086 -47.038482 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
47.909061 24.366719 40.103917 42.678742 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-83.40951 104.64817 -100.85949 91.75216 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-59.655182 -154.78139 -23.673675 -193.64695 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
277.20649 -153.49831 294.1955 -85.558064 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-72.392663 550.61871 -184.57542 598.78008 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-692.27189 -48.642397 -643.53179 -274.07385 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
782.5345 -1455.5791 1046.2385 -1395.7514 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1219.6655 1363.8304 864.04879 1925.9947 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3159.1428 2802.6988 -3575.0671 2164.407 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-642.35443 -6078.7183 676.23737 -7066.7624 MAarrowhead1
% End of user PostScript
.865 1 0 r
.33306 .77036 m
.28528 .75241 L
.24395 .71702 L
.21238 .66398 L
.19376 .59409 L
.19092 .50929 L
.20613 .41264 L
.2409 .30834 L
.29575 .20158 L
.37008 .09839 L
.46206 .00542 L
s
.46206 .00542 m
.46968 0 L
s
1 0 0 r
.33306 .77036 m
.28528 .75241 L
s
% Start of user PostScript
-5.0080506 8.1107042 -6.441454 7.5723082 MAarrowhead1
% End of user PostScript
1 .158 0 r
.24395 .71702 m
.21238 .66398 L
s
% Start of user PostScript
-7.6815669 6.5106393 -8.6286967 4.9193389 MAarrowhead1
% End of user PostScript
1 .473 0 r
.46206 .00542 m
0 0 rlineto s
.46206 .00542 m
.46968 0 L
s
% Start of user PostScript
-1.1381239 -14.837317 2.0564923 -17.112944 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
21.843662 -5.1434783 21.715173 1.1075967 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-15.3888 44.684053 -23.963948 45.580635 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-46.356332 -23.827018 -38.751386 -41.577826 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
81.054499 -101.30313 97.929409 -88.720838 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
57.427069 150.484 22.476343 188.08946 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-268.91964 148.0417 -285.2176 82.020425 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
71.437561 -534.32019 180.23365 -580.67996 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
670.55403 49.684381 622.80103 268.37512 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-761.56216 1410.3935 -1016.8954 1351.372 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1178.3755 -1328.43 -832.52471 -1872.9533 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3067.1975 -2709.8248 3468.6311 -2088.6512 MAarrowhead1
% End of user PostScript
.239 0 1 r
.64916 .73703 m
.59084 .81485 L
.51935 .88425 L
.43717 .93998 L
.34781 .97689 L
.25562 .99027 L
.16573 .9762 L
.08381 .93185 L
.0158 .85585 L
s
.0158 .85585 m
0 .82065 L
s
0 .25305 m
.06937 .08074 L
s
.06937 .08074 m
.11703 0 L
s
1 0 0 r
.64916 .73703 m
.59084 .81485 L
s
% Start of user PostScript
4.4747369 7.11105 2.7252834 9.4455725 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51935 .88425 m
.43717 .93998 L
s
% Start of user PostScript
0.58036642 11.527632 -1.884754 13.199446 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-16.657347 3.3611824 -16.440949 -1.4781369 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
12.516653 -34.179343 19.034445 -34.62912 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
34.688669 19.783469 28.585551 33.318672 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-63.374855 76.169735 -75.92803 65.939838 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-40.670319 -118.22641 -13.458728 -146.3631 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
206.68302 -107.01609 217.7816 -55.401098 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-64.326968 411.92206 -147.68655 444.7326 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-507.39384 -57.639009 -467.02998 -225.70504 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
604.17912 -1070.9502 796.62096 -1017.9331 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
868.0264 1062.8404 595.47556 1474.8319 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2376.7908 2011.8452 -2669.289 1519.1321 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-348.47041 -4591.3789 639.89059 -5294.3895 MAarrowhead1
% End of user PostScript
1 0 .416 r
.80068 .66829 m
.74846 .7852 L
.67446 .90067 L
s
.67446 .90067 m
.58692 1 L
s
1 0 0 r
.80068 .66829 m
.74846 .7852 L
s
% Start of user PostScript
9.0205457 5.0485533 7.453733 8.5558957 MAarrowhead1
% End of user PostScript
1 .158 0 r
.67446 .90067 m
0 0 rlineto s
.67446 .90067 m
.58692 1 L
s
% Start of user PostScript
5.2337868 12.019991 2.4061332 15.228495 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-22.147895 13.176344 -23.697805 7.8659111 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
4.5130532 -43.822602 13.510835 -48.050911 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
56.385598 1.2625266 52.985412 19.275473 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-59.977201 118.05392 -81.558715 114.3064 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-102.52354 -103.32067 -75.020146 -149.11405 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
249.783 -233.48129 285.17624 -184.54739 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
67.339404 478.40982 -37.369791 561.48477 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-735.95838 229.87185 -743.56976 26.563651 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
439.66773 -1494.9538 730.73704 -1548.7501 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1628.527 640.06624 1402.9349 1238.2338 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2573.0836 3522.1276 -3173.4121 3162.2346 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2249.6364 -4720.0523 -1128.4585 -6041.5246 MAarrowhead1
% End of user PostScript
0 .188 1 r
.52253 .25439 m
.57311 .22982 L
.62607 .21809 L
.67856 .22161 L
.72739 .2422 L
.76916 .2809 L
.80044 .33783 L
.81797 .412 L
.81887 .5013 L
.80087 .60242 L
.76253 .71088 L
.70344 .82122 L
.62434 .92709 L
s
.62434 .92709 m
.54946 1 L
s
1 0 0 r
.52253 .25439 m
.57311 .22982 L
s
% Start of user PostScript
0.67595362 -7.368196 2.1934177 -8.105361 MAarrowhead1
% End of user PostScript
1 .158 0 r
.62607 .21809 m
.67856 .22161 L
s
% Start of user PostScript
3.7821219 -8.4573026 5.3568069 -8.3517404 MAarrowhead1
% End of user PostScript
1 .473 0 r
.76253 .71088 m
.70344 .82122 L
s
% Start of user PostScript
7.8760484 6.326549 6.1031268 9.6365532 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-16.945021 17.63626 -19.725339 14.548624 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-7.0716576 -32.119882 0.1001491 -38.50487 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
52.044871 -20.762783 53.534292 -6.9671991 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-24.81388 104.87887 -45.569113 110.56223 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-120.4769 -32.301884 -106.96398 -74.611023 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
169.39004 -257.75879 214.37494 -237.40881 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
184.16447 305.90263 109.36953 403.6921 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-616.27663 441.82815 -675.27216 303.76874 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
20.83817 -1205.3729 274.06968 -1354.3762 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1657.5818 -181.11334 1603.6819 320.24703 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1459.1709 3429.7883 -2101.9193 3410.6062 MAarrowhead1
% End of user PostScript
1 0 .964 r
.52897 .49721 m
.52795 .50603 L
.52513 .51565 L
.52043 .52563 L
.51388 .5354 L
.50564 .54437 L
.49596 .55188 L
.48524 .5573 L
.47397 .56002 L
.46275 .55953 L
.45225 .55542 L
.44321 .54746 L
.43635 .53561 L
.43237 .52005 L
.4319 .50123 L
.43542 .47984 L
.44327 .45679 L
.45554 .43325 L
.4721 .41056 L
.49253 .39018 L
.51612 .37364 L
.54189 .36243 L
.56859 .35793 L
.59476 .36131 L
.61877 .37341 L
.63888 .39466 L
.6534 .42503 L
.66069 .46391 L
.65938 .51013 L
.64838 .56189 L
.62707 .61685 L
.59535 .67216 L
.55372 .72457 L
.50334 .77057 L
.44605 .80655 L
.38435 .82904 L
.32133 .83491 L
.26058 .82158 L
.20602 .7873 L
.16172 .73133 L
.1317 .6541 L
.11965 .5574 L
.12868 .4444 L
.16105 .31968 L
.21794 .1891 L
.29923 .05967 L
s
.29923 .05967 m
.35082 0 L
s
1 0 0 r
.52897 .49721 m
.52795 .50603 L
s
% Start of user PostScript
0.8692079 -0.083603938 0.83854437 0.18076856 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52513 .51565 m
.52043 .52563 L
s
% Start of user PostScript
0.75379015 0.46956144 0.6127976 0.76880362 MAarrowhead1
% End of user PostScript
1 .473 0 r
.45225 .55542 m
.44321 .54746 L
s
% Start of user PostScript
-1.4323972 1.6625726 -1.7036691 1.4237386 MAarrowhead1
% End of user PostScript
1 .788 0 r
.4721 .41056 m
.49253 .39018 L
s
% Start of user PostScript
-0.83702222 -2.6831501 -0.22423392 -3.2944904 MAarrowhead1
% End of user PostScript
.897 1 0 r
.6534 .42503 m
.66069 .46391 L
s
% Start of user PostScript
4.6018876 -2.2490516 4.8207834 -1.0825611 MAarrowhead1
% End of user PostScript
.581 1 0 r
.44605 .80655 m
.38435 .82904 L
s
% Start of user PostScript
-1.618525 9.1965443 -3.4694703 9.871339 MAarrowhead1
% End of user PostScript
.266 1 0 r
.12868 .4444 m
.16105 .31968 L
s
% Start of user PostScript
-11.139748 -1.6679002 -10.168631 -5.4097132 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
13.825263 -23.587542 18.034965 -22.25577 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
18.583027 24.491909 12.381311 33.536362 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-53.304586 43.394288 -59.500294 32.12139 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-5.4113856 -103.29305 16.688991 -118.3401 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
149.47561 -30.558733 147.61754 12.815918 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-111.76588 306.63622 -170.26876 310.83783 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-311.74857 -176.38634 -257.19686 -297.84597 MAarrowhead1
% End of user PostScript
0 .676 1 r
.83012 .31291 m
.85125 .39326 L
.85426 .49068 L
.83654 .60162 L
.79639 .72128 L
.73322 .84367 L
.64773 .96186 L
s
.64773 .96186 m
.60984 1 L
s
1 0 0 r
.83012 .31291 m
.85125 .39326 L
s
% Start of user PostScript
9.9034795 -5.6128187 10.537641 -3.2022297 MAarrowhead1
% End of user PostScript
1 .158 0 r
.85426 .49068 m
.83654 .60162 L
s
% Start of user PostScript
10.627811 -0.27970448 10.096181 3.048631 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-10.583651 22.154851 -14.671147 21.664331 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-19.934258 -17.985531 -15.030593 -26.617842 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
45.636286 -45.005062 52.598122 -36.367647 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
15.572779 86.969798 -3.6473717 103.12649 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-137.22886 48.748834 -139.89037 11.599272 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
73.782015 -277.65619 128.27979 -290.14134 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
310.59765 102.41969 271.7203 213.96671 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-463.36578 668.08757 -578.61086 607.64264 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-452.22505 -843.69339 -249.03333 -1095.7655 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1642.1992 -1102.1775 1783.5415 -724.58578 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-160.23607 3225.98 -832.16219 3591.6919 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-4328.3799 266.43599 -4144.0526 -1069.4038 MAarrowhead1
% End of user PostScript
.625 0 1 r
.24376 .73463 m
.20849 .6838 L
.1859 .61525 L
.17903 .53069 L
.19039 .43304 L
.22173 .32638 L
.27384 .21588 L
.34637 .10761 L
.43772 .00832 L
s
.43772 .00832 m
.44844 0 L
s
1 0 0 r
.24376 .73463 m
.20849 .6838 L
s
% Start of user PostScript
-7.6871029 7.0389632 -8.7454259 5.5141109 MAarrowhead1
% End of user PostScript
1 .158 0 r
.1859 .61525 m
.17903 .53069 L
s
% Start of user PostScript
-9.423116 3.4573844 -9.6290775 0.92062145 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
4.9132535 -19.045372 8.6596481 -19.948529 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
21.457442 6.7166832 18.847373 14.376506 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-31.511357 46.087513 -39.48666 42.061354 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-31.664724 -57.253787 -17.821691 -74.668698 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
112.44917 -76.834799 122.41531 -51.155316 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-9.07278 220.64403 -55.134677 246.25453 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-297.9918 22.165482 -286.10829 -69.308358 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
276.80167 -618.52749 391.95592 -610.74544 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
575.81596 463.10159 446.07798 705.16866 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1239.6391 1289.4887 -1442.8859 1063.5151 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-516.33631 -2349.9135 8.3008852 -2816.7173 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3806.5753 -1516.8653 3915.1468 -507.62943 MAarrowhead1
% End of user PostScript
1 .012 0 r
.16712 .52583 m
.18017 .42378 L
.21403 .31269 L
.26946 .19799 L
.34601 .08602 L
s
.34601 .08602 m
.42675 0 L
s
1 0 0 r
.16712 .52583 m
.18017 .42378 L
s
% Start of user PostScript
-9.9863563 0.77479954 -9.5948647 -2.2865598 MAarrowhead1
% End of user PostScript
1 .158 0 r
.21403 .31269 m
.26946 .19799 L
s
% Start of user PostScript
-8.5790421 -5.6191718 -6.9163397 -9.060408 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
16.685482 -18.973337 19.76241 -16.140464 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
9.2021955 31.32837 2.079026 38.285646 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-53.142081 25.067056 -55.478923 11.479762 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
19.950858 -106.36928 41.290909 -113.78453 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
127.57417 21.862739 115.86994 65.071081 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-162.17617 270.64301 -210.28117 254.23993 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-209.56069 -288.4278 -137.04231 -392.00114 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
618.15576 -491.63705 687.55885 -359.41252 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
46.605939 1200.0161 -209.24337 1369.6787 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1719.7562 321.0405 -1691.932 -181.93937 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1328.4463 -3533.6233 2000.374 -3569.2286 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3550.746 2117.2201 2906.5749 3514.5878 MAarrowhead1
% End of user PostScript
0 .557 1 r
.69268 .68525 m
.64288 .77017 L
.57792 .85027 L
.49966 .92016 L
.41101 .97429 L
s
.41101 .97429 m
.33699 1 L
s
.15901 1 m
.12605 .99201 L
.04299 .93714 L
s
.04299 .93714 m
0 .8804 L
s
0 .17269 m
.07335 .00879 L
s
.07335 .00879 m
.07899 0 L
s
1 0 0 r
.69268 .68525 m
.64288 .77017 L
s
% Start of user PostScript
5.7805163 5.5576378 4.2863338 8.1050023 MAarrowhead1
% End of user PostScript
1 .158 0 r
.57792 .85027 m
.49966 .92016 L
s
% Start of user PostScript
2.337581 10.50819 -0.010050357 12.604687 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-17.051589 6.8429091 -17.548087 2.3282364 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
8.073628 -34.354202 14.875253 -36.233078 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
39.519699 10.467107 35.114273 24.32903 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-55.385132 84.527887 -70.146309 77.906236 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-60.562752 -99.973984 -36.097713 -132.05183 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
201.79626 -145.1798 221.22073 -100.03831 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6.1188969 394.5982 -89.057368 443.59934 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-543.36173 60.758907 -525.98634 -103.40963 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
476.38662 -1124.039 687.13496 -1118.3302 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1073.9261 785.92134 848.37478 1227.3474 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2203.6324 2390.4644 -2585.6604 2001.4434 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1054.6781 -4158.9953 -118.32132 -5029.7539 MAarrowhead1
% End of user PostScript
1 0 .473 r
.34811 .50671 m
.35514 .45949 L
.37174 .4084 L
.3982 .35597 L
.43425 .30515 L
.47903 .25919 L
.53102 .22146 L
.58808 .19532 L
.64748 .18388 L
.706 .18976 L
.76003 .21492 L
.80574 .26044 L
.83931 .3263 L
.85711 .4113 L
.85598 .5129 L
.83348 .62725 L
.78809 .74925 L
.71947 .87262 L
.62863 .9902 L
s
.62863 .9902 m
.61822 1 L
s
1 0 0 r
.34811 .50671 m
.35514 .45949 L
s
% Start of user PostScript
-4.5566561 0.20122151 -4.3458786 -1.215302 MAarrowhead1
% End of user PostScript
1 .158 0 r
.37174 .4084 m
.3982 .35597 L
s
% Start of user PostScript
-3.8478632 -2.7479571 -3.0540645 -4.3208041 MAarrowhead1
% End of user PostScript
1 .473 0 r
.76003 .21492 m
.80574 .26044 L
s
% Start of user PostScript
7.8008768 -8.5523309 9.1722675 -7.1868199 MAarrowhead1
% End of user PostScript
1 .788 0 r
.62863 .9902 m
0 0 rlineto s
.62863 .9902 m
.61822 1 L
s
% Start of user PostScript
3.8590338 14.706091 0.54089291 17.826135 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-24.470219 10.804406 -25.390473 4.4526046 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
10.215004 -49.117213 20.013298 -52.223934 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
57.873749 12.190045 52.084643 32.084714 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-76.735876 123.20009 -98.472076 114.81159 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-92.388763 -137.37906 -58.260727 -184.36063 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
286.76249 -218.65225 316.9709 -156.0975 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
8.5008408 558.44285 -109.82898 633.22266 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-786.69406 121.84413 -768.68684 -111.47062 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
642.53643 -1621.1008 948.95381 -1626.9592 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1594.7879 1040.4526 1286.5708 1679.6248 MAarrowhead1
% End of user PostScript
0 1 .69 r
.7825 .30838 m
.80723 .37308 L
.81695 .45396 L
.80905 .54835 L
.78167 .65242 L
.73385 .76127 L
.66571 .86902 L
.57862 .96912 L
s
.57862 .96912 m
.54126 1 L
s
1 0 0 r
.7825 .30838 m
.80723 .37308 L
s
% Start of user PostScript
8.4748622 -5.7484602 9.2170479 -3.8076378 MAarrowhead1
% End of user PostScript
1 .158 0 r
.81695 .45396 m
.80905 .54835 L
s
% Start of user PostScript
9.5083817 -1.3813235 9.2714592 1.4504281 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-7.893266 19.610468 -11.593302 19.643191 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-19.167746 -12.838146 -15.393018 -20.563332 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
37.674494 -42.444061 44.538331 -35.996512 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
20.225879 70.81082 4.1574179 86.3546 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-119.52358 55.459882 -124.58544 24.781593 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
46.152644 -239.40994 94.114238 -255.70455 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
285.84772 51.815938 259.02563 148.9955 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-367.31974 606.94076 -474.99794 569.00771 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-466.21503 -654.40008 -302.19546 -886.4653 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1392.9563 -1096.1296 1546.8744 -796.65995 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
88.684082 2706.3101 -487.40178 3083.739 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3861.4859 689.7036 -3792.4361 -443.69261 MAarrowhead1
% End of user PostScript
.085 0 1 r
.77091 .76376 m
.70019 .88357 L
.60811 .99646 L
s
.60811 .99646 m
.60413 1 L
s
1 0 0 r
.77091 .76376 m
.70019 .88357 L
s
% Start of user PostScript
8.1274297 7.9128782 6.0057481 11.507239 MAarrowhead1
% End of user PostScript
1 .158 0 r
.60811 .99646 m
0 0 rlineto s
.60811 .99646 m
.60413 1 L
s
% Start of user PostScript
3.2434057 14.893932 -0.080163724 17.843335 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-24.096244 9.5530504 -24.773188 3.1581025 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
11.572024 -48.569012 21.179203 -51.175374 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
55.708967 15.127732 49.420184 34.71632 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-78.592955 119.22426 -99.386859 109.73463 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-84.932948 -142.00046 -50.243952 -187.21832 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
285.50197 -203.93453 312.67432 -139.87893 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-10.69961 558.55205 -127.98537 627.26767 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-767.02158 81.744829 -741.64489 -150.51858 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
678.08323 -1587.4685 975.42704 -1577.7323 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1511.2354 1120.9965 1190.6634 1744.1159 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3121.9204 3366.6799 -3658.9396 2812.9752 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1466.4186 -5895.8277 -140.62629 -7121.1364 MAarrowhead1
% End of user PostScript
.724 1 0 r
.63429 .73126 m
.57802 .80363 L
.5096 .86752 L
.4315 .918 L
.34709 .95028 L
.26056 .96 L
.17679 .94358 L
.10114 .89852 L
.0392 .8237 L
s
.0392 .8237 m
0 .72815 L
s
0 .38812 m
.03064 .26442 L
.10644 .08542 L
s
.10644 .08542 m
.1589 0 L
s
1 0 0 r
.63429 .73126 m
.57802 .80363 L
s
% Start of user PostScript
4.0285964 6.9378491 2.3404914 9.1087788 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5096 .86752 m
.4315 .918 L
s
% Start of user PostScript
0.28803903 11.025548 -2.0548718 12.540007 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-15.656109 2.6567823 -15.346696 -1.9565058 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
12.464106 -32.218526 18.570995 -32.431819 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
32.011484 20.039124 26.003201 32.759814 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-60.966776 70.623365 -72.483242 60.439817 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-35.430522 -114.22841 -9.3539064 -140.19025 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
195.70365 -95.322314 204.94449 -45.673522 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-69.28025 391.15993 -147.98278 419.72226 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-473.35768 -71.858575 -431.88446 -230.98538 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
588.84458 -1002.4814 767.68855 -945.48012 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
788.48152 1043.5597 524.42065 1427.8809 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2267.802 1842.0415 -2530.521 1361.911 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-224.4635 -4395.2928 715.62231 -5033.7341 MAarrowhead1
% End of user PostScript
0 1 .875 r
.70671 .35069 m
.72673 .39686 L
.7359 .45532 L
.73222 .52423 L
.7142 .60087 L
.68101 .6817 L
.6326 .76245 L
.56984 .83831 L
.49456 .90409 L
.40958 .95453 L
.31868 .98458 L
.22649 .98974 L
.13833 .96637 L
.06001 .91208 L
s
.06001 .91208 m
0 .82944 L
s
0 .25464 m
.01218 .21144 L
.10019 .01977 L
s
.10019 .01977 m
.11315 0 L
s
1 0 0 r
.70671 .35069 m
.72673 .39686 L
s
% Start of user PostScript
6.2012167 -4.479246 6.8019014 -3.0943494 MAarrowhead1
% End of user PostScript
1 .158 0 r
.7359 .45532 m
.73222 .52423 L
s
% Start of user PostScript
7.0769245 -1.3405197 6.9665232 0.72677376 MAarrowhead1
% End of user PostScript
1 .473 0 r
.31868 .98458 m
.22649 .98974 L
s
% Start of user PostScript
-5.4396112 14.537504 -8.2053831 14.692117 MAarrowhead1
% End of user PostScript
1 .788 0 r
.01218 .21144 m
.10019 .01977 L
s
% Start of user PostScript
-14.634466 -8.6566836 -11.994167 -14.406992 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
27.169033 -32.192369 32.453147 -27.747151 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
16.792116 50.77018 5.1439984 62.639914 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-88.061372 44.549844 -92.569284 22.423172 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
28.865515 -175.70254 64.342654 -189.24582 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
214.9517 27.567862 197.18726 99.173745 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-260.34132 454.28308 -341.74719 430.50976 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-364.01714 -459.31899 -246.84858 -633.84869 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1015.6863 -846.22664 1137.8307 -633.92955 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
130.10026 1964.5748 -291.74679 2259.3651 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2871.0031 638.00018 -2846.0894 -188.51357 MAarrowhead1
% End of user PostScript
0 1 .871 r
.56162 .66226 m
.52395 .70272 L
.47984 .73647 L
.43105 .76061 L
.37989 .77242 L
.32907 .76957 L
.28168 .75025 L
.24099 .71344 L
.21034 .659 L
.19288 .58783 L
.19142 .50195 L
.20816 .40451 L
.24453 .29979 L
.30098 .19307 L
.37682 .09045 L
s
.37682 .09045 m
.46866 0 L
s
1 0 0 r
.56162 .66226 m
.52395 .70272 L
s
% Start of user PostScript
1.8486622 4.8678428 0.71857852 6.0814569 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47984 .73647 m
.43105 .76061 L
s
% Start of user PostScript
-0.60482757 7.0939849 -2.0683733 7.8182686 MAarrowhead1
% End of user PostScript
1 .473 0 r
.19142 .50195 m
.20816 .40451 L
s
% Start of user PostScript
-9.2575087 0.058366073 -8.7553235 -2.8647457 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
9.477132 -19.332835 13.030549 -18.828315 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
17.145648 16.199404 12.773921 23.718356 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-40.268934 38.845321 -46.229079 31.111894 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-12.534019 -76.90267 4.3926159 -90.797831 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
120.0677 -40.523004 121.94695 -7.7442804 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-67.521682 243.33079 -115.12313 253.36675 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-269.24584 -95.736125 -234.07723 -193.32964 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
411.35949 -580.43663 510.9965 -525.14055 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
383.82317 751.36163 203.9193 969.86073 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1442.9547 942.04199 -1561.5744 606.85339 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
177.58524 -2839.5011 766.98216 -3149.8306 MAarrowhead1
% End of user PostScript
0 1 .181 r
.47425 .22518 m
.53368 .18155 L
.59902 .15111 L
.66715 .13741 L
.73438 .14352 L
.79659 .1717 L
.84939 .22321 L
.88839 .29809 L
.90941 .39498 L
.90883 .51103 L
.88378 .64187 L
.83251 .78168 L
.75458 .9233 L
s
.75458 .9233 m
.69589 1 L
s
1 0 0 r
.47425 .22518 m
.53368 .18155 L
s
% Start of user PostScript
-0.77247417 -8.2446227 1.0104557 -9.5534527 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59902 .15111 m
.66715 .13741 L
s
% Start of user PostScript
2.9705198 -10.466817 5.0144119 -10.877589 MAarrowhead1
% End of user PostScript
1 .473 0 r
.88378 .64187 m
.83251 .78168 L
s
% Start of user PostScript
11.513307 4.2561641 9.9751856 8.4503506 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-17.816445 24.850496 -22.070872 22.418271 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-16.221416 -32.596162 -8.4405768 -41.939168 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
62.155518 -39.970118 67.13666 -25.453261 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-8.4971638 122.4254 -33.862362 135.5392 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-161.76652 5.0624462 -153.84446 -45.494419 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
159.97292 -337.07023 222.21959 -329.93964 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
304.36939 271.4435 230.16631 402.83792 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-692.38703 686.57584 -798.80572 556.01635 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-241.5135 -1318.7912 50.235226 -1565.4882 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2086.4545 -750.44007 2128.8736 -186.80531 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1108.9064 4219.8147 -1937.8537 4413.4993 MAarrowhead1
% End of user PostScript
0 .454 1 r
.54812 .40409 m
.56569 .40694 L
.58168 .41572 L
.59493 .4307 L
.60428 .4518 L
.60865 .47859 L
.60713 .51023 L
.59902 .54546 L
.58392 .58268 L
.56181 .61992 L
.53307 .65496 L
.49852 .68544 L
.45947 .70891 L
.41763 .72304 L
.37514 .72576 L
.33443 .71538 L
.29818 .69077 L
.26913 .6515 L
.24999 .59797 L
.24321 .53148 L
.25084 .45425 L
.27434 .36946 L
.31443 .28118 L
.37093 .19418 L
.44264 .11385 L
.52733 .04584 L
s
.52733 .04584 m
.61385 0 L
s
.90313 0 m
.91483 .00415 L
.99642 .07147 L
s
.99642 .07147 m
1 .07726 L
s
1 .8849 m
.94201 1 L
s
1 0 0 r
.54812 .40409 m
.56569 .40694 L
s
% Start of user PostScript
1.4436892 -2.8774328 1.9707254 -2.7918489 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58168 .41572 m
.59493 .4307 L
s
% Start of user PostScript
2.4504084 -2.5283734 2.8478266 -2.0790331 MAarrowhead1
% End of user PostScript
1 .473 0 r
.53307 .65496 m
.49852 .68544 L
s
% Start of user PostScript
0.99198902 4.6489346 -0.044283634 5.5630934 MAarrowhead1
% End of user PostScript
1 .788 0 r
.24999 .59797 m
.24321 .53148 L
s
% Start of user PostScript
-7.5002507 2.9392363 -7.7037257 0.94430709 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
3.6496687 -15.124085 6.6387157 -15.921061 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
17.299707 4.807244 15.323692 10.904367 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-24.5586 37.043981 -31.01171 34.051436 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-26.245753 -44.411405 -15.414228 -58.453027 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
88.964471 -63.118234 97.340983 -43.102639 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-3.9320027 174.12884 -40.462744 195.36216 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-238.50353 24.237809 -230.36355 -48.136336 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
212.49287 -493.83956 304.90626 -490.31991 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
468.52356 351.96643 368.20324 545.72168 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-974.04657 1044.5863 -1140.3683 871.07713 MAarrowhead1
% End of user PostScript
0 1 .797 r
.17034 .37959 m
.21407 .25968 L
.28068 .13814 L
.36924 .022 L
s
.36924 .022 m
.39232 0 L
s
1 0 0 r
.17034 .37959 m
.21407 .25968 L
s
% Start of user PostScript
-9.8898358 -3.6123817 -8.5778096 -7.2095214 MAarrowhead1
% End of user PostScript
1 .158 0 r
.28068 .13814 m
.36924 .022 L
s
% Start of user PostScript
-6.5795382 -10.855664 -3.9228191 -14.33989 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
21.915471 -15.771308 24.025956 -10.869434 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.65826122 42.853304 -9.6657137 48.176798 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-59.015453 6.6114674 -57.130886 -11.217567 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
51.723985 -122.08151 74.614194 -121.46661 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
116.65551 85.324786 92.164668 133.26885 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-239.30589 259.65622 -280.80554 217.41795 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-114.61905 -451.6393 -12.932027 -546.22577 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
747.48328 -323.674 774.25075 -128.82617 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-320.89988 1501.5526 -619.96258 1593.799 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1760.3478 -390.66902 -1580.0639 -998.37265 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2361.7764 -3751.0871 3022.1698 -3487.6436 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2786.7555 4235.8495 1737.9155 5664.8522 MAarrowhead1
% End of user PostScript
.471 1 0 r
.61559 .78396 m
.54924 .8572 L
.47111 .9189 L
.38431 .96383 L
.29285 .98708 L
.20157 .98438 L
.11593 .95244 L
.04179 .88925 L
s
.04179 .88925 m
0 .81936 L
s
0 .26442 m
.03537 .15794 L
s
.03537 .15794 m
.11632 0 L
s
1 0 0 r
.61559 .78396 m
.54924 .8572 L
s
% Start of user PostScript
3.4676192 8.5186745 1.477064 10.716083 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47111 .9189 m
.38431 .96383 L
s
% Start of user PostScript
-0.86661754 12.567002 -3.4706746 13.914916 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-16.611181 0.53140195 -15.800134 -4.6585955 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
16.410901 -34.610288 22.803212 -33.882894 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
31.268143 27.840244 23.654774 41.332651 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-71.066315 70.524098 -82.000531 57.13053 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-24.864405 -135.35006 5.0826281 -160.69355 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
214.21675 -77.180854 218.6 -19.329517 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-113.66639 433.22453 -198.77966 453.16562 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-486.12514 -156.76422 -426.02331 -330.89318 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
720.30154 -1044.9837 900.80952 -951.85378 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
711.95762 1310.3196 395.85098 1704.8513 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2560.3901 1731.8617 -2783.5949 1144.8838 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
231.11705 -5027.1953 1279.2439 -5602.9851 MAarrowhead1
% End of user PostScript
0 1 .603 r
.34766 .81421 m
.28981 .80655 L
.2368 .77958 L
.19242 .73235 L
.16048 .66497 L
.14453 .57878 L
.14766 .47642 L
.17222 .36184 L
.21959 .24024 L
.29 .11794 L
.3823 .00214 L
s
.3823 .00214 m
.38465 0 L
s
1 0 0 r
.34766 .81421 m
.28981 .80655 L
s
% Start of user PostScript
-4.5702998 9.426422 -6.3057095 9.196449 MAarrowhead1
% End of user PostScript
1 .158 0 r
.2368 .77958 m
.19242 .73235 L
s
% Start of user PostScript
-7.8961357 8.3874111 -9.2274265 6.9704548 MAarrowhead1
% End of user PostScript
1 .473 0 r
.3823 .00214 m
0 0 rlineto s
.3823 .00214 m
.38465 0 L
s
% Start of user PostScript
-3.5309434 -14.935873 -0.18254196 -17.981716 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
24.451553 -10.161682 25.2372 -3.7328215 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-11.091052 49.198 -20.857708 52.037819 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-57.08176 -14.005505 -50.953524 -33.883811 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
78.447098 -121.88358 99.810348 -112.78341 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
88.788001 141.20005 54.053677 187.53498 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-288.36736 211.84055 -317.049 147.89843 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
2.6449782 -563.06582 121.33101 -634.91397 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
781.62577 -99.41638 759.16694 135.18907 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-668.54548 1614.6906 -972.16451 1611.4878 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1559.0039 -1095.9937 -1241.0538 -1731.0074 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3136.4123 -3461.8328 3692.7079 -2915.8236 MAarrowhead1
% End of user PostScript
1 .563 0 r
.25648 .45646 m
.2792 .37375 L
.31812 .28756 L
.37306 .20255 L
.44289 .12397 L
.52542 .05735 L
.61743 .00826 L
s
.61743 .00826 m
.64796 0 L
s
.86061 0 m
.90384 .01511 L
.98373 .08036 L
s
.98373 .08036 m
1 .10646 L
s
1 .85197 m
.99998 .85203 L
s
.99998 .85203 m
.92584 1 L
s
1 0 0 r
.25648 .45646 m
.2792 .37375 L
s
% Start of user PostScript
-7.3056541 -1.306098 -6.6239815 -3.7874489 MAarrowhead1
% End of user PostScript
1 .158 0 r
.31812 .28756 m
.37306 .20255 L
s
% Start of user PostScript
-5.4565139 -6.3733174 -3.8081922 -8.9234077 MAarrowhead1
% End of user PostScript
1 .473 0 r
.98373 .08036 m
0 0 rlineto s
.98373 .08036 m
1 .10646 L
s
% Start of user PostScript
14.511985 -12.58932 16.362385 -9.6204061 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
2.5533415 27.976653 -3.4929378 32.396435 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-41.608119 10.549482 -41.522101 -1.2605655 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
28.265105 -84.974642 44.627814 -86.99604 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
89.186688 43.222985 75.107916 77.036384 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-152.2959 194.41284 -184.86191 171.29709 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-113.57268 -281.99046 -47.747589 -354.34592 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
510.08024 -289.86877 542.90736 -165.81165 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-122.87078 1011.7957 -329.57788 1103.51 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1282.5774 -68.163974 -1196.91 -482.98825 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1419.2225 -2692.6704 1908.625 -2590.9812 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2285.5626 2463.6335 1638.5971 3505.2007 MAarrowhead1
% End of user PostScript
.899 1 0 r
.58947 .42372 m
.6006 .4422 L
.6072 .46658 L
.6083 .49621 L
.60308 .53 L
.59102 .5665 L
.57193 .6039 L
.546 .64009 L
.51388 .67273 L
.47665 .69942 L
.43586 .71777 L
.39347 .72558 L
.35178 .72098 L
.31338 .70258 L
.281 .66965 L
.25736 .62223 L
.24505 .56119 L
.24631 .48838 L
.26286 .40657 L
.29576 .31944 L
.34521 .23148 L
.41049 .14781 L
.48979 .07401 L
.58026 .01579 L
s
.58026 .01579 m
.62185 0 L
s
.89651 0 m
.9624 .03958 L
s
.9624 .03958 m
1 .08531 L
s
1 .87446 m
.95428 .98194 L
s
.95428 .98194 m
.94315 1 L
s
1 0 0 r
.58947 .42372 m
.6006 .4422 L
s
% Start of user PostScript
2.6840858 -2.2883433 3.0178595 -1.7340426 MAarrowhead1
% End of user PostScript
1 .158 0 r
.6072 .46658 m
.6083 .49621 L
s
% Start of user PostScript
3.2160998 -1.0025254 3.2489385 -0.11382055 MAarrowhead1
% End of user PostScript
1 .473 0 r
.43586 .71777 m
.39347 .72558 L
s
% Start of user PostScript
-1.9241149 6.5332436 -3.1959964 6.7674956 MAarrowhead1
% End of user PostScript
1 .788 0 r
.26286 .40657 m
.29576 .31944 L
s
% Start of user PostScript
-7.1142176 -2.8028159 -6.1273075 -5.4167733 MAarrowhead1
% End of user PostScript
.897 1 0 r
.89651 0 m
.9624 .03958 L
s
% Start of user PostScript
11.249827 -15.387656 13.872107 -13.812675 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
9.819651 20.638774 4.9181661 26.411612 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-38.888886 24.364933 -41.869696 15.199132 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6.2124084 -76.717865 22.058174 -84.65462 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
100.45446 -1.3175981 95.14959 30.313146 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-101.88444 209.65564 -140.46909 204.4663 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-186.85622 -173.81396 -139.78852 -255.4044 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
435.05495 -422.83419 500.11361 -339.69215 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
139.81556 830.24732 -43.175675 981.68428 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1300.9039 446.88674 -1322.9176 92.748128 MAarrowhead1
% End of user PostScript
0 .45 1 r
.68512 .58954 m
.65594 .65971 L
.61357 .72969 L
.55878 .79529 L
.49319 .85202 L
.41928 .8953 L
.34034 .92078 L
.26041 .92455 L
.18412 .90351 L
.11652 .8556 L
.06278 .78011 L
.02797 .67786 L
.01667 .55138 L
.03268 .40501 L
.0787 .24481 L
.15598 .07849 L
s
.15598 .07849 m
.20792 0 L
s
1 0 0 r
.68512 .58954 m
.65594 .65971 L
s
% Start of user PostScript
5.5537342 2.6863093 4.6781391 4.7912253 MAarrowhead1
% End of user PostScript
1 .158 0 r
.61357 .72969 m
.55878 .79529 L
s
% Start of user PostScript
3.4069719 6.8906755 1.7633707 8.8587281 MAarrowhead1
% End of user PostScript
1 .473 0 r
.06278 .78011 m
.02797 .67786 L
s
% Start of user PostScript
-13.116505 8.4031932 -14.160995 5.3356638 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.8371363 -25.840978 7.18868 -28.595176 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
34.099904 -0.97746491 32.411029 9.6913497 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-33.846748 71.07012 -46.964747 69.529622 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-64.054458 -57.477415 -48.364109 -85.174801 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
146.20329 -144.55535 168.58566 -116.9323 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
50.411327 278.55219 -11.17782 330.46884 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-440.0762 157.25129 -448.80547 38.235901 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
235.32873 -890.23811 410.13148 -930.65992 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
997.13283 325.80234 872.9559 683.52174 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1483.3921 2144.2475 -1853.4856 1951.4489 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1455.348 -2699.9311 -804.65351 -3509.1808 MAarrowhead1
% End of user PostScript
.88 1 0 r
.76913 .42026 m
.771 .49517 L
.75696 .58033 L
.72572 .67205 L
.67687 .76571 L
.61096 .856 L
.52966 .93709 L
s
.52966 .93709 m
.4399 1 L
s
.02376 1 m
0 .97487 L
s
0 .02503 m
.01436 0 L
s
1 0 0 r
.76913 .42026 m
.771 .49517 L
s
% Start of user PostScript
8.073787 -2.3921242 8.1299206 -0.14500474 MAarrowhead1
% End of user PostScript
1 .158 0 r
.75696 .58033 m
.72572 .67205 L
s
% Start of user PostScript
7.7086879 2.4099628 6.7716492 5.1613984 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-11.316373 16.556592 -14.181654 15.111441 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-11.379283 -20.559959 -6.407752 -26.816354 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
40.389425 -27.609119 43.971513 -18.38708 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-3.2425384 79.248619 -19.787466 88.452236 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-107.04624 7.9948663 -102.78423 -24.860674 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
99.388983 -222.18476 140.75656 -219.40279 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
206.886 166.26452 160.2984 253.22123 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-445.21937 463.27969 -518.249 382.14096 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-185.66176 -843.94788 2.7689234 -1011.6669 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1367.3254 -545.23658 1406.404 -182.76679 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-652.25174 2755.4283 -1197.5249 2904.64 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3164.8871 -849.33917 -2809.7426 -1960.8865 MAarrowhead1
% End of user PostScript
0 .099 1 r
.76067 .76433 m
.6904 .88098 L
.59941 .99043 L
s
.59941 .99043 m
.5884 1 L
s
1 0 0 r
.76067 .76433 m
.6904 .88098 L
s
% Start of user PostScript
7.8200658 7.9299937 5.7118543 11.429262 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59941 .99043 m
0 0 rlineto s
.59941 .99043 m
.5884 1 L
s
% Start of user PostScript
2.9823025 14.712851 -0.28853919 17.556221 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-23.574406 8.9737214 -24.158086 2.6691869 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
11.840233 -47.586596 21.225171 -49.981232 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
54.063522 15.871262 47.709269 35.034933 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-77.929768 115.92465 -98.064161 106.21903 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-81.021308 -141.22969 -46.712376 -185.10975 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
280.38949 -195.61744 306.09069 -132.10665 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-17.006738 549.41957 -132.01459 614.95964 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-747.78779 66.863891 -720.33948 -161.23164 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
678.95352 -1550.0527 968.35249 -1535.211 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1458.2162 1129.7885 1138.7353 1737.2585 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3079.425 3257.5339 -3595.7711 2703.1925 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1358.2539 -5827.3753 -52.919662 -7009.6059 MAarrowhead1
% End of user PostScript
1 0 .916 r
.60088 .70782 m
.55141 .76658 L
.49229 .81727 L
.42576 .85579 L
.3548 .87821 L
.28305 .88107 L
.21468 .86158 L
.15423 .81794 L
.10635 .74952 L
.07557 .65711 L
.066 .54303 L
.08104 .41119 L
.12306 .26709 L
.19317 .1177 L
s
.19317 .1177 m
.2717 0 L
s
1 0 0 r
.60088 .70782 m
.55141 .76658 L
s
% Start of user PostScript
3.0263091 6.2346233 1.5423214 7.9974807 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49229 .81727 m
.42576 .85579 L
s
% Start of user PostScript
-0.23123568 9.5181177 -2.2271491 10.673598 MAarrowhead1
% End of user PostScript
1 .473 0 r
.066 .54303 m
.08104 .41119 L
s
% Start of user PostScript
-13.020088 1.2907975 -12.56889 -2.6643396 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
11.645229 -26.965107 16.688913 -26.759473 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
25.538911 19.307189 20.044825 29.884374 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-53.264208 56.962401 -62.325662 47.453776 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-24.353602 -100.67988 -1.7519769 -121.38613 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
165.3934 -69.651763 170.90111 -26.284494 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-73.744084 332.61062 -139.8419 352.20177 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-387.18892 -92.098135 -346.2332 -226.55923 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
528.06871 -826.20256 673.08741 -765.6855 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
605.67473 949.42205 371.6411 1263.72 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1947.9181 1442.5185 -2144.0973 1012.0797 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1.7940358 -3801.3525 803.95618 -4291.4964 MAarrowhead1
% End of user PostScript
1 0 .959 r
.81983 .57516 m
.7862 .68611 L
.73101 .80074 L
.65471 .91269 L
s
.65471 .91269 m
.57299 1 L
s
1 0 0 r
.81983 .57516 m
.7862 .68611 L
s
% Start of user PostScript
9.595027 2.2547244 8.5859141 5.5832782 MAarrowhead1
% End of user PostScript
1 .158 0 r
.73101 .80074 m
.65471 .91269 L
s
% Start of user PostScript
6.9304051 9.0220564 4.6411622 12.380658 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-19.723509 16.162706 -22.038419 12.005266 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-2.1501753 -38.200215 6.0313436 -43.812114 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
55.433379 -11.612507 54.803344 4.4369734 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-41.058969 113.66462 -62.765552 115.33942 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-115.94239 -64.608786 -95.863225 -109.6529 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
209.71199 -254.30515 251.72705 -220.74464 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
137.72085 390.79968 47.589881 484.84576 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-686.58579 360.60641 -724.53221 189.80443 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
206.5756 -1367.4229 483.6845 -1478.5463 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1691.5442 176.78542 1560.2236 735.09798 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1992.7941 3567.4578 -2634.9401 3397.1184 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2911.9344 -3499.0796 -2011.63 -4872.6015 MAarrowhead1
% End of user PostScript
0 1 .201 r
.52942 .32107 m
.56555 .30729 L
.60258 .30317 L
.63842 .31023 L
.67077 .32955 L
.69726 .36161 L
.7155 .40619 L
.72332 .4623 L
.71887 .52813 L
.70077 .60105 L
.66828 .67765 L
.62144 .75385 L
.56112 .82507 L
.48911 .88638 L
.40818 .93281 L
.32194 .95961 L
.23483 .96257 L
.15195 .93834 L
.07878 .88474 L
.02099 .80106 L
s
.02099 .80106 m
0 .73693 L
s
0 .36137 m
.04361 .2136 L
.12942 .03215 L
s
.12942 .03215 m
.15101 0 L
s
1 0 0 r
.52942 .32107 m
.56555 .30729 L
s
% Start of user PostScript
0.88263836 -5.367759 1.9664305 -5.7812599 MAarrowhead1
% End of user PostScript
1 .158 0 r
.60258 .30317 m
.63842 .31023 L
s
% Start of user PostScript
3.0772567 -5.9050435 4.1524707 -5.6931522 MAarrowhead1
% End of user PostScript
1 .473 0 r
.66828 .67765 m
.62144 .75385 L
s
% Start of user PostScript
5.0485019 5.3294069 3.6431697 7.6155759 MAarrowhead1
% End of user PostScript
1 .788 0 r
.07878 .88474 m
.02099 .80106 L
s
% Start of user PostScript
-12.636531 11.54221 -14.370175 9.0318379 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-3.0311241 -24.253021 2.2558496 -28.343375 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
36.914373 -10.853813 37.153447 -0.56894874 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-22.994846 75.110264 -37.568618 77.526685 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-80.887079 -34.049198 -69.205668 -64.05096 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
130.94732 -175.36088 160.67897 -156.54405 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
109.07564 240.93312 52.165489 306.56491 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-448.24371 272.81996 -480.90941 166.1376 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
82.77335 -885.7648 265.11056 -973.90355 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1148.4159 7.8691388 1082.9298 372.43855 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1196.7085 2401.1001 -1636.9427 2332.2135 MAarrowhead1
% End of user PostScript
.407 0 1 r
.23413 .54654 m
.23909 .46838 L
.26026 .3817 L
.29855 .29053 L
.35395 .19972 L
.42544 .11472 L
.5109 .04139 L
s
.5109 .04139 m
.5823 0 L
s
.94423 0 m
.99979 .04003 L
s
.99979 .04003 m
1 .04033 L
s
1 .93283 m
.96851 1 L
s
1 0 0 r
.23413 .54654 m
.23909 .46838 L
s
% Start of user PostScript
-7.9760701 1.3961074 -7.8274286 -0.94865247 MAarrowhead1
% End of user PostScript
1 .158 0 r
.26026 .3817 m
.29855 .29053 L
s
% Start of user PostScript
-7.192195 -3.5490391 -6.0434634 -6.2840108 MAarrowhead1
% End of user PostScript
1 .473 0 r
.94423 0 m
.99979 .04003 L
s
% Start of user PostScript
12.369837 -15.68967 14.993609 -13.799116 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
9.0839443 22.922763 3.7413201 28.757535 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-41.310884 23.253347 -43.922491 13.177322 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
10.261588 -81.985844 26.9941 -89.320789 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
103.61201 6.1613919 96.553237 39.757174 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-115.56294 217.6473 -155.074 209.15941 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-183.86556 -200.90594 -131.24641 -285.0469 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
469.70649 -421.6345 532.58614 -327.36797 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
102.36645 902.87586 -93.871476 1051.8331 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1363.4098 382.17259 -1368.2919 -0.10736459 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
875.35873 -2777.6381 1412.9196 -2859.088 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2965.4662 1311.3854 2523.8917 2419.4471 MAarrowhead1
% End of user PostScript
0 1 .204 r
.34398 .60129 m
.33128 .56498 L
.32694 .51996 L
.33235 .46775 L
.34847 .41051 L
.37578 .35099 L
.41413 .29243 L
.46271 .23845 L
.51998 .19288 L
.58369 .15956 L
.65089 .14211 L
.71803 .14368 L
.78112 .1667 L
.83583 .21267 L
.87781 .28189 L
.90284 .37334 L
.90718 .48452 L
.88782 .61142 L
.84275 .74858 L
.77124 .88917 L
s
.77124 .88917 m
.69209 1 L
s
1 0 0 r
.34398 .60129 m
.33128 .56498 L
s
% Start of user PostScript
-4.680464 3.0388037 -5.0616672 1.9493864 MAarrowhead1
% End of user PostScript
1 .158 0 r
.32694 .51996 m
.33235 .46775 L
s
% Start of user PostScript
-5.1917666 0.5986601 -5.0295696 -0.96761529 MAarrowhead1
% End of user PostScript
1 .473 0 r
.65089 .14211 m
.71803 .14368 L
s
% Start of user PostScript
4.5265921 -10.736703 6.5409611 -10.689709 MAarrowhead1
% End of user PostScript
1 .788 0 r
.84275 .74858 m
.77124 .88917 L
s
% Start of user PostScript
10.282607 7.4573013 8.1372955 11.675116 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-21.004958 22.875551 -24.665372 19.178995 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-10.178135 -39.626697 -1.2493933 -47.964147 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
65.709404 -28.652923 68.104578 -11.550091 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-27.931547 131.96058 -54.229008 140.15293 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-154.98301 -33.768862 -139.24274 -87.190957 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
207.06132 -330.13326 265.22695 -307.20042 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
246.08704 371.12838 154.08498 496.94057 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-771.07224 583.37301 -851.33726 414.58185 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-16.507878 -1502.4399 301.49416 -1701.614 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2109.9595 -314.51529 2059.0719 312.83342 MAarrowhead1
% End of user PostScript
.065 0 1 r
.47422 .50584 m
.47442 .49844 L
.47618 .49014 L
.47958 .48132 L
.48466 .47245 L
.49133 .46403 L
.4994 .45664 L
.50858 .45086 L
.51848 .44723 L
.52859 .44627 L
.53834 .44838 L
.5471 .45385 L
.55422 .46281 L
.55906 .47517 L
.56102 .49066 L
.5596 .50877 L
.55443 .52877 L
.54533 .54972 L
.53232 .57049 L
.51565 .58982 L
.49582 .60637 L
.47361 .61878 L
.45001 .62575 L
.42624 .62616 L
.40372 .6191 L
.38393 .60399 L
.36844 .58067 L
.35872 .54944 L
.35614 .5111 L
.36179 .46699 L
.37644 .41897 L
.40041 .3694 L
.43351 .32101 L
.47498 .27686 L
.52346 .24013 L
.577 .21401 L
.63308 .20147 L
.68869 .20506 L
.74044 .22672 L
.78476 .26756 L
.81798 .3277 L
.83668 .40612 L
.83778 .50059 L
.81888 .60759 L
.77845 .72243 L
.71603 .83929 L
.63242 .95148 L
s
.63242 .95148 m
.58272 1 L
s
1 0 0 r
.47422 .50584 m
.47442 .49844 L
s
% Start of user PostScript
-0.77327327 0.17522745 -0.7672783 -0.046947493 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47618 .49014 m
.47958 .48132 L
s
% Start of user PostScript
-0.71472729 -0.2959049 -0.61255532 -0.56036386 MAarrowhead1
% End of user PostScript
1 .473 0 r
.53834 .44838 m
.5471 .45385 L
s
% Start of user PostScript
1.1501592 -1.5485843 1.4130601 -1.3843837 MAarrowhead1
% End of user PostScript
1 .788 0 r
.53232 .57049 m
.51565 .58982 L
s
% Start of user PostScript
0.96964797 2.114654 0.46946783 2.6945931 MAarrowhead1
% End of user PostScript
.897 1 0 r
.36844 .58067 m
.35872 .54944 L
s
% Start of user PostScript
-3.9469034 2.4202201 -4.2383257 1.4831736 MAarrowhead1
% End of user PostScript
.581 1 0 r
.52346 .24013 m
.577 .21401 L
s
% Start of user PostScript
0.70381017 -7.7960422 2.3100215 -8.5796187 MAarrowhead1
% End of user PostScript
.266 1 0 r
.83778 .50059 m
.81888 .60759 L
s
% Start of user PostScript
10.133282 0.017611602 9.5663891 3.2277745 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-10.487211 21.176938 -14.373682 20.59071 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-18.67159 -17.96628 -13.842163 -26.196383 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
44.305756 -42.363108 50.783964 -33.805852 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
13.26629 84.682037 -5.3428503 99.813242 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-131.66051 43.502998 -133.52439 7.4390249 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
75.340174 -266.99876 127.50214 -277.61489 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
294.14293 107.6618 255.07375 214.67645 MAarrowhead1
% End of user PostScript
.072 0 1 r
.40848 .44284 m
.42563 .40649 L
.4495 .37088 L
.47956 .33822 L
.51483 .31086 L
.55393 .29114 L
.59501 .28125 L
.63589 .28309 L
.67412 .29811 L
.70705 .32717 L
.73202 .37041 L
.74647 .42713 L
.74815 .49575 L
.73526 .57376 L
.70662 .65775 L
.66184 .74353 L
.60145 .8262 L
.52697 .90042 L
.44096 .96065 L
s
.44096 .96065 m
.35031 1 L
s
.14382 1 m
.06692 .96113 L
s
.06692 .96113 m
0 .89027 L
s
0 .16939 m
.03723 .0735 L
s
.03723 .0735 m
.07943 0 L
s
1 0 0 r
.40848 .44284 m
.42563 .40649 L
s
% Start of user PostScript
-2.7456144 -1.7147653 -2.2311267 -2.8053003 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4495 .37088 m
.47956 .33822 L
s
% Start of user PostScript
-1.5150791 -3.8737401 -0.61333674 -4.8534244 MAarrowhead1
% End of user PostScript
1 .473 0 r
.73202 .37041 m
.74647 .42713 L
s
% Start of user PostScript
6.9604902 -3.8877622 7.3941464 -2.1861487 MAarrowhead1
% End of user PostScript
1 .788 0 r
.44096 .96065 m
0 0 rlineto s
.44096 .96065 m
.35031 1 L
s
% Start of user PostScript
-1.7710559 13.819463 -4.5891744 15.042738 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-17.422034 -1.1250054 -16.216343 -6.7855178 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
19.555505 -36.613296 26.195777 -35.148982 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
30.811531 34.037628 21.915604 48.185498 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-79.227882 70.725057 -89.750916 54.773725 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-16.717472 -152.36634 16.368003 -177.32736 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
229.50884 -63.329166 230.11885 1.1512798 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-148.75112 467.75925 -239.20292 481.05162 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-498.00717 -223.63782 -423.13153 -410.16089 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
825.72544 -1082.2752 1008.2445 -960.58514 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
655.05417 1523.6543 297.08653 1927.7112 MAarrowhead1
% End of user PostScript
0 .167 1 r
.59531 .29975 m
.63228 .30407 L
.66628 .32065 L
.69489 .35014 L
.71568 .39249 L
.72639 .44689 L
.72501 .5117 L
.71004 .58444 L
.68054 .66184 L
.63635 .73988 L
.57815 .81401 L
.50754 .87929 L
.42707 .93064 L
.34024 .96314 L
.25137 .97235 L
.1655 .95462 L
.08815 .90741 L
.02506 .82962 L
s
.02506 .82962 m
0 .76705 L
s
0 .33074 m
.0198 .2525 L
.09872 .06853 L
s
.09872 .06853 m
.14123 0 L
s
1 0 0 r
.59531 .29975 m
.63228 .30407 L
s
% Start of user PostScript
2.8593883 -6.0075927 3.9683535 -5.8779099 MAarrowhead1
% End of user PostScript
1 .158 0 r
.66628 .32065 m
.69489 .35014 L
s
% Start of user PostScript
4.9883167 -5.3804218 5.8466006 -4.4958242 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57815 .81401 m
.50754 .87929 L
s
% Start of user PostScript
2.3445166 9.4203756 0.22607916 11.378643 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-15.543413 6.6546564 -16.084 2.5931253 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
6.7786644 -31.237929 12.994581 -33.124475 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
36.515756 8.3420644 32.725762 20.978711 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-49.323335 77.855038 -63.013127 72.290978 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-57.526247 -88.551433 -35.640655 -118.19349 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
182.74931 -136.70606 201.444 -96.500394 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
1.7431859 356.37862 -73.566129 402.93493 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-498.23909 70.063564 -485.33519 -78.619385 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
416.83573 -1028.0203 610.62931 -1028.7686 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1001.6578 679.38455 802.60709 1084.1799 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1980.608 2219.6024 -2338.9711 1879.1278 MAarrowhead1
% End of user PostScript
0 .652 1 r
.34632 .82987 m
.28525 .82381 L
.22884 .79762 L
.1811 .7502 L
.14602 .68155 L
.12738 .59292 L
.12848 .48696 L
.15188 .36766 L
.19915 .24037 L
.27067 .11162 L
s
.27067 .11162 m
.3568 0 L
s
1 0 0 r
.34632 .82987 m
.28525 .82381 L
s
% Start of user PostScript
-4.6102989 9.8962191 -6.4426346 9.7142291 MAarrowhead1
% End of user PostScript
1 .158 0 r
.22884 .79762 m
.1811 .7502 L
s
% Start of user PostScript
-8.1347266 8.9286845 -9.566991 7.5060699 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-4.0385965 -15.333531 -0.578057 -18.591415 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
25.52965 -11.296546 26.494888 -4.672891 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-10.623316 51.239187 -20.846753 54.490571 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-60.408096 -12.647731 -54.381545 -33.40378 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
79.990167 -128.58095 102.68111 -119.85685 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
96.524285 143.17608 60.942969 192.21516 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-299.10775 228.37392 -330.68178 163.166 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-9.2966783 -582.42657 114.13905 -660.55434 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
820.92534 -127.97708 802.30999 115.38255 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-669.33717 1691.4846 -989.11929 1697.9444 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1665.1613 -1083.3352 -1343.9828 -1750.3211 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3228.3872 -3681.2912 3825.8869 -3134.4952 MAarrowhead1
% End of user PostScript
1 .182 0 r
.24221 .34146 m
.29 .23938 L
.35667 .13926 L
.44077 .04732 L
s
.44077 .04732 m
.50136 0 L
s
1 0 0 r
.24221 .34146 m
.29 .23938 L
s
% Start of user PostScript
-7.7336684 -4.7563156 -6.300052 -7.8185471 MAarrowhead1
% End of user PostScript
1 .158 0 r
.35667 .13926 m
.44077 .04732 L
s
% Start of user PostScript
-4.2998385 -10.822239 -1.7768722 -13.580467 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
19.515105 -11.001609 20.752368 -6.2439038 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-4.8241102 38.726668 -12.729126 42.19868 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-48.96574 -2.8622553 -45.64031 -18.732807 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
54.54459 -102.84816 73.218911 -98.857545 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
86.950961 94.803159 62.110632 134.56722 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-221.83924 199.35466 -251.5832 154.86154 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-48.652759 -426.38132 44.037463 -496.82435 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
644.18804 -181.12884 646.61269 -0.58016229 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-412.81383 1312.2828 -666.82353 1350.9995 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1401.7912 -618.00042 -1193.4573 -1141.5419 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2308.2395 -3044.247 2822.4323 -2706.5065 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1857.3967 4255.7228 856.01336 5393.0843 MAarrowhead1
% End of user PostScript
.096 0 1 r
.66508 .45422 m
.66557 .50058 L
.65625 .55307 L
.63636 .60938 L
.6057 .66667 L
.56465 .72164 L
.51428 .77072 L
.45635 .81019 L
.39331 .83641 L
.32825 .84607 L
.26475 .83637 L
.20684 .80532 L
.1587 .75193 L
.1245 .6764 L
.10814 .5803 L
.11297 .46661 L
.14152 .33978 L
.19526 .20561 L
.27433 .07114 L
s
.27433 .07114 m
.33214 0 L
s
1 0 0 r
.66508 .45422 m
.66557 .50058 L
s
% Start of user PostScript
4.9525221 -1.3732525 4.9670966 0.017294159 MAarrowhead1
% End of user PostScript
1 .158 0 r
.65625 .55307 m
.63636 .60938 L
s
% Start of user PostScript
4.6873911 1.5919586 4.0909034 3.2813483 MAarrowhead1
% End of user PostScript
1 .473 0 r
.26475 .83637 m
.20684 .80532 L
s
% Start of user PostScript
-7.0573764 10.091085 -8.7948371 9.1595798 MAarrowhead1
% End of user PostScript
1 .788 0 r
.27433 .07114 m
0 0 rlineto s
.27433 .07114 m
.33214 0 L
s
% Start of user PostScript
-6.770204 -12.865745 -3.6786679 -16.669809 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
24.912399 -16.544343 27.019471 -10.793522 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-2.6757637 48.971357 -12.862283 54.445944 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-65.454883 3.5361344 -62.563395 -16.728419 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
62.656709 -136.10997 87.89997 -133.84503 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
124.9092 105.55429 95.690287 158.72263 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-276.00781 280.67279 -319.90315 229.52881 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-106.0004 -524.41151 10.565941 -625.66365 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
839.95695 -319.22834 860.64678 -94.532263 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-422.57238 1695.6064 -756.93881 1780.7166 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1925.6893 -566.94799 -1699.0132 -1249.7494 MAarrowhead1
% End of user PostScript
0 1 .271 r
.22583 .64416 m
.21065 .57597 L
.21069 .49418 L
.228 .40184 L
.26383 .30307 L
.31852 .20288 L
.39131 .10707 L
.48028 .02194 L
s
.48028 .02194 m
.51321 0 L
s
1 0 0 r
.22583 .64416 m
.21065 .57597 L
s
% Start of user PostScript
-8.2250388 4.3247307 -8.6806359 2.2792073 MAarrowhead1
% End of user PostScript
1 .158 0 r
.21069 .49418 m
.228 .40184 L
s
% Start of user PostScript
-8.679212 -0.17459848 -8.1600003 -2.9447122 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
9.204559 -18.167895 12.527268 -17.599282 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
15.804306 15.846978 11.581505 22.895808 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-38.393057 35.976881 -43.852083 28.467016 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-10.475107 -73.517609 5.6226951 -86.324007 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
113.22643 -35.589973 114.4448 -4.3401876 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-67.329796 229.95526 -112.11905 238.32534 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-250.81171 -97.828081 -216.22611 -189.85596 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
395.24025 -542.30811 487.72622 -487.19293 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
347.35295 724.78653 175.08456 928.30973 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1368.2795 860.88387 -1473.9213 538.85855 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
213.53684 -2698.5923 771.19739 -2979.3509 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3538.6898 -56.769676 3354.0016 1056.1438 MAarrowhead1
% End of user PostScript
1 0 .078 r
.76188 .44659 m
.7586 .52259 L
.73946 .60738 L
.70349 .69704 L
.65059 .78689 L
.58167 .8716 L
.49871 .94543 L
s
.49871 .94543 m
.40892 1 L
s
.07262 1 m
.01542 .96191 L
s
.01542 .96191 m
0 .94142 L
s
0 .08821 m
.03964 0 L
s
1 0 0 r
.76188 .44659 m
.7586 .52259 L
s
% Start of user PostScript
7.8563292 -1.6023823 7.7578762 0.67784343 MAarrowhead1
% End of user PostScript
1 .158 0 r
.73946 .60738 m
.70349 .69704 L
s
% Start of user PostScript
7.1836614 3.2212535 6.1045821 5.9112102 MAarrowhead1
% End of user PostScript
1 .473 0 r
.07262 1 m
.01542 .96191 L
s
% Start of user PostScript
-11.904417 15.610747 -14.537399 13.857342 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-9.4545524 -21.96497 -4.2934698 -27.793425 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
40.359324 -23.849228 43.149574 -14.151358 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-8.4490282 79.886485 -24.839215 87.524226 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-102.55905 -2.7652939 -96.27554 -35.589345 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
109.74496 -214.81419 148.98145 -207.80236 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
185.9261 189.27721 135.64663 272.56933 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-455.63506 423.77269 -519.74801 334.23676 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-119.87381 -873.07487 71.047727 -1023.7274 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1339.9731 -413.20025 1352.7061 -42.344946 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-807.93839 2722.884 -1337.6906 2818.609 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2958.8051 -1180.7145 -2545.1784 -2269.7993 MAarrowhead1
% End of user PostScript
.658 0 1 r
.24763 .80471 m
.19735 .76416 L
.15842 .70244 L
.13468 .62044 L
.12956 .52034 L
.14586 .4057 L
.18544 .28141 L
.24906 .15362 L
.33611 .02946 L
s
.33611 .02946 m
.36446 0 L
s
1 0 0 r
.24763 .80471 m
.19735 .76416 L
s
% Start of user PostScript
-7.5710971 9.141383 -9.0795755 7.9246534 MAarrowhead1
% End of user PostScript
1 .158 0 r
.15842 .70244 m
.13468 .62044 L
s
% Start of user PostScript
-10.247431 6.0733192 -10.959663 3.6132909 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.1203388 -20.280239 6.2825689 -22.226955 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
26.061327 0.65069089 24.475594 8.9849126 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-27.814905 54.576836 -37.787286 52.816739 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-47.307053 -47.947767 -34.558671 -69.113262 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
115.63659 -107.78526 131.95756 -85.092094 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
30.750514 221.5357 -17.712822 259.86815 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-340.35171 105.54308 -343.71053 11.422492 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
204.39266 -691.49947 338.97165 -716.05977 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
752.22947 298.20143 647.48857 574.82889 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1192.0795 1627.3738 -1469.2789 1460.0733 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1036.1195 -2187.5625 -516.85798 -2797.9562 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4117.098 -2572.702 4431.2422 -1601.4607 MAarrowhead1
% End of user PostScript
1 .422 0 r
.6479 .44689 m
.65089 .48685 L
.64528 .53292 L
.63026 .58316 L
.60547 .63513 L
.57109 .68596 L
.52789 .73247 L
.47728 .7713 L
.42129 .79913 L
.36253 .81283 L
.30415 .80969 L
.24967 .78767 L
.20287 .74556 L
.16756 .6832 L
.14738 .6016 L
.14553 .50309 L
.16458 .39128 L
.20617 .27106 L
.27081 .14848 L
.35774 .03055 L
s
.35774 .03055 m
.38868 0 L
s
1 0 0 r
.6479 .44689 m
.65089 .48685 L
s
% Start of user PostScript
4.4368977 -1.5934372 4.5265981 -0.39454499 MAarrowhead1
% End of user PostScript
1 .158 0 r
.64528 .53292 m
.63026 .58316 L
s
% Start of user PostScript
4.3582913 0.9875072 3.9076613 2.494686 MAarrowhead1
% End of user PostScript
1 .473 0 r
.30415 .80969 m
.24967 .78767 L
s
% Start of user PostScript
-5.8755716 9.2907695 -7.5098094 8.6300759 MAarrowhead1
% End of user PostScript
1 .788 0 r
.27081 .14848 m
.35774 .03055 L
s
% Start of user PostScript
-6.8755766 -10.545506 -4.2678624 -14.083411 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
21.789079 -16.332079 24.024938 -11.542606 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
0.25339826 42.484691 -8.726927 48.049206 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-59.443266 8.4476933 -57.922452 -9.2797376 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
49.607822 -122.6332 72.732073 -122.75943 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
119.60897 80.800207 95.908882 129.09517 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-236.05257 264.98425 -278.85749 224.46366 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-125.40012 -443.84841 -24.758155 -540.84212 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
747.76201 -344.74916 778.96183 -152.53366 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-291.82974 1498.2071 -591.80201 1599.2244 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1785.7025 -330.55003 -1616.6974 -938.51952 MAarrowhead1
% End of user PostScript
0 .983 1 r
.40676 .79264 m
.35018 .8009 L
.29501 .79231 L
.24471 .76515 L
.20294 .71856 L
.17332 .65273 L
.15924 .56903 L
.16361 .47007 L
.18862 .35971 L
.23554 .24303 L
.30447 .12614 L
.39424 .01598 L
s
.39424 .01598 m
.41222 0 L
s
1 0 0 r
.40676 .79264 m
.35018 .8009 L
s
% Start of user PostScript
-2.7972032 8.7791201 -4.4945454 9.0268963 MAarrowhead1
% End of user PostScript
1 .158 0 r
.29501 .79231 m
.24471 .76515 L
s
% Start of user PostScript
-6.1498469 8.7693306 -7.6587936 7.9544978 MAarrowhead1
% End of user PostScript
1 .473 0 r
.30447 .12614 m
.39424 .01598 L
s
% Start of user PostScript
-5.8660156 -11.215793 -3.1729478 -14.520629 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
21.680419 -14.347512 23.50348 -9.3362519 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-2.3989323 42.627523 -11.261994 47.370828 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-56.903684 2.9322266 -54.359992 -14.703235 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
54.668792 -118.35466 76.6088 -116.32644 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
108.42344 92.17261 82.944904 138.39463 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-240.34532 243.73147 -278.42634 199.10843 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-91.362481 -456.77923 10.116781 -544.66688 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
730.63071 -276.03699 748.28117 -80.374769 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-369.85835 1475.2174 -660.64214 1548.5655 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1673.1126 -497.87684 -1475.0511 -1091.8038 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2421.0471 -3588.7889 3043.894 -3285.6312 MAarrowhead1
% End of user PostScript
.304 0 1 r
.23116 .67488 m
.20919 .61235 L
.20165 .53479 L
.21088 .44483 L
.23859 .34619 L
.28558 .24358 L
.35162 .1426 L
.43529 .04949 L
s
.43529 .04949 m
.49739 0 L
s
1 0 0 r
.23116 .67488 m
.20919 .61235 L
s
% Start of user PostScript
-8.0651504 5.246431 -8.7241552 3.3705046 MAarrowhead1
% End of user PostScript
1 .158 0 r
.20165 .53479 m
.21088 .44483 L
s
% Start of user PostScript
-8.9506271 1.0437962 -8.6734688 -1.6549582 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
7.78756 -18.507939 11.260786 -18.431801 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
17.741052 12.822758 14.048863 20.094311 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-36.179989 39.460094 -42.497131 33.100463 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-17.612267 -68.244174 -2.2307431 -82.629239 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
113.24964 -49.52033 117.40667 -20.061449 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-47.948625 227.40745 -93.277321 241.58412 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-267.27376 -57.805668 -240.21984 -149.87849 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
356.48577 -569.24653 456.81086 -529.87729 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
424.8927 638.7877 266.46464 855.75614 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1328.5425 1006.8761 -1467.2039 716.27632 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-30.86068 -2588.3514 517.11677 -2932.248 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3637.4651 -546.89575 3550.7266 534.01717 MAarrowhead1
% End of user PostScript
0 1 .021 r
.28776 .62724 m
.2727 .57647 L
.26919 .51439 L
.27898 .44318 L
.30326 .36588 L
.3425 .28628 L
.39636 .20883 L
.46357 .13843 L
.5419 .08023 L
.62816 .0393 L
.71827 .0204 L
.80735 .02759 L
.88997 .0639 L
.96034 .13106 L
s
.96034 .13106 m
1 .20549 L
s
1 .70805 m
.94272 .86669 L
s
.94272 .86669 m
.8702 1 L
s
1 0 0 r
.28776 .62724 m
.2727 .57647 L
s
% Start of user PostScript
-6.3673384 3.8171799 -6.8190639 2.2942289 MAarrowhead1
% End of user PostScript
1 .158 0 r
.26919 .51439 m
.27898 .44318 L
s
% Start of user PostScript
-6.9242706 0.43167946 -6.6305458 -1.7046094 MAarrowhead1
% End of user PostScript
1 .473 0 r
.71827 .0204 m
.80735 .02759 L
s
% Start of user PostScript
6.5480192 -14.387919 9.2206198 -14.172334 MAarrowhead1
% End of user PostScript
1 .788 0 r
.94272 .86669 m
0 0 rlineto s
.94272 .86669 m
.8702 1 L
s
% Start of user PostScript
13.281655 11.000599 10.221865 16.625222 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-29.037345 29.802501 -33.713252 24.457327 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-11.53396 -55.119469 0.73982787 -65.886075 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
88.690899 -34.373454 91.016132 -10.733835 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-43.691325 178.9146 -79.022386 188.17912 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-204.11839 -57.947974 -180.54442 -130.04609 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
291.47568 -437.30889 367.56886 -401.48821 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
308.22549 527.53836 179.7602 693.21246 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1053.1114 742.36369 -1151.2559 504.81141 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
53.223588 -2062.1329 485.47136 -2311.4821 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2817.6195 -273.12474 2718.6671 583.59071 MAarrowhead1
% End of user PostScript
.517 0 1 r
.77118 .5537 m
.74477 .64648 L
.70026 .74287 L
.63787 .83762 L
.55895 .92485 L
.46601 .99836 L
s
.46601 .99836 m
.46284 1 L
s
1 0 0 r
.77118 .5537 m
.74477 .64648 L
s
% Start of user PostScript
8.1353155 1.6109843 7.3431878 4.3943382 MAarrowhead1
% End of user PostScript
1 .158 0 r
.70026 .74287 m
.63787 .83762 L
s
% Start of user PostScript
6.0076671 7.2862282 4.1360474 10.128643 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-16.352748 13.91111 -18.379804 10.530094 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-2.494009 -31.576606 4.30873 -36.442318 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
46.561631 -11.096458 46.315749 2.2111127 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-32.617694 95.223141 -50.901409 97.189607 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-98.96888 -50.407695 -82.830137 -88.245304 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
172.40446 -216.19196 208.4493 -189.52189 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
123.14902 319.94845 48.780805 400.23544 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-572.84377 316.95322 -607.89876 176.52338 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
149.94559 -1137.8932 381.76037 -1237.3142 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1430.2776 101.23543 1329.4219 567.08625 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1617.7927 3007.4561 -2162.5938 2883.5409 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2519.0374 -2819.8802 -1783.9116 -3981.3458 MAarrowhead1
% End of user PostScript
0 .662 1 r
.48023 .20838 m
.54288 .16447 L
.61131 .13473 L
.68221 .12282 L
.75168 .13181 L
.8154 .16395 L
.86879 .22042 L
.9073 .30108 L
.92665 .40434 L
.92312 .52706 L
.8939 .6645 L
.83729 .81043 L
.75303 .95728 L
s
.75303 .95728 m
.71908 1 L
s
1 0 0 r
.48023 .20838 m
.54288 .16447 L
s
% Start of user PostScript
-0.5930567 -8.7487229 1.2862902 -10.065829 MAarrowhead1
% End of user PostScript
1 .158 0 r
.61131 .13473 m
.68221 .12282 L
s
% Start of user PostScript
3.3391594 -10.958013 5.466229 -11.315493 MAarrowhead1
% End of user PostScript
1 .473 0 r
.8939 .6645 m
.83729 .81043 L
s
% Start of user PostScript
11.816927 4.9348942 10.118688 9.3128139 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-19.075413 25.611415 -23.420459 22.878865 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-15.981491 -35.084977 -7.6887315 -44.673308 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
65.37474 -39.932653 70.169061 -24.391852 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-11.87322 129.159 -38.47189 142.07328 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-167.6607 -0.73688269 -158.18713 -53.908293 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
174.13722 -350.46707 238.42405 -340.58187 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
308.4066 298.54316 228.25987 434.7139 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-734.3056 700.06245 -841.24088 557.97379 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-217.01931 -1403.8671 91.323079 -1653.7923 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2179.6758 -715.11534 2209.4588 -117.40953 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1254.3657 4421.1858 -2117.7275 4594.8171 MAarrowhead1
% End of user PostScript
0 .017 1 r
.48543 .45768 m
.49517 .44761 L
.50649 .43932 L
.51894 .43354 L
.53191 .43095 L
.54471 .43214 L
.55655 .43754 L
.56659 .44738 L
.57399 .46166 L
.57797 .48014 L
.57783 .50226 L
.57303 .52719 L
.56323 .55382 L
.54836 .58078 L
.52862 .60652 L
.50455 .62933 L
.47701 .64746 L
.44716 .65922 L
.4165 .66305 L
.38673 .65766 L
.35975 .64215 L
.33754 .6161 L
.32207 .57966 L
.31514 .53362 L
.31832 .47944 L
.33276 .41927 L
.35909 .3559 L
.39734 .2927 L
.44679 .23344 L
.50601 .18218 L
.57275 .14306 L
.64404 .12001 L
.71623 .11655 L
.78514 .1355 L
.84621 .17872 L
.89478 .24684 L
.92627 .33914 L
.93652 .45332 L
.92212 .58548 L
.88062 .73014 L
.81089 .88034 L
s
.81089 .88034 m
.73177 1 L
s
1 0 0 r
.48543 .45768 m
.49517 .44761 L
s
% Start of user PostScript
-0.43717901 -1.2694716 -0.14496453 -1.5717437 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50649 .43932 m
.51894 .43354 L
s
% Start of user PostScript
0.19480303 -1.8205295 0.56819274 -1.9938707 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57783 .50226 m
.57303 .52719 L
s
% Start of user PostScript
2.3348818 0.067737336 2.1908207 0.81563416 MAarrowhead1
% End of user PostScript
1 .788 0 r
.4165 .66305 m
.38673 .65766 L
s
% Start of user PostScript
-2.5051391 4.8913979 -3.3982234 4.7297714 MAarrowhead1
% End of user PostScript
.897 1 0 r
.35909 .3559 m
.39734 .2927 L
s
% Start of user PostScript
-4.2271977 -4.3228794 -3.0799351 -6.219117 MAarrowhead1
% End of user PostScript
.581 1 0 r
.84621 .17872 m
.89478 .24684 L
s
% Start of user PostScript
10.386426 -9.6384874 11.843349 -7.5946808 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2.7024658 19.906201 -1.6488614 23.331387 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-30.519865 9.3569247 -30.798413 0.90313582 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
18.477658 -62.027824 30.541479 -64.185454 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
67.327125 27.04874 57.876756 51.854152 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-107.19487 145.7224 -131.99151 130.59889 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-92.313489 -196.82595 -45.643583 -251.45761 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
369.49492 -229.57456 397.41044 -142.23918 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-61.70603 729.27793 -212.1881 803.88526 MAarrowhead1
% End of user PostScript
.509 1 0 r
.81695 .46937 m
.8058 .56575 L
.77493 .67105 L
.72355 .78016 L
.652 .8871 L
.56186 .98519 L
s
.56186 .98519 m
.54279 1 L
s
1 0 0 r
.81695 .46937 m
.8058 .56575 L
s
% Start of user PostScript
9.5086296 -0.91895374 9.1741118 1.9725631 MAarrowhead1
% End of user PostScript
1 .158 0 r
.77493 .67105 m
.72355 .78016 L
s
% Start of user PostScript
8.2479411 5.1314441 6.7065735 8.4049036 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-15.664208 18.190594 -18.632701 15.579983 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-9.1662985 -29.340288 -2.4647016 -36.029561 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
50.335597 -24.621514 52.734385 -11.865153 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-17.673791 100.58813 -37.920302 107.97794 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-121.87204 -18.182251 -111.26148 -59.110365 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
151.16173 -258.04237 197.21956 -243.49953 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
203.38034 267.76144 135.56701 366.71047 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-582.98605 474.87136 -650.80542 351.61623 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-59.564096 -1129.6531 182.15555 -1294.3349 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1635.1193 -335.00268 1614.9456 139.38135 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1221.6087 3354.1709 -1861.6013 3400.4324 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3411.0773 -1927.4272 -2814.7237 -3256.0799 MAarrowhead1
% End of user PostScript
.919 1 0 r
.26346 .8257 m
.20787 .79286 L
.1623 .73818 L
.1308 .66202 L
.11712 .56606 L
.12446 .45338 L
.15517 .32848 L
.21053 .19718 L
.29053 .06645 L
s
.29053 .06645 m
.34658 0 L
s
1 0 0 r
.26346 .8257 m
.20787 .79286 L
s
% Start of user PostScript
-7.0961929 9.7708702 -8.763916 8.7857405 MAarrowhead1
% End of user PostScript
1 .158 0 r
.1623 .73818 m
.1308 .66202 L
s
% Start of user PostScript
-10.131044 7.1454912 -11.076023 4.8607129 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
0.50662154 -19.837217 4.6650389 -22.237598 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
27.110367 -2.6386279 26.160531 5.6030739 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-24.315989 56.155765 -34.816056 55.70714 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-53.119171 -40.342448 -41.652845 -62.366122 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
111.04334 -118.51231 129.8835 -98.657965 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
50.43596 209.93876 3.3260627 253.00599 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-344.5224 144.51473 -355.87424 54.104623 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
154.411 -692.95072 292.07409 -733.52104 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
805.85746 193.49347 720.23433 473.5813 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1101.5914 1719.9151 -1403.3504 1593.2064 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1258.46 -1981.2386 -770.38544 -2635.3845 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4059.2546 -2998.8318 4466.5467 -2100.9106 MAarrowhead1
% End of user PostScript
1 .506 0 r
.18846 .32722 m
.24224 .2063 L
.31855 .08678 L
s
.31855 .08678 m
.39477 0 L
s
1 0 0 r
.18846 .32722 m
.24224 .2063 L
s
% Start of user PostScript
-9.3460583 -5.1833477 -7.7327068 -8.8111379 MAarrowhead1
% End of user PostScript
1 .158 0 r
.31855 .08678 m
0 0 rlineto s
.31855 .08678 m
.39477 0 L
s
% Start of user PostScript
-5.4433881 -12.396497 -2.5246253 -15.719957 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
22.888786 -13.684482 24.50476 -8.2051 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-4.5701869 45.276 -13.871528 49.673841 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-58.351207 -1.1110267 -54.873752 -19.726668 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
61.795664 -122.13286 84.136958 -118.33621 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
106.32797 106.36015 77.971662 153.75026 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-257.94513 241.99719 -294.68199 191.57871 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-70.7747 -493.87754 37.389825 -580.0367 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
761.05204 -239.9328 769.39212 -29.979465 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-451.56209 1545.5123 -752.64053 1602.0697 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1686.6745 -655.4967 -1454.5942 -1274.0639 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2654.616 -3646.5036 3276.6624 -3276.8554 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2338.7108 4867.2347 1181.5201 6235.9049 MAarrowhead1
% End of user PostScript
0 .881 1 r
.71935 .16696 m
.77745 .19341 L
.82673 .24167 L
.86309 .31175 L
.88264 .4024 L
.88197 .51093 L
.85844 .63326 L
.81039 .76394 L
.73744 .89627 L
s
.73744 .89627 m
.65793 1 L
s
1 0 0 r
.71935 .16696 m
.77745 .19341 L
s
% Start of user PostScript
6.5805684 -9.9910549 8.3234175 -9.1975797 MAarrowhead1
% End of user PostScript
1 .158 0 r
.82673 .24167 m
.86309 .31175 L
s
% Start of user PostScript
9.8019445 -7.7499426 10.892781 -5.6473751 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
0.67518335 19.036902 -3.3800113 21.708094 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-27.215739 4.9588669 -26.749725 -3.0166758 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
21.192669 -55.943501 31.821523 -56.456224 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
56.048333 33.855782 45.788201 55.969384 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-105.03173 123.42387 -125.24256 106.10665 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-63.484847 -196.46199 -18.493959 -241.9204 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
339.22216 -169.26881 356.09284 -83.732075 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-114.45577 677.26218 -251.02844 728.45589 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-825.25717 -112.93037 -755.55843 -388.75977 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1009.3965 -1745.4359 1321.6654 -1651.2078 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1389.2026 1783.8393 935.52223 2453.8923 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3919.2678 3235.2298 -4384.2309 2412.1404 MAarrowhead1
% End of user PostScript
1 0 .976 r
.3258 .82126 m
.26768 .80758 L
.21568 .77374 L
.17371 .71907 L
.14561 .64405 L
.1349 .55046 L
.14454 .44139 L
.17667 .3213 L
.23235 .19587 L
.31141 .07189 L
s
.31141 .07189 m
.37446 0 L
s
1 0 0 r
.3258 .82126 m
.26768 .80758 L
s
% Start of user PostScript
-5.2261061 9.6377371 -6.9696655 9.2274341 MAarrowhead1
% End of user PostScript
1 .158 0 r
.21568 .77374 m
.17371 .71907 L
s
% Start of user PostScript
-8.5297304 8.2122077 -9.7888319 6.5720578 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.6326927 -16.292434 0.95208401 -19.229035 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
25.413807 -8.5376057 25.803219 -1.594475 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-14.346941 51.511337 -24.420866 53.619066 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-56.942537 -20.377582 -49.477234 -41.034377 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
87.179721 -122.78028 108.24689 -111.03138 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
81.020635 159.27988 42.902313 205.4898 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-305.5329 198.98019 -330.5464 127.94386 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
38.283118 -601.33038 163.06409 -666.8361 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
798.13211 -32.081588 760.54514 216.44143 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-779.38647 1661.7306 -1086.7729 1629.5112 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1510.0871 -1318.8305 -1147.8267 -1967.1244 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3396.3195 -3401.1522 3925.3637 -2765.0312 MAarrowhead1
% End of user PostScript
.128 1 0 r
.4166 .39466 m
.44346 .35466 L
.47728 .318 L
.51695 .28732 L
.5609 .26523 L
.60706 .2542 L
.65298 .25636 L
.6959 .27334 L
.73285 .3061 L
.76083 .35478 L
.77698 .41861 L
.77877 .49578 L
.76416 .58349 L
.73186 .67789 L
.68143 .77426 L
.61347 .86709 L
.52969 .9504 L
s
.52969 .9504 m
.45868 1 L
s
1 0 0 r
.4166 .39466 m
.44346 .35466 L
s
% Start of user PostScript
-2.5020481 -3.1601317 -1.6960576 -4.3601417 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47728 .318 m
.51695 .28732 L
s
% Start of user PostScript
-0.68160374 -5.4599074 0.50857159 -6.3804951 MAarrowhead1
% End of user PostScript
1 .473 0 r
.77698 .41861 m
.77877 .49578 L
s
% Start of user PostScript
8.3094697 -2.4418288 8.3629948 -0.12651567 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-5.1780865 16.907667 -8.4586075 17.451032 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-18.206155 -7.6684771 -15.57591 -14.421907 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
29.480242 -39.47129 36.172097 -35.23404 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
24.545394 54.242857 11.733477 69.015327 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-100.90416 61.397673 -108.25398 37.38023 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
18.656566 -199.39768 59.701861 -219.23158 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
258.50009 1.8198447 243.74939 83.888046 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-269.43805 540.47927 -368.52974 524.95317 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-474.69694 -462.26166 -350.7561 -672.20909 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1134.0631 -1078.0423 1298.5524 -858.19553 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
330.79721 2168.7196 -145.28798 2553.3973 MAarrowhead1
% End of user PostScript
1 0 .575 r
.71433 .66794 m
.66697 .75746 L
.60336 .84356 L
.52511 .92063 L
.43494 .98287 L
s
.43494 .98287 m
.39461 1 L
s
.08477 1 m
.04477 .97914 L
s
.04477 .97914 m
0 .93057 L
s
0 .09903 m
.02052 .04705 L
s
.02052 .04705 m
.04787 0 L
s
1 0 0 r
.71433 .66794 m
.66697 .75746 L
s
% Start of user PostScript
6.4298648 5.0380598 5.0092486 7.7239167 MAarrowhead1
% End of user PostScript
1 .158 0 r
.60336 .84356 m
.52511 .92063 L
s
% Start of user PostScript
3.1007453 10.306764 0.75321004 12.618853 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-17.558971 8.4000117 -18.355891 3.9257216 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
6.4284431 -35.124176 13.484002 -37.623262 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
42.290945 6.8859602 38.48729 21.16289 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-53.257886 89.651003 -69.218504 84.364111 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-69.895704 -94.574232 -46.051567 -128.90956 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
203.91068 -163.67476 227.12094 -120.2514 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
17.461626 395.56926 -66.992315 452.16063 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-569.06146 110.21177 -560.69462 -55.708707 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
434.03339 -1168.522 656.52358 -1181.9633 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1179.6215 689.13291 968.62281 1151.5246 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2177.9362 2593.2774 -2604.1953 2238.5718 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1363.7302 -4067.5028 -429.50644 -5024.2873 MAarrowhead1
% End of user PostScript
.855 1 0 r
.70668 .71215 m
.65042 .80497 L
.5777 .89195 L
.49066 .96715 L
s
.49066 .96715 m
.43448 1 L
s
.03132 1 m
0 .97775 L
s
0 .03493 m
.01625 0 L
s
1 0 0 r
.70668 .71215 m
.65042 .80497 L
s
% Start of user PostScript
6.2004659 6.3645533 4.5126473 9.1490249 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5777 .89195 m
.49066 .96715 L
s
% Start of user PostScript
2.3309795 11.758628 -0.28018546 14.014453 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-18.786647 7.0621694 -19.23299 2.0265342 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
9.5596542 -37.938767 17.0352 -39.80994 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
42.978706 12.904098 37.866721 28.175626 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-62.351334 92.209739 -78.346579 84.374441 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-64.071008 -113.09825 -36.641162 -147.98089 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
223.70079 -154.95643 243.97121 -104.14269 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-15.116515 438.54593 -106.82994 490.37185 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-595.29129 50.14913 -572.79066 -131.82833 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
544.78375 -1234.524 775.04827 -1221.4252 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1157.2125 908.24625 901.21617 1391.829 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2460.0261 2587.2914 -2869.3441 2142.5121 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1064.1321 -4658.0497 -21.926252 -5596.2236 MAarrowhead1
% End of user PostScript
0 1 .117 r
.35914 .41447 m
.38502 .35884 L
.4212 .30422 L
.4669 .254 L
.52066 .21177 L
.58034 .1811 L
.64318 .16536 L
.70585 .16749 L
.76458 .18974 L
.81536 .23344 L
.85409 .29886 L
.87686 .38499 L
.88018 .48945 L
.86128 .60844 L
.81832 .73681 L
.75065 .86815 L
.65902 .99502 L
s
.65902 .99502 m
.65408 1 L
s
1 0 0 r
.35914 .41447 m
.38502 .35884 L
s
% Start of user PostScript
-4.2257183 -2.5659028 -3.4493415 -4.2348661 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4212 .30422 m
.4669 .254 L
s
% Start of user PostScript
-2.3638846 -5.8734966 -0.9929269 -7.3800331 MAarrowhead1
% End of user PostScript
1 .473 0 r
.85409 .29886 m
.87686 .38499 L
s
% Start of user PostScript
10.62257 -6.0340658 11.305669 -3.4502128 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-2.5623522 21.071413 -6.8669911 22.980333 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-26.707059 -1.4268275 -24.921638 -10.065659 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
29.562794 -56.070759 39.75332 -53.950182 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
47.583397 51.321576 34.107626 73.010073 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-120.62167 108.99149 -136.92016 84.875908 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-27.283678 -231.72729 23.137879 -270.27786 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
350.96917 -100.19856 352.60996 -2.0268886 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-222.80022 714.68092 -361.24854 736.40642 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-765.51555 -332.34382 -652.83063 -617.58466 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1253.3582 -1661.4987 1534.3538 -1479.2043 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1020.3852 2309.2452 476.31743 2930.3658 MAarrowhead1
% End of user PostScript
1 .024 0 r
.54758 .73732 m
.49485 .78302 L
.43541 .81792 L
.3719 .83851 L
.30758 .84166 L
.24617 .82485 L
.19172 .78643 L
.1484 .72581 L
.12028 .64366 L
.11107 .542 L
.12382 .42429 L
.16071 .29543 L
.22274 .16161 L
.30956 .03016 L
s
.30956 .03016 m
.33693 0 L
s
1 0 0 r
.54758 .73732 m
.49485 .78302 L
s
% Start of user PostScript
1.4275055 7.1195441 -0.15438513 8.4905021 MAarrowhead1
% End of user PostScript
1 .158 0 r
.43541 .81792 m
.3719 .83851 L
s
% Start of user PostScript
-1.937695 9.5376569 -3.8428924 10.155446 MAarrowhead1
% End of user PostScript
1 .473 0 r
.12382 .42429 m
.16071 .29543 L
s
% Start of user PostScript
-11.285376 -2.2712351 -10.178834 -6.1370334 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
14.816077 -24.004283 19.058664 -22.412646 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
18.14053 26.484561 11.542865 35.646161 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-55.62349 42.841071 -61.573566 30.762664 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2.2464649 -108.24154 20.722377 -122.92547 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
153.10112 -24.867871 149.84052 20.389132 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-123.43667 315.27243 -183.11356 316.89425 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-311.72873 -199.16304 -252.37118 -323.5566 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
599.29815 -688.48182 711.29267 -587.63749 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
340.28342 1123.9252 84.171138 1376.7348 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1916.9847 920.50268 -2004.7135 432.47008 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
697.02877 -3834.0089 1467.444 -4108.2782 MAarrowhead1
% End of user PostScript
.438 0 1 r
.50339 .42766 m
.51847 .41939 L
.53445 .41483 L
.55051 .41475 L
.5657 .41973 L
.57899 .43017 L
.58933 .44616 L
.59573 .46749 L
.59727 .4936 L
.59322 .52357 L
.58306 .55612 L
.5666 .58966 L
.54398 .62232 L
.51572 .65203 L
.48276 .67663 L
.44644 .69397 L
.40848 .70206 L
.37092 .69917 L
.33606 .68402 L
.30634 .65588 L
.2842 .61469 L
.27199 .56118 L
.27175 .4969 L
.28509 .42424 L
.31302 .34643 L
.35583 .26741 L
.41292 .19175 L
.48282 .12439 L
.56304 .07047 L
.65019 .03498 L
.73999 .02249 L
.82742 .03683 L
.90698 .08069 L
.97285 .1554 L
s
.97285 .1554 m
1 .21688 L
s
1 .6956 m
.99271 .72716 L
.91738 .91246 L
s
.91738 .91246 m
.86532 1 L
s
1 0 0 r
.50339 .42766 m
.51847 .41939 L
s
% Start of user PostScript
0.1016863 -2.1702308 0.55405436 -2.4181924 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53445 .41483 m
.55051 .41475 L
s
% Start of user PostScript
1.0336126 -2.5549571 1.5153823 -2.557563 MAarrowhead1
% End of user PostScript
1 .473 0 r
.58306 .55612 m
.5666 .58966 L
s
% Start of user PostScript
2.4918711 1.6835623 1.9980709 2.689742 MAarrowhead1
% End of user PostScript
1 .788 0 r
.33606 .68402 m
.30634 .65588 L
s
% Start of user PostScript
-4.9180931 5.5205838 -5.8098604 4.6763102 MAarrowhead1
% End of user PostScript
.897 1 0 r
.41292 .19175 m
.48282 .12439 L
s
% Start of user PostScript
-2.6122702 -9.2475191 -0.51543256 -11.268235 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
15.579079 -7.1819151 16.22896 -3.1771563 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-6.081013 31.214185 -12.330692 33.318521 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-37.20301 -6.888736 -33.68154 -19.555338 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
48.008427 -79.020197 62.017199 -74.022806 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
60.506977 85.586751 39.081411 115.78971 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-181.6971 142.38179 -201.64811 103.2419 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-10.735956 -353.12217 64.385887 -402.10496 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
502.98792 -88.247173 493.65768 59.591813 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-396.40896 1034.554 -592.71673 1042.6123 MAarrowhead1
% End of user PostScript
0 1 .574 r
.61137 .53468 m
.59786 .57441 L
.57672 .61499 L
.54818 .65412 L
.51298 .68927 L
.47231 .71781 L
.42788 .73717 L
.38184 .74495 L
.33671 .73916 L
.29531 .71834 L
.2606 .68173 L
.23555 .6294 L
.22294 .56239 L
.22517 .48274 L
.24409 .39351 L
.28079 .29875 L
.33544 .20337 L
.40719 .11299 L
.49403 .03365 L
s
.49403 .03365 m
.54754 0 L
s
.99961 0 m
1 .00024 L
s
1 0 0 r
.61137 .53468 m
.59786 .57441 L
s
% Start of user PostScript
3.3409861 1.0403418 2.9357442 2.232293 MAarrowhead1
% End of user PostScript
1 .158 0 r
.57672 .61499 m
.54818 .65412 L
s
% Start of user PostScript
2.3014673 3.4498244 1.4454859 4.6237327 MAarrowhead1
% End of user PostScript
1 .473 0 r
.2606 .68173 m
.23555 .6294 L
s
% Start of user PostScript
-7.181922 5.4519245 -7.9333826 3.8821283 MAarrowhead1
% End of user PostScript
1 .788 0 r
.49403 .03365 m
0 0 rlineto s
.49403 .03365 m
.54754 0 L
s
% Start of user PostScript
-0.17920931 -13.990623 2.7834215 -15.853387 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
19.674122 -2.9820056 19.210038 2.8612807 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-16.15969 40.553615 -23.820281 40.672963 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-39.806638 -26.20763 -32.063283 -42.192313 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
77.608115 -88.061137 91.879888 -74.860467 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
42.539237 145.75074 9.4148663 178.03216 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-246.95438 116.05116 -257.72162 52.8538 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
93.321458 -494.38577 192.47329 -528.66268 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
592.32968 102.85404 537.70288 303.64493 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-754.86093 1256.8521 -978.16228 1180.1316 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-971.40981 -1343.0444 -633.97718 -1823.9352 MAarrowhead1
% End of user PostScript
.476 0 1 r
.20484 .69119 m
.1809 .62243 L
.17279 .53722 L
.18313 .43844 L
.21373 .33018 L
.26548 .21763 L
.33811 .10694 L
.43006 .00495 L
s
.43006 .00495 m
.43629 0 L
s
1 0 0 r
.20484 .69119 m
.1809 .62243 L
s
% Start of user PostScript
-8.8546879 5.7356061 -9.5730514 3.672883 MAarrowhead1
% End of user PostScript
1 .158 0 r
.17279 .53722 m
.18313 .43844 L
s
% Start of user PostScript
-9.8161601 1.1164736 -9.5062365 -1.8469005 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
8.5799879 -20.302938 12.388002 -20.207656 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
19.423319 14.144001 15.358791 22.118666 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-39.757445 43.221469 -46.669588 36.214875 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-19.158155 -75.018289 -2.2610635 -90.767198 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
124.2822 -54.013036 128.77424 -21.641541 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-53.08142 249.62281 -102.81332 265.04234 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-292.92035 -64.390272 -263.05142 -165.43202 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
392.13846 -624.06272 502.05084 -580.48307 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
464.44061 703.06803 290.24847 940.85402 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1458.9192 1101.4926 -1610.3031 781.83338 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-28.047655 -2843.1411 573.54591 -3219.0377 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3989.4855 -588.5051 3891.9643 598.47547 MAarrowhead1
% End of user PostScript
0 1 .326 r
.62256 .1746 m
.68442 .1714 L
.74352 .18736 L
.79597 .22409 L
.83775 .28217 L
.86495 .36097 L
.87401 .45856 L
.86197 .57161 L
.82674 .69544 L
.76733 .82411 L
.68407 .95057 L
s
.68407 .95057 m
.63937 1 L
s
1 0 0 r
.62256 .1746 m
.68442 .1714 L
s
% Start of user PostScript
3.6767613 -9.7619251 5.5326379 -9.858129 MAarrowhead1
% End of user PostScript
1 .158 0 r
.74352 .18736 m
.79597 .22409 L
s
% Start of user PostScript
7.3056741 -9.3792375 8.8791023 -8.2772371 MAarrowhead1
% End of user PostScript
1 .473 0 r
.68407 .95057 m
0 0 rlineto s
.68407 .95057 m
.63937 1 L
s
% Start of user PostScript
5.5222236 13.51724 2.3625506 17.010332 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-24.531391 14.058092 -26.134923 8.1069399 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
5.7457442 -48.638616 15.69142 -53.098387 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
61.821597 2.9406548 57.765133 22.891101 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-67.927555 129.7253 -91.530415 124.96757 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-110.5731 -117.75777 -79.575435 -167.96306 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
278.20527 -252.99173 316.13649 -197.57878 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
65.171491 534.16228 -51.183575 623.74794 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-811.38376 235.733 -816.04021 9.304016 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
509.38029 -1651.464 829.6061 -1703.3951 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1774.5687 756.56169 1516.2741 1415.9999 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2886.152 3848.9963 -3538.0656 3432.1904 MAarrowhead1
% End of user PostScript
1 .746 0 r
.304 .6607 m
.28098 .6194 L
.26795 .56548 L
.26703 .50047 L
.27988 .42678 L
.30756 .34764 L
.35041 .26705 L
.40789 .18963 L
.47851 .1204 L
.55982 .0646 L
.64838 .02733 L
.73989 .01329 L
.82928 .0264 L
.91093 .06951 L
.97895 .14402 L
s
.97895 .14402 m
1 .18988 L
s
1 .73511 m
.9303 .91055 L
s
.9303 .91055 m
.87804 1 L
s
1 0 0 r
.304 .6607 m
.28098 .6194 L
s
% Start of user PostScript
-5.8800478 4.8210847 -6.5707259 3.581988 MAarrowhead1
% End of user PostScript
1 .158 0 r
.26795 .56548 m
.26703 .50047 L
s
% Start of user PostScript
-6.9615114 1.9642901 -6.9891689 0.01405473 MAarrowhead1
% End of user PostScript
1 .473 0 r
.64838 .02733 m
.73989 .01329 L
s
% Start of user PostScript
4.4515275 -14.18009 7.1967828 -14.601361 MAarrowhead1
% End of user PostScript
1 .788 0 r
1 .73511 m
.9303 .91055 L
s
% Start of user PostScript
15.156787 6.6586811 12.909129 12.31642 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-24.925092 32.911381 -30.485664 29.269343 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-20.110591 -45.947423 -9.2958683 -58.245122 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
84.769566 -50.584995 90.734123 -30.279478 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-17.059675 167.69944 -51.503919 183.94698 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-215.9929 -4.3909719 -203.06199 -73.334591 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
229.13071 -452.13902 311.81867 -437.96926 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
393.25559 394.50352 288.14112 569.92227 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-955.58653 895.24068 -1091.4154 708.29651 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-260.43072 -1829.8602 140.22866 -2148.5191 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2817.9113 -885.21994 2848.1232 -107.42673 MAarrowhead1
% End of user PostScript
.382 0 1 r
.53058 .39436 m
.55117 .39041 L
.57146 .39246 L
.59018 .4012 L
.60602 .417 L
.61765 .43984 L
.6238 .46932 L
.6234 .50456 L
.61558 .54421 L
.59983 .5865 L
.57602 .62927 L
.54451 .67003 L
.50616 .70606 L
.46232 .73461 L
.4149 .75297 L
.36624 .75869 L
.31908 .74974 L
.27643 .72471 L
.24143 .68294 L
.21719 .6247 L
.20659 .55127 L
.21208 .465 L
.23547 .36934 L
.27774 .26873 L
.3389 .16852 L
.41782 .07473 L
s
.41782 .07473 m
.50492 0 L
s
1 0 0 r
.53058 .39436 m
.55117 .39041 L
s
% Start of user PostScript
0.91738349 -3.1690768 1.5352205 -3.2877533 MAarrowhead1
% End of user PostScript
1 .158 0 r
.57146 .39246 m
.59018 .4012 L
s
% Start of user PostScript
2.1437664 -3.2261611 2.7054924 -2.9639709 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57602 .62927 m
.54451 .67003 L
s
% Start of user PostScript
2.2806246 3.8781488 1.3354052 5.1007507 MAarrowhead1
% End of user PostScript
1 .788 0 r
.24143 .68294 m
.21719 .6247 L
s
% Start of user PostScript
-7.7570623 5.4882037 -8.4842149 3.7410187 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
0.36408945 -15.185626 3.5487266 -17.03066 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
20.777815 -2.0694964 20.059809 4.2409802 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-18.570395 43.02987 -26.619611 42.70572 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-40.76702 -30.783317 -32.004608 -47.662698 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
84.973697 -90.920679 99.439611 -75.757425 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
38.9176 160.60829 2.8588762 193.66115 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-263.91174 111.25281 -272.72386 42.067853 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
117.51419 -530.71275 222.98815 -562.02038 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
617.95441 146.63459 552.66374 361.18907 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-842.3054 1318.5551 -1073.7691 1222.1175 MAarrowhead1
% End of user PostScript
0 .637 1 r
.5552 .68001 m
.51414 .72072 L
.46677 .75369 L
.41508 .77592 L
.36157 .78466 L
.30918 .77758 L
.26121 .753 L
.22108 .71007 L
.19225 .64889 L
.17793 .57068 L
.18091 .47785 L
.20332 .37398 L
.24641 .26379 L
.31035 .15302 L
.39412 .04819 L
s
.39412 .04819 m
.44724 0 L
s
1 0 0 r
.5552 .68001 m
.51414 .72072 L
s
% Start of user PostScript
1.6559709 5.4003227 0.42421846 6.6216738 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46677 .75369 m
.41508 .77592 L
s
% Start of user PostScript
-0.99683885 7.6107522 -2.5476597 8.2776459 MAarrowhead1
% End of user PostScript
1 .473 0 r
.18091 .47785 m
.20332 .37398 L
s
% Start of user PostScript
-9.572617 -0.66443373 -8.9003747 -3.7806046 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
10.809351 -20.125973 14.456116 -19.302098 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
16.874973 18.835274 11.961998 26.6088 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-43.661255 38.771009 -49.417183 29.954083 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-8.9279086 -84.00483 9.2971957 -97.675215 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
126.23775 -34.311665 126.46321 1.2221246 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-82.544764 257.38087 -132.2765 264.47469 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-273.30633 -124.50847 -231.83975 -227.1016 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
455.63215 -594.28362 555.73098 -526.75965 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
357.40037 841.2893 159.98608 1063.0324 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1540.9432 903.59167 -1646.0022 532.41938 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
332.32071 -3051.4159 957.84178 -3340.1168 MAarrowhead1
% End of user PostScript
.095 0 1 r
.45675 .48416 m
.4625 .46842 L
.47125 .45247 L
.48288 .43723 L
.49707 .42371 L
.51334 .41294 L
.53097 .40592 L
.54911 .40358 L
.56673 .40668 L
.58271 .41575 L
.5959 .43106 L
.60512 .45252 L
.60929 .47967 L
.60751 .51164 L
.59908 .54718 L
.58361 .58464 L
.56111 .62203 L
.53196 .65713 L
.49702 .68753 L
.45761 .71079 L
.41548 .72458 L
.37278 .72682 L
.33198 .71582 L
.29577 .69049 L
.26692 .65043 L
.24812 .59606 L
.24185 .52872 L
.25014 .4507 L
.27443 .36524 L
.3154 .27644 L
.37284 .18914 L
.44552 .10876 L
.53112 .041 L
s
.53112 .041 m
.61009 0 L
s
.91106 0 m
.92063 .00354 L
s
.92063 .00354 m
1 .0709 L
s
1 .89346 m
.94552 1 L
s
1 0 0 r
.45675 .48416 m
.4625 .46842 L
s
% Start of user PostScript
-1.297486 -0.47531493 -1.1250623 -0.94741741 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47125 .45247 m
.48288 .43723 L
s
% Start of user PostScript
-0.86258578 -1.4258789 -0.51371933 -1.8830123 MAarrowhead1
% End of user PostScript
1 .473 0 r
.5959 .43106 m
.60512 .45252 L
s
% Start of user PostScript
2.8768899 -2.0681394 3.1534748 -1.424377 MAarrowhead1
% End of user PostScript
1 .788 0 r
.49702 .68753 m
.45761 .71079 L
s
% Start of user PostScript
-0.08946673 5.625852 -1.2718104 6.3237639 MAarrowhead1
% End of user PostScript
.897 1 0 r
.24185 .52872 m
.25014 .4507 L
s
% Start of user PostScript
-7.7444973 0.86159311 -7.4959186 -1.4788576 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
6.7960341 -16.02167 9.799648 -15.938469 MAarrowhead1
% End of user PostScript
.266 1 0 r
1 .89346 m
.94552 1 L
s
% Start of user PostScript
15.301409 11.214335 12.08426 17.505942 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-31.420492 34.062647 -36.863039 28.512978 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-15.007776 -59.305093 -1.6575627 -71.711721 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
98.108255 -42.412156 101.60664 -16.828994 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-42.216808 197.09408 -81.466532 209.17216 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-230.96505 -51.47869 -207.26435 -131.24053 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
310.18325 -492.19969 396.82122 -457.54254 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
365.37328 556.39767 227.64124 743.88845 MAarrowhead1
% End of user PostScript
1 .322 0 r
.47815 .57987 m
.46251 .58326 L
.44702 .58214 L
.43263 .57597 L
.42034 .56445 L
.41116 .54755 L
.40607 .52556 L
.40589 .49913 L
.41131 .46922 L
.42273 .43717 L
.44028 .4046 L
.46374 .37338 L
.49247 .34556 L
.52549 .32324 L
.56138 .30849 L
.59838 .3032 L
.63445 .30894 L
.6673 .32684 L
.69455 .35744 L
.71382 .40063 L
.72291 .45549 L
.71991 .52031 L
.70341 .59255 L
.67257 .66889 L
.62733 .74532 L
.56848 .8173 L
.49771 .87994 L
.41765 .92826 L
.33185 .95748 L
.24464 .9633 L
.16106 .94227 L
.08656 .89206 L
.02679 .81179 L
s
.02679 .81179 m
0 .73749 L
s
0 .36583 m
.03635 .23391 L
.11827 .05278 L
s
.11827 .05278 m
.15244 0 L
s
1 0 0 r
.47815 .57987 m
.46251 .58326 L
s
% Start of user PostScript
-0.6555831 2.3960374 -1.124823 2.4978013 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44702 .58214 m
.43263 .57597 L
s
% Start of user PostScript
-1.5894609 2.4641545 -2.0211747 2.2790741 MAarrowhead1
% End of user PostScript
1 .473 0 r
.44028 .4046 m
.46374 .37338 L
s
% Start of user PostScript
-1.7914653 -2.8619398 -1.0878991 -3.7985076 MAarrowhead1
% End of user PostScript
1 .788 0 r
.69455 .35744 m
.71382 .40063 L
s
% Start of user PostScript
5.8364121 -4.2766982 6.4146245 -2.981141 MAarrowhead1
% End of user PostScript
.897 1 0 r
.49771 .87994 m
.41765 .92826 L
s
% Start of user PostScript
-0.068646039 11.398194 -2.4703791 12.847842 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-15.80693 1.9809362 -15.3465 -2.7673412 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
13.56129 -32.659631 19.700294 -32.58253 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
31.493098 22.249495 25.047135 35.091414 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-63.51061 69.952153 -74.744042 58.87666 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-31.868993 -119.6689 -4.8421215 -145.20556 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
199.60499 -88.894427 207.27243 -37.180819 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-82.262531 400.50988 -162.21682 426.16938 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-472.97797 -97.242635 -426.16863 -259.52603 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
623.81279 -1006.419 801.54436 -938.85616 MAarrowhead1
% End of user PostScript
1 0 .32 r
.67423 .19183 m
.72959 .20721 L
.77862 .24209 L
.81757 .297 L
.84276 .37133 L
.85086 .46323 L
.83912 .56956 L
.8056 .68589 L
.74938 .80663 L
.67081 .92516 L
s
.67081 .92516 m
.60265 1 L
s
1 0 0 r
.67423 .19183 m
.72959 .20721 L
s
% Start of user PostScript
5.2270395 -9.2450092 6.8876633 -8.7837141 MAarrowhead1
% End of user PostScript
1 .158 0 r
.77862 .24209 m
.81757 .297 L
s
% Start of user PostScript
8.3586401 -7.7371678 9.5269947 -6.0898576 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.1476089 16.023475 -1.3534455 18.771793 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-24.538292 7.4738872 -24.751868 0.67060381 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
14.924737 -49.880188 24.622303 -51.594441 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
54.073751 21.888907 46.448926 41.832627 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-86.322973 117.06758 -106.23211 104.85246 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-73.947383 -158.55441 -36.375278 -202.4315 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
297.21914 -184.06531 319.54696 -113.73552 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-50.475701 586.73845 -171.49947 646.50072 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-765.21648 3.8853733 -723.50814 -237.85737 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
784.6785 -1598.208 1078.3646 -1556.1133 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1416.1354 1341.7275 1054.2642 1963.2349 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3331.2095 3209.1061 -3823.3417 2568.8059 MAarrowhead1
% End of user PostScript
1 0 .53 r
.31091 .17986 m
.38899 .07867 L
s
.38899 .07867 m
.47254 0 L
s
1 0 0 r
.31091 .17986 m
.38899 .07867 L
s
% Start of user PostScript
-5.6725954 -9.604328 -3.3303713 -12.63991 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-0.47767181 -15.325875 2.7833469 -17.45549 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
21.842308 -3.8545096 21.441862 2.5625281 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-17.182948 44.921458 -25.708487 45.280714 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-44.83457 -27.531674 -36.532344 -45.278967 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
84.643894 -98.813854 100.79396 -84.773926 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
50.253401 158.44805 14.020581 194.81061 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-272.60679 134.53653 -285.84961 65.60465 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
94.05741 -544.54161 203.75356 -585.0601 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
661.43743 95.043873 604.61815 316.70398 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-815.33548 1399.7983 -1065.4441 1322.386 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1108.0949 -1442.765 -742.02011 -1979.7989 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3153.9021 -2584.2819 3524.0216 -1919.454 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
343.50846 6108.4758 -964.75465 7005.7558 MAarrowhead1
% End of user PostScript
0 1 .563 r
.23045 .63069 m
.21785 .56223 L
.22039 .48095 L
.23996 .38997 L
.27763 .29345 L
.33358 .19639 L
.40691 .10451 L
.49555 .02399 L
s
.49555 .02399 m
.53398 0 L
s
1 0 0 r
.23045 .63069 m
.21785 .56223 L
s
% Start of user PostScript
-8.0865193 3.9207977 -8.4645664 1.8669821 MAarrowhead1
% End of user PostScript
1 .158 0 r
.22039 .48095 m
.23996 .38997 L
s
% Start of user PostScript
-8.3881523 -0.57163617 -7.8013234 -3.3008623 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
9.4571158 -17.63372 12.653053 -16.916199 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
14.799429 16.474257 10.50009 23.285949 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-38.229321 33.994084 -43.278986 26.280096 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-7.8821069 -73.545031 8.0773718 -85.534105 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
110.58734 -30.176968 110.80999 0.93611952 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-72.145293 225.44971 -115.71604 231.71372 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-239.56339 -108.72988 -203.30216 -198.60418 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
398.81261 -520.83642 486.56852 -461.81859 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
313.75418 736.25289 140.93317 930.61991 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1349.5613 792.81578 -1441.8779 467.92924 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
289.02977 -2672.1667 836.91764 -2925.6154 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3423.9318 105.89917 3211.2908 1203.4824 MAarrowhead1
% End of user PostScript
0 .832 1 r
.53479 .43019 m
.54759 .4322 L
.55925 .43851 L
.56894 .44933 L
.5758 .46461 L
.57906 .48404 L
.57803 .507 L
.57222 .53261 L
.56132 .55968 L
.54532 .5868 L
.52448 .61235 L
.49941 .6346 L
.47104 .65179 L
.44061 .66221 L
.40968 .66435 L
.38001 .65698 L
.35355 .63925 L
.3323 .61087 L
.31822 .57209 L
.31311 .52386 L
.31846 .46777 L
.33535 .40614 L
.36431 .3419 L
.40522 .27854 L
.45723 .21995 L
.51871 .17026 L
.58726 .13361 L
.65973 .11394 L
.73233 .11467 L
.80074 .13848 L
.86033 .18701 L
.90636 .26068 L
.93428 .35843 L
.94002 .47763 L
.92029 .61404 L
.87286 .76181 L
.79689 .91365 L
s
.79689 .91365 m
.73607 1 L
s
1 0 0 r
.53479 .43019 m
.54759 .4322 L
s
% Start of user PostScript
1.0436258 -2.0941631 1.42759 -2.0341158 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55925 .43851 m
.56894 .44933 L
s
% Start of user PostScript
1.7775419 -1.8447656 2.0680829 -1.5201884 MAarrowhead1
% End of user PostScript
1 .473 0 r
.52448 .61235 m
.49941 .6346 L
s
% Start of user PostScript
0.73445507 3.3703785 -0.017669979 4.0379627 MAarrowhead1
% End of user PostScript
1 .788 0 r
.31822 .57209 m
.31311 .52386 L
s
% Start of user PostScript
-5.453303 2.1628202 -5.606681 0.71566588 MAarrowhead1
% End of user PostScript
.897 1 0 r
.58726 .13361 m
.65973 .11394 L
s
% Start of user PostScript
2.6177381 -10.991662 4.7920035 -11.581866 MAarrowhead1
% End of user PostScript
.581 1 0 r
.92029 .61404 m
.87286 .76181 L
s
% Start of user PostScript
12.608672 3.4212015 11.185889 7.854363 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-17.784304 26.98366 -22.490714 24.836977 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-19.226121 -32.131428 -11.37637 -42.365641 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
64.610516 -46.161882 70.761967 -31.667134 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-2.4067716 126.40115 -28.949522 141.95621 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-173.59316 18.529411 -167.85596 -34.032972 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
153.42437 -359.27222 220.72064 -357.08073 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
342.05842 253.62223 269.52182 394.64732 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-706.47598 762.00619 -828.03095 636.72379 MAarrowhead1
% End of user PostScript
1 0 .864 r
.17786 .47326 m
.20141 .36783 L
.2459 .25624 L
.31146 .14433 L
.39701 .03873 L
s
.39701 .03873 m
.44033 0 L
s
1 0 0 r
.17786 .47326 m
.20141 .36783 L
s
% Start of user PostScript
-9.6642248 -0.80226685 -8.957802 -3.9652307 MAarrowhead1
% End of user PostScript
1 .158 0 r
.2459 .25624 m
.31146 .14433 L
s
% Start of user PostScript
-7.6231078 -7.3128655 -5.6560853 -10.670119 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
18.057807 -17.291564 20.703534 -13.807157 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
5.4425335 34.509311 -2.1430122 40.687017 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-53.691291 17.804039 -54.464777 3.1053081 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
30.635381 -108.87054 51.9095 -113.22627 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
120.0266 43.722045 104.12852 87.362847 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-184.8335 258.94634 -229.21074 233.86073 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-169.87326 -337.95067 -89.108961 -435.35302 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
646.16413 -417.9395 698.45699 -267.33485 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-84.974352 1272.2756 -348.76096 1409.6118 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1684.557 59.568958 -1603.5064 -466.02096 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1656.3356 -3508.8066 2304.8028 -3437.4086 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3177.6283 2806.9754 2408.6235 4175.265 MAarrowhead1
% End of user PostScript
0 .467 1 r
.26582 .80285 m
.21492 .76781 L
.17424 .71213 L
.14758 .63639 L
.13838 .54243 L
.14952 .43343 L
.18305 .31389 L
.23994 .18953 L
.31992 .06712 L
s
.31992 .06712 m
.38019 0 L
s
1 0 0 r
.26582 .80285 m
.21492 .76781 L
s
% Start of user PostScript
-7.0253599 9.0854787 -8.5523703 8.0342962 MAarrowhead1
% End of user PostScript
1 .158 0 r
.17424 .71213 m
.14758 .63639 L
s
% Start of user PostScript
-9.7726659 6.3640129 -10.572634 4.0918061 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.2252014 -19.23403 5.2163819 -21.329066 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
25.528183 -1.024723 24.325671 6.9244443 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-24.93056 53.150563 -34.762235 52.119445 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-48.298342 -42.186709 -36.710718 -62.922328 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
108.63488 -108.78284 125.55553 -88.434976 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
39.369456 206.71961 -6.4460087 245.86796 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-328.61184 120.79111 -335.84116 32.35535 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
171.0305 -664.12692 301.68678 -695.71518 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
748.54585 233.59232 657.6452 500.71335 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1098.2749 1607.6351 -1376.5219 1467.4822 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1105.4771 -1995.2353 -622.95085 -2602.7582 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3920.7962 -2681.7802 4268.8708 -1786.7628 MAarrowhead1
% End of user PostScript
1 .791 0 r
.74135 .38643 m
.75191 .44817 L
.74885 .52123 L
.73054 .60275 L
.69604 .68899 L
.64526 .77545 L
.57905 .85699 L
.49932 .9281 L
.40901 .98315 L
s
.40901 .98315 m
.36034 1 L
s
.11754 1 m
.03432 .94485 L
s
.03432 .94485 m
0 .89943 L
s
0 .14619 m
.06553 0 L
s
1 0 0 r
.74135 .38643 m
.75191 .44817 L
s
% Start of user PostScript
7.2406222 -3.4071518 7.5572784 -1.5548156 MAarrowhead1
% End of user PostScript
1 .158 0 r
.74885 .52123 m
.73054 .60275 L
s
% Start of user PostScript
7.4654069 0.63688003 6.9160918 3.0824152 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-8.5952607 15.717788 -11.434746 15.02578 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-13.020387 -15.030485 -9.1246242 -21.092611 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
34.381259 -30.00766 38.803466 -22.997249 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
6.3021241 66.247424 -8.0294103 76.794284 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-98.790356 25.515455 -98.684844 -2.4648138 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
66.458367 -201.66852 105.32624 -206.66296 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
212.30772 101.27924 179.13371 181.56344 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-360.29215 462.49663 -437.8765 408.1422 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-272.25885 -666.63702 -116.43619 -838.88125 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1209.7415 -693.13574 1288.7917 -399.64435 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-283.52026 2398.5891 -773.97674 2618.4661 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3048.5238 -145.37581 -2848.4154 -1129.2123 MAarrowhead1
% End of user PostScript
.919 0 1 r
.41787 .18597 m
.48871 .11944 L
.56965 .06673 L
.65722 .03285 L
.74707 .02232 L
.83415 .03887 L
.9129 .08513 L
.97751 .16229 L
s
.97751 .16229 m
1 .21637 L
s
1 .69407 m
.98841 .74144 L
.91031 .92723 L
s
.91031 .92723 m
.86588 1 L
s
1 0 0 r
.41787 .18597 m
.48871 .11944 L
s
% Start of user PostScript
-2.4639813 -9.420762 -0.33882279 -11.416898 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56965 .06673 m
.65722 .03285 L
s
% Start of user PostScript
2.0895035 -12.997953 4.7165469 -14.014369 MAarrowhead1
% End of user PostScript
1 .473 0 r
1 .69407 m
.98841 .74144 L
s
% Start of user PostScript
15.948862 1.9435182 14.652302 7.24333 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-19.174643 33.687633 -25.218631 31.966218 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-27.129293 -33.78709 -18.490888 -46.736934 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
75.076946 -62.984266 84.197009 -47.347746 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
10.220336 145.1356 -20.978028 167.10643 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-212.72801 48.405646 -211.1211 -12.688959 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
152.21344 -435.47686 235.65973 -443.50587 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
449.46259 236.88911 374.48828 409.75504 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-794.06205 983.31025 -957.45469 858.86862 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-549.88762 -1475.938 -207.83516 -1840.5427 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2623.7599 -1424.0815 2778.4869 -777.31167 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-725.28799 5216.9711 -1786.0019 5660.8193 MAarrowhead1
% End of user PostScript
.025 0 1 r
.7595 .25646 m
.79648 .30717 L
.8207 .37614 L
.82902 .46167 L
.81882 .56088 L
.78825 .66967 L
.73643 .78282 L
.6636 .89417 L
.57132 .99685 L
s
.57132 .99685 m
.56736 1 L
s
1 0 0 r
.7595 .25646 m
.79648 .30717 L
s
% Start of user PostScript
7.7851305 -7.3062381 8.8944129 -5.7848554 MAarrowhead1
% End of user PostScript
1 .158 0 r
.8207 .37614 m
.82902 .46167 L
s
% Start of user PostScript
9.6209624 -3.7159142 9.87049 -1.1498923 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-4.7573965 19.410591 -8.5895312 20.410233 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-22.12712 -6.3229485 -19.562928 -14.143944 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
31.654327 -47.413431 39.901514 -43.513174 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
33.364125 57.305402 19.415752 75.264955 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-114.27571 80.395346 -124.89178 54.597261 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5.9988183 -223.79701 52.896982 -250.78765 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
305.55782 -29.176221 294.73341 63.787785 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-274.8476 633.03018 -393.17119 627.73885 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-598.03594 -456.31556 -468.49521 -704.54079 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1253.1284 -1334.6529 1465.1572 -1110.2392 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
565.32284 2369.6819 33.791081 2854.5453 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3884.6917 1622.9078 -4011.3017 602.63156 MAarrowhead1
% End of user PostScript
0 .907 1 r
.75628 .73319 m
.69282 .84442 L
.60942 .94993 L
s
.60942 .94993 m
.55485 1 L
s
1 0 0 r
.75628 .73319 m
.69282 .84442 L
s
% Start of user PostScript
7.688446 6.9957147 5.7847257 10.332711 MAarrowhead1
% End of user PostScript
1 .158 0 r
.60942 .94993 m
0 0 rlineto s
.60942 .94993 m
.55485 1 L
s
% Start of user PostScript
3.282547 13.497817 0.25144736 16.279388 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-22.191855 9.3746316 -22.936984 3.5595238 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
9.8542683 -44.623012 18.724126 -47.263779 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
51.98574 12.273903 46.506172 30.315432 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-70.773284 110.91263 -90.247641 102.82553 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-81.428612 -127.21024 -50.0558 -169.40948 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
261.28079 -193.85559 287.67215 -136.16661 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
0.26884891 509.81998 -107.34178 575.71712 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-710.46229 95.581014 -691.14906 -116.99134 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
600.41145 -1466.7082 876.58599 -1465.9717 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1423.2116 981.20718 1137.0337 1558.4156 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2836.3072 3156.6991 -3344.8842 2666.3047 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1468.8105 -5338.1701 -260.57693 -6492.2487 MAarrowhead1
% End of user PostScript
.152 0 1 r
.38415 .54101 m
.38193 .50963 L
.38646 .4735 L
.39837 .43413 L
.41792 .39346 L
.44496 .35372 L
.47889 .31741 L
.5186 .28716 L
.56249 .26557 L
.60849 .25509 L
.65415 .25782 L
.69669 .27536 L
.73317 .30863 L
.7606 .35774 L
.77614 .42187 L
.77728 .4992 L
.76204 .58688 L
.72914 .68104 L
.6782 .77695 L
.60984 .86912 L
.52584 .95154 L
s
.52584 .95154 m
.45531 1 L
s
1 0 0 r
.38415 .54101 m
.38193 .50963 L
s
% Start of user PostScript
-3.4754745 1.2303057 -3.5419702 0.28889462 MAarrowhead1
% End of user PostScript
1 .158 0 r
.38646 .4735 m
.39837 .43413 L
s
% Start of user PostScript
-3.4060888 -0.79509254 -3.0489876 -1.9759944 MAarrowhead1
% End of user PostScript
1 .473 0 r
.65415 .25782 m
.69669 .27536 L
s
% Start of user PostScript
4.6243807 -7.2652651 5.9006804 -6.7391907 MAarrowhead1
% End of user PostScript
1 .788 0 r
.6782 .77695 m
.60984 .86912 L
s
% Start of user PostScript
5.3458898 8.3086321 3.295275 11.07353 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-17.093679 12.718869 -18.827938 8.9493928 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-0.068189705 -33.346999 6.973365 -37.673309 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
46.523134 -6.3576319 45.27928 7.5494809 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-39.179181 96.025913 -57.267651 96.018841 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-93.312374 -63.968408 -74.626062 -101.76588 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
185.4543 -206.90001 218.81284 -174.89928 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
96.731201 348.94812 17.710932 424.61556 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-585.96406 267.15767 -609.78069 116.14629 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
232.85811 -1174.589 467.80939 -1252.4994 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1395.7876 267.64316 1261.729 744.05687 MAarrowhead1
% End of user PostScript
1 0 .988 r
.6661 .43332 m
.67094 .4773 L
.66623 .52848 L
.65098 .58478 L
.6247 .64352 L
.58748 .70152 L
.54009 .75523 L
.48399 .80087 L
.42139 .83464 L
.35513 .85295 L
.28869 .85265 L
.22601 .83128 L
.17132 .78731 L
.12895 .72035 L
.10307 .63133 L
.09741 .52263 L
.11501 .3981 L
.15791 .26307 L
.22693 .1242 L
s
.22693 .1242 m
.31388 0 L
s
1 0 0 r
.6661 .43332 m
.67094 .4773 L
s
% Start of user PostScript
4.9829877 -2.0003655 5.1282189 -0.68112759 MAarrowhead1
% End of user PostScript
1 .158 0 r
.66623 .52848 m
.65098 .58478 L
s
% Start of user PostScript
4.9869581 0.85438488 4.5294838 2.5433959 MAarrowhead1
% End of user PostScript
1 .473 0 r
.28869 .85265 m
.22601 .83128 L
s
% Start of user PostScript
-6.3392332 10.579568 -8.2196986 9.9384625 MAarrowhead1
% End of user PostScript
1 .788 0 r
.22693 .1242 m
0 0 rlineto s
.22693 .1242 m
.31388 0 L
s
% Start of user PostScript
-8.192153 -11.274131 -5.3574939 -15.322881 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
24.163435 -19.218886 26.876585 -14.050418 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1.8232144 46.907908 -8.1778605 53.540366 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-67.2257 12.55224 -66.138612 -7.1090225 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
51.925557 -138.12972 78.191481 -139.52266 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
138.80271 82.75494 113.62336 137.3784 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-258.5932 305.45421 -308.68643 263.02216 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-158.50187 -483.4047 -47.671998 -595.9837 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
837.04212 -421.28823 879.43333 -210.68968 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-277.39228 1670.4941 -614.5275 1798.3222 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2040.6069 -268.27222 -1870.5785 -948.89735 MAarrowhead1
% End of user PostScript
.571 1 0 r
.38955 .60553 m
.37342 .58418 L
.36268 .55498 L
.35871 .5186 L
.36264 .47628 L
.37528 .42973 L
.39704 .38118 L
.42784 .33325 L
.46704 .28888 L
.51343 .25119 L
.56519 .22332 L
.61996 .20825 L
.67487 .20856 L
.72666 .2263 L
.77183 .26272 L
.8068 .31814 L
.82813 .39179 L
.83273 .48169 L
.8181 .58466 L
.78255 .69629 L
.72542 .81108 L
.64724 .92259 L
s
.64724 .92259 m
.57274 1 L
s
1 0 0 r
.38955 .60553 m
.37342 .58418 L
s
% Start of user PostScript
-3.3135589 3.1658069 -3.7975339 2.5255049 MAarrowhead1
% End of user PostScript
1 .158 0 r
.36268 .55498 m
.35871 .5186 L
s
% Start of user PostScript
-4.1194777 1.6493353 -4.2386164 0.55814437 MAarrowhead1
% End of user PostScript
1 .473 0 r
.56519 .22332 m
.61996 .20825 L
s
% Start of user PostScript
1.9558451 -8.3003151 3.5988972 -8.7526313 MAarrowhead1
% End of user PostScript
1 .788 0 r
.8181 .58466 m
.78255 .69629 L
s
% Start of user PostScript
9.5430055 2.5397734 8.4766251 5.8886554 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-13.391145 20.413622 -16.955129 18.809561 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-14.609951 -24.176363 -8.6956412 -31.922327 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
48.7628 -35.033672 53.446448 -24.119303 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1.5456204 95.361149 -21.585349 107.18191 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-131.24324 14.543626 -127.01853 -25.126581 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
115.25005 -271.52425 166.14904 -270.09031 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
259.23978 190.21068 204.68877 296.83219 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-532.63224 577.1368 -624.83288 483.02348 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-254.01158 -1005.378 -27.712977 -1215.5734 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1662.7709 -718.14167 1721.9206 -284.4629 MAarrowhead1
% End of user PostScript
0 1 .359 r
.39054 .41701 m
.41414 .37164 L
.446 .32789 L
.48533 .28858 L
.53076 .25664 L
.58041 .23496 L
.63188 .22621 L
.68233 .23261 L
.72863 .25581 L
.76746 .29667 L
.79551 .35509 L
.80966 .42993 L
.80724 .51892 L
.78617 .61862 L
.74523 .72453 L
.68422 .83115 L
.60409 .93221 L
s
.60409 .93221 m
.53 1 L
s
1 0 0 r
.39054 .41701 m
.41414 .37164 L
s
% Start of user PostScript
-3.2837788 -2.489835 -2.5758059 -3.8507894 MAarrowhead1
% End of user PostScript
1 .158 0 r
.446 .32789 m
.48533 .28858 L
s
% Start of user PostScript
-1.6199554 -5.1633051 -0.44022628 -6.3426584 MAarrowhead1
% End of user PostScript
1 .473 0 r
.79551 .35509 m
.80966 .42993 L
s
% Start of user PostScript
8.8651536 -4.3472495 9.2899277 -2.1019922 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-3.0975621 17.713649 -6.6638116 19.019688 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-21.477051 -3.1709705 -19.614202 -10.379289 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
26.592387 -45.467643 34.71025 -42.918662 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
35.880106 47.091051 23.947604 64.528529 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-102.64478 83.748796 -114.61499 62.065605 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-10.681589 -198.86898 31.882647 -227.92219 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
288.05542 -59.384162 284.57902 24.139612 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-214.69628 590.82854 -327.45639 599.13155 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-601.35523 -338.49386 -496.49587 -572.56043 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1092.4287 -1319.6292 1310.218 -1144.1488 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
710.31816 2036.6974 241.00321 2524.4773 MAarrowhead1
% End of user PostScript
0 1 .302 r
.78074 .6759 m
.72802 .78748 L
.65467 .89677 L
.56234 .99696 L
s
.56234 .99696 m
.55841 1 L
s
1 0 0 r
.78074 .6759 m
.72802 .78748 L
s
% Start of user PostScript
8.4222945 5.2769355 6.8405315 8.6243713 MAarrowhead1
% End of user PostScript
1 .158 0 r
.65467 .89677 m
.56234 .99696 L
s
% Start of user PostScript
4.6402135 11.903185 1.8702003 14.908704 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-21.372315 11.914293 -22.698978 6.6864687 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
5.4703123 -42.437233 14.122516 -46.183668 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
53.467389 3.5209373 49.752758 20.901603 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-60.110122 112.37719 -80.486195 107.85479 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-94.478556 -104.65642 -67.14037 -148.07544 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
243.33723 -216.92012 275.59353 -167.88889 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
50.924823 468.02791 -50.681037 544.56631 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-704.54811 193.63836 -706.25822 -4.4036398 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
457.71008 -1436.0747 735.35042 -1476.5587 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1527.8789 688.73979 1297.6081 1261.3284 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2536.9665 3320.8935 -3096.8326 2946.4569 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2006.6062 -4682.0908 -906.94678 -5921.7267 MAarrowhead1
% End of user PostScript
0 1 .308 r
.56437 .53932 m
.55249 .56477 L
.5359 .58975 L
.51497 .6127 L
.49035 .63199 L
.46303 .64597 L
.43428 .65311 L
.40561 .65207 L
.37877 .64182 L
.35557 .62175 L
.3379 .59175 L
.32755 .55228 L
.3261 .50443 L
.33483 .44995 L
.35457 .39121 L
.38561 .33112 L
.42761 .27311 L
.47952 .22091 L
.53956 .1784 L
.60523 .1494 L
.67338 .13746 L
.74025 .14554 L
.80171 .17585 L
.85335 .22951 L
.8908 .30646 L
.90993 .40519 L
.90715 .52272 L
.87973 .65454 L
.82601 .79471 L
.7457 .93595 L
s
.7457 .93595 m
.69521 1 L
s
1 0 0 r
.56437 .53932 m
.55249 .56477 L
s
% Start of user PostScript
1.9310144 1.1796417 1.5747355 1.9432208 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5359 .58975 m
.51497 .6127 L
s
% Start of user PostScript
1.0771068 2.6925822 0.44898478 3.3811436 MAarrowhead1
% End of user PostScript
1 .473 0 r
.3379 .59175 m
.32755 .55228 L
s
% Start of user PostScript
-4.8629155 2.7524702 -5.1735489 1.5683318 MAarrowhead1
% End of user PostScript
1 .788 0 r
.53956 .1784 m
.60523 .1494 L
s
% Start of user PostScript
1.1867705 -9.6481401 3.157019 -10.517911 MAarrowhead1
% End of user PostScript
.897 1 0 r
.90715 .52272 m
.87973 .65454 L
s
% Start of user PostScript
12.214615 0.6815746 11.391921 4.6363344 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-13.561108 25.649664 -18.220694 24.667713 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-21.728328 -23.555619 -15.549407 -33.474914 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
55.247866 -49.791941 62.685775 -38.729724 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
12.316935 106.16118 -10.772539 123.76457 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-160.60098 45.522548 -161.28265 0.55760339 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
102.40813 -327.09393 165.74861 -336.89877 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
349.9083 153.02032 298.16711 283.54386 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-574.44148 759.65866 -702.83908 675.87132 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-465.09818 -1058.721 -215.8102 -1342.626 MAarrowhead1
% End of user PostScript
.192 1 0 r
.73016 .7465 m
.66535 .85119 L
.58204 .94886 L
s
.58204 .94886 m
.52154 1 L
s
1 0 0 r
.73016 .7465 m
.66535 .85119 L
s
% Start of user PostScript
6.904847 7.3951151 4.9603847 10.535606 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58204 .94886 m
0 0 rlineto s
.58204 .94886 m
.52154 1 L
s
% Start of user PostScript
2.4612001 13.465942 -0.51752459 15.983385 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-21.299406 7.6524731 -21.730679 1.897576 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
11.331795 -43.079199 19.793721 -45.052938 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
48.309637 15.648951 42.322084 32.962419 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-71.679164 103.86038 -89.614824 94.576146 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-70.669438 -130.41747 -39.217712 -169.6247 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
254.63958 -171.97188 276.78156 -113.56036 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-23.358306 500.02172 -127.58792 557.17437 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-672.41802 44.385512 -644.41454 -162.75195 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
632.44638 -1396.7558 892.07731 -1376.8479 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1292.6909 1061.1823 996.88848 1607.3957 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2812.9499 2898.8795 -3268.4131 2382.5978 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1133.7817 -5337.4165 55.673001 -6385.3379 MAarrowhead1
% End of user PostScript
.886 0 1 r
.31871 .21646 m
.38863 .12247 L
.4745 .03847 L
s
.4745 .03847 m
.5307 0 L
s
1 0 0 r
.31871 .21646 m
.38863 .12247 L
s
% Start of user PostScript
-5.4386214 -8.5062407 -3.3411482 -11.326003 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4745 .03847 m
0 0 rlineto s
.4745 .03847 m
.5307 0 L
s
% Start of user PostScript
-0.76514521 -13.845769 2.1994792 -15.875324 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
20.077322 -4.1793306 19.843521 1.6370354 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-14.90811 41.172952 -22.768969 41.768463 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-41.961646 -23.477002 -34.674812 -39.791402 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
76.029382 -92.055132 91.231814 -79.869822 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
49.732968 141.70756 17.062092 175.74436 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-248.74976 130.32902 -262.4305 68.406406 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
75.285988 -495.47616 175.6703 -535.60331 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
612.47034 64.965407 564.72045 267.24123 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-722.87703 1291.8748 -955.34734 1229.8004 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1053.2203 -1269.6861 -726.72291 -1767.0059 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2856.143 -2437.3624 3211.8041 -1847.8303 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
446.28617 5513.6859 -742.16072 6366.7215 MAarrowhead1
% End of user PostScript
.231 1 0 r
.18482 .70336 m
.15941 .62984 L
.15094 .53878 L
.16216 .43328 L
.19501 .31772 L
.25043 .19764 L
.32811 .07961 L
s
.32811 .07961 m
.4001 0 L
s
1 0 0 r
.18482 .70336 m
.15941 .62984 L
s
% Start of user PostScript
-9.4554917 6.1009137 -10.217561 3.8951515 MAarrowhead1
% End of user PostScript
1 .158 0 r
.15094 .53878 m
.16216 .43328 L
s
% Start of user PostScript
-10.471759 1.1634022 -10.135303 -2.0014567 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
9.191526 -21.664076 13.252816 -21.550907 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
20.687982 15.168133 16.337029 23.675356 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-42.489845 46.054878 -49.848111 38.549051 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-20.283905 -80.199597 -2.2307509 -96.973733 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
132.66216 -57.33099 137.38872 -22.734964 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-57.111838 266.51448 -110.18467 282.83863 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-312.2892 -69.663658 -280.23088 -177.51773 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
419.4828 -665.51708 536.62427 -618.63234 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
493.95378 752.47829 307.69353 1005.9856 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1558.2207 1172.3698 -1719.0442 830.42419 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-24.250899 -3037.4233 618.13423 -3437.1977 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4256.2025 -616.78166 4149.8257 650.98325 MAarrowhead1
% End of user PostScript
1 0 .425 r
.50508 .71388 m
.45966 .7431 L
.4106 .76171 L
.36033 .76719 L
.3117 .75747 L
.26783 .7311 L
.23196 .68743 L
.2073 .62677 L
.19681 .55048 L
.20301 .46102 L
.22774 .36197 L
.27201 .25796 L
.33576 .15454 L
.4178 .05795 L
s
.4178 .05795 m
.48605 0 L
s
1 0 0 r
.50508 .71388 m
.45966 .7431 L
s
% Start of user PostScript
0.15242725 6.4164768 -1.2102187 7.2930257 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4106 .76171 m
.36033 .76719 L
s
% Start of user PostScript
-2.6821255 7.8513549 -4.1900618 8.0157971 MAarrowhead1
% End of user PostScript
1 .473 0 r
.22774 .36197 m
.27201 .25796 L
s
% Start of user PostScript
-8.16771 -4.1410243 -6.839826 -7.261233 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
14.201704 -17.838358 17.177139 -15.645261 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
10.185674 26.35001 4.058511 32.975976 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-47.22262 26.194194 -50.126326 14.626322 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
12.268862 -93.790403 31.381127 -102.01374 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
117.98336 8.155514 109.70502 46.558249 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-133.17929 248.04814 -178.12727 237.90785 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-208.02526 -232.04953 -147.49064 -327.859 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
538.03489 -477.92106 608.99613 -369.28979 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
110.22473 1035.1586 -114.36773 1203.6797 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1555.7947 423.24717 -1558.6533 -14.633747 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1016.7801 -3171.9741 1629.7044 -3259.5587 MAarrowhead1
% End of user PostScript
.702 1 0 r
.45798 .45122 m
.47061 .43162 L
.48668 .41349 L
.50567 .3981 L
.52686 .38674 L
.54927 .38063 L
.57173 .38082 L
.59289 .38814 L
.61134 .40311 L
.6256 .42585 L
.63427 .45603 L
.63609 .49286 L
.63003 .53502 L
.61541 .58071 L
.59196 .62766 L
.55991 .67326 L
.52001 .71459 L
.47361 .74862 L
.42261 .77237 L
.36943 .78303 L
.31695 .77823 L
.26841 .7562 L
.22721 .71595 L
.19679 .65747 L
.18041 .58182 L
.18091 .49121 L
.2005 .38906 L
.24056 .27992 L
.30142 .16938 L
.38224 .06383 L
s
.38224 .06383 m
.44949 0 L
s
1 0 0 r
.45798 .45122 m
.47061 .43162 L
s
% Start of user PostScript
-1.260605 -1.4634562 -0.88168736 -2.0514413 MAarrowhead1
% End of user PostScript
1 .158 0 r
.48668 .41349 m
.50567 .3981 L
s
% Start of user PostScript
-0.3997366 -2.5953747 0.17022406 -3.0569529 MAarrowhead1
% End of user PostScript
1 .473 0 r
.63427 .45603 m
.63609 .49286 L
s
% Start of user PostScript
4.0281154 -1.3189769 4.0826108 -0.21406299 MAarrowhead1
% End of user PostScript
1 .788 0 r
.42261 .77237 m
.36943 .78303 L
s
% Start of user PostScript
-2.3217057 8.1709837 -3.9171295 8.4907844 MAarrowhead1
% End of user PostScript
.897 1 0 r
.2005 .38906 m
.24056 .27992 L
s
% Start of user PostScript
-8.9850921 -3.3283496 -7.7832926 -6.6024094 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
13.913591 -19.394826 17.233526 -17.493859 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
12.651329 25.457903 6.5754086 32.749259 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-48.52571 31.17995 -52.40922 19.843165 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
6.6690985 -95.583994 26.471111 -105.81158 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
126.26364 -3.8795689 120.06508 35.590858 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-124.96373 263.10685 -173.5464 257.51126 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-237.48481 -212.07639 -179.52819 -314.63355 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
540.62926 -535.75472 623.65191 -433.76783 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
188.10894 1029.8006 -39.68131 1222.2859 MAarrowhead1
% End of user PostScript
0 1 .107 r
.74315 .53346 m
.72258 .61476 L
.68599 .70003 L
.63343 .78473 L
.56593 .86373 L
.4855 .93155 L
.39523 .98267 L
s
.39523 .98267 m
.33811 1 L
s
.15506 1 m
.11033 .98646 L
.02932 .9259 L
s
.02932 .9259 m
0 .88264 L
s
0 .16404 m
.07842 0 L
s
1 0 0 r
.74315 .53346 m
.72258 .61476 L
s
% Start of user PostScript
7.2945417 1.0039198 6.6772603 3.442745 MAarrowhead1
% End of user PostScript
1 .158 0 r
.68599 .70003 m
.63343 .78473 L
s
% Start of user PostScript
5.5795802 6.0009825 4.0029987 8.5419677 MAarrowhead1
% End of user PostScript
1 .473 0 r
.02932 .9259 m
0 0 rlineto s
.02932 .9259 m
0 .88264 L
s
% Start of user PostScript
-14.120385 12.777074 -16.032174 9.9563655 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-3.219214 -27.123406 2.6839976 -31.643838 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
41.107054 -11.781807 41.308961 -0.28946032 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-26.031111 83.697981 -42.248544 86.261791 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-89.714898 -38.79296 -76.541711 -72.201708 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
146.67021 -194.69088 179.60756 -173.39195 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
119.76856 270.18366 56.090905 342.97643 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-500.03054 300.61464 -535.68406 181.12612 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
97.52529 -988.79389 300.78656 -1085.5625 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1276.705 19.491193 1201.6362 426.17333 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1345.3575 2671.3284 -1834.3611 2590.2676 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2332.099 -2313.2691 -1714.2811 -3350.1579 MAarrowhead1
% End of user PostScript
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0333333 0.5 0.0333333 [
[0 .4875 -18.4688 -20 ]
[0 .4875 18.4688 0 ]
[.16667 .4875 -18.4688 -20 ]
[.16667 .4875 18.4688 0 ]
[.33333 .4875 -13.4688 -20 ]
[.33333 .4875 13.4688 0 ]
[.66667 .4875 -7 -20 ]
[.66667 .4875 7 0 ]
[.83333 .4875 -12 -20 ]
[.83333 .4875 12 0 ]
[1 .4875 -12 -20 ]
[1 .4875 12 0 ]
[.4875 0 -36.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .16667 -36.9375 -10 ]
[.4875 .16667 0 10 ]
[.4875 .33333 -26.9375 -10 ]
[.4875 .33333 0 10 ]
[.4875 .66667 -14 -10 ]
[.4875 .66667 0 10 ]
[.4875 .83333 -24 -10 ]
[.4875 .83333 0 10 ]
[.4875 1 -24 -10 ]
[.4875 1 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.16667 .5 m
.16667 .50625 L
s
gsave
.16667 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.33333 .5 m
.33333 .50625 L
s
gsave
.33333 .4875 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.66667 .5 m
.66667 .50625 L
s
gsave
.66667 .4875 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.83333 .5 m
.83333 .50625 L
s
gsave
.83333 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.5 .16667 m
.50625 .16667 L
s
gsave
.4875 .16667 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 .33333 m
.50625 .33333 L
s
gsave
.4875 .33333 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .66667 m
.50625 .66667 L
s
gsave
.4875 .66667 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .83333 m
.50625 .83333 L
s
gsave
.4875 .83333 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.01 w
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 .176 r
.5 Mabswid
.48296 .66313 m
.44948 .6788 L
.41455 .68588 L
.38007 .68283 L
.34815 .66846 L
.32104 .64214 L
.30099 .60384 L
.29013 .55424 L
.29035 .4948 L
.3031 .42776 L
.32929 .3561 L
.36914 .28348 L
.42211 .21411 L
.48678 .15255 L
.56084 .10351 L
.64114 .07159 L
.72371 .06096 L
.80393 .07511 L
.87671 .11647 L
.93672 .18622 L
.97867 .28396 L
.99766 .40761 L
.9895 .55323 L
.95106 .71506 L
.88061 .88561 L
s
.88061 .88561 m
.81172 1 L
s
.25 1 0 r
.61807 .7729 m
.55391 .8455 L
.478 .90717 L
.39329 .95276 L
.30367 .97743 L
.21382 .9769 L
.12907 .94787 L
.05517 .88826 L
s
.05517 .88826 m
0 .80081 L
s
0 .29697 m
.03765 .17874 L
s
.03765 .17874 m
.12662 0 L
s
0 .534 1 r
.3612 .6364 m
.34013 .61007 L
.32579 .57367 L
.31992 .52803 L
.32401 .47464 L
.33914 .41566 L
.36588 .35385 L
.40418 .29252 L
.45329 .23541 L
.51173 .18647 L
.57725 .14971 L
.64688 .12894 L
.71703 .12754 L
.78357 .14817 L
.84207 .19252 L
.88795 .26112 L
.9168 .35309 L
.92464 .46608 L
.9082 .59613 L
.86523 .73776 L
.79475 .88407 L
s
.79475 .88407 m
.7157 1 L
s
0 .366 1 r
.78446 .70992 m
.72435 .82707 L
.64286 .94032 L
s
.64286 .94032 m
.58387 1 L
s
0 .092 1 r
.17703 .54011 m
.18652 .44304 L
.21596 .33645 L
.26626 .22542 L
.3372 .11598 L
.4273 .01487 L
s
.4273 .01487 m
.44577 0 L
s
0 .975 1 r
.75182 .54487 m
.72835 .63038 L
.68814 .7195 L
.63136 .8074 L
.55919 .88866 L
.47387 .95757 L
s
.47387 .95757 m
.39442 1 L
s
.08084 1 m
0 .93406 L
s
0 .10223 m
.05119 0 L
s
1 .341 0 r
.53289 .62783 m
.50409 .65475 L
.4712 .67602 L
.43565 .68962 L
.39921 .69373 L
.36393 .68683 L
.33206 .66787 L
.30596 .63638 L
.28796 .59256 L
.28021 .53738 L
.28454 .47263 L
.30229 .40089 L
.3342 .32551 L
.38024 .25049 L
.43955 .18037 L
.51037 .11997 L
.58999 .0742 L
.67485 .04772 L
.76059 .04469 L
.8422 .06841 L
.91426 .12103 L
.97122 .20325 L
s
.97122 .20325 m
1 .29081 L
s
1 .60945 m
.94949 .78107 L
.86519 .95964 L
s
.86519 .95964 m
.83813 1 L
s
1 .505 0 r
.44746 .20875 m
.51184 .15452 L
.5841 .11367 L
.66096 .09043 L
.73845 .08851 L
.81204 .11087 L
.87682 .15943 L
.92776 .23475 L
.95996 .33593 L
.96903 .46036 L
.95133 .60372 L
.90435 .75998 L
.82701 .92155 L
s
.82701 .92155 m
.7738 1 L
s
1 .089 0 r
.52968 .77407 m
.47019 .81885 L
.40455 .85057 L
.33587 .86561 L
.26783 .86084 L
.20458 .83393 L
.15053 .78351 L
.11011 .70948 L
.08757 .61309 L
.08663 .49713 L
.11021 .3659 L
.16017 .22519 L
.23706 .08214 L
s
.23706 .08214 m
.29861 0 L
s
1 .572 0 r
.52455 .77672 m
.46479 .82021 L
.39917 .8504 L
.33082 .86371 L
.26346 .8571 L
.20124 .82832 L
.14855 .77613 L
.10981 .70051 L
.08918 .60288 L
.0903 .4861 L
.116 .35461 L
.16803 .21428 L
.24678 .0723 L
s
.24678 .0723 m
.30251 0 L
s
0 .862 1 r
.53013 .46657 m
.53551 .47179 L
.53949 .47939 L
.54165 .48923 L
.54161 .50103 L
.53908 .51433 L
.53388 .52855 L
.52597 .54296 L
.51546 .55673 L
.50263 .56895 L
.48793 .57868 L
.472 .58502 L
.45561 .58713 L
.43969 .58433 L
.42525 .57612 L
.41334 .56228 L
.40501 .54288 L
.40124 .51835 L
.40285 .48945 L
.41048 .45734 L
.42446 .42349 L
.4448 .3897 L
.47115 .35799 L
.50272 .33052 L
.53834 .30951 L
.57641 .29705 L
.615 .29504 L
.65186 .30499 L
.68458 .32789 L
.71064 .36411 L
.72761 .41325 L
.73327 .4741 L
.72577 .54461 L
.70381 .62184 L
.66677 .70209 L
.61485 .78097 L
.54917 .8536 L
.47181 .91481 L
.38583 .95944 L
.29522 .9826 L
.20475 .98007 L
.11984 .94858 L
.0463 .88613 L
s
.0463 .88613 m
0 .80898 L
s
0 .2803 m
.03917 .16205 L
s
.03917 .16205 m
.12206 0 L
s
0 1 .034 r
.3839 .62864 m
.36321 .60849 L
.34791 .57919 L
.33965 .54127 L
.33985 .49583 L
.34963 .4446 L
.36968 .38985 L
.40017 .33437 L
.44068 .28139 L
.49011 .23439 L
.54672 .19697 L
.60807 .17264 L
.67115 .1646 L
.73243 .17548 L
.788 .20717 L
.83379 .26054 L
.86578 .3353 L
.88021 .42983 L
.87389 .54114 L
.84443 .66481 L
.7905 .79512 L
.71208 .92518 L
s
.71208 .92518 m
.64983 1 L
s
0 1 .692 r
.71158 .80661 m
.63511 .91316 L
s
.63511 .91316 m
.54954 1 L
s
.865 1 0 r
.33306 .77036 m
.28528 .75241 L
.24395 .71702 L
.21238 .66398 L
.19376 .59409 L
.19092 .50929 L
.20613 .41264 L
.2409 .30834 L
.29575 .20158 L
.37008 .09839 L
.46206 .00542 L
s
.46206 .00542 m
.46968 0 L
s
.239 0 1 r
.64916 .73703 m
.59084 .81485 L
.51935 .88425 L
.43717 .93998 L
.34781 .97689 L
.25562 .99027 L
.16573 .9762 L
.08381 .93185 L
.0158 .85585 L
s
.0158 .85585 m
0 .82065 L
s
0 .25305 m
.06937 .08074 L
s
.06937 .08074 m
.11703 0 L
s
1 0 .416 r
.80068 .66829 m
.74846 .7852 L
.67446 .90067 L
s
.67446 .90067 m
.58692 1 L
s
0 .188 1 r
.52253 .25439 m
.57311 .22982 L
.62607 .21809 L
.67856 .22161 L
.72739 .2422 L
.76916 .2809 L
.80044 .33783 L
.81797 .412 L
.81887 .5013 L
.80087 .60242 L
.76253 .71088 L
.70344 .82122 L
.62434 .92709 L
s
.62434 .92709 m
.54946 1 L
s
1 0 .964 r
.52897 .49721 m
.52795 .50603 L
.52513 .51565 L
.52043 .52563 L
.51388 .5354 L
.50564 .54437 L
.49596 .55188 L
.48524 .5573 L
.47397 .56002 L
.46275 .55953 L
.45225 .55542 L
.44321 .54746 L
.43635 .53561 L
.43237 .52005 L
.4319 .50123 L
.43542 .47984 L
.44327 .45679 L
.45554 .43325 L
.4721 .41056 L
.49253 .39018 L
.51612 .37364 L
.54189 .36243 L
.56859 .35793 L
.59476 .36131 L
.61877 .37341 L
.63888 .39466 L
.6534 .42503 L
.66069 .46391 L
.65938 .51013 L
.64838 .56189 L
.62707 .61685 L
.59535 .67216 L
.55372 .72457 L
.50334 .77057 L
.44605 .80655 L
.38435 .82904 L
.32133 .83491 L
.26058 .82158 L
.20602 .7873 L
.16172 .73133 L
.1317 .6541 L
.11965 .5574 L
.12868 .4444 L
.16105 .31968 L
.21794 .1891 L
.29923 .05967 L
s
.29923 .05967 m
.35082 0 L
s
0 .676 1 r
.83012 .31291 m
.85125 .39326 L
.85426 .49068 L
.83654 .60162 L
.79639 .72128 L
.73322 .84367 L
.64773 .96186 L
s
.64773 .96186 m
.60984 1 L
s
.625 0 1 r
.24376 .73463 m
.20849 .6838 L
.1859 .61525 L
.17903 .53069 L
.19039 .43304 L
.22173 .32638 L
.27384 .21588 L
.34637 .10761 L
.43772 .00832 L
s
.43772 .00832 m
.44844 0 L
s
1 .012 0 r
.16712 .52583 m
.18017 .42378 L
.21403 .31269 L
.26946 .19799 L
.34601 .08602 L
s
.34601 .08602 m
.42675 0 L
s
0 .557 1 r
.69268 .68525 m
.64288 .77017 L
.57792 .85027 L
.49966 .92016 L
.41101 .97429 L
s
.41101 .97429 m
.33699 1 L
s
.15901 1 m
.12605 .99201 L
.04299 .93714 L
s
.04299 .93714 m
0 .8804 L
s
0 .17269 m
.07335 .00879 L
s
.07335 .00879 m
.07899 0 L
s
1 0 .473 r
.34811 .50671 m
.35514 .45949 L
.37174 .4084 L
.3982 .35597 L
.43425 .30515 L
.47903 .25919 L
.53102 .22146 L
.58808 .19532 L
.64748 .18388 L
.706 .18976 L
.76003 .21492 L
.80574 .26044 L
.83931 .3263 L
.85711 .4113 L
.85598 .5129 L
.83348 .62725 L
.78809 .74925 L
.71947 .87262 L
.62863 .9902 L
s
.62863 .9902 m
.61822 1 L
s
0 1 .69 r
.7825 .30838 m
.80723 .37308 L
.81695 .45396 L
.80905 .54835 L
.78167 .65242 L
.73385 .76127 L
.66571 .86902 L
.57862 .96912 L
s
.57862 .96912 m
.54126 1 L
s
.085 0 1 r
.77091 .76376 m
.70019 .88357 L
.60811 .99646 L
s
.60811 .99646 m
.60413 1 L
s
.724 1 0 r
.63429 .73126 m
.57802 .80363 L
.5096 .86752 L
.4315 .918 L
.34709 .95028 L
.26056 .96 L
.17679 .94358 L
.10114 .89852 L
.0392 .8237 L
s
.0392 .8237 m
0 .72815 L
s
0 .38812 m
.03064 .26442 L
.10644 .08542 L
s
.10644 .08542 m
.1589 0 L
s
0 1 .875 r
.70671 .35069 m
.72673 .39686 L
.7359 .45532 L
.73222 .52423 L
.7142 .60087 L
.68101 .6817 L
.6326 .76245 L
.56984 .83831 L
.49456 .90409 L
.40958 .95453 L
.31868 .98458 L
.22649 .98974 L
.13833 .96637 L
.06001 .91208 L
s
.06001 .91208 m
0 .82944 L
s
0 .25464 m
.01218 .21144 L
.10019 .01977 L
s
.10019 .01977 m
.11315 0 L
s
0 1 .871 r
.56162 .66226 m
.52395 .70272 L
.47984 .73647 L
.43105 .76061 L
.37989 .77242 L
.32907 .76957 L
.28168 .75025 L
.24099 .71344 L
.21034 .659 L
.19288 .58783 L
.19142 .50195 L
.20816 .40451 L
.24453 .29979 L
.30098 .19307 L
.37682 .09045 L
s
.37682 .09045 m
.46866 0 L
s
0 1 .181 r
.47425 .22518 m
.53368 .18155 L
.59902 .15111 L
.66715 .13741 L
.73438 .14352 L
.79659 .1717 L
.84939 .22321 L
.88839 .29809 L
.90941 .39498 L
.90883 .51103 L
.88378 .64187 L
.83251 .78168 L
.75458 .9233 L
s
.75458 .9233 m
.69589 1 L
s
0 .454 1 r
.54812 .40409 m
.56569 .40694 L
.58168 .41572 L
.59493 .4307 L
.60428 .4518 L
.60865 .47859 L
.60713 .51023 L
.59902 .54546 L
.58392 .58268 L
.56181 .61992 L
.53307 .65496 L
.49852 .68544 L
.45947 .70891 L
.41763 .72304 L
.37514 .72576 L
.33443 .71538 L
.29818 .69077 L
.26913 .6515 L
.24999 .59797 L
.24321 .53148 L
.25084 .45425 L
.27434 .36946 L
.31443 .28118 L
.37093 .19418 L
.44264 .11385 L
.52733 .04584 L
s
.52733 .04584 m
.61385 0 L
s
.90313 0 m
.91483 .00415 L
.99642 .07147 L
s
.99642 .07147 m
1 .07726 L
s
1 .8849 m
.94201 1 L
s
0 1 .797 r
.17034 .37959 m
.21407 .25968 L
.28068 .13814 L
.36924 .022 L
s
.36924 .022 m
.39232 0 L
s
.471 1 0 r
.61559 .78396 m
.54924 .8572 L
.47111 .9189 L
.38431 .96383 L
.29285 .98708 L
.20157 .98438 L
.11593 .95244 L
.04179 .88925 L
s
.04179 .88925 m
0 .81936 L
s
0 .26442 m
.03537 .15794 L
s
.03537 .15794 m
.11632 0 L
s
0 1 .603 r
.34766 .81421 m
.28981 .80655 L
.2368 .77958 L
.19242 .73235 L
.16048 .66497 L
.14453 .57878 L
.14766 .47642 L
.17222 .36184 L
.21959 .24024 L
.29 .11794 L
.3823 .00214 L
s
.3823 .00214 m
.38465 0 L
s
1 .563 0 r
.25648 .45646 m
.2792 .37375 L
.31812 .28756 L
.37306 .20255 L
.44289 .12397 L
.52542 .05735 L
.61743 .00826 L
s
.61743 .00826 m
.64796 0 L
s
.86061 0 m
.90384 .01511 L
.98373 .08036 L
s
.98373 .08036 m
1 .10646 L
s
1 .85197 m
.99998 .85203 L
s
.99998 .85203 m
.92584 1 L
s
.899 1 0 r
.58947 .42372 m
.6006 .4422 L
.6072 .46658 L
.6083 .49621 L
.60308 .53 L
.59102 .5665 L
.57193 .6039 L
.546 .64009 L
.51388 .67273 L
.47665 .69942 L
.43586 .71777 L
.39347 .72558 L
.35178 .72098 L
.31338 .70258 L
.281 .66965 L
.25736 .62223 L
.24505 .56119 L
.24631 .48838 L
.26286 .40657 L
.29576 .31944 L
.34521 .23148 L
.41049 .14781 L
.48979 .07401 L
.58026 .01579 L
s
.58026 .01579 m
.62185 0 L
s
.89651 0 m
.9624 .03958 L
s
.9624 .03958 m
1 .08531 L
s
1 .87446 m
.95428 .98194 L
s
.95428 .98194 m
.94315 1 L
s
0 .45 1 r
.68512 .58954 m
.65594 .65971 L
.61357 .72969 L
.55878 .79529 L
.49319 .85202 L
.41928 .8953 L
.34034 .92078 L
.26041 .92455 L
.18412 .90351 L
.11652 .8556 L
.06278 .78011 L
.02797 .67786 L
.01667 .55138 L
.03268 .40501 L
.0787 .24481 L
.15598 .07849 L
s
.15598 .07849 m
.20792 0 L
s
.88 1 0 r
.76913 .42026 m
.771 .49517 L
.75696 .58033 L
.72572 .67205 L
.67687 .76571 L
.61096 .856 L
.52966 .93709 L
s
.52966 .93709 m
.4399 1 L
s
.02376 1 m
0 .97487 L
s
0 .02503 m
.01436 0 L
s
0 .099 1 r
.76067 .76433 m
.6904 .88098 L
.59941 .99043 L
s
.59941 .99043 m
.5884 1 L
s
1 0 .916 r
.60088 .70782 m
.55141 .76658 L
.49229 .81727 L
.42576 .85579 L
.3548 .87821 L
.28305 .88107 L
.21468 .86158 L
.15423 .81794 L
.10635 .74952 L
.07557 .65711 L
.066 .54303 L
.08104 .41119 L
.12306 .26709 L
.19317 .1177 L
s
.19317 .1177 m
.2717 0 L
s
1 0 .959 r
.81983 .57516 m
.7862 .68611 L
.73101 .80074 L
.65471 .91269 L
s
.65471 .91269 m
.57299 1 L
s
0 1 .201 r
.52942 .32107 m
.56555 .30729 L
.60258 .30317 L
.63842 .31023 L
.67077 .32955 L
.69726 .36161 L
.7155 .40619 L
.72332 .4623 L
.71887 .52813 L
.70077 .60105 L
.66828 .67765 L
.62144 .75385 L
.56112 .82507 L
.48911 .88638 L
.40818 .93281 L
.32194 .95961 L
.23483 .96257 L
.15195 .93834 L
.07878 .88474 L
.02099 .80106 L
s
.02099 .80106 m
0 .73693 L
s
0 .36137 m
.04361 .2136 L
.12942 .03215 L
s
.12942 .03215 m
.15101 0 L
s
.407 0 1 r
.23413 .54654 m
.23909 .46838 L
.26026 .3817 L
.29855 .29053 L
.35395 .19972 L
.42544 .11472 L
.5109 .04139 L
s
.5109 .04139 m
.5823 0 L
s
.94423 0 m
.99979 .04003 L
s
.99979 .04003 m
1 .04033 L
s
1 .93283 m
.96851 1 L
s
0 1 .204 r
.34398 .60129 m
.33128 .56498 L
.32694 .51996 L
.33235 .46775 L
.34847 .41051 L
.37578 .35099 L
.41413 .29243 L
.46271 .23845 L
.51998 .19288 L
.58369 .15956 L
.65089 .14211 L
.71803 .14368 L
.78112 .1667 L
.83583 .21267 L
.87781 .28189 L
.90284 .37334 L
.90718 .48452 L
.88782 .61142 L
.84275 .74858 L
.77124 .88917 L
s
.77124 .88917 m
.69209 1 L
s
.065 0 1 r
.47422 .50584 m
.47442 .49844 L
.47618 .49014 L
.47958 .48132 L
.48466 .47245 L
.49133 .46403 L
.4994 .45664 L
.50858 .45086 L
.51848 .44723 L
.52859 .44627 L
.53834 .44838 L
.5471 .45385 L
.55422 .46281 L
.55906 .47517 L
.56102 .49066 L
.5596 .50877 L
.55443 .52877 L
.54533 .54972 L
.53232 .57049 L
.51565 .58982 L
.49582 .60637 L
.47361 .61878 L
.45001 .62575 L
.42624 .62616 L
.40372 .6191 L
.38393 .60399 L
.36844 .58067 L
.35872 .54944 L
.35614 .5111 L
.36179 .46699 L
.37644 .41897 L
.40041 .3694 L
.43351 .32101 L
.47498 .27686 L
.52346 .24013 L
.577 .21401 L
.63308 .20147 L
.68869 .20506 L
.74044 .22672 L
.78476 .26756 L
.81798 .3277 L
.83668 .40612 L
.83778 .50059 L
.81888 .60759 L
.77845 .72243 L
.71603 .83929 L
.63242 .95148 L
s
.63242 .95148 m
.58272 1 L
s
.072 0 1 r
.40848 .44284 m
.42563 .40649 L
.4495 .37088 L
.47956 .33822 L
.51483 .31086 L
.55393 .29114 L
.59501 .28125 L
.63589 .28309 L
.67412 .29811 L
.70705 .32717 L
.73202 .37041 L
.74647 .42713 L
.74815 .49575 L
.73526 .57376 L
.70662 .65775 L
.66184 .74353 L
.60145 .8262 L
.52697 .90042 L
.44096 .96065 L
s
.44096 .96065 m
.35031 1 L
s
.14382 1 m
.06692 .96113 L
s
.06692 .96113 m
0 .89027 L
s
0 .16939 m
.03723 .0735 L
s
.03723 .0735 m
.07943 0 L
s
0 .167 1 r
.59531 .29975 m
.63228 .30407 L
.66628 .32065 L
.69489 .35014 L
.71568 .39249 L
.72639 .44689 L
.72501 .5117 L
.71004 .58444 L
.68054 .66184 L
.63635 .73988 L
.57815 .81401 L
.50754 .87929 L
.42707 .93064 L
.34024 .96314 L
.25137 .97235 L
.1655 .95462 L
.08815 .90741 L
.02506 .82962 L
s
.02506 .82962 m
0 .76705 L
s
0 .33074 m
.0198 .2525 L
.09872 .06853 L
s
.09872 .06853 m
.14123 0 L
s
0 .652 1 r
.34632 .82987 m
.28525 .82381 L
.22884 .79762 L
.1811 .7502 L
.14602 .68155 L
.12738 .59292 L
.12848 .48696 L
.15188 .36766 L
.19915 .24037 L
.27067 .11162 L
s
.27067 .11162 m
.3568 0 L
s
1 .182 0 r
.24221 .34146 m
.29 .23938 L
.35667 .13926 L
.44077 .04732 L
s
.44077 .04732 m
.50136 0 L
s
.096 0 1 r
.66508 .45422 m
.66557 .50058 L
.65625 .55307 L
.63636 .60938 L
.6057 .66667 L
.56465 .72164 L
.51428 .77072 L
.45635 .81019 L
.39331 .83641 L
.32825 .84607 L
.26475 .83637 L
.20684 .80532 L
.1587 .75193 L
.1245 .6764 L
.10814 .5803 L
.11297 .46661 L
.14152 .33978 L
.19526 .20561 L
.27433 .07114 L
s
.27433 .07114 m
.33214 0 L
s
0 1 .271 r
.22583 .64416 m
.21065 .57597 L
.21069 .49418 L
.228 .40184 L
.26383 .30307 L
.31852 .20288 L
.39131 .10707 L
.48028 .02194 L
s
.48028 .02194 m
.51321 0 L
s
1 0 .078 r
.76188 .44659 m
.7586 .52259 L
.73946 .60738 L
.70349 .69704 L
.65059 .78689 L
.58167 .8716 L
.49871 .94543 L
s
.49871 .94543 m
.40892 1 L
s
.07262 1 m
.01542 .96191 L
s
.01542 .96191 m
0 .94142 L
s
0 .08821 m
.03964 0 L
s
.658 0 1 r
.24763 .80471 m
.19735 .76416 L
.15842 .70244 L
.13468 .62044 L
.12956 .52034 L
.14586 .4057 L
.18544 .28141 L
.24906 .15362 L
.33611 .02946 L
s
.33611 .02946 m
.36446 0 L
s
1 .422 0 r
.6479 .44689 m
.65089 .48685 L
.64528 .53292 L
.63026 .58316 L
.60547 .63513 L
.57109 .68596 L
.52789 .73247 L
.47728 .7713 L
.42129 .79913 L
.36253 .81283 L
.30415 .80969 L
.24967 .78767 L
.20287 .74556 L
.16756 .6832 L
.14738 .6016 L
.14553 .50309 L
.16458 .39128 L
.20617 .27106 L
.27081 .14848 L
.35774 .03055 L
s
.35774 .03055 m
.38868 0 L
s
0 .983 1 r
.40676 .79264 m
.35018 .8009 L
.29501 .79231 L
.24471 .76515 L
.20294 .71856 L
.17332 .65273 L
.15924 .56903 L
.16361 .47007 L
.18862 .35971 L
.23554 .24303 L
.30447 .12614 L
.39424 .01598 L
s
.39424 .01598 m
.41222 0 L
s
.304 0 1 r
.23116 .67488 m
.20919 .61235 L
.20165 .53479 L
.21088 .44483 L
.23859 .34619 L
.28558 .24358 L
.35162 .1426 L
.43529 .04949 L
s
.43529 .04949 m
.49739 0 L
s
0 1 .021 r
.28776 .62724 m
.2727 .57647 L
.26919 .51439 L
.27898 .44318 L
.30326 .36588 L
.3425 .28628 L
.39636 .20883 L
.46357 .13843 L
.5419 .08023 L
.62816 .0393 L
.71827 .0204 L
.80735 .02759 L
.88997 .0639 L
.96034 .13106 L
s
.96034 .13106 m
1 .20549 L
s
1 .70805 m
.94272 .86669 L
s
.94272 .86669 m
.8702 1 L
s
.517 0 1 r
.77118 .5537 m
.74477 .64648 L
.70026 .74287 L
.63787 .83762 L
.55895 .92485 L
.46601 .99836 L
s
.46601 .99836 m
.46284 1 L
s
0 .662 1 r
.48023 .20838 m
.54288 .16447 L
.61131 .13473 L
.68221 .12282 L
.75168 .13181 L
.8154 .16395 L
.86879 .22042 L
.9073 .30108 L
.92665 .40434 L
.92312 .52706 L
.8939 .6645 L
.83729 .81043 L
.75303 .95728 L
s
.75303 .95728 m
.71908 1 L
s
0 .017 1 r
.48543 .45768 m
.49517 .44761 L
.50649 .43932 L
.51894 .43354 L
.53191 .43095 L
.54471 .43214 L
.55655 .43754 L
.56659 .44738 L
.57399 .46166 L
.57797 .48014 L
.57783 .50226 L
.57303 .52719 L
.56323 .55382 L
.54836 .58078 L
.52862 .60652 L
.50455 .62933 L
.47701 .64746 L
.44716 .65922 L
.4165 .66305 L
.38673 .65766 L
.35975 .64215 L
.33754 .6161 L
.32207 .57966 L
.31514 .53362 L
.31832 .47944 L
.33276 .41927 L
.35909 .3559 L
.39734 .2927 L
.44679 .23344 L
.50601 .18218 L
.57275 .14306 L
.64404 .12001 L
.71623 .11655 L
.78514 .1355 L
.84621 .17872 L
.89478 .24684 L
.92627 .33914 L
.93652 .45332 L
.92212 .58548 L
.88062 .73014 L
.81089 .88034 L
s
.81089 .88034 m
.73177 1 L
s
.509 1 0 r
.81695 .46937 m
.8058 .56575 L
.77493 .67105 L
.72355 .78016 L
.652 .8871 L
.56186 .98519 L
s
.56186 .98519 m
.54279 1 L
s
.919 1 0 r
.26346 .8257 m
.20787 .79286 L
.1623 .73818 L
.1308 .66202 L
.11712 .56606 L
.12446 .45338 L
.15517 .32848 L
.21053 .19718 L
.29053 .06645 L
s
.29053 .06645 m
.34658 0 L
s
1 .506 0 r
.18846 .32722 m
.24224 .2063 L
.31855 .08678 L
s
.31855 .08678 m
.39477 0 L
s
0 .881 1 r
.71935 .16696 m
.77745 .19341 L
.82673 .24167 L
.86309 .31175 L
.88264 .4024 L
.88197 .51093 L
.85844 .63326 L
.81039 .76394 L
.73744 .89627 L
s
.73744 .89627 m
.65793 1 L
s
1 0 .976 r
.3258 .82126 m
.26768 .80758 L
.21568 .77374 L
.17371 .71907 L
.14561 .64405 L
.1349 .55046 L
.14454 .44139 L
.17667 .3213 L
.23235 .19587 L
.31141 .07189 L
s
.31141 .07189 m
.37446 0 L
s
.128 1 0 r
.4166 .39466 m
.44346 .35466 L
.47728 .318 L
.51695 .28732 L
.5609 .26523 L
.60706 .2542 L
.65298 .25636 L
.6959 .27334 L
.73285 .3061 L
.76083 .35478 L
.77698 .41861 L
.77877 .49578 L
.76416 .58349 L
.73186 .67789 L
.68143 .77426 L
.61347 .86709 L
.52969 .9504 L
s
.52969 .9504 m
.45868 1 L
s
1 0 .575 r
.71433 .66794 m
.66697 .75746 L
.60336 .84356 L
.52511 .92063 L
.43494 .98287 L
s
.43494 .98287 m
.39461 1 L
s
.08477 1 m
.04477 .97914 L
s
.04477 .97914 m
0 .93057 L
s
0 .09903 m
.02052 .04705 L
s
.02052 .04705 m
.04787 0 L
s
.855 1 0 r
.70668 .71215 m
.65042 .80497 L
.5777 .89195 L
.49066 .96715 L
s
.49066 .96715 m
.43448 1 L
s
.03132 1 m
0 .97775 L
s
0 .03493 m
.01625 0 L
s
0 1 .117 r
.35914 .41447 m
.38502 .35884 L
.4212 .30422 L
.4669 .254 L
.52066 .21177 L
.58034 .1811 L
.64318 .16536 L
.70585 .16749 L
.76458 .18974 L
.81536 .23344 L
.85409 .29886 L
.87686 .38499 L
.88018 .48945 L
.86128 .60844 L
.81832 .73681 L
.75065 .86815 L
.65902 .99502 L
s
.65902 .99502 m
.65408 1 L
s
1 .024 0 r
.54758 .73732 m
.49485 .78302 L
.43541 .81792 L
.3719 .83851 L
.30758 .84166 L
.24617 .82485 L
.19172 .78643 L
.1484 .72581 L
.12028 .64366 L
.11107 .542 L
.12382 .42429 L
.16071 .29543 L
.22274 .16161 L
.30956 .03016 L
s
.30956 .03016 m
.33693 0 L
s
.438 0 1 r
.50339 .42766 m
.51847 .41939 L
.53445 .41483 L
.55051 .41475 L
.5657 .41973 L
.57899 .43017 L
.58933 .44616 L
.59573 .46749 L
.59727 .4936 L
.59322 .52357 L
.58306 .55612 L
.5666 .58966 L
.54398 .62232 L
.51572 .65203 L
.48276 .67663 L
.44644 .69397 L
.40848 .70206 L
.37092 .69917 L
.33606 .68402 L
.30634 .65588 L
.2842 .61469 L
.27199 .56118 L
.27175 .4969 L
.28509 .42424 L
.31302 .34643 L
.35583 .26741 L
.41292 .19175 L
.48282 .12439 L
.56304 .07047 L
.65019 .03498 L
.73999 .02249 L
.82742 .03683 L
.90698 .08069 L
.97285 .1554 L
s
.97285 .1554 m
1 .21688 L
s
1 .6956 m
.99271 .72716 L
.91738 .91246 L
s
.91738 .91246 m
.86532 1 L
s
0 1 .574 r
.61137 .53468 m
.59786 .57441 L
.57672 .61499 L
.54818 .65412 L
.51298 .68927 L
.47231 .71781 L
.42788 .73717 L
.38184 .74495 L
.33671 .73916 L
.29531 .71834 L
.2606 .68173 L
.23555 .6294 L
.22294 .56239 L
.22517 .48274 L
.24409 .39351 L
.28079 .29875 L
.33544 .20337 L
.40719 .11299 L
.49403 .03365 L
s
.49403 .03365 m
.54754 0 L
s
.99961 0 m
1 .00024 L
s
.476 0 1 r
.20484 .69119 m
.1809 .62243 L
.17279 .53722 L
.18313 .43844 L
.21373 .33018 L
.26548 .21763 L
.33811 .10694 L
.43006 .00495 L
s
.43006 .00495 m
.43629 0 L
s
0 1 .326 r
.62256 .1746 m
.68442 .1714 L
.74352 .18736 L
.79597 .22409 L
.83775 .28217 L
.86495 .36097 L
.87401 .45856 L
.86197 .57161 L
.82674 .69544 L
.76733 .82411 L
.68407 .95057 L
s
.68407 .95057 m
.63937 1 L
s
1 .746 0 r
.304 .6607 m
.28098 .6194 L
.26795 .56548 L
.26703 .50047 L
.27988 .42678 L
.30756 .34764 L
.35041 .26705 L
.40789 .18963 L
.47851 .1204 L
.55982 .0646 L
.64838 .02733 L
.73989 .01329 L
.82928 .0264 L
.91093 .06951 L
.97895 .14402 L
s
.97895 .14402 m
1 .18988 L
s
1 .73511 m
.9303 .91055 L
s
.9303 .91055 m
.87804 1 L
s
.382 0 1 r
.53058 .39436 m
.55117 .39041 L
.57146 .39246 L
.59018 .4012 L
.60602 .417 L
.61765 .43984 L
.6238 .46932 L
.6234 .50456 L
.61558 .54421 L
.59983 .5865 L
.57602 .62927 L
.54451 .67003 L
.50616 .70606 L
.46232 .73461 L
.4149 .75297 L
.36624 .75869 L
.31908 .74974 L
.27643 .72471 L
.24143 .68294 L
.21719 .6247 L
.20659 .55127 L
.21208 .465 L
.23547 .36934 L
.27774 .26873 L
.3389 .16852 L
.41782 .07473 L
s
.41782 .07473 m
.50492 0 L
s
0 .637 1 r
.5552 .68001 m
.51414 .72072 L
.46677 .75369 L
.41508 .77592 L
.36157 .78466 L
.30918 .77758 L
.26121 .753 L
.22108 .71007 L
.19225 .64889 L
.17793 .57068 L
.18091 .47785 L
.20332 .37398 L
.24641 .26379 L
.31035 .15302 L
.39412 .04819 L
s
.39412 .04819 m
.44724 0 L
s
.095 0 1 r
.45675 .48416 m
.4625 .46842 L
.47125 .45247 L
.48288 .43723 L
.49707 .42371 L
.51334 .41294 L
.53097 .40592 L
.54911 .40358 L
.56673 .40668 L
.58271 .41575 L
.5959 .43106 L
.60512 .45252 L
.60929 .47967 L
.60751 .51164 L
.59908 .54718 L
.58361 .58464 L
.56111 .62203 L
.53196 .65713 L
.49702 .68753 L
.45761 .71079 L
.41548 .72458 L
.37278 .72682 L
.33198 .71582 L
.29577 .69049 L
.26692 .65043 L
.24812 .59606 L
.24185 .52872 L
.25014 .4507 L
.27443 .36524 L
.3154 .27644 L
.37284 .18914 L
.44552 .10876 L
.53112 .041 L
s
.53112 .041 m
.61009 0 L
s
.91106 0 m
.92063 .00354 L
s
.92063 .00354 m
1 .0709 L
s
1 .89346 m
.94552 1 L
s
1 .322 0 r
.47815 .57987 m
.46251 .58326 L
.44702 .58214 L
.43263 .57597 L
.42034 .56445 L
.41116 .54755 L
.40607 .52556 L
.40589 .49913 L
.41131 .46922 L
.42273 .43717 L
.44028 .4046 L
.46374 .37338 L
.49247 .34556 L
.52549 .32324 L
.56138 .30849 L
.59838 .3032 L
.63445 .30894 L
.6673 .32684 L
.69455 .35744 L
.71382 .40063 L
.72291 .45549 L
.71991 .52031 L
.70341 .59255 L
.67257 .66889 L
.62733 .74532 L
.56848 .8173 L
.49771 .87994 L
.41765 .92826 L
.33185 .95748 L
.24464 .9633 L
.16106 .94227 L
.08656 .89206 L
.02679 .81179 L
s
.02679 .81179 m
0 .73749 L
s
0 .36583 m
.03635 .23391 L
.11827 .05278 L
s
.11827 .05278 m
.15244 0 L
s
1 0 .32 r
.67423 .19183 m
.72959 .20721 L
.77862 .24209 L
.81757 .297 L
.84276 .37133 L
.85086 .46323 L
.83912 .56956 L
.8056 .68589 L
.74938 .80663 L
.67081 .92516 L
s
.67081 .92516 m
.60265 1 L
s
1 0 .53 r
.31091 .17986 m
.38899 .07867 L
s
.38899 .07867 m
.47254 0 L
s
0 1 .563 r
.23045 .63069 m
.21785 .56223 L
.22039 .48095 L
.23996 .38997 L
.27763 .29345 L
.33358 .19639 L
.40691 .10451 L
.49555 .02399 L
s
.49555 .02399 m
.53398 0 L
s
0 .832 1 r
.53479 .43019 m
.54759 .4322 L
.55925 .43851 L
.56894 .44933 L
.5758 .46461 L
.57906 .48404 L
.57803 .507 L
.57222 .53261 L
.56132 .55968 L
.54532 .5868 L
.52448 .61235 L
.49941 .6346 L
.47104 .65179 L
.44061 .66221 L
.40968 .66435 L
.38001 .65698 L
.35355 .63925 L
.3323 .61087 L
.31822 .57209 L
.31311 .52386 L
.31846 .46777 L
.33535 .40614 L
.36431 .3419 L
.40522 .27854 L
.45723 .21995 L
.51871 .17026 L
.58726 .13361 L
.65973 .11394 L
.73233 .11467 L
.80074 .13848 L
.86033 .18701 L
.90636 .26068 L
.93428 .35843 L
.94002 .47763 L
.92029 .61404 L
.87286 .76181 L
.79689 .91365 L
s
.79689 .91365 m
.73607 1 L
s
1 0 .864 r
.17786 .47326 m
.20141 .36783 L
.2459 .25624 L
.31146 .14433 L
.39701 .03873 L
s
.39701 .03873 m
.44033 0 L
s
0 .467 1 r
.26582 .80285 m
.21492 .76781 L
.17424 .71213 L
.14758 .63639 L
.13838 .54243 L
.14952 .43343 L
.18305 .31389 L
.23994 .18953 L
.31992 .06712 L
s
.31992 .06712 m
.38019 0 L
s
1 .791 0 r
.74135 .38643 m
.75191 .44817 L
.74885 .52123 L
.73054 .60275 L
.69604 .68899 L
.64526 .77545 L
.57905 .85699 L
.49932 .9281 L
.40901 .98315 L
s
.40901 .98315 m
.36034 1 L
s
.11754 1 m
.03432 .94485 L
s
.03432 .94485 m
0 .89943 L
s
0 .14619 m
.06553 0 L
s
.919 0 1 r
.41787 .18597 m
.48871 .11944 L
.56965 .06673 L
.65722 .03285 L
.74707 .02232 L
.83415 .03887 L
.9129 .08513 L
.97751 .16229 L
s
.97751 .16229 m
1 .21637 L
s
1 .69407 m
.98841 .74144 L
.91031 .92723 L
s
.91031 .92723 m
.86588 1 L
s
.025 0 1 r
.7595 .25646 m
.79648 .30717 L
.8207 .37614 L
.82902 .46167 L
.81882 .56088 L
.78825 .66967 L
.73643 .78282 L
.6636 .89417 L
.57132 .99685 L
s
.57132 .99685 m
.56736 1 L
s
0 .907 1 r
.75628 .73319 m
.69282 .84442 L
.60942 .94993 L
s
.60942 .94993 m
.55485 1 L
s
.152 0 1 r
.38415 .54101 m
.38193 .50963 L
.38646 .4735 L
.39837 .43413 L
.41792 .39346 L
.44496 .35372 L
.47889 .31741 L
.5186 .28716 L
.56249 .26557 L
.60849 .25509 L
.65415 .25782 L
.69669 .27536 L
.73317 .30863 L
.7606 .35774 L
.77614 .42187 L
.77728 .4992 L
.76204 .58688 L
.72914 .68104 L
.6782 .77695 L
.60984 .86912 L
.52584 .95154 L
s
.52584 .95154 m
.45531 1 L
s
1 0 .988 r
.6661 .43332 m
.67094 .4773 L
.66623 .52848 L
.65098 .58478 L
.6247 .64352 L
.58748 .70152 L
.54009 .75523 L
.48399 .80087 L
.42139 .83464 L
.35513 .85295 L
.28869 .85265 L
.22601 .83128 L
.17132 .78731 L
.12895 .72035 L
.10307 .63133 L
.09741 .52263 L
.11501 .3981 L
.15791 .26307 L
.22693 .1242 L
s
.22693 .1242 m
.31388 0 L
s
.571 1 0 r
.38955 .60553 m
.37342 .58418 L
.36268 .55498 L
.35871 .5186 L
.36264 .47628 L
.37528 .42973 L
.39704 .38118 L
.42784 .33325 L
.46704 .28888 L
.51343 .25119 L
.56519 .22332 L
.61996 .20825 L
.67487 .20856 L
.72666 .2263 L
.77183 .26272 L
.8068 .31814 L
.82813 .39179 L
.83273 .48169 L
.8181 .58466 L
.78255 .69629 L
.72542 .81108 L
.64724 .92259 L
s
.64724 .92259 m
.57274 1 L
s
0 1 .359 r
.39054 .41701 m
.41414 .37164 L
.446 .32789 L
.48533 .28858 L
.53076 .25664 L
.58041 .23496 L
.63188 .22621 L
.68233 .23261 L
.72863 .25581 L
.76746 .29667 L
.79551 .35509 L
.80966 .42993 L
.80724 .51892 L
.78617 .61862 L
.74523 .72453 L
.68422 .83115 L
.60409 .93221 L
s
.60409 .93221 m
.53 1 L
s
0 1 .302 r
.78074 .6759 m
.72802 .78748 L
.65467 .89677 L
.56234 .99696 L
s
.56234 .99696 m
.55841 1 L
s
0 1 .308 r
.56437 .53932 m
.55249 .56477 L
.5359 .58975 L
.51497 .6127 L
.49035 .63199 L
.46303 .64597 L
.43428 .65311 L
.40561 .65207 L
.37877 .64182 L
.35557 .62175 L
.3379 .59175 L
.32755 .55228 L
.3261 .50443 L
.33483 .44995 L
.35457 .39121 L
.38561 .33112 L
.42761 .27311 L
.47952 .22091 L
.53956 .1784 L
.60523 .1494 L
.67338 .13746 L
.74025 .14554 L
.80171 .17585 L
.85335 .22951 L
.8908 .30646 L
.90993 .40519 L
.90715 .52272 L
.87973 .65454 L
.82601 .79471 L
.7457 .93595 L
s
.7457 .93595 m
.69521 1 L
s
.192 1 0 r
.73016 .7465 m
.66535 .85119 L
.58204 .94886 L
s
.58204 .94886 m
.52154 1 L
s
.886 0 1 r
.31871 .21646 m
.38863 .12247 L
.4745 .03847 L
s
.4745 .03847 m
.5307 0 L
s
.231 1 0 r
.18482 .70336 m
.15941 .62984 L
.15094 .53878 L
.16216 .43328 L
.19501 .31772 L
.25043 .19764 L
.32811 .07961 L
s
.32811 .07961 m
.4001 0 L
s
1 0 .425 r
.50508 .71388 m
.45966 .7431 L
.4106 .76171 L
.36033 .76719 L
.3117 .75747 L
.26783 .7311 L
.23196 .68743 L
.2073 .62677 L
.19681 .55048 L
.20301 .46102 L
.22774 .36197 L
.27201 .25796 L
.33576 .15454 L
.4178 .05795 L
s
.4178 .05795 m
.48605 0 L
s
.702 1 0 r
.45798 .45122 m
.47061 .43162 L
.48668 .41349 L
.50567 .3981 L
.52686 .38674 L
.54927 .38063 L
.57173 .38082 L
.59289 .38814 L
.61134 .40311 L
.6256 .42585 L
.63427 .45603 L
.63609 .49286 L
.63003 .53502 L
.61541 .58071 L
.59196 .62766 L
.55991 .67326 L
.52001 .71459 L
.47361 .74862 L
.42261 .77237 L
.36943 .78303 L
.31695 .77823 L
.26841 .7562 L
.22721 .71595 L
.19679 .65747 L
.18041 .58182 L
.18091 .49121 L
.2005 .38906 L
.24056 .27992 L
.30142 .16938 L
.38224 .06383 L
s
.38224 .06383 m
.44949 0 L
s
0 1 .107 r
.74315 .53346 m
.72258 .61476 L
.68599 .70003 L
.63343 .78473 L
.56593 .86373 L
.4855 .93155 L
.39523 .98267 L
s
.39523 .98267 m
.33811 1 L
s
.15506 1 m
.11033 .98646 L
.02932 .9259 L
s
.02932 .9259 m
0 .88264 L
s
0 .16404 m
.07842 0 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{1000, 1000},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000?X0003j2000`400?l00000o`00003ooooonf[o
oookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00
oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[
oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Z
oooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooook
J_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z
003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooook
J^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooo
nf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oo
oo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]Zjooo
nfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oo
oo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[o
oookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00
oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[
oookJP00i?oonfX5o`00O`Gooo]Z1Ol007oooookJ^Cooo]Z1Ol007l5oookJPGo001ooooonfX4oook
JP00hooonfX7o`00O`?ooo]Z1ol007oooookJ^;ooo]Z1ol007l3oookJPOo001ooooonfX3oookJP00
hooonfX3o`00O`;ooo]Z0ol007l2oookJP?o001o00Cooo]Zo`00Ool007oo001ooooonf[RoookJP?o
001o0_oonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007oooookJP?ooo]Z003FoookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX4o`00
0?oooo]Zb_oonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`Kooo]Z1?l0003goookJP00@ooonfX00ooo0>[ooo]ZoookJP08oookJP03oolF0?oonf[ooi80
00Sooo]Z00?oo`3loookJ_oonfX00ooonfX01OlH0?oooo]ZoookJ_oonf[oo`H000GoU?l01?oonfX0
1Ol0Y_oooo]ZoookJ_nDo`3ooo]Z00SoU?l000Ko0?nJoom/0?ooP@3o0?o<oookJ_lko`06oookJP03
o`3koooonf[ooo]Z00;ooo]Z00?oo`<0oookJ_oonfX00_oonfX01_mi0?oooo]Zool0gOoonf[o0:?o
ok?o00Oooo]Z00?o0?oNoookJ_oo08L01?oonfX02_oo06cooo]ZoookJ_oonf[oC@3ooookJ_oo;P3o
oo]Zof40ool0odD6oookJP03on80oooonf[ooo]Z00;ooo]Z00?o0?nBoookJ_oonfX02?oonfX00omX
0?oooo]ZoookJP03oookJP;o0?mM0_l0M?l01?oVo`3ooo]ZoookJ_oonfX2oon@00;ooo]Z2_l007l2
oookJP03o`00Oooo_P3ookh000;ooo]Z0_o[0?l00om`0?oo001ooookJP03o`00O`?ooo]Z00?o001o
odCo0?m4o`001_oonfX4o`0000;oo`0]4?oonfX2oon101Gooo]Z0_l0e?l3oookJP;o00Co1_oonfX3
o`2Yo`03oookJ_l0R?oo08So013ooo]Z0ol0obh5o`3oCPGo0?l^3OoonfX6o`3o=003oookJ_l0ocCo
0?ld00;o0?ld2_oonfX01?l0obko0?m>o`3oC_l0odhIoookJP;o08So0_oonfX3o`2Yo`Wooo]Z0_l0
1?l3oookJP;o0=Co8?oonfX00oooP@3ooo]ZoookJP1ToookJP03ool0j_oonf[ooo]Z00Wooo]Z00?o
oaH0oonB0?oonfX01ooonfX00ooo0?cooo]ZoookJP03oookJP05oaP0oooonf[ooo]ZoookJ_oo1P00
0_oonfX01?o[o`3ooo]ZoookJ_oo0?H3oookJP04o`2Voooonf[ooo]ZojP0o`?ooo]Z00?oo`3ioook
J_l0Mol01?oonfX01OooK03ooh40oon10?oonf[o>ol000Kooo]Z00?o0?_ooookJ_oonfX00_oonfX0
0ooo0`3ooo]ZoookJP03oookJP06ogT0oooo0=gooo]Zo`0Gool0Xooo/ol01_oonfX00ooMo`3o0?oN
ool0Q`05oookJP08ool0K?oonf[ooo]ZoookJ_m=0?ooobh0oookJ_mQ0?l2o`3oA@Gooo]Z00?ohP3o
o`3oT?oonfX00_oonfX00ol0oi;ooo]ZoookJP08oookJP03ofP0oooonf[ooo]Z00Cooo]Z00Co603o
o`1dool0M?ooi_l00ooonfX2oon@00;ooo]Z2_l007l2oookJP03o`00Oooo_P3ookh000;ooo]Z00Go
0?l5on/0ooo[0?oo001ooookJP03o`00O`?ooo]Z00?o001ooomG0?ooE`001_oonfX4o`0000;oo`0]
4?oonfX2oon101Kooo]Z0_l0e?l2oookJP;o00Co1ooonfX3o`2Yo`03oookJ_l0R?oo08So00oooo]Z
1?l0obh5o`3oCPCo0?l^3_oonfX:o`3o=0_ooo]Z0ol0odhJoookJP;o08So0_oonfX3o`2Yo`Sooo]Z
0_l01?l4oookJP;o0=Co7ooonfX00oooP@3ooo]ZoookJP0UoookJP00@ooonfX00ooo0>[ooo]Zoook
JP08oookJP03oolF0?oonf[ooi8000Sooo]Z00?oo`3loookJ_oonfX00ooonfX01OlH0?oooo]Zoook
J_nDo`3oo`H000GoU?l01?oonfX00ol0Y_oooo]ZoookJP0:oiCo0006o`3oV_ooK03ooh40o`3oc?oo
nf[o>ol01_oonfX00ol0nooooo]ZoookJP02oookJP03ool30?oonf[ooo]Z00;ooo]Z00KoN@3ooook
J_oo0=gooo]Zo`2Soonco`06oookJP04omgo0?l0omkooo]Zool0Q`Cooo]Z00Woo`1/oookJ_oonf[o
oo]Zodd0oooonf[oobh0oookJ_mQ0?l01_oonfX00ol0oi3ohP3ooookJP02oookJP03o`3oT_oonf[o
oo]Z00Sooo]Z00?oJ03ooookJ_oonfX00ooonfX00ol0oegooo]Zo`1do`02oookJP04onKo0?oonf[o
oo]Zoon@013ooo]Z00Kookh0o`00Ool007oo001oon/0oom`0?l3o`00O`04oookJ_l007oo001oo`00
O`;ooo]Z0_m4o`02o`00O`Kooo]Z0ol000000ooo02gooo]ZoookJP0?oookJP03oon10?oonf[ooo]Z
01;ooo]Z0ol0e?l3oookJP;o00Co1?oonfX4o`2Yo`04oookJ_l0R?oo08Soo`28o`oooo]Z0ol0obh3
o`3oCPgooo]Z2_l0oc@;oookJPGo0?ld2?oonfX01?l0obko0?m>o`3oC_l0odhHoookJP;o08So0ooo
nfX4o`2Yo`Oooo]Z0_l01?l3oookJP;o0=Co7_oonfX00oooP@3ooo]ZoookJP1ToookJP03ool0j_oo
nf[ooo]Z00Wooo]Z00?ooaH0oonB0?oonfX01ooonfX00ooo0?cooo]ZoookJP03oookJP05oaP0oooo
nf[ooo]ZoookJ_oo1P000_oonfX01?o[o`3ooo]ZoookJ_oo0?H3oookJP04o`2Voooonf[ooo]ZojP0
o`?ooo]Z00?oo`3ioookJ_l0Mol01?oonfX01OooK03ooh40o`3oc?oonf[o>ol000Kooo]Z00?o0?_o
oookJ_oonfX00_oonfX00ooo0`3ooo]ZoookJP03oookJP06ogT0oooo0=gooo]Zo`0Gool0Xooo/ol0
1OoonfX01?oMo`3ooo]Zo`3og_oo08L5oookJP08ool0K?oonf[ooo]ZoookJ_m=0?ooobh0oookJ_mQ
0?l6oookJP03o`3oT?oR0?oooo]Z00;ooo]Z00?o0?nBoookJ_oonfX02?oonfX00omX0?oooo]Zoook
JP04oookJP05oaP0ool0M?oooo]ZoookJ_oVo`000_oonfX00oooT03ooo]ZoookJP0>oookJP06oonn
0?l007oo001oo`00Ool0o`Goj`3o0ol007l01?oonf[o001oo`00Ool007l2oookJP;ooeL00_l007l6
oookJP?o000000?oo`0]oookJ_oonfX03ooonfX00oooP@3ooo]ZoookJP0CoookJP?o0=Co0_oonfX2
o`04o`Gooo]Z1?l0ZOl01?oonf[o08Soo`28ool0R?l>oookJP?o0?l^00Cooo]Zo`3oC_l0odko0?m>
3OoonfX:o`3o=0[ooo]Z1Ol0oc@9oookJP?o0?m>00?o0?l^oookJ_oonfX05_oonfX2o`28o`?ooo]Z
0ol0ZOl7oookJP;o00Co1?oonfX2o`3Doakooo]Z00?ooh40oookJ_oonfX09?oonfX004;ooo]Z00?o
o`3ZoookJ_oonfX02?oonfX00ooo5P3ooo]ZoonB0008oookJP03ool0o?oonf[ooo]Z00?ooo]Z00Go
603ooookJ_oonf[oU?l0ool60006oiCo00?ooo]Z00Co0:KooookJ_oonf[oU?l00_oonfX00ooo0?Wo
U?l0oiCo0005oiCo0005oom/0?ooP@3o0?o<oookJ_lko`001_oonfX00ol0nooooo]ZoookJP02oook
JP03ool30?oonf[ooo]Z00;ooo]Z00KoN@3ooookJ_oo0=gooo]Zo`2Soonco`06oookJP04omgo0?l0
omkooo]Zool0Q`Cooo]Z00Woo`1/oookJ_oonf[ooo]Zodd0oooonf[oobh0oookJ_mQ0?l01_oonfX0
0ol0oi3ohP3ooookJP02oookJP03o`3oT_oonf[ooo]Z00Sooo]Z00?oJ03ooookJ_oonfX00ooonfX0
0ol0oegooo]Zo`1do`02oookJP04onKo0?oonf[ooo]Zoon@013ooo]Z00?ookh0o`00Ool007l00_o[
0?l01?m`0?oo001oo`00Ool007l2oookJP?o001o00?ooo]ZodCo0?oonfX00ol007l6oookJP;o0000
00?oo`0]o`000?oonfX03_oonfX2oon101;ooo]Z0ol0e?l3oookJP?o00Co0ooonfX3o`2Yo`?ooo]Z
0_l0R?l?oookJP;o0?l^1?l0odh7oookJPWo0?ld6_oonfX6o`3o=0Kooo]Z1?l0odhFoookJP;o08So
1OoonfX3o`2Yo`Kooo]Z0ol01?l2oookJP03o`3Doooonf[ooo]Z01cooo]Z00?ooh40oookJ_oonfX0
H_oonfX00ooo0>[ooo]ZoookJP09oookJP03oolF0?ooTP3ooo]Z00Oooo]Z00?oo`3loookJ_oonfX0
0ooonfX01OlH0?oooo]ZoookJ_oonf[oo`H000;ooo]Z00Cojol0oookJ_oonf[oo`3f0ooonfX01?l0
Y_oooo]ZoookJ_nX0?l3oookJP03ool0nOoonf[o07Oo00Cooo]Z00Goof`0oon10?l0olcooo]Zoc_o
0006oookJP03o`3koooonf[ooo]Z00;ooo]Z00?oo`<0oookJ_oonfX00ooonfX01_mi0?ooo`3Moook
J_l05ooo0:?ook?o00Gooo]Z00CogOl0oookJ_l0omkoo`271OoonfX02?oo06cooo]ZoookJ_oonf[o
C@3oool^0?oonf[oH@3o1_oonfX00ol0oi3ohP3ooookJP02oookJP03o`3oT_oonf[ooo]Z00Sooo]Z
00?oJ03ooookJ_oonfX01?oonfX01OlH0?oo07CooookJ_oonf[oi_l000;ooo]Z00?ooi00oookJ_oo
nfX03_oonfX01?oo_P3o001oo`00Ool007l2on/0o`?o001o0_oonfX3o`00O`03oookJ_ooE`3ooo]Z
00?o001o1_oonfX2o`000003ool0;Ol0003ooo]Z00kooo]Z0_ooP@0CoookJP?o0=Co0ooonfX2o`04
o`?ooo]Z1?l0ZOl3oookJP;o08So3_oonfX3o`3o;PCo0?m>1ooonfX9o`3o=1Wooo]Z1_l0oc@6oook
JPCo0?m>00?o0?l^oookJ_oonfX05?oonfX2o`28o`Cooo]Z0ol0ZOl6oookJP?o00Co0ooonfX00ol0
e?oooo]ZoookJP0LoookJP03oon10?oonf[ooo]Z02?ooo]Z0012oookJP03ool0j_oonf[ooo]Z00So
oo]Z00?ooaH0oookJ_ooTP001ooonfX00ooo0?cooo]ZoookJP04oookJP05oaP0oooonf[oU?l0oiCo
0?oo1P001_nDo`02oookJP04o`2Voooonf[ooo]ZoiCo00?ooo]Z00?oo`3ioookJ_oonfX01?nDo`00
0oooK03ooo]Zoon10002oookJP03oc_o0?oonf[ooo]Z00?ooo]Z00?o0?_ooookJ_oonfX00ooonfX0
2_oo0`3ooo]ZoookJ_oonf[oN@3ooookJ_oo0=gooo]Zo`2Soonco`07oookJP03o`3og_oonf[oo`27
00Cooo]Z00Woo`1/oookJ_oonf[ooo]Zodd0oooonf[oobh0oookJ_mQ0?l01_oonfX00ol0oi3ohP3o
oookJP02oookJP03o`3oT_oonf[ooo]Z00Sooo]Z00?oJ03ooookJ_oonfX01?oonfX01OlH0?oo07Co
oookJ_oonf[oi_l000;ooo]Z00?ooi00oookJ_oonfX03OoonfX2oonn0005oookJ_l007ooj`3ooiCo
0?m`0?l00ol007l3oookJP;o001o00CooeL0odCo0?oonf[ooo]Z0ol007l6oookJP04o`000?oo02go
0000o`0000kooo]Z00?ooh40oookJ_oonfX03ooonfX3o`3Do`Cooo]Z0_l01?l3oookJP?o0:Wo0ooo
nfX3o`28o`kooo]Z0_l0obh3o`3oCP03oookJ_l0ocCo0?ld00So0?ld:OoonfX5o`3o=0Gooo]Z0ol0
odh00ol0obkooo]ZoookJP0BoookJP;o08So1_oonfX3o`2Yo`Kooo]Z0_l01?l00ooonf[o0=Coo`3D
o`0MoookJP03oon10?oonf[ooo]Z067ooo]Z00?oo`3ZoookJ_oonfX02?oonfX00ooo5P3ooo]ZoonB
0007oookJP03ool0o?oonf[ooo]Z00Cooo]Z00Go603ooookJ_oonf[ooo]Zool60002oookJP04on_o
0?oonf[ooo]Zool0mP;ooo]Z00Go0:KooookJ_oonf[ooo]ZojP0o`03oookJP03ool0nOoonf[o07Oo
00?ooo]Z00?oof`0oookJ_ooP@000_oonfX00olko`3ooo]ZoookJP03oookJP03o`3koooonf[ooo]Z
00?ooo]Z00?oo`<0oookJ_oonfX00_oonfX01_mi0?ooo`3MoookJ_l05ooo0:?ook?o00Kooo]Z00?o
gOl0o`3og_oo08L01OoonfX02?oo06cooo]ZoookJ_oonf[oC@3oool^0?oonf[oH@3o1_oonfX00ol0
oi3ohP3ooookJP02oookJP03o`3oT_oonf[ooo]Z00Sooo]Z00?oJ03ooookJ_oonfX01OoonfX01?lH
0?oooo]ZoookJ_oVo`02oookJP03oon@0?oonf[ooo]Z00kooo]Z00Kookh0oookJ_l007oo001oon/0
oom`0?l3o`00O`?ooo]Z0ol007l00oooE`3ooo]ZoookJP03o`00O`Kooo]Z00Co0000ool0;Ol0003o
00003_oonfX00oooP@3ooo]ZoookJP0@oookJP?o0=Co0ooonfX3o`04o`;ooo]Z0ol0ZOl4oookJP?o
08So3OoonfX2o`3o;PCo0?m>00?ooo]Zo`3o=?l0oc@02?l0oc@XoookJPGo0?ld1OoonfX4o`3oCP03
o`3o;_oonf[ooo]Z01;ooo]Z0_l0R?l5oookJP?o0:Wo1_oonfX2o`04o`;ooo]Z0_l0e?lMoookJP03
oon10?oonf[ooo]Z02;ooo]Z0011oookJP03ool0j_oonf[ooo]Z00Sooo]Z00?ooaH0oookJ_ooTP00
2?oonfX00ooo0?cooo]ZoookJP03oookJP05oaP0oooonf[ooo]ZoookJ_oo1P001_nDo`03oookJP04
o`2Voooonf[ooo]ZoiCo00;ooo]Z00Coo`3ioookJ_oonf[oU?l00ooonfX01_nDo`3oof`0oon10?l0
olcooo]Zoc_o00Kooo]Z00?o0?_ooookJ_oonfX00_oonfX00ooo0`3ooo]ZoookJP02oookJP06ogT0
oooo0=gooo]Zo`0Gool0Xooo/ol01_oonfX01?oMo`3o0?oNoookJ_oo08L3oookJP09ool0K?oonf[o
oo]ZoookJ_m=0?oooo]Zool^0?oonf[oH@3o00Oooo]Z00GohP3ooookJ_oonf[ooo]Zo`3oTP0:oook
JP03ofP0oooonf[ooo]Z00Cooo]Z00Go603oo`1doooonf[ooo]ZonKo0002oookJP03oon@0?oonf[o
oo]Z00gooo]Z00Gookh0oookJ_oonf[ooo]Zon/0o`02og00o`Oooo]Z00?o001ooomG0?l007l00ooo
nfX3o`00O`Gooo]Z0_oo02d3o`0000cooo]Z0_ooP@0?oookJP?o0=Co1OoonfX2o`04o`?ooo]Z0_l0
ZOl4oookJP;o08So3_oonfX00ol0obko0?m>o`3oCP02o`3oCPCo0?ld>?oonfX5o`3o=0?ooo]Z1?l0
odh2o`3o;Q7ooo]Z0_l0R?l7oookJP03o`2Yoooonf[ooo]Z00Gooo]Z0_l01?l00ooonf[o0=Coo`3D
o`1noookJP03ool0j_oonf[ooo]Z00Sooo]Z00?ooaH0oookJ_ooTP002?oonfX00ooo0?cooo]Zoook
JP03oookJP05oaP0oooonf[ooo]ZoookJ_oo1P000_oonfX01?o[o`3ooo]ZoookJ_oo0?H3oookJP04
o`2Voooonf[ooo]ZojP0o`?ooo]Z00?oo`3ioookJ_l0Mol00ooonfX01_l0oi[oof`0oon10?l0olco
oo]Zoc_o00Kooo]Z00?o0?_ooookJ_oonfX00_oonfX00ooo0`3ooo]ZoookJP02oookJP07ogT0oooo
0=gooo]Zo`0Goooonf[o0:?ook?o0005oookJP04omgo0?oonf[o0?oNool0Q`Cooo]Z00Soo`1/oook
J_oonf[ooo]Zodd0oooo;P3ooo]Zof40o`Oooo]Z00GohP3ooookJ_oonf[ooo]Zo`3oTP0:oookJP03
ofP0oooonf[ooo]Z00Gooo]Z00Co603ooookJ_oonf[oi_l00_oonfX00oooT03ooo]ZoookJP0>oook
JP06oonn0?oonf[ooo]Zo`00Ooo[0?ooL03o1ooonfX2o`00O`04oomG0?oonf[ooo]ZoookJP?o001o
1OoonfX2ool0;@?o00003?oonfX2oon1013ooo]Z0ol0e?l4oookJP;o00Co0ooonfX2o`2Yo`Gooo]Z
0_l0R?l=oookJP;o0?l^0ol0odh5o`3o=3Oooo]Z1Ol0oc@4oookJP?o0?m>0_l0obhBoookJP;o08So
1_oonfX00ol0ZOoooo]ZoookJP05oookJP;o00Co0_oonfX2o`3Dod3ooo]Z0010oookJP03ool0j_oo
nf[ooo]Z00Wooo]Z00?ooaH0oookJ_ooTP001ooonfX00ooo0?cooo]ZoookJP04oookJP04oaP0oooo
nf[ooo]Zool600?ooo]Z1?nDo`02oookJP04o`2Voooonf[ooo]ZoiCo00?ooo]Z00?oo`3ioookJ_nD
o`000ooonfX01_l0oi[oof`0oookJ_ooP@3ooo]Zoc_o00Kooo]Z00?o0?_ooookJ_oonfX00_oonfX0
0ooo0`3ooo]ZoookJP02oookJP06ogT0oooonf[oo`3MoookJ_l0Xooo/ol01_oonfX01?oMo`3o0?oN
oookJ_oo08L4oookJP09ool0K?oonf[ooo]Zodd0oooonf[oobh0oookJ_l0odGoH@3o00Kooo]Z00Go
hP3ooookJ_oonf[ooo]Zo`3oTP0:oookJP03ofP0oooonf[ooo]Z00Cooo]Z00Ko603oo`3o3?oonf[o
oo]ZonKo0?oonfX2oon@00oooo]Z00?ookh0oookJ_oonfX00_oonfX00oo[0?oo001oo`00O`07oook
JP03oomG0?l007oo001o00?ooo]Z0ol007l4oookJP03ool0;Ooonf[o000000?o00002ooonfX00ooo
P@3ooo]ZoookJP0>oookJP03o`3Doooonf[ooo]Z00?ooo]Z0ol01?l4oookJP03o`2Yoooonf[ooo]Z
00;ooo]Z0_l0R?l=oookJPCo0?m>0_l0ocA3oookJPKo0?ld00Cooo]Zo`3oC_l0odko0?m>0ol0obh?
oookJP;o08So1_oonfX00ol0ZOoooo]ZoookJP06oookJP;o00Co00?ooo]Zo`3Dool0e?l0NooonfX0
0ooo0>[ooo]ZoookJP09oookJP03oolF0?oonf[ooi8000Oooo]Z00?oo`3loookJ_oonfX01?oonfX0
1?lH0?oooo]ZoookJ_oo1P03oookJP04on_o0?oonf[ooo]Zool0mP;ooo]Z00Co0:KooookJ_oonf[o
Z03o0ooonfX00ooo0?Wooo]Zo`1go`04oookJP05oom/0?oonf[ooh40oookJ_lko`001_oonfX00ol0
nooooo]ZoookJP02oookJP03ool30?oonf[ooo]Z00;ooo]Z00OoN@3ooookJ_oo0=gooo]Zo`0Gool0
Xooo/ol000Gooo]Z00CogOl0oookJ_l0omkoo`271OoonfX02?oo06cooo]ZoookJ_m=0?oooo]Zool^
0?l0odGoH@3o1_oonfX01OoR0?oooo]ZoookJ_oonf[o0?nB00[ooo]Z00?oJ03ooookJ_oonfX01Ooo
nfX01?lH0?oooo]ZoookJ_oVo`02oookJP03oon@0?oonf[ooo]Z00kooo]Z00Oookh0oookJ_oonf[o
oo]Zog00ooo[0?oo001o00Oooo]Z00?o001ooomG0?l007l00ooonfX3o`00O`Cooo]Z00?oo`0]oook
J_l000000ol0000;oookJP03oon10?oonf[ooo]Z00oooo]Z00?o0=CooookJ_oonfX00ooonfX2o`04
o`Cooo]Z00?o0:WooookJ_oonfX00ooonfX2o`28o`cooo]Z00?o0?l^o`3oC_l0odh00_l0odh2o`3o
=4;ooo]Z1_l0oc@00ooonf[o0?m>o`3oCP02o`3oCP;o0?l^4?oonfX2o`28o`Gooo]Z00?o0:Wooook
J_oonfX01_oonfX2o`04o`;ooo]Z0_l0e?lnoookJP00@?oonfX00ooo0>[ooo]ZoookJP08oookJP03
oolF0?oonf[ooi8000Sooo]Z00?oo`3loookJ_oonfX00ooonfX01OlH0?oooo]ZoookJ_oonf[oo`H0
00;ooo]Z00OoU?l0oookJ_oo0?Kooo]ZoiCo0?oonf[o0:Ko00?ooo]Z00CoU?l0oookJ_oonf[oo`3i
0_oonfX01onDo`3ooo]ZoookJ_l0oi[oof`0oookJ_ooP@000_oonfX00olko`3ooo]ZoookJP03oook
JP03o`3koooonf[ooo]Z00?ooo]Z00[oo`<0oookJ_oonf[ooo]ZogT0oooonf[oo`3MoookJ_l0Xooo
/ol01ooonfX00ol0omkooo]Zool0Q`04oookJP09ool0K?oonf[ooo]ZoookJ_m=0?oooo]Zool^0?oo
nf[oH@3o00Kooo]Z00GohP3ooookJ_oonf[ooo]Zo`3oTP0:oookJP03ofP0oooonf[ooo]Z00Cooo]Z
00Oo603oo`3o3?l0o`cooo]ZonKo0?oonf[ooi0000oooo]Z0_nDo`03oookJP03oiCo0?o[0?oooo]Z
00?o001o0_oonfX3o`00O`03oomG0?oonf[o001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX0
0ooo02gooo]ZoookJP04o`0000[ooo]Z00?ooh40oookJ_oonfX03OoonfX2o`3Do`Cooo]Z0_l01?l5
oookJP;o0:Wo0_oonfX3o`28o`cooo]Z0ol0odh00ooonf[o0?ldo`3o=01<oookJPCo0?ld1?l0odh3
o`3o;Pgooo]Z0_l0R?l5oookJP;o0:Wo2?oonfX3o`04o`03o`3Doooonf[ooo]Z07Sooo]Z00?oo`3Z
oookJ_oonfX02?oonfX00ooo5P3ooo]ZoonB0008oookJP03ool0o?oonf[ooo]Z00?ooo]Z00Go603o
oookJ_oonf[ooo]Zool60002oookJP04on_o0?oonf[ooo]Zool0mP;ooo]Z00Go0:KooookJ_oonf[o
oo]ZojP0o`03oookJP03ool0nOoonf[o07Oo00?ooo]Z00?oof`0oookJ_ooP@000_oonfX00olko`3o
oo]ZoookJP03oookJP03o`3koooonf[ooo]Z00?ooo]Z00?oo`<0oookJ_oonfX00_oonfX01_mi0?oo
o`3MoookJ_l05ooo0:?ook?o00Kooo]Z00?ogOl0o`3og_oo08L01OoonfX02?oo06cooo]ZoookJ_oo
nf[oC@3oool^0?oonf[oH@3o1_oonfX01OoR0?oooo]ZoookJ_oonf[o0?nB00[ooo]Z00?oJ03ooook
J_oonfX01OoonfX01?lH0?oo07CooookJ_oVo`02oookJP03oon@0?oonf[ooo]Z00kooo]Z00Kookh0
oookJ_oonf[ooo]Zog00ooo[0?l3o`00O`;ooo]Z0ol007l00ooonf[ooeL0o`00O`02o`00O`04oook
J_l007oo001oo`00O`Cooo]Z00?oo`0]oookJ_oonfX01?l0000:oookJP03oon10?oonf[ooo]Z00ko
oo]Z0_l0e?l4oookJP;o00Co1?oonfX2o`2Yo`?ooo]Z0ol0R?l;oookJPCo0?m>0ol0ocA;oookJPGo
0?ld0ol0odh3o`3o;Pkooo]Z0_l0R?l4oookJP;o0:Wo2?oonfX3o`04o`03oookJ_l0e?oooo]Z03co
oo]Z000ooookJP03ool0j_oonf[ooo]Z00Wooo]Z00?ooaH0oookJ_ooTP001ooonfX00ooo0?cooo]Z
oookJP04oookJP04oaP0oooonf[ooo]Zool600?ooo]Z00?oU?l0oookJ_oo0?H00_oonfX01Ol0Y_oo
oo]ZoookJ_oonf[oU?l000;ooo]Z00Coo`3ioookJ_oonf[oU?l00ooonfX01_l0oi[oof`0oon10?l0
olcooo]Zoc_o00Gooo]Z00?o0?_ooookJ_oonfX00ooonfX02ooo0`3ooo]ZoookJ_oonf[oN@3ooook
J_oo0=gooo]Zo`0Gool0Xooo/ol000Kooo]Z00CogOl0o`3og_oonf[oo`270ooonfX02Ooo06cooo]Z
oookJ_oonf[oC@3ooookJ_oo;P3ooo]Zof40o`06oookJP05on80ool0oi3ooo]ZoookJ_l0oi802_oo
nfX00omX0?oooo]ZoookJP04oookJP07oaP0ool0o`co0?l<oookJ_oVo`3ooo]Zoon@000?oookJP?o
U?l00_oonfX01?nDo`3oj`3ooookJ_oonfX7o`00O`03oomG0?oonf[ooo]Z00Oo001o0ooonfX01?oo
02gooo]ZoookJ_oonfX4o`0000Sooo]Z0_ooP@0?oookJP03o`3Doooonf[ooo]Z00;ooo]Z0_l01?l5
oookJP;o0:Wo0_oonfX2o`28o`_ooo]Z1?l0odh01?oonf[o0?ldo`3o=?l0ocACoookJP?o0?ld0ol0
odh4o`3o;P_ooo]Z0_l0R?l5oookJP03o`2Yoooonf[ooo]Z00Sooo]Z00?o00Coo`3Dool0e?l0Mooo
nfX00ooo0>[ooo]ZoookJP09oookJP03oolF0?oonf[ooi8000Oooo]Z00?oo`3loookJ_oonfX01?oo
nfX01?lH0?oooo]ZoookJ_oo1P03oookJP03on_o0?oonf[oo`3f00;ooo]Z00Go0:KooookJ_oonf[o
oo]ZojP0o`03oookJP03ool0nOoonf[o07Oo00?ooo]Z00Ko0?nJoom/0?oonf[ooh40oookJ_lko`05
oookJP03o`3koooonf[ooo]Z00?ooo]Z00?oo`<0oookJ_oonfX00_oonfX01omi0?ooo`3MoookJ_l0
5ooo0:?ooookJ_nco`001OoonfX01?oMo`3ooo]Zo`3og_oo08L4oookJP08ool0K?oonf[ooo]Zoook
J_m=0?ooobh0oookJ_mQ0?l6oookJP05on80ool0oi3ooo]ZoookJ_l0oi802_oonfX00omX0?oooo]Z
oookJP05oookJP04oaP0ool0M?oooo]ZonKo00;ooo]Z00?ooi00oookJ_oonfX03ooonfX01_oo_P3o
oo]ZoookJ_m`0?ooj`3ooookJPOo001o00?ooo]ZoomG0?oonfX01ol007l3oookJP04ool0;Ooonf[o
oo]ZoookJPCo00002?oonfX2oon1013ooo]Z00?o0=CooookJ_oonfX00_oonfX2o`04o`Cooo]Z0_l0
ZOl3oookJP;o08So2ooonfX3o`3oCP;ooo]Z0_l0ocACoookJP?o0?ld1?l0odh3o`3o;Pcooo]Z0_l0
R?l4oookJP03o`2Yoooonf[ooo]Z00Sooo]Z0_l01?l2o`3Doc_ooo]Z000ooookJP03ool0j_oonf[o
oo]Z00Sooo]Z00?ooaH0oookJ_ooTP001ooonfX00ooo0?cooo]ZoookJP04oookJP05oaP0oooonf[o
oo]ZoookJ_oo1P000_oonfX00onDo`3ooo]Zool0mP03oookJP04o`2Voooonf[ooo]ZoiCo00?ooo]Z
00Coo`3ioookJ_oonf[oU?l00_oonfX01?l0oi[oof`0oookJ_ooP@02oookJP03oc_o0?oonf[ooo]Z
00?ooo]Z00?o0?_ooookJ_oonfX00ooonfX02_oo0`3ooo]ZoookJ_oonf[oN@3ooookJ_oo0=go01Oo
o`2Soonco`07oookJP03o`3og_oonf[oo`2700Cooo]Z00Soo`1/oookJ_oonf[oC@3ooookJ_oo;P3o
oo]Zof40o`Kooo]Z00?ohP3oo`3oT?oonfX00_oonfX00ol0oi;ooo]ZoookJP08oookJP03ofP0oooo
nf[ooo]Z00?ooo]Z00Oo0?l<oaP0ool0o`co0?l<onKo0?oonf[ooi0000oooo]Z0onDo`02oookJP03
oiCo0?o[0?oooo]Z00Cooo]Z1?l007l00oooE`3ooo]ZoookJP02oookJPGo001o0_oonfX2ool0;@Co
oo]Z1?l00007oookJP03oon10?oonf[ooo]Z00gooo]Z0_l0e?l3oookJP;o00Co1OoonfX2o`2Yo`04
oookJ_l0R?oo08Soo`28o`[ooo]Z0ol0odh00ol0obkooo]ZoookJP02o`3o=5[ooo]Z00?o0?ldoook
J_l0odh00ol0odh3o`3o;P[ooo]Z0_l0R?l4oookJP03o`2Yoooonf[ooo]Z00Wooo]Z00?o00Coo`3D
ool0e?l0MOoonfX00ooo0>[ooo]ZoookJP08oookJP03oolF0?oonf[ooi8000Oooo]Z00?oo`3loook
J_oonfX01?oonfX01OlH0?oooo]ZoookJ_oonf[oo`H000;ooo]Z00Cojol0oookJ_oonf[oo`3f0_oo
nfX01Ol0Y_oooo]ZoookJ_oonf[oZ03o00?ooo]Z00?oo`3ioookJ_l0Mol00_oonfX01?l0oi[oof`0
oookJ_ooP@02oookJP03oc_o0?oonf[ooo]Z00?ooo]Z00?o0?_ooookJ_oonfX00ooonfX02ooo0`3o
oo]ZoookJ_oonf[oN@3ooookJ_oo0=go01Oooil0ool0Xooo/ol000Kooo]Z00?ogOl0o`3og_oo08L0
1?oonfX02Ooo06cooo]ZoookJ_oonf[oC@3oool^0?oonf[o0?m5of40o`06oookJP05on80oooonf[o
oo]ZoookJ_l0oi802_oonfX00omX0?oooo]ZoookJP05oookJP03oaP0oooonf[oi_l000;ooo]Z00?o
oi00oookJ_oonfX03ooonfX01Ooo_P3ooo]Zo`3o1Om`0?ooj`3o00Cooo]Z1?l007l00ooonf[ooeL0
oookJP02oookJPGo001o0_oonfX2ool0;@Cooo]Z1?l00007oookJP03oon10?oonf[ooo]Z00kooo]Z
0_l0e?l2oookJP?o00Co1?oonfX2o`2Yo`;ooo]Z0ol0R?l9oookJPCo0?m>0_oonfX3o`3o=5Wooo]Z
0_l0oc@00ooonf[o0?m>o`3oCP02o`3oCP;o0?l^2ooonfX00ol0R?oooo]ZoookJP02oookJP03o`2Y
oooonf[ooo]Z00Wooo]Z00Co00CooookJ_l0e?oo0=Co>OoonfX003kooo]Z00?oo`3ZoookJ_oonfX0
2OoonfX00ooo5P3ooo]ZoonB0007oookJP03ool0o?oonf[ooo]Z00Cooo]Z00Co603ooookJ_oonf[o
o`H00ooonfX00onDo`3oo`3foookJP02oookJP05o`2Voooonf[ooo]ZoookJ_nDo`000_oonfX01?oo
0?Wooo]ZoookJ_nDo`02oookJP04o`3oV_ooK03ooo]Zoon100;ooo]Z00?o>ol0oookJ_oonfX00ooo
nfX00ol0nooooo]ZoookJP03oookJP0:ool30?oonf[ooo]ZoookJ_mi0?oooo]Zool0gOoonf[o0:?o
ok?o00Oooo]Z00?ogOl0o`3og_oo08L01?oonfX01_oo06cooo]ZoookJ_m=0?oooo]Zool^00;ooo]Z
00?oH@3ooookJ_oonfX00ooonfX00ooR0?oo0?n@oookJP02oookJP03o`3oT_oonf[ooo]Z00Sooo]Z
00?oJ03ooookJ_oonfX00ooonfX01ol0o`co603oo`3o3?l0o`coi_l0oookJ_ooT0003_oonfX5oiCo
0004oookJ_nDo`3oj`3oog00o`Sooo]Z00?ooeL0oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP04
oookJPCo00001OoonfX2oon100oooo]Z00?o0=CooookJ_oonfX00ol01?l5oookJP;o0:Wo00?ooo]Z
o`28ool0R?l02OoonfX4o`3oCP03o`3o;_oonf[ooo]Z00?o0?ld9_oonfX4onGo03?ooo]Z0_l0oc@3
oookJP?o0?m>00?o0?l^oookJ_oonfX02OoonfX2o`28o`?ooo]Z0_l0ZOl9oookJP03o`04oooonf[o
oo]Z00;o0=CoL_oonfX00ooo0>[ooo]ZoookJP09oookJP03oolF0?oonf[ooi8000Oooo]Z00?oo`3l
oookJ_oonfX01?oonfX01?lH0?oooo]ZoookJ_oo1P03oookJP03on_o0?oonf[oo`3f00;ooo]Z00Go
0:KooookJ_oonf[ooo]ZojP0o`03oookJP03ool0nOoonf[o07Oo00?ooo]Z00Koof`0oookJ_ooP@3o
0?o<oookJ_lko`05oookJP03o`3koooonf[ooo]Z00?ooo]Z00_oo`<0oookJ_oonf[ooo]ZogT0oooo
nf[oo`3MoookJ_nO0?oo0:?ook?o0006oookJP03omgo0?oonf[oo`2700Gooo]Z00Goo`1/oookJ_oo
nf[oC@3oool^0002oookJP03of40oooonf[ooo]Z00Cooo]Z00GohP3ooookJ_oonf[ooo]Zo`3oTP0:
oookJP03ofP0oooonf[ooo]Z00Gooo]Z00?o603ooookJ_oVo`000_oonfX00oooT03ooo]ZoookJP0?
oookJP05oonn0?oonf[o0?l5oookJ_o[0?l02OoonfX00oooE`3ooo]ZoookJP08oookJP03ool0;Ooo
nf[ooo]Z00Cooo]Z1?l00005oookJP;ooh404?oonfX00ol0e?oooo]ZoookJP02o`04o`Gooo]Z0_l0
ZOl2oookJP;o08So2?oonfX4o`3oCP04o`3o;_oonf[ooo]ZoookJP;o0?ldG_oonfX00ol0ocCooo]Z
oookJP02oookJP?o0?m>2ooonfX2o`28o`?ooo]Z0_l0ZOl9oookJP04o`04oooonf[ooo]ZoookJP;o
0=Co=ooonfX003gooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ooo5P3ooo]ZoonB0006oookJP03ool0
o?oonf[ooo]Z00Cooo]Z00Co603ooookJ_oonf[oo`H00ooonfX00onDo`3ooo]Zool0mP02oookJP05
o`2Voooonf[ooo]ZoookJ_nDo`000ooonfX02_oo0?Wooo]ZoookJ_nDo`3ooo]Zo`3oV_oonf[oof`0
oookJ_ooP@02oookJP03oc_o0?oonf[ooo]Z00;ooo]Z00?o0?_ooookJ_oonfX00ooonfX02ooo0`3o
oo]ZoookJ_oonf[oN@3ooookJ_oo0=gooo]Zo`0Gool0Xooo/ol000Kooo]Z00?ogOl0o`3og_oo08L0
1?oonfX01_oo06cooo]ZoookJ_oonf[oC@3oool^00;ooo]Z00?oH@3ooookJ_oonfX00ooonfX00ooR
0?oooo]Zo`3oT002oookJP03o`3oT_oonf[ooo]Z00Sooo]Z00?oJ03ooookJ_oonfX00_oonfX2o`3o
3006oaP0ool0o`co0?l<onKo0?oonf[ooi003_oonfX5oiCo0004oookJ_nDo`3oj`3oog00o`Sooo]Z
00?ooeL0oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP05oookJPCo00001?oonfX00oooP@3ooo]Z
oookJP0=oookJP;o0=Co00?ooo]Zo`04ool01?l01ooonfX01?l0ZOoo08Soo`28ool0R?l8oookJP?o
0?m>0_l0obh3oookJP;o0?ld:OoonfX9onGo033ooo]Z0_l0oc@4oookJP?o0?m>2ooonfX2o`28o`?o
oo]Z00?o0:WooookJ_oonfX01ooonfX01Ol01?oooo]ZoookJ_oonf[o0=Co077ooo]Z00?oo`3Zoook
J_oonfX02OoonfX00ooo5P3ooo]ZoonB0006oookJP03ool0o?oonf[ooo]Z00Cooo]Z00Go603ooook
J_oonf[ooo]Zool60002oookJP06on_o0?oonf[ooo]Zool0m_oonf[o0:Ko0ooonfX00onX0?oooo]Z
oookJP02oookJP03ool0nOoonf[o07Oo00;ooo]Z00Co0?nJoom/0?oonf[ooh400_oonfX00olko`3o
oo]ZoookJP02oookJP03o`3koooonf[ooo]Z00?ooo]Z00coo`<0oookJ_oonf[ooo]ZogT0oooonf[o
o`3MoookJ_l05ooo0:?ooookJ_nco`05oookJP04omgo0?oonf[o0?oNool0Q`Cooo]Z00Soo`1/oook
J_oonf[ooo]Zodd0oooo;P3ooo]Zof40o`Kooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP0:oookJP03
ofP0oooonf[ooo]Z00Gooo]Z00?o603oo`1doooVo`000_oonfX00oooT03ooo]ZoookJP0?oookJP05
oonn0?oonf[o0?l5oookJ_o[0?l02OoonfX00oooE`3ooo]ZoookJP08oookJP03ool0;Ooonf[ooo]Z
00Gooo]Z1?l00004oookJP03oon10?oonf[ooo]Z00kooo]Z0_l0e?l00ooonf[o00Coo`04o`06oook
JP03o`2Yoooonf[o08So00;o08So1ooonfX3o`3oCP;o0?l^0ooonfX3o`3o=67ooo]Z0_l0oc@5oook
JP?o0?m>2_oonfX2o`28o`?ooo]Z00?o0:WooookJ_oonfX01ooonfX00ol01?oooo]ZoookJP02oook
JP03o`3Doooonf[ooo]Z03Cooo]Z000moookJP03ool0j_oonf[ooo]Z00Wooo]Z00?ooaH0oookJ_oo
TP001ooonfX00ooo0?cooo]ZoookJP04oookJP04oaP0oooonf[ooo]Zool600?ooo]Z00?oU?l0ool0
m_oonfX00_oonfX01?l0Y_oooo]ZoookJ_nDo`03oookJP04ool0nOoonf[ooo]ZoiCo00;ooo]Z00Co
0?nJoom/0?oonf[ooh400_oonfX00olko`3ooo]ZoookJP03oookJP03o`3koooonf[ooo]Z00?ooo]Z
00[oo`<0oookJ_oonf[ooo]ZogT0oooo0=gooo]Zo`0Gool0Xooo/ol01ooonfX00ol0omkooo]Zool0
Q`03oookJP09ool0K?oonf[ooo]ZoookJ_m=0?oooo]Zool^0?oonf[oH@3o00Gooo]Z00?ohP3ooook
J_l0oi000ooonfX00ol0oi;ooo]ZoookJP07oookJP03ofP0oooonf[ooo]Z00;ooo]Z0_l0o``01olH
0?oo0?l<o`3o3?oVo`3o0?l<oookJ_ooT0003OoonfX7oiCo0003on/0oom`0?oooo]Z00Oooo]Z00?o
oeL0oookJ_oonfX02?oonfX2ool0;@Sooo]Z1?l00002oookJP;ooh403ooonfX01?l0e?oooo]Zo`04
ool01?l7oookJP;o0:Wo00?o08SooookJ_oonfX01_oonfX3o`3oCP;o0?l^0ooonfX3o`3o=2_ooo]Z
3_oUo`0]oookJP03o`3o=?oonf[ooo]Z00Cooo]Z00?o0?m>oookJ_oonfX02_oonfX2o`28o`;ooo]Z
00?o0:WooookJ_oonfX01ooonfX01?l01?oooo]ZoookJ_oonfX2o`3Dofkooo]Z00?oo`3ZoookJ_oo
nfX02OoonfX00ooo5P3ooo]ZoonB0007oookJP03ool0o?oonf[ooo]Z00Cooo]Z00Co603ooookJ_oo
nf[oo`H00ooonfX00oo[o`3ooo]Zool0mP02oookJP05o`2Voooonf[ooo]ZoookJ_nX0?l00ooonfX0
0ooo0?Wooo]Zo`1go`02oookJP04o`3oV_ooK03ooo]Zoon100;ooo]Z00?o>ol0oookJ_oonfX00ooo
nfX00ol0nooooo]ZoookJP03oookJP0;ool30?oonf[ooo]ZoookJ_mi0?ooo`3MoookJ_l05oooW`3o
o`2Soonco`001_oonfX00ooMo`3o0?oNool0Q`04oookJP08ool0K?oonf[ooo]ZoookJ_m=0?ooobh0
oookJ_mQ0?l6oookJP03on80ool0oi3ooo]Z00;ooo]Z00?o0?nBoookJ_oonfX01ooonfX00omX0?oo
oo]ZoookJP05oookJP03oaP0ool0M?ooi_l000?ooo]Z00?ooi00oookJ_oonfX03_oonfX01Ooo_P3o
oo]Zo`3o1Ooonf[oj`3o00Wooo]Z00?ooeL0oookJ_oonfX01ooonfX2ool0;@Sooo]Z1?l00002oook
JP;ooh404?oonfX01?l0e?oooo]Zo`04ool01?l6oookJP;o0:Wo0_l0R?l7oookJP?o0?m>0_l0obh3
oookJP?o0?ldI_oonfX2o`3o=0Gooo]Z00?o0?l^o`3oC_oonfX02_oonfX2o`28o`;ooo]Z00?o0:Wo
oookJ_oonfX01ooonfX00ol01?oooo]ZoookJP02oookJP;o0=Co=?oonfX003cooo]Z00?oo`3Zoook
J_oonfX02_oonfX00ooo5P3ooo]ZoonB0006oookJP03ool0o?oonf[ooo]Z00Cooo]Z00Co603ooook
J_oonf[oo`H00ooonfX00onDo`3ooo]Zool0mP02oookJP05o`2Voooonf[ooo]ZoookJ_nDo`000ooo
nfX02_oo0?Wooo]ZoookJ_nDo`3ooo]Zo`3oV_oonf[oof`0o`3oc?ooP@02oookJP03oc_o0?oonf[o
oo]Z00;ooo]Z00?o0?_ooookJ_oonfX00ooonfX02_oo0`3ooo]ZoookJ_oonf[oN@3ooookJ_oo0=go
oo]Zo`2Soonco`07oookJP03omgo0?l0omkoo`2700Cooo]Z00Woo`1/oookJ_oonf[oC@3ooookJ_oo
;P3ooo]Zof40ool0odD01?oonfX00ooR0?oooo]Zo`3oT003oookJP03o`3oT_oonf[ooo]Z00Sooo]Z
00CoJ03ooookJ_oonf[ooo]Z0ol0o``01_lH0?oo0?l<onKo0?l0o`cooo]Zoon@00cooo]Z1onDo`00
0ooonf[oj`3oog00o`08oookJP03oomG0?oonf[ooo]Z00Sooo]Z00?oo`0]oookJ_oonfX02?oonfX4
o`000003oookJ_ooP@3ooo]Z00oooo]Z00?o0=CooookJ_l01?l01ooonfX2o`2Yo`03o`28oooonf[o
oo]Z00Kooo]Z0_l0odh2o`3o;P?ooo]Z0ol0oc@^oookJQ3oiOl00_l0hOlZoookJP;o0?ld1OoonfX0
0ol0odkooo]ZoookJP0;oookJP;o08So00?ooo]Zo`2YoooonfX02?oonfX00ol01?oooo]ZoookJP02
oookJP03o`3Doooonf[ooo]Z06_ooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ooo5P3ooo]ZoonB0006
oookJP03ool0o?oonf[ooo]Z00Cooo]Z00Go603ooookJ_oonf[ooo]Zool60002oookJP06on_o0?oo
nf[ooo]Zool0m_oonf[o0:Ko0ooonfX00onX0?oooo]ZoookJP02oookJP03ool0nOoonf[o07Oo00;o
oo]Z00Co0?nJoom/0?oonf[ooh400_oonfX00olko`3ooo]ZoookJP02oookJP03o`3koooonf[ooo]Z
00?ooo]Z00_oo`<0oookJ_oonf[ooo]ZogT0oooonf[oo`3MoookJ_l05ooo0:?ook?o0006oookJP03
omgo0?oonf[oo`2700Cooo]Z00Koo`1/oookJ_oonf[ooo]Zodd0oooo;P02oookJP03of40oooonf[o
oo]Z00?ooo]Z00?ohP3oo`3oT?oonfX00_oonfX00ol0oi;ooo]ZoookJP08oookJP03ofP0oooonf[o
oo]Z00Gooo]Z00?o603oonKo0?oonfX00_oonfX00oooT03ooo]ZoookJP0>oookJP05oonn0?oonf[o
0?l5oookJ_o[0?l02OoonfX00oooE`3ooo]ZoookJP07oookJP03ool0;Ooonf[ooo]Z00Sooo]Z1?l0
00000ooonf[ooh40oookJP0?oookJP;o0=Co00?ooo]Zo`04oooonfX01OoonfX2o`2Yo`;o08So1ooo
nfX2o`3oCP;o0?l^1?oonfX2o`3o=3Cooo]Z3?l0hOl[oookJP03o`3o=?oonf[ooo]Z00?ooo]Z00?o
0?l^o`3oC_oonfX02ooonfX2o`28o`03oookJ_l0ZOoo0:Wo00Sooo]Z00?o00CooookJ_oonfX00ooo
nfX00ol0e?oooo]ZoookJP0aoookJP00??oonfX00ooo0>[ooo]ZoookJP09oookJP03oolF0?oonf[o
oi8000Kooo]Z00?oo`3loookJ_oonfX01OoonfX01?lH0?oooo]ZoookJ_oo1P02oookJP03oiCo0?oo
nf[oo`3f00;ooo]Z00Go0:KooookJ_oonf[ooo]ZoiCo0003oookJP0:ool0nOoonf[ooo]ZoiCo0?oo
nf[o0?nJoookJ_ooK03ooo]Zoon100;ooo]Z00?o>ol0oookJ_oonfX00_oonfX00ol0nooooo]Zoook
JP04oookJP0:ool30?oonf[ooo]ZoookJ_mi0?ooo`3MoookJ_l05ooo0:?ook?o00Oooo]Z00?o0?oN
ool0QooonfX00ooonfX01_oo06cooo]ZoookJ_m=0?oooo]Zool^00;ooo]Z00?oH@3ooookJ_oonfX0
0_oonfX01?oR0?oooo]ZoookJ_l0oi02oookJP03o`3oT_oonf[ooo]Z00Sooo]Z00CoJ03ooookJ_oo
nf[ooo]Z0ol0o``00olH0?oo0?l<onKo0002o`3o3003oon@0?oonf[ooo]Z00[ooo]Z1onDo`000ooo
nf[oj`3oog00o`08oookJP03oomG0?oonf[ooo]Z00Sooo]Z00?oo`0]oookJ_oonfX02OoonfX3o`00
00;ooh403ooonfX2o`3Do`;o00Co1_oonfX2o`2Yo`03o`28oooonf[ooo]Z00Kooo]Z0_l0odh00ol0
obkooo]ZoookJP02oookJP;o0?ld9?oonfX?onGo00Go0?lM0onDo`04onGo00Cooo]Z0ol0hOlYoook
JP;o0?ld1?oonfX2o`3oCPgooo]Z0_l0R?l2o`2Yo`Sooo]Z00Go00CooookJ_oonf[ooo]Zo`3Do`1/
oookJP03ool0j_oonf[ooo]Z00Wooo]Z00?ooaH0oookJ_ooTP001_oonfX00ooo0?cooo]ZoookJP05
oookJP04oaP0oooonf[ooo]Zool600;ooo]Z00Kojol0oookJ_oonf[oo`3foookJ_l0Y_l4oookJP07
ojP0oooonf[ooo]ZoookJ_oo0?Wooo]Zo`1go`02oookJP04o`3oV_ooK03ooo]Zoon100;ooo]Z00?o
>ol0oookJ_oonfX00_oonfX00ol0nooooo]ZoookJP04oookJP0;ool30?oonf[ooo]ZoookJ_mi0?oo
o`3MoookJ_l05ooo0:?ooookJ_nco`001_oonfX00ooMo`3o0?oNool0Q`04oookJP05ool0K?oonf[o
oo]Zodd0oooo;P000_oonfX00omQ0?oooo]ZoookJP03oookJP03on80oooonf[o0?n@00;ooo]Z00?o
0?nBoookJ_oonfX02?oonfX00omX0?oooo]ZoookJP05oookJP03oaP0oooVo`3ooo]Z00;ooo]Z00?o
oi00oookJ_oonfX03_oonfX01Ooo_P3ooo]Zo`3o1Ooonf[oj`3o00Wooo]Z00?ooeL0oookJ_oonfX0
1ooonfX00ooo02gooo]ZoookJP09oookJP?o00000_ooP@0@oookJP04o`3Doooonf[o00Coo`04o`Go
oo]Z0_l0ZOl2o`28o`Oooo]Z00?o0?l^o`3oC_l0obh01?oonfX3o`3o=2?ooo]Z4?l0hOl8o`3o7@Oo
oo]Z0ol0hOlYoookJP;o0?ld1?oonfX00ol0obko0?m>o`3oCP0<oookJP;o08So00?ooo]Zo`2Yoooo
nfX01ooonfX00ol01?oooo]ZoookJP02oookJP03o`3Doooonf[ooo]Z037ooo]Z000koookJP03ool0
j_oonf[ooo]Z00[ooo]Z00?ooaH0oookJ_ooTP001_oonfX00ooo0?cooo]ZoookJP04oookJP04oaP0
oooonf[ooo]Zool600?ooo]Z00GoU?l0oookJ_oo0?Kooo]Zo`2Vo`04oookJP07oiCo0?oonf[ooo]Z
oookJ_oo0?Wooo]ZoiCo0002oookJP07o`3oV_ooK03ooo]Zo`3oc?ooP@3ooo]Zoc_o0005oookJP03
o`3koooonf[ooo]Z00?ooo]Z00[oo`<0oookJ_oonf[ooo]ZogT0oooo0=gooo]Zo`0Gool0Xooo/ol0
1ooonfX00ol0omkooo]Zool0Q`03oookJP06ool0K?oonf[ooo]Zodd0oooonf[oobh00_oonfX00omQ
0?oooo]ZoookJP02oookJP04on80oooonf[ooo]Zo`3oT0?ooo]Z00?o0?nBoookJ_oonfX01ooonfX0
1?mX0?oooo]ZoookJ_oonfX3o`3o3006oaP0ool0o`co0?l<onKo0?l0o`cooi003?oonfX8oiCo0003
on/0oom`0?oooo]Z00Oooo]Z00?ooeL0oookJ_oonfX02?oonfX00ooo02gooo]ZoookJP0:oookJP;o
000000?ooh40o`000?oonfX03_oonfX00ol0e?oooo]Zo`04o`06oookJP03o`28ool0ZOoooo]Z00So
oo]Z00?o0?l^o`3oC_oonfX00ooonfX3o`3o=1_ooo]Z0_l0hOl9onGo00Kooo]Z2Ol0oad8onGo00Go
U?l01_oonfX4o`3Qo`Cooo]Z0_nDo`0QoookJP03o`3o=?oonf[ooo]Z00?ooo]Z00?o0?m>oookJ_oo
nfX03?oonfX2o`28o`03o`2Yoooonf[ooo]Z00Kooo]Z00Go00CooookJ_oonf[ooo]Zo`3Do`1Zoook
JP03ool0j_oonf[ooo]Z00[ooo]Z00?ooaH0oookJ_ooTP001_oonfX00ooo0?cooo]ZoookJP04oook
JP04oaP0oooonf[ooo]Zool600?ooo]Z00Gojol0oookJ_oonf[oo`3fo`2Vo`04oookJP07ojP0oooo
nf[ooo]ZoookJ_oo0?Wooo]Zo`1go`02oookJP07o`3oV_ooK03ooo]Zo`3oc?ooP@3ooo]Zoc_o0005
oookJP03o`3koooonf[ooo]Z00?ooo]Z00_oo`<0oookJ_oonf[ooo]ZogT0oooo0=gooo]Zo`0GoonO
0?oo0:?ook?o0006oookJP03omgo0?l0omkoo`2700Cooo]Z00Soo`1/oookJ_oonf[oC@3ooookJ_oo
;P3ooo]Zof40o`Gooo]Z00?ohP3ooookJ_l0oi000ooonfX00ol0oi;ooo]ZoookJP07oookJP03ofP0
oooonf[ooo]Z00Gooo]Z00?o603ooookJ_oVo`000_oonfX00oooT03ooo]ZoookJP0>oookJP05oonn
0?oonf[o0?l5oookJ_o[0?l02OoonfX00oooE`3ooo]ZoookJP07oookJP03ool0;Ooonf[ooo]Z00[o
oo]Z0_l000000oooP@3o0000oookJP0>oookJP;o0=Co00?ooo]Zo`04oooonfX01OoonfX00ol0ZOoo
08SooookJP07oookJP03o`3o;_l0odko0?m>00Cooo]Z0_l0oc@KoookJP_o0>7o1ooonfX9o`3o7@So
oo]Z1Ol0oad5oookJPCo0>7o9ooonfX2o`3o=0Cooo]Z00?o0?l^o`3oC_oonfX03?oonfX2o`28o`03
o`2Yoooonf[ooo]Z00Kooo]Z00?o00CooookJ_oonfX00_oonfX00ol0e?oooo]ZoookJP0`oookJP00
>_oonfX00ooo0>[ooo]ZoookJP0:oookJP03oolF0?oonf[ooi8000Kooo]Z00?oo`3loookJ_oonfX0
1OoonfX01?lH0?oooo]ZoookJ_oo1P02oookJP03oiCo0?oonf[oo`3f00;ooo]Z00Go0:KooookJ_oo
nf[ooo]ZoiCo0003oookJP0:ool0nOoonf[ooo]ZoiCo0?oonf[o0?nJoookJ_ooK03o0?o<oon100;o
oo]Z00?o>ol0oookJ_oonfX00_oonfX00ol0nooooo]ZoookJP04oookJP09ool30?oonf[ooo]ZogT0
oooonf[oo`3Mo`0Gool0Xooo/ol000Oooo]Z00?ogOl0o`3og_oo08L01?oonfX01Ooo06cooo]Zoook
J_m=0?ooobh000;ooo]Z00?oH@3oo`3oAOoonfX00ooonfX00ooR0?oooo]Zo`3oT003oookJP03o`3o
T_oonf[ooo]Z00Sooo]Z00?oJ03ooookJ_oonfX00ol0o``01?lH0?oo0?l<o`3o3?oVo`02o`3o3003
oon@0?oonf[ooo]Z00Wooo]Z2?nDo`000oo[0?ooL03ooookJP07oookJP03oomG0?oonf[ooo]Z00Oo
oo]Z0_oo02d=oookJP;ooh400_l0000=oookJP;o0=Co00?ooo]Zo`04oooonfX01OoonfX2o`2Yo`Wo
oo]Z0_l0odh3oookJP;o0?ld6ooonfX3o`3Qo`Sooo]Z2Ol0oad7o`3o20SoiOl01ooonfX4oiCo00Ko
oo]Z1?l0hOl4oiCo023ooo]Z0_l0oc@4oookJP03o`3oC_l0obkooo]Z00gooo]Z00?o08Soo`2Yoooo
nfX01ooonfX01Ol01?oooo]ZoookJ_oonf[o0=Co06Wooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ooo
5P3ooo]ZoonB0006oookJP03ool0o?oonf[ooo]Z00Gooo]Z00Co603ooookJ_oonf[oo`H00_oonfX0
1_o[o`3ooo]ZoookJ_oo0?Kooo]Zo`2Vo`?ooo]Z00?oZ03ooookJ_oonfX00_oonfX02Ooo0?Wooo]Z
o`1goooonf[o0?nJoookJ_ooK03ooo]Zoon10002oookJP03oc_o0?oonf[ooo]Z00;ooo]Z00?o0?_o
oookJ_oonfX01?oonfX02_oo0`3ooo]ZoookJ_mi0?oooo]Zool0gOl05ooooo]Zo`2Soonco`06oook
JP03omgo0?oonf[oo`2700Cooo]Z00Koo`1/oookJ_oonf[ooo]Zodd0oooo;P02oookJP03of40oooo
nf[ooo]Z00?ooo]Z00?ohP3oo`3oT?oonfX00_oonfX00ol0oi;ooo]ZoookJP08oookJP03ofP0oooo
nf[ooo]Z00Cooo]Z00?o603oo`1doooVo`000ooonfX00oooT03ooo]ZoookJP0=oookJP05oonn0?oo
nf[o0?l5oookJ_o[0?l02OoonfX00oooE`3ooo]ZoookJP06oookJP;oo`0]3OoonfX2oon100;o0000
3_oonfX01?l0e?oooo]Zo`04ool01?l5oookJP;o0:Wo2OoonfX2o`3oCP?ooo]Z0ol0oc@JoookJP?o
0>7o2?oonfX:o`3o7@go0?l82OoonfX4o`3o7@Gooo]Z1?l0hOlUoookJP03o`3o=?oonf[ooo]Z00;o
oo]Z00?o0?l^o`3oC_oonfX03OoonfX00ol0R?oo0:Woo`2Yo`07oookJP03o`04oooonf[ooo]Z00;o
oo]Z00?o0=CooookJ_oonfX0;ooonfX003[ooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ooo5P3ooo]Z
oonB0006oookJP03ool0o?oonf[ooo]Z00Cooo]Z00Co603ooookJ_oonf[oo`H00ooonfX01OnDo`3o
oo]Zool0m_oonf[o0:Ko00?ooo]Z00?oU?l0oookJ_oonfX00_oonfX02Ooo0?Wooo]ZoiCo0?oonf[o
0?nJoookJ_ooK03o0?o<oon10002oookJP03oc_o0?oonf[ooo]Z00;ooo]Z00?o0?_ooookJ_oonfX0
1?oonfX02_oo0`3ooo]ZoookJ_oonf[oN@3oool0gOoonf[o01Ooo`2Soonco`07oookJP03o`3og_oo
08Oooo]Z00?ooo]Z00Goo`1/oookJ_oonf[oC@3oool^0002oookJP03of40ool0odGooo]Z00?ooo]Z
00CohP3ooookJ_oonf[o0?n@0_oonfX00ol0oi;ooo]ZoookJP08oookJP03ofP0oooonf[ooo]Z00?o
oo]Z00Co603oo`3o3?l0o`coi_l00_l0o``00oooT03ooo]ZoookJP0<oookJPKoU?l000?oj`3ooook
J_oonfX01_oonfX00oooE`3ooo]ZoookJP07oookJP03ool0;Ooonf[ooo]Z00cooo]Z00?ooh40o`00
0?l000000_l0000<oookJP04o`3Doooonf[o00Coo`04o`Gooo]Z0_l0ZOl9oookJP;o0?m>0_oonfX3
o`3o=1[ooo]Z0ol0hOl2oookJPWo0?lM4?oonfX5onGo0003oookJ_l0o`So0?l800_o0?l81OnDo`00
0ol0o`Sooo]ZoookJP02oookJPKoU?l08?oonfX00ol0ocCooo]ZoookJP02oookJP;o0?m>3ooonfX2
o`2Yo`Oooo]Z00Go00CooookJ_oonf[ooo]Zo`3Do`1WoookJP03ool0j_oonf[ooo]Z00[ooo]Z00?o
oaH0oookJ_ooTP001_oonfX00ooo0?cooo]ZoookJP04oookJP04oaP0oooonf[ooo]Zool600?ooo]Z
00Gojol0oookJ_oonf[oo`3fo`2Vo`04oookJP07ojP0oooonf[ooo]ZoookJ_oo0?Wooo]Zo`1go`02
oookJP07o`3oV_ooK03ooo]Zo`3oc?ooP@3ooo]Zoc_o0004oookJP03o`3koooonf[ooo]Z00Cooo]Z
00_oo`<0oookJ_oonf[ooo]ZogT0oooo0=gooo]Zo`0Gool0Xooooo]Zok?o0006oookJP03omgo0?l0
omkoo`2700?ooo]Z00Koo`1/oookJ_oonf[ooo]Zodd0oooo;P02oookJP03of40oooonf[ooo]Z00?o
oo]Z00?ohP3ooookJ_l0oi000_oonfX00ol0oi;ooo]ZoookJP08oookJP03ofP0oooonf[ooo]Z00Co
oo]Z00?o603oo`1doooVo`000ooonfX00oooT03ooo]ZoookJP0>oookJP04oonn0?l0o`Gooo]Zon/0
o`Wooo]Z00?ooeL0oookJ_oonfX01_oonfX00ooo02gooo]ZoookJP0<oookJP03oon10?l0003o0000
00;o00003?oonfX2o`3Do`03oookJ_l01?oooo]Z00Cooo]Z0_l0ZOl00ol0R?oooo]ZoookJP06oook
JP;o0?m>0_oonfX3o`3o=1[ooo]Z0ol0hOl2oookJPWo0?lM00?o0?l8oookJ_oonfX05?oonfX=o`3o
20Co0?lM0_l0o`P3oookJP?o0>7o8ooonfX2o`3o=0Cooo]Z0_l0odh>oookJP03o`28ool0ZOoooo]Z
00Kooo]Z00?o00CooookJ_oonfX00_oonfX00ol0e?oooo]ZoookJP0^oookJP00>OoonfX00ooo0>[o
oo]ZoookJP0:oookJP03oolF0?oonf[ooi8000Kooo]Z00?oo`3loookJ_oonfX01OoonfX00olH0?oo
oo]Zool60003oookJP05oiCo0?oonf[oo`3foookJ_l0Y_l01?oonfX01OnDo`3ooo]ZoookJ_oonf[o
o`3i00;ooo]Z00OoU?l0oookJ_l0oi[oof`0oookJ_l0olcooh4000;ooo]Z00?o>ol0oookJ_oonfX0
0_oonfX00ol0nooooo]ZoookJP03oookJP0:ool30?oonf[ooo]ZoookJ_mi0?ooo`3MoookJ_l05ooo
0:?ook?o00Oooo]Z00?o0?oNoookJ_oo08L00ooonfX01_oo06cooo]ZoookJ_m=0?oooo]Zool^00;o
oo]Z00?oH@3ooookJ_oonfX00_oonfX01?oR0?oooo]ZoookJ_l0oi02oookJP03o`3oT_oonf[ooo]Z
00Sooo]Z00?oJ03ooookJ_oonfX01?oonfX00olH0?oo0?l<onKo0002o`3o3003oon@0?oonf[ooo]Z
00kooo]Z1?nDo`000oo[0?oooo]ZoookJP06oookJP03oomG0?oonf[ooo]Z00Oooo]Z00?oo`0]oook
J_oonfX03?oonfX00oooP@3ooo]Zo`000004o`0000Wooo]Z0_l0e?l00ooonf[o00CooookJP04oook
JP;o0:Wo2OoonfX2o`3oCP;ooo]Z0_l0oc@JoookJP;o0>7o1_l0oad00ooonf[o0?l8o`3o2002o`3o
20cooo]Z2?l0oe<2onGo01Kooo]Z1?nDo`000ooonf[oU?l0oiCo0006oiCo01oooo]Z0_l0oc@4oook
JP03o`3oC_oonf[ooo]Z00cooo]Z00?o08SooookJ_l0ZOl01ooonfX01Ol01?oooo]ZoookJ_oonf[o
0=Co06Kooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ooo5P3ooo]ZoonB0006oookJP03ool0o?oonf[o
oo]Z00Gooo]Z00Co603ooookJ_oonf[oo`H00_oonfX01Oo[o`3ooo]ZoookJ_oo0?Ko0:Ko00Cooo]Z
00?oZ03ooookJ_oonfX00_oonfX02Ooo0?Wooo]Zo`1goooonf[o0?nJoom/0?oonf[o0?o<oon10002
oookJP03oc_o0?oonf[ooo]Z00;ooo]Z00?o0?_ooookJ_oonfX00ooonfX02ooo0`3ooo]ZoookJ_oo
nf[oN@3oool0gOoonf[o01Ooo`2SoonO0?oo/ol000Kooo]Z00?ogOl0o`3og_oo08L01?oonfX01Ooo
06cooo]ZoookJ_m=0?ooobh000;ooo]Z00?oH@3ooookJ_oonfX00ooonfX00ooR0?oooo]Zo`3oT002
oookJP03o`3oT_oonf[ooo]Z00Sooo]Z00?oJ03ooookJ_oonfX01OoonfX00olH0?ooi_l0oookJP02
oookJP03oon@0?oonf[ooo]Z00kooo]Z00Gookh0o`3o1Ooonf[oj`3oog00o`08oookJP03oomG0?oo
nf[ooo]Z00Kooo]Z00?oo`0]oookJ_oonfX03?oonfX00oooP@3ooo]Zo`000004o`0000[ooo]Z00Co
0=CooookJ_l01?oo00Co1?oonfX2o`2Yo`03o`28oooonf[ooo]Z00Kooo]Z00Co0?l^o`3oC_oonf[o
oo]Z0_l0oc@JoookJP;o0>7o1_l0oad2oookJPCo0?l82ooonfX9o`3oDaOooo]Z1Ol0oad3oookJPCo
0>7o8OoonfX2o`3o=0?ooo]Z00?o0?l^o`3oC_oonfX03?oonfX01?l0R?oooo]Zo`2Yool0ZOl6oook
JP03o`04oooonf[ooo]Z00;ooo]Z00?o0=CooookJ_oonfX0;OoonfX003Wooo]Z00?oo`3ZoookJ_oo
nfX02_oonfX00ooo5P3ooo]ZoonB0005oookJP03ool0o?oonf[ooo]Z00Gooo]Z00Co603ooookJ_oo
nf[oo`H00ooonfX01OnDo`3ooo]Zool0m_oonf[o0:Ko00?ooo]Z00GoU?l0oookJ_oonf[ooo]Zool0
n@02oookJP07oiCo0?oonf[o0?nJoookJ_ooK03o0?o<oon10002oookJP03oc_o0?oonf[ooo]Z00;o
oo]Z00?o0?_ooookJ_oonfX01?oonfX01Ooo0`3ooo]ZoookJ_oonf[oo`3M00;ooo]Z00?o0:?ook?o
0?oonfX01_oonfX00ooMo`3o0?oNool0Q`03oookJP06ool0K?oonf[ooo]Zodd0oooonf[oobh00_oo
nfX00omQ0?oo0?m5oookJP03oookJP03on80oooonf[o0?n@00?ooo]Z00?o0?nBoookJ_oonfX01ooo
nfX00omX0?oooo]ZoookJP04oookJP07oaP0ool0o`coi_l0oookJ_l0o`cooi00o`3o300?oookJP05
oiCo0?oonf[oU?l0oiCo0?o[0?l02?oonfX00oooE`3ooo]ZoookJP07oookJP03ool0;Ooonf[ooo]Z
00_ooo]Z0_ooP@02oookJPCo00002OoonfX01?l0e?oooo]Zo`04ool01?l5oookJP03o`2Yool0R?oo
oo]Z00Oooo]Z0_l0odh01?oonf[o0?ldo`3o=?l0oc@IoookJP;o0>7o0ol0oad3oookJPCo0?l82ooo
nfX5o`3oD`Sooo]Z2Ol0oe<CoookJP_oU?l07ooonfX2o`3o=0?ooo]Z0_l0odh=oookJP03o`28oooo
nf[o0:Wo00Oooo]Z00Go00CooookJ_oonf[ooo]Zo`3Do`1ToookJP03ool0j_oonf[ooo]Z00[ooo]Z
00?ooaH0oookJ_ooTP001OoonfX00ooo0?cooo]ZoookJP05oookJP04oaP0oooonf[ooo]Zool600?o
oo]Z00Gojol0oookJ_oo0?Kooo]Zo`2Vo`04oookJP0@ojP0oooonf[ooo]ZoookJ_oo0?Wooo]Zo`1g
oooonf[o0?nJoookJ_ooK03ooo]Zo`3oc?ooP@3ooo]Zoc_o00Cooo]Z00?o0?_ooookJ_oonfX01?oo
nfX01Ooo0`3ooo]ZoookJ_oonf[oo`3M00;ooo]Z00?o01Ooo`2Soonco`001_oonfX00ooMo`3ooo]Z
ool0Q`04oookJP09ool0K?oonf[ooo]Zodd0oooonf[oobh0oookJ_mQ0?oo0?m500Gooo]Z00?ohP3o
o`3oT?oonfX00_oonfX00ol0oi;ooo]ZoookJP07oookJP03ofP0oooonf[ooo]Z00Gooo]Z00?o603o
onKo0?oonfX00_oonfX00oooT03ooo]ZoookJP0>oookJP05oonn0?oonf[o0?l5on/0oom`0?l02?oo
nfX00oooE`3ooo]ZoookJP06oookJP03ool0;Ooonf[ooo]Z00_ooo]Z0_ooP@02oookJPCo00002Ooo
nfX2o`3Do`03oookJ_l01?oooo]Z00Cooo]Z00?o0:Woo`28ool0R?l02?oonfX2o`3oCP?o0?ld6Ooo
nfX2o`3Qo`?o0?lM1?oonfX4o`3o20[ooo]Z1Ol0oe<9oookJPWo0?mC4ooonfX4o`3o7@?ooo]Z0ol0
hOlPoookJP06o`3o=?oonf[ooo]ZoookJ_l0obko0?m>3OoonfX01?l0R?oooo]ZoookJ_l0ZOl6oook
JP03o`04oooonf[ooo]Z00;ooo]Z00?o0=CooookJ_oonfX0;?oonfX003Sooo]Z00?oo`3ZoookJ_oo
nfX02_oonfX00ooo5P3ooo]ZoonB0006oookJP03ool0o?oonf[ooo]Z00Gooo]Z00?o603ooookJ_oo
1P000ooonfX01OnDo`3ooo]Zool0m_oonf[o0:Ko00Cooo]Z00GoU?l0oookJ_oonf[ooo]Zool0n@02
oookJP07oiCo0?l0oi[ooo]Zoom/0?l0olcooo]Zoon10002oookJP05oc_o0?oonf[ooo]ZoookJ_l0
nol01_oonfX02_oo0`3ooo]ZoookJ_oonf[oN@3oool0gOoonf[o0:?ooil0oonco`07oookJP03o`3o
g_oo08Oooo]Z00?ooo]Z00Goo`1/oookJ_m=0?oooo]Zool^0002oookJP03of40ool0odGooo]Z00?o
oo]Z00?ohP3ooookJ_l0oi000ooonfX00ol0oi;ooo]ZoookJP08oookJP03ofP0oooonf[ooo]Z00?o
oo]Z00?o603ooookJ_oVo`000ooonfX00oooT03ooo]ZoookJP0=oookJP05oiCo0?oonf[o0?l5oook
J_o[0?l02?oonfX00oooE`3ooo]ZoookJP06oookJP;oo`0]3OoonfX00oooP@3ooo]ZoookJP02oook
JPCo00001ooonfX2o`3Do`03oookJ_l01?oooo]Z00Cooo]Z0_l0ZOl9oookJP04o`3oC_l0obko0?ld
o`3o=1Wooo]Z0ol0hOl2o`3o7@;ooo]Z1?l0o`P:oookJPGo0?mC5_oonfX9o`3oD`[ooo]Z3OnDo`02
o`3Qoagooo]Z00?o0?ldoookJ_oonfX00_oonfX00ol0odkooo]ZoookJP0;oookJP04o`28oooonf[o
0:Woo`2Yo`Kooo]Z00Go00CooookJ_oonf[ooo]Zo`3Do`1SoookJP03ool0j_oonf[ooo]Z00Wooo]Z
00?ooaH0oookJ_ooTP001_oonfX00ooo0?cooo]ZoookJP05oookJP04oaP0oooonf[ooo]Zool600;o
oo]Z00Gojol0oookJ_oonf[oo`3fo`2Vo`04oookJP03ojP0oooonf[ooo]Z00;ooo]Z00Woo`3ioook
J_l0Mooo0?nJoookJ_ooK03ooo]Zo`3oc?ooP@000_oonfX01Olko`3ooo]ZoookJ_oonf[o0?_o00Ko
oo]Z00_oo`<0oookJ_oonf[ooo]ZogT0oooo0=gooo]Zo`0Gool0XoooW`3ook?o0006oookJP03omgo
0?l0omkoo`2700?ooo]Z00Koo`1/oookJ_oonf[oC@3ooookJ_oo;P02oookJP03of40oooonf[ooo]Z
00?ooo]Z00?ohP3oo`3oT?oonfX00_oonfX00ol0oi;ooo]ZoookJP08oookJP03ofP0oooonf[ooo]Z
00Cooo]Z00?o603oonKo0?oonfX00ooonfX00oooT03ooo]ZoookJP0=oookJP05oonn0?oonf[o0?l5
oookJ_o[0?l02?oonfX00oooE`3ooo]ZoookJP05oookJP;oo`0]3OoonfX00oooP@3ooo]ZoookJP02
oookJPCo00002?oonfX01?l0e?oooo]ZoookJ_l01?l4oookJP;o0:Wo00?o08SooookJ_oonfX01_oo
nfX2o`3oCP;o0?ld6OoonfX3o`3Qo`;o0?lM0_oonfX5o`3o20Wooo]Z1Ol0oe<GoookJPWo0?mC3Ooo
nfX00ol0o`So0?lMo`3o7@02o`3o7@;ooo]Z1?l0hOlMoookJP;o0?ld0ooonfX2o`3oCPcooo]Z00Co
08SooookJ_oonf[o0:Wo1_oonfX00ol01?oooo]ZoookJP02oookJP03o`3Doooonf[ooo]Z02_ooo]Z
000goookJP03ool0j_oonf[ooo]Z00_ooo]Z00?ooaH0oookJ_ooTP001OoonfX00ooo0?cooo]Zoook
JP05oookJP04oaP0oooonf[ooo]Zool600?ooo]Z00GoU?l0oookJ_oo0?Kooo]Zo`2Vo`03oookJP05
oiCo0?oonf[ooo]ZoookJ_oo0?T00_oonfX01onDo`3ooo]Zo`3oV_ooK03ooo]Zo`3oc?ooP@000_oo
nfX01Olko`3ooo]ZoookJ_oonf[o0?_o00Oooo]Z00Woo`<0oookJ_oonf[ooo]Zool0gOoonf[o01Oo
o`2Soonco`001ooonfX00ol0omkooo]Zool0Q`03oookJP05ool0K?oonf[ooo]Zodd0oooo;P000_oo
nfX00omQ0?oo0?m5oookJP04oookJP03on80oooonf[o0?n@00;ooo]Z00?o0?nBoookJ_oonfX02?oo
nfX00omX0?oooo]ZoookJP03oookJP03oaP0oooonf[oi_l000?ooo]Z00?ooi00oookJ_oonfX03Ooo
nfX01_nDo`3ooo]Zo`3o1Ooonf[oj`3oog00o`Oooo]Z00?ooeL0oookJ_oonfX01_oonfX00ooo02go
oo]ZoookJP0;oookJP;ooh401OoonfX4o`0000Kooo]Z00Co0=CooookJ_l01?oo00Co1?oonfX2o`2Y
o`03o`28oooonf[ooo]Z00Kooo]Z0_l0odh00ooonf[o0?ldoookJP0GoookJP?o0>7o0ol0oad4o`3o
20Sooo]Z1_l0oe<ToookJPWo0?mC00?ooo]ZoiCo0?nDo`003OnDo`04o`3Qoa[ooo]Z0_l0oc@3oook
JP03o`3oC_l0obkooo]Z00_ooo]Z00Co08SooookJ_oonf[o0:Wo1_oonfX01Ol01?oooo]ZoookJ_oo
nf[o0=Co067ooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ooo5P3ooo]ZoonB0005oookJP03ool0o?oo
nf[ooo]Z00Gooo]Z00Co603ooookJ_oonf[oo`H00ooonfX01Oo[o`3ooo]Zool0m_oonf[o0:Ko00?o
oo]Z00?oZ03ooookJ_oonfX00_oonfX03?oo0?Wooo]Zo`1goooonf[o0?nJoom/0?oonf[o0?o<oook
J_ooP@3ooo]Zoc_o00?ooo]Z00?o0?_ooookJ_oonfX01OoonfX01Ooo0`3ooo]ZoookJ_oonf[oo`3M
00;ooo]Z00?o0:?ooil0oonco`001_oonfX00ooMo`3o0?oNool0Q`03oookJP06ool0K?oonf[ooo]Z
oookJ_m=0?ooobh00_oonfX00omQ0?oooo]ZoookJP03oookJP03on80oooonf[o0?n@00;ooo]Z00?o
0?nBoookJ_oonfX02?oonfX00omX0?oooo]ZoookJP04oookJP03oaP0oooVo`3ooo]Z00?ooo]Z00?o
oi00oookJ_oonfX03OoonfX01Ooo_P3ooo]Zo`3o1Ooonf[oj`3o00Sooo]Z00?ooeL0oookJ_oonfX0
1OoonfX00ooo02gooo]ZoookJP0;oookJP;ooh401OoonfX4o`0000Kooo]Z0_l0e?l00ooonf[o00Co
o`04o`03oookJP;o0:Wo0_l0R?l7oookJP;o0?m>00?ooo]Zo`3o=?oonfX05ooonfX3o`3Qo`?o0?lM
1?l0o`P9oookJPGo0?mC9OoonfX9o`3oD`Oooo]Z0_l0o`P5o`3o7@03oookJ_l0hOoo0>7o00;o0>7o
6ooonfX2o`3o=0;ooo]Z00?o0?l^o`3oC_oonfX02ooonfX00ol0R?oooo]ZoookJP02o`2Yo`Gooo]Z
00?o00CooookJ_oonfX00_oonfX00ol0e?oooo]ZoookJP0ZoookJP00=ooonfX00ooo0>[ooo]Zoook
JP0;oookJP03oolF0?ooTP3ooo]Z00Gooo]Z00?oo`3loookJ_oonfX01OoonfX00olH0?oooo]Zool6
0003oookJP05oiCo0?oonf[oo`3foookJ_l0Y_l00ooonfX00onDo`3ooo]ZoookJP02oookJP0:ool0
nOoonf[oU?l0oookJ_l0oi[ooo]Zoom/0?l0olcooo]Zoon100;ooo]Z00Go>ol0oookJ_oonf[ooo]Z
o`3ko`06oookJP05ool30?oonf[ooo]ZoookJ_oo0=d00_oonfX00ol0Xooo/ol0oookJP07oookJP03
o`3og_oo08Oooo]Z00;ooo]Z00Goo`1/oookJ_oonf[oC@3oool^0003oookJP03of40ool0odGooo]Z
00?ooo]Z00?ohP3ooookJ_l0oi000ooonfX00ol0oi;ooo]ZoookJP07oookJP03ofP0oooonf[ooo]Z
00Cooo]Z00?o603oonKo0?oonfX00_oonfX00oooT03ooo]ZoookJP0=oookJP06oiCo0?oonf[o0?l5
oookJ_o[0?ooL03o1ooonfX00oooE`3ooo]ZoookJP06oookJP03ool0;Ooonf[ooo]Z00_ooo]Z00?o
oh40oookJ_oonfX01OoonfX4o`0000Cooo]Z0_l0e?l00ooonf[o00CooookJP03oookJP;o0:Wo00?o
08SooookJ_oonfX01_oonfX2o`3oCP03oookJ_l0ocCo0?ld01Kooo]Z0ol0hOl3o`3o7@?o0?l81ooo
nfX5o`3oDc?ooo]Z1Ol0oe<<oiCo0003o`3o7Ooonf[ooo]Z00?o0>7o6OoonfX01?l0ocCooo]Zoook
J_oonfX2o`3oCPcooo]Z00Co08SooookJ_oonf[o0:Wo1_oonfX01Ol01?oooo]ZoookJ_oonf[o0=Co
063ooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ooo5P3ooi80oookJP05oookJP03ool0o?oonf[ooo]Z
00Gooo]Z00?o603ooookJ_oo1P000ooonfX01Oo[o`3ooo]ZoookJ_oo0?Ko0:Ko00Cooo]Z00?oZ03o
oookJ_oonfX00_oonfX02Ooo0?Wo07OooookJ_l0oi[ooo]Zoom/0?oonf[o0?o<oon10002oookJP05
oc_o0?oonf[ooo]ZoookJ_l0nol01_oonfX01Ooo0`3ooo]ZoookJ_oonf[oo`3M00;ooo]Z00?o01Oo
o`2Soonco`001ooonfX00ooMo`3oo`27oookJP03oookJP05ool0K?oonf[ooo]Zodd0oooo;P000_oo
nfX00omQ0?oo0?m5oookJP04oookJP03on80ool0oi3ooo]Z00;ooo]Z00?o0?nBoookJ_oonfX01ooo
nfX00omX0?oooo]ZoookJP05oookJP03oaP0oooonf[ooo]Z00;ooo]Z00?ooi00oookJ_oonfX03Ooo
nfX01Ooo_P3ooo]Zo`3o1Ooonf[oj`3o00Sooo]Z00?ooeL0oookJ_oonfX01OoonfX00ooo02gooo]Z
oookJP0;oookJP03oon10?oonf[ooo]Z00Gooo]Z1?l00005oookJP04o`3Doooonf[ooo]Zo`04o`?o
oo]Z0_l0ZOl00ooonf[o08SooookJP06oookJP;o0?m>00?ooo]Zo`3o=?l0oc@05_oonfX3o`3Qo`?o
0?lM0ol0o`P8oookJPGo0?mC<ooonfX5o`3oD`Gooo]Z0ol0o`P01?oonf[o0?lMo`3o7Ol0oad2oook
JP?o0>7o6_oonfX01Ol0ocCooo]ZoookJ_oonf[o0?m>00cooo]Z00Go08SooookJ_oonf[ooo]Zo`2Y
o`05oookJP03o`04oooonf[ooo]Z00;ooo]Z00?o0=CooookJ_oonfX0:OoonfX003Kooo]Z00?oo`3Z
oookJ_oonfX02ooonfX00ooo5P3ooo]ZoonB0005oookJP03ool0o?oonf[ooo]Z00Gooo]Z00?o603o
oookJ_oo1P001?oonfX01OnDo`3ooo]Zool0m_oonf[o0:Ko00?ooo]Z00GoU?l0oookJ_oonf[ooo]Z
ool0n@02oookJP07oiCo0?oonf[o0?nJoom/0?l0olcooo]Zoon10002oookJP05oc_o0?oonf[ooo]Z
oookJ_l0nol01_oonfX00ooo0`3ooo]ZoookJP02oookJP05ool0gOoonf[o0:?ooookJ_nco`001ooo
nfX00ol0omkoo`27oookJP02oookJP06ool0K?oonf[ooo]Zodd0oooonf[oobh00_oonfX00omQ0?oo
0?m5oookJP03oookJP03on80oooonf[o0?n@00?ooo]Z00?o0?nBoookJ_oonfX01ooonfX00omX0?oo
oo]ZoookJP04oookJP03oaP0oooVo`3ooo]Z00;ooo]Z00?ooi00oookJ_oonfX03OoonfX01_nDo`3o
oo]Zo`3o1Ooonf[oj`3oog00o`Oooo]Z00?ooeL0oookJ_oonfX01_oonfX00ooo02gooo]ZoookJP0:
oookJP;ooh402?oonfX4o`0000?ooo]Z00Co0=CooookJ_oonf[o00Co0ooonfX2o`2Yo`;o08So1ooo
nfX2o`3oCP03o`3o;_oonf[o0?ld01Gooo]Z0ol0hOl00ooonf[o0?lMo`3o7@02o`3o20Kooo]Z1Ol0
oe<moookJP;o0?mC1_oonfX3o`3o20;ooo]Z00?o0?lMoookJ_oonfX00_oonfX3o`3QoaOooo]Z0_l0
oc@3oookJP03o`3oC_l0obkooo]Z00[ooo]Z00?o08SooookJ_oonfX00_l0ZOl4oookJP05o`04oooo
nf[ooo]ZoookJ_l0e?l0GooonfX00ooo0>[ooo]ZoookJP0:oookJP03oolF0?oonf[ooi8000Gooo]Z
00?oo`3loookJ_oonfX01OoonfX01?lH0?oooo]ZoookJ_oo1P03oookJP05on_o0?oonf[oo`3foook
J_l0Y_l00ooonfX00onX0?oooo]ZoookJP02oookJP09ool0nOoonf[o07OooookJ_l0oi[oof`0oook
J_l0olcooh4000;ooo]Z00Go>ol0oookJ_oonf[ooo]Zo`3ko`06oookJP03ool30?oonf[ooo]Z00;o
oo]Z00Koo`3MoookJ_l05ooo0:?ooil0oonco`06oookJP03omgo0?l0omkoo`2700?ooo]Z00Goo`1/
oookJ_oonf[oC@3oool^0002oookJP03of40ool0odGooo]Z00Cooo]Z00?ohP3oo`3oT?oonfX00_oo
nfX00ol0oi;ooo]ZoookJP07oookJP03ofP0oooonf[ooo]Z00Gooo]Z00?o603ooookJ_oonfX00_oo
nfX00oooT03ooo]ZoookJP0=oookJP05oonn0?oonf[o0?l5oookJ_o[0?l02?oonfX00oooE`3ooo]Z
oookJP05oookJP03ool0;Ooonf[ooo]Z00[ooo]Z0_ooP@08oookJPCo00000ooonfX2o`3Do`03oook
J_l01?oo00Co00;ooo]Z0_l0ZOl00ooonf[o08Soo`28o`07oookJP04o`3oC_l0obkooo]Zo`3o=1Go
oo]Z0ol0hOl00ooonf[o0?lMo`3o7@02o`3o20Oooo]Z1Ol0oe<moookJP;o0?mC1_oonfX2o`3o20;o
oo]Z00?o0?lMoookJ_oonfX00_oonfX3o`3QoaSooo]Z0_l0oc@2oookJP;o0?m>2ooonfX01Ol0R?oo
oo]ZoookJ_oonf[o0:Wo00Gooo]Z00Go00CooookJ_oonf[ooo]Zo`3Do`0[oookJP00=_oonfX00ooo
0>[ooo]ZoookJP0;oookJP03oolF0?ooTP3ooo]Z00Cooo]Z00?oo`3loookJ_oonfX01_oonfX00olH
0?oooo]Zool60003oookJP05oiCo0?oonf[oo`3foookJ_l0Y_l00ooonfX00onDo`3ooo]ZoookJP02
oookJP0<ool0nOoonf[oU?l0oookJ_l0oi[oof`0oookJ_l0olcooo]Zoon10?oonf[o>ol00ooonfX0
0ol0nooooo]ZoookJP05oookJP05ool30?oonf[ooo]ZoookJ_oo0=d00_oonfX00ol0Xooo/ol0oook
JP06oookJP03omgo0?l0omkoo`2700?ooo]Z00Goo`1/oookJ_m=0?oooo]Zool^0002oookJP03of40
oooonf[o0?m500Cooo]Z00?ohP3ooookJ_l0oi000_oonfX00ol0oi;ooo]ZoookJP08oookJP03ofP0
oooonf[ooo]Z00?ooo]Z00?o603oonKo0?oonfX00ooonfX00oooT03ooo]ZoookJP0<oookJP06oiCo
0?oonf[o0?l5oookJ_o[0?ooL03o1ooonfX00oooE`3ooo]ZoookJP06oookJP03ool0;Ooonf[ooo]Z
00[ooo]Z00?ooh40oookJ_oonfX02?oonfX4o`000004oookJ_l0e?oo0=CooookJP;o00Co0ooonfX0
0ol0ZOoooo]Zo`28o`07oookJP;o0?m>00Co0?l^oookJ_l0ocCo0?ld4ooonfX3o`3Qo`04o`3o2?l0
oago0?lMo`3o7@Gooo]Z1Ol0oe=4oookJP;o0?mC1ooonfX3o`3o20;o0?lM1OoonfX00ol0hOoooo]Z
oookJP0FoookJP;o0?ld0_oonfX00ol0odko0?l^oookJP0:oookJP05o`28oooonf[ooo]ZoookJ_l0
ZOl01?oonfX01Ol01?oooo]ZoookJ_oonf[o0=Co05gooo]Z00?oo`3ZoookJ_oonfX02ooonfX00ooo
5P3ooi80oookJP04oookJP03ool0o?oonf[ooo]Z00Kooo]Z00?o603ooookJ_oo1P000ooonfX01Oo[
o`3ooo]ZoookJ_oo0?Ko0:Ko00Cooo]Z013oZ03ooookJ_oonf[ooo]Zool0nOoonf[o07OooookJ_l0
oi[oof`0oookJ_l0olcooo]Zoon10?oonf[o>ol00ooonfX00ol0nooooo]ZoookJP05oookJP05ool3
0?oonf[ooo]ZoookJ_oo0=d00_oonfX00ol0XoooW`3ook?o0006oookJP03omgo0?oonf[oo`2700?o
oo]Z00Koo`1/oookJ_oonf[oC@3ooookJ_oo;P02oookJP03of40ool0odGooo]Z00?ooo]Z00?ohP3o
oookJ_l0oi000_oonfX00ol0oi;ooo]ZoookJP08oookJP03ofP0oooonf[ooo]Z00Cooo]Z00?o603o
oookJ_oonfX00ooonfX00oooT03ooo]ZoookJP0<oookJP05oonn0?oonf[o0?l5oookJ_o[0?l02?oo
nfX00oooE`3ooo]ZoookJP05oookJP03ool0;Ooonf[ooo]Z00[ooo]Z00?ooh40oookJ_oonfX02?oo
nfX4o`0000;ooo]Z00Co0=CooookJ_oonf[o00Co0ooonfX01?l0ZOoooo]ZoookJ_l0R?l7oookJP;o
0?m>00?ooo]Zo`3o=?l0oc@04ooonfX3o`3Qo`04o`3o2?l0oago0?lMo`3o7@Kooo]Z1Ol0oe=4oook
JP;o0?mC1_oonfX3o`3o20;o0?lM1OoonfX00ol0hOoooo]ZoookJP0GoookJP;o0?ld0_oonfX00ol0
odkooo]ZoookJP09oookJP04o`28oooonf[ooo]ZoookJP;o0:Wo1?oonfX01Ol01?oooo]ZoookJ_oo
nf[o0=Co02[ooo]Z000eoookJP03ool0j_oonf[ooo]Z00_ooo]Z00?ooaH0oookJ_ooTP001OoonfX0
0ooo0?cooo]ZoookJP05oookJP03oaP0oooonf[oo`H000Cooo]Z00GoU?l0oookJ_oo0?Kooo]Zo`2V
o`02oookJP03oiCo0?oonf[ooo]Z00;ooo]Z00[oo`3ioookJ_oonf[oU?l0oookJ_l0oi[oof`0o`3o
c?oonf[ooh400_oonfX01Olko`3ooo]ZoookJ_oonf[o0?_o00Kooo]Z00Goo`<0oookJ_oonf[ooo]Z
ool0g@02oookJP03o`2Soonco`3oW`3o00Oooo]Z00?o0?oNool0QooonfX00_oonfX01Ooo06cooo]Z
oookJ_m=0?ooobh000?ooo]Z00?oH@3oo`3oAOoonfX00ooonfX00ooR0?oooo]Zo`3oT003oookJP03
o`3oT_oonf[ooo]Z00Oooo]Z00?oJ03ooookJ_oonfX00ooonfX00olH0?ooi_l0o`3o3003oookJP03
oon@0?oonf[ooo]Z00gooo]Z00GoU?l0oookJ_l0o`Goj`3oog00o`07oookJP03oomG0?oonf[ooo]Z
00Oooo]Z00?oo`0]oookJ_oonfX02OoonfX00oooP@3ooo]ZoookJP09oookJPCo000000Co0=Cooook
J_oonf[o00Co0ooonfX2o`2Yo`;o08So1ooonfX00ol0odko0?l^oookJP02o`3o=1;ooo]Z0ol0hOl2
o`3o20;o0?lM0ooonfX3onGo00;o0?mCBooonfX2o`3oD`Sooo]Z0_l0o`P2o`3o7@Cooo]Z0_l0hOlH
oookJP03o`3o=?oonf[ooo]Z00;o0?m>2ooonfX01Ol0R?oooo]ZoookJ_oonf[o0:Wo00Cooo]Z00Go
00CooookJ_oonf[ooo]Zo`3Do`1LoookJP03ool0j_oonf[ooo]Z00[ooo]Z00?ooaH0oookJ_ooTP00
1OoonfX00ooo0?cooo]ZoookJP05oookJP04oaP0oooonf[ooo]Zool600?ooo]Z00Gojol0oookJ_oo
0?Kooo]Zo`2Vo`03oookJP03ojP0oooonf[ooo]Z00;ooo]Z00Woo`3ioookJ_l0Mooooo]Zo`3oV_oo
K03ooo]Zo`3oc?ooP@000_oonfX01Olko`3ooo]ZoookJ_oonf[o0?_o00Kooo]Z00Goo`<0oookJ_oo
nf[ooo]Zool0g@02oookJP03o`2Soooonf[o/ol000Oooo]Z00?ogOl0ool0QooonfX00_oonfX01_oo
06cooo]ZoookJ_oonf[oC@3oool^00;ooo]Z00?oH@3oo`3oAOoonfX01?oonfX00ooR0?oo0?n@oook
JP02oookJP03o`3oT_oonf[ooo]Z00Oooo]Z00?oJ03ooookJ_oonfX01?oonfX00olH0?oo07Cooook
JP03oookJP03oon@0?oonf[ooo]Z00gooo]Z00Cookh0oookJ_l0o`Goj`3o2?oonfX00oooE`3ooo]Z
oookJP06oookJP03ool0;Ooonf[ooo]Z00Wooo]Z00?ooh40oookJ_oonfX02OoonfX4o`0000;o0=Co
00?ooo]Zo`04ool01?l00_oonfX2o`2Yo`03oookJ_l0R?oo08So00Kooo]Z0_l0odh00ooonf[o0?ld
o`3o=00BoookJP?o0>7o0_l0o`P2o`3o7@Gooo]Z1?l0oe=;oookJP;o0?mC1ooonfX2o`3o20;o0?lM
1?oonfX2o`3QoaWooo]Z00Co0?ldoookJ_oonf[o0?m>2ooonfX00ol0R?oooo]ZoookJP02oookJP03
o`2Yoooonf[ooo]Z00;ooo]Z00Go00CooookJ_oonf[ooo]Zo`3Do`0YoookJP00=?oonfX00ooo0>[o
oo]ZoookJP0<oookJP03oolF0?oonf[ooi8000Cooo]Z00?oo`3loookJ_oonfX01_oonfX00olH0?oo
oo]Zool60003oookJP03oiCo0?oonf[oo`3f00;ooo]Z00Co0:KooookJ_oonf[oU?l01?oonfX01ooo
0?Wooo]ZoiCo0?oonf[o0?nJoom/0?l0ol`00_oonfX00oooP@3ooo]Zoc_o0003oookJP03o`3koooo
nf[ooo]Z00Gooo]Z00Woo`<0oookJ_oonf[oo`3MogT0oooonf[o0:?ook?o0?nO0?l01ooonfX00ol0
omkoo`27oookJP02oookJP05ool0K?oonf[ooo]Zodd0oooo;P000ooonfX00omQ0?oo0?m5oookJP03
oookJP03on80oooonf[o0?n@00?ooo]Z00?o0?nBoookJ_oonfX01ooonfX00omX0?oooo]ZoookJP03
oookJP03oaP0oooVo`3o0?l<00?ooo]Z00?ooi00oookJ_oonfX03OoonfX01OnDo`3ooo]Zo`3o1Oo[
0?ooL03o00Oooo]Z00?ooeL0oookJ_oonfX01ooonfX00ooo02gooo]ZoookJP09oookJP03oon10?oo
nf[ooo]Z00[ooo]Z0ol000001?l0e?oooo]Zo`04ool01?l2oookJP;o0:Wo00?ooo]Zo`28oooonfX0
1_oonfX2o`3oCP03o`3o;_oonf[o0?ld017ooo]Z0ol0hOl00ooonf[o0?l8o`3o7@02o`3o7@KoiOl0
DOoonfX2o`3oD`Wooo]Z00?o0?l8o`3o7Ol0o`P01?oonfX00ol0hOoooo]ZoookJP0FoookJP;o0?ld
0_oonfX00ol0odko0?l^oookJP09oookJP05o`28oooonf[ooo]ZoookJ_l0ZOl01?oonfX01Ol01?oo
oo]ZoookJ_oonf[o0=Co05[ooo]Z00?oo`3ZoookJ_oonfX02ooonfX00ooo5P3ooo]ZoonB0004oook
JP03ool0o?oonf[ooo]Z00Kooo]Z00?o603ooookJ_oo1P000ooonfX01_o[o`3ooo]ZoookJ_oo0?Ko
oo]Zo`2Vo`;ooo]Z00?oZ03ooookJ_oonfX00_oonfX03?oo0?Wooo]Zo`1goooonf[o0?nJoom/0?oo
nf[o0?o<oookJ_ooP@3ooo]Zoc_o00?ooo]Z00?o0?_ooookJ_oonfX01OoonfX01Ooo0`3ooo]Zoook
J_oo0=goN@3o00;ooo]Z00?o0:?ook?o0?oonfX01_oonfX00ooMo`3o0?oNool0Q`03oookJP05ool0
K?oonf[ooo]Zodd0oooo;P000_oonfX00omQ0?oo0?m5oookJP04oookJP03on80ool0oi3ooo]Z00;o
oo]Z00?o0?nBoookJ_oonfX01ooonfX00omX0?oooo]ZoookJP04oookJP03oaP0ool0M?oooo]Z00?o
oo]Z00?ooi00oookJ_oonfX03OoonfX01?oo_P3ooo]Zo`3o1Oo[0?l8oookJP03oomG0?oonf[ooo]Z
00Kooo]Z00?oo`0]oookJ_oonfX02OoonfX00oooP@3ooo]ZoookJP0:oookJP?o000000Co0=Cooook
J_oonf[o00Co0_oonfX2o`2Yo`;ooo]Z00?o08SooookJ_oonfX01?oonfX2o`3oCP03o`3o;_oonf[o
0?ld017ooo]Z0ol0hOl00ooonf[o0?l8o`3o7@02o`3o7@Gooo]Z0_l0oe=AoookJP;o0?mC2?oonfX0
0ol0o`So0?lMo`3o2004oookJP03o`3Qoooonf[ooo]Z01Oooo]Z0_l0oc@00ooonf[o0?m>o`3o;P0:
oookJP03o`28oooonf[ooo]Z00;ooo]Z00?o0:WooookJ_oonfX00_oonfX01Ol01?oooo]ZoookJ_oo
nf[o0=Co02Sooo]Z000doookJP03ool0j_oonf[ooo]Z00_ooo]Z00?ooaH0oookJ_ooTP001OoonfX0
0ooo0?cooo]ZoookJP05oookJP03oaP0oooonf[oo`H000Cooo]Z00GoU?l0ool0m_oonf[ooo]Zo`2V
o`02oookJP03oiCo0?oonf[ooo]Z00;ooo]Z00[oo`3ioookJ_oonf[oU?l0oookJ_ooK03ooo]Zo`3o
c?oonf[ooh400_oonfX01Olko`3ooo]ZoookJ_oonf[o0?_o00Kooo]Z00Goo`<0oookJ_oonf[ooo]Z
ool0g@02oookJP03o`2Soonco`3ooo]Z00Oooo]Z00?oo`27oookJ_oonfX00_oonfX01?oo06cooo]Z
odd0oooo;P03oookJP03of40oooonf[o0?m500Cooo]Z00?ohP3ooookJ_l0oi000_oonfX00ol0oi;o
oo]ZoookJP07oookJP03ofP0oooonf[ooo]Z00Cooo]Z00?o603oo`3o3?oonfX00_oonfX00oooT03o
oo]ZoookJP0=oookJP05oiCo0?oonf[o0?l5oookJ_o[0?l01ooonfX00oooE`3ooo]ZoookJP07oook
JP03ool0;Ooonf[ooo]Z00Wooo]Z00?ooh40oookJ_oonfX02ooonfX01Ol0003o0=Coo`3Dool0003o
00Co00?ooo]Z00Co0:WooookJ_l0R?oo08So1_oonfX2o`3oCP04o`3o;_oonf[o0?ldo`3o=0oooo]Z
0ol0hOl2oookJP03o`3o2?oUo`3oiOl000SoiOl08ooonfXDool0NAgooo]Z0_l0oe<9oookJP;o0?lM
0_l0o`P2oookJP03o`3Qoooonf[ooo]Z01Oooo]Z0_l0oc@00ooonf[o0?m>o`3o;P09oookJP03o`28
oooonf[ooo]Z00;ooo]Z0_l0ZOl3oookJP05o`04oooonf[ooo]ZoookJ_l0e?l0FOoonfX00ooo0>[o
oo]ZoookJP0:oookJP03oolF0?oonf[ooi8000Gooo]Z00?oo`3loookJ_oonfX01OoonfX01?lH0?oo
oo]ZoookJ_oo1P03oookJP05on_o0?oonf[oo`3foookJ_l0Y_l00ooonfX00onX0?oooo]ZoookJP02
oookJP05ool0nOoonf[o07OooookJ_ooK0000_oonfX01Ol0olcooh40oookJ_oonf[o>ol000?ooo]Z
00?o0?_ooookJ_oonfX01?oonfX01Ooo0`3ooo]ZoookJ_oonf[oo`3M00;ooo]Z00?o0:?ooookJ_nc
o`001ooonfX00ooMo`3oo`27oookJP02oookJP05ool0K?oonf[ooo]Zodd0oooo;P000ooonfX00omQ
0?oo0?m5oookJP04oookJP05on80ool0oi3ooo]ZoookJ_l0oi802OoonfX00omX0?oooo]ZoookJP04
oookJP03onKo0?lH0?oooo]Z00?ooo]Z00?ooi00oookJ_oonfX03OoonfX01Ooo_P3ooo]Zo`3o1Oo[
0?ooL03o00Oooo]Z00?ooeL0oookJ_oonfX01_oonfX00ooo02gooo]ZoookJP09oookJP03oon10?oo
nf[ooo]Z00_ooo]Z00Co0000o`3Dool0e?oo00000_l01?l2oookJP03o`2Yoooonf[ooo]Z00;o08So
1_oonfX00ol0odko0?l^oookJP02o`3o=0oooo]Z0ol0hOl2oookJP03o`3o2?l0oago0?lM00Kooo]Z
0_l0oe<ToookJQCoo`1i7OoonfX2o`3oD`Sooo]Z0_l0oad2o`3o20;ooo]Z0_l0hOlIoookJP;o0?ld
0_l0odh:oookJP03o`28oooonf[ooo]Z00;ooo]Z0_l0ZOl3oookJP05o`04oooonf[ooo]ZoookJ_l0
e?l09ooonfX003?ooo]Z00?oo`3ZoookJ_oonfX03?oonfX00ooo5P3ooo]ZoonB0004oookJP03ool0
o?oonf[ooo]Z00Kooo]Z00?o603ooookJ_oo1P000ooonfX00onDo`3ooo]Zool0mP02oookJP04o`2V
oooonf[ooo]ZoiCo00Cooo]Z00Woo`3ioookJ_nDo`3ooo]Zo`3oV_ooK03o0?o<oookJ_ooP@000_oo
nfX01Olko`3ooo]ZoookJ_oonf[o0?_o00Oooo]Z00Woo`<0oookJ_oonf[oo`3MogT0oooonf[o0:?o
ok?o0?nO0?l01ooonfX00ol0omkoo`27oookJP02oookJP05ool0K?oonf[oC@3ooookJ_oo;P000_oo
nfX00omQ0?oooo]Zo`3oA@04oookJP03on80oooonf[o0?n@00?ooo]Z00?o0?nBoookJ_oonfX01ooo
nfX00omX0?oooo]ZoookJP03oookJP03oaP0oooVo`3ooo]Z00?ooo]Z00?ooi00oookJ_oonfX03?oo
nfX01OnDo`3ooo]Zo`3o1Ooonf[oj`3o00Oooo]Z00?ooeL0oookJ_oonfX01ooonfX00ooo02gooo]Z
oookJP09oookJP03oon10?oonf[ooo]Z00cooo]Z00Co0=Coo`000?l0003o00Co0ooonfX00ol0ZOoo
oo]Zo`28o`06oookJP;o0?m>00Co0?l^oookJ_oonf[o0?ld3ooonfX2o`3Qo`?ooo]Z3?oUo`0;oook
JPSoU?l04Ooo07T3oookJPWo0:go2?oonfX4ool0NA_ooo]Z0_l0oe<9oookJP03o`3o7Ooonf[o0?l8
00;o0?l80_l0hOlIoookJP05o`3o=?oonf[o0?m>o`3oC_l0obh02?oonfX00ol0R?oooo]ZoookJP03
oookJP05o`2Yoooonf[ooo]ZoookJ_l01?l00ooonfX00ol0e?oooo]ZoookJP1EoookJP03ool0j_oo
nf[ooo]Z00_ooo]Z00?ooaH0oookJ_ooTP001?oonfX00ooo0?cooo]ZoookJP06oookJP03oaP0oooo
nf[oo`H000?ooo]Z00Kojol0oookJ_oonf[oo`3foookJ_l0Y_l2oookJP03ojP0oooonf[ooo]Z00;o
oo]Z00coo`3ioookJ_l0Mooooo]Zo`3oV_ooK03ooo]Zo`3oc?oonf[ooh40oookJ_lko`03oookJP03
o`3koooonf[ooo]Z00Gooo]Z00Woo`<0oookJ_oonf[oo`3MogT0oooonf[o0:?oo`0Goonco`001ooo
nfX00ooMo`3oo`27oookJP02oookJP06ool0K?oonf[ooo]Zodd0oooonf[oobh00_oonfX00omQ0?oo
0?m5oookJP04oookJP03on80ool0oi3ooo]Z00;ooo]Z00?o0?nBoookJ_oonfX01ooonfX00omX0?oo
oo]ZoookJP04oookJP03oaP0oooonf[ooo]Z00?ooo]Z00?ooi00oookJ_oonfX03?oonfX01Ooo_P3o
oo]Zo`3o1Oo[0?ooL03o00Oooo]Z00?ooeL0oookJ_oonfX01_oonfX00ooo02gooo]ZoookJP09oook
JP03oon10?oonf[ooo]Z00cooo]Z00Co0=Coo`000?l0003o00Co0ooonfX01?l0ZOoooo]ZoookJ_l0
R?l6oookJP;o0?m>0_oonfX00ol0ocCooo]ZoookJP0=oookJP;o0>7o0ooonfX3o`3o7@Gooo]Z0ol0
oe<BoookJQCoo`1i0ooonfX9o`2]o`Sooo]Z1?oo07TKoookJP;o0?mC2?oonfX2o`3o7@?o0?l800?o
oo]Zo`3QoooonfX06OoonfX01?l0ocCooo]Zo`3oC_l0obh9oookJP03o`28oooonf[ooo]Z00?ooo]Z
00Go0:WooookJ_oonf[ooo]Zo`04o`03oookJP03o`3Doooonf[ooo]Z02Cooo]Z000coookJP03ool0
j_oonf[ooo]Z00_ooo]Z00?ooaH0oookJ_ooTP001?oonfX00ooo0?cooo]ZoookJP06oookJP03oaP0
oooonf[oo`H000Cooo]Z00GoU?l0ool0m_oonf[ooo]Zo`2Vo`02oookJP03oiCo0?oonf[ooo]Z00;o
oo]Z00?oo`3ioookJ_nDo`000_oonfX01OooK03o0?o<oookJ_oonf[ooh4000;ooo]Z00Go>ol0oook
J_oonf[ooo]Zo`3ko`06oookJP09ool30?oonf[ooo]Zool0gOmi0?oooo]Zo`2Soonco`3oW`3o00Oo
oo]Z00?o0?oNool0QooonfX00_oonfX01Ooo06cooo]Zodd0oooonf[oobh000?ooo]Z00?oH@3oo`3o
AOoonfX00ooonfX00ooR0?oooo]Zo`3oT003oookJP03o`3oT_oonf[ooo]Z00Oooo]Z00?oJ03ooook
J_oonfX00ooonfX00olH0?ooi_l0o`3o3003oookJP03oon@0?oonf[ooo]Z00cooo]Z00GoU?l0oook
J_l0o`Gooo]Zon/0o`07oookJP03oomG0?oonf[ooo]Z00Oooo]Z00?oo`0]oookJ_oonfX02OoonfX0
0oooP@3ooo]ZoookJP0;oookJP;o0=Co00Co0000o`04ool01?oo00000_oonfX00ol0ZOoooo]Zo`28
o`05oookJP;o0?m>0_l0obh00ooonf[o0?ldo`3o=00?oookJP03o`3Qoooonf[ooo]Z00?o0?lM2_oU
o`05oookJPkoU?l00_oonfX9onGo00_o0:go2OoonfX5o`2]o`Oooo]Z0ooo07TJoookJP;o0?mC2?oo
nfX2o`3o7@;ooo]Z0_l0o`P00ol0hOoooo]ZoookJP0GoookJP05o`3o=?oonf[ooo]Zo`3oC_l0obh0
2?oonfX00ol0R?oooo]ZoookJP03oookJP05o`2Yoooonf[ooo]ZoookJ_l01?l00ooonfX00ol0e?oo
oo]ZoookJP1DoookJP03ool0j_oonf[ooo]Z00[ooo]Z00?ooaH0oookJ_ooTP001?oonfX00ooo0?co
oo]ZoookJP06oookJP04oaP0oooonf[ooo]Zool600?ooo]Z00Gojol0oookJ_oo0?Kooo]Zo`2Vo`03
oookJP03ojP0oooonf[ooo]Z00;ooo]Z00Woo`3io`1goooonf[ooo]Zoom/0?oonf[o0?o<oookJ_oo
P@000_oonfX01Olko`3ooo]ZoookJ_oonf[o0?_o00Kooo]Z00Goo`<0oookJ_oonf[oo`3MogT0o`02
oookJP03o`2Soonco`3ooo]Z00Kooo]Z00?ogOl0o`3og_oo08L00_oonfX01_oo06cooo]ZoookJ_m=
0?oooo]Zool^00;ooo]Z00?oH@3oo`3oAOoonfX01?oonfX00ooR0?oo0?n@oookJP02oookJP03o`3o
T_oonf[ooo]Z00Oooo]Z00?oJ03ooookJ_oonfX01?oonfX00olH0?oo07CooookJP03oookJP03oon@
0?oonf[ooo]Z00cooo]Z00Gookh0oookJ_l0o`Goj`3oog00o`07oookJP03oomG0?oonf[ooo]Z00Ko
oo]Z00?oo`0]oookJ_oonfX02OoonfX00oooP@3ooo]ZoookJP0;oookJP;o0=Co00Co0000o`04ool0
1?oo00000_oonfX01?l0ZOoooo]ZoookJ_l0R?l5oookJP;o0?m>00Co0?l^oookJ_l0ocCo0?ld3ooo
nfX00ol0hOoooo]ZoookJP03o`3o7@Kooo]Z0_l0oe<BoookJP?oo`1i2ooonfX<o`2]o`Wooo]Z1Ol0
[Ol7oookJP?oo`1i6_oonfX2o`3oD`Sooo]Z00?o0?lMoookJ_oonfX00_l0o`P00ol0hOoooo]Zoook
JP0HoookJP04o`3o=?oonf[o0?m>o`3o;PWooo]Z00?o08SooookJ_oonfX00ooonfX01Ol0ZOoooo]Z
oookJ_oonf[o00Co00?ooo]Z00?o0=CooookJ_oonfX08ooonfX003;ooo]Z00?oo`3ZoookJ_oonfX0
3?oonfX00ooo5P3ooo]ZoonB0004oookJP03ool0o?oonf[ooo]Z00Kooo]Z00?o603oool60?oonfX0
0ooonfX00onDo`3ooo]Zool0mP02oookJP03o`2Voooonf[oU?l000Cooo]Z00[oo`3ioookJ_oonf[o
U?l0oookJ_l0oi[oof`0o`3oc?oonf[ooh400_oonfX01Olko`3ooo]ZoookJ_oonf[o0?_o00Kooo]Z
00[oo`<0oookJ_oonf[ooo]Zool0gOmi0?oooo]Zo`2Soonco`3oW`3o1ooonfX01Ooo08Oooo]Zoook
J_oonf[oo`1/00;ooo]Z00?oC@3ooookJ_oo;P000_oonfX00omQ0?oooo]Zo`3oA@04oookJP03on80
oooonf[o0?n@00;ooo]Z00?o0?nBoookJ_oonfX01ooonfX00omX0?oooo]ZoookJP03oookJP03oaP0
oooVo`3o0?l<00?ooo]Z00?ooi00oookJ_oonfX03?oonfX01OnDo`3ooo]Zo`3o1Ooonf[oj`3o00Oo
oo]Z00?ooeL0oookJ_oonfX01ooonfX00ooo02gooo]ZoookJP09oookJP03oon10?oonf[ooo]Z00_o
oo]Z00Co0=CooookJ_oonf[o00Co0ol000001?oonf[o0:Woo`28ool0R?l5oookJP03o`3oC_l0obko
0?l^00;ooo]Z00?o0?ldoookJ_oonfX03OoonfX2o`3Qo`04oookJ_l0oago0?lMo`3o20?ooo]Z2?oU
o`06oookJPgoU?l000?ooo]Zo`2]ool0[Ol04OoUo`04ool0D@gooo]Z1Ol0[Ol5oookJPCoo`1i6?oo
nfX3o`3oD`Oooo]Z0_l0oad2oookJP03o`3o2?l0hOoo0>7o01Oooo]Z00Co0?ldoookJ_oonf[ooo]Z
0_l0odh8oookJP03o`28oooonf[ooo]Z00?ooo]Z00Go0:WooookJ_oonf[ooo]Zo`04o`03oookJP03
o`3Doooonf[ooo]Z05;ooo]Z00?oo`3ZoookJ_oonfX02ooonfX00ooo5P3ooo]ZoonB0004oookJP03
ool0o?oonf[ooo]Z00Kooo]Z00?o603ooookJ_oo1P000ooonfX00oo[o`3ooo]Zool0mP02oookJP04
o`2Voooonf[ooo]ZojP0o`Cooo]Z00coo`3ioookJ_l0Mooooo]Zo`3oV_ooK03ooo]Zo`3oc?oonf[o
oh40oookJ_lko`03oookJP03o`3koooonf[ooo]Z00Cooo]Z00[oo`<0oookJ_oonf[ooo]Zool0gOmi
0?oooo]Zo`2Sool05ooo/ol01ooonfX00ooMo`3oo`27oookJP02oookJP0:ool0K?oonf[ooo]Zodd0
oooonf[oobh0oookJ_mQ0?oooo]Zo`3oA@Gooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP09oookJP03
ofP0oooonf[ooo]Z00Cooo]Z00?o603oo`1doooonfX00ooonfX00oooT03ooo]ZoookJP0<oookJP05
oonn0?oonf[o0?l5on/0oom`0?l01ooonfX00oooE`3ooo]ZoookJP06oookJP03ool0;Ooonf[ooo]Z
00Wooo]Z00?ooh40oookJ_oonfX02ooonfX01?l0e?oooo]ZoookJ_l01?l3o`000003oookJ_l0ZOoo
oo]Z00;o08So1?oonfX2o`3oCP04o`3o;_oonf[ooo]Zo`3o=0oooo]Z0_l0hOl01?oonf[o0?lMo`3o
7Ol0o`P6oookJP;o0?mC4OoonfX3ool0N@?ooo]Z2ol0[Ol4oookJPSoo`1A3_oonfX5o`2]o`Gooo]Z
1?oo07THoookJP?o0?mC1_oonfX2o`3o7@;ooo]Z00?o0?l8o`3Qool0hOl06?oonfX00ol0ocCooo]Z
oookJP02o`3oCPWooo]Z00?o08SooookJ_oonfX00ooonfX01Ol0ZOoooo]ZoookJ_oonf[o00Co00?o
oo]Z00?o0=CooookJ_oonfX08_oonfX003;ooo]Z00?oo`3ZoookJ_oonfX02ooonfX00ooo5P3ooo]Z
oonB0004oookJP03ool0o?oonf[ooo]Z00Kooo]Z00?o603ooookJ_oo1P001?oonfX01OnDo`3oo`3f
oookJ_oonf[o0:Ko00;ooo]Z00?oU?l0oookJ_oonfX00_oonfX00ooo0?Wooo]ZoiCo0002oookJP07
oom/0?l0olcooo]ZoookJ_ooP@3ooo]Zoc_o0004oookJP03o`3koooonf[ooo]Z00Cooo]Z00Woo`<0
oookJ_oonf[oo`3MogT0oooonf[o0:?ook?o0?nO0?l01ooonfX00ol0omkoo`27oookJP02oookJP05
ool0K?oonf[oC@3ooookJ_oo;P000_oonfX00omQ0?oooo]Zo`3oA@04oookJP03on80oooonf[o0?n@
00;ooo]Z00?o0?nBoookJ_oonfX02?oonfX00omX0?oooo]ZoookJP03oookJP03oaP0oooVo`3ooo]Z
00;ooo]Z00?ooi00oookJ_oonfX03?oonfX01_nDo`3ooo]ZoookJ_l0o`Goj`3oog00o`Kooo]Z00?o
oeL0oookJ_oonfX01ooonfX00ooo02gooo]ZoookJP09oookJP03oon10?oonf[ooo]Z00[ooo]Z0_l0
e?l00ooonf[o00Coo`04o`03o`0000;o0:Wo00?o08SooookJ_oonfX00ooonfX2o`3oCP03o`3o;_oo
nf[ooo]Z00;o0?ld3_oonfX2o`3Qo`?o0?lM00?o0?l8oookJ_oonfX00ooonfX7onGo00Oooo]Z2onD
o`03o`2]o`;ooo]Z3ooUo`06oookJPSoo`1A2_oonfX5o`2]o`Cooo]Z1?oo07TGoookJP;o0?mC1ooo
nfX01_l0oagooo]ZoookJ_l0o`Sooo]Zo`3QoaOooo]Z00?o0?ldoookJ_oonfX00_oonfX00ol0odko
0?l^oookJP06oookJP03o`28oooonf[ooo]Z00;ooo]Z00?o0:WooookJ_oonfX00_oonfX00ol01?oo
oo]ZoookJP1EoookJP03ool0j_oonf[ooo]Z00[ooo]Z00?ooaH0oookJ_ooTP001?oonfX00ooo0?co
oo]ZoookJP06oookJP03oaP0oooonf[oo`H000Cooo]Z00Gojol0oookJ_oo0?Kooo]Zo`2Vo`02oook
JP03ojP0oooonf[ooo]Z00;ooo]Z00?oo`3ioookJ_l0Mol00_oonfX01oooK03ooo]Zo`3oc?oonf[o
oh40oookJ_lko`001?oonfX00ol0nooooo]ZoookJP04oookJP09ool30?oonf[ooo]Zool0gOmi0?oo
oo]Zo`2Sool05ooo/ol000Oooo]Z00?ogOl0ool0QooonfX00_oonfX01_oo06cooo]ZoookJ_m=0?oo
oo]Zool^00;ooo]Z00?oH@3oo`3oAOoonfX01?oonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00[ooo]Z
00?oJ03ooookJ_oonfX01?oonfX00olH0?oooo]ZoookJP02oookJP03oon@0?oonf[ooo]Z00cooo]Z
00Gookh0oookJ_oonf[oj`3oog00o`07oookJP03oomG0?oonf[ooo]Z00Kooo]Z00?oo`0]oookJ_oo
nfX02OoonfX00oooP@3ooo]ZoookJP0:oookJP;o0=Co00?ooo]Zo`04ool01?l00ol00002o`2Yo`03
oookJ_l0R?oooo]Z00Cooo]Z00Co0?m>o`3o;_oonf[ooo]Z0_l0oc@>oookJP;o0>7o0ol0oad00ol0
o`Sooo]ZoookJP04oookJP;o0?mC4?oonfX3ool0N@Ko0:go2OoonfX6ool0D@Sooo]Z2Ooo054:oook
JPGo0:go1?oonfX4ool0NAOooo]Z0_l0oe<6oookJP;o0?lM00Cooo]Zo`3o2?oonf[o0>7o6?oonfX0
1_l0ocCooo]ZoookJ_oonf[o0?m>o`3o;PSooo]Z00?o08SooookJ_oonfX00_oonfX00ol0ZOoooo]Z
oookJP02oookJP03o`04oooonf[ooo]Z02Gooo]Z000boookJP03ool0j_oonf[ooo]Z00_ooo]Z00?o
oaH0oookJ_ooTP001?oonfX00ooo0?cooo]ZoookJP06oookJP03oaP0oooo1P3ooo]Z00?ooo]Z00?o
U?l0oookJ_oo0?H00_oonfX00ol0Y_oooo]ZoiCo0004oookJP07ool0nOoonf[ooo]ZoiCo0?oonf[o
of`0o`3oc002oookJP04oon10?oonf[ooo]Zoc_o00?ooo]Z00?o0?_ooookJ_oonfX01?oonfX02Ooo
0`3ooo]ZoookJ_oo0=gooo]ZogT0ool0Xooo/ol0oil0o`07oookJP03o`3og_oo08Oooo]Z00;ooo]Z
00Goo`1/oookJ_oonf[oC@3oool^0002oookJP03of40oooonf[o0?m500Gooo]Z00?ohP3oo`3oT?oo
nfX00_oonfX00ol0oi;ooo]ZoookJP07oookJP03ofP0oooonf[ooo]Z00?ooo]Z00?o603oonKo0?oo
nfX00ooonfX00oooT03ooo]ZoookJP0;oookJP06oiCo0?oonf[ooo]Zo`3o1Oo[0?ooL03o1_oonfX0
0oooE`3ooo]ZoookJP07oookJP03ool0;Ooonf[ooo]Z00Wooo]Z00?ooh40oookJ_oonfX02_oonfX0
1?l0e?oooo]ZoookJ_l01?l2oookJP;o000000?o0:Woo`28ool0R?l01?oonfX2o`3oCP;o0?l^00?o
oo]Zo`3o=?l0oc@03_oonfX2o`3Qo`;o0?lM0_l0o`P5oookJP;oiOl000?ooo]ZonGo0?oUo`000_oU
o`0:oookJP?oU?l03Ooob@0;onGo017o5@3o2Ooo05400olE0?oooo]ZoookJP03oookJPGo0:go0ooo
nfX4ool0NAGooo]Z0_l0oe<6oookJP;o0?lM00Cooo]Zo`3o2?oonf[o0>7o5ooonfX00ol0ocCooo]Z
oookJP02oookJP03o`3oC_l0obkooo]Z00Kooo]Z00?o08SooookJ_oonfX00_oonfX00ol0ZOoooo]Z
oookJP02oookJP03o`04oooonf[ooo]Z05Cooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ooo5P3ooo]Z
oonB0004oookJP03ool0o?oonf[ooo]Z00Kooo]Z00?o603ooookJ_oo1P000ooonfX00oo[o`3ooo]Z
ool0mP02oookJP04o`2Voooonf[ooo]ZojP0o`Cooo]Z00Ooo`3ioookJ_l0Mooooo]Zoom/0?oonf[o
0?o<00;ooo]Z00?ooh40oookJ_lko`000ooonfX00ol0nooooo]ZoookJP04oookJP0:ool30?oonf[o
oo]Zool0gOoonf[oN@3ooookJ_l0Xooo/ol0oil0o`Oooo]Z00Go0?oNool0Qooonf[ooo]Zool0K003
oookJP06odd0oooo;P3ooo]ZoookJ_mQ0?oo0?m51OoonfX00ooR0?oo0?n@oookJP02oookJP03o`3o
T_oonf[ooo]Z00Oooo]Z00?oJ03ooookJ_oonfX01?oonfX00olH0?oooo]ZoookJP03oookJP03oon@
0?oonf[ooo]Z00_ooo]Z00Gookh0oookJ_oonf[oj`3oog00o`07oookJP03oomG0?oonf[ooo]Z00Ko
oo]Z00?oo`0]oookJ_oonfX02OoonfX00oooP@3ooo]ZoookJP0:oookJP04o`3Doooonf[ooo]Zo`04
o`;ooo]Z0_l000001?l0ZOoo0000o`28ool0R?l4oookJP;o0?m>00Co0?l^oookJ_l0ocCo0?ld3_oo
nfX2o`3Qo`;o0?lM0_l0o`P6oookJP;o0?mC3ooonfX3ool0N@;o0:go2ooonfX5ool0DAOo5@3o2?oo
0542oaD0o`Gooo]Z1?l0[Ol4oookJP?oo`1i5_oonfX2o`3oD`Kooo]Z00Co0?lMoookJ_l0o`Sooo]Z
0_l0hOlGoookJP06o`3o=?oonf[ooo]ZoookJ_l0odko0?l^1ooonfX00ol0R?oooo]ZoookJP03oook
JP03o`2Yoooonf[ooo]Z00;ooo]Z00?o00CooookJ_oonfX09?oonfX0037ooo]Z00?oo`3ZoookJ_oo
nfX03?oonfX00ooo5P3ooi80oookJP04oookJP03ool0o?oonf[ooo]Z00Gooo]Z00?o603ooookJ_oo
1P001?oonfX01onDo`3oo`3foookJ_oonf[o0:KooookJ_nDo`001OoonfX00ooo0?Wooo]ZoiCo0002
oookJP07oom/0?l0olcooo]ZoookJ_ooP@3ooo]Zoc_o0004oookJP03o`3koooonf[ooo]Z00Cooo]Z
00Woo`<0oookJ_oo0=gooo]ZogT0oooonf[o0:?ook?o0?nO0?l01ooonfX01Ooo08Oooo]ZoookJ_oo
nf[oo`1/00;ooo]Z00?oC@3ooookJ_oo;P000_oonfX00omQ0?oooo]Zo`3oA@04oookJP03on80oooo
nf[o0?n@00;ooo]Z00?o0?nBoookJ_oonfX01ooonfX00omX0?oooo]ZoookJP03oookJP03oaP0oooV
o`3ooo]Z00?ooo]Z00?ooi00oookJ_oonfX02ooonfX01_nDo`3ooo]ZoookJ_l0o`Goj`3oog00o`Ko
oo]Z00?ooeL0oookJ_oonfX01ooonfX00ooo02gooo]ZoookJP09oookJP03oon10?oonf[ooo]Z00[o
oo]Z00Co0=CooookJ_l01?oo00Co0ooonfX01?l0003o0:Woo`28ool00003oookJP;o0?m>0_l0obh2
oookJP03o`3o=?oonf[ooo]Z00gooo]Z00?o0>7ooookJ_l0oad00_l0o`P4oookJP?oiOl00ooonfX3
onGo00Sooo]Z1_nDo`08ooo900koiOl07?oonfX8ool0D@?ooo]Z1Ol0[Ol2oookJPCoo`1i4ooonfX2
o`3oD`Kooo]Z00Co0?lMoookJ_l0o`Sooo]Z0_l0hOlFoookJP03o`3o=?oonf[ooo]Z00;ooo]Z0_l0
odh7oookJP03o`28oooonf[ooo]Z00;ooo]Z00?o0:WooookJ_oonfX00_oonfX00ol01?oooo]Zoook
JP1BoookJP03ool0j_oonf[ooo]Z00_ooo]Z00?ooaH0oonB0?oonfX01?oonfX00ooo0?cooo]Zoook
JP05oookJP03oaP0oooonf[oo`H000Cooo]Z00Gojol0oookJ_oo0?Kooo]Zo`2Vo`02oookJP03ojP0
oooonf[ooo]Z00;ooo]Z00?oo`3ioookJ_l0Mol00_oonfX01oooK03ooo]Zo`3oc?oonf[ooh40oook
J_lko`001?oonfX00ol0nooooo]ZoookJP04oookJP09ool30?oonf[oo`3MoookJ_mi0?oooo]Zo`2S
ool05ooo/ol000Oooo]Z00GogOl0ool0Qooonf[ooo]Zool0K003oookJP07odd0oooonf[oobh0oook
J_mQ0?oooo]Zo`3oA@05oookJP05on80ool0oi3ooo]ZoookJ_l0oi802OoonfX00omX0?oooo]Zoook
JP04oookJP03oaP0oooonf[ooo]Z00?ooo]Z00?ooi00oookJ_oonfX02ooonfX01Ooo_P3ooo]Zoook
J_o[0?ooL03o00Oooo]Z00?ooeL0oookJ_oonfX01_oonfX00ooo02gooo]ZoookJP09oookJP03oon1
0?oonf[ooo]Z00[ooo]Z00Co0=CooookJ_oonf[o00Co0ooonfX01?l0003o0:Woo`000?l0R?l4oook
JP;o0?m>00Co0?l^oookJ_oonf[o0?ld3ooonfX00ol0hOoooo]Zo`3o7@02o`3o20Gooo]Z0ol0oe<=
oookJPCoo`1i0_l0[Ol8oookJPKoo`1A9?oonfX9ool0D@;ooo]Z1Ol0[Ol2oookJPCoo`1i5?oonfX2
o`3oD`Gooo]Z0_l0oad01?l0o`Sooo]ZoookJ_l0hOlGoookJP04o`3o=?oonf[ooo]ZoookJP;o0?m>
1ooonfX00ol0R?oooo]ZoookJP03oookJP03o`2Yoooonf[ooo]Z00;ooo]Z00?o00CooookJ_oonfX0
8ooonfX0037ooo]Z00?oo`3ZoookJ_oonfX02ooonfX00ooo5P3ooo]ZoonB0004oookJP03ool0o?oo
nf[ooo]Z00Kooo]Z00?o603oool60?oonfX00ooonfX00onDo`3ooo]Zool0mP02oookJP03o`2Voooo
nf[oU?l000Cooo]Z00Ooo`3ioookJ_oonf[oU?l0oookJ_ooK03o0?nJ00;ooo]Z00Cooh40oookJ_oo
nf[o>ol00ooonfX00ol0nooooo]ZoookJP04oookJP09ool30?oonf[ooo]Zool0gOmi0?oooo]Zo`2S
oonco`3oW`3o00Oooo]Z00?o0?oNool0QooonfX00_oonfX01Ooo06cooo]ZoookJ_m=0?ooobh000;o
oo]Z00?oH@3ooookJ_l0odD01?oonfX00ooR0?oooo]Zo`3oT002oookJP03o`3oT_oonf[ooo]Z00Oo
oo]Z00?oJ03ooookJ_oonfX00ooonfX00olH0?oooo]ZonKo0003oookJP03oon@0?oonf[ooo]Z00co
oo]Z00GoU?l0oookJ_l0o`Goj`3oog00o`06oookJP03oomG0?oonf[ooo]Z00Oooo]Z00?oo`0]oook
J_oonfX02OoonfX00oooP@3ooo]ZoookJP0:oookJP03o`3Doooonf[o00Co00Gooo]Z00Co0:Woo`28
ool0003o00000_oonfX00ol0odkooo]Zo`3o;P02oookJP;o0?ld3_oonfX2o`3Qo`;o0?lM00?o0?l8
oookJ_oonfX00_oonfX2onGo00Oooo]Z00?oiOl0oookJ_oonfX01?oonfX3oiCo0003oookJ_l0[Ooo
0:go00?oU?l00_oob@06onGo00GoolT01ooUo`0RoookJP?o5@3o00?ooo]Zool0DOoo05400ooo0543
oookJPGo0:go00Cooo]Zool0NOoo07Woo`1i4_oonfX2o`3oD`Gooo]Z0_l0oad01?l0o`Sooo]Zoook
J_l0hOlFoookJP03o`3o=?oonf[ooo]Z00;ooo]Z00?o0?l^o`3oC_oonfX01_oonfX01Ol0R?oooo]Z
oookJ_oonf[o0:Wo00Gooo]Z00?o00CooookJ_oonfX0DOoonfX00ooo0>[ooo]ZoookJP0:oookJP03
oolF0?oonf[ooi8000Cooo]Z00?oo`3loookJ_oonfX01_oonfX00olH0?oooo]Zool60003oookJP03
on_o0?oonf[oo`3f00;ooo]Z00Co0:KooookJ_oonf[oZ03o1?oonfX01ooo0?Wooo]Zo`1goooonf[o
of`0o`3oV_l0ol`00_oonfX00oooP@3ooo]Zoc_o0003oookJP03o`3koooonf[ooo]Z00Cooo]Z00[o
o`<0oookJ_oonf[oo`3MogT0oooonf[o0:?oo`0Goonco`3oW`3o1_oonfX00ooMo`3oo`27oookJP02
oookJP06ool0K?oonf[ooo]Zodd0oooonf[oobh00_oonfX00omQ0?oo0?m5oookJP04oookJP05on80
ool0oi3ooo]ZoookJ_l0oi802OoonfX00omX0?oooo]ZoookJP04oookJP03oaP0oooVo`3ooo]Z00?o
oo]Z00?ooi00oookJ_oonfX03?oonfX01?oo_P3ooo]Zo`3o1Oo[0?l7oookJP03oomG0?oonf[ooo]Z
00Kooo]Z00?oo`0]oookJ_oonfX02OoonfX00oooP@3ooo]ZoookJP0:oookJP04o`3Doooonf[o00Co
o`04o`Cooo]Z00Co0:Woo`28ool0R?oo00000ooonfX01?l0odko0?l^oookJ_oonfX2o`3o=0kooo]Z
0_l0hOl2o`3o7@03o`3o2?oonf[ooo]Z00?ooo]Z0_l0oe<=oookJP?oo`1i00?ooo]Zo`2]ool0[Ol0
1OoonfX6ool0D@;o5@3o;OoonfX3oaD0o`03oookJ_oo057oo`1A00?oo`1A0_oonfX5o`2]o`03oook
J_oo07Woo`1i00;oo`1i4_oonfX2o`3oD`Gooo]Z0_l0oad2oookJP;o0>7o5_oonfX01_l0ocCooo]Z
oookJ_oonf[o0?l^o`3oCPOooo]Z00?o08SooookJ_oonfX00_oonfX00ol0ZOoooo]ZoookJP03oook
JP03o`04oooonf[ooo]Z02;ooo]Z000aoookJP03ool0j_oonf[ooo]Z00_ooo]Z00?ooaH0oonB0?oo
nfX01?oonfX00ooo0?cooo]ZoookJP05oookJP03oaP0oooo1P3ooo]Z00Cooo]Z00OoU?l0ool0m_oo
nf[ooo]Zo`2Voooonf[oU?l000Gooo]Z00Ooo`3ioookJ_nDo`3ooo]Zoom/0?l0oi[o0?o<00;ooo]Z
00?ooh40oookJ_lko`001?oonfX00ol0nooooo]ZoookJP03oookJP0:ool30?oonf[ooo]Zool0gOoo
nf[oN@3oo`2Soonco`3ooo]Zoil0o`Kooo]Z00?o0?oNool0QooonfX00_oonfX02_oo06cooo]Zoook
J_m=0?oooo]Zool^0?oonf[oH@3ooookJ_l0odD5oookJP03on80ool0oi3ooo]Z00;ooo]Z00?o0?nB
oookJ_oonfX01ooonfX00omX0?oooo]ZoookJP02oookJP03oaP0oooonf[oi_l000?ooo]Z00?ooi00
oookJ_oonfX03?oonfX01OnDo`3ooo]Zo`3o1Oo[0?ooL03o00Kooo]Z00?ooeL0oookJ_oonfX01ooo
nfX00ooo02gooo]ZoookJP09oookJP03oon10?oonf[ooo]Z00[ooo]Z00?o0=CooookJ_l01?l01Ooo
nfX00ol0ZOoo0000o`000002o`000004oookJ_l0odko0?l^o`3o;P;ooo]Z00?o0?ldoookJ_oonfX0
3?oonfX2o`3Qo`;o0?lM0_l0o`P3oookJP;oiOl03OoonfX3oiCo0004oookJ_l0[Ooo0:goo`2]o`;o
oo]Z1OoUo`09ooo900?ooo]Z0ooUo`0XoookJP?o5@3o0ooonfX2ool0D@Kooo]Z0ol0[Ol00ooonf[o
o`1iool0N@02ool0NA3ooo]Z0_l0oe<5oookJP;o0?lM00Co0?l8oookJ_l0hOoo0>7o5OoonfX00ol0
ocCooo]ZoookJP02oookJP03o`3o;_l0odkooo]Z00Kooo]Z00Go08SooookJ_oonf[ooo]Zo`2Yo`1G
oookJP03ool0j_oonf[ooo]Z00_ooo]Z00?ooaH0oonB0?oonfX01?oonfX00ooo0?cooo]ZoookJP05
oookJP03oaP0oooonf[oo`H000Cooo]Z00Gojol0oookJ_oo0?Kooo]Zo`2Vo`02oookJP03ojP0oooo
nf[ooo]Z00;ooo]Z00coo`3ioookJ_l0Mooooo]Zoom/0?l0oi[ooo]Zo`3oc?oonf[ooh40oookJ_lk
o`04oookJP03o`3koooonf[ooo]Z00?ooo]Z00[oo`<0oookJ_oonf[oo`3MoookJ_mi0?oo0:?ooook
J_nco`3oW`3o1ooonfX01Ol0omkoo`27oookJ_oonf[oo`1/00?ooo]Z00KoC@3ooookJ_oo;P3ooo]Z
of40ool0odD5oookJP03on80ool0oi3ooo]Z00;ooo]Z00?o0?nBoookJ_oonfX01ooonfX00omX0?oo
oo]ZoookJP03oookJP03oaP0oooVo`3ooo]Z00?ooo]Z00?ooi00oookJ_oonfX03?oonfX01Ooo_P3o
oo]Zo`3o1Oo[0?ooL03o00Kooo]Z00?ooeL0oookJ_oonfX01_oonfX00ooo02gooo]ZoookJP09oook
JP03oon10?oonf[ooo]Z00[ooo]Z00?o0=CooookJ_l01?l01OoonfX00ol0ZOoo08Soo`000002o`00
00;ooo]Z00Go0?m>o`3o;_oonf[ooo]Zo`3o=00>oookJP;o0>7o0_l0oad2o`3o20Cooo]Z0_l0oe<<
oookJP?oo`1i00Cooo]Zo`2]ool0[Ooo0:go0_oonfX5ool0D@03oookJ_lE0?oo5@3o00;o5@3o<ooo
nfX3oaD0o`?ooo]Z0_oo0545oookJP?o0:go0_oonfX3ool0NA7ooo]Z0_l0oe<5oookJP05o`3o7Ol0
o`Sooo]ZoookJ_l0hOl05_oonfX01_l0ocCooo]ZoookJ_oonf[o0?l^o`3oCPOooo]Z00?o08Sooook
J_oonfX00_oonfX00ol0ZOoooo]ZoookJP0WoookJP00<?oonfX00ooo0>[ooo]ZoookJP0;oookJP03
oolF0?oonf[ooi8000Cooo]Z00?oo`3loookJ_oonfX01_oonfX00olH0?ooo`H0oookJP03oookJP03
oiCo0?oonf[oo`3f00;ooo]Z00?o0:KooookJ_nDo`001?oonfX01ooo0?Wooo]ZoookJ_nDo`3ooo]Z
oom/0?l0oiX00_oonfX01?ooP@3ooo]ZoookJ_lko`03oookJP03o`3koooonf[ooo]Z00Cooo]Z00Wo
o`<0oookJ_oonf[oo`3MogT0oooonf[o0:?ook?o0?nO0?l01ooonfX01Ooo08Oooo]ZoookJ_oonf[o
o`1/00;ooo]Z00GoC@3ooookJ_oo;P3ooo]Zof40o`02oookJP03o`3oAOoonf[ooo]Z00;ooo]Z00?o
hP3ooookJ_l0oi000_oonfX00ol0oi;ooo]ZoookJP07oookJP03ofP0oooonf[ooo]Z00?ooo]Z00?o
603oonKo0?oonfX00_oonfX00oooT03ooo]ZoookJP0<oookJP05oiCo0?oonf[o0?l5on/0oom`0?l0
1_oonfX00oooE`3ooo]ZoookJP07oookJP03ool0;Ooonf[ooo]Z00Wooo]Z00?ooh40oookJ_oonfX0
2_oonfX00ol0e?oo00Coo`04o`04oookJP;o0:Wo00?ooo]Zo`000?l000000_l000001?l0odko0?l^
oookJ_oonfX2o`3o=0gooo]Z0_l0hOl01?oonf[o0?lMo`3o2?l0o`P3oookJP;oiOl03?oonfX3oiCo
00;ooo]Z0_l0[Ol00ooonf[oo`1AonGo0002onGo0003oookJ_nDo`3oolT000koolT000?oiOl0ooo9
0?oob@003ol06Ol8oa00oaCooo]Z0olE0?l2oookJP;oo`1A1ooonfX2o`2]o`?ooo]Z0ooo07T?oook
JP;o0?mC1OoonfX01Ol0oago0?l8oookJ_oonf[o0>7o01Cooo]Z00?o0?ldoookJ_oonfX00ooonfX0
0ol0obko0?l<oookJP06oookJP04o`28oooonf[ooo]Zo`2YoeOooo]Z00?oo`3ZoookJ_oonfX02_oo
nfX00ooo5P3ooo]ZoonB0004oookJP03ool0o?oonf[ooo]Z00Kooo]Z00?o603ooookJ_oo1P000ooo
nfX00oo[o`3ooo]Zool0mP02oookJP03o`2Voooonf[oZ03o00Gooo]Z00Ooo`3ioookJ_l0Mooooo]Z
oom/0?l0oi[o0?o<00;ooo]Z00?ooh40oookJ_lko`000ooonfX00ol0nooooo]ZoookJP04oookJP09
ool30?oonf[ooo]Zool0gOmi0?oooo]Zo`2Sool05ooo/ol000Oooo]Z00GogOl0ool0Qooonf[ooo]Z
ool0K003oookJP07odd0oooonf[oobh0oookJ_mQ0?oooo]Zo`3oA@05oookJP05on80ool0oi3ooo]Z
oookJ_l0oi802OoonfX00omX0?oooo]ZoookJP04oookJP03oaP0oooonf[ooo]Z00;ooo]Z00?ooi00
oookJ_oonfX03?oonfX01Ooo_P3ooo]Zo`3o1Oo[0?ooL03o00Kooo]Z00?ooeL0oookJ_oonfX01_oo
nfX00ooo02gooo]ZoookJP09oookJP03oon10?oonf[ooo]Z00[ooo]Z00?o0=Coo`04ool01?l01?oo
nfX2o`2Yo`03o`28ool0003o000000;o000000Co0?l^o`3oC_oonf[ooo]Z0_l0oc@=oookJP;o0>7o
00Cooo]Zo`3o7Ol0o`So0?l81?oonfX2o`3oD`_ooo]Z0ooo07T2oookJP;o0:go00?ooo]Zool0DOoo
05400_oo0542oookJPCo5@3o2ooonfXBo`0Io`So403o5OoonfX3oaD0o`;ooo]Z0_oo0546oookJP;o
0:go0ooonfX3ool0NA3ooo]Z0_l0oe<4oookJP;o0?lM0_oonfX2o`3QoaCooo]Z00?o0?ldoookJ_oo
nfX00_oonfX00ol0obko0?m>oookJP06oookJP05o`28oooonf[ooo]ZoookJ_l0ZOl0:OoonfX0033o
oo]Z00?oo`3ZoookJ_oonfX02ooonfX00ooo5P3ooi80oookJP04oookJP03ool0o?oonf[ooo]Z00Go
oo]Z00?o603oool60?oonfX00ooonfX00onDo`3ooo]Zool0mP02oookJP03o`2Voooonf[oU?l000Go
oo]Z00Woo`3ioookJ_nDo`3ooo]Zoom/0?l0oi[o0?o<oookJ_ooP@000_oonfX00olko`3ooo]Zoook
JP02oookJP03o`3koooonf[ooo]Z00?ooo]Z00[oo`<0oookJ_oonf[oo`3MoookJ_mi0?oo0:?ook?o
0?oonf[oW`3o1_oonfX01Ol0omkoo`27oookJ_oonf[oo`1/00?ooo]Z00OoC@3ooookJ_oo;P3ooo]Z
of40oooonf[o0?m500Cooo]Z00?ohP3ooookJ_l0oi000_oonfX00ol0oi;ooo]ZoookJP07oookJP03
ofP0oooonf[ooo]Z00?ooo]Z00?o603oonKo0?oonfX00ooonfX00oooT03ooo]ZoookJP0;oookJP05
oiCo0?oonf[ooo]Zon/0oom`0?l01_oonfX00oooE`3ooo]ZoookJP07oookJP03ool0;Ooonf[ooo]Z
00Wooo]Z00?ooh40oookJ_oonfX02_oonfX00ol0e?oo00CooookJP04oookJP04o`2Yoooonf[ooo]Z
oookJP?o000000Go0?m>oookJ_oonf[ooo]Zo`3o=00>oookJP05o`3Qoooonf[o0?lMo`3o7Ol0o`P0
0ooonfX2onGo00_ooo]Z0onDo`02oookJP?o0:go00?ooo]Zool0DOoo05400_oonfX4ooo90003oook
J_oob@3oolT000goolT01Ooo06X00ol0GOoo403ooa00o`09oa00o`;oo`1Z1_l06Ol4oa00o`Oo01Wo
3?oonfX3oaD0o`03oookJ_oo057oo`1A00Oooo]Z00?o0:gooookJ_oonfX00ooonfX00ooo07Wooo]Z
oookJP0>oookJP;o0?mC1?oonfX2o`3o7@;ooo]Z00?o0>7ooookJ_oonfX04_oonfX00ol0ocCooo]Z
oookJP02oookJP03o`3o;_l0o`cooo]Z00Kooo]Z00Go08SooookJ_oonf[ooo]Zo`2Yo`1FoookJP03
ool0j_oonf[ooo]Z00[ooo]Z00?ooaH0oonB0?oonfX01?oonfX00ooo0?cooo]ZoookJP05oookJP03
oaP0oooonf[oo`H000?ooo]Z00Kojol0oookJ_oonf[oo`3foookJ_l0Y_l2oookJP03ojP0oooonf[o
oo]Z00;ooo]Z00coo`3ioookJ_l0Mooooo]Zoom/0?l0oi[ooo]Zo`3oc?oonf[ooh40oookJ_lko`04
oookJP03o`3koooonf[ooo]Z00?ooo]Z00[oo`<0oookJ_oonf[oo`3MoookJ_mi0?oo0:?ooookJ_nc
o`3oW`3o1_oonfX01OoMo`3oo`27oookJ_oonf[oo`1/00Cooo]Z00KoC@3ooookJ_oo;P3oH@3ooook
J_l0odD5oookJP05on80ool0oi3ooo]ZoookJ_l0oi802OoonfX00omX0?oooo]ZoookJP04oookJP03
oaP0oooVo`3ooo]Z00?ooo]Z00?ooi00oookJ_oonfX02ooonfX01Ooo_P3ooo]ZoookJ_o[0?ooL03o
00Kooo]Z00?ooeL0oookJ_oonfX01_oonfX00ooo02gooo]ZoookJP09oookJP03oon10?oonf[ooo]Z
00[ooo]Z00?o0=Coo`04oooonfX01?oonfX01?l0ZOoo08SooookJ_oonfX3o`000005o`3o;_l0odko
oo]ZoookJ_l0oc@03_oonfX01Ol0hOoooo]Zo`3o7Ol0oago0?l800Cooo]Z0_l0oe<:oookJP?oo`1i
0_oonfX3o`2]o`03oookJ_oo057oo`1A00;ooo]Z1?lE0?l;oookJPCo01Wo00?ooo]Zool0J_oo06X0
0ooo06X00ol0GOoo403ooa00o`09oa00o`;oo`1Z1_l06Ol4oa00o`Oo01Wo3OoonfX3oaD0o`03oook
J_oo057oo`1A00Kooo]Z00?o0:gooookJ_oonfX00ooonfX00ooo07Wooo]ZoookJP0?oookJP;o0?mC
1?oonfX2o`3o7@;ooo]Z00?o0>7ooookJ_oonfX04_oonfX00ol0ocCooo]ZoookJP02oookJP03o`3o
C_oonf[ooo]Z00Kooo]Z00Go08SooookJ_oonf[ooo]Zo`2Yo`0XoookJP00<?oonfX00ooo0>[ooo]Z
oookJP0:oookJP03oolF0?oonf[ooi8000Gooo]Z00?oo`3loookJ_oonfX01OoonfX00olH0?ooo`H0
oookJP03oookJP03oiCo0?oonf[oo`3f00;ooo]Z00?o0:KooiCo0?oonfX01?oonfX01ooo0?Wooo]Z
oiCo0?oonf[oof`0oookJ_l0oiX00_oonfX01?ooP@3ooo]ZoookJ_lko`03oookJP03o`3koooonf[o
oo]Z00Cooo]Z00Woo`<0oookJ_oonf[oo`3MogT0ool0Xooo/ol0o`0GoonO0?l01_oonfX00ol0omko
o`27oookJP02oookJP0:ool0K?oonf[ooo]Zodd0oooonf[oobh0oookJ_mQ0?oooo]Zo`3oA@Gooo]Z
00?ohP3oo`3oT?oonfX00_oonfX00ol0oi;ooo]ZoookJP06oookJP03ofP0oooonf[ooo]Z00?ooo]Z
00?o603ooookJ_oVo`000ooonfX00oooT03ooo]ZoookJP0;oookJP05oiCo0?oonf[ooo]Zo`3o1Oo[
0?l01_oonfX00oooE`3ooo]ZoookJP08oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00?ooh40oookJ_oo
nfX02_oonfX00ol0e?oo00CooookJP03oookJP03o`28ool0ZOoooo]Z00?ooo]Z0_l000000ol0odko
0000oookJP02o`3o=0gooo]Z0_l0hOl2o`3o7@03o`3o2?oonf[ooo]Z00?oiOl02_oonfX3oiCo00;o
oo]Z0ol0[Ol01?oonf[oo`1Aool0DOoo0544ooo900Gooo]Z2_oob@0;oa00oa;ooo]Z1Ooo06X4oa00
o`;oo`1Z00Cooo]Zo`0Iool06Ooo01Wo3?oonfX3oaD0o`;oo`1A1_oonfX2o`2]o`Cooo]Z00?oo`1i
oookJ_oonfX03ooonfX00ol0oe?ooo]ZoookJP03oookJP03o`3o7Ooonf[ooo]Z00;o0>7o4ooonfX0
0ol0ocCooo]ZoookJP02oookJP03o`3o;_l0o`cooo]Z00Kooo]Z00Go08SooookJ_oonf[ooo]Zo`2Y
o`1DoookJP03ool0j_oonf[ooo]Z00[ooo]Z00?ooaH0oookJ_ooTP001OoonfX00ooo0?cooo]Zoook
JP05oookJP03oaP0oooo1P3ooo]Z00?ooo]Z00?ojol0oookJ_oo0?H00_oonfX00ol0Y_oooo]ZojP0
o`05oookJP09ool0nOl0Mooooo]Zoom/0?oonf[o0?nJo`3oc?oonf[ooh4000;ooo]Z00Go>ol0oook
J_oonf[ooo]Zo`3ko`06oookJP09ool30?oonf[ooo]Zool0gOmi0?oo0:?ooookJ_nco`3oW`3o00Oo
oo]Z00Go0?oNool0Qooonf[ooo]Zool0K003oookJP06odd0oooonf[oobh0oookJ_mQ0?oo0?m51Ooo
nfX00ooR0?oo0?n@oookJP02oookJP03o`3oT_oonf[ooo]Z00Kooo]Z00?oJ03ooookJ_oonfX01?oo
nfX00olH0?ooi_l0oookJP03oookJP03oon@0?oonf[ooo]Z00_ooo]Z00Gookh0oookJ_oonf[oj`3o
og00o`06oookJP03oomG0?oonf[ooo]Z00Oooo]Z00?oo`0]oookJ_oonfX02?oonfX00oooP@3ooo]Z
oookJP0:oookJP03o`3Dool01?oooo]Z00Cooo]Z00?o0:Woo`28oooonfX00_oonfX2o`000003o`3o
;_l0odkooo]Z00;o0?ld3OoonfX2o`3Qo`;o0?lM00Co0?l8oookJ_oonf[ooo]Z0ol0oe<9oookJP?o
o`1i0_oonfX3o`2]o`04oookJ_oo057oo`1Aool0D@Co5@3o2ooonfX4o`0Io`_o403o4ooonfX4ool0
JPCo403o0ooo06X3o`0Io`gooo]Z0olE0?l2ool0D@Gooo]Z0_l0[Ol4oookJP03ool0NOoonf[ooo]Z
013ooo]Z00?o0?mCoookJ_oonfX00_oonfX01?l0o`So0?lMoookJ_oonfX2o`3Qoa?ooo]Z00Ko0?ld
oookJ_oonf[ooo]Zo`3o;_l0odh8oookJP05o`28oooonf[ooo]ZoookJ_l0ZOl09ooonfX002oooo]Z
00?oo`3ZoookJ_oonfX02ooonfX00ooo5P3ooi80oookJP04oookJP03ool0o?oonf[ooo]Z00Gooo]Z
00?o603oool60?oonfX00ooonfX00onDo`3ooo]Zool0mP03oookJP03o`2VoonDo`3ooo]Z00Cooo]Z
00Woo`3ioookJ_nDo`3ooo]Zoom/0?l0oi[o0?o<oookJ_ooP@000_oonfX00olko`3ooo]ZoookJP02
oookJP03o`3koooonf[ooo]Z00?ooo]Z00Woo`<0oookJ_oonf[oo`3MoookJ_mi0?oo0:?ook?o0?nO
0?l01ooonfX01Ooo08Oooo]ZoookJ_oonf[oo`1/00?ooo]Z00CoC@3oool^0?oonf[oH@3o0_oonfX0
0ol0odGooo]ZoookJP02oookJP03on80oooonf[o0?n@00;ooo]Z00?o0?nBoookJ_oonfX01ooonfX0
0omX0?oooo]ZoookJP02oookJP03oaP0oooonf[oi_l000?ooo]Z00?ooi00oookJ_oonfX02ooonfX0
1OnDo`3ooo]ZoookJ_l0o`Goj`3o00Kooo]Z00?ooeL0oookJ_oonfX02?oonfX00ooo02gooo]Zoook
JP08oookJP03oon10?oonf[ooo]Z00[ooo]Z00?o0=CooookJ_l01?l00ooonfX00ol0R?oo0:Wooook
JP04oookJP;o0?m>00?o0000o`3o=?l0oc@03OoonfX2o`3Qo`03oookJ_l0oago0?l800;ooo]Z0_oU
o`0:oookJP03ool0NOnDo`3oU?l000?ooo]Z0_l0[Ol2oookJP;oo`1A0ooob@05oookJPOoolT01ol@
0?l00ooob@3ooo]ZoookJP0:oookJP;oo`3e2?nBo`0?oookJPCo403o0_oo06X3o`0Io`cooo]Z0_lE
0?l2ool0D@Kooo]Z0_l0[Ol3oookJP;oo`1i4?oonfX00ol0oe?ooo]ZoookJP03oookJP;o0?lM0_oo
nfX00ol0hOoooo]ZoookJP0AoookJP03o`3o=?oonf[ooo]Z00;ooo]Z00?o0?l^o`3o3?oonfX01_oo
nfX01?l0R?oooo]ZoookJ_l0ZOmDoookJP03ool0j_oonf[ooo]Z00[ooo]Z00?ooaH0oonB0?oonfX0
1?oonfX00ooo0?cooo]ZoookJP05oookJP03oaP0oooonf[oo`H000?ooo]Z00?ojol0oookJ_oo0?H0
0ooonfX00ol0Y_oooo]ZojP0o`04oookJP0<ool0nOoonf[o07OooookJ_ooK03o0?nJoookJ_l0olco
oo]Zoon10?oonf[o>ol01?oonfX00ol0nooooo]ZoookJP03oookJP0:ool30?oonf[ooo]Zool0gOoo
nf[oN@3oo`2Soooonf[o/ol0oil0o`Kooo]Z00GogOl0ool0Qooonf[ooo]Zool0K004oookJP06odd0
oooo;P3ooo]Zof40oooonf[o0?m51OoonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Wooo]Z00?oJ03o
oookJ_oonfX00ooonfX00olH0?ooi_l0oookJP03oookJP03oon@0?oonf[ooo]Z00_ooo]Z00Gookh0
oookJ_oonf[oj`3oog00o`06oookJP03oomG0?oonf[ooo]Z00Oooo]Z00?oo`0]oookJ_oonfX02?oo
nfX00oooP@3ooo]ZoookJP0:oookJP03o`3Doooonf[o00Co00Cooo]Z00?o0:WooookJ_oonfX00ooo
nfX00ol0003o0?m>o`3oCP02o`3o=0gooo]Z0_l0hOl00ooonf[o0?lMo`3o2003oookJP;o0?mC2Ooo
nfX3ool0N@?ooo]Z0_l0[Ol2oookJP;oo`1A0olE0?l9oookJP;o05go00?o01Wooa00ool@0?l01Ol@
0?l=oookJP;oo`3e2?nBo`0?oookJPCo403o0_oo06X3o`0Io`gooo]Z0_lE0?l2ool0D@Gooo]Z0_l0
[Ol3oookJP;oo`1i4OoonfX00ol0oe?ooo]ZoookJP02oookJP03o`3o2?l0oago0?lM00;ooo]Z00?o
0>7ooookJ_oonfX04OoonfX01_l0ocCooo]ZoookJ_oonf[o0?l^o`3oCPSooo]Z00Co08SooookJ_oo
nf[o0:Wo9ooonfX002oooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ooo5P3ooo]ZoonB0005oookJP03
ool0o?oonf[ooo]Z00Cooo]Z00?o603ooookJ_oo1P001?oonfX00onDo`3ooo]Zool0mP02oookJP03
o`2VoonDo`3ooo]Z00Cooo]Z00coo`3ioookJ_nDo`3ooo]Zoom/0?oonf[o0?nJo`3oc?oonf[ooh40
oookJ_lko`04oookJP03o`3koooonf[ooo]Z00?ooo]Z00[oo`<0oookJ_oonf[ooo]Zool0gOmi0?oo
0:?ook?o0?l05oooW`3o1_oonfX00ol0omkoo`27oookJP02oookJP07ool0K?oonf[ooo]Zodd0oooo
nf[oobh0of40o`02oookJP03o`3oAOoonf[ooo]Z00?ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP09
oookJP03ofP0oooonf[ooo]Z00?ooo]Z00?o603oonKo0?oonfX00_oonfX00oooT03ooo]ZoookJP0;
oookJP05oiCo0?oonf[ooo]Zo`3o1Oo[0?l01_oonfX00oooE`3ooo]ZoookJP08oookJP03ool0;Ooo
nf[ooo]Z00Sooo]Z00?ooh40oookJ_oonfX02_oonfX00ol0e?oooo]Zo`04o`02oookJP03o`28ool0
ZOoo0:Wo00Gooo]Z00Go0?m>o`3o;_l0003o0?ldo`00000<oookJP;o0>7o00?ooo]Zo`3o7Ol0oad0
0_oonfX2onGo00[ooo]Z0_oo07T3oookJP?o0:go0_oonfX2ool0D@;oolT000?ooo]Zooo90?oob@00
2Ooob@03oa00o`KoolT01ooonfX00ooo0?GoT_l0oi;o0006oi;o00Gooo]Z0ooo0?D5oi;o00kooo]Z
1?l@0?l01?oo06[o01Woo`0Iool06Ol<oookJP03oaD0oooo057oo`1A00Kooo]Z00?o0:gooookJ_oo
nfX00_oonfX00ooo07Wooo]ZoookJP0>oookJP03o`3oDooonf[ooo]Z00?ooo]Z00Co0?l8o`3o7Ol0
oagooo]Z0_l0hOlBoookJP03o`3o=?oonf[ooo]Z00;ooo]Z00?o0?l<oookJ_oonfX01_oonfX01?l0
R?oooo]ZoookJ_l0ZOmBoookJP03ool0j_oonf[ooo]Z00[ooo]Z00?ooaH0oookJ_ooTP001OoonfX0
0ooo0?cooo]ZoookJP05oookJP03oaP0oooo1P3ooo]Z00?ooo]Z00?ojol0oookJ_oo0?H00_oonfX0
0ol0Y_oooo]ZojP0o`04oookJP0<ool0nOoonf[o07OooookJ_ooK03ooo]Zo`3oV_oonf[o0?o<oon1
0?oonf[o>ol01?oonfX00ol0nooooo]ZoookJP03oookJP0:ool30?oonf[ooo]ZoookJ_oo0=goN@3o
o`2Soooonf[o/ol0oil0o`Oooo]Z00Goo`27oookJ_oonf[ooo]Zool0K003oookJP06odd0oooonf[o
obh0of40oooonf[o0?m51OoonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Wooo]Z00?oJ03ooookJ_oo
nfX01?oonfX00olH0?ooi_l0oookJP02oookJP03oon@0?oonf[ooo]Z00_ooo]Z00Gookh0oookJ_oo
nf[oj`3oog00o`06oookJP03oomG0?oonf[ooo]Z00Oooo]Z00?oo`0]oookJ_oonfX02?oonfX00ooo
P@3ooo]ZoookJP0:oookJP03o`3Doooonf[o00Co00?ooo]Z0_l0ZOl6oookJP04o`3oC_l0003o0?ld
o`0000cooo]Z0_l0hOl00ooonf[o0?lMo`3o7@03oookJP;o0?mC2OoonfX2ool0N@?ooo]Z0ol0[Ol2
oookJP;oo`1A0_lE0?l9oookJP?o01Wo0ol@0?l2ool0JP_ooo]Z00?oo`3eoi;o0?nBo`001_nBo`05
oookJP?oo`3e1OnBo`0>oookJPCo403o00Co05goo`0Iool06Ooo01Wo3OoonfX00olE0?ooo`1Aool0
D@05oookJP03o`2]oooonf[ooo]Z00;ooo]Z00?oo`1ioookJ_oonfX03ooonfX00ol0oe?ooo]Zoook
JP02oookJP06o`3o2?oonf[o0?lMo`3o7Ooonf[o0>7o4ooonfX01Ol0ocCooo]ZoookJ_oonf[o0?m>
00Wooo]Z00Co08SooookJ_oonf[o0:Wo9_oonfX002kooo]Z00?oo`3ZoookJ_oonfX02ooonfX00ooo
5P3ooi80oookJP04oookJP03ool0o?oonf[ooo]Z00Gooo]Z00?o603oool60?oonfX00ooonfX00onD
o`3ooo]Zool0mP03oookJP03o`2VoonDo`3ooo]Z00?ooo]Z00[oo`3ioookJ_oonf[oU?l0oookJ_oo
K03o0?nJo`3oc?oonf[ooh400_oonfX00olko`3ooo]ZoookJP02oookJP03o`3koooonf[ooo]Z00?o
oo]Z00Woo`<0oookJ_oonf[oo`3MogT0oooonf[o/ol0o`0GoonO0?l01ooonfX01Ooo08Oooo]Zoook
J_oonf[oo`1/00?ooo]Z00KoC@3oool^0?oonf[oH@3ooookJ_l0odD5oookJP03on80ool0oi3ooo]Z
00;ooo]Z00?o0?nBoookJ_oonfX01_oonfX00omX0?oooo]ZoookJP03oookJP03oaP0ool0o`coi_l0
00?ooo]Z00?ooi00oookJ_oonfX02_oonfX01OnDo`3ooo]ZoookJ_l0o`Goj`3o00Kooo]Z00?ooeL0
oookJ_oonfX02?oonfX00ooo02gooo]ZoookJP08oookJP03oon10?oonf[ooo]Z00[ooo]Z00?o0=Co
oookJ_l01?l00_oonfX00ol0R?oo0:WooookJP05oookJP04o`3oC_l0obko0?ldo`3o=0;o00002ooo
nfX01?l0hOoooo]Zo`3o2?l0oad2oookJP03o`3oDooUo`3ooo]Z00[ooo]Z00Coo`1ioookJ_oonf[o
oo]Z0_l0[Ol2oookJP04oaD0oooo057oo`1AoookJPcoolT00ol@0?l00ooo06[oolT0ooo90004ooo9
00;ooo]Z2?nBo`0DoookJP03ool0mOnBo`3oT_l000?oT_l03OoonfX4oa00o`?o01Wo00?o05gooook
J_oonfX02OoonfX3ool0D@Cooo]Z0_l0[Ol3oookJP;oo`1i3ooonfX00ol0oe?ooo]ZoookJP03oook
JP03o`3o2?oonf[o0?lM00;ooo]Z00?o0>7ooookJ_oonfX03ooonfX00ol0ocCooo]ZoookJP02oook
JP03o`3o;_l0o`cooo]Z00Oooo]Z00?o08SooookJ_l0ZOl0D_oonfX00ooo0>[ooo]ZoookJP0:oook
JP03oolF0?ooTP3ooo]Z00Cooo]Z00?oo`3loookJ_oonfX01_oonfX00olH0?ooo`H0oookJP02oook
JP03on_o0?oonf[oo`3f00?ooo]Z00?o0:KoojP0oooonfX01?oonfX03?oo0?Wooo]Zo`1goooonf[o
of`0o`3oV_oonf[o0?o<oookJ_ooP@3ooo]Zoc_o00Cooo]Z00?o0?_ooookJ_oonfX00ooonfX02_oo
0`3ooo]ZoookJ_oo0=goN@3ooookJ_l0Xooo/ol0oookJ_nO0?l6oookJP05omgo0?oo08Oooo]Zoook
J_oo06`00ooonfX01_m=0?oooo]Zool^0?oonf[oH@3oo`3oA@Gooo]Z00?ohP3oo`3oT?oonfX00_oo
nfX00ol0oi;ooo]ZoookJP06oookJP03ofP0oooonf[ooo]Z00Cooo]Z00?o603oonKo0?oonfX00ooo
nfX00oooT03ooo]ZoookJP0:oookJP05oonn0?oonf[ooo]Zon/0oom`0?l01_oonfX00oooE`3ooo]Z
oookJP07oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00?ooh40oookJ_oonfX02_oonfX00ol0e?oooo]Z
o`04o`03oookJP03o`2Yoooonf[ooo]Z00Gooo]Z00?o0?m>o`3o=?l0oc@00_l0000;oookJP04o`3Q
oooonf[o0?l8o`3o7@?ooo]Z0_l0oe<:oookJP04ool0NOoonf[ooo]ZoookJP;o0:go0_oonfX00olE
0?ooo`1Aool0D@09oookJPCo01Wo0ol@0?l00ooo06[ooo]ZoookJP06oookJPSoT_l05?oonfX00ooo
0?GoT_l0oi;o0003oi;o00gooo]Z1?l@0?l3o`0Io`03o`1Moooonf[ooo]Z00[ooo]Z0_oo05401?lE
0?oooo]ZoookJ_oonfX2o`2]o`?ooo]Z0_oo07T@oookJP03o`3oDooonf[ooo]Z00;ooo]Z00Go0?l8
oookJ_oonf[o0?lMoookJP02o`3Qoa7ooo]Z00?o0?ldoookJ_oonfX00_oonfX00ol0odkooo]Zoook
JP07oookJP03o`28oooonf[o0:Wo02Kooo]Z000^oookJP03ool0j_oonf[ooo]Z00[ooo]Z00?ooaH0
oookJ_ooTP001OoonfX00ooo0?cooo]ZoookJP04oookJP03oaP0oooo1P3ooo]Z00Cooo]Z00?oU?l0
ool0m_oonfX00_oonfX00ol0Y_ooU?l0oookJP04oookJP0<ool0nOoonf[oU?l0oookJ_ooK03ooo]Z
o`3oV_l0olcooo]Zoon10?oonf[o>ol01?oonfX00ol0nooooo]ZoookJP03oookJP0:ool30?oonf[o
oo]ZoookJ_oo0=goN@3oo`2Soonco`3ooo]Zoil0o`Kooo]Z00?oo`27oookJ_oonfX00_oonfX01ooo
06cooo]ZoookJ_m=0?oooo]Zool^0?mQ0?l00_oonfX00ol0odGooo]ZoookJP02oookJP03on80oooo
nf[o0?n@00;ooo]Z00?o0?nBoookJ_oonfX01ooonfX00omX0?oooo]ZoookJP02oookJP03oaP0ool0
o`coi_l000?ooo]Z00?ooi00oookJ_oonfX02ooonfX01OnDo`3ooo]Zo`3o1Oo[0?ooL03o00Gooo]Z
00?ooeL0oookJ_oonfX02?oonfX00ooo02gooo]ZoookJP08oookJP03oon10?oonf[ooo]Z00[ooo]Z
00?o0=CooookJ_l01?l00_oonfX00ol0R?oo0:WooookJP05oookJP03o`3oC_l0obko0?ld00Co0000
2OoonfX2o`3Qo`03o`3o2?l0oago0?lM00;ooo]Z00?o0?mCoookJ_oonfX02OoonfX2ool0N@04oook
J_l0[Ooo0:goo`2]o`;ooo]Z00?o5@3oool0DOoo05400ooonfX8ooo90004ool0J_l@0?oo403ooa00
o`Cooo]Z2?nBo`000ooo0?Gooo]ZoookJP06oookJPWo1P3o4?oonfX6oi;o00_ooo]Z1?l@0?l2o`0I
o`;o05go2_oonfX2ool0D@04oaD0oooonf[ooo]ZoookJP;o0:go0ooonfX00ooo07Wooo]ZoookJP0=
oookJP03o`3oDooonf[ooo]Z00?ooo]Z0_l0o`P01?l0oagooo]ZoookJ_l0hOlAoookJP03o`3o=?oo
nf[ooo]Z00;ooo]Z00?o0?l^o`3o3?oonfX01ooonfX00ol0R?oooo]Zo`2Yo`1AoookJP03ool0j_oo
nf[ooo]Z00Wooo]Z00?ooaH0oookJ_ooTP001OoonfX00ooo0?cooo]ZoookJP05oookJP03oaP0oooo
1P3ooo]Z00?ooo]Z00?ojol0oookJ_oo0?H00_oonfX00ol0Y_oooo]ZojP0o`04oookJP0<ool0nOoo
nf[o07OooookJ_ooK03ooo]Zo`3oV_oonf[o0?o<oon10?oonf[o>ol01?oonfX00ol0nooooo]Zoook
JP03oookJP0:ool30?oonf[ooo]ZoookJ_oo0=goN@3oo`2Soooonf[o/ol0oil0o`Kooo]Z00?ogOl0
ool0QooonfX00_oonfX02_oo06cooo]ZoookJ_oonf[oC@3ooookJ_oo;P3oH@3ooookJ_l0odD5oook
JP05on80ool0oi3ooo]ZoookJ_l0oi802OoonfX00omX0?oooo]ZoookJP03oookJP03oaP0oooVo`3o
oo]Z00?ooo]Z00?ooi00oookJ_oonfX02ooonfX01?oo_P3ooo]Zon/0oom`0?l6oookJP03oomG0?oo
nf[ooo]Z00Oooo]Z00?oo`0]oookJ_oonfX02?oonfX00oooP@3ooo]ZoookJP0:oookJP03o`3Doooo
nf[o00Co00?ooo]Z00?o0:WooookJ_oonfX01OoonfX00ol0odko0?ldo`000003o`0000Wooo]Z0_l0
hOl00ol0o`So0?lMo`3o7@03oookJP03o`3oDooonf[ooo]Z00Sooo]Z0_oo07T01?oonf[o0:goo`2]
ool0[Ol2oookJP03oaD0oooo057oo`1A00Oooo]Z1?l06Ol01?oo06[o403ooa00ool@0?l4oookJPSo
T_l000?oo`3eoookJ_oonfX01_oonfX9o`H0oa3ooo]Z1_nBo`0;oookJPCo403o0_l06Ol2o`1Mo`[o
oo]Z0_oo0542oaD0o`;ooo]Z0_l0[Ol3oookJP03ool0NOoonf[ooo]Z00kooo]Z00?o0?mCoookJ_oo
nfX00_oonfX2o`3o2005oookJ_l0oagooo]ZoookJ_l0hOl04OoonfX01_l0ocCooo]ZoookJ_oonf[o
0?l^o`3oCPWooo]Z00?o08SooookJ_l0ZOl09OoonfX002kooo]Z00?oo`3ZoookJ_oonfX02_oonfX0
0ooo5P3ooo]ZoonB0004oookJP03ool0o?oonf[ooo]Z00Gooo]Z00?o603oool60?oonfX00ooonfX0
0onDo`3ooo]Zool0mP03oookJP;oU?l01?oonfX02_oo0?Wooo]ZoookJ_nDo`3ooo]Zoom/0?l0oi[o
0?o<oookJ_ooP@02oookJP03oc_o0?oonf[ooo]Z00;ooo]Z00?o0?_ooookJ_oonfX00ooonfX02Ooo
0`3ooo]ZoookJ_oo0=goN@3ooookJ_nco`3o01Oooil0o`06oookJP03o`3og_oo08Oooo]Z00;ooo]Z
00Ooo`1/oookJ_oonf[ooo]Zodd0oooo;P3oH@3o00;ooo]Z00?o0?m5oookJ_oonfX00ooonfX01OoR
0?oo0?n@oookJ_oonf[o0?nB00Wooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?oooo]ZonKo0003
oookJP03oon@0?oonf[ooo]Z00_ooo]Z00GoU?l0oookJ_l0o`Goj`3oog00o`06oookJP03oomG0?oo
nf[ooo]Z00Oooo]Z00?oo`0]oookJ_oonfX02?oonfX00oooP@3ooo]ZoookJP0:oookJP03o`3Doooo
nf[o00Co00;ooo]Z00?o08Soo`2YoooonfX01OoonfX01?l0odkoU?l0oiCo0?oonfX4o`0000Oooo]Z
0_l0hOl00ol0o`So0?lMo`3o7@02oookJP;o0?mC2_oonfX2ool0N@?o0:go0ooonfX3ool0D@Gooo]Z
1Ooob@001_oo06[o403ooa00ool@0?ooolT0oookJPGoT_l00ooo0?D9oookJPGo1P3o2OoonfX;o`H0
o`_ooo]Z1OnBo`02ool0m@Oooo]Z00?oo`1Zoa00ool@0?l00_l@0?l00ol0GOoooo]ZoookJP09oook
JP;oo`1A00Go5@3ooookJ_oonf[ooo]Zo`2]o`03oookJP03ool0NOoonf[ooo]Z00gooo]Z00?o0?mC
oookJ_oonfX01?oonfX01?l0oagooo]ZoookJ_oonfX2o`3Qoa3ooo]Z00?o0?ldoookJ_oonfX00_oo
nfX00ol0o`cooo]ZoookJP07oookJP03o`28oooonf[o0:Wo04oooo]Z00?oo`3ZoookJ_oonfX02_oo
nfX00ooo5P3ooo]ZoonB0004oookJP03ool0o?oonf[ooo]Z00Kooo]Z00?o603oool60?oonfX00_oo
nfX00oo[o`3ooo]Zool0mP03oookJP03o`2VoonX0?oooo]Z00Cooo]Z00coo`3ioookJ_l0Mooooo]Z
oom/0?l0oi[ooo]Zo`3oc?oonf[ooh40oookJ_lko`04oookJP03o`3koooonf[ooo]Z00?ooo]Z00Wo
o`<0oookJ_oonf[oo`3MogT0oooonf[o0:?ook?o0?nO0?l01ooonfX01Ooo08Oooo]ZoookJ_oonf[o
o`1/00?ooo]Z00KoC@3ooookJ_oo;P3oH@3ooookJ_l0odD5oookJP05on80ool0oi3ooo]ZoookJ_l0
oi802OoonfX00omX0?oooo]ZoookJP03oookJP03oaP0ool0M?ooi_l000?ooo]Z00?ooi00oookJ_oo
nfX02ooonfX01?oo_P3ooo]Zon/0oom`0?l7oookJP03oomG0?oonf[ooo]Z00Kooo]Z00?oo`0]oook
J_oonfX02?oonfX00oooP@3ooo]ZoookJP0:oookJP03o`3Doooonf[o00Co00?ooo]Z00?o0:Wooook
J_oonfX01?oonfX01?l0obko0?m>o`3o=?oonfX4o`0000Oooo]Z0_l0hOl00ol0o`So0?lMo`3o7@03
oookJP;o0?mC2OoonfX2ool0N@?o0:go0ooonfX3ool0D@Gooo]Z1?l06Ol2ool0JP?o403o0_oonfX5
oi;o00?oo`3e2OoonfX5o`H0o`Wooo]Z2ol60?l;oookJPGoT_l00_oo0?D8oookJPCo403o00?o05go
oookJ_oonfX02OoonfX2ool0D@;o5@3o0_oonfX01Ol0[Ooooo]ZoookJ_oonf[oo`1i013ooo]Z00?o
0?mCoookJ_oonfX00ooonfX00ol0o`So0?lMoookJP02oookJP;o0>7o4?oonfX01Ol0ocCooo]Zoook
J_oonf[o0?m>00[ooo]Z00?o08SooookJ_l0ZOl09?oonfX002gooo]Z00?oo`3ZoookJ_oonfX02ooo
nfX00ooo5P3ooi80oookJP04oookJP03ool0o?oonf[ooo]Z00Cooo]Z00?o603oool60?oonfX01?oo
nfX00onDo`3oo`3foookJP02oookJP03o`2VoonX0?oooo]Z00Cooo]Z00?oo`3ioookJ_nDo`000_oo
nfX01oooK03o0?nJo`3oc?oonf[ooh40oookJ_lko`001?oonfX00ol0nooooo]ZoookJP03oookJP09
ool30?oonf[ooo]ZoookJ_oo0=goN@3ook?o0?l05oooW`3o00Oooo]Z00Goo`27oookJ_oonf[ooo]Z
ool0K003oookJP03odd0oooo;P3o0?l<00;ooo]Z00?o0?m5oookJ_oonfX00ooonfX01OoR0?oo0?n@
oookJ_oonf[o0?nB00Wooo]Z00?oJ03ooookJ_oonfX00_oonfX01?lH0?oooo]Zo`3o3?oVo`02oook
JP03oon@0?oonf[ooo]Z00_ooo]Z00GoU?l0oookJ_oonf[oj`3oog00o`06oookJP03oomG0?oonf[o
oo]Z00Oooo]Z00?oo`0]oookJ_oonfX02?oonfX00oooP@3ooo]ZoookJP0:oookJP03o`3Doooonf[o
00Co00;ooo]Z00?o08Soo`2YoooonfX01?oonfX2o`3oCP?oU?l000?ooo]Zo`000?l000000_l00005
oookJP;o0>7o00?ooo]Zo`3o2?l0oad00ooonfX00ol0oe?ooo]ZoookJP09oookJP03ool0NOl0[Ooo
0:go00Cooo]Z0_oo0544oookJP03ooo90?l06OooolT000CoolT00ol@0?l2ooo900?oT_l000?oo`3e
oookJ_oonfX02OoonfX5o`H0o`CoolT00_oonfX8o`3oC@_ooo]Z2_l60?l6oookJPGoT_l000?oo`3e
oookJ_oonfX01?oonfX2ool0JP?o403o2ooonfX2ool0D@?ooo]Z0_l0[Ol2oookJP;oo`1i3_oonfX0
0ol0oe?ooo]ZoookJP04oookJP03o`3o7Ooonf[ooo]Z00;ooo]Z00?o0>7ooookJ_oonfX03_oonfX0
1_l0ocCooo]ZoookJ_oonf[o0?l^o`3o30Wooo]Z00?o08SooookJ_oonfX0C_oonfX00ooo0>[ooo]Z
oookJP0:oookJP03oolF0?ooTP3ooo]Z00Cooo]Z00?oo`3loookJ_oonfX01OoonfX00olH0?ooo`H0
oookJP03oookJP03on_o0?oonf[oo`3f00;ooo]Z00?o0:KooookJ_nX0?l01?oonfX00ooo0?Wooo]Z
o`1go`02oookJP07oom/0?l0oi[ooo]Zo`3oc?ooP@3ooo]Zoc_o0004oookJP03o`3koooonf[ooo]Z
00?ooo]Z00[oo`<0oookJ_oonf[ooo]Zool0gOmi0?oo0:?ook?o0?l05oooW`3o1_oonfX00ooMo`3o
o`27oookJP02oookJP09ool0K?oonf[ooo]ZoookJ_m=0?ooobh0of40oooonf[o0?m500Gooo]Z00Go
hP3oo`3oT?oonf[ooo]Zo`3oTP09oookJP03ofP0oooonf[ooo]Z00?ooo]Z00?o603oo`1doooVo`00
0ooonfX00oooT03ooo]ZoookJP0;oookJP05oonn0?oonf[oj`3oo`3o1Om`0?l01_oonfX00oooE`3o
oo]ZoookJP06oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00?ooh40oookJ_oonfX02_oonfX00ol0e?oo
oo]Zo`04o`03oookJP03o`2Yoooonf[ooo]Z00Cooo]Z0_l0odh3oookJPCo00001OoonfX2o`3Qo`03
oookJ_l0o`So0?lM00Cooo]Z00?o0?mCoookJ_oonfX02?oonfX00ooo07Wo0:goo`2]o`04oookJP;o
o`1A1OoonfX3o`0Io`03oookJ_oo06[oo`1Z00?o403o0_oonfX3oi;o0003ool0mOoonf[ooo]Z00Wo
oo]Z1Ol60?l7oookJPSo0?m=2_oonfX;o`H0o`Gooo]Z1OnBo`000ooo0?Gooo]ZoookJP04oookJP;o
o`1Z0ol@0?l;oookJP;oo`1A00?o5@3ooookJ_oonfX00_l0[Ol2oookJP;oo`1i3ooonfX00ol0oe?o
oo]ZoookJP03oookJP03o`3o2?l0oagooo]Z00?ooo]Z00?o0>7ooookJ_oonfX03_oonfX01Ol0ocCo
oo]ZoookJ_oonf[o0?m>00[ooo]Z00?o08SooookJ_oonfX08ooonfX002gooo]Z00?oo`3ZoookJ_oo
nfX02_oonfX00ooo5P3ooo]ZoonB0005oookJP03ool0o?oonf[ooo]Z00Cooo]Z00?o603oool60?oo
nfX00ooonfX00onDo`3ooo]Zool0mP03oookJP03ojP0oooonf[ooo]Z00?ooo]Z00?oo`3ioookJ_nD
o`000_oonfX01OooK03o0?nJo`3oc?oonf[ooh4000;ooo]Z00?o>ol0oookJ_oonfX00_oonfX00ol0
nooooo]ZoookJP03oookJP09ool30?oonf[ooo]Zool0gOmi0?oooo]Zok?o0?l05oooW`3o00Kooo]Z
00?oo`27omgo0?oonfX00_oonfX01ooo06cooo]ZoookJ_m=0?oooo]Zool^0?l0o``00_oonfX00ol0
odGooo]ZoookJP02oookJP03on80oooonf[o0?n@00;ooo]Z00?o0?nBoookJ_oonfX01_oonfX00omX
0?oooo]ZoookJP03oookJP03oaP0ool0o`coi_l000?ooo]Z00?ooi00oookJ_oonfX02_oonfX01OnD
o`3ooo]ZoookJ_o[0?ooL03o00Kooo]Z00?ooeL0oookJ_oonfX01ooonfX00ooo02gooo]ZoookJP08
oookJP03oon10?oonf[ooo]Z00[ooo]Z00?o0=CooookJ_l01?l00_oonfX2o`2Yo`Gooo]Z00?o0?m>
oiCo0?nDo`000_nDo`02oookJPCo00001?oonfX00ol0hOoooo]ZoookJP02o`3o7@;ooo]Z0_l0oe<:
oookJP;oo`1i00?o0:gooookJ_oonfX00_oonfX2ool0D@03oookJ_oob@3oolT000;oolT00_l06Ol3
ooo900?o403o0ooob@02oi;o00Kooo]Z2Ooob@05o`3Xo`Ko0?m=2?l0j?l8o`3oC@Ko0>So1ooonfX4
o`H0o`;oiOl01OoonfX4oi;o00Gooo]Z0ooo06X00ol@0?oo01Woo`0Io`0:oookJP;oo`1A0ooonfX2
o`2]o`;ooo]Z00?oo`1ioookJ_oonfX03?oonfX00ol0oe?ooo]ZoookJP04oookJP03o`3o7Ooonf[o
oo]Z00;ooo]Z00?o0>7ooookJ_oonfX03_oonfX01Ol0ocCooo]ZoookJ_oonf[o0?l<00[ooo]Z00?o
08SooookJ_oonfX0C?oonfX00ooo0>[ooo]ZoookJP0:oookJP03oolF0?oonf[ooi8000Gooo]Z00?o
o`3loookJ_oonfX01OoonfX00olH0?ooo`H0oookJP02oookJP03on_o0?oonf[oo`3f00?ooo]Z00?o
0:KoojP0oooonfX01?oonfX03?oo0?Wo07OooookJ_oonf[oof`0o`3oV_oonf[o0?o<oookJ_ooP@3o
oo]Zoc_o00Cooo]Z00?o0?_ooookJ_oonfX00ooonfX02Ooo0`3ooo]ZoookJ_oo0=goN@3ooookJ_l0
Xooo/ol0oil0o`07oookJP05ool0Qooonf[ooo]ZoookJ_oo06`00ooonfX01_m=0?oooo]Zool^0?mQ
0?oooo]Zo`3oA@Gooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP08oookJP03ofP0oooonf[ooo]Z00Co
oo]Z00?o603oonKo0?oonfX00ooonfX00oooT03ooo]ZoookJP0:oookJP05oonn0?oonf[oj`3oo`3o
1Om`0?l01_oonfX00oooE`3ooo]ZoookJP06oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00?ooh40oook
J_oonfX02_oonfX00ol0e?oooo]Zo`04o`02oookJP;o0:Wo1_oonfX00ol0odko0?ldoookJP03oook
JPCo00001?oonfX00ol0hOoooo]ZoookJP02o`3o7@?ooo]Z0_l0oe<9oookJP;oo`1i00?o0:gooook
J_oonfX00_oonfX2ool0D@Gooo]Z0_l06Ol00ooonf[o05goool0JP03oa00o`?ooo]Z0_nBo`09oook
JP?o1P3o2?l0j?l7o`3oC@So0>So2?l0odd6o`3Xo`Oooo]Z1_l60?l4oookJPCoT_l01_oonfX2ool0
JP03oa00ool06Ooo01Wo00[ooo]Z0_oo0543oookJP;o0:go0_oonfX00ooo07Wooo]ZoookJP0=oook
JP03o`3oDooonf[ooo]Z00?ooo]Z00?o0?l8o`3o7OoonfX00ooonfX00ol0hOoooo]ZoookJP0>oook
JP05o`3o=?oonf[ooo]ZoookJ_l0odh02_oonfX00ol0R?oooo]ZoookJP0RoookJP00;OoonfX00ooo
0>[ooo]ZoookJP0:oookJP03oolF0?ooTP3ooo]Z00Cooo]Z00?oo`3loookJ_oonfX01?oonfX00olH
0?ooo`H0oookJP04oookJP03oiCo0?oo0?Kooo]Z00;ooo]Z00?o0:KoojP0oooonfX01?oonfX00ooo
0?Wooo]ZoiCo0002oookJP07oom/0?l0oi[o0?o<oookJ_ooP@3ooo]Zoc_o0004oookJP03o`3koooo
nf[ooo]Z00?ooo]Z00Woo`<0oookJ_oonf[ooo]Zool0gOmi0?oo/ol0o`0GoonO0?l01_oonfX00ooo
08OogOl0oookJP02oookJP06ool0K?oonf[ooo]ZoookJ_m=0?ooobh00_l0o``00ooonf[o0?m5oook
JP04oookJP05on80ool0oi3ooo]ZoookJ_l0oi802OoonfX00omX0?oooo]ZoookJP02oookJP03oaP0
ool0o`coi_l000?ooo]Z00?ooi00oookJ_oonfX02_oonfX01OnDo`3ooo]ZoookJ_o[0?ooL03o00Ko
oo]Z00?ooeL0oookJ_oonfX01ooonfX00ooo02gooo]ZoookJP08oookJP03oon10?oonf[ooo]Z00[o
oo]Z00?o0=CooookJ_l01?l00_oonfX00ol0ZOoooo]ZoookJP03oookJP03oiCo0?l0odkoU?l000?o
U?l00ooonfX4o`0000;ooo]Z0_l0hOl2oookJP05o`3o7Ooonf[ooo]ZoookJ_l0oe<02_oonfX2ool0
N@;o0:go0ooonfX2ool0D@03oaD0oooob@3oolT000;oolT00_l06Ol2ooo900?o403o00?oolT0oook
J_oob@000onBo`0?ooo900Oo0?m=2ooob@0;o`0`o`Oo0?m=0_l0j?l:oookJP;oiOl01_oonfX00ooo
0?GoT_l0oi;o0006oookJP03ool0J_l@0?oo403o00?o01Wo2?oonfX00olE0?ooo`1Aool0D@03oook
JP03o`2]oooonf[ooo]Z00;oo`1i3OoonfX00ol0oe?ooo]ZoookJP04oookJP05o`3o7Ooonf[ooo]Z
oookJ_l0hOl04OoonfX01Ol0ocCooo]ZoookJ_oonf[o0?l<05Sooo]Z00?oo`3ZoookJ_oonfX02_oo
nfX00ooo5P3ooi80oookJP04oookJP03ool0o?oonf[ooo]Z00Gooo]Z00?o603oool60?oonfX00ooo
nfX00oo[o`3ooo]Zool0mP02oookJP03o`2Voooonf[oZ03o00Cooo]Z00?oo`3ioookJ_l0Mol00_oo
nfX01oooK03o0?nJoookJ_l0olcooh40oookJ_lko`001?oonfX00ol0nooooo]ZoookJP03oookJP0:
ool30?oonf[ooo]ZoookJ_oo0=goN@3oo`2Soonco`3o01Oooil0o`Kooo]Z00?oo`27oookJ_oonfX0
0_oonfX02Ooo06cooo]ZoookJ_oonf[oC@3oool^0?mQ0?oooo]Zo`3oA@05oookJP05on80ool0oi3o
oo]ZoookJ_l0oi802OoonfX00omX0?oooo]ZoookJP03oookJP03oaP0oooonf[oi_l000?ooo]Z00?o
oi00oookJ_oonfX02_oonfX01Ooo_P3ooo]Zon/0ool0o`GoL03o00Kooo]Z00?ooeL0oookJ_oonfX0
1_oonfX00ooo02gooo]ZoookJP08oookJP03oon10?oonf[ooo]Z00[ooo]Z00?o0=CooookJ_l01?l0
0_oonfX00ol0ZOoo08SooookJP05oookJP03o`3oC_l0ocCooo]Z00Cooo]Z1?l00002oookJP;o0>7o
0_oonfX00ol0oagooo]ZoookJP02oookJP03o`3oDooonf[ooo]Z00Oooo]Z0_oo07T2o`2]o`?ooo]Z
0_oo05400olE0?oooo]ZoookJP02oookJP;o01Wo0_l0GOl3oa00o`?ooo]Z0onBo`06oookJPGo1P3o
0ol0j?l2oookJPKo0?m=2ooonfX;o`0`o`03oookJ_l0odgo0?m=00Go0?m=0_l0j?l:oookJP;o1P3o
1OoonfX00ooo0?GoT_l0oi;o0006oookJP03ool0J_l@0?oo403o00?o01Wo2OoonfX2ool0D@?ooo]Z
00?o0:gooookJ_oonfX00_oo07T>oookJP03o`3oDooonf[ooo]Z00?ooo]Z00?o0?l8o`3o7OoonfX0
0_oonfX00ol0hOoooo]ZoookJP0?oookJP04o`3o=?oonf[ooo]Zo`3oCRoooo]Z000/oookJP03ool0
j_oonf[ooo]Z00[ooo]Z00?ooaH0oookJ_ooTP001OoonfX00ooo0?cooo]ZoookJP04oookJP03ool6
0?oonf[ooo]Z00?ooo]Z00?oU?l0oookJ_oo0?H00ooonfX00ol0Y_ooZ03ooookJP03oookJP03ool0
nOoonf[oU?l000;ooo]Z00Ooof`0o`3oV_l0olcooo]Zoon10?oonf[o>ol000Gooo]Z00?o0?_ooook
J_oonfX00_oonfX02_oo0`3ooo]ZoookJ_oonf[oo`3MogT0oonco`3o0:?oo`0GoonO0?l6oookJP03
ool0Qooonf[ooo]Z00;ooo]Z00Goo`1/oookJ_oonf[oC@3ooookJP02o`3o3003oookJ_l0odGooo]Z
00Cooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP09oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Co603o
oookJ_l0o`coi_l00_oonfX00oooT03ooo]ZoookJP0:oookJP05oiCo0?oonf[oiOl0onGo0?m`0?l0
1ooonfX00oooE`3ooo]ZoookJP06oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00?ooh40oookJ_oonfX0
2OoonfX2o`3Do`05oookJ_l01?oooo]ZoookJ_l0ZOl01?oonfX2oiCo0003o`3oC_nDo`3oU?l000?o
U?l00ooonfX4o`0000;o0>7o0_oonfX2o`3o7@?ooo]Z00?o0?mCoookJ_oonfX02?oonfX00ooo07Wo
0:goo`2]o`03oookJP;oo`1A00?o5@3ooookJ_oob@000_oob@02o`0Io`04ooo90?l@0?oo403ooa00
o`;oolT00_oonfX2oi;o00;oolT000?ooo]Zooo90?oob@001ooob@06o`3oC@?ooo]Z3ol0<?l3ooo9
00Gooo]Z0ol0ok44o`0`o`?ooo]Z2?l0odd6oookJP;oiOl01_oonfX00ooo0?GoT_l0oookJP06oook
JP04ool0J_l@0?oo05gooookJP?o01Wo1_oonfX01?lE0?oooo]Zool0DOoo0542oookJP;o0:go0_oo
nfX00ooo07Wooo]ZoookJP0;oookJP03o`3oDooonf[ooo]Z00Cooo]Z00Go0?lMoookJ_oonf[ooo]Z
o`3Qo`0@oookJP03o`3o=?oonf[ooo]Z00;ooo]Z00?o0?l<oookJ_oonfX0EOoonfX00ooo0>[ooo]Z
oookJP09oookJP03oolF0?oonf[ooi8000Gooo]Z00?oo`3loookJ_oonfX01OoonfX00ooo1P3ooo]Z
oookJP02oookJP03on_o0?oonf[oo`3f00?ooo]Z00?o0:KooookJ_nX0?l00ooonfX00ooo0?Wooo]Z
o`1go`02oookJP07oom/0?l0oi[ooo]Zo`3oc?oonf[ooh40oc_o0005oookJP03o`3koooonf[ooo]Z
00;ooo]Z00[oo`<0oookJ_oonf[ooo]Zool0gOmi0?oooo]Zok?o0?l05oooW`3o1_oonfX00ooMo`3o
o`27oookJP02oookJP09ool0K?oonf[ooo]ZoookJ_m=0?oooo]Zool^0?mQ0?oo0?m500Kooo]Z00Co
hP3ooookJ_oonf[o0?nB2OoonfX00omX0?oooo]ZoookJP03oookJP03oaP0ool0M?ooi_l000?ooo]Z
00?ooi00oookJ_oonfX02_oonfX01Ooo_P3ooo]Zon/0ool0o`GoL03o00Oooo]Z00?ooeL0oookJ_oo
nfX01OoonfX00ooo02gooo]ZoookJP08oookJP03oon10?oonf[ooo]Z00Wooo]Z0_l0e?l01_oonf[o
00CooookJ_oonf[o0:Woo`28o`Kooo]Z00?o0?m>o`3o=?oonfX01OoonfX4o`0000;o0>7o0_oonfX2
o`3o7@Cooo]Z00?o0?mCoookJ_oonfX01ooonfX00ooo07Wooo]Zo`2]o`03oookJP;oo`1A00?o5@3o
oookJ_oonfX00ooonfX00ol06Ooo05gooa00o`02oa00o`Cooo]Z0_nBo`04oookJPGo1P3o0_oonfX2
o`3Xo`Ko0?m=0_oonfX?o`0`o`Sooo]Z0ol0ok44o`0`o`Cooo]Z2?l0odd6oookJP;o1P3o1OoonfX0
0ooo0?GoT_l0oi;o0006oookJP04ool0J_l@0?ooo`1ZoookJP?o01Wo1ooonfX00olE0?ooo`1Aool0
D@02oookJP;o0:go0_oonfX00ooo07Wooo]ZoookJP0<oookJP03o`3oDooonf[ooo]Z00?ooo]Z00?o
0?l8o`3o7OoonfX00_oonfX00ol0hOoooo]ZoookJP0>oookJP05o`3o=?oonf[ooo]ZoookJ_l0odh0
;_oonfX002cooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ooo5P3ooi80oookJP04oookJP03ool0o?oo
nf[ooo]Z00Cooo]Z00?o603oool60?oonfX01?oonfX00onDo`3oo`3foookJP02oookJP03o`2VoonX
0?oooo]Z00Cooo]Z00?oo`3ioookJ_nDo`000_oonfX01?ooK03o0?nJo`3oc?ooP@02oookJP03oc_o
0?oonf[ooo]Z00;ooo]Z00?o0?_ooookJ_oonfX00ooonfX02Ooo0`3ooo]ZoookJ_oonf[oo`3MogT0
oonco`3o01Oooil0o`06oookJP03ool0QooMo`3ooo]Z00;ooo]Z00Goo`1/oookJ_oonf[ooo]Zodd0
o`03o`3o3003oookJ_l0odGooo]Z00?ooo]Z00?ohP3oo`3oT?oonfX00_oonfX00ol0oi;ooo]Zoook
JP06oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Co603ooookJ_l0o`coi_l00_oonfX00oooT03ooo]Z
oookJP0:oookJP03oiCo0?oonf[oiOl000;oiOl01ooonfX00oooE`3ooo]ZoookJP06oookJP03ool0
;Ooonf[ooo]Z00Sooo]Z00?ooh40oookJ_oonfX02OoonfX01?l0e?oooo]ZoookJ_l01?l2oookJP04
o`2Yoooonf[ooo]ZoookJP?oU?l000?o0?m>oiCo0?nDo`000onDo`04oookJP?o000000?o0>7ooook
J_oonfX00_l0oad3oookJP;o0?mC2OoonfX2ool0N@03o`2]oooonf[ooo]Z00?oo`1A00?o5@3ooook
J_oonfX00_oonfX00ooob@3o01Wooa00o`02oa00o`CoolT00onBo`02oookJPCo1P3o0_oob@06o`3o
C@?oolT01_l0<?l4ooo900Co0?n`2?n2o`0<oookJP;o0?na1Ol0<?l3oookJP?o0>So1Ol0odd3oook
JP?oiOl01OoonfX2oi;o00Oooo]Z0_l@0?l00ooo06[ooo]ZoookJP02o`0Io`Gooo]Z0_lE0?l00ooo
nf[oo`1Aool0D@02oookJP;o0:go00?ooo]Zool0NOoonfX03?oonfX00ol0oe?ooo]ZoookJP04oook
JP05o`3o7Ol0o`Sooo]ZoookJ_l0hOl04?oonfX01Ol0ocCooo]ZoookJ_oonf[o0?l<05Kooo]Z00?o
o`3ZoookJ_oonfX02_oonfX00ooo5P3ooi80oookJP04oookJP03ool0o?oonf[ooo]Z00Gooo]Z00?o
603oool60?oonfX00ooonfX00oo[o`3ooo]Zool0mP02oookJP03o`2Voooonf[oZ03o00Cooo]Z00?o
o`3ioookJ_l0Mol00_oonfX01oooK03o0?nJoookJ_l0olcooh40oookJ_lko`001?oonfX00ol0nooo
oo]ZoookJP03oookJP0:ool30?oonf[ooo]ZoookJ_oo0=goN@3oo`2Soonco`3o01Oooil0o`Kooo]Z
00Goo`27oookJ_oonf[ooo]Zool0K004oookJP05odd0oooo;P3oH@3ooookJ_l0odD01OoonfX01OoR
0?oooo]ZoookJ_oonf[o0?nB00Sooo]Z00?oJ03ooookJ_oonfX00ooonfX00olH0?oo07CoonKo0003
oookJP03oon@0?oonf[ooo]Z00[ooo]Z00Gookh0oookJ_oonf[oj`3oog00o`07oookJP03oomG0?oo
nf[ooo]Z00Gooo]Z00?oo`0]oookJ_oonfX02?oonfX00oooP@3ooo]ZoookJP09oookJP04o`3Doooo
nf[ooo]Zo`04o`;ooo]Z00?o0:Woo`28oooonfX01OoonfX00ol0odko0?ldoookJP06oookJP?o0000
00?o0>7ooookJ_oonfX00_l0oad4oookJP;o0?mC2?oonfX2ool0N@;o0:go00Gooo]Zool0DOoo057o
o`1AoaD0o`05oookJP04o`0Iool@0?oo403ooa00o`Cooo]Z0onBo`02oookJPCo1P3o0_oonfX7o`3o
C@So033o1?l0ok45o`3o/0SoP_l02ooonfX2o`3o/@Go033o1?oonfX3o`3Xo`Go0?m=0ooonfX2o`H0
o`Gooo]Z00?oo`3eoi;o0?oonfX01_oonfX2oa00o`03ool0J_oonf[ooo]Z00;o01Wo1_oonfX2oaD0
o`;oo`1A0_oonfX2o`2]o`03oookJ_oo07Wooo]Z00gooo]Z00?o0?mCoookJ_oonfX00ooonfX00ol0
oago0?l8oookJP02oookJP03o`3Qoooonf[ooo]Z00kooo]Z00Go0?ldoookJ_oonf[ooo]Zo`3oCP0]
oookJP00;?oonfX00ooo0>[ooo]ZoookJP09oookJP03oolF0?oonf[ooi8000Gooo]Z00?oo`3loook
J_oonfX01?oonfX00ooo1P3ooo]ZoookJP03oookJP03oiCo0?oonf[oo`3f00?ooo]Z00?o0:KoojP0
oooonfX00ooonfX00ooo0?Wooo]ZoiCo0002oookJP07oom/0?l0oi[o0?o<oookJ_ooP@3ooo]Zoc_o
0005oookJP03o`3koooonf[ooo]Z00;ooo]Z00Woo`<0oookJ_oonf[ooo]Zool0gOmi0?oo/ol0o`2S
oonO0?l01_oonfX00ooo08OogOl0oookJP03oookJP04ool0K?oonf[ooo]Zodd0o`Co0?l<00?o0?m5
oookJ_oonfX00ooonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Sooo]Z00?oJ03ooookJ_oonfX00ooo
nfX00olH0?oo0?l<onKo0003oookJP03oon@0?oonf[ooo]Z00Wooo]Z00?oU?l0oookJ_oUo`000_oU
o`07oookJP03oomG0?oonf[ooo]Z00Kooo]Z00?oo`0]oookJ_oonfX02?oonfX00oooP@3ooo]Zoook
JP09oookJP04o`3Doooonf[ooo]Zo`04o`;ooo]Z00?o0:WooookJ_oonfX01?nDo`000ol0odkoU?l0
oiCo0003oiCo00Gooo]Z0_l000001Ol0hOoo0000oookJ_l0oago0?l800?ooo]Z00?o0?mCoookJ_oo
nfX01ooonfX2ool0N@;o0:go00?ooo]Zool0DOoo05400_lE0?l4oookJP04ooo90?l@0?oo403ooa00
o`GoolT00_nBo`000ooo0?Gooo]ZoookJP02o`H0o`CoolT00_l0odd>ooo900?o0?n`1_n2o`05ooo9
00;ooo]Z00?o0?n`oh;o0?n2o`001On2o`07o`3o/0?ooo]Z0_l0ok44o`0`o`?ooo]Z0ol0j?l00ooo
nf[o0?m=o`3oC@04oookJP;oiOl01OoonfX2oi;o00;oiOl01OoonfX00ol@0?ooo`1Zool0JP02oook
JP03o`0Ioooonf[ooo]Z00Cooo]Z00Co5@3ooookJ_oonf[oo`1A0ooonfX01?l0[Ooooo]Zool0NOoo
07T<oookJP03o`3oDooonf[ooo]Z00?ooo]Z00?o0?lMoookJ_l0o`P00_oonfX00ol0hOoooo]Zoook
JP0>oookJP05o`3o=?oonf[ooo]ZoookJ_l0o``0EOoonfX00ooo0>[ooo]ZoookJP09oookJP03oolF
0?oonf[ooi8000Gooo]Z00?oo`3loookJ_oonfX01OoonfX00ooo1P3ooo]ZoookJP02oookJP03on_o
0?oonf[oo`3f00?ooo]Z00?o0:KooookJ_nX0?l00ooonfX00ooo0?Wooo]Zo`1go`02oookJP07oom/
0?l0oi[ooo]Zo`3oc?oonf[ooh40oc_o0005oookJP03o`3koooonf[ooo]Z00;ooo]Z00[oo`<0oook
J_oonf[ooo]Zool0gOmi0?oooo]Zok?o0?l05oooW`3o1_oonfX00ooo08Oooo]ZoookJP02oookJP09
ool0K?oonf[ooo]ZoookJ_m=0?oooo]Zool^0?mQ0?oo0?m500Gooo]Z00GohP3oo`3oT?oonf[ooo]Z
o`3oTP08oookJP03ofP0oooonf[ooo]Z00Cooo]Z00?o603ooookJ_oVo`000ooonfX00oooT03ooo]Z
oookJP09oookJP05oonn0?oonf[ooo]Zon/0oom`0?l01ooonfX00oooE`3ooo]ZoookJP05oookJP03
ool0;Ooonf[ooo]Z00Sooo]Z00?ooh40oookJ_oonfX02OoonfX01?l0e?oooo]ZoookJ_l01?l2oook
JP03o`2Yool0R?oooo]Z00Gooo]Z00?o0?m>o`3o=?oonfX01ooonfX2o`000005o`3Qool0003ooo]Z
o`3o7Ol0o`P01?oonfX00ol0oe?ooo]ZoookJP06oookJP;oo`1i0_l0[Ol00ooonf[oo`1Aool0D@02
oaD0o`Cooo]Z00Go05gooa00ool@0?oo403oool0JP04oookJP;oT_l000?oo`3eoookJ_oonfX00_l6
0?l2oookJPCo0?m=0_l0j?l01Ooonf[o033oo`0`ool0<?oooo]Z00Oo0?na1?l0ok06oh;o00Kooo]Z
0_l0ok07oh;o00Ko0?n`0ooonfX2o`3o/@Co033o1?oonfX3o`3Xo`03oookJ_l0odgo0?m=00?ooo]Z
0_l60?l5oookJP;oT_l01ooonfX00ol@0?ooo`1Zool0JP02oookJP03o`0Ioooonf[ooo]Z00Gooo]Z
00?o5@3ooookJ_oo05400ooonfX01?l0[Ooooo]Zool0NOoo07T=oookJP03o`3oDooonf[ooo]Z00?o
oo]Z00Go0?lMo`3o2?oonf[ooo]Zo`3Qo`0AoookJP05o`3o=?oonf[ooo]Zo`3o;_l0odh0;?oonfX0
02_ooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ooo5P3ooi80oookJP05oookJP03ool0o?oonf[ooo]Z
00?ooo]Z00?o603oool60?oonfX01?oonfX00onDo`3oo`3foookJP02oookJP03o`2VoonX0?oooo]Z
00Cooo]Z00?oo`3ioookJ_nDo`000_oonfX01?ooK03o0?nJo`3oc?ooP@02oookJP03oc_o0?oonf[o
oo]Z00;ooo]Z00?o0?_ooookJ_oonfX00ooonfX02Ooo0`3ooo]ZoookJ_oonf[oo`3MoookJ_nco`3o
01Oooil0o`06oookJP03ool0Qooonf[ooo]Z00;ooo]Z00Coo`1/oookJ_oonf[ooo]Z1Ol0o``5oook
JP05on80ool0oi3ooo]ZoookJ_l0oi802OoonfX00omX0?oooo]ZoookJP02oookJP04oaP0ool0o`co
oo]ZonKo00;ooo]Z00?ooi00oookJ_oonfX02OoonfX00onDo`3ooo]ZonGo0003onGo00Oooo]Z00?o
oeL0oookJ_oonfX01_oonfX00ooo02gooo]ZoookJP07oookJP03oon10?oonf[ooo]Z00Wooo]Z00Go
0=CooookJ_oonf[o00CooookJP02o`2Yo`;ooo]Z0onDo`02o`3oCPGoU?l01_oonfX00ol0003o0>7o
o`000002o`3o7@03o`3o2?oonf[ooo]Z00;o0?mC2OoonfX01?oo07Wooo]Zo`2]oooonfX2ool0D@;o
5@3o0ooonfX01?oob@3o403ooa00ool@0?l6ooo900;oT_l00_oonfXBooo900?ooo]Z1on2o`02oook
JPKoolT03OoonfX8oh;o00Oo0?n`00?o0?nao`0`ool0<?l00_l0<?l2oookJP?o0>So0_l0odd4oook
JP;oiOl01OoonfX2oi;o0003onGo0?oonf[ooo]Z00?ooo]Z0_l@0?l2ool0JP03oookJ_l06Ooooo]Z
00Gooo]Z00?o5@3ooookJ_oo05401?oonfX2o`2]o`03oookJ_oo07Wooo]Z00_ooo]Z00?o0?mCoook
J_oonfX00ooonfX01Ol0oagooo]Zo`3o2?oonf[o0>7o017ooo]Z00Go0?ldoookJ_oonf[ooo]Zo`3o
301CoookJP03ool0j_oonf[ooo]Z00[ooo]Z00?ooaH0oonB0?oonfX01OoonfX00ooo0?cooo]Zoook
JP04oookJP03oaP0oooo1P3ooo]Z00?ooo]Z00?ojol0ool0m_oonfX00_oonfX00ol0Y_oooo]ZojP0
o`04oookJP03ool0nOoonf[o07Oo00;ooo]Z00Ooof`0o`3oV_oonf[o0?o<oon10?oonf[o>ol000Co
oo]Z00?o0?_ooookJ_oonfX00ooonfX02_oo0`3ooo]ZoookJ_oonf[oo`3MoookJ_l0Xooo/ol0oook
J_nO0?l5oookJP03omgo0?oo08Oooo]Z00;ooo]Z00Woo`1/oookJ_oonf[ooo]Zodd0oooonf[oobh0
of40ool0odD01_oonfX01?oR0?oooo]ZoookJ_l0oi89oookJP03ofP0oooonf[ooo]Z00?ooo]Z00?o
603ooookJ_oVo`000ooonfX00oooT03ooo]ZoookJP09oookJP05oonn0?oonf[ooo]Zon/0oom`0?l0
1ooonfX00oooE`3ooo]ZoookJP06oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooh40oookJ_oonfX0
2OoonfX01Ol0e?oooo]ZoookJ_l01?oooo]Z00;o0:Wo00?o08SooookJ_oonfX00ooonfX2o`3oCP03
o`3o=?oonf[ooo]Z00Oooo]Z00?o0000o`3Qool000000_l0oad01?l0o`Sooo]ZoookJ_oonfX2o`3o
D`Sooo]Z00Coo`1ioookJ_l0[Ooooo]Z0_oo0542oaD0o`?ooo]Z0_l0GOl2oa00o`;oo`1Z1?oonfX2
oi;o0003ool0mOoonf[ooo]Z00;o1P3o0_oonfX2o`3oC@?o0>So00Cooo]Zo`0`ool0<?oo033o1?l0
ok43oookJP03o`3o/?n2o`3oP_l000GoP_l05OoonfX8oh;o00Oo0?n`1?l0<?l3oookJP?o0>So0_l0
odd3oookJP;o1P3o1OoonfX2oi;o00Kooo]Z0_l@0?l3ool0JP03o`0Ioooonf[ooo]Z00Gooo]Z00?o
5@3oool0DOoonfX00ooonfX2o`2]o`03oookJ_oo07Wooo]Z00cooo]Z00?o0?mCoookJ_oonfX00ooo
nfX01Ol0oago0?l8oookJ_oonf[o0>7o017ooo]Z00Co0?ldoookJ_oonf[o0?m>;?oonfX002_ooo]Z
00?oo`3ZoookJ_oonfX02OoonfX00ooo5P3ooo]ZoonB0005oookJP03ool0o?oonf[ooo]Z00Cooo]Z
00?oo`H0oookJ_oonfX00ooonfX00onDo`3ooo]Zool0mP03oookJP03o`2VoonX0?oooo]Z00?ooo]Z
00?oo`3ioookJ_nDo`000_oonfX01oooK03o0?nJoookJ_l0olcooh40oookJ_lko`001OoonfX00ol0
nooooo]ZoookJP02oookJP09ool30?oonf[ooo]ZoookJ_oo0=goN@3ook?o0?l0XoooW`3o00Kooo]Z
00?oo`27omgo0?oonfX00ooonfX01?oo06cooo]ZoookJ_m=0?l5o`3o30Gooo]Z00GohP3ooookJ_oo
nf[ooo]Zo`3oTP08oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Co603oo`3o3?oonf[oi_l00_oonfX0
0oooT03ooo]ZoookJP0:oookJP03oonn0?oUo`3oiOl000?oiOl01_oonfX00oooE`3ooo]ZoookJP06
oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooh40oookJ_oonfX02OoonfX01ol0e?oooo]ZoookJ_l0
1?oooo]Zo`2Yool0R?l00ooonfX2oiCo0003o`3oC_nDo`3oU?l000GoU?l01_oonfX01?l0hOoo0?lM
o`3o7Ol0o`P3oookJP03o`3oDooonf[ooo]Z00Oooo]Z0_oo07T2o`2]o`;oo`1A0_lE0?l3oookJP04
o`1Mool@0?oo403oo`0Io`;oolT00ooonfX2oi;o00coolT000?ooo]Zo`0`ool0<?l01Ooob@06oh;o
00Wooo]Z1?oob@0GoookJPOoP_l00ol0ok02oookJPGo033o0_l0j?l2o`3oC@Cooo]Z0_oUo`02oook
JP?oiOl000?oT_l0onGo0?oonfX01OoonfX01Ol@0?oo05goool0J_oo06[o01Wo00Kooo]Z00?o5@3o
oookJ_oo05401OoonfX2o`2]o`03ool0NOoonf[ooo]Z00[ooo]Z00?o0?mCoookJ_oonfX00ooonfX0
1Ol0oagooo]Zo`3o2?oonf[o0>7o017ooo]Z00Co0?ldoookJ_oonf[o0?l<DooonfX00ooo0>[ooo]Z
oookJP09oookJP03oolF0?oonf[ooi8000Gooo]Z00?oo`3loookJ_oonfX01OoonfX00ooo1P3ooo]Z
oookJP02oookJP03on_o0?oonf[oo`3f00?ooo]Z00?o0:KooookJ_nX0?l00ooonfX00ooo0?Wooo]Z
o`1go`03oookJP06oom/0?oonf[ooo]Zo`3oc?ooP@3o>ol01OoonfX00ol0nooooo]ZoookJP02oook
JP0:ool30?oonf[ooo]ZoookJ_oo0=goN@3ooookJ_nco`3o01Oooil0o`Kooo]Z00?oo`27oookJ_oo
nfX00_oonfX02Ooo06cooo]ZoookJ_oonf[oC@3oool^0?oonf[oH@3oo`3oA@05oookJP05on80oooo
nf[ooo]ZoookJ_l0oi802?oonfX00omX0?oooo]ZoookJP03oookJP03oaP0oooonf[oi_l000?ooo]Z
00?ooi00oookJ_oonfX02_oonfX01?oo_P3ooo]ZoookJ_o[0?l8oookJP03oomG0?oonf[ooo]Z00Go
oo]Z00?oo`0]oookJ_oonfX01ooonfX00oooP@3ooo]ZoookJP09oookJP08o`3Doooonf[ooo]Zo`04
oooonf[o0:WooookJ_l0R?l5oookJP03o`3oC_oonf[o0?ld00[ooo]Z00?o0>7oo`3o7Ol0oad00_l0
o`P3oookJP03o`3oDooonf[ooo]Z00Kooo]Z0_oo07T2o`2]o`;oo`1A0_lE0?l3oookJP;o05go0_l@
0?l2ool0JP?ooo]Z0onBo`000ooo0?Gooo]Zo`H0o`02o`H0o`04oookJ_l0odgo0?m=o`3oC@;o0>So
00Cooo]Zo`0`ool0<?oo033o0_l0ok43oookJPKoP_l09?oonfX7oh;o00?o0?n`00?ooo]Zo`0`ool0
<?l00ol0<?l00ooonf[o0>Soo`3Xo`02o`3oC@?ooo]Z0_l60?l5oookJP;oT_l01_oonfX01Ol@0?oo
05gooookJ_oo06[o01Wo00Oooo]Z00?o5@3oool0DOoonfX01?oonfX2o`2]o`03ool0NOoonf[ooo]Z
00_ooo]Z00?o0?mCoookJ_oonfX00ooonfX01Ol0oago0?l8oookJ_oonf[o0>7o017ooo]Z00Co0?ld
oookJ_oonf[o0?m>:ooonfX002_ooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ooo5P3ooi80oookJP05
oookJP03ool0o?oonf[ooo]Z00?ooo]Z00?o603oool60?oonfX01?oonfX00onDo`3oo`3foookJP03
oookJP03o`2VoonX0?oooo]Z00;ooo]Z00?oo`3ioookJ_nDo`000ooonfX01?ooK03o0?nJo`3oc?oo
P@02oookJP03oc_o0?oonf[ooo]Z00;ooo]Z00?o0?_ooookJ_oonfX00_oonfX00ooo0`3ooo]Zoook
JP02oookJP05ool0gOoonf[o/ol0o`0GoonO0?l01OoonfX00ooUo`3ogOl0oookJP03oookJP04ool0
K?oonf[ooo]ZoookJPGo0?l<1OoonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Sooo]Z00?oJ03ooook
J_oonfX00_oonfX01?lH0?oooo]Zo`3o3?oVo`02oookJP03oon@0?oonf[ooo]Z00[ooo]Z00?ookh0
onGo0?oUo`000ooUo`06oookJP03oomG0?oonf[ooo]Z00Kooo]Z00?oo`0]oookJ_oonfX01ooonfX0
0oooP@3ooo]ZoookJP09oookJP07o`3Doooonf[ooo]Zo`04oooonf[o0:Woo`28o`05oookJP03o`3o
C_nDo`3oU?l000GoU?l01_oonfX01_l0hOoo0?lMo`000?l0o`So0000oookJP;o0?mC2?oonfX2ool0
N@;o0:go00Cooo]Zool0DOlE0?oo5@3o1?oonfX00ol0GOoo403oo`0Io`02ooo900?ooo]Z00?oT_l0
ooo90?oob@002ooob@03o`0`o`03o`3o/On2o`3oolT000;oolT00_n2o`000ol0ok3ooo]ZoookJP02
oookJR3o0?mK0onDo`09oookJPGoP_l01OoonfX4o`0`o`;o0?m=00Co0>SooookJ_oonf[ooo]Z1_oU
o`02oi;o00Kooo]Z0_l@0?l2oookJP03o`0Ioooonf[ooo]Z00Cooo]Z0_lE0?l00ooo057ooo]Zoook
JP04oookJP03o`2]oooo07Woo`1i00_ooo]Z00?o0?mCoookJ_oonfX00ooonfX01Ol0oagooo]Zo`3o
2?oonf[o0>7o017ooo]Z00Co0?ldoookJ_oonf[o0?l<D_oonfX00ooo0>[ooo]ZoookJP09oookJP03
oolF0?ooTP3ooo]Z00Gooo]Z00?oo`3loookJ_oonfX01?oonfX00olH0?ooo`H0oookJP03oookJP03
on_o0?oo0?Kooo]Z00?ooo]Z00?o0:KoojP0oooonfX00ooonfX00ooo0?Wo07OooookJP02oookJP07
oom/0?l0oi[ooo]Zo`3oc?ooP@3ooo]Zoc_o0004oookJP03o`3koooonf[ooo]Z00;ooo]Z00?oo`<0
oookJ_oonfX00_oonfX01Ooo0=gooo]Zo`2Soonco`3oW`3o00Kooo]Z00?oo`27oookJ_oonfX00_oo
nfX02Ooo06cooo]ZoookJ_oonf[oC@3ooookJ_oo;P3oH@3oo`3oA@05oookJP05on80ool0oi3ooo]Z
oookJ_l0oi802?oonfX00omX0?oooo]ZoookJP03oookJP04oaP0ool0M?oooo]ZonKo00;ooo]Z00?o
oi00oookJ_oonfX02_oonfX01Ooo_P3ooo]ZoookJ_o[0?ooL03o00Oooo]Z00?ooeL0oookJ_oonfX0
1OoonfX00ooo02gooo]ZoookJP07oookJP03oon10?oonf[ooo]Z00Wooo]Z00So0=CooookJ_oonf[o
00CooookJ_l0ZOoooo]Zo`28o`Gooo]Z00?o0?m>oookJ_l0oc@02_oonfX01Ol0hOoo0?lMo`000?l0
o`So000000;ooo]Z0_l0oe<7oookJP;oo`1i00Cooo]Zo`2]oooonf[oo`1A0_lE0?l4oookJP03o`1M
ool06Ooo403o00;oo`1Z0ooonfX2oi;o0003ool0mOoonf[ooo]Z00;o1P3o0_oonfX2o`3oC@;o0>So
00Cooo]Zo`0`ool0<?oo033o0_l0ok46oh;o00Cooo]Z8ol0oe/:oookJPGoP_l01?oonfX4o`0`o`04
oookJ_l0odgo0?m=o`3Xo`;ooo]Z0ol60?l4oookJP;oT_l01OoonfX2oa00o`04o`1Moooonf[o01Wo
ool0JPKooo]Z00?o5@3oool0DOoonfX01OoonfX00ol0[Oooo`1iool0N@0<oookJP03o`3oDooonf[o
oo]Z00?ooo]Z00Go0?lMo`3o2?oonf[ooo]Zo`3Qo`0AoookJP04o`3o=?oonf[ooo]Zo`3oCR[ooo]Z
000ZoookJP03ool0j_oonf[ooo]Z00Wooo]Z00?ooaH0oookJ_ooTP001OoonfX00ooo0?cooo]Zoook
JP04oookJP03oaP0oooo1P3ooo]Z00?ooo]Z00?oU?l0oookJ_oo0?H00ooonfX00ol0Y_ooZ03ooook
JP03oookJP03ool0nOoonf[oU?l000?ooo]Z00Koof`0oookJ_l0olcooh40oookJ_lko`05oookJP03
o`3koooonf[ooo]Z00;ooo]Z00Woo`<0oookJ_oonf[ooo]Zool0gOmi0?oo/ol0o`2SoonO0?l01_oo
nfX00ooUo`3ogOl0oookJP03oookJP03ool0K?oonf[ooo]Z00Ko0?l<1?oonfX01OoR0?oo0?n@oook
J_oonf[o0?nB00Sooo]Z00?oJ03ooookJ_oonfX00_oonfX01?lH0?oooo]Zo`3o3?oVo`03oookJP03
oon@0?oonf[ooo]Z00Wooo]Z00?ookh0onGo0?oUo`001?oUo`05oookJP03oomG0?oonf[ooo]Z00Ko
oo]Z00?oo`0]oookJ_oonfX01ooonfX00oooP@3ooo]ZoookJP09oookJP07o`3Doooonf[ooo]Zo`04
oooonf[o0:Woo`28o`05oookJP03o`3oC_l0obkoU?l000GoU?l01_oonfX2o`3o7@05o`000?l0o`So
0000o`000?l0oe<02OoonfX01?oo07Wooo]Zo`2]oooonfX2ool0D@03oaD0oooonf[ooo]Z00;ooo]Z
00?o05gooa00ool@0?l00_oob@02oookJP?oT_l000?oo`3eooo90?oob@002Ooob@02o`0`o`CoP_l0
0_l0ok0Booo900Oo<Ol04ooonfX3oiCo00Wooo]Z0_nDo`02oh;o00Kooo]Z00?o0?nao`0`ool0<?l0
0_l0odd2o`3Xo`03oookJ_oUo`3oiOl000GoiOl00_nBo`06oookJP04oa00ool0GOoooo]Zo`0Io`Oo
oo]Z00?o5@3oool0DOoonfX01OoonfX00ooUo`3ooo]Zool0N@0;oookJP03o`3oDooonf[ooo]Z00?o
oo]Z00Co0?lMoookJ_l0o`So0>7o4OoonfX01Ol0ocCooo]ZoookJ_oonf[o0?l<053ooo]Z00?oo`3Z
oookJ_oonfX02OoonfX00ooo5P3ooo]ZoonB0005oookJP03ool0o?oonf[ooo]Z00Gooo]Z00?o603o
ool60?oonfX00_oonfX00oo[o`3ooo]Zool0mP03oookJP03o`2Voooonf[oZ03o00?ooo]Z00?oo`3i
oookJ_l0Mol00ooonfX01_ooK03ooo]ZoookJ_ooP@3ooo]Zoc_o00Gooo]Z00?o0?_ooookJ_oonfX0
0_oonfX02_oo0`3ooo]ZoookJ_oonf[oo`3MogT0oooonf[o/ol0o`0GoonO0?l6oookJP03ool0Qooo
nf[ooo]Z00;ooo]Z00Woo`1/oookJ_oonf[ooo]Zodd0oooo;P3ooo]Zof40ool0odD01OoonfX01?oR
0?oooo]ZoookJ_l0oi88oookJP03ofP0oooonf[ooo]Z00?ooo]Z00Co603oo`1doooonf[oi_l00ooo
nfX00oooT03ooo]ZoookJP09oookJP05oonn0?oonf[ooo]Zon/0oom`0?l01ooonfX00oooE`3ooo]Z
oookJP05oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooh40oookJ_oonfX02OoonfX02?l0e?oooo]Z
oookJ_l01?oooo]Zo`2Yoooonf[o08So1OoonfX00ol0odkooo]Zo`3o=00:oookJP;o0?lM00?o0000
o`3o2?l000000_l000000ol0oe?ooo]ZoookJP06oookJP04ool0NOoonf[o0:goo`2]o`;oo`1A00?o
5@3ooookJ_oonfX00_oonfX2o`1Mo`;o403o00?oo`1ZoookJ_oonfX00onBo`000ooo0?Gooo]Zoook
JP02o`H0o`;ooo]Z0_l0odd00ol0j?oooo]Zo`0`o`02o`0`o`03o`3o/On2o`3oP_l000;oP_l00_l0
ok05oookJP?o0?mK1_oonfX;oc7o01;ooo]Z0ol0oe/<oookJP;oP_l01OoonfX01?l0ok7o033oo`0`
ool0<?l2o`3oC@;o0>So0_oonfX2o`H0o`?ooo]Z00?oo`3eoi;o0?oonfX01OoonfX01Ol@0?oo05go
o`1Mool06Oooo`1Z00Oooo]Z00?oo`1AoookJ_oonfX01?oonfX00ol0[Ooooo]Zool0N@0<oookJP03
o`3oDooonf[ooo]Z00?ooo]Z00Co0?lMo`3o2?oonf[o0>7o4OoonfX01?l0ocCooo]ZoookJ_l0odhZ
oookJP00=_oonfX00ooo5P3ooi80oookJP05oookJP03ool0o?oonf[ooo]Z00?ooo]Z00?o603oool6
0?oonfX01?oonfX00onDo`3oo`3foookJP03oookJP03o`2VoonX0?oooo]Z00;ooo]Z00?oo`3ioook
J_nDo`000ooonfX01?ooK03o0?nJo`3oc?ooP@02oookJP03oc_o0?oonf[ooo]Z00;ooo]Z00?o0?_o
oookJ_oonfX00_oonfX00ooo0`3ooo]ZoookJP02oookJP05ool0gOoonf[o/ol0o`0GoonO0?l01Ooo
nfX2onGo00Cooo]Z00?oo`1/oookJ_oonfX01ol0o``4oookJP05on80oooonf[ooo]ZoookJ_l0oi80
2?oonfX00omX0?oooo]ZoookJP02oookJP04oaP0ool0o`cooo]ZonKo00;ooo]Z00?ooi00oookJ_oo
nfX02_oonfX7onGo00Gooo]Z00?ooeL0oookJ_oonfX01OoonfX00ooo02gooo]ZoookJP07oookJP03
oon10?oonf[ooo]Z00Wooo]Z00Oo0=CooookJ_oonf[o00CooookJ_l0ZOoo08So00Gooo]Z00Co0?m>
oookJ_nDo`3ooo]Z1OnDo`04oookJP03o`3Qool0oagooo]Z00;o0?l800?o0000o`3oDol0oe<02?oo
nfX2ool0N@;o0:go00?ooo]Zool0DOlE0?l01OoonfX2oa00o`;oolT00_oonfX2oi;o0005ool0mOoo
nf[ooo]ZoookJ_l60?l02Ooob@000ol0ok7oP_l0oh;o0003o`3o/0Cooo]Z3ooob@09oookJPoo<Ol0
1ooonfX3oiCo00Kooo]Z0onDo`001?oonf[oP_l0oh;o0?l0ok04oookJP;o0?na00Cooo]Zo`0`ool0
odgo0?m=0ol0j?l7onGo00;oT_l01OoonfX00ol@0?oo05gooookJP02o`0Io`Kooo]Z00?o5@3oool0
DOoonfX01?oonfX00ooUo`3ooo]ZoookJP02ool0N@[ooo]Z00?o0?mCoookJ_oonfX00ooonfX01?l0
oagooo]Zo`3o2?l0hOlAoookJP04o`3o=?oonf[ooo]Zo`3o35cooo]Z00?ooaH0oonB0?oonfX01Ooo
nfX00ooo0?cooo]ZoookJP04oookJP03oaP0oooo1P3ooo]Z00?ooo]Z00?ojol0ool0m_oonfX00ooo
nfX00ol0Y_oooo]ZojP0o`03oookJP03ool0nOl0Mooooo]Z00;ooo]Z00Ooof`0o`3oV_oonf[o0?o<
oon10?oonf[o>ol000Cooo]Z00?o0?_ooookJ_oonfX00_oonfX00ooo0`3ooo]ZoookJP02oookJP05
ool0gOoonf[o0:?ook?o0?nO0?l01_oonfX00ooo08Oooo]ZoookJP02oookJP09ool0K?oonf[ooo]Z
oookJ_m=0?oooo]Zool^0?mQ0?oo0?m500Gooo]Z00GohP3ooookJ_oonf[ooo]Zo`3oTP08oookJP03
ofP0oooonf[ooo]Z00?ooo]Z00?o603ooookJ_oVo`000ooonfX00oooT03ooo]ZoookJP0:oookJP04
oonn0?oonf[o0?l5on/0o`Oooo]Z00?ooeL0oookJ_oonfX01OoonfX00ooo02gooo]ZoookJP07oook
JP03oon10?oonf[ooo]Z00Wooo]Z00So0=CooookJ_oonf[o00CooookJ_l0ZOoooo]Zo`28o`Gooo]Z
00?o0?m>oookJ_l0oc@02_oonfX01?l0oagooo]ZoookJ_l0o`P2o`0000;o0?mC1ooonfX2ool0N@05
oookJ_l0[Ooooo]Zool0DOlE0?l01OoonfX01?l0GOoo403ooa00oooo06X2oookJP;oT_l00_oo0?D2
oookJP;o1P3o00Cooo]Zo`3oCOl0odgo0?m=0_oonfX2o`0`o`04o`3o/Ol0ok3oP_l0oh;o00;o0?n`
1_oonfX3o`3oF`Gooo]Z1?lao`0;oookJPoo<Ol01_oonfX3o`3oF`_ooo]Z0_n2o`001?l0ok3ooo]Z
oookJ_oonfX2o`3o/@03oookJ_l0<?oooo]Z00;o0?m=0ol0j?l00ooonf[o1P3oo`H0o`03oookJP;o
T_l01OoonfX00ol@0?oooo]Zo`1Mo`02o`0Io`Oooo]Z00?oo`1AoookJ_oonfX00ooonfX00ol0[Ooo
oo]ZoookJP02ool0N@_ooo]Z00?o0?mCoookJ_oonfX00_oonfX01Ol0oagooo]Zo`3o2?oonf[o0>7o
017ooo]Z00Co0?ldoookJ_oonf[o0?m>:OoonfX003Kooo]Z00?ooaH0oonB0?oonfX01OoonfX00ooo
0?cooo]ZoookJP03oookJP03oaP0oooo1P3ooo]Z00?ooo]Z00?oU?l0oookJ_oo0?H00ooonfX00ol0
Y_ooZ03ooookJP03oookJP03ool0nOoonf[oU?l000?ooo]Z00Koof`0oookJ_l0olcooh40oookJ_lk
o`05oookJP03o`3koooonf[ooo]Z00;ooo]Z00Woo`<0oookJ_oonf[ooo]Zool0gOmi0?oooo]Zok?o
0?nO0?l01OoonfX3onGo00Cooo]Z00?oo`1/oookJ_l0o``01ol0o``3oookJP05on80ool0oi3ooo]Z
oookJ_l0oi802?oonfX00omX0?oooo]ZoookJP02oookJP04oaP0ool0o`cooo]ZonKo00;ooo]Z00?o
oi00oookJ_oonfX02_oonfX7onGo00Gooo]Z00?ooeL0oookJ_oonfX01OoonfX00ooo02gooo]Zoook
JP07oookJP03oon10?oonf[ooo]Z00Wooo]Z00Co0=CooookJ_oonf[o00Co0_oUo`000ol0R?oooo]Z
oookJP02oookJP;o0?m>00?ooo]ZoiCo0?oonfX00_oonfX3oiCo00Cooo]Z00Oo0>7oo`3o7Ooonf[o
0?l8oookJ_l0003o0?mC00;o00001_oonfX2ool0N@06oookJ_l0[Ooooo]ZoookJ_oo057o5@3o1?oo
nfX00ol06Ooo403oooo90002oookJP?oT_l000?oo`3eoookJ_oonfX00ol60?l9ooo900;oP_l01ooo
nfX2o`3oF`goolT06_oonfX8oc7o00;ooo]Z0onDo`03oookJPGoU?l000Cooo]Zoh;o0?n2o`3o0?n`
1?oonfX2o`3o/@;o033o0ol0odd00ol0j?ooiOl0onGo0006onGo0003oi;o0?oo0?Gooo]Z00?ooo]Z
0_l@0?l00ol0GOooo`1Zo`0Io`06oookJP03oaD0oooo057ooo]Z00Cooo]Z00GoiOl0oookJ_oonf[o
oo]Zool0N@0:oookJP03o`3oDooonf[ooo]Z00?ooo]Z00Co0?lMoookJ_m4o`3o0>7o4OoonfX01?l0
ocCooo]ZoookJ_l0o`aKoookJP03oolF0?ooTP3ooo]Z00Gooo]Z00?oo`3loookJ_oonfX01?oonfX0
0olH0?ooo`H0oookJP02oookJP03on_o0?oonf[oo`3f00?ooo]Z00?o0:KooookJ_nX0?l00ooonfX0
0ooo0?Wooo]Zo`1go`03oookJP06oom/0?oonf[ooo]Zoon10?oonf[o>ol01OoonfX00ol0nooooo]Z
oookJP02oookJP0:ool30?oonf[ooo]ZoookJ_oo0=goN@3ooookJ_nco`3o01Oooil0o`Gooo]Z00?o
gOl0ool0QooonfX00ooonfX02?oo06cooo]ZoookJ_oonf[oC@3oool^0?mQ0?oo0?m51OoonfX01OoR
0?oo0?n@oookJ_oonf[o0?nB00Sooo]Z00?oJ03ooookJ_oonfX00ooonfX01?lH0?oooo]ZoookJ_oV
o`02oookJP03oon@0?oonf[ooo]Z00[ooo]Z00Gookh0oookJ_l0o`Goj`3oog00o`07oookJP03oomG
0?oonf[ooo]Z00Cooo]Z00?oo`0]oookJ_oonfX01ooonfX00oooP@3ooo]ZoookJP09oookJP08o`3D
oooonf[ooo]Zo`04oooonf[o0:WooookJ_l0R?l4oookJP;o0?m>00?ooo]Zo`3o=?oonfX02OoonfX0
1?l0oagooo]Zo`3o2?l0o`P2o`000003o`3oDol0003ooo]Z00Gooo]Z0_oo07T01_oonf[o0:goo`2]
oooonf[oo`1AoaD0o`Cooo]Z00?o05goo`0Iool@0?l00_oonfX3oi;o00;oo`3e0_oonfX2o`H0o`03
o`3Xool0odgo0?m=00;ooo]Z0ol0<?l01?l0ok3oP_l0oh;o0?n2o`06oookJPCo0?mK0ooonfX5oc7o
01kooo]Z2?lao`001?oonf[o0?mKo`3oFol0oe/:oookJP;oP_l000Co0?n`oookJ_oonf[ooo]Z0_l0
ok42o`0`o`05oookJ_l0odgo0?m=oookJ_l0j?l00_oonfX2o`H0o`?ooo]Z0_nBo`04oookJP;o403o
0_l0GOl00ol06Ooooo]ZoookJP05oookJP03ool0DOoonf[ooo]Z00?ooo]Z00Go0:gooookJ_oonf[o
oo]Zool0N@0;oookJP03o`3oDooonf[ooo]Z00;ooo]Z00Go0?lMoookJ_l0o`Sooo]Zo`3Qo`0Aoook
JP04o`3o=?oonf[ooo]Zo`3oCRSooo]Z000eoookJP03oolF0?ooTP3ooo]Z00Gooo]Z00?oo`3loook
J_oonfX00ooonfX00olH0?oooo]Zool60004oookJP03oiCo0?oo0?Kooo]Z00?ooo]Z00?o0:KoojP0
oooonfX00_oonfX00ooo0?Wooo]ZoiCo0003oookJP06oom/0?l0oi[o0?o<oon10?oonf[o>ol01Ooo
nfX00ol0nooooo]ZoookJP02oookJP03ool30?oonf[ooo]Z00;ooo]Z00Coo`3MoookJ_nco`3oW`3o
1OoonfX3onGo00Cooo]Z00?oo`1/oookJ_l0o``02?l0o``2oookJP05on80ool0oi3ooo]ZoookJ_l0
oi802?oonfX00omX0?oooo]ZoookJP03oookJP03oaP0ool0M?ooi_l000;ooo]Z00?ooi00oookJ_oo
nfX02_oonfX8onGo00Cooo]Z00?ooeL0oookJ_oonfX01OoonfX00ooo02gooo]ZoookJP07oookJP03
oon10?oonf[ooo]Z00Wooo]Z00Co0=CooookJ_oonf[o00Co0ooUo`04oookJP04o`3oC_l0obkooo]Z
oiCo00Gooo]Z00?oU?l0oookJ_oonfX00_oonfX01Ol0hOoo0?lMoookJ_l0o`Sooo]Z00;o0?mC0ol0
0005oookJP05ool0NOoonf[o0:goo`2]oooonfX00_oo0544oookJP03o`0Iool@0?oo403o00;ooo]Z
0_nBo`02ool0m@;ooo]Z0_l60?l00ooonf[oolT0ooo90002oookJPKoolT01ooonfX3o`3oF`?ooo]Z
2_oob@0ToookJP?o<Ol00_oonfX:oiCo0003oookJ_n2o`3oP_l000;o0?n`0ooonfX00ol0ok7oiOl0
onGo0002onGo00;o0?m=2?oUo`02oi;o0003ool0mOoonf[ooo]Z00;ooo]Z00Co403oo`1Moooo06[o
01Wo1_oonfX00olE0?ooo`1AoookJP04oookJP05onGo0?oonf[ooo]ZoookJ_oo07T02_oonfX00ol0
oe?ooo]ZoookJP02oookJP05o`3o7Ooonf[oA?l0oookJ_l0hOl04OoonfX01?l0ocCooo]Zo`3o3?l0
obiIoookJP03oolF0?ooTP3ooo]Z00Gooo]Z00?oo`3loookJ_oonfX01?oonfX00olH0?ooo`H0oook
JP03oookJP03on_o0?oo0?Kooo]Z00?ooo]Z00?o0:KooookJ_nX0?l00_oonfX00ooo0?Wooo]Zo`1g
o`03oookJP06oom/0?l0oi[ooo]Zo`3oc?ooP@3o>ol01OoonfX00ol0nooooo]ZoookJP02oookJP03
ool30?oonf[ooo]Z00;ooo]Z00Goo`3MoookJ_l0Xooo/ol0oil0o`06oookJP03ool0Qooonf[ooo]Z
00;ooo]Z00Woo`1/oookJ_oonf[ooo]Zodd0oooonf[oobh0of40ool0odD01OoonfX01?oR0?oooo]Z
oookJ_l0oi88oookJP03ofP0oooonf[ooo]Z00Cooo]Z00?o603ooookJ_oVo`000_oonfX00oooT03o
oo]ZoookJP0:oookJP05oonn0?oonf[ooo]Zon/0oom`0?l01ooonfX00oooE`3ooo]ZoookJP04oook
JP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooh40oookJ_oonfX02OoonfX01?l0e?oooo]ZoookJ_l01?l2
oookJP03o`2Yool0R?oooo]Z00?ooo]Z00Co0?m>o`3o;_oonf[o0?ld2OoonfX01?l0hOoo0?lMoook
J_l0o`P2oookJP;o0?mC0_l00005oookJP05ool0NOoonf[ooo]Zo`2]oooonfX00_oo0545oookJP04
o`0Iool@0?oo403ooookJP;oT_l00ooo0?D2oookJP;o1P3o00Co0>Soo`3oCOl0odgooo]Z0ol0<?l0
1?l0ok7o0?n`oh;o0?n2o`06oookJP?o0?mK0ooonfX4oc7o02_ooo]Z0olao`000ooonf[o0?mKo`3o
F`02o`3oF`Sooo]Z0_n2o`001ol0ok3ooo]ZoookJ_oonf[o0?naoookJ_l0<?l00_oonfX2o`3oC@04
o`3Xoooonf[ooo]ZoookJP;o1P3o0ooonfX2oi;o00Cooo]Z00Co403ooookJ_l0GOoo01Wo1ooonfX0
0ooo057ooo]ZoookJP03oookJP05o`2]oooonf[ooo]ZoookJ_oo07T02ooonfX00ol0oe?ooo]Zoook
JP02oookJP04o`3o7Ol0o`Sooo]Zo`3Qoa;ooo]Z00Co0?ldoookJ_l0odko0?l^9ooonfX003Gooo]Z
00?ooaH0oonB0?oonfX01OoonfX00ooo0?cooo]ZoookJP03oookJP03oaP0oooo1P3ooo]Z00?ooo]Z
00?oU?l0oookJ_oo0?H00ooonfX00ol0Y_oooo]ZojP0o`03oookJP03ool0nOoonf[oU?l000?ooo]Z
00Koof`0oookJ_l0olcooh40oookJ_lko`05oookJP03o`3koooonf[ooo]Z00;ooo]Z00Goo`<0oook
J_oonf[ooo]Zool0g@02oookJP03ok?o0?nO0?oooo]Z00Cooo]Z0ooUo`03oookJP05ool0K?oonf[o
oo]ZoookJ_m=0?l01_l0o``3oookJP04on80oooonf[ooo]Zo`3oTPWooo]Z00?oJ03ooookJ_oonfX0
0_oonfX01?lH0?oo07CooookJ_oVo`02oookJP03oon@0?oonf[ooo]Z00Wooo]Z2OoUo`04oookJP03
oomG0?oonf[ooo]Z00Cooo]Z00?oo`0]oookJ_oonfX01_oonfX2onGo00_ooo]Z00Co0=CooookJ_oo
nf[o00Co0ooUo`04oookJP04o`3oC_l0obkooo]ZoiCo00[ooo]Z00Oo0>7oo`3o7Ol0o`So0?l8oook
J_l0oe?ooo]Z00Co00000ooonfX2ool0N@;o0:go00?ooo]ZoaD0oooo05401OoonfX2oa00o`?ooo]Z
00?oT_l0ool0mOoonfX00_oonfX2o`H0o`04oookJ_oob@3oolT0oookJP?o033o1?oob@06oookJP?o
0?mK0_oonfX<ooo902Wooo]Z0_lao`02oookJPWoU?l00_oonfX2oh;o00;o0?n`0_oonfX2o`3o/@;o
033o0_oUo`02o`3oC@OoiOl000Cooo]Zoi;o0?nBo`3oo`3e0ooonfX2oa00o`03ool0J_l06Ooooo]Z
00Gooo]Z00?o5@3oool0DOoonfX01?oonfX01OoUo`3ooo]ZoookJ_oonf[oo`1i00[ooo]Z00?o0?mC
oookJ_oonfX00_oonfX01?l0oagooo]ZodCo0?l0hOlBoookJP04o`3o=?oonf[o0?l<o`3o;USooo]Z
00?ooaH0oonB0?oonfX01OoonfX00ooo0?cooo]ZoookJP04oookJP03oaP0oooo1P3ooo]Z00;ooo]Z
00?ojol0oookJ_oo0?H00ooonfX00ol0Y_oooo]ZojP0o`03oookJP03ool0nOoonf[o07Oo00?ooo]Z
00Koof`0oookJ_oonf[ooh40oookJ_lko`05oookJP03o`3koooonf[ooo]Z00;ooo]Z00Goo`<0oook
J_oonf[ooo]Zool0g@02oookJP03ok?o0?l05oooW`3o00Gooo]Z00?o0?oNool0QooonfX00ooonfX0
2?oo06cooo]ZoookJ_m=0?oooo]Zool^0?mQ0?oo0?m51OoonfX01?oR0?oooo]ZoookJ_l0oi89oook
JP03ofP0oooonf[ooo]Z00?ooo]Z00?o603ooookJ_oVo`000ooonfX00oooT03ooo]ZoookJP0:oook
JP04oonn0?oonf[o0?l5on/0o`Oooo]Z00?ooeL0oookJ_oonfX01?oonfX00ooo02gooo]ZoookJP07
oookJP03oon10?oonf[ooo]Z00Wooo]Z00Co0=CooookJ_oonf[o00Co0_oonfX00ol0ZOoo08Sooook
JP03oookJP04o`3oC_l0obko0?ldo`3o=0Wooo]Z00Co0>7oo`3o7Ooonf[o0?l80_oonfX00ol0oe?o
0000o`000002o`0000?ooo]Z0_oo07T01Ooonf[o0:goo`2]oolE0?ooo`1A00Gooo]Z00?o01Wooa00
ool@0?l00_oonfX00onBo`3oo`3eool0m@03oookJP;o1P3o0ol0odd3o`0`o`;o0?na00?o0?n`oh;o
0?n2o`001OoonfX3o`3oF`;ooo]Z1?lao`0boookJP;o<Ol00ooonfX3o`3oF`Oooo]Z0_n2o`02o`3o
/003oookJ_l0ok7o0?na00;o033o0_oonfX2o`3oC@04o`3Xoooonf[ooo]ZoookJP;o1P3o0ooonfX2
oi;o00?ooo]Z0_l@0?l00ol0GOoo01WooookJP06oookJP03ool0DOlE0?oooo]Z00?ooo]Z00Go0:go
oookJ_oonf[ooo]Zool0N@0;oookJP03o`3oDooonf[ooo]Z00;ooo]Z00Co0?lMo`3o2?oonf[o0>7o
4_oonfX00ol0ocCooo]Zo`3oCP0WoookJP00=?oonfX00ooo5P3ooi80oookJP05oookJP03ool0o?oo
nf[ooo]Z00?ooo]Z00?o603ooookJ_oo1P001?oonfX00onDo`3oo`3foookJP03oookJP03o`2VoonX
0?oooo]Z00;ooo]Z00?oo`3ioookJ_nDo`000ooonfX01_ooK03o0?nJo`3oc?ooP@3ooo]Zoc_o00Go
oo]Z00?o0?_ooookJ_oonfX00_oonfX00ooo0`3ooo]ZoookJP02oookJP04ool0gOoonf[o/ol0oil0
o`Gooo]Z1?oUo`03oookJP08ool0K?oonf[ooo]Zodd0oooo;P3ooo]Zo`3o3?l0odD3o`3o30;ooo]Z
00GohP3oo`3oT?oonf[ooo]Zo`3oTP08oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Co603ooookJ_l0
M?ooi_l00_oonfX00oooT03ooo]ZoookJP09oookJPWoiOl01?oonfX00oooE`3ooo]ZoookJP04oook
JP03ool0;Ooonf[ooo]Z00Kooo]Z0ooUo`0:oookJP04o`3Doooonf[oiOl0o`04o`CoiOl00ooonfX0
1?l0odko0?l^oookJ_nDo`0:oookJP03o`3Qool0oago0?l800;ooo]Z00?o0?mCoookJ_oonfX01?l0
00001ooonf[oo`1iool0NOoonf[o0:gooookJ_lE0?l00_oo0544oookJP03o`0Iool@0?oooo]Z00;o
oo]Z0_nBo`03oookJP;o1P3o0ooob@03o`0`o`;o0?na00Cooo]Zooo90?oob@3oolT00ooonfX4o`3o
F`GoolT01?oonfX6ooo902gooo]Z0olao`0:oiCo00;ooo]Z0_n2o`03o`3o/004oookJ_l0ok7ooo]Z
o`0`o`?ooo]Z0_l0odd6onGo00;ooo]Z0_nBo`001ooo0?Gooo]ZoookJ_oonf[o403oool0J_l06Ol0
1ooonfX00ooo057ooo]ZoookJP02oookJP05onGo0?oonf[ooo]ZoookJ_oo07T02ooonfX00ol0oe?o
oo]ZoookJP02oookJP04o`3o7Ooonf[oA?l0o`3Qoa7ooo]Z00Co0?ldoookJ_oonf[o0?l<EooonfX0
0ooo5P3ooi80oookJP05oookJP03ool0o?oonf[ooo]Z00Cooo]Z00?o603ooookJ_oo1P000ooonfX0
0oo[o`3oo`3foookJP03oookJP03o`2Voooonf[oZ03o00;ooo]Z00?oo`3ioookJ_l0Mol01?oonfX0
1OooK03ooo]Zo`3oc?ooP@3o>ol000Gooo]Z00?o0?_ooookJ_oonfX00_oonfX00ooo0`3ooo]Zoook
JP02oookJP05ool0gOoonf[o0:?ook?o0?nO0?l01_oonfX00ooo08Oooo]ZoookJP02oookJP08ool0
K?oonf[ooo]ZoookJ_m=0?ooobh0oookJ_mQ0?l5oookJP05on80ool0oi3ooo]ZoookJ_l0oi802?oo
nfX00omX0?oooo]ZoookJP03oookJP04oaP0ool0M?oooo]ZonKo00;ooo]Z00?ooi00oookJ_oonfX0
2_oonfX01Ooo_P3ooo]Zo`3o1Oo[0?ooL03o00Kooo]Z00?ooeL0oookJ_oonfX01?oonfX00ooo02go
oo]ZoookJP08oookJP03oon10?oonf[ooo]Z00Sooo]Z00Co0=CooookJ_oonf[o00Co0_oonfX00ol0
ZOoo08SooookJP03oookJP03o`3oC_oonf[o0?ld00[ooo]Z00Co0>7oo`3o7Ooonf[o0?l80_oonfX0
0ol0oe?ooo]Zo`000003o`000003oookJ_oo07Woo`1i00;ooo]Z00Co0:gooaD0oooo057oo`1A1?oo
nfX00ooo06[o01Wooa00o`02oookJP;oT_l000?oo`3eoookJ_oonfX00ol60?l2o`3oC@?o033o0ol0
ok43oh;o00?ooo]Z1?l0oe/5oc7o03Sooo]Z0olao`03oookJP?o0?mK1_oonfX2oh;o00;o0?n`00Co
oo]Zo`3o/Ooonf[o033o0ooonfX2o`3oC@Cooo]Z0_l60?l3oookJP03oi;o0?oo0?Gooo]Z00;ooo]Z
00Co403ooookJ_l06Ooo05go1_oonfX00ooo057o5@3ooookJP03oookJP04o`2]oooonf[ooo]Zool0
N@cooo]Z00?o0?mCoookJ_oonfX00_oonfX01?l0oago0?l8oookJ_l0hOlAoookJP04o`3o=?oonf[o
oo]Zo`3oCRKooo]Z000doookJP03oolF0?ooTP3ooo]Z00Gooo]Z00?oo`3loookJ_oonfX00ooonfX0
0olH0?ooo`H0oookJP03oookJP03oiCo0?oo0?Kooo]Z00?ooo]Z00?o0:KooookJ_nX0?l00ooonfX0
0ooo0?Wooo]ZoiCo0003oookJP03oom/0?l0oi[ooh4000;ooo]Z00?o>ol0oookJ_oonfX00_oonfX0
0ol0nooooo]ZoookJP02oookJP03ool30?oonf[ooo]Z00;ooo]Z00Goo`3MoookJ_oonf[o/ol0oil0
o`04oookJPGoiOl00_oonfX02Ooo06cooo]ZoookJ_oonf[oC@3oool^0?l0o`cooo]Zo`3oA@02oook
JP04o`3o3?oonf[ooo]Zon80o`;ooo]Z00?o0?nBoookJ_oonfX01_oonfX00omX0?oooo]ZoookJP03
oookJP03oaP0ool0M?ooi_l000;ooo]Z00?ooi00oookJ_oonfX02ooonfX00ooo_P3oiOl0onGo0005
onGo00?ooo]Z00?ooeL0oookJ_oonfX01?oonfX00ooo02gooo]ZoookJP06oookJP?oiOl02_oonfX0
1?l0e?oooo]ZonGo0?l01?l4onGo00?ooo]Z00Co0?m>oookJ_oonf[oU?l02_oonfX01?l0hOoo0?lM
o`3o2?oonfX2o`3oD`?ooo]Z1?l000001ooo07Wooo]Zo`2]ool0[Ooooo]ZoaD0oooo05401?oonfX0
1?l06Ooo403ooa00oooonfX2ooo90004oi;o0?oob@3oolT0oookJP;o1P3o0_oob@000ol0j?oo033o
o`0`o`02o`3o/@07oookJ_n2o`3oP_l0oh;o0?oonf[oolT0oookJP03o`3oF`CoolT02_oonfX3ooo9
033ooo]Z0_nDo`02oc7o00[oU?l00_oonfX2oh;o0003oookJ_l0ok3o0?n`00;o0?na0_l0<?l2oook
JP03o`3Xool0odgo0?m=00;ooo]Z0ooUo`03oookJP03oi;o0?oo0?Gooo]Z00;ooo]Z0_l@0?l2o`0I
o`Kooo]Z00?oo`1AoookJ_oonfX00_oonfX01OoUo`3ooo]ZoookJ_oonf[oo`1i00_ooo]Z00?o0?mC
oookJ_oonfX00_oonfX01?l0oagoA?l0oookJ_l0hOlAoookJP04o`3o=?oonf[o0?l<o`3o;UKooo]Z
00?ooaH0oonB0?oonfX01OoonfX00ooo0?cooo]ZoookJP04oookJP03oaP0oooo1P3ooo]Z00;ooo]Z
00?ojol0oookJ_oo0?H00ooonfX01?l0Y_oooo]ZoookJ_nX0?l2oookJP03ool0nOoonf[o07Oo00?o
oo]Z00Koof`0o`3oV_oonf[ooh40oookJ_lko`05oookJP05o`3koooonf[ooo]ZoookJ_oo0`001?oo
nfX01Ooo0=gooo]ZoookJ_l0Xooo/ol000Kooo]Z00?o0?oNool0QooonfX00ooonfX02?oo06cooo]Z
oookJ_m=0?oooo]Zool^0?mQ0?oo0?m51OoonfX01?oR0?oooo]ZoookJ_l0oi88oookJP03ofP0oooo
nf[ooo]Z00Cooo]Z00?o603ooookJ_oVo`000_oonfX00oooT03ooo]ZoookJP0;oookJP04oonn0?l0
o`Goj`3oog00o`Oooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP08oookJP03oon1
0?oonf[ooo]Z00Sooo]Z00Co0=CooookJ_oonf[o00Co0_oonfX00ol0ZOoo08SooookJP03oookJP03
o`3oC_oonf[o0?ld00[ooo]Z00Go0>7oo`3o7Ooonf[o0?l8oookJP02o`3oD`;ooo]Z1?l000000ooo
07Wooo]ZoookJP02o`2]o`03oaD0oooo057ooo]Z00Cooo]Z00?o01Wooa00ool@0?l00_oonfX01?nB
o`3oo`3eoookJ_oonfX2o`H0o`05oookJ_l0odgo0?m=o`3Xool0<?l00ol0ok400ooonf[oP_l0oh;o
0003oookJP?o0?mK1?lao`10oookJP;o<Ol01?oonfX3o`3oF`Gooo]Z0_n2o`02o`3o/0;o0?na0_l0
<?l3oookJP;o0?m=1?oonfX01?l60?oooo]ZoookJ_oonfX2oi;o00?ooo]Z0_l@0?l2o`0Io`Kooo]Z
00?oo`1AoaD0oooonfX00_oonfX01Ol0[Ooooo]ZoookJ_oonf[oo`1i00cooo]Z00So0?mCoookJ_oo
nf[ooo]Zo`3o7Ol0o`Sooo]Zo`3Qoa;ooo]Z00Co0?ldoookJ_l0odko0?l^9OoonfX003?ooo]Z00?o
oaH0oookJ_ooTP001OoonfX00ooo0?cooo]ZoookJP03oookJP03oaP0oooonf[oo`H000?ooo]Z00?o
U?l0oookJ_oo0?H01?oonfX00ol0Y_ooZ03ooookJP02oookJP03ool0nOoonf[oU?l000?ooo]Z00Ko
of`0o`3oV_l0olcooh40oookJ_lko`05oookJP03o`3koooonf[ooo]Z00;ooo]Z00?oo`<0oookJ_oo
nfX00_oonfX01?oo0=gooo]Zok?o0?nO0?l4oookJPKoiOl00_oonfX02?oo06cooo]ZoookJ_m=0?oo
obh0oookJ_l0o`co0?m51OoonfX01?oR0?oooo]ZoookJ_l0oi88oookJP03ofP0oooonf[ooo]Z00?o
oo]Z00Ko603oo`1doooonf[oi_l0oookJ_ooT00=oookJP04oonn0?l0o`Gooo]ZoookJPGoiOl00_oo
nfX00oooE`3ooo]ZoookJP04oookJP03ool0;Ooonf[ooo]Z00Kooo]Z1?oUo`09oookJP04o`3DoooU
o`3oiOl0o`04o`GoiOl00_oonfX01?l0odkooo]ZoookJ_nDo`09oookJP;o0>7o00Co0?lMo`3o2?oo
nf[o0?mC1OoonfX3o`000003ool0NOoonf[o0:go00;ooo]Z0_oo0543oookJP03o`0Iool@0?oo403o
00?oolT00_nBo`001?oob@3o1P3oo`H0ool60?l2ooo900;o0>So00Co033oo`3o/Ooonf[ooo]Z0_n2
o`000ol0ok3ooo]ZoookJP03o`3oF`03oc7o0?oob@3oolT000kooo]Z00?oolT0oookJ_oonfX0<?oo
nfX4oiCo00?o<Ol02?nDo`03oookJP;oP_l000?ooo]Zo`3o/?l0ok000_l0ok401Ol0<?oooo]Zoook
J_l0j?oooo]Z00;o0?m=0ooonfX01?l60?oooo]ZoookJ_oonfX2oi;o00Cooo]Z00?o403oo`1Mool0
6Ol01_oonfX00ooo057ooo]ZoookJP02oookJP05onGo0?oonf[ooo]ZoookJ_oo07T02ooonfX00ol0
oe?ooo]ZoookJP02oookJP03o`3o7Om4o`3o0>7o01;ooo]Z00Co0?ldoookJ_l0o`co0?l^E?oonfX0
0ooo5P3ooo]ZoonB0005oookJP03ool0o?oonf[ooo]Z00Cooo]Z00?o603ooookJ_oo1P000_oonfX0
0oo[o`3ooo]Zool0mP04oookJP03o`2Voooonf[oZ03o00;ooo]Z00?oo`3ioookJ_l0Mol01?oonfX0
1OooK03ooo]Zo`3oc?ooP@3o>ol000Kooo]Z00Go0?_ooookJ_oonf[ooo]Zool30004oookJP05ool0
gOoonf[o0:?ook?o0?nO0?l01OoonfX00ol0omkooo]Zool0Q`03oookJP08ool0K?oonf[ooo]Zoook
J_m=0?ooobh0oookJ_mQ0?l5oookJP04on80oooonf[ooo]Zo`3oTPSooo]Z00?oJ03ooookJ_oonfX0
1?oonfX00olH0?oooo]ZonKo0002oookJP03oon@0?oonf[ooo]Z00_ooo]Z00Cookh0o`3o1Ooonf[o
j`3o1ooonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00?ooh40oookJ_oo
nfX02?oonfX01?l0e?oooo]ZoookJ_l01?l2oookJP03o`2Yool0R?oooo]Z00?ooo]Z00?o0?m>oook
J_l0oc@02_oonfX01_l0hOoo0?lMo`3o2?l0o`Sooo]Zo`3oD`Cooo]Z0ol000001Ooo07Wooo]Zo`2]
ool0[Ooooo]Z00;oo`1A1?oonfX00ol06Ooo403ooa00o`02oookJP;oT_l000Coo`3eoookJ_l60?oo
1P3o0ol0odd01?l0j?oo033oo`3o/Ol0ok42oookJP;oP_l00_oonfX3o`3oF`?o<Ol0A_oonfX3oc7o
00Cooo]Z0ol0oe/4oookJP;oP_l00ol0ok000ol0ok7o033ooookJP02oookJP03o`3Xool0odgo0?m=
00?ooo]Z00Go1P3ooookJ_oonf[ooo]Zool0m@02oi;o00?ooo]Z00?o403oool0J_l06Ol01_oonfX0
0ooo057o5@3ooookJP02oookJP05o`2]oooonf[ooo]ZoookJ_oo07T03?oonfX02?l0oe?ooo]Zoook
J_oonf[o0?lMo`3o2?oonf[o0>7o4_oonfX01?l0ocCooo]Zo`3oC_l0obhToookJP00<ooonfX00ooo
5P3ooi80oookJP05oookJP03ool0o?oonf[ooo]Z00?ooo]Z00?o603ooookJ_oo1P000ooonfX00onD
o`3oo`3foookJP03oookJP03o`2Voooonf[oZ03o00?ooo]Z00?oo`3ioiCo0?oonfX00ooonfX00ooo
K03o0?nJoon10002oookJP03oc_o0?oonf[ooo]Z00;ooo]Z00?o0?_ooookJ_oonfX00_oonfX00ooo
0`3ooo]ZoookJP02oookJP04ool0gOoonf[ooo]Zok?o00Gooo]Z1OoUo`02oookJP08ool0K?oonf[o
oo]ZoookJ_m=0?ooobh0o`3o3?l0odD5oookJP05on80ool0oi3ooo]ZoookJ_l0oi802?oonfX00omX
0?oooo]ZoookJP03oookJP03oaP0ool0M?ooi_l000;ooo]Z00?ooi00oookJ_oonfX02_oonfX01_oo
_P3o0?l5oookJ_oonf[oiOl0oookJP?oiOl00ooonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooo
nf[ooo]Z00Kooo]Z1OoUo`08oookJP04o`3DoooUo`3oiOl0o`04o`GoiOl00_oonfX01?l0odkooo]Z
oookJ_nDo`09oookJP04o`3Qoooonf[o0?lMo`3o20;o0?mC1_oonfX2o`000003ool0NOl0[Ooo0:go
00;ooo]Z00Coo`1AoookJ_oonf[ooo]Z0_l06Ol00ol@0?ooolT0ooo90002ooo90004oi;o0?oob@3o
1P3oo`H0o`?oolT00_l0j?l01?l0<?oooo]ZoookJ_oonfX2oh;o0003o`3o/?oonf[o0?mK00;o0?mK
00?ooo]Zoc7o0?lao`00BooonfX3oc7o00KoU?l000Co0?mKoookJ_oonf[ooo]Z0_n2o`001?oonf[o
0?n`o`3o/?l0ok02o`0`o`04oookJ_l0j?oo0>SooookJP;o0?m=0_oonfX01_l60?oooo]ZoookJ_oo
nf[oo`3eoi;o00Cooo]Z0_l@0?l00ol06Ooooo]ZoookJP04oookJP03ool0DOlE0?oooo]Z00;ooo]Z
00CoiOl0oookJ_oonf[oo`1i3?oonfX00ol0oe?ooo]ZoookJP02oookJP03o`3o7Ooonf[o0>7o01;o
oo]Z00?o0?ldoookJ_l0o``0E?oonfX00ooo5P3ooi80oookJP05oookJP03ool0o?oonf[ooo]Z00Co
oo]Z00?o603ooookJ_oo1P000_oonfX00oo[o`3oo`3foookJP03oookJP04o`2Voooonf[ooo]ZojP0
o`;ooo]Z00?oo`3io`1goooonfX00ooonfX01_ooK03o0?nJoookJ_ooP@3ooo]Zoc_o00Gooo]Z00Go
0?_ooookJ_oonf[ooo]Zool30004oookJP05ool0gOoonf[ooo]Zo`2Soonco`001_oonfX00ol0omko
o`27oookJP03oookJP07ool0K?oonf[ooo]Zodd0oooonf[oobh0of40o`05oookJP05on80ool0oi3o
oo]ZoookJ_l0oi802?oonfX00omX0?oooo]ZoookJP04oookJP03oaP0oooonf[oi_l000;ooo]Z00?o
oi00oookJ_oonfX02_oonfX01Ooo_P3o0?l5oookJ_o[0?ooL03o00Kooo]Z00?ooeL0oookJ_oonfX0
0ooonfX00ooo02gooo]ZoookJP08oookJP03oon10?oonf[ooo]Z00Sooo]Z00Co0=CooookJ_oonf[o
00Co0_oonfX00ol0ZOoo08SooookJP03oookJP03o`3oC_oonf[o0?ld00[ooo]Z00Co0>7oo`3o7Ol0
o`Sooo]Z0_l0oe<5oookJP;o000000?oo`1io`000?l0[Ol00_oonfX00ooo057ooo]ZoookJP02oook
JP;o01Wo00Oo403ooookJ_oonf[ooo]Zoi;o0?oo0?Gooo]Z00;o1P3o0_l0odd2o`3Xo`;o033o0_oo
nfX3oh;o0005oookJ_l0oe_o0?mKo`3oFooonfX00_lao`1<oookJP;o<Ol01OoonfX3o`3oF`?ooo]Z
0_n2o`000ooonf[o0?n`o`3o/002o`0`o`;ooo]Z0_l0j?l2o`3oC@;ooo]Z00Oo1P3ooookJ_oonf[o
oo]Zool0mOoonf[oT_l000?ooo]Z0_l@0?l00ol06Ooooo]ZoookJP04oookJP03ool0DOlE0?oo5@3o
00;ooo]Z00Go0:gooookJ_oonf[ooo]Zool0N@0<oookJP05o`3oDooonf[ooo]ZoookJ_l0oad00_oo
nfX00ol0hOoooo]ZoookJP0@oookJP03o`3o=?oonf[o0?m>02Cooo]Z000boookJP03oolF0?oonf[o
oi8000Kooo]Z00?oo`3loookJ_oonfX00_oonfX00olH0?oooo]Zool60003oookJP03oiCo0?oonf[o
o`3f00Cooo]Z00?o0:KooookJ_nX0?l00_oonfX00ooo0?Wooo]ZoiCo0004oookJP05oom/0?l0olco
oh40oookJ_lko`001OoonfX00ol0nooooo]ZoookJP02oookJP03ool30?oonf[ooo]Z00;ooo]Z00Co
o`3MoookJ_nco`3oW`3o1?oonfX6onGo00;ooo]Z00Soo`1/oookJ_oonf[oC@3oool^0?oonf[o0?l<
o`3oA@Gooo]Z00CohP3ooookJ_oonf[o0?nB2?oonfX00omX0?oooo]ZoookJP03oookJP03oaP0ool0
M?ooi_l000;ooo]Z00?ooi00oookJ_oonfX02ooonfX01?oo_P3o0?l5oookJ_oUo`04oookJP04onGo
0?oonf[ooo]ZoomG00Gooo]Z00?oo`0]oookJ_oonfX01OoonfX6onGo00Sooo]Z00Co0=CoonGo0?oU
o`3o00Co1OoUo`02oookJP04o`3o;_l0odkoU?l0oiCo00Wooo]Z00Go0>7oo`3o7Ol0oagooo]Zo`3o
D`08oookJP07o`000?oo07Wo0:goo`000?oonf[o5@3oool0D@03oookJP03ooo90?l@0?oo403o00?o
olT00_nBo`02o`H0o`03o`3oCOoob@3ooo]Z00;o0>So0_l0<?l2oookJP;oP_l000Co0?n`oookJ_l0
oe_o0?mK0_oonfX2oc7o053ooo]Z0_lao`05oookJP03o`3oFooonf[ooo]Z00;ooo]Z0_n2o`02oook
JP;oiOl000Co033ooookJ_oonf[o0>So0_oonfX01?l0odgooo]ZoookJ_l60?l3oookJP03oi;o0?oo
nf[ooo]Z00?ooo]Z00?oo`1Zoa00ool06Ol01_oonfX00ooo057o5@3ooookJP02oookJP04onGo0?oo
nf[ooo]Zool0N@cooo]Z00So0?mCoookJ_oonf[ooo]Zo`3o7Om4o`3ooo]Zo`3Qoa;ooo]Z00?o0?ld
oookJ_oonfX0D_oonfX00ooo5P3ooo]ZoonB0006oookJP03ool0o?oonf[ooo]Z00?ooo]Z00?o603o
oookJ_oo1P000_oonfX00oo[o`3ooo]Zool0mP04oookJP03o`2Voooonf[oZ03o00;ooo]Z00?oo`3i
oookJ_l0Mol01?oonfX01OooK03ooo]Zo`3oc?ooP@3o>ol000Kooo]Z00Go0?_ooookJ_oonf[ooo]Z
ool30004oookJP05ool0gOoonf[o0:?ook?o0?nO0?l01OoonfX00ol0omkooo]Zool0Q`03oookJP08
ool0K?oonf[ooo]ZoookJ_m=0?ooobh0oookJ_mQ0?l5oookJP04on80oooonf[ooo]Zo`3oTPSooo]Z
00?oJ03ooookJ_oonfX01?oonfX00olH0?oooo]ZonKo0002oookJP03oon@0?oonf[ooo]Z00_ooo]Z
00Cookh0o`3o1Ooonf[oj`3o1_oonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Wo
oo]Z00?ooh40oookJ_oonfX01ooonfX01?l0e?oooo]ZoookJ_l01?l2oookJP03o`2Yool0R?oooo]Z
00?ooo]Z00?o0?l^o`3oC_l0oc@02_oonfX01Ol0hOoo0?lMo`3o2?oonf[o0?mC00Oooo]Z00Oo0000
ool0NOl0[Ooo0:gooookJ_lE0?ooo`1A00Cooo]Z00?o01Wooa00ool@0?l00_oonfX2oi;o0003ool0
mOl60?oo1P3o00;o0?m=0_l0j?l2o`0`o`;ooo]Z0_n2o`001?l0ok3ooo]Zo`3oFol0oe/2oookJP;o
<Ol0D?oonfX2oc7o00Kooo]Z00?o0?mKoookJ_oonfX00_oonfX2oh;o0004oookJ_l0ok3o0?n`o`0`
o`?ooo]Z00?o0>SooookJ_l0odd00_oonfX01_l60?oooo]ZoookJ_oonf[oo`3eoi;o00Gooo]Z00?o
403oo`0IoooonfX01OoonfX00ooo057ooo]ZoaD0o`02oookJP04o`2]oooonf[ooo]Zool0N@gooo]Z
00Oo0?mCoookJ_oonf[ooo]Zo`3o7Ooonf[o0>7o01?ooo]Z00?o0?ldoookJ_oonfX08ooonfX003;o
oo]Z00?ooaH0oonB0?oonfX01OoonfX00ooo0?cooo]ZoookJP03oookJP03oaP0oooonf[oo`H000?o
oo]Z00?oU?l0ool0m_oonfX01?oonfX01ol0Y_ooZ03ooookJ_oonf[oo`3ioookJ_nDo`001?oonfX0
0oooK03o0?nJoon10002oookJP03oc_o0?oonf[ooo]Z00;ooo]Z00?o0?_ooookJ_oonfX00_oonfX0
0ooo0`3ooo]ZoookJP02oookJP04ool0gOoonf[ooo]Zok?o00Cooo]Z1ooUo`000ooonf[oo`1/oook
JP02oookJP04odd0oooo;P3o0?l<o`3oA@Gooo]Z00CohP3oo`3oT?oonf[oA?l02OoonfX00omX0?oo
oo]ZoookJP03oookJP03oaP0ool0M?ooi_l000;ooo]Z00?ooi00oookJ_oonfX02_oonfX01Ooo_P3o
0?l5oookJ_oonf[oiOl000Kooo]Z00?ooeL0oookJ_oonfX01?oonfX00ooo02gooo]ZoookJP04oook
JPOoiOl01_oonfX2o`3o30;oiOl000?o00CoonGo0?oUo`001?oUo`001?oonf[o0?l^o`3oC_nDo`0:
oookJP05o`3Qool0oago0?l8oookJ_l0oe<02?oonfX2ool0N@?o00000_oo0543oookJP;o403o1?oo
b@001_nBo`3oolT0o`H0oooob@3o0?m=oookJP;o0>So0_l0<?l2oookJP;oP_l00_oonfX2o`3oF`;o
oo]Z0_lao`1DoookJP?o<Ol00ooonfX00ol0oe_ooo]ZoookJP03oookJP;oP_l00_oonfX01ooUo`3o
033oo`0`oooonf[o0>SooookJ_l0odd00ooonfX01Ol60?oooo]ZoookJ_oonf[oT_l000Gooo]Z00?o
o`1Zo`3o[Ol06Ol01_oonfX01Ooo057o5@3ooookJ_oonf[oiOl000?ooo]Z00?oo`1ioookJ_oonfX0
2_oonfX02?l0oe?ooo]ZoookJ_oonf[o0?lModCo0?oonf[o0>7o4_oonfX00ol0ocCooo]ZoookJP1A
oookJP03oolF0?ooTP3ooo]Z00Gooo]Z00?oo`3loookJ_oonfX01?oonfX00olH0?oooo]Zool60002
oookJP03on_o0?oo0?Kooo]Z00Cooo]Z00?o0:KooookJ_nX0?l00_oonfX00ooo0?Wo07OooookJP03
oookJP06oom/0?l0oi[ooo]Zoon10?oonf[o>ol01OoonfX01Ol0nooooo]ZoookJ_oonf[oo`<000Co
oo]Z00Goo`3MoookJ_oonf[o0:?ook?o0006oookJP03o`3og_oo08Oooo]Z00?ooo]Z00Ooo`1/oook
J_oonf[oC@3ooookJ_oo;P3oH@3o00Gooo]Z00CohP3oo`3oT?oonf[o0?nB2OoonfX00omX0?oooo]Z
oookJP04oookJP03oaP0oooVo`3ooo]Z00;ooo]Z00?ooi00oookJ_oonfX02_oonfX01?oo_P3o0?l5
oookJ_o[0?l7oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX02?oonfX00oooP@3o
oo]ZoookJP07oookJP04o`3Doooonf[ooo]Zo`04o`;ooo]Z00?o0:Woo`28oooonfX00ooonfX00ol0
obko0?m>o`3o=00:oookJP05o`3Qool0oago0?l8oookJ_l0oe<01ooonfX2ool0N@03o`2]ool0003o
000000;oo`1A1?oonfX2oa00o`?ooo]Z00coT_l0ool0mOoonf[o1P3ooookJ_l0odgooo]Zo`3Xoooo
nf[o033oo`3o/OoonfX2oh;o00?ooo]Z00?o0?mKoookJ_oonfX00_lao`1DoookJP?o<Ol01?oonfX0
0ol0oe_ooo]ZoookJP03oookJP;oP_l000Cooo]Zo`3o/?l0<?oo033o0_oonfX00ol0j?oo0?m=oook
JP02oookJP06o`H0oooonf[ooo]ZoookJ_oo0?GoT_l01OoonfX00ol@0?oo01WooookJP05oookJP03
ool0DOoonf[o5@3o00;ooo]Z00Co0:gooookJ_oonf[oo`1i3OoonfX01ol0oe?ooo]ZoookJ_oonf[o
0?lMoookJ_l0hOl04ooonfX00ol0ocCooo]ZoookJP0RoookJP00<OoonfX00ooo5P3ooo]ZoonB0006
oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Co603ooookJ_oonf[oo`H00_oonfX00onDo`3ooo]Zool0
mP04oookJP03o`2Voooonf[oZ03o00;ooo]Z00?oo`3ioookJ_l0Mol01?oonfX01OooK03ooo]Zoon1
0?oonf[o>ol000Gooo]Z00Go0?_ooookJ_oonf[ooo]Zool30005oookJP04ool0gOoonf[o/ol0oil0
o`?ooo]Z2?oUo`002?oonf[oo`1/oookJ_oonf[oC@3oool^0?oonf[o0?l<1OoonfX01OoR0?oo0?n@
oookJ_oonf[oA?l000Sooo]Z00?oJ03ooookJ_oonfX00ooonfX00olH0?oo07CoonKo0002oookJP03
oon@0?oonf[ooo]Z00[ooo]Z00Gookh0oookJ_l0o`Gooo]ZonGo0006oookJP03oomG0?oonf[ooo]Z
00Cooo]Z00?oo`0]oookJ_oonfX01?oonfX7onGo00Kooo]Z0ol0o``00ooonf[o00CoonGo0007onGo
0003o`3oC_nDo`3ooo]Z00Wooo]Z00?o0>7oo`3o7Ol0o`P00_oonfX00ol0oe?ooo]ZoookJP05oook
JP03ool0NOl0[Ooo000000;o000000?oo`1AoookJ_oonfX00_oonfX00ol@0?ooolT0ooo90002ooo9
00;oT_l00_l60?l2o`3oC@;o0>So00?ooo]Zo`0`oooonfX00on2o`03oookJP03o`3oFooonf[ooo]Z
00;o<Ol0FOoonfX2oc7o00;ooo]Z0_l0oe/5oookJP;oP_l000Gooo]ZonGo0?l0ok7o033ooookJP02
o`3Xo`05o`3oCOoonf[ooo]ZoookJ_l60?l00ooonfX00onBo`3ooo]ZoookJP03oookJP03o`3o[Ooo
nf[o01Wo00Kooo]Z00Goo`1AoaD0oooonf[ooo]ZonGo0003oookJP03ool0NOoonf[ooo]Z00[ooo]Z
00Oo0?mCoookJ_oonf[ooo]Zo`3o7Ooonf[o0>7o017ooo]Z0_l0o`aBoookJP03oolF0?oonf[ooi80
00Kooo]Z00?oo`3loookJ_oonfX00ooonfX00olH0?oooo]Zool60002oookJP03on_o0?oonf[oo`3f
00Cooo]Z00So0:KooookJ_oonf[oZ03ooookJ_oo0?Wooo]Zo`1go`Cooo]Z00Goof`0oookJ_oonf[o
oh40oc_o0006oookJP04o`3koooonf[ooo]Zool300Gooo]Z00Goo`3MoookJ_l0Xooo/ol0oil0o`05
oookJP03o`3og_oonf[oo`2700?ooo]Z00Soo`1/oookJ_oonf[oC@3ooookJ_oo;P3o0?m5of40o`Go
oo]Z00CohP3ooookJ_oonf[o0?nB2?oonfX00omX0?oooo]ZoookJP04oookJP03oaP0oooonf[oi_l0
00;ooo]Z00?ooi00oookJ_oonfX02_oonfX01Ooo_P3ooo]Zo`3o1Oo[0?ooL03o00Kooo]Z00?ooeL0
oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP08oookJP03oon10?oonf[ooo]Z00Sooo]Z00?o0=Co
oookJ_l01?l00ooonfX00ol0ZOoooo]ZoookJP02oookJP03o`3o;_l0odko0?ld00[ooo]Z00Go0>7o
o`3o7Ol0o`Sooo]Zo`3oD`07oookJP03ool0NOl0[Ooo0:go00;o000000?oo`1AoookJ_oonfX00ooo
nfX01?l@0?oooo]ZoookJ_oonfX2oi;o0003ool0mOl60?oo1P3o00;o0?m=0_l0j?l2o`0`o`?oP_l0
0ooonfX2o`3oF`03oookJ_lao`3o<Ol005Wooo]Z0_lao`03oookJP;o0?mK1OoonfX2oh;o0003o`3o
/?l0ok7o033o00;ooo]Z00?o0>Soo`3oCOoonfX00_oonfX01_l60?oooo]ZoookJ_oonf[oo`3eoi;o
00Cooo]Z00?o403oool0J_l06Ol01_oonfX01Ooo057ooo]ZoaD0oooonf[o0:go00?ooo]Z00?oo`1i
oookJ_oonfX02ooonfX01?l0oe?ooo]ZoookJ_l0oad2oookJP03o`3Qoooonf[ooo]Z03Gooo]Z000a
oookJP03oolF0?ooTP3ooo]Z00Gooo]Z00?oo`3loookJ_oonfX00ooonfX00olH0?oooo]Zool60003
oookJP03oiCo0?oo0?Kooo]Z00Cooo]Z00Oo0:KoojP0oooonf[ooo]Zool0nOoonf[o07Oo00Cooo]Z
00Goof`0o`3oV_ooP@3ooo]Zoc_o0005oookJP03o`3koooonf[ooo]Z00;ooo]Z00?oo`<0oookJ_oo
nfX00_oonfX01?oo0=gooo]Zo`0Goonco`06oookJPKoiOl000Soo`1/oookJ_oonf[oC@3oool^0?oo
nf[o0?l<o`3oA@Gooo]Z00?ohP3oo`3oT?oonfX00_m4o`08oookJP03ofP0oooonf[ooo]Z00?ooo]Z
00Go603oonKo0?oonf[ooo]Zoon@000=oookJP04oonn0?l0o`Gooo]ZonGo00Oooo]Z00?ooeL0oook
J_oonfX00ooonfX00ooo02gooo]ZoookJP04oookJPSoiOl01OoonfX3o`3o3003oookJ_l01?oooo]Z
00OoiOl000?o0?m>oiCo0?oonfX02OoonfX00ol0hOoo0?lMoookJP02oookJP03o`3oDooonf[ooo]Z
00Gooo]Z00Coo`1ioookJ_oonf[o00000_oo05400ol0003ooo]ZoookJP02oa00o`03ool0J_oonf[o
olT000;oT_l000CoolT0o`H0oooob@3o0?m=0_l0j?l00ooonf[o033oo`0`o`02oh;o0004o`3o/?oo
nf[ooo]ZoookJP;o0?mK00?ooo]Zoc7o0?lao`00GOoonfX3oc7o0003oookJ_l0oe_ooo]Z00Gooo]Z
0_n2o`001ooUo`3o0?nao`0`ool0<?oooo]Zo`3Xool0odd00ooonfX01Ol60?oooo]ZoookJ_oonf[o
T_l000Gooo]Z00Co0?n]oookJ_l06Ooo01Wo1OoonfX01Ooo057o5@3ooookJ_oonf[oiOl000;ooo]Z
00?oo`1ioookJ_oonfX02ooonfX01ol0oe?ooo]ZoookJ_oonf[o0?lMoookJ_l0hOl03ooonfX3o`3o
35;ooo]Z00?ooaH0oonB0?oonfX01OoonfX00ooo0?cooo]ZoookJP04oookJP03oaP0oooonf[oo`H0
00;ooo]Z00?ojol0ool0m_oonfX01?oonfX01ol0Y_oooo]ZojP0oooonf[oo`3ioookJ_l0Mol01Ooo
nfX01?ooK03ooo]Zoon10?lko`06oookJP05o`3koooonf[ooo]ZoookJ_oo0`001?oonfX01Ooo0=go
oo]ZoookJ_l0Xooo/ol000Gooo]Z00?ogOl0o`3og_oo08L01?oonfX01ooo06cooo]ZoookJ_m=0?oo
obh0oookJ_mQ0?l01OoonfX01?oR0?oo0?n@oookJ_l0oi89oookJP03ofP0oooonf[ooo]Z00?ooo]Z
00?o603oo`1doooVo`000_oonfX00oooT03ooo]ZoookJP0;oookJP04oonn0?l0o`Gooo]Zon/0o`Ko
oo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP08oookJP03oon10?oonf[ooo]Z00So
oo]Z00?o0=CooookJ_l01?l00ooonfX00ol0ZOoooo]ZoookJP03oookJP03o`3oC_l0ocCooo]Z00So
oo]Z0_l0hOl01?l0oagooo]ZoookJ_l0oe<7oookJP04ool0NOl0[Ooooo]Zo`0000;oo`1A00Co0000
oookJ_oonf[ooo]Z0_l@0?l2oookJP;oT_l000Goo`3eoookJ_l60?oooo]Zo`3oC@02o`3Xo`;o033o
0_n2o`001?l0ok3ooo]ZoookJ_oonfX2o`3oF`03oookJ_lao`3o<Ol005gooo]Z0olao`02oookJP03
o`3oFooonf[ooo]Z00Cooo]Z0_n2o`000ol0ok7o033oo`0`o`02oookJP05o`3oCOoonf[ooo]Zoook
J_l60?l00ooonfX00ooo0?GoT_l0oookJP03oookJP04oa00oooo06[o01Woo`0Io`Gooo]Z00Goo`1A
oookJ_lE0?oooo]Zo`2]o`02oookJP03ool0NOoonf[ooo]Z00cooo]Z00Co0?mCoookJ_oonf[o0?lM
0_oonfX00ol0hOoooo]ZoookJP0doookJP00<OoonfX00ooo5P3ooi80oookJP05oookJP03ool0o?oo
nf[ooo]Z00;ooo]Z00Co603ooookJ_oonf[oo`H00_oonfX00onDo`3ooo]Zool0mP04oookJP03o`2V
oooonf[oZ03o00;ooo]Z00?oo`3ioookJ_l0Mol01?oonfX01OooK03ooo]Zoon10?oonf[o>ol000Go
oo]Z00Go0?_ooookJ_oonf[ooo]Zool30004oookJP05ogT0oooo0=gooo]Zok?o0?nO0?l01_oonfX0
0ol0omkoiOl0onGo0002onGo0008oookJ_oo06cooo]ZoookJ_m=0?ooobh0oookJ_l0o``5oookJP03
on80ool0oi3ooo]Z00;oA?l02?oonfX00omX0?oooo]ZoookJP03oookJP03oaP0ool0M?ooi_l000;o
oo]Z00?ooi00oookJ_oonfX02_oonfX01Ooo_P3o0?l5oookJ_oonf[oiOl000Kooo]Z00?ooeL0oook
J_oonfX01?oonfX00ooo02gooo]ZoookJP03oookJPWoiOl00ooonfX5o`3o3004o`04oooonf[ooo]Z
o`28o`GoiOl000?o0?m>oiCo0?oonfX02OoonfX00ol0hOoo0?lMoookJP02oookJP03o`3oDooonf[o
oo]Z00Gooo]Z00Koo`1ioookJ_oonf[ooo]Zool0DOlE0?l2o`0000;o403o0_oo06X2oookJP08oi;o
0?oob@3oolT0o`H0oooob@3o0?m=o`3XoooonfX2o`0`o`;oP_l000Co0?n`oookJ_oonf[ooo]Z0_l0
oe/00ooonf[o<Ol0oc7o001RoookJP;o<Ol000?o0?mKoookJ_oonfX01OoonfX02?n2o`3oiOl0o`3o
/Ol0ok7o033ooookJ_l0j?oo0?m=0ooonfX01Ol60?oooo]ZoookJ_oonf[oT_l000Gooo]Z00Co0?n]
oookJ_oonf[o01Wo1OoonfX01Ooo057o5@3ooookJ_oonf[oiOl000;ooo]Z00?oo`1ioookJ_oonfX0
2ooonfX01ol0oe?ooo]ZoookJ_m4o`3o0?lMoookJ_l0hOl04?oonfX00ol0o`cooo]ZoookJP1@oook
JP03oolF0?ooTP3ooo]Z00Gooo]Z00?oo`3loookJ_oonfX00ooonfX02?lH0?oooo]ZoookJ_oo1P3o
oo]Zon_o0?oonf[oo`3f1?oonfX02?l0Y_oooo]ZoookJ_nX0?oooo]Zool0nOoonf[o07Oo1?oonfX0
1OooK03ooo]Zoon10?l0olco>ol000Kooo]Z00Co0?_ooookJ_oonf[oo`<01?oonfX01Omi0?ooo`3M
oookJ_l0Xooo/ol000Kooo]Z00?ogOl0o`3og_oo08L00ooonfX02?oo06cooo]ZoookJ_m=0?oooo]Z
ool^0?l0odGoH@3o1?oonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Sooo]Z00?oJ03ooookJ_oonfX0
1?oonfX00olH0?ooi_l0oookJP02oookJP03oon@0?oonf[ooo]Z00[ooo]Z00Gookh0o`3o1Ooonf[o
j`3oog00o`06oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX02?oonfX00oooP@3o
oo]ZoookJP07oookJP03o`3Doooonf[o00Co00?ooo]Z00?o0:WooookJ_oonfX00ooonfX00ol0odko
0?ldoookJP08oookJP03o`3Qool0oago0?lM00;ooo]Z00?o0?mCoookJ_oonfX01OoonfX01_oo07Wo
0:gooookJ_oonf[oo`1AoaD0o`;o000000Cooo]Zoa00ool@0?ooo`1Z0_oonfX02_nBo`3oo`3eool0
mOoonf[o1P3ooookJ_l0odgo0>SooookJ_l0<?l2oh;o0004o`3o/?oonf[ooo]ZoookJP;o0?mK00?o
oo]Zoc7o0?lao`00H_oonfX2oc7o0003oookJ_l0oe_ooo]Z00Kooo]Z00CoP_l0o`3o/Ol0ok7o033o
0_oonfX01Ol0odgooo]ZoookJ_oonf[o1P3o00?ooo]Z00?oo`3eoi;o0?oonfX00ooonfX01?l@0?oo
o`1ZoookJ_l06Ol5oookJP05ool0DOoonf[o5@3ooookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP0<
oookJP06o`3oDooonf[o0?l8o`3o7Ooonf[o0>7o=_oonfX0033ooo]Z00?ooaH0oonB0?oonfX01_oo
nfX00ooo0?cooo]ZoookJP02oookJP03oaP0oooonf[oo`H000?ooo]Z00?oU?l0ool0m_oonfX01?oo
nfX01Ol0Y_oooo]ZojP0oooonf[oU?l000;ooo]Z00Wo07OooookJ_oonf[ooo]Zoom/0?l0oi[ooh40
oookJ_lko`001OoonfX00ol0nooooo]ZoookJP02oookJP03ool30?oonf[ooo]Z00;ooo]Z00Coo`3M
oookJ_l05ooo/ol01_oonfX01?l0omkoiOl0oookJ_oonfX2onGo0008ool0K?oonf[ooo]Zodd0oooo
;P3ooo]Zo`3o3?l0odD4oookJP03on80oooonf[o0?n@00?oA?l02?oonfX00omX0?oooo]ZoookJP02
oookJP03oaP0oooonf[oi_l000;ooo]Z00?ooi00oookJ_oonfX02_oonfX01Ooo_P3ooo]Zo`3o1Ooo
nf[oiOl000Kooo]Z00?ooeL0oookJ_oonfX01?oonfX00ooo02gooo]ZoookJP03oookJPWoiOl00ooo
nfX5o`3o3006o`04oooonf[ooo]Zo`28oooUo`3ooo]Z0ooUo`000ol0odkoU?l0oookJP07oookJP04
o`00Ool0hOoo0>7oo`3o7@?ooo]Z00?o0?mCo`00Ool007l00_l007l3oookJP03ool0NOoonf[ooo]Z
00;oo`1A0ol000000ol@0?oo01Woool0JP02oookJP;oT_l000?ooo]Zo`H0ool60?l00_l0odd01_oo
b@3o033oo`0`oooonf[oP_l0o`3o/0?ooo]Z0_l0oe/00ooonf[o<Ol0oc7o000WoookJPGoQ03o2_lP
o`0`oookJP03oc7o0?l0oe_o0?mK00Gooo]Z00GoP_l0oookJ_oUo`3ooo]Zo`3o/@02o`0`o`03o`3X
ool0odgooo]Z00;ooo]Z00Go1P3ooookJ_oonf[ooo]Zoi;o0004oookJP05o`1Mool0ojgooo]Zoook
J_l06Ol01OoonfX01?oo057ooo]ZoookJ_oUo`03oookJP03ool0NOoonf[ooo]Z00[ooo]Z00So0?mC
oookJ_oonf[ooo]ZodCo0?l0oagooo]Zo`3Qof7ooo]Z00?ooaH0oonB0?oonfX01_oonfX00ooo0?co
oo]ZoookJP03oookJP03oaP0oooonf[oo`H000;ooo]Z00?ojol0ool0m_oonfX01?oonfX01Ol0Y_oo
oo]ZojP0oooonf[oo`3i00;ooo]Z00?o07OooookJ_oonfX00_oonfX01?ooK03ooo]Zoon10?lko`06
oookJP05o`3koooonf[ooo]ZoookJ_oo0`001?oonfX01Ooo0=gooo]ZoookJ_l0Xooo/ol000Gooo]Z
00?ogOl0o`3og_oo08L01?oonfX01ooo06cooo]ZoookJ_m=0?ooobh0oookJ_mQ0?l01OoonfX01?oR
0?oo0?n@oookJ_l0oi89oookJP03ofP0oooonf[ooo]Z00?ooo]Z00?o603oo`1doooVo`000_oonfX0
0oooT03ooo]ZoookJP0:oookJP05oonn0?oonf[o0?l5on/0oom`0?l01_oonfX00oooE`3ooo]Zoook
JP03oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00?ooh40oookJ_oonfX01ooonfX00ol0e?oooo]Zo`04
o`03oookJP03o`2Yoooonf[ooo]Z00?ooo]Z00?o0?m>o`3o=?oonfX01_oonfX2o`00O`03o`3Qool0
oago0?l800;ooo]Z00?o0?mCo`00Ool007l00_l007l3oookJP03ool0NOl0[Ooooo]Z00;oo`1A1?l0
00001?l@0?oo01WooookJ_oonfX2oi;o0004ool0mOoonf[o1P3oo`H0o`;o0?m=00Gooo]Zo`0`ool0
<?ooP_l0o`3o/004oookJP04o`3oFooonf[o<Ol0oc7o02Oooo]Z1On40?l:ob3o033ooo]Z00Co<Ol0
oookJ_l0oe_o0?mK1OoonfX01?n2o`3o0?n`oookJ_l0ok42o`0`o`03oookJ_l0odgo0>So00;ooo]Z
00Ko1P3ooookJ_oonf[ooo]Zool0mOnBo`04oookJP04oa00oooo06[ooo]Zo`0Io`Gooo]Z00Goo`1A
oaD0oooonf[ooo]Zo`2]o`02oookJP03ool0NOoonf[ooo]Z00_ooo]Z00Oo0?mCoookJ_oonf[o0?l8
o`3o7Ooonf[o0>7o03Gooo]Z000`oookJP03oolF0?ooTP3ooo]Z00Gooo]Z00?oo`3loookJ_oonfX0
0_oonfX01?lH0?oooo]ZoookJ_oo1P02oookJP03oiCo0?oonf[oo`3f00Cooo]Z00?o0:KooookJ_nX
0?l00_oonfX00onDo`3ooo]Zo`1go`04oookJP05oom/0?ooP@3o0?o<oookJ_lko`001OoonfX01Ol0
nooooo]ZoookJ_oonf[oo`<000Cooo]Z00GoN@3oool0gOoonf[o0:?ook?o0005oookJP03oiCo0?l0
omkoiOl000?ooo]Z00Soo`1/oookJ_oonf[ooo]Zodd0oooo;P3ooo]Zo`3o30Gooo]Z00?ohP3oo`3o
T?m4o`000om4o`07oookJP03ofP0oooonf[ooo]Z00?ooo]Z00?o603oonKo0?oonfX00_oonfX00ooo
T03ooo]ZoookJP0:oookJP05oonn0?l0o`Gooo]ZonGo0?m`0?l01_oonfX00oooE`3ooo]ZoookJP03
oookJP03ool0;Ooonf[ooo]Z00Kooo]Z1ooUo`02oookJPKo0?l<0_oonfX00ol0R?ooiOl0oookJP03
onGo0003o`3oC_nDo`3ooo]Z00Sooo]Z00?o0>7oo`00Ool0oad00ooonfX00ol0oe?o001oo`00O`04
o`00O`;oo`1i0_oonfX01?oo057o5@3ooookJ_l00002oa00o`05o`0Ioooo06[ooo]ZoookJ_nBo`00
0_oonfX01ol60?oooo]Zo`3oCOl0j?ooolT0o`0`ool0ok400_n2o`03oookJP;o0?mK00?ooo]Zoc7o
0?lao`008?oonfX>ob3o00[o9P3o1OlPo`0/oookJP03oc7o0?oonf[o0?mK00Gooo]Z00?oP_l0oook
J_oUo`000_oonfX01?l0ok7o033ooookJ_l0odd3oookJP05o`H0oooonf[ooo]ZoookJ_nBo`001?oo
nfX01Ol0ojgoo`1ZoookJ_oonf[o01Wo00Gooo]Z00Coo`1AoookJ_oonf[oiOl00_oonfX00ooo07Wo
oo]ZoookJP0;oookJP07o`3oDooonf[ooo]ZoookJ_m4o`3o0?lMo`3Qo`1QoookJP03oolF0?ooTP3o
oo]Z00Gooo]Z00?oo`3loookJ_oonfX00ooonfX02?lH0?oooo]ZoookJ_oo1P3ooo]Zon_o0?oonf[o
o`3f1?oonfX02?l0Y_oooo]ZoookJ_nX0?oooo]Zool0nOoonf[o07Oo1?oonfX01OooK03ooo]Zoon1
0?l0olco>ol000Kooo]Z00Co0?_ooookJ_oonf[oo`<01?oonfX01Omi0?ooo`3MoookJ_l0Xooo/ol0
00Kooo]Z00?ogOl0o`3og_oo08L00ooonfX02?oo06cooo]ZoookJ_m=0?oooo]Zool^0?l0odGoH@3o
1?oonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Sooo]Z00?oJ03ooookJ_oonfX01?oonfX00olH0?oo
i_l0oookJP02oookJP03oon@0?oonf[ooo]Z00[ooo]Z00Cookh0o`3o1Ooonf[oj`3o1_oonfX00ooo
E`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00?ooh40oookJ_oonfX02?oonfX00ol0
e?oo00CooookJP02oookJP03o`2Yoooonf[ooo]Z00?ooo]Z00?o0?m>o`3o=?oonfX01ooonfX01?l0
07oo0>7oo`3o7Ol0o`P2oookJP03o`3oDol007oo001o00Co001o0_oo07T01Ol0[Ooooo]Zool0DOlE
0?oooo]Z00;o00000_l@0?l01Ol06Ooooo]ZoookJ_nBo`3oo`3e00;ooo]Z00Co1P3ooookJ_l0odgo
oo]Z0_l0<?l2oh;o00Cooo]Z0_l0oe/2oc7o027ooo]Z3OlPo`000ooonf[o9P3oobH0o`08obH0o`Co
8?l0;?oonfX01?lao`3ooo]ZoookJ_l0oe/5oookJP09oh;o0?l0ok3ooo]ZoookJ_l0ok7o033ooook
J_l0odgo0>So00;ooo]Z00Ko1P3ooookJ_oonf[ooo]Zool0mOnBo`03oookJP05oa00ool0GOooo`1Z
oookJ_l06Ol01OoonfX01Ooo057o5@3ooookJ_oonf[o0:go00;ooo]Z00?oo`1ioookJ_oonfX02ooo
nfX01ol0oe?ooo]ZoookJ_l0o`So0?lMoookJ_l0hOl0=?oonfX002oooo]Z00?ooaH0oonB0?oonfX0
1_oonfX00ooo0?cooo]ZoookJP02oookJP04oaP0oooonf[ooo]Zool600;ooo]Z00?oU?l0oookJ_oo
0?H01?oonfX01?l0Y_oooo]ZojP0oooonfX2oiCo0003oookJ_l0Mooooo]Z00;ooo]Z00Goof`0o`3o
V_ooP@3ooo]Zoc_o0005oookJP03o`3koooonf[ooo]Z00;ooo]Z00?oo`<0oookJ_oonfX00_oonfX0
1?oo0=gooo]Zo`0Goonco`05oookJP03oiCo0?l0omkoiOl000Cooo]Z00Soo`1/oookJ_oonf[oC@3o
ool^0?oonf[o0?l<o`3oA@Cooo]Z00?ohP3ooookJ_l0oi001?m4o`07oookJP03ofP0oooonf[ooo]Z
00;ooo]Z00?o603oo`1doooVo`000_oonfX00oooT03ooo]ZoookJP0:oookJP05oonn0?oonf[o0?l5
oookJ_oUo`001_oonfX00oooE`3ooo]ZoookJP04oookJP03ool0;Ooonf[ooo]Z00Oooo]Z1OoUo`00
0ooonf[o0?l<o`3o3006o`3o3004oookJ_l0R?ooiOl0oookJPCoiOl000?o0?m>onGo0?oonfX01ooo
nfX01?l0hOoo001oo`3o7Ol0o`P2oookJP05o`3oDol007oo001oo`00OooonfX00_l007l01_oo07Wo
0:gooookJ_oonf[oo`1AoaD0o`;ooo]Z00Go403oo`0Ioooo06[o0000oookJP02oi;o0003oookJ_l6
0?oo1P3o00;o0?m=00Gooo]Zooo90?l0<?oo0?n`oh;o0004oookJP04o`3oFooonf[o<Ol0oc7o01[o
oo]Z2?lPo`000on40?oo9P3oobH0o`0;obH0o`[ooo]Z1OlV0?l4ob3o00;oQ03o9ooonfX00olao`3o
oo]Zo`3oF`05oookJP03oh;o0?oonf[oiOl000;ooo]Z00Co0?nao`0`ool0<?oo0?m=0ooonfX01Ol6
0?oooo]ZoookJ_oo0?GoT_l000Cooo]Z00Go0?n]ool0J_oonf[ooo]Zo`0Io`05oookJP04ool0DOoo
nf[ooo]ZonGo00;ooo]Z00?oo`1ioookJ_oonfX02_oonfX02?l0oe?ooo]ZoookJ_oonf[oA?l0o`3o
7Ooonf[o0>7oGooonfX00ooo5P3ooi80oookJP06oookJP03ool0o?oonf[ooo]Z00?ooo]Z00?o603o
oookJ_oo1P000_oonfX00oo[o`3ooo]Zool0mP04oookJP05o`2Voooonf[oZ03ooookJ_oo0?T00_oo
nfX00ol0Mooooo]ZoookJP02oookJP04oom/0?oonf[ooh40oc_o00Kooo]Z00Go0?_ooookJ_oonf[o
oo]Zool30004oookJP05ool0gOoonf[ooo]Zo`2Soonco`001OoonfX00ooMo`3o0?oNool0Q`03oook
JP08ool0K?oonf[ooo]ZoookJ_m=0?ooobh0oookJ_mQ0?l4oookJP05on80oooonf[o0?n@oookJ_l0
oi802OoonfX00omX0?oooo]ZoookJP03oookJP03oaP0oooVo`3ooo]Z00;ooo]Z00?ooi00oookJ_oo
nfX02_oonfX01Ooo_P3ooo]Zo`3o1Oo[0?ooL03o00Gooo]Z00?ooeL0oookJ_oonfX01?oonfX00ooo
02gooo]ZoookJP07oookJP03oon10?oonf[ooo]Z00Sooo]Z00?o0=Coo`04oooonfX00_oonfX00ol0
ZOoooo]ZoookJP03oookJP03o`3o;_l0odkooo]Z00Sooo]Z00Ko0>7oo`3o7Ol007oo0?l8oookJ_l0
oe<3o`00O`09oookJ_l007oo001oool0NOoonf[o0:gooookJ_oo057o5@3o00;ooo]Z00Go0000oa00
ool06Ooo0000oookJP02oi;o0004ool0mOoonf[o1P3oo`H0o`;o0?m=00Cooo]Zo`0`ool0ok3oP_l0
1?oonfX2o`3oF`;o<Ol06ooonfX8ob3o0003oh@0oolV0?oo9P3o00_o9P3o2_oonfX5obH0o`?o8?l0
0on40?lVoookJP04oc7o0?oonf[ooo]Zo`3oF`Gooo]Z00GoP_l0o`3o/?oonf[ooo]Zo`3o/@02o`0`
o`05o`3oCOl0j?oooo]ZoookJ_l60?l00_oonfX00ooo0?GoT_l0oookJP03oookJP05oa00ool0GOoo
o`1ZoookJ_l06Ol01OoonfX01ooo057o5@3ooookJ_oonf[o0:gooookJ_oo07T03OoonfX01ol0oe?o
oo]ZoookJ_l0o`Sooo]Zo`3o7Ol0hOl0=?oonfX002oooo]Z00?ooaH0oonB0?oonfX01OoonfX00ooo
0?cooo]ZoookJP02oookJP04oaP0oooonf[ooo]Zool600;ooo]Z00?oU?l0oookJ_oo0?H01?oonfX0
1?l0Y_oooo]ZojP0oooonfX3oiCo0003oookJ_l0Mooooo]Z00;ooo]Z00Goof`0oon10?l0olcooo]Z
oc_o0005oookJP03o`3koooonf[ooo]Z00;ooo]Z00Woo`<0oookJ_oonf[ooo]ZogT0oooo0=gooo]Z
o`2Soonco`001OoonfX00onDo`3o0?oNonGo0003oookJP08ool0K?oonf[ooo]ZoookJ_m=0?ooobh0
oookJ_l0o``5oookJP03on80ool0oi3oA?l000CoA?l01_oonfX00omX0?oooo]ZoookJP03oookJP03
oaP0oooVo`3ooo]Z00;ooo]Z00?ooi00oookJ_oonfX02_oonfX01?oo_P3o0?l5oookJ_oUo`06oook
JP03oomG0?oonf[ooo]Z00Cooo]Z00?oo`0]oookJ_oonfX02?oonfX5onGo00So0?l<00?ooo]Zo`28
oooUo`001OoUo`000ol0odkoiOl0onGo0002o`00O`;ooo]Z0ol007l01?l0hOoo001oo`3o7Ol0o`P2
o`00O`04o`3oDol007oo001oo`00O`?ooo]Z00?oo`1io`2]ool007l00_oo0543oookJP03oa00ool0
6Oooo`1Z00;o000000OoT_l0oookJ_oonf[o1P3oo`3Xool0odgooo]Z00;o033o00?o0?naoh;o0?n2
o`000ooonfX2o`3oF`;o<Ol06OoonfX3ob3o0003oh@0oolV0?oo9P3o00Ko9P3o7?oonfX4obH0o`Co
8?l00on40?lSoookJP04oc7o0?oonf[o0?mKo`3oF`Cooo]Z00GoP_l0oookJ_oUo`3ooo]Zo`3o/@02
oookJP03o`0`ool0odgooo]Z00;ooo]Z00Go1P3ooookJ_oonf[oo`3eoi;o0004oookJP05o`3o[Ooo
06[ooo]ZoookJ_l06Ol01?oonfX01OlE0?ooo`1AoookJ_oonf[oiOl000;ooo]Z00?oo`1ionGo0?oU
o`002_oonfX02?l0oe?ooo]ZoookJ_oonf[oA?l0o`3o7Ooonf[o0>7oG_oonfX00ooo5P3ooi80oook
JP05oookJP03ool0o?oonf[ooo]Z00?ooo]Z00So603ooookJ_oonf[oo`H0oookJ_o[o`3ooo]Zool0
mPCooo]Z00Ko0:KooookJ_oonf[oZ03ooookJ_oo0?T2oookJP09o`1goooonf[ooo]ZoookJ_ooK03o
oo]Zoon10?l0olco>ol000Kooo]Z00Go0?_ooookJ_oonf[ooo]Zool30003oookJP05ogT0oooo0=go
oo]Zo`2Soonco`001_oonfX00ooMo`3o0?oNool0Q`03oookJP08ool0K?oonf[ooo]Zodd0oooonf[o
obh0o`3oAOmQ0?l4oookJP05on80ool0oi3ooo]ZoookJ_l0oi802?oonfX00omX0?oooo]ZoookJP03
oookJP03oaP0ool0M?ooi_l000?ooo]Z00?ooi00oookJ_oonfX02_oonfX01?oo_P3o0?l5on/0oom`
0?l6oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX02?oonfX00oooP@3ooo]Zoook
JP07oookJP03o`3Dool01?oooo]Z00;ooo]Z00?o0:Woo`00Ool007l00ol007l00ol0obko0?m>o`00
O`02o`00O`;ooo]Z1?l007l01_l0hOoo0?lMo`00Ool0o`So001oo`3oD`?o001o0ooonfX00ooo07Wo
001oo`2]o`02ool0D@Cooo]Z00Ko403oo`0Iool0003o0000oi;o0?oo0?D2oookJP04o`H0ool0j?oo
0?m=oookJP;o033o00?o0?n`oh;o0?oonfX00_oonfX2o`3oF`;o<Ol06_oonfX3ob3o0003oh@0oolV
0?oo9P3o00Ko9P3o7?oonfX4obH0o`?o8?l01?n40?lRoookJP03oc7o0?oonf[ooo]Z00;o0?mK1?oo
nfX01?n2o`3o0?n`oookJ_l0ok42oookJP03o`0`ool0odgo0>So00;ooo]Z00Go1P3ooookJ_oonf[o
o`3eoi;o0004oookJP05oa00ool0GOooo`1ZoookJ_l06Ol01OoonfX01?oo057ooo]ZoookJ_l0[Ol2
oookJP03ool0NOoonf[ooo]Z00_ooo]Z00Oo0?mCoookJ_oonf[o0?l8o`3o7Ooonf[o0>7o03?ooo]Z
000^oookJP03oolF0?ooTP3ooo]Z00Kooo]Z00?oo`3loookJ_oonfX00_oonfX01?lH0?oooo]Zoook
J_oo1P02oookJP03on_o0?oonf[oo`3f00Cooo]Z00Co0:KooookJ_nX0?oooo]Z0onDo`000ol0Mooo
oo]ZoookJP02oookJP05oom/0?ooP@3ooo]ZoookJ_lko`001?oonfX00ol0nooooo]ZoookJP02oook
JP03ool30?oonf[ooo]Z00;ooo]Z00Coo`3MoookJ_l05ooo/ol01OoonfX01?nDo`3o0?oNonGo0?nD
o`03oookJP08ool0K?oonf[ooo]Zodd0oooo;P3ooo]Zo`3o3?l0odD4oookJP03on80oooonf[o0?n@
00CoA?l01ooonfX00omX0?oooo]ZoookJP02oookJP03oaP0oooVo`3ooo]Z00;ooo]Z00?ooi00oook
J_oonfX02_oonfX01Ooo_P3ooo]Zo`3o1OoUo`3oL03o00Gooo]Z00?ooeL0oookJ_oonfX01?oonfX0
0ooo02gooo]ZoookJP08oookJP03onGo0?oonf[ooo]Z00;oiOl02Ol0o``00onDo`3oiOl0onGo0004
onGo0003o`3oC_oUo`3oiOl000?o001o0_oonfX2o`00O`04o`3Qool0oago0?lMo`3o20;o001o00?o
0?mCoookJ_l007l00_l007l2oookJP05ool0NOl0[Ooo001oool0DOlE0?l00ooonfX01?l@0?oo01Wo
ool0J_l00002oi;o00;o00000_l0j?l01_l0odgooo]Zo`0`ool0ok7ooo]Zoh;o00?ooo]Z0_l0oe/2
oc7o01Sooo]Z0olPo`001?n40?oo9P3oobH0oolV0?lCoookJPWohOl03?oonfX4obH0o`Go8?l08_oo
nfX01?lao`3ooo]ZoookJ_l0oe/4oookJP05oh;o0?oonf[oiOl0oookJ_l0ok400_oonfX00ol0<?oo
0?m=o`3Xo`02oookJP04o`H0oooonf[ooo]Zoi;o00Gooo]Z00Go0?n]ool0J_oonf[ooo]Zo`0Io`04
oookJP07oaD0oooo057ooo]ZoookJ_oUo`3ooo]Zool0N@02onGo00[ooo]Z00So0?mCoookJ_oonf[o
oo]ZodCo0?oonf[o0?lMo`3Qoegooo]Z00?ooaH0oonB0?oonfX01_oonfX00ooo0?cooo]ZoookJP03
oookJP08oaP0oooonf[ooo]Zool60?oonf[ojol0oookJ_oo0?H4oookJP08o`2Voooonf[ooo]ZojP0
oooonf[oo`3ioookJ_l0Mol4oookJP05oom/0?oonf[ooh40oookJ_lko`001OoonfX01Ol0nooooo]Z
oookJ_oonf[oo`<000Cooo]Z00Goo`3MoookJ_oonf[o0:?ook?o0006oookJP03o`3og_oo08Oooo]Z
00;ooo]Z00Soo`1/oookJ_oonf[oC@3ooookJ_oo;P3ooo]Zof40o`Cooo]Z00GohP3ooookJ_l0oi3o
oo]Zo`3oTP09oookJP03ofP0oooonf[ooo]Z00?ooo]Z00?o603oonKo0?oonfX00_oonfX00oooT03o
oo]ZoookJP0:oookJP04oonn0?l0o`Gooo]Zon/0o`Kooo]Z00?ooeL0oookJ_oonfX01?oonfX00ooo
02gooo]ZoookJP07oookJP03oon10?oonf[ooo]Z00Oooo]Z00?o0=Coo`04oooonfX00_oonfX00ol0
ZOoooo]Zo`00O`03o`00O`03o`3o;_l0odko001o00?o001o0_oonfX3o`00O`07o`3Qool0oago001o
o`3o2?l007oo0?mCoookJP03o`00O`;ooo]Z00Goo`1io`00Ool0[Oooo`1AoaD0o`03oookJP04o`1M
ool@0?oo01Woo`0000;oT_l000?oo`3eo`000?oonfX00_l0j?l01?l0odgo033oo`0`ool0ok42oh;o
00?ooo]Z00?o0?mKoc7o0?lao`006OoonfX3ob3o0004oh@0oolV0?oo9P3oobH0oa;ooo]Z2_oQo`0<
oookJPCo9P3o1?lPo`000on40?oooo]ZoookJP0OoookJP05oc7o0?oonf[ooo]ZoookJ_l0oe/01?oo
nfX01?n2o`3o0?n`oookJ_l0ok42oookJP06o`0`ool0odgo0>Soo`3Xoooonf[o1P3o0_oonfX00ooo
0?GoT_l0oookJP03oookJP05oa00oooonf[oo`1ZoookJ_l06Ol01OoonfX01?oo057ooo]ZoookJ_l0
[Ol2oookJP03ool0NOoonf[ooo]Z00[ooo]Z00So0?mCoookJ_oonf[o0?l8oookJ_l0oagooo]Zo`3Q
oc;ooo]Z000^oookJP03oolF0?ooTP3ooo]Z00Kooo]Z00Goo`3loookJ_oonf[ooo]ZoaP0o`03oook
JP03ool60?oonf[ojol000;ooo]Z00Goo`3foookJ_oonf[ooo]Zo`2Vo`02oookJP06ojP0oonDo`3o
U?l0oiCo0?oonf[o07Oo0ooonfX01OooK03ooh40o`3oc?oonf[o>ol000Gooo]Z00?o0?_ooookJ_oo
nfX00_oonfX02Ooo0`3ooo]ZoookJ_oonf[oN@3oool0gOl05oooW`3ook?o0004oookJP;oU?l000?o
0?oNonGo0?nDo`000_oonfX01Ooo06cooo]ZoookJ_oonf[oC@3o00;ooo]Z00?o0?l<o`3oAOoonfX0
0_oonfX00ooUo`3ooo]Zo`3oT005odCo00Kooo]Z00?oJ03ooookJ_oonfX00ooonfX00olH0?oo07Co
oookJP02oookJP03oon@0?oonf[ooo]Z00Wooo]Z00Gookh0oookJ_l0o`GoiOl0og00o`06oookJP03
oomG0?oonf[ooo]Z00Cooo]Z00?oo`0]oookJ_oonfX01ooonfX00ooUo`3ooo]ZoookJP02oookJPWo
0?l<00?oU?l0onGo0?oUo`001?oUo`001?l0odkoiOl0onGo0?oUo`05oookJP05o`00Ool0hOoo0?lM
oookJ_l0o`P00_l007l00ol0oe?ooo]ZoookJP03o`00O`;oo`1i00Co0:goo`00Oooo057o5@3o0ooo
nfX01Ol@0?oo01WooookJ_l0003oT_l000;o000000Co1P3oo`3Xool0odgo0?m=0_l0<?l00ol0ok7o
P_l0oh;o0002oookJP;o0?mK0_lao`0GoookJP04oh@0oolPo`3o8?l0oh@0o`?o9P3o3_oob@0=om[o
00Cooo]Z1OoQo`0;oookJPGo9P3o1?lPo`0OoookJP04oc7o0?oonf[ooo]Zo`3oF`Cooo]Z00[oP_l0
oookJ_oUo`3ooo]Zo`3o/Ooonf[oiOl0o`3oCOoonf[o0>So0_oonfX01?l60?oooo]ZoookJ_nBo`05
oookJP04o`3o[Ooo06[ooo]Zo`0Io`Gooo]Z00?o5@3oool0DOoonfX00ooUo`000ooo07WoiOl0onGo
000:oookJP08o`3oDooonf[ooo]ZoookJ_m4o`3ooo]Zo`3o7Ol0hOmLoookJP03oolF0?ooTP3ooo]Z
00Kooo]Z00?oo`3loookJ_oonfX00_oonfX01_lH0?oooo]ZoookJ_oo1P3ooo]Zon_o00;ooo]Z00Go
o`3foookJ_oonf[ooo]Zo`2Vo`02oookJP03ojP0oooonf[oo`3i00;ooo]Z00Wo07OooookJ_oonf[o
oo]Zo`3oV_ooK03ooh40o`3oc?lko`001_oonfX01Ol0nooooo]ZoookJ_oonf[oo`<000?ooo]Z00Go
N@3oool0gOoonf[o01Oook?o0006oookJP03omgo0?l0omkoo`2700?ooo]Z00Goo`1/oookJ_oonf[o
C@3oool^0002oookJP07of40oooonf[ooo]ZoookJ_oR0?oooo]Zo`3oT002oookJP03o`3oT_oonf[o
oo]Z00Kooo]Z00?oJ03ooookJ_oonfX00ooonfX00olH0?ooi_l0oookJP03oookJP03oon@0?oonf[o
oo]Z00Wooo]Z00Gookh0oookJ_l0o`Goj`3oog00o`05oookJP03oomG0?oonf[ooo]Z00Cooo]Z00?o
o`0]oookJ_oonfX01ooonfX00oooP@3ooo]ZoookJP08oookJP06o`3Dool01?oooo]ZoookJ_l0ZOoo
08So1OoonfX00ol0odkooo]ZoookJP05oookJP;o001o00Ko0>7oo`3o7Ooonf[o0?l8o`00Ool0oe<2
oookJP?o001o0_oo07T2o`2]o`03ool0DOlE0?oooo]Z00;ooo]Z00[o05gooa00ool06Ooo0000oi;o
0?oo0?Go0000oookJ_l60?oo0>So0_l0odd01?l0<?oo0?nao`3o/?n2o`03oookJP03o`3oFolao`3o
<Ol001Sooo]Z00CoQ03oob3o0?lPo`3oQ03o0olV0?l8oookJP;ohOl04OoJo`04oookJPCohOl03?oo
nfX5obH0o`?o8?l07ooonfX01Olao`3ooo]ZoookJ_oonf[o0?mK00Cooo]Z00coP_l0o`3o/?oonf[o
0?naoookJ_l0<?oooo]Zo`3oCOoonf[o0>SooookJ_l60?l2oookJP03ool0mOnBo`3ooo]Z00?ooo]Z
00Co403ooookJ_oo06[o01Wo1OoonfX01OlE0?ooo`1AoookJ_oonf[o0:go00;ooo]Z00?oo`1ioook
J_oonfX02_oonfX01ol0oe?ooo]ZoookJ_l0o`Sooo]Zo`3o7Ol0hOl0<_oonfX002gooo]Z00?ooaH0
oonB0?oonfX01_oonfX00ooo0?cooo]ZoookJP02oookJP04oaP0oooonf[ooo]Zool600;ooo]Z00?o
jol0oookJ_oo0?H01?oonfX00ol0Y_oooo]ZojP0o`04oiCo0003o`1goooonf[ooo]Z00;ooo]Z00Go
of`0oon10?oonf[ooo]Zoc_o0004oookJP03o`3koooonf[ooo]Z00;ooo]Z00?oo`<0oookJ_oonfX0
0_oonfX01?oo0=gooo]Zoil0oonco`04oookJP;oU?l000Co0?oNoiCo0?oUo`3oU?l00_oonfX02?oo
06cooo]ZoookJ_m=0?ooobh0oookJ_l0o`co0?m51?oonfX00ooUo`3oA?l0o`3oT005odCo00Kooo]Z
00?oJ03ooookJ_oonfX00_oonfX00olH0?ooi_l0oookJP02oookJP03oon@0?oonf[ooo]Z00[ooo]Z
00Cookh0o`3o1Ooonf[oiOl01_oonfX00oooE`3ooo]ZoookJP04oookJP03ool0;Ooonf[ooo]Z00Oo
oo]Z00?oiOl0oookJ_oonfX01OoonfX7o`3o3003oiCo0?oUo`3oiOl000?oiOl000Co0?m>o`3o=?oU
o`3oiOl01_oonfX02?l0hOoo0?lMo`00Ool0o`Sooo]Zo`00Ool0oe?o001o0_oonfX2o`00O`07ool0
NOoonf[o0:gooookJ_oo057o5@3oo`00O`02oookJP03oa00oooo06[ooo]Z00;oT_l00_l000000ol6
0?oo0>Soo`3oC@02o`0`o`03o`3o/Ooonf[oP_l000;ooo]Z0_l0oe/2oc7o01Oooo]Z0olPo`03obH0
o`03oookJ_oob@3oolT000coolT03ooonfX>om[o00_ooo]Z1?lV0?l00olPo`3oU?l0oiCo000Moook
JP;o<Ol000?ooo]Zo`3oFooonfX00ooonfX02_n2o`3ooo]ZonGo0?oonf[o0?naonGo0?l0<?oo0?m=
oookJ_l0j?l2oookJP04o`H0oooonf[ooo]Zoi;o00Cooo]Z00Go0?n]oookJ_oo06[ooo]Zo`0Io`04
oookJP03oaD0oooonf[oo`1A00CoiOl000?oo`1ionGo0?oonfX02OoonfX00ol0oe?ooo]ZoookJP02
oookJP04odCo0?oonf[o0?lMo`3Qoe[ooo]Z00?ooaH0oonB0?oonfX01_oonfX00ooo0?cooo]Zoook
JP03oookJP08oaP0oooonf[ooo]Zool60?oonf[ojol0oookJ_oo0?H4oookJP08o`2Voooonf[ooo]Z
ojP0oooonf[oo`3ioookJ_l0Mol4oookJP05oom/0?oonf[ooh40oookJ_lko`001OoonfX01Ol0nooo
oo]ZoookJ_oonf[oo`<000Cooo]Z00Goo`3MoookJ_oonf[o0:?ook?o0006oookJP03o`3og_oonf[o
o`2700;ooo]Z00Soo`1/oookJ_oonf[oC@3ooookJ_oo;P3ooo]Zof40o`Cooo]Z00GohP3ooookJ_l0
oi3ooo]Zo`3oTP09oookJP03ofP0oooonf[ooo]Z00?ooo]Z00?o603oonKo0?oonfX00_oonfX00ooo
T03ooo]ZoookJP0:oookJP04oonn0?l0o`Goj`3oog00o`Gooo]Z00?ooeL0oookJ_oonfX01?oonfX0
0ooo02gooo]ZoookJP07oookJP03oon10?oonf[ooo]Z00Sooo]Z00?o0=Coo`04oooonfX00_oonfX0
0ol0ZOoooo]ZoookJP03oookJP03o`3oC_l0ocCooo]Z00Oooo]Z00Oo0>7oo`3o7Ooonf[o0?l8o`00
Ool0oe?o001o00;ooo]Z0_l007l01ooo07Wooo]Zo`2]oooonf[oo`1AoaD0ool007l00_oonfX00ol0
GOoo403ooookJP02oi;o0006ool0mOl0003o0000o`H0ool0j?oo0?m=0_l0<?l00ooonf[oP_l0oh;o
0002oookJP03o`3oFolao`3o<Ol001Sooo]Z0olPo`03obH0o`?ooo]Z1OoQo`05om[o017ooo]Z3_oJ
o`0;oookJPCo9P3o0_lPo`0MoookJP;o<Ol00_oonfX00ol0oe_ooo]ZoookJP02oookJP0<oh;o0?l0
ok3ooo]Zo`3o/Ooonf[o033ooookJ_l0odgooo]Zo`3Xoooonf[o1P3o0_oonfX00ooo0?GoT_l0oook
JP02oookJP05oa00ool0GOoooo]Zool0J_l06Ol01OoonfX01olE0?ooo`1AoookJ_oonf[o0:gooook
J_oo07T03?oonfX02?l0oe?ooo]ZoookJ_oonf[o0?l8oookJ_l0oago0>7o<OoonfX002gooo]Z00?o
oaH0oonB0?oonfX01_oonfX01Ooo0?cooo]ZoookJ_oonf[o603o00?ooo]Z00Koo`H0oookJ_oonf[o
jol0oookJ_oo0?H3oookJP03o`2Voooonf[ooo]Z00GoU?l000Wo07OooookJ_oonf[ooo]Zoom/0?oo
P@3o0?o<oookJ_lko`001OoonfX00ol0nooooo]ZoookJP02oookJP09ool30?oonf[ooo]ZoookJ_mi
0?ooo`3Mo`0GoonO0?oo/ol000?ooo]Z0onDo`000ol0omkoiOl0oiCo0002oookJP09ool0K?oonf[o
oo]ZoookJ_m=0?oooo]Zo`3o3?oonf[o0?m500?ooo]Z0_oUo`000ol0oi3oA?l0odCo0004odCo00Go
oo]Z00?oJ03ooookJ_oonfX00ooonfX01OlH0?oo07CooookJ_oonf[ooi0000cooo]Z00Gookh0oook
J_l0o`GoiOl0og00o`05oookJP03oomG0?oonf[ooo]Z00Cooo]Z00?oo`0]oookJ_oonfX02?oonfX0
0ooUo`3ooo]ZoookJP06oookJPGo0?l<00CoU?l0onGo0?oonf[ooo]Z0_oUo`000ol0odko0?ldonGo
0002onGo00Gooo]Z00Oo0>7oo`3o7Ol007oo0?l8o`00Oooonf[o0?mC00;o001o0_oonfX01_l007oo
o`1io`00Ool0[Ooooo]Zool0D@?o001o00Oooo]Zoa00oooo06[ooo]Zoi;o0?oonf[o000000;o1P3o
0_l0odd00ol0<?oo0?nao`3o/@02oh;o00;ooo]Z00?o0?mKoc7o0?lao`005ooonfX2ob3o00?o9P3o
1?oonfX<ooo901kooo]Z00CohOl0om[o0?oJo`3of_l03?oonfX3obH0o`03oiCo0?oonf[ooo]Z01co
oo]Z00Co<Ol0oookJ_l0oe_o0?mK0ooonfX00on2o`3ooo]ZonGo0003onGo0004o`0`ool0odgooo]Z
o`3Xo`;ooo]Z00Co1P3ooookJ_oonf[oT_l01?oonfX01?l0ojgooo]Zool0J_l06Ol5oookJP03oaD0
oooUo`3oo`1A00CoiOl000?oo`1ionGo0?oonfX02OoonfX01Ol0oe?ooo]ZoookJ_oonf[oA?l000;o
oo]Z00?o0?lMo`3QoooonfX0F?oonfX00ooo5P3ooi80oookJP06oookJP03ool0o?oonf[ooo]Z00;o
oo]Z00Wo603ooookJ_oonf[ooo]Zool60?oonf[ojol0oookJ_oo0?H00ooonfX01?l0Y_oooo]Zoook
J_nX0?l2oookJP03ool0nOoonf[o07Oo00?ooo]Z00Ko0?nJoom/0?ooP@3o0?o<oookJ_lko`05oook
JP05o`3koooonf[ooo]ZoookJ_oo0`000ooonfX01Omi0?ooo`3MoookJ_l05ooo/ol000Kooo]Z00?o
gOl0o`3og_oo08L00ooonfX02?oo06cooo]ZoookJ_m=0?ooobh0oookJ_mQ0?oo0?m50ooonfX00ooR
0?oooo]Zo`3oT002oookJP03o`3oT_oonf[ooo]Z00Kooo]Z00?oJ03ooookJ_oonfX00ooonfX00olH
0?ooi_l0oookJP02oookJP03oon@0?oonf[ooo]Z00[ooo]Z00Cookh0oookJ_l0o`Goj`3o1_oonfX0
0oooE`3ooo]ZoookJP04oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooh40oookJ_oonfX01ooonfX0
0ol0e?oo00CooookJP02oookJP03o`2Yoooonf[ooo]Z00?ooo]Z00?o0?m>o`3o=?oonfX01ooonfX0
1_l0hOoo0?lMo`00Ool0o`Sooo]Zo`3oD`;o001o0_oonfX01_l007ooo`1io`00Ool0[Ooooo]Zool0
D@?o001o00Kooo]Zool0J_l@0?oooo]Zoi;o0?oo0?D2o`0000;o1P3o0_l0odd01?l0<?oo0?naoook
J_n2o`02oookJP03o`3oFolao`3o<Ol001Oooo]Z0olPo`03obH0o`?ooo]Z0ooQo`000ooonf[of_l0
om[o0002om[o02;ooo]Z0_oQo`03om[o00cooo]Z0olV0?lNoookJP03oc7o0?oonf[ooo]Z00;o0?mK
0ooonfX03?n2o`3o0?n`oookJ_l0ok7ooo]Zo`0`oooonf[o0?m=oookJ_l0j?oooo]Zo`H0o`;ooo]Z
00?oo`3eoi;o0?oonfX00_oonfX01?l@0?oo05gooookJ_l06Ol6oookJP07oaD0oooo057ooo]Zoook
J_l0[Ooooo]Zool0N@0<oookJP04o`3oDooonf[ooo]Zo`3o20;ooo]Z00?o0?lMo`3QoooonfX0;ooo
nfX002cooo]Z00?ooaH0oookJ_ooTP001_oonfX00ooo0?cooo]ZoookJP02oookJP07oaP0oooonf[o
oo]ZoookJ_oo1P3ooo]Zon_o0002oookJP07ool0m_oonf[ooo]ZoookJ_l0Y_oooo]ZojP0o`05oiCo
0009o`1goooonf[ooo]ZoookJ_ooK03ooh40o`3oc?oonf[o>ol000Cooo]Z00?o0?_ooookJ_oonfX0
0ooonfX02?oo0`3ooo]ZoookJ_mi0?ooo`3MoookJ_nO0?oo/ol01?oonfX3oiCo0003o`3og_oUo`3o
U?l000;ooo]Z00Soo`1/oookJ_oonf[oC@3oool^0?oonf[o0?l<o`3oA@?ooo]Z0_oUo`000om4o`3o
0?n@odCo0005odCo00Cooo]Z00?oJ03ooookJ_oonfX00ooonfX00olH0?oo07CooookJP02oookJP03
oon@0?oonf[ooo]Z00Wooo]Z00Gookh0oookJ_l0o`GoiOl0og00o`06oookJP03oomG0?oonf[ooo]Z
00Cooo]Z00?oo`0]oookJ_oonfX01ooonfX00ooUo`3ooo]ZoookJP07oookJPGo0?l<00?oiOl0oiCo
0?oonfX00_oonfX00ooUo`3o0?m>onGo0002onGo00Kooo]Z00?o0?lMoookJ_l0o`P00_l007l01?l0
oe?o001oo`00Ool007l2oookJP06ool0NOl007oo0:gooookJ_oo057ooo]Z0ol007l01?l@0?oooo]Z
oi;o0?nBo`02oookJP03o`H0ool0003o0?m=00;o033o00Go0?naoookJ_n2o`3o0?n`oookJP02o`3o
F`03oc7o0?oonf[ooo]Z01Cooo]Z0_lPo`03obH0o`Cooo]Z0ooQo`0:ooo902Cooo]Z0ooJo`02on7o
00Wooo]Z00CoQ03oobH0oonDo`3oU?l07OoonfX01?lao`3ooo]ZoookJ_l0oe/3oookJP03oh;o0?oU
o`3oiOl000?oiOl000?o033oo`3oCOl0j?l00ooonfX01?l60?oooo]ZoookJ_nBo`04oookJP04o`3o
[Ooonf[oo`1Zo`0Io`Gooo]Z00?o5@3oonGo0?oo05400ooUo`000ooo07WoiOl0oookJP09oookJP03
o`3oDooonf[ooo]Z00;ooo]Z00CoA?l0oookJ_l0oago0>7oF?oonfX00ooo5P3ooo]ZoonB0006oook
JP03ool0o?oonf[ooo]Z00?ooo]Z00Ko603ooookJ_oonf[oo`H0oookJ_o[o`02oookJP05ool0m_oo
nf[ooo]ZoookJ_l0Y_l00_oonfX00onX0?oooo]Zool0n@02oookJP09o`1goooonf[ooo]ZoookJ_oo
K03ooo]Zoon10?l0olco>ol000Gooo]Z00?o0?_ooookJ_oonfX00_oonfX01Ooo0`3ooo]ZoookJ_mi
0?ooo`3M00;ooo]Z00?o0:?ook?o0?oonfX01OoonfX00ooMo`3o0?oNool0Q`02oookJP08ool0K?oo
nf[ooo]Zodd0oooonf[oobh0oookJ_mQ0?l4oookJP03on80oooonf[o0?n@00;ooo]Z00?o0?nBoook
J_oonfX01OoonfX00omX0?oooo]ZoookJP04oookJP03oaP0oooonf[ooo]Z00;ooo]Z00?ooi00oook
J_oonfX02OoonfX01Ooo_P3ooo]Zo`3o1Oo[0?ooL03o00Gooo]Z00?ooeL0oookJ_oonfX01?oonfX0
0ooo02gooo]ZoookJP07oookJP03oon10?oonf[ooo]Z00Oooo]Z00?o0=Coo`04oooonfX00_oonfX0
0ol0ZOoooo]ZoookJP03oookJP03o`3o;_l0odkooo]Z00Sooo]Z00Go0?lMoookJ_l0o`So001oo`3o
D`03o`00O`;ooo]Z00Koo`1io`00Ool0[Ooooo]Zool0DOoonfX3o`00O`0=ool0J_l@0?ooT_l0oi;o
0?oo0?Gooo]Zo`000?l60?oo0>Soo`3oCOl0<?oo0?naoookJP02oh;o00;ooo]Z00?o0?mKoc7o0?oo
nfX05OoonfX3ob3o00?o9P3o0ooonfX3on7o00Cof_l0:ooonfX3om[o0003on7o0?oonf[ooo]Z00So
oo]Z00?oQ03oobH0oolPo`007OoonfX01Olao`3ooo]ZoookJ_oonf[o0?mK00?ooo]Z00WoP_l0o`3o
/?oonf[o0?naoookJ_l0<?oooo]Zo`3oCOl0j?l00_oonfX01Ol60?oooo]ZoookJ_oo0?GoT_l000?o
oo]Z00Co403oo`1Moooonf[o01Wo1OoonfX01OlE0?oooo]Zool0DOoonf[o0:go00;ooo]Z00?oo`1i
oookJ_oonfX02OoonfX02?l0oe?ooo]ZoookJ_oonf[o0?l8oookJ_l0oago0>7o<?oonfX002cooo]Z
00?ooaH0oonB0?oonfX01_oonfX01Ooo0?cooo]ZoookJ_oonf[o603o00?ooo]Z00Koo`H0oookJ_oo
nf[ojol0oookJ_oo0?H4oookJP03o`2Voooonf[oU?l000CoU?l000Oo07OooookJ_oonf[ooo]Zoom/
0?oonf[ooh4000;ooo]Z00?o>ol0oookJ_oonfX00_oonfX00ol0nooooo]ZoookJP02oookJP09ool3
0?oonf[ooo]ZoookJ_mi0?ooo`3Mo`0GoonO0?oo/ol000?ooo]Z0onDo`001_l0omkoiOl0oiCo0?nD
o`3ooo]Zool0K0;ooo]Z00KoC@3oool^0?oonf[o0?l<oookJ_l0odD2oookJP?oiOl000?o0?n@odCo
0?m4o`001?m4o`05oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603oonKo0?l0M?l00_oonfX00ooo
T03ooo]ZoookJP0:oookJP05oonn0?oonf[o0?l5onGo0?m`0?l01OoonfX00oooE`3ooo]ZoookJP04
oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?oiOl0oookJ_oonfX01ooonfX00ol0o`coU?l0o`04o`03
o`3o3003oiCo0?oonf[ooo]Z00;ooo]Z00?o0?m>onGo0?oUo`000_oUo`05oookJP03o`3o7Ooonf[o
0?l800;ooo]Z00?o0?mCo`00Ool007l00_l007l01_oonf[oo`1io`2]ool0[Ooo001oool0D@;ooo]Z
00Go001ooa00ool@0?oooo]Zoi;o0003oookJP05o`H0ool0j?oo0?m=onGo0?l0ok400_oonfX01_n2
o`3ooo]Zo`3oFol0oe_ooo]Zoc7o01Cooo]Z0_lPo`03obH0o`Gooo]Z1Ooob@000ooonf[oolT0ooo9
0005ooo902Wooo]Z0ooJo`03on7o00Oooo]Z0_lV0?l00onDo`3ooo]ZoookJP0KoookJP04oc7o0?oo
nf[ooo]Zo`3oF`;ooo]Z00?oiOl0oh;o0?oUo`000ooUo`001?l0<?oooo]Zo`3oCOl0j?l3oookJP04
o`H0oooonf[ooo]Zoi;o00Cooo]Z00Co0?n]oookJ_oo06[o01Wo1?oonfX01?lE0?oooo]ZonGo0?oo
0543onGo0003ool0NOoonf[ooo]Z00Wooo]Z00Go0?mCoookJ_oonf[ooo]ZodCo0002oookJP03o`3o
7Ol0hOoooo]Z05Kooo]Z00?ooaH0oonB0?oonfX01_oonfX00ooo0?cooo]ZoookJP02oookJP09oaP0
oooonf[ooo]ZoookJ_oo1P3ooo]Zon_o0?oonf[oo`3f00Cooo]Z00So0:KooookJ_oonf[oZ03ooook
J_oo0?Wooo]Zo`1go`?ooo]Z00Ko0?nJoom/0?oonf[ooh40oookJ_lko`05oookJP05o`3koooonf[o
oo]ZoookJ_oo0`000ooonfX01Omi0?ooo`3MoookJ_l05ooo/ol000Kooo]Z00?ogOl0o`3og_oo08L0
0ooonfX02?oo06cooo]ZoookJ_m=0?ooobh0oookJ_mQ0?oo0?m50ooonfX00ooR0?oooo]Zo`3oT002
oookJP03o`3oT_oonf[ooo]Z00Kooo]Z00?oJ03ooookJ_oonfX00ooonfX00olH0?ooi_l0oookJP02
oookJP03oon@0?oonf[ooo]Z00[ooo]Z00Cookh0o`3o1Oo[0?ooL03o1OoonfX00oooE`3ooo]Zoook
JP04oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooh40oookJ_oonfX02?oonfX01_l0e?oo00Cooook
J_oonf[o0:Woo`28o`Cooo]Z00?o0?l^o`3oC_oonfX02?oonfX01Ol0oagooo]Zo`3o2?oonf[o0?mC
00Co001o00Kooo]Zool0NOl007oo0:goo`00Oooo0542oookJP06o`00Oooo06[o403ooa00oonBo`3o
o`3e0ooonfX01ol60?oo0>Soo`3oCOl0<?oo0?naoookJ_n2o`000_oonfX2o`3oF`03oc7o0?oonf[o
oo]Z01?ooo]Z0_lPo`03obH0o`Cooo]Z1OoJo`0boookJP;of_l00ooQo`08oookJP;o9P3o00?o8?l0
oookJ_oonfX06_oonfX01Olao`3ooo]ZoookJ_oonf[o0?mK00?ooo]Z00WoP_l0o`3o/?oonf[o0?na
o`0`oooonf[o0?m=oookJ_l0j?l00_oonfX01?l60?oooo]ZoookJ_nBo`04oookJP04oa00oooonf[o
oo]Zo`0Io`Gooo]Z00Oo5@3ooookJ_oo057ooo]Zo`2]oooonf[oo`1i00cooo]Z00Co0?mCoookJ_oo
nf[o0?l80_oonfX00ol0oago0>7ooookJP0^oookJP00;?oonfX00ooo5P3ooi80oookJP05oookJP03
ool0o?oonf[ooo]Z00;ooo]Z00Go603ooookJ_oonf[ooo]Zool60002oookJP03on_o0?oonf[oo`3f
00?ooo]Z00?o0:KooookJ_nDo`001OnDo`002Ol0Mooooo]ZoookJ_oonf[oof`0oon10?l0olcooo]Z
oc_o0004oookJP03o`3koooonf[ooo]Z00?ooo]Z00Soo`<0oookJ_oonf[oN@3oool0gOoonf[oW`3o
ok?o00?ooo]Z1?nDo`001_l0omkoiOl0oiCo0?nDo`3ooo]Zool0K0;ooo]Z00GoC@3ooookJ_oonf[o
0?l<o`3oA@02oookJPCoiOl000?o0?n@oookJ_oonfX01?m4o`04oookJP03ofP0oooonf[ooo]Z00?o
oo]Z00?o603oo`1doooonfX00_oonfX00oooT03ooo]ZoookJP09oookJP05oonn0?oonf[o0?l5onGo
0?m`0?l01OoonfX00oooE`3ooo]ZoookJP04oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?oiOl0oook
J_oonfX01ooonfX00ol0o`coU?l0o`04o`02oiCo0003o`3o3?nDo`3oU?l000?ooo]Z00?o0?m>o`3o
=?oonfX00ooUo`04oookJP03o`3o7Ooonf[o0?l800;ooo]Z00?o0?mCo`00Ool007l00_l007l2ool0
N@0;o`2]oooonf[o5@3oool0DOl007oooo]Zo`00Ool@0?oo05gooookJ_nBo`000_oonfX2o`H0o`;o
0?m=0_oUo`000ol0003oP_l0oh;o0002o`3oF`03oookJ_lao`3o<Ol001?ooo]Z00Co8?l0obH0oolV
0?oo9P3o1?oonfX4ooo900Kooo]Z1Ooob@03oookJPgoo`0C2Ooo09<8ool04`gooo]Z0ooJo`03on7o
00Kooo]Z0_lV0?l00onDo`3ooo]ZoookJP03oookJP03oiCo0?oonf[ooo]Z01Cooo]Z00?o<Ol0oook
J_oonfX00_l0oe/2onGo0003oh;o0?oUo`3oiOl000;oiOl000Co033ooookJ_l0odgo0>So0ooonfX0
1?l60?oooo]ZoookJ_nBo`03oookJP04o`3o[Ol0GOoooo]Zo`0Io`Gooo]Z00?o5@3ooookJ_oo0540
1?oUo`000ooo07Wooo]ZoookJP08oookJP03o`3oDooonf[ooo]Z00;ooo]Z00GoA?l0oookJ_l0oago
oo]Zo`3Qo`1FoookJP03oolF0?ooTP3ooo]Z00Gooo]Z00?oo`3loookJ_oonfX00ooonfX01?lH0?oo
oo]ZoookJ_oo1P02oookJP03on_o0?oonf[oo`3f00?ooo]Z00Co0:KooookJ_oonf[oZ03o0_oonfX0
0ooo0?Wooo]Zo`1go`03oookJP05oom/0?oonf[ooh40o`3oc?lko`001OoonfX00ol0nooooo]Zoook
JP02oookJP09ool30?oonf[ooo]ZogT0oooo0=gooo]Zo`0Gool0Xooo/ol000Kooo]Z00?ogOl0o`3o
g_oo08L00_oonfX01Ooo06cooo]ZoookJ_m=0?ooobh000;ooo]Z00?oH@3ooookJ_oonfX00_oonfX0
0ooR0?oooo]Zo`3oT002oookJP03o`3oT_oonf[ooo]Z00Gooo]Z00?oJ03ooookJ_oonfX00ooonfX0
0olH0?ooi_l0oookJP03oookJP03oon@0?oonf[ooo]Z00Wooo]Z00Cookh0oookJ_l0o`Goj`3o1Ooo
nfX00oooE`3ooo]ZoookJP05oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooh40oookJ_oonfX02?oo
nfX01_l0e?oo00CooookJ_oonf[o0:Woo`28o`Cooo]Z00?o0?l^o`3oC_l0oc@02?oonfX01Ol0oago
oo]Zo`3o2?oonf[o0?mC00Co001o0_oo07T03?oonf[o0:gooaD0oooo057o001ooookJ_l007ooo`1Z
oa00oooonf[oT_l0ool0m@;ooo]Z0_l60?l2o`3oC@05o`3o/Ol0003ooo]Zoh;o0?oonfX00_l0oe/2
oc7o01?ooo]Z0_lPo`03obH0o`?ooo]Z1?oJo`0>oookJPgoo`0C2Ooo09<8ool04`gooo]Z0ooJo`03
on7o00Oooo]Z00?o9P3oob3o0?n40?l06ooonfX01?lao`3ooo]ZoookJ_oonfX2o`3oF`;ooo]Z00Wo
P_l0o`3o/?l0ok7ooo]Zo`0`oooonf[o0?m=oookJ_l0j?l00_oonfX01?l60?oooo]ZoookJ_nBo`03
oookJP05oa00ool0GOoooo]Zo`0Ioooo06X01?oonfX00olE0?oooo]Zool0D@02oookJP03o`2]oooo
nf[oo`1i00_ooo]Z00Wo0?mCoookJ_oonf[ooo]Zo`3o2?oonf[o0?lMoookJ_l0hOl0;_oonfX002_o
oo]Z00?ooaH0oonB0?oonfX01_oonfX00ooo0?cooo]ZoookJP02oookJP04oaP0oooonf[ooo]Zool6
00;ooo]Z00?ojol0oookJ_oo0?H01?oonfX00ol0Y_oooo]ZoiCo0005oiCo0006o`1goooonf[ooo]Z
oom/0?oonf[ooh400_oonfX00olko`3ooo]ZoookJP02oookJP03o`3koooonf[ooo]Z00;ooo]Z00Wo
o`<0oookJ_oonf[ooo]ZogT0oooo0=go01Oooil0oonco`000_oonfX4oiCo0003o`3og_oUo`3oU?l0
00;oU?l000[oo`1/oookJ_oonf[oC@3oool^0?oonf[o0?l<oookJ_l0odGooo]Z1OoUo`02oookJP05
odCo0?oonf[ooo]ZoookJ_m4o`001?oonfX00omX0?oooo]ZoookJP02oookJP03oaP0ool0M?oooo]Z
00;ooo]Z00?ooi00oookJ_oonfX02OoonfX01Ooo_P3ooo]ZoookJ_oUo`3oL03o00Gooo]Z00?ooeL0
oookJ_oonfX01OoonfX00ooo02gooo]ZoookJP07oookJP03onGo0?oonf[ooo]Z00Oooo]Z00Go0?l<
o`04oonDo`3oU?l0onGo0002oiCo00?ooo]Z00?o0?m>o`3o=?oonfX00_oonfX00ooUo`3ooo]Zoook
JP02oookJP03o`3o7Ooonf[o0?l800;ooo]Z00?o0?mCoookJ_oonfX00_l007l01_oo07Wo001oo`2]
oooonf[o5@3oool0D@?o001o00Co403oo`1Mool007ooT_l00_oonfX00ol60?ooiOl0o`3oC@03onGo
0004o`000?n2o`3o0?n`o`3oF`;ooo]Z00?o<Ol0oookJ_oonfX04?oonfX01?lPo`3o9P3oobH0oolV
0?l4oookJP04om[o0?oob@3oolT0on7o00Wooo]Z0ooob@000ooonf[oo`0Cool04`02ool04`goo`2C
0_l0nOl7oookJPCoo`2C1?oonfX3ool04`gooo]Z0_oJo`000ooonf[ohOl0oookJP06oookJP03obH0
oonDo`3oQ03o00?ooo]Z00?oU?l0oookJ_oonfX05OoonfX01Olao`3ooo]ZonGo0?oUo`3o0?mK00;o
iOl000?oP_l0onGo0?oUo`000_oUo`000ol0<?oooo]Zo`3oC@04oookJP04o`H0oooonf[oo`3eoi;o
00?ooo]Z00Co0?n]oookJ_oo06[o01Wo1?oonfX01?lE0?oooo]ZoookJ_oo0543onGo0003ool0NOoo
nf[ooo]Z00Wooo]Z00?o0?mCoookJ_oonfX00_oonfX01Om4o`3o0?lMoookJ_l0hOooA?l005Cooo]Z
00?ooaH0oonB0?oonfX01_oonfX00ooo0?cooo]ZoookJP03oookJP06oaP0oooonf[ooo]Zool60?oo
nf[ojol00_oonfX01Ooo0?Kooo]ZoookJ_oonf[o0:Ko00;ooo]Z00?oZ03ooookJ_oo0?T00_oonfX0
2Ol0Mooooo]ZoookJ_l0oi[oof`0oookJ_ooP@3ooo]Zoc_o0005oookJP05o`3koooonf[ooo]Zoook
J_oo0`000ooonfX01Omi0?ooo`3MoookJ_l05ooo/ol000Oooo]Z00?o0?oNool0QooonfX00_oonfX0
2?oo06cooo]ZoookJ_m=0?ooobh0oookJ_mQ0?oo0?m51?oonfX01OoR0?oo0?n@oookJ_oonf[o0?nB
00Sooo]Z00?oJ03ooookJ_oonfX00ooonfX00olH0?oooo]ZoookJP02oookJP03oon@0?oonf[ooo]Z
00Wooo]Z00Gookh0oookJ_l0o`Goj`3oog00o`05oookJP03oomG0?oonf[ooo]Z00Cooo]Z00?oo`0]
oookJ_oonfX01ooonfX00oooP@3ooo]ZoookJP07oookJP06o`3Dool01?oooo]ZoookJ_l0ZOoo08So
1OoonfX00ol0odko0?ldoookJP07oookJP05o`3o7Ooonf[o0?l8oookJ_l0oe<00_oonfX2o`00O`06
ool0NOl007oooo]Zo`2]oolE0?ooo`1A0ol007l01Ooo06[o403oo`00OonBo`3oo`3e00;ooo]Z00Co
1P3ooookJ_l0odgo033o0_l00002oh;o0004oookJ_l0oe_ooo]Zoc7o01;ooo]Z0_lPo`03obH0o`?o
oo]Z0ooJo`000ooQo`3ooo]ZoookJP0<oookJP?oo`0C3Ooo09<2o`3io`Oooo]Z1?oo09<4oookJP?o
o`0C3OoonfX3om[o0003on7o0?oonf[ooo]Z00Gooo]Z0_lV0?l00olPo`3oQ03ooookJP0IoookJP03
oc7o0?oonf[ooo]Z00;ooo]Z00_o0?mKoookJ_oonf[oP_l0o`3o/?l0ok7ooo]Zo`0`oooonf[o0?m=
o`3Xo`03oookJP04o`H0oooonf[oo`3eoi;o00?ooo]Z00Co403oo`1Moooonf[o01Wo1OoonfX00olE
0?oooo]Zool0D@02oookJP03o`2]oooonf[oo`1i00_ooo]Z00Ko0?mCoookJ_oonf[ooo]Zo`3o2?l0
oad2oookJP03o`3Qoooonf[ooo]Z02_ooo]Z000[oookJP03oolF0?ooTP3ooo]Z00Kooo]Z00Goo`3l
oookJ_oonf[ooo]ZoaP0o`03oookJP06ool60?oonf[ooo]Zon_o0?oonf[oo`3f0ooonfX00ol0Y_oo
oo]ZoiCo0005oiCo0007o`1goonDo`3ooo]ZoookJ_ooK03ooo]Zoon10002oookJP05oc_o0?oonf[o
oo]ZoookJ_l0nol01OoonfX02?oo0`3ooo]ZoookJ_mi0?ooo`3Mo`0Goooonf[o/ol01OoonfX2oiCo
0006o`3og_oUo`3oU?l0oiCo0?oonf[oo`1/0_oonfX01Om=0?oooo]ZoookJ_l0o`co0?m500;ooo]Z
1OoUo`02oookJP03odCo0?oonf[ooo]Z00Gooo]Z00?oJ03ooookJ_oonfX00ooonfX00olH0?oo07Co
oookJP02oookJP03oon@0?oonf[ooo]Z00Wooo]Z00Gookh0oookJ_l0o`GoiOl0og00o`05oookJP03
oomG0?oonf[ooo]Z00Cooo]Z00?oo`0]oookJ_oonfX01ooonfX00ooUo`3ooo]ZoookJP07oookJP05
o`3o3?l01?ooU?l0oiCo0?oUo`000onDo`02oookJP03o`3oC_l0ocCooo]Z00Oooo]Z00?o0?lMoook
J_l0o`P00_oonfX00ol0oe?ooo]ZoookJP02oookJP0>ool0NOl007oo0:gooookJ_lE0?ooo`1Aoook
J_l007oo01Wooa00ool0GOoo001ooi;o0?oonfX2o`H0o`;o0?m=0ooUo`02oh;o0005o`000?l0oe_o
oo]ZoookJ_lao`004OoonfX01?lPo`3oU?l0oiCo0?n40?l4oookJP;of_l00_oQo`09oookJPGoolT0
1Ooo09<00ooonf[o0?Woo`3io`03o`3io`Wooo]Z2ol0nOl4ool0T`?ooo]Z0ooo01<<oookJP?of_l0
00?ohOl0oookJ_oonfX01?oonfX2obH0o`03oiCo0?n40?ooU?l000;oU?l05ooonfX01Olao`3ooo]Z
oookJ_oUo`3o0?mK00;oiOl000?oP_l0onGo0?oUo`000_oUo`02oookJP03o`3oCOoonf[ooo]Z00;o
oo]Z00Co1P3ooookJ_oo0?GoT_l00ooonfX01?l0ojgooo]Zo`0IoooonfX2o`3o[@;ooo]Z00?o5@3o
oookJ_oo05401?oUo`000ooo07Wooo]ZoookJP08oookJP03o`3oDooonf[ooo]Z00;ooo]Z00GoA?l0
oookJ_l0oagoA?l0o`3Qo`1DoookJP03oolF0?ooTP3ooo]Z00Kooo]Z00?oo`3loookJ_oonfX00_oo
nfX02OlH0?oooo]ZoookJ_oonf[oo`H0oookJ_o[o`3ooo]Zool0mP03oookJP04o`2Voooonf[ooo]Z
ojP0o`;ooo]Z00?oo`3ioookJ_l0Mol00ooonfX01_l0oi[oof`0oookJ_ooP@3ooo]Zoc_o00Cooo]Z
00?o0?_ooookJ_oonfX00_oonfX02Ooo0`3ooo]ZoookJ_mi0?ooo`3MoookJ_l05ooo0:?ook?o0006
oookJP03omgo0?l0omkoo`2700;ooo]Z00Goo`1/oookJ_oonf[oC@3oool^0002oookJP03of40oooo
nf[ooo]Z00;ooo]Z00?ohP3ooookJ_l0oi000_oonfX00ol0oi;ooo]ZoookJP05oookJP03ofP0oooo
nf[ooo]Z00?ooo]Z00?o603oonKo0?oonfX00ooonfX00oooT03ooo]ZoookJP09oookJP04oonn0?oo
nf[oj`3oog00o`Gooo]Z00?ooeL0oookJ_oonfX01?oonfX00ooo02gooo]ZoookJP07oookJP03oon1
0?oonf[ooo]Z00Oooo]Z00Ko0=CooookJ_l01?oooo]Zo`2Yool0R?l5oookJP03o`3oC_l0ocCooo]Z
00Oooo]Z00Go0?lMoookJ_l0o`Sooo]Zo`3oD`04oookJP07ool0NOl007oo001oo`2]oolE0?ooo`1A
oookJP02o`00O`06o`0Iool@0?oo001ooi;o0?oo0?Gooo]Z0_l60?l2o`3oC@09o`0`ool0003o0000
oh;o0?l0003ooo]Zo`3oFooonf[o<Ol0017ooo]Z00Go8?l0obH0oolV0?oo9P3ooh@0o`03oookJP;o
f_l00_oQo`0<oookJPOoo`2C00?ooo]Zo`3iool0nOl00ol0nOl9oookJP_o0?Wo1?oo09<3oookJP?o
o`0C3OoonfX2om[o0003on7o0?oonf[ooo]Z00Gooo]Z00Co9P3oob3o0?n40?ooQ03o6OoonfX00ola
o`3ooo]ZoookJP02oookJP07o`3oFooonf[ooo]Zoh;o0?l0ok3o0?nao`0`o`02oookJP03o`3oCOl0
j?oooo]Z00;ooo]Z00Co1P3ooookJ_oo0?GoT_l00ooonfX01?l@0?oo05goo`0Ioooo06X5oookJP03
oaD0oooo057ooo]Z00;ooo]Z00?o0:gooookJ_oo07T02_oonfX02Ol0oe?ooo]ZoookJ_oonf[o0?l8
oookJ_l0oagooo]Zo`3Qo`0]oookJP00:_oonfX00ooo5P3ooi80oookJP06oookJP03ool0o?oonf[o
oo]Z00;ooo]Z00Go603ooookJ_oonf[ooo]Zool60002oookJP03on_o0?oonf[oo`3f00?ooo]Z00?o
0:KooiCo0?nDo`001OnDo`001_l0Mooooo]ZoookJ_l0oi[oof`0oon100;ooo]Z00?o>ol0oookJ_oo
nfX00_oonfX00ol0nooooo]ZoookJP02oookJP09ool30?oonf[ooo]ZoookJ_mi0?ooo`3Mo`0GoonO
0?oo/ol000Kooo]Z00?o0?oNonGo0?nDo`000_nDo`002_oo06cooo]ZoookJ_m=0?ooobh0oookJ_l0
o`cooo]Zo`3oAOoonfX5onGo00;ooo]Z00?oA?l0oookJ_oonfX01_oonfX00omX0?oooo]ZoookJP02
oookJP03oaP0ool0M?oooo]Z00;ooo]Z00?ooi00oookJ_oonfX02OoonfX01Ooo_P3ooo]Zo`3o1OoU
o`3oL03o00Gooo]Z00?ooeL0oookJ_oonfX01?oonfX00ooo02gooo]ZoookJP07oookJP03onGo0?oo
nf[ooo]Z00Oooo]Z00Go0?l<oiCo0?l01?ooU?l0onGo0004oiCo0003oookJ_l0odko0?ld00Sooo]Z
00?o0?lMoookJ_l0o`P00_oonfX00ol0oe?ooo]ZoookJP02oookJP06ool0NOoonf[o0:gooookJ_lE
0?ooo`1A0_oonfX02_l06Ooo403oool0J_oonf[oT_l0oookJ_l60?ooiOl0o`3oCOl0j?l3onGo0004
oh;o0?l0ok3o0000o`3oF`;ooo]Z00?o<Ol0oookJ_oonfX03_oonfX4oiCo00Cooo]Z0_oJo`000ooQ
o`3ooo]ZoookJP02oookJP_oolT00ooonfX5o`3ioa_ooo]Z0_l0nOl4ool0T`03o`3ioooonf[oo`0C
00;oo`0C3?oonfX3om[o00Kooo]Z00?o9P3ooiCo0?nDo`000onDo`0GoookJP;o<Ol00_oonfX01?l0
oe_oiOl0onGo0?n2o`03onGo0004o`0`oooonf[o0?m=o`3Xo`Cooo]Z00?o1P3ooookJ_nBo`001?oo
nfX00ol0ojgoo`1Zo`3o[@02o`3o[@?ooo]Z00Co5@3ooookJ_oo057ooo]Z0ooUo`000ooo07Wooo]Z
oookJP08oookJP04o`3oDooonf[ooo]ZoookJP;oA?l000Co0?lModCo0?m4o`3o0>7oD_oonfX00ooo
5P3ooi80oookJP06oookJP03ool0o?oonf[ooo]Z00?ooo]Z00Co603ooookJ_oonf[oo`H00_oonfX0
0oo[o`3ooo]Zool0mP03oookJP04o`2Voooonf[ooo]ZojP0o`;ooo]Z00?oo`3ioookJ_l0Mol00_oo
nfX01_l0oi[oof`0oookJ_ooP@3ooo]Zoc_o00Gooo]Z00Go0?_ooookJ_oonf[ooo]Zool30003oook
JP05ogT0oooo0=gooo]Zo`0Goonco`001ooonfX00ol0omkoo`27oookJP02oookJP08ool0K?oonf[o
C@3ooookJ_oo;P3ooo]Zof40ool0odD4oookJP05on80ool0oi3ooo]ZoookJ_l0oi802?oonfX00omX
0?oooo]ZoookJP03oookJP03oaP0oooonf[ooo]Z00;ooo]Z00?ooi00oookJ_oonfX02OoonfX01?oo
_P3ooo]Zo`3o1Oo[0?l5oookJP03oomG0?oonf[ooo]Z00Gooo]Z00?oo`0]oookJ_oonfX01_oonfX0
0oooP@3ooo]ZoookJP08oookJP06o`3Dool01?oooo]Zo`2Yoooonf[o08So1?oonfX00ol0odko0?ld
oookJP07oookJP05o`3o7Ooonf[o0?l8oookJ_l0oe<01?oonfX01_oo07Wooo]ZoookJ_l0[Ooo5@3o
ool0D@?ooo]Z00co01Wooa00oooonf[oT_l0ool0mOoonf[o1P3ooookJ_l0odgo0>Soo`0`oooonfX2
oh;o00;o000000?o0?mKoookJ_lao`004OoonfX2obH0o`;oQ03o0ooonfX2om[o0003on7o0?oonf[o
oo]Z00Wooo]Z00Coo`0Cool0Tooo09?oo`2C0ooonfX5o`3ioa_ooo]Z0_l0nOl5ool0T`04oookJ_oo
01?oo`0Cool04`cooo]Z0ooJo`06oookJP;o9P3o00?o8?l0oh@0oon40?l06?oonfX2oc7o00?ooo]Z
00Oo0?mKoookJ_oonf[oP_l0o`3o/?l0ok7o033o00;ooo]Z00?o0?m=o`3XoooonfX00_oonfX01?l6
0?oooo]Zool0mOnBo`03oookJP03oa00oooonf[o01Wo00Gooo]Z00?o5@3ooookJ_oo05400_oonfX0
0ol0[Ooooo]Zool0N@0;oookJP06o`3oDooonf[ooo]ZoookJ_l0o`So0?lM0_oonfX00ol0hOoooo]Z
oookJP0ZoookJP00:ooonfX00oooTP3ooo]ZoookJP05oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Co
603ooookJ_oonf[oo`H00_oonfX00oo[o`3ooo]Zool0mP03oookJP04o`2Voooonf[ooo]ZojP0o`Go
U?l000Ko07OooookJ_oonf[oof`0oookJ_ooP@02oookJP05oc_o0?oonf[ooo]ZoookJ_l0nol01Ooo
nfX02Ooo0`3ooo]ZoookJ_oonf[oo`3Mo`0Goooonf[o0:?ook?o0006oookJP05o`3og_oUo`3ooo]Z
oookJ_oo06`00ooonfX01_m=0?oooo]ZoookJ_l0o`co0?m5oookJPKoiOl00_oonfX00om4o`3ooo]Z
oookJP05oookJP03ofP0oooonf[ooo]Z00?ooo]Z00?o603oo`1doooonfX00_oonfX00oooT03ooo]Z
oookJP09oookJP04oonn0?oonf[oiOl0og00o`Gooo]Z00?ooeL0oookJ_oonfX01OoonfX00ooo02go
oo]ZoookJP07oookJP03onGo0?oonf[ooo]Z00Kooo]Z00?o0?l<oiCo0?l01?l00_nDo`001ooUo`3o
U?l0oiCo0?nDo`3ooo]Zo`3oC_l0oc@02OoonfX01Ol0oago0?l8oookJ_oonf[o0?mC00Cooo]Z00Ko
o`1ioookJ_l0[Ooooo]ZoaD0oooo0542oookJP0:o`0Iool@0?ooo`1ZoookJ_nBo`3ooo]Zo`H0oooU
o`3o0?m=o`3Xo`;oiOl00_n2o`02o`000004o`3oFol0003o<Ol0oc7o00kooo]Z1_nDo`03oookJP;o
f_l00ooonfX>ooo900Co0?Wo7?oonfX2oiCo00Sooo]Z1?oo09<01?oonf[oo`0Cool04ooo01<<oook
JP?of_l01?oonfX2obH0o`CoU?l06?oonfX01?lao`3ooo]Zo`3oFooonfX2onGo0007oh;o0?oUo`3o
iOl0onGo0?l0<?oooo]Zo`3oC@05oookJP03o`H0oooonf[oT_l000?ooo]Z1_l0ojd2oookJP03oaD0
oooonf[oo`1A00;ooo]Z0_oUo`000ooo07Wooo]ZoookJP08oookJP03o`3oDooonf[ooo]Z00?oA?l0
00Go0?lModCo0?m4o`3oA?l0o`3Qo`1BoookJP03oonB0?oonf[ooo]Z00Gooo]Z00?oo`3loookJ_oo
nfX00ooonfX01_lH0?oooo]ZoookJ_oo1P3ooo]Zon_o00;ooo]Z00Coo`3foookJ_oonf[o0:Ko0_oo
nfX01?nX0?oooo]ZoookJ_oo0?T2oookJP09o`1goooonf[ooo]Zo`3oV_ooK03ooo]Zoon10?oonf[o
>ol000Cooo]Z00?o0?_ooookJ_oonfX00_oonfX02Ooo0`3ooo]ZoookJ_oonf[oo`3MoookJ_l05ooo
0:?ook?o0006oookJP03omgo0?l0omkoo`2700;ooo]Z00Goo`1/oookJ_oonf[oC@3oool^0002oook
JP03of40oooonf[ooo]Z00;ooo]Z00?ohP3ooookJ_l0oi000_oonfX00ol0oi;ooo]ZoookJP05oook
JP03ofP0oooonf[ooo]Z00?ooo]Z00?o603oonKo0?oonfX00ooonfX00oooT03ooo]ZoookJP09oook
JP04oonn0?l0o`Goj`3oog00o`Cooo]Z00?ooeL0oookJ_oonfX01OoonfX00ooo02gooo]ZoookJP07
oookJP03oon10?oonf[ooo]Z00Oooo]Z00Ko0=Coo`04oooonf[ooo]Zo`2Yool0R?l4oookJP03o`3o
C_l0ocCooo]Z00Oooo]Z00Go0>7oo`3o7Ol0o`Sooo]Zo`3oD`04oookJP06ool0NOoonf[o0:goo`2]
oolE0?ooo`1A0ooonfX03Ol06Ooo403ooookJ_nBo`3oo`3eoookJ_l60?oooo]Zo`3oCOl0ok7o033o
oookJ_n2o`000ol000000ol0oe_o<Ol0oc7o000@oookJP04ob3o0?lV0?ooQ03ooh@0o`?ooo]Z0_oJ
o`0;oookJP05ool04ooo09?oo`2Cool0TooonfX01Ol0nOlWoookJPCoo`2C0ooo01<<oookJP?of_l0
1OoonfX2obH0o`03ob3o0?n40?ooQ03o01Sooo]Z00Co<Ol0oookJ_oonf[o0?mK0ooonfX01?n2o`3o
0?n`o`3o/Ol0<?l2oookJP03o`3oCOoonf[ooo]Z00;ooo]Z00Co1P3ooookJ_oo0?GoT_l00_oonfX0
1?l@0?oo05gooookJ_l06Ol5oookJP03oaD0oooo057ooo]Z00;ooo]Z00?o0:gooookJ_oo07T02_oo
nfX01ol0oe?ooo]ZoookJ_oonf[o0?l8oookJ_l0oad00_oonfX00ol0hOoooo]ZoookJP0YoookJP00
:_oonfX00oooTP3ooo]ZoookJP05oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Go603ooookJ_oonf[o
oo]Zool60002oookJP03on_o0?oonf[oo`3f00?ooo]Z00Co0:KooookJ_oonf[oZ03o0_oonfX2oiCo
0009o`1goonDo`3ooo]ZoookJ_ooK03o0?o<oon10?oonf[o>ol000Cooo]Z00?o0?_ooookJ_oonfX0
0ooonfX02?oo0`3ooo]ZoookJ_mi0?ooo`3Mo`0GoonO0?oo/ol01_oonfX00ol0omkoiOl0oookJP02
oookJP09ool0K?oonf[ooo]Zodd0oooo;P3ooo]Zo`3o3?oonf[o0?m500OoiOl000?ooo]ZodCo0?oo
nfX01ooonfX00omX0?oooo]ZoookJP02oookJP03oaP0ool0M?oooo]Z00;ooo]Z00?ooi00oookJ_oo
nfX02OoonfX01Ooo_P3ooo]Zo`3o1OoUo`3oL03o00Gooo]Z00?ooeL0oookJ_oonfX01?oonfX00ooo
02gooo]ZoookJP07oookJP03onGo0?oonf[ooo]Z00Oooo]Z00Go0?l<o`04oonDo`3oU?l0onGo0004
oiCo0003oookJ_l0odko0?ld00Sooo]Z00Go0?lMo`3o2?oonf[ooo]Zo`3oD`04oookJP03ool0NOoo
nf[o0:go00;ooo]Z00goo`1AoookJ_oonf[o01Wooa00oooo06[ooo]Zoi;o0?oUo`3o1P3oonGo0?l0
odgo0>So00;oiOl000?oP_l0o`3o/?oUo`000_l0oe/00ol0003o<Ol0oookJP0<oookJPSoU?l000Co
oo]Zon7o0?oJo`3of_l01OoonfX<ooo90003o`3ioooonf[ooo]Z00Cooo]Z7OoobP02oiCo00Wooo]Z
00?o0?Woool0Tooo09<00_oo09<3ool04`[ooo]Z0_oQo`02om[o0004oookJ_nDo`3oU?l0oiCo00;o
9P3o0onDo`0HoookJP03oc7o0?oonf[o0?mK00;ooo]Z00?oiOl0oh;o0?oUo`000_oUo`000ol0<?oo
oo]Zo`3oC@05oookJP04o`H0oooonf[oT_l0oookJPOo0?n]0ooonfX00olE0?oooo]Zool0D@02oook
JP;oiOl000?oo`1ioookJ_oonfX02?oonfX00ol0oe?oA?l0odCo0003odCo0004o`3o7Om4o`3oA?l0
o`3Qoe7ooo]Z00?ooi80oookJ_oonfX01OoonfX00ooo0?cooo]ZoookJP03oookJP04oaP0oooonf[o
oo]Zool600;ooo]Z00?ojol0oookJ_oo0?H00ooonfX01?l0Y_oooo]ZoookJ_nX0?l2oookJP03ool0
nOoonf[o07Oo00?ooo]Z00?oof`0oookJ_ooP@000_oonfX00olko`3ooo]ZoookJP02oookJP03o`3k
oooonf[ooo]Z00;ooo]Z00Woo`<0oookJ_oonf[oN@3oool0gOoonf[o01Ooo`2Soonco`001_oonfX0
0ol0omkoo`27oookJP02oookJP08ool0K?oonf[oC@3ooookJ_oo;P3ooo]Zof40ool0odD4oookJP05
on80ool0oi3ooo]ZoookJ_l0oi802?oonfX00omX0?oooo]ZoookJP03oookJP03oaP0oooonf[ooo]Z
00;ooo]Z00?ooi00oookJ_oonfX02OoonfX01?oo_P3ooo]Zon/0oom`0?l5oookJP03oomG0?oonf[o
oo]Z00Cooo]Z00?oo`0]oookJ_oonfX01ooonfX00oooP@3ooo]ZoookJP07oookJP06o`3Dool01?oo
oo]ZoookJ_l0ZOoo08So1?oonfX00ol0obko0?m>o`3o=007oookJP05o`3Qool0oago0?l8oookJ_l0
oe<01?oonfX00ooo07Wooo]Zo`2]o`02oookJP09ool0DOoonf[ooo]ZoookJ_l06Ooo403ooookJ_nB
o`3oo`3e00;o1P3o00Sooo]Zo`3oCOl0ok7o033ooookJ_n2o`3ooo]Zo`0000;o0?mK00?o<Ol0oook
J_oonfX03ooonfX2obH0o`?ooo]Z00?ohOl0om[o0?oJo`002OoonfX2ool04`?oo`2C1?l0nOl7oook
JQcoolX02ooonfX2o`3io`Coo`2C0_oo01<:oookJP;ohOl00_oJo`05oookJP04obH0oolPo`3ooo]Z
oh@0oaSooo]Z00Co<Ol0oookJ_oonf[o0?mK0ooonfX01?n2o`3o0?n`o`3o/Ol0<?l2oookJP03o`3o
COoonf[ooo]Z00;ooo]Z00?o1P3ooookJ_nBo`000ooonfX00ol@0?oo05goo`0Io`06oookJP03oaD0
oooo057ooo]Z00;ooo]Z00?o0:gooookJ_oo07T02_oonfX01_l0oe?ooo]ZoookJ_oonf[o0?l8o`3o
7@;ooo]Z00?o0>7ooookJ_oonfX0:OoonfX003;ooo]Z00?oo`3loookJ_oonfX00_oonfX01OlH0?oo
oo]ZoookJ_oonf[oo`H000;ooo]Z00?ojol0oookJ_oo0?H00_oonfX01?l0Y_oooo]ZoookJ_nX0?l2
oookJP09oiCo0?oonf[ooo]Zo`1goonDo`3ooo]Zoom/0?oonf[ooh4000;ooo]Z00Go>ol0oookJ_oo
nf[ooo]Zo`3ko`05oookJP09ool30?oonf[ooo]ZoookJ_oo0=go01OooookJ_l0Xooo/ol000Kooo]Z
00Go0?oNonGo0?oonf[ooo]Zool0K003oookJP05odd0oooonf[ooo]Zo`3o3?oonfX02?oUo`000ooo
nf[oA?l0oookJP06oookJP03ofP0oooonf[ooo]Z00?ooo]Z00Go603oo`1doooonf[ooo]Zoon@000;
oookJP05oonn0?oonf[ooo]ZonGo0?m`0?l01OoonfX00oooE`3ooo]ZoookJP04oookJP03ool0;Ooo
nf[ooo]Z00Oooo]Z00?oiOl0oookJ_oonfX01ooonfX01Ol0o`co00CooookJ_oonf[oiOl000CoU?l0
00?ooo]Zo`3oC_l0oc@02?oonfX01Ol0oago0?l8oookJ_oonf[o0?mC00Gooo]Z00Goo`1io`2]oooo
nf[ooo]Zool0D@02oookJP09o`0Iool@0?ooo`1ZoookJ_nBo`3oiOl0o`H0oooUo`3o0?m=00;oiOl0
0_n2o`000ol0ok3oiOl0o`3oF`02o`000003oc7o0?l0003ooo]Z00Wooo]Z2_nDo`000ooQo`3of_l0
om[o0007oookJP03ool04ooob@3oolT000SoolT01OoonfX3ooo:00Cooo]Z2Ol0oa/5oa80o`?oU?l0
1_oonfX2oiCo00?oolX000?oU?l0oookJ_oonfX01ooonfX2o`3io`04oookJ_oo09?oo`2Cool0T`?o
o`0C2OoonfX2on7o0003om[o0?nDo`3oU?l000?oU?l000Co9P3ooiCo0?nDo`3oU?l06?oonfX00ola
o`3ooo]Zo`3oF`03oookJP04oh;o0?oUo`3oiOl0o`0`o`;ooo]Z00?o0?m=oookJ_oonfX00ooonfX0
0ol60?oooo]Zoi;o0008o`3o[@?ooo]Z00?o5@3oool0DOoonfX00_oonfX00ooUo`3ooo]Zool0N@09
oookJP03o`3oDooonf[oA?l000?oA?l000Co0?lModCo0?m4o`3o0>7oFOoonfX00ooo0?cooo]Zoook
JP03oookJP04oaP0oooonf[ooo]Zool600;ooo]Z00?ojol0oookJ_oo0?H00_oonfX01ol0Y_oooo]Z
oookJ_oonf[oZ03ooookJ_oo0?T00_oonfX02Ol0Mooooo]ZoookJ_l0oi[oof`0oookJ_ooP@3ooo]Z
oc_o0004oookJP03o`3koooonf[ooo]Z00;ooo]Z00Woo`<0oookJ_oonf[ooo]Zool0gOoonf[o01Oo
o`2Soonco`001_oonfX00ooMo`3o0?oNool0Q`02oookJP05ool0K?oonf[ooo]Zodd0oooo;P000_oo
nfX00omQ0?oo0?m5oookJP02oookJP03on80oooonf[o0?n@00;ooo]Z00?o0?nBoookJ_oonfX01Ooo
nfX00omX0?oooo]ZoookJP03oookJP03oaP0oooVo`3ooo]Z00;ooo]Z00?ooi00oookJ_oonfX02Ooo
nfX01?oo_P3ooo]Zo`3o1Oo[0?l5oookJP03oomG0?oonf[ooo]Z00Gooo]Z00?oo`0]oookJ_oonfX0
1_oonfX00oooP@3ooo]ZoookJP07oookJP06o`3Doooonf[o00CooookJ_l0ZOoo08So1?oonfX00ol0
obko0?m>o`3o=008oookJP04o`3o7Ol0o`Sooo]Zo`3oD`Gooo]Z00Goo`1io`2]oooonf[ooo]Zool0
D@03oookJP06o`0Iool@0?oooo]Zoi;o0?oo0?Go1P3o0_oonfX00ol0odgo0?nao`0`o`02oh;o00;o
oo]Z00Co0?mKo`000?lao`3o00003ooonfX2obH0o`?ooo]Z00?ohOl0om[o0?oJo`002?oonfX2ool0
4`?oo`2C0_l0nOl9oookJP?oolX00ooonfX9o`3o6`So4P3o2?oonfX3ooo:00[ooo]Z0_l0nOl2oook
JP?oo`2C0_oo01<9oookJP;ohOl000?of_l0oookJ_oonfX00ooonfX2obH0o`03ob3o0?oonf[ooo]Z
01Oooo]Z00Co<Ol0oookJ_oonf[o0?mK0ooonfX00on2o`3o0?n`o`0`o`02oookJP03o`3Xool0odgo
oo]Z00?ooo]Z00?o1P3ooookJ_nBo`000ooonfX00ol@0?oo05goo`0Io`05oookJP03oaD0oooo057o
oo]Z00?ooo]Z00?o0:gooookJ_oo07T02OoonfX00ol0oe?ooo]ZoookJP02oookJP05o`3o7Ooonf[o
oo]ZoookJ_l0hOl0:_oonfX003;ooo]Z00?oo`3loookJ_oonfX00_oonfX01?lH0?oooo]ZoookJ_oo
1P02oookJP03on_o0?oonf[oo`3f00?ooo]Z00Co0:KooookJ_oonf[oZ03o0_oonfX00onDo`3ooo]Z
o`1go`03oookJP03oom/0?l0olcooh4000;ooo]Z00Go>ol0oookJ_oonf[ooo]Zo`3ko`05oookJP08
ool30?oonf[ooo]ZogT0oooo0=go01OooookJ_nco`07oookJP05onGo0?oonf[ooo]ZoookJ_oo06`0
0_oonfX01Om=0?oooo]ZoookJ_l0o`cooo]Z00WoiOl000?oA?l0oookJ_oonfX01_oonfX00omX0?oo
oo]ZoookJP02oookJP03oaP0ool0M?oooo]Z00;ooo]Z00?ooi00oookJ_oonfX02OoonfX01Ooo_P3o
oo]ZonGo0?oonf[oL03o00Cooo]Z00?ooeL0oookJ_oonfX01OoonfX00ooo02gooo]ZoookJP06oook
JP03onGo0?oonf[ooo]Z00Oooo]Z00Go0?l<oookJ_l01?oooo]ZonGo0005oiCo0003o`3oC_l0ocCo
oo]Z00Oooo]Z00Go0?lMoookJ_l0o`Sooo]Zo`3oD`05oookJP05ool0NOl0[Ooooo]ZoookJ_oo0540
0_oonfX2oa00o`07ool0J_oonf[oT_l0oookJ_l60?ooiOl0o`3oC@02onGo0006oh;o0?l0ok3oiOl0
onGo0?l0oe_ooo]Z0_lao`02o`0000Sooo]Z2onDo`02om[o00Kooo]Z0ooo01<00ooonf[oolT0ooo9
0006ooo900?ooo]Z1?oobP03ooo900Co0?lK2?lB0?l00ol0S_oo0?lKo`3o6`0:o`3o6`03oiCo0?l0
S_ooU?l000CoU?l00ooobP09oookJP;o0?Wo0_oonfX00ooo09?ooo]ZoookJP03ool04`Sooo]Z00?o
hOl0om[o0?nDo`001?nDo`02obH0o`;oU?l06?oonfX00olao`3o0?mKoookJP03oookJP07oh;o0?oU
o`3oiOl0o`0`oooonf[o0>Soo`3oC@04oookJP04o`H0oooonf[ooo]Zoi;o00Oo0?n]0ooonfX00olE
0?oooo]Zool0D@03oookJP03onGo0?oo07Wooo]Z00Wooo]Z00?o0?mCoookJ_m4o`000om4o`001?l0
oagoA?l0odCo0?l0hOmHoookJP03ool0o?oonf[ooo]Z00?ooo]Z00Ko603ooookJ_oonf[oo`H0oook
J_o[o`02oookJP04ool0m_oonf[ooo]Zo`2Vo`;ooo]Z00KoZ03ooookJ_oonf[oo`3ioookJ_l0Mol3
oookJP06oom/0?oonf[o0?o<oon10?oonf[o>ol01?oonfX00ol0nooooo]ZoookJP02oookJP09ool3
0?oonf[ooo]ZogT0oooo0=gooo]Zo`0Gool0Xooo/ol000Kooo]Z00?ogOl0ool0QooonfX00_oonfX0
1?oo06cooo]Zodd0oooo;P02oookJP03of40ool0odGooo]Z00?ooo]Z00GohP3oo`3oT?oonf[ooo]Z
o`3oTP08oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603oonKo0?oonfX00ooonfX00oooT03ooo]Z
oookJP09oookJP04oonn0?oonf[oj`3oog00o`Cooo]Z00?ooeL0oookJ_oonfX01OoonfX00ooo02go
oo]ZoookJP06oookJP03oon10?oonf[ooo]Z00Sooo]Z00Ko0=Coo`04oooonf[o0:WooookJ_l0R?l3
oookJP03o`3o;_l0odko0?ld00Sooo]Z00Co0?lMoookJ_l0o`So0?mC1OoonfX01Ooo07Wo0:gooook
J_oonf[oo`1A00?ooo]Z0_l@0?l01ooonf[oT_l0ool0mOl60?oooo]Zo`3Xool0odd00_l0<?l01On2
o`3ooo]ZoookJ_oonf[o0?mK00;o<Ol00_l0000=oookJP03ob3o0?lV0?oooo]Z00?ooo]Z0_oJo`07
oookJP?oo`0C0_oo09<00ol0nOoooo]ZoookJP07oookJPCoolX00_oonfX4o`3o6`So4P3o00?o08ko
o`3o6ol0oa/02_l0oa/00olB0?oo08koo`2>o`04oookJP?oolX02OoonfX2o`3io`?ooo]Z00?oo`2C
oookJ_oo01<00_oo01<8oookJP03on7o0?oJo`3ooo]Z00Gooo]Z00?o9P3oob3o0?oonfX06?oonfX0
0olao`3ooo]Zo`3oF`04oookJP03oh;o0?l0ok3o033o00;ooo]Z00?o0>Soo`3oCOoonfX00_oonfX0
1?l60?oooo]ZoookJ_nBo`03oookJP03oa00ool06Ooooo]Z00Gooo]Z00?o5@3oool0DOoonfX00ooo
nfX00ol0[Oooo`1ioookJP09oookJP06o`3oDooonf[ooo]ZoookJ_l0o`So0?lM0_oonfX00ol0hOoo
oo]ZoookJP0XoookJP00<OoonfX00ooo0?cooo]ZoookJP02oookJP05oaP0oooonf[ooo]ZoookJ_oo
1P000_oonfX00oo[o`3ooo]Zool0mP02oookJP04o`2Voooonf[ooo]ZojP0o`?ooo]Z00?oU?l0oook
J_l0Mol00_oonfX01_ooK03ooo]Zo`3oc?ooP@3ooo]Zoc_o00?ooo]Z00?o0?_ooookJ_oonfX00ooo
nfX02Ooo0`3ooo]ZoookJ_oonf[oo`3MoookJ_l05ooo0:?ook?o0006oookJP05o`3og_oUo`3ooo]Z
oookJ_oo06`00_oonfX02?m=0?ooobh0oookJ_oonf[o0?l<oookJ_l0odGooo]Z1_oUo`000ooonf[o
A?l0oookJP06oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603oonKo0?l0M?l00_oonfX00oooT03o
oo]ZoookJP09oookJP05oonn0?oonf[o0?l5onGo0?m`0?l01?oonfX00oooE`3ooo]ZoookJP05oook
JP03ool0;Ooonf[ooo]Z00Oooo]Z00?oiOl0oookJ_oonfX01_oonfX01_l0o`cooo]Zo`04oooonf[o
iOl0oiCo00;ooo]Z0_nDo`000ol0odko0?ldoookJP07oookJP05o`3Qool0oago0?l8oookJ_l0oe<0
1OoonfX01Ooo07Wo0:gooookJ_oonf[oo`1A00;ooo]Z00[o403oo`0Ioooo06[ooo]Zoi;o0?oonf[o
1P3ooookJ_l0odgoiOl00_oob@001_l0ok3oiOl0onGo0?l0oe_ooo]Zoc7o00Co00002?oonfX:oiCo
0003om[o0?oonf[ooo]Z00Cooo]Z0_oo01<01Ooonf[oolT0ooo90?oob@3o0?Wo00OoolT00ooobP03
oa80o`Co0?lK6OoonfX7o`3o6`?oU?l00ooobP08oookJP?o0?Wo0_oo09<3oookJP;oo`0C1ooonfX0
1?oQo`3of_l0oookJ_oonfX4oiCo0003obH0oonDo`3oU?l001Sooo]Z00?o<Ol0o`3oFooonfX00ooo
nfX01on2o`3ooo]ZonGo0?l0<?oooo]Zo`3Xool0odd01?oonfX01?l60?oooo]ZoookJ_nBo`06o`3o
[@Cooo]Z00?o5@3oool0DOoonfX00_oonfX00ol0[Ooooo]Zool0N@09oookJP03o`3oDooonf[ooo]Z
00?oA?l000Co0?lModCo0?m4o`3o0>7oEooonfX00ooo0?cooo]ZoookJP03oookJP04oaP0oooonf[o
oo]Zool600;ooo]Z00?ojol0oookJ_oo0?H00_oonfX01Ol0Y_oooo]ZoookJ_oonf[oZ03o00;ooo]Z
00?oo`3ioookJ_l0Mol00_oonfX01_l0oi[oof`0oookJ_ooP@3ooo]Zoc_o00Cooo]Z00?o0?_ooook
J_oonfX00_oonfX01Ooo0`3ooo]ZoookJ_oonf[oo`3M00;ooo]Z00?o0:?ook?o0?oonfX01_oonfX0
1Ol0omkoo`27oookJ_oonf[oo`1/00;ooo]Z00KoC@3oool^0?oonf[ooo]Zof40ool0odD4oookJP05
on80ool0oi3ooo]ZoookJ_l0oi801ooonfX00omX0?oooo]ZoookJP03oookJP03oaP0oooVo`3ooo]Z
00;ooo]Z00?ooi00oookJ_oonfX02OoonfX01?oo_P3ooo]Zo`3o1Oo[0?l4oookJP03oomG0?oonf[o
oo]Z00Kooo]Z00?oo`0]oookJ_oonfX01_oonfX00oooP@3ooo]ZoookJP07oookJP06o`3Dool01?oo
oo]Zo`2Yoooonf[o08So1?oonfX00ol0odko0?ldoookJP07oookJP04o`3o7Ooonf[o0?l8o`3oD`Go
oo]Z00Goo`1io`2]oooonf[ooo]Zool0D@03oookJP0<oa00ool06Ooooo]Zoi;o0?oo0?Go1P3ooook
J_l0j?oo0?m=o`0`oooonf[oP_l00ooonfX00ol0oe_o<Ol0o`000003o`0000cooo]Z0_lV0?l3oook
JP03on7o0?oJo`3ooo]Z00Kooo]Z0_oo01<3ool0T`03o`3ioooonf[ooo]Z00Gooo]Z1?oobP02oa80
o`Co0?lK6OoonfX7o`3o6`?ooo]Z0ooobP08oookJP?o0?Wo00?ooo]Zool0Tooo09<00_oonfX2ool0
4`Oooo]Z00?ohOl0om[o0?oonfX01OoonfX2obH0o`03ob3o0?oonf[ooo]Z01Kooo]Z00?o<Ol0oook
J_l0oe/01?oonfX00on2o`3o0?n`o`0`o`02oookJP03o`3Xool0odgooo]Z00;ooo]Z00Co1P3ooook
J_oonf[oT_l00_oonfX00ol@0?oo05goo`0Io`05oookJP03oaD0oooo057ooo]Z00?ooo]Z00?o0:go
oookJ_oo07T02OoonfX00ol0oe?ooo]ZoookJP02oookJP04o`3o7Ooonf[ooo]Zo`3Qob[ooo]Z000a
oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Co603ooookJ_oonf[oo`H00ooonfX00oo[o`3ooo]Zool0
mP02oookJP04o`2Voooonf[ooo]ZojP0o`;ooo]Z00CoU?l0oookJ_oonf[o07Oo0_oonfX00oooK03o
0?o<oon10002oookJP05oc_o0?oonf[ooo]ZoookJ_l0nol01OoonfX02?oo0`3ooo]ZoookJ_oonf[o
o`3Mo`0Goooonf[o/ol01ooonfX01Ol0omkoiOl0oookJ_oonf[oo`1/00;ooo]Z00KoC@3ooookJ_oo
nf[o0?l<oookJ_l0odD4oookJPCoiOl000?oA?l0oookJ_oonfX01_oonfX00omX0?oooo]ZoookJP02
oookJP03oaP0oooVo`3ooo]Z00;ooo]Z00?ooi00oookJ_oonfX02?oonfX01Ooo_P3ooo]ZoookJ_oU
o`3oL03o00Gooo]Z00?ooeL0oookJ_oonfX01?oonfX00ooo02gooo]ZoookJP07oookJP03onGo0?oo
nf[ooo]Z00Kooo]Z00Ko0?l<oookJ_l01?oooo]ZonGo0?nDo`04oookJP03o`3oC_oonf[o0?ld00Oo
oo]Z00Go0>7oo`3o7Ol0o`Sooo]Zo`3oD`05oookJP05ool0NOl0[Ooooo]ZoookJ_oo05400_oonfX0
2_l@0?oo01Woool0J_oonf[oT_l0oookJ_l60?oooo]Zo`3oCOoonfX3ooo900;oiOl000Co0?mKoook
J_lao`3ooo]Z1?l00006oookJP?oolT02?nDo`000ooJo`3ooo]ZoookJP03oookJP;oo`0C0ooob@02
o`3io`;ooo]Z1?oob@03ooo:0003oa80ool0oa_o0?lK00?o0?lK0ooob@0KoookJPKoU?l00ol0oa/3
oiCo00?oolX02?oonfX2o`3io`;oo`2C0ooonfX00ooo01?ooo]ZoookJP06oookJP03om[o0?oQo`3o
oo]Z00;ooo]Z0_nDo`02obH0o`03oiCo0?oonf[ooo]Z01Kooo]Z00?o<Ol0o`3oFooonfX00ooonfX0
1on2o`3o0?n`oookJ_l0<?oooo]Zo`3Xool0odd00ooonfX01Ol60?oooo]ZoookJ_oonf[oT_l000Ko
0?n]1?oonfX00olE0?ooo`1AoookJP02oookJP03o`2]oooonf[oo`1i00Wooo]Z00?o0?mCoookJ_oo
nfX00_m4o`001?l0oagoA?l0odCo0?l0hOmGoookJP03ool0o?oonf[ooo]Z00?ooo]Z00Co603ooook
J_oonf[oo`H00_oonfX00oo[o`3ooo]Zool0mP02oookJP04o`2Voooonf[ooo]ZojP0o`;ooo]Z00Co
o`3ioookJ_oonf[o07Oo0_oonfX01_l0oi[oof`0o`3oc?ooP@3ooo]Zoc_o00Cooo]Z00?o0?_ooook
J_oonfX00_oonfX02Ooo0`3ooo]ZoookJ_oonf[oo`3MoookJ_l05ooo0:?ook?o0006oookJP03omgo
0?l0omkoo`2700;ooo]Z00Coo`1/oookJ_m=0?ooobh00_oonfX00omQ0?oo0?m5oookJP03oookJP05
on80ool0oi3ooo]ZoookJ_l0oi802?oonfX00omX0?oooo]ZoookJP02oookJP03oaP0oooVo`3ooo]Z
00?ooo]Z00?ooi00oookJ_oonfX02?oonfX01?oo_P3ooo]Zo`3o1Oo[0?l5oookJP03oomG0?oonf[o
oo]Z00Gooo]Z00?oo`0]oookJ_oonfX01_oonfX00oooP@3ooo]ZoookJP07oookJP06o`3Doooonf[o
00Coo`2Yoooonf[o08So1?oonfX00ol0odkooo]Zo`3o=007oookJP04o`3Qool0oago0?l8o`3oD`Go
oo]Z00Goo`1io`2]oooonf[ooo]Zool0D@03oookJP0<oa00ool06Ooooo]Zoi;o0?oo0?Go1P3ooook
J_l0j?oo0?m=o`0`ool0ok3oP_l00ooonfX00ol0oe_o<Ol0oookJP04o`0000[ooo]Z0_lV0?l3oook
JP03on7o0?oJo`3of_l000Kooo]Z00Coo`0Cool0Tooo09?oo`2C0_l0nOl6oookJP?oolX00_lB0?l4
o`3o6`03o`2>oooonf[ooo]Z023ooo]Z00Go4P3oo`3o6ol0oa_o0?lKoa80o`02oookJP?oolX02?oo
nfX2o`3io`03oookJ_oo09?ooo]Z00;ooo]Z00?oo`0CoookJ_oonfX01_oonfX2om[o00Kooo]Z00?o
9P3oob3o0?lPo`005ooonfX00olao`3ooo]Zo`3oF`04oookJP07oh;o0?l0ok7o033ooookJ_l0j?oo
oo]Zo`3oC@02oookJP05o`H0oooonf[ooo]ZoookJ_nBo`000_oonfX00ol@0?ooo`1Zo`0Io`05oook
JP03oaD0oooo057ooo]Z00?ooo]Z00?o0:gooookJ_oo07T02OoonfX01_l0oe?ooo]ZoookJ_oonf[o
0?l8o`3o7@;ooo]Z00?o0>7ooookJ_oonfX09ooonfX0033ooo]Z00?oo`3loookJ_oonfX00ooonfX0
1?lH0?oooo]ZoookJ_oo1P02oookJP03on_o0?oonf[oo`3f00;ooo]Z00Go0:KooookJ_oonf[ooo]Z
ojP0o`02oookJP03oiCo0?oonf[o07Oo00;ooo]Z00Koof`0oookJ_l0olcooh40oookJ_lko`03oook
JP03o`3koooonf[ooo]Z00Cooo]Z00Soo`<0oookJ_oonf[oo`3MoookJ_l05ooo0:?ook?o00Kooo]Z
00Go0?oNonGo0?oonf[ooo]Zool0K002oookJP07odd0oooo;P3ooo]ZoookJ_l0o`cooo]Zo`3oA@03
oookJP06onGo0?oonf[o0?n@oookJ_oUo`3oA?l01ooonfX00omX0?oooo]ZoookJP02oookJP03oaP0
oooVo`3ooo]Z00;ooo]Z00?ooi00oookJ_oonfX02OoonfX01Ooo_P3ooo]ZonGo0?oonf[oL03o00Co
oo]Z00?ooeL0oookJ_oonfX01OoonfX00ooo02gooo]ZoookJP06oookJP03onGo0?oonf[ooo]Z00Oo
oo]Z00Go0?l<o`04oooonf[oiOl0oiCo0004oookJP03o`3oC_oUo`3o0?ld00Sooo]Z00Co0?lMo`3o
2?oonf[o0?mC1OoonfX01Ooo07Wo0:gooookJ_oonf[oo`1A00;ooo]Z00?o403oo`0Ioooo06X00_nB
o`001?oonf[o1P3oo`3Xool0odd4ooo90003onGo0?l0oe_o0?mK00;o<Ol00_oonfX4o`0000?ooo]Z
1_oob@07oiCo00Kooo]Z0ooob@02o`3io`Gooo]Z1?oobP04o`3o6`KoolT01?oonfX4ooo900[ooo]Z
0_oob@09oookJPWoU?l00_l0oa/4oiCo00?oolX01ooonfX2o`3io`05ool0Tooonf[ooo]ZoookJ_oo
01<02?oonfX00ooJo`3ohOl0oookJP04oookJP03oiCo0?lV0?oo9P3o01Sooo]Z00?o<Ol0oookJ_oo
nfX00ooonfX01on2o`3o0?n`o`0`oooonf[o0>SooookJ_l0odd00ooonfX01Ol60?oooo]ZoookJ_oo
0?GoT_l000Go0?n]1?oonfX00olE0?ooo`1AoookJP02oookJP04o`2]oooonf[ooo]Zool0N@Sooo]Z
00Co0?mCoookJ_oonf[ooo]Z0_m4o`001?l0oagoA?l0odCo0?l0hOmEoookJP03ool0o?oonf[ooo]Z
00Cooo]Z00Ko603ooookJ_oonf[oo`H0oookJ_o[o`02oookJP03ool0m_oonf[o0:Ko00?ooo]Z00Ko
Z03ooookJ_oonf[oo`3ioookJ_l0Mol2oookJP07o`3oV_ooK03ooo]Zo`3oc?ooP@3ooo]Zoc_o0003
oookJP03o`3koooonf[ooo]Z00?ooo]Z00Coo`<0oookJ_oonf[oo`3M0_oonfX00ol0Xooo/ol0oil0
o`06oookJP09o`3og_oo08Oooo]ZoookJ_oo06cooo]Zodd0oooonf[oobh000;ooo]Z00?oH@3oo`3o
AOoonfX00ooonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Oooo]Z00?oJ03ooookJ_oonfX00ooonfX0
0olH0?ooi_l0oookJP02oookJP03oon@0?oonf[ooo]Z00Wooo]Z00Cookh0oookJ_o[0?ooL03o1?oo
nfX00oooE`3ooo]ZoookJP05oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooh40oookJ_oonfX01ooo
nfX01_l0e?oooo]Zo`04ool0ZOoooo]Zo`28o`Cooo]Z00?o0?m>oookJ_l0oc@01ooonfX01?l0hOoo
0?lMo`3o2?l0oe<5oookJP05ool0NOl0[Ooooo]ZoookJ_oo05400ooonfX03?l@0?oo01WooookJ_nB
o`3oo`3eo`H0oooonf[o0>Soo`3oCOl0<?oo0?n`oh;o00;ooo]Z00?o0?mKoc7o0?lao`000_oonfX4
o`0000Wooo]Z00?o9P3ooookJ_oonfX00_oonfX2om[o00Kooo]Z0ooo09<2o`3io`Gooo]Z1?oobP00
0olB0?oo0?lKo`3o6`02o`3o6`03o`2>oooonf[ooo]Z02Oooo]Z00?o08koo`3o6ol0oa/01?lB0?l3
ooo:00Oooo]Z0_l0nOl2ool0T`;ooo]Z00?oo`0CoookJ_oonfX01ooonfX00ooJo`3ooo]ZoookJP04
oookJP;o9P3o00?o8?l0oookJ_oonfX05OoonfX00olao`3o0?mKoookJP04oookJP07oh;o0?l0<?oo
oo]ZoookJ_l0j?oooo]Zo`3oC@02oookJP05o`H0oooonf[ooo]Zool0mOnBo`000_oonfX00ol@0?oo
01WooookJP05oookJP03ool0DOoonf[ooo]Z00;ooo]Z00?o0:gooookJ_oo07T02OoonfX00ol0oe?o
oo]ZoookJP02oookJP04o`3o7Ooonf[ooo]Zo`3QobWooo]Z000`oookJP03ool0o?oonf[ooo]Z00;o
oo]Z00Go603ooookJ_oonf[ooo]Zool60002oookJP03on_o0?oonf[oo`3f00;ooo]Z00Co0:Kooook
J_oonf[oZ03o0_oonfX01?nDo`3ooo]ZoookJ_l0Mol2oookJP03oom/0?oonf[ooh4000;ooo]Z00Go
>ol0oookJ_oonf[ooo]Zo`3ko`05oookJP08ool30?oonf[ooo]ZoookJ_oo0=gooo]Zo`0Goonco`07
oookJP05o`3og_oUo`3ooo]ZoookJ_oo06`00_oonfX01_m=0?oooo]ZoookJ_l0o`cooo]Zo`3oA@Co
oo]Z00GoiOl0o`3oT?oonf[ooo]ZodCo0008oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603oonKo
0?oonfX00_oonfX00oooT03ooo]ZoookJP08oookJP05oonn0?oonf[ooo]ZonGo0?m`0?l01OoonfX0
0oooE`3ooo]ZoookJP04oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?oiOl0oookJ_oonfX01ooonfX0
1_l0o`cooo]Zo`04oooUo`3ooo]ZoiCo00Cooo]Z00?o0?m>o`3o=?oonfX01ooonfX01?l0oago0?l8
oookJ_l0oe<5oookJP05ool0NOl0[Ooooo]ZoookJ_oo05400_oonfX02Ol@0?oo01Woool0J_nBo`3o
o`3eoookJ_l60?oo0>Soo`3oC@04ooo90004oookJ_l0oe_oiOl0oc7o00Cooo]Z1?l00007ooo900;o
U?l000?oolT0oiCo0?nDo`000onDo`05oookJP03ool0Tooob@3ooo]Z00;o0?Wo1?oonfX3ooo:00Co
0?lK2?oob@06oookJPWoolT01OoonfX5ooo900Kooo]Z2onDo`03o`3o6`;oU?l000?o4P3ooookJ_oo
bP000_oobP06oookJP03o`3ioooo09?oo`2C00;ooo]Z00?oo`0CoookJ_oonfX01_oonfX2om[o0003
on7o0?oonf[ooo]Z00?ooo]Z00?oQ03oobH0oooonfX05_oonfX00olao`3o0?mKoookJP04oookJP07
oh;o0?l0ok7o033ooookJ_l0j?oooo]Zo`3oC@02oookJP06o`H0oooonf[ooo]ZoookJ_oo0?GoA?l0
1Ol0ojd4oookJP05oaD0oooo057ooo]ZoookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP06oookJP03
o`3oDooonf[ooo]Z00;ooo]Z00GoA?l0o`3o7Om4o`3oA?l0o`3Qo`1EoookJP03ool0o?oonf[ooo]Z
00?ooo]Z00Co603ooookJ_oonf[oo`H00_oonfX00oo[o`3ooo]Zool0mP02oookJP05o`2Voooonf[o
oo]ZoookJ_nX0?l00_oonfX00ooo0?Wooo]Zo`1go`02oookJP06o`3oV_ooK03ooo]Zoon10?oonf[o
>ol01?oonfX00ol0nooooo]ZoookJP02oookJP05ool30?oonf[ooo]ZoookJ_oo0=d00_oonfX00ol0
Xooo/ol0oookJP05oookJP03omgo0?l0omkoo`2700;ooo]Z00Coo`1/oookJ_m=0?ooobh00_oonfX0
0omQ0?oo0?m5oookJP03oookJP05on80ool0oi3ooo]ZoookJ_l0oi802?oonfX00omX0?oooo]Zoook
JP02oookJP03oaP0oooVo`3ooo]Z00?ooo]Z00?ooi00oookJ_oonfX02?oonfX01?oo_P3ooo]Zo`3o
1Oo[0?l5oookJP03oomG0?oonf[ooo]Z00Gooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]Z
oookJP08oookJP03o`3Dool01?oo0:Wo00;ooo]Z00Oo08SooookJ_oonf[ooo]Zo`3o;_l0odko0?ld
00Oooo]Z00Co0>7oo`3o7Ol0o`So0?mC1OoonfX01Ooo07Wo0:gooookJ_oonf[oo`1A00?ooo]Z00co
403oo`0Ioooonf[oT_l0ool0mOl60?oooo]Zo`3Xool0odgo033oo`3o/?n2o`02oookJP03o`3oFola
o`3ooo]Z00?ooo]Z1?l00007oookJP;o9P3o0ooonfX2om[o00Kooo]Z0_oo09<00ooo01?o0?Woo`3i
o`04oookJP?oolX000?ooo]Zo`3o6ol0oa/00_l0oa/2o`2>oboooo]Z0ol0oa/01?oonf[o4P3ooa80
oolB0?l3ooo:00Kooo]Z0_l0nOl01?oo09?ooo]ZoookJ_oo01<9oookJP03om[o0?oQo`3ooo]Z00Co
oo]Z00?oQ03oobH0oolPo`005_oonfX00olao`3ooo]Zo`3oF`04oookJP03o`3o/?n2o`3o033o00;o
oo]Z00Go0>SooookJ_l0odgooo]Zo`H0o`03oookJP06ool0mOnBo`3ooo]ZoookJ_l@0?oo01Wo1Ooo
nfX00olE0?ooo`1AoookJP02oookJP04o`2]oooonf[ooo]Zool0N@Sooo]Z00?o0?mCoookJ_oonfX0
0_oonfX01?l0oago0?l8oookJ_l0hOlYoookJP00<?oonfX00ooo0?cooo]ZoookJP02oookJP04oaP0
oooonf[ooo]Zool600?ooo]Z00?ojol0oookJ_oo0?H00_oonfX01?l0Y_oooo]ZoookJ_nX0?l2oook
JP09oiCo0?oonf[ooo]Zo`1goooonf[o0?nJoom/0?l0olcooh4000;ooo]Z00Co>ol0oookJ_oonf[o
0?_o1_oonfX02?oo0`3ooo]ZoookJ_oo0=goN@3oo`0Gool0Xooo/ol01_oonfX01Ol0omkoiOl0oook
J_oonf[oo`1/00;ooo]Z00OoC@3oool^0?oonf[ooo]Zo`3o3?oonf[o0?m500?ooo]Z00?oiOl0oook
J_l0oi000_oonfX00om4o`3ooo]ZoookJP05oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603oonKo
0?oonfX00_oonfX00oooT03ooo]ZoookJP08oookJP05oonn0?oonf[ooo]ZonGo0?m`0?l01OoonfX0
0oooE`3ooo]ZoookJP04oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?oiOl0oookJ_oonfX01_oonfX0
1_l0o`cooo]Zo`04oooonf[o0:WooiCo00Cooo]Z00?o0?m>o`3o=?oonfX01ooonfX01?l0oago0?l8
oookJ_l0oe<6oookJP04ool0NOoonf[ooo]Zool0D@;ooo]Z00Wo403oo`0Ioooo06[oT_l0ool0mOoo
nf[o1P3oo`3Xool0odd01Ooob@000ol0oe_ooo]Zoc7o0005oookJP?o00001_oob@02oiCo00?oolT0
00Cof_l0oiCo0?nDo`3oU?l01?oonfX00ooo01?oo`2CoookJP02o`3io`?ooo]Z0ooobP03o`3o6`;o
4P3o00?oolT0oookJ_oob@001_oob@07oookJQGoolT01?oonfX8oiCo00Gooo]Z00Go08koo`3o6ol0
oa_ooo]Zoa80o`03oookJP?oolX01OoonfX01?l0nOooo`2CoookJ_oonfX2ool04`Sooo]Z00?of_l0
on7o0?oQo`001?oonfX00olPo`3o9P3ooookJP0FoookJP03oc7o0?l0oe_ooo]Z00Cooo]Z00KoP_l0
o`3o/Ol0<?oooo]Zo`3Xool0odd3oookJP05o`H0oooonf[ooo]Zool0mOm4o`000_oonfX3o`3o[@Go
oo]Z00Goo`1AoookJ_oonf[ooo]Zo`2]o`02oookJP03ool0NOoonf[ooo]Z00Kooo]Z00?o0?mCoook
J_oonfX00_oonfX01?l0oagoA?l0odCo0?l0hOmEoookJP03ool0o?oonf[ooo]Z00?ooo]Z00Co603o
oookJ_oonf[oo`H00_oonfX00oo[o`3ooo]Zool0mP02oookJP04o`2Voooonf[ooo]ZojP0o`;ooo]Z
00coo`3ioookJ_oonf[o07OooookJ_l0oi[oof`0oookJ_l0olcooh40oookJ_lko`03oookJP03o`3k
oooonf[ooo]Z00?ooo]Z00Woo`<0oookJ_oonf[oo`3MogT0oooonf[o0:?ook?o0?nO0?l01_oonfX0
2Ol0omkoo`27oookJ_oonf[oo`1/oookJ_m=0?oooo]Zool^0002oookJP03of40ool0odGooo]Z00?o
oo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP07oookJP03ofP0oooonf[ooo]Z00?ooo]Z00?o603oonKo
0?oonfX00_oonfX00oooT03ooo]ZoookJP08oookJP05oonn0?oonf[ooo]Zon/0oom`0?l01?oonfX0
0oooE`3ooo]ZoookJP05oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooh40oookJ_oonfX01ooonfX0
1_l0e?oo00CooookJ_l0ZOoooo]Zo`28o`?ooo]Z00?o0?l^o`3oC_l0oc@01ooonfX01?l0hOoo0?lM
o`3o2?l0oe<6oookJP04ool0NOoonf[ooo]Zool0D@?ooo]Z00Ko403oo`0Ioooonf[oT_l0ool0mOl6
0?l2o`3Xo`04o`3oCOl0<?oo0?n`oh;o00;ooo]Z00?o0?mKoc7o0?oonfX01?oonfX5o`0000Cooo]Z
0_lV0?l00on40?oooo]ZoookJP02om[o00Oooo]Z00Coo`2Cool04ol0nOoo0?Wo0ooonfX3ooo:0005
oookJ_l0oa_o0?lKo`3o6olB0?l00_l0S_ldoookJP03o`2>ool0oa_o0?lK00;ooo]Z00?o4P3ooook
J_oonfX00ooobP05oookJP04o`3ioooo09?oo`2CoookJP;oo`0C2?oonfX00ooJo`3ohOl0on7o0004
oookJP03oh@0oolV0?oooo]Z01Kooo]Z00?o<Ol0oookJ_l0oe/01?oonfX01ol0ok3oP_l0o`0`oooo
nf[o0>SooookJ_l0odd00_oonfX01Ol60?oooo]ZoookJ_oo0?GoT_l000?ooo]Z00?o403oo`1Moooo
nfX01?oonfX00ooo057ooo]ZoookJP02oookJP04o`2]oooonf[ooo]Zool0N@Sooo]Z00?o0?mCoook
J_oonfX00_oonfX01?l0oagooo]ZoookJ_l0hOlXoookJP00;ooonfX00ooo0?cooo]ZoookJP03oook
JP04oaP0oooonf[ooo]Zool600;ooo]Z00?ojol0oookJ_oo0?H00_oonfX01?l0Y_oooo]ZoookJ_nX
0?l3oookJP03oiCo0?oonf[o07Oo00;ooo]Z00Koof`0oookJ_l0olcooh40oookJ_lko`03oookJP03
o`3koooonf[ooo]Z00?ooo]Z00Soo`<0oookJ_oonf[ooo]Zool0gOoonf[o01Oook?o00Oooo]Z00Go
0?oNonGo0?oonf[ooo]Zool0K002oookJP06odd0oooo;P3ooo]Zo`3o3?oonf[o0?m51?oonfX01OoU
o`3ooo]Zo`3oT?oonf[oA?l000Sooo]Z00?oJ03ooookJ_oonfX00_oonfX01OlH0?ooi_l0oookJ_oo
nf[ooi0000_ooo]Z00Gookh0oookJ_oUo`3o0?l5og00o`05oookJP03oomG0?oonf[ooo]Z00Cooo]Z
00?oo`0]oookJ_oonfX01_oonfX00ooUo`3ooo]ZoookJP06oookJP06o`3o3?oonf[o00CooookJ_l0
ZOooU?l01?oonfX00ol0odkooo]Zo`3o=007oookJP04o`3Qool0oagooo]Zo`3oD`Kooo]Z00Coo`1i
o`2]oooonf[oo`1A0_oonfX02Ol@0?oo01Woool0J_nBo`3oo`3eoookJ_l60?oo0>Soo`3oC@05ooo9
0003o`3oFooonf[o<Ol000Kooo]Z0ol00005ooo90004oiCo0?lPo`3oolT0ooo900;of_l000?ohOl0
oookJ_nDo`000ooonfX00ooo01?oo`2Cool0T`02o`3io`?ooo]Z0_oobP000ooonf[o0?lKo`3o6`02
oa80o`Gooo]Z1Ooob@06oookJPKo0?oO0omho`05ooo90003o`3ogooob@3oolT000WoolT04_oonfX2
o`3o6`;o4P3o1?oonfX2ooo:00Gooo]Z0_oo09<2oookJP03ool04ooonf[ooo]Z00Kooo]Z00?of_l0
oookJ_oQo`001?oonfX00olV0?oooo]ZoookJP0EoookJP03oc7o0?oonf[o0?mK00Cooo]Z00?o0?n`
oh;o0?l0<?l00_oonfX01Ol0j?oo0?m=oookJ_oonf[o1P3o00?ooo]Z00Coo`3eodCo0?oonf[ooo]Z
0ol0ojd4oookJP05oaD0oooo057ooo]ZoookJ_l0[Ol00ooonfX00ooo07Wooo]ZoookJP05oookJP03
o`3oDooonf[ooo]Z00?ooo]Z00Co0?lModCo0?m4o`3o0>7oDooonfX00ooo0?cooo]ZoookJP04oook
JP03oaP0oooonf[oo`H000;ooo]Z00Kojol0oookJ_oonf[oo`3foookJ_l0Y_l3oookJP06ojP0oooo
nf[ooo]Zool0nOoonf[o07Oo0_oonfX01?l0oi[oof`0oookJ_ooP@02oookJP05oc_o0?oonf[ooo]Z
oookJ_l0nol01?oonfX01Ooo0`3ooo]ZoookJ_oonf[oo`3M00;ooo]Z00?o0:?ook?o0?oonfX01Ooo
nfX01OoMo`3o0?oNool0Qooonf[oo`1/00;ooo]Z00KoC@3ooookJ_oo;P3ooo]Zof40ool0odD4oook
JP05on80oooonf[o0?n@oookJ_l0oi802?oonfX00omX0?oooo]ZoookJP02oookJP03oaP0oooVo`3o
oo]Z00;ooo]Z00?ooi00oookJ_oonfX02OoonfX01?oo_P3ooo]Zon/0oom`0?l5oookJP03oomG0?oo
nf[ooo]Z00Cooo]Z00?oo`0]oookJ_oonfX01_oonfX00oooP@3ooo]ZoookJP07oookJP06o`3Doooo
nf[o00Coo`2Yoooonf[o08So0ooonfX01?l0obko0?m>oookJ_l0oc@7oookJP03o`3o7Ol0o`So0?mC
00Kooo]Z00Coo`1io`2]oooonf[oo`1A0ooonfX03?l@0?oo01WooookJ_nBo`3oo`3eo`H0ool0j?oo
oo]Zo`3oCOl0<?oooo]Zoh;o00;ooo]Z00?o0?mKoc7o0?oonfX01OoonfX4o`0000Cooo]Z00Co9P3o
ob3o0?oonf[ooo]Z0_oJo`000ooQo`3ooo]ZoookJP04oookJP;oo`2C0_l0nOl3oookJP;oolX00_oo
nfX2o`3o6`03oa80ool0S_oooo]Z00oooo]Z1Ol0oml8ogSo00;o0?oO1Olm0?lGoookJP;o0?lK00?o
08kooa80oolB0?l00ooonfX2ooo:00Gooo]Z00Go0?Woool0Tooonf[ooo]Zool04`08oookJP03om[o
0?oonf[ohOl000Cooo]Z00?o9P3oob3o0?oonfX05OoonfX00olao`3ooo]Zo`3oF`04oookJP03o`3o
/?oonf[oP_l000;ooo]Z00Go0>SooookJ_l0odgooo]Zo`H0o`03oookJP06ool0mOnBo`3ooo]Zoook
J_l@0?oo01Wo1_oonfX01Ooo057ooo]ZoookJ_oonf[o0:go00?ooo]Z00?oo`1ioookJ_oonfX01Ooo
nfX00ol0oe?ooo]ZoookJP02oookJP04o`3o7Ol0o`Sooo]Zo`3QobSooo]Z000_oookJP03ool0o?oo
nf[ooo]Z00?ooo]Z00Co603ooookJ_oonf[oo`H00_oonfX00oo[o`3ooo]Zool0mP02oookJP04o`2V
oooonf[ooo]ZojP0o`;ooo]Z00WoU?l0oookJ_oonf[o07OooookJ_l0oi[oof`0o`3oc?ooP@000_oo
nfX01?lko`3ooo]ZoookJ_l0nol6oookJP08ool30?oonf[ooo]Zool0gOmi0?oooo]Zo`2Soonco`06
oookJP05o`3og_oUo`3ooo]ZoookJ_oo06`00_oonfX01om=0?ooobh0oookJ_oonf[o0?l<oookJ_l0
odD01?oonfX01OoUo`3o0?n@oookJ_oonf[oA?l000Oooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH
0?ooi_l0oookJP02oookJP03oon@0?oonf[ooo]Z00Sooo]Z00Gookh0oookJ_oonf[oiOl0og00o`05
oookJP03oomG0?oonf[ooo]Z00Cooo]Z00?oo`0]oookJ_oonfX01_oonfX00ooUo`3ooo]ZoookJP07
oookJP06o`3o3?l01?oooo]Zo`2Yoooonf[oU?l00ooonfX00ol0odkooo]Zo`3o=007oookJP04o`3Q
ool0oagooo]Zo`3oD`Kooo]Z00ooo`1io`2]oooonf[oo`1AoaD0oooonf[o403oo`0Ioooo06[oT_l0
ool0mOoonf[o1P3oo`3Xool0odd01Ooob@000ol0oe_o<Ol0oc7o0007oookJPCo00000_oob@02oiCo
00;oolT00_oJo`000ooQo`3ooo]ZoookJP03oookJP03ool04ooo09?oo`2C00;o0?Wo0ooonfX2ooo:
0004oookJ_l0oa_o0?lKoa80o`Wooo]Z0_oob@02oookJP03ocd0oooob@3o0?oO00?o0?oO1_mho`0G
ooo9017ooo]Z0ol0oa/00olB0?oooo]ZoookJP02oookJP03ooo:0?oonf[ooo]Z00Cooo]Z00Coo`2C
oookJ_oonf[oo`0C2?oonfX00ooJo`3ooo]Zon7o0004oookJP03obH0oooonf[ooo]Z01Gooo]Z00?o
<Ol0o`3oFooonfX01?oonfX01_n2o`3ooo]Zo`0`oooonf[o0>Soo`3oC@?ooo]Z00Go1P3ooookJ_oo
nf[oo`3eodCo0002oookJP03ool0J_l0ojgo0?n]00Gooo]Z00Goo`1AoookJ_oonf[ooo]Zo`2]o`02
oookJP03ool0NOoonf[ooo]Z00Kooo]Z00?o0?mCoookJ_oonfX00_oonfX01?l0oagoA?l0odCo0?l0
hOmCoookJP03ool0o?oonf[ooo]Z00?ooo]Z00Co603ooookJ_oonf[oo`H00_oonfX00oo[o`3ooo]Z
ool0mP02oookJP04o`2Voooonf[ooo]ZojP0o`?ooo]Z00_oo`3ioookJ_l0Mooooo]Zo`3oV_ooK03o
oo]Zo`3oc?ooP@3ooo]Zoc_o0003oookJP03o`3koooonf[ooo]Z00?ooo]Z00Woo`<0oookJ_oonf[o
o`3MogT0oooonf[o0:?ook?o0?nO0?l01_oonfX02Ol0omkoo`27oookJ_oonf[oo`1/oookJ_m=0?oo
oo]Zool^0002oookJP03of40ool0odGooo]Z00?ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP07oook
JP03ofP0oooonf[ooo]Z00;ooo]Z00?o603oo`1doooVo`000ooonfX00oooT03ooo]ZoookJP08oook
JP04oonn0?oonf[o0?l5on/0o`Gooo]Z00?ooeL0oookJ_oonfX01OoonfX00ooo02gooo]ZoookJP05
oookJP03oon10?oonf[ooo]Z00Oooo]Z00Co0=CooookJ_l01?oo0:Wo0_oonfX01ol0R?oooo]Zoook
J_oonf[o0?m>oookJ_l0oc@01ooonfX00ol0hOoo0?lMo`3oD`06oookJP05ool0NOl0[Ooooo]Zool0
DOlE0?l00_oonfX03?l@0?oo01WooookJ_nBo`3oo`3eo`H0ool0j?oooo]Zo`3oCOl0<?oooo]Zoh;o
00;ooo]Z0_lao`07oookJPCo00000_oonfX2obH0o`05oh@0oooonf[of_l0om[o0?oQo`001_oonfX2
ool0T`;o0?Wo0ooonfX2ooo:00;ooo]Z0_l0oa/00ol0S_oooo]ZoookJP0:oookJP?o?@3o0ol0oml6
ogSo0003ocd0ool0g?oo0=co00Go0=co2?mho`07o`3oga7ooo]Z0ol0oa/2oa80o`?ooo]Z00?oolX0
oookJ_oonfX01?oonfX2ool0T`03oookJ_oo01?ooo]Z00Oooo]Z0_oJo`000ooQo`3ooo]ZoookJP02
oookJP03obH0oolPo`3ooo]Z01Gooo]Z00?o<Ol0oookJ_l0oe/01?oonfX00ol0ok3oP_l0o`0`o`02
oookJP05o`3Xool0odgooo]ZoookJ_l60?l00_oonfX00ooo0?GoT_l0oookJP02oookJP03oa00ool0
GOoooo]Z00Cooo]Z00Goo`1AoookJ_oonf[ooo]Zo`2]o`03oookJP03ool0NOoonf[ooo]Z00Kooo]Z
00?o0?mCoookJ_oonfX00_oonfX01?l0oagooo]ZoookJ_l0hOlWoookJP00;_oonfX00ooo0?cooo]Z
oookJP03oookJP04oaP0oooonf[ooo]Zool600?ooo]Z00Gojol0ool0m_oonf[ooo]Zo`2Vo`03oook
JP06ojP0oooonf[ooo]ZoiCo0?oonf[o07Oo0_oonfX01?ooK03ooo]Zo`3oc?ooP@02oookJP04oc_o
0?oonf[ooo]Zo`3ko`Kooo]Z00Soo`<0oookJ_oonf[oo`3MoookJ_l05ooo/ol0oil0o`Kooo]Z00Go
0?oNonGo0?oonf[ooo]Zool0K002oookJP06odd0oooo;P3ooo]Zo`3o3?oonf[o0?m51?oonfX01OoU
o`3ooo]Zo`3oT?oonf[oA?l000Sooo]Z00?oJ03ooookJ_oonfX00_oonfX01OlH0?ooi_l0oookJ_oo
nf[ooi0000_ooo]Z00Cookh0oookJ_oUo`3oL03o1_oonfX00oooE`3ooo]ZoookJP03oookJP03ool0
;Ooonf[ooo]Z00Kooo]Z00?oiOl0oookJ_oonfX01ooonfX01_l0o`cooo]Zo`04oooonf[o0:WooiCo
00?ooo]Z00?o0?m>oookJ_l0oc@01ooonfX01Ol0hOoo0?lMoookJ_oonf[o0?mC00Gooo]Z00ooo`1i
o`2]oooonf[oo`1AoaD0oooonf[o403oo`0Ioooo06[oT_l0ool0mOoonf[o1P3oo`3Xool0odd01Ooo
b@000ol0oe_o<Ol0oookJP08oookJPCo00000_nDo`03ooo90003om[o0?oob@3ooo]Z00Cooo]Z0_oo
01<00ooo09?o0?WooookJP03oookJP;oolX000Cooo]Zo`3o6ol0oa_o4P3o2ooonfX00ooob@3o?@3o
ocd0o`02o`3og`GoN?l00ol0g?l;ooo900;o0=co3ooob@0BoookJP;o0?lK00Go08kooookJ_oonf[o
oo]Zooo:0006oookJP;oo`2C00?ooo]Zool04ooonfX01ooonfX00ooJo`3ohOl0oookJP04oookJP03
obH0oooonf[ooo]Z01Gooo]Z00?o<Ol0o`3oFooonfX01?oonfX01_n2o`3o0?nao`0`oooonf[o0>So
o`3oC@;ooo]Z00Go1P3ooookJ_oonf[ooo]ZodCo0003oookJP03ool0J_l0ojgooo]Z00Gooo]Z00Co
o`1AoookJ_oonf[o0:go0ooonfX00ooo07Wooo]ZoookJP05oookJP03o`3oDooonf[ooo]Z00?ooo]Z
00?o0?lModCo0?l0hOl0D_oonfX00ooo0?cooo]ZoookJP04oookJP04oaP0oooonf[ooo]Zool600;o
oo]Z00Gojol0oookJ_oo0?Kooo]Zo`2Vo`03oookJP06ojP0oooonf[ooo]Zool0nOoonf[o07Oo0_oo
nfX01ol0oi[oof`0oookJ_l0olcooh40oookJ_lko`000ooonfX00ol0nooooo]ZoookJP03oookJP04
ool30?oonf[ooo]Zool0g@;ooo]Z00?o0:?ook?o0?nO0?l01_oonfX01?l0omkoo`27oookJ_oo06`2
oookJP06odd0oooonf[oobh0oookJ_mQ0?oo0?m51?oonfX01OoR0?oooo]Zo`3oT?oonf[o0?nB00So
oo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?oo07CoonKo0002oookJP03oon@0?oonf[ooo]Z00Wo
oo]Z00Cookh0oookJ_o[0?ooL03o1OoonfX00oooE`3ooo]ZoookJP04oookJP03ool0;Ooonf[ooo]Z
00Gooo]Z00?ooh40oookJ_oonfX02?oonfX01_l0e?oo00CooookJ_l0ZOoooo]Zo`28o`?ooo]Z00?o
0?m>oookJ_l0oc@01ooonfX01?l0hOoo0?lMoookJ_l0oe<5oookJP05ool0NOl0[Ooooo]Zool0DOlE
0?l00_oonfX03?l@0?oo01WooookJ_nBo`3oo`3eo`H0ool0j?oooo]Zo`3oCOl0ok7ooo]Zoh;o00;o
oo]Z00?o<Ol0oookJ_oonfX01ooonfX4o`0000;o9P3o00GoQ03ooookJ_oonf[of_l0on7o0006oook
JP03ool04ooo09?o0?Wo00Cooo]Z0_oobP001?oonf[o4P3oo`3o6ol0oa/<oookJP;o?@3o0_l0oml5
ogSo00Ko0=co1oloo`000ooonf[o0=coo`3Lo`05o`3Lo`03oookJ_mho`3oN?l000GoN?l00ol0omlA
oookJP;o0?lK00Go4P3ooookJ_oonf[ooo]Zooo:0007oookJP03ool0Tooonf[oo`0C00Wooo]Z00?o
f_l0oookJ_oonfX00ooonfX00olV0?oo8?l0oookJP0EoookJP03oc7o0?oonf[o0?mK00Cooo]Z00Wo
0?n`oh;o0?l0<?oooo]Zo`3Xoooonf[o0?m=oookJ_l60?l00ooonfX00ooo0?GoT_l0oookJP02oook
JP03oa00oooonf[ooo]Z00Cooo]Z00Goo`1AoookJ_oonf[ooo]Zo`2]o`03oookJP03ool0NOoonf[o
oo]Z00Gooo]Z00?o0?mCoookJ_oonfX00_oonfX01?l0oago0?l8oookJ_l0hOlWoookJP00;_oonfX0
0ooo0?cooo]ZoookJP03oookJP04oaP0oooonf[ooo]Zool600;ooo]Z00?ojol0oookJ_oo0?H00_oo
nfX01?l0Y_oooo]ZoookJ_nX0?l3oookJP0;oiCo0?oonf[o07OooookJ_nDo`3oof`0o`3oc?oonf[o
oh40oookJ_lko`000_oonfX00ol0nooooo]ZoookJP04oookJP08ool30?oonf[ooo]Zool0gOmi0?oo
oo]Zo`2Soonco`07oookJP04onGo0?oonf[ooo]Zool0K0?ooo]Z00KoC@3oool^0?oonf[o0?l<oook
J_l0odD4oookJP05onGo0?l0oi3ooo]ZoookJ_m4o`001ooonfX00omX0?oooo]ZoookJP02oookJP03
oaP0oooVo`3ooo]Z00;ooo]Z00?ooi00oookJ_oonfX02?oonfX01Ooo_P3ooo]ZonGo0?l0o`GoL03o
00Gooo]Z00?ooeL0oookJ_oonfX01?oonfX00ooo02gooo]ZoookJP06oookJP03onGo0?oonf[ooo]Z
00Kooo]Z00Ko0?l<oookJ_l01?oooo]Zo`2YoonDo`03oookJP03o`3oC_oUo`3o0?ld00Sooo]Z00Co
0?lMoookJ_oonf[o0?mC1OoonfX01Ooo07Wo0:gooookJ_oo057o5@3o00;ooo]Z00So403oool0J_nB
o`3oo`3eoookJ_l60?oo0>Soo`3oC@CoolT00_l0oe/00olao`3ooo]ZoookJP08oookJP?o000000?o
U?l0ob3o0?oob@000_oob@000ooJo`3oolT0oookJP03oookJP;oo`0C0_oo09<4oookJP;oolX000?o
4P3oo`3o6ol0oa/03?oonfX00olm0?ooN?l0ogSo0004ogSo00Co0=co1?loo`02ooo900?oA?l00ooo
b@02oookJQ?oolT000?oN?l0o`3ogooonfX04?oonfX3o`3o6`;ooo]Z00?oolX0oookJ_oonfX01?oo
nfX00ol0nOooo`2Cool0T`02ool04`Oooo]Z00?of_l0on7o0?oonfX01?oonfX00olV0?oooo]Zoook
JP0DoookJP03oc7o0?oonf[o0?mK00Cooo]Z00KoP_l0oookJ_l0ok7o033ooookJ_l0odd3oookJP05
o`H0oooonf[ooo]Zool0mOm4o`000_oonfX00ooo06[o05goo`3o[@05oookJP04ool0DOoonf[ooo]Z
o`2]o`?ooo]Z00?oo`1ioookJ_oonfX01_oonfX00ol0oe?ooo]ZoookJP02oookJP04o`3o7Ooonf[o
A?l0o`3Qoe7ooo]Z00?oo`3loookJ_oonfX01?oonfX00olH0?oooo]Zool60002oookJP03on_o0?oo
nf[oo`3f00;ooo]Z00Go0:KooookJ_oonf[ooo]ZojP0o`02oookJP09ool0nOoonf[o07OooookJ_l0
oi[ooo]Zoom/0?l0olcooh4000;ooo]Z00Co>ol0oookJ_oonf[o0?_o1OoonfX02Ooo0`3ooo]Zoook
J_oo0=goN@3ooookJ_l0Xooo/ol0oil0o`06oookJP05omgo0?oo08Oooo]ZoookJ_oo06`00_oonfX0
1_m=0?oooo]Zool^0?oonf[oH@3oo`3oA@Cooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP07oookJP03
ofP0oooonf[ooo]Z00;ooo]Z00?o603oo`1doooVo`000ooonfX00oooT03ooo]ZoookJP08oookJP04
oonn0?oonf[oj`3oog00o`Gooo]Z00?ooeL0oookJ_oonfX01?oonfX00ooo02gooo]ZoookJP06oook
JP03oon10?oonf[ooo]Z00Oooo]Z00Ko0=Coo`04oooonf[o0:WooookJ_l0R?l3oookJP03o`3oC_oo
nf[o0?ld00Oooo]Z00Co0>7oo`3o7Ooonf[o0?mC1OoonfX01Ooo07Wo0:gooookJ_oo057o5@3o00;o
oo]Z00oo05gooa00oooo06[oT_l0ool0mOl60?oo0>SooookJ_l0odgo0?naoookJ_n2o`3ooo]Zo`3o
Folao`002_oonfX3o`000003obH0oolPo`3oQ03o00;ooo]Z00?of_l0on7o0?oonfX01?oonfX00ooo
01?oo`2Cool0T`04oookJP;oolX00_lB0?l2o`3o6`_ooo]Z00?o?@3oogSo0?mho`001?mho`05o`3L
o`Co?ol02OoonfX8ocoo00Oo0=co00?ooo]ZogSo0?mho`000omho`000ol0omoooo]ZoookJP0>oook
JP?o0?lK0_oonfX00ooobP3ooo]ZoookJP05oookJP;oo`2C0_oo01<8oookJP03om[o0?oonf[ooo]Z
00?ooo]Z00?o9P3oob3o0?oonfX05?oonfX00olao`3ooo]Zo`3oF`04oookJP07o`3o/?n2o`3ooo]Z
o`0`oooonf[o0>Soo`3oC@02oookJP05o`H0oooonf[ooo]Zool0mOnBo`000ooonfX00ooo06[o403o
oookJP04oookJP05ool0DOoonf[ooo]ZoookJ_l0[Ol00ooonfX00ooo07Wooo]ZoookJP06oookJP03
o`3oDooonf[ooo]Z00;ooo]Z00?o0?lMo`3o2?l0hOl09ooonfX002gooo]Z00?oo`3loookJ_oonfX0
1?oonfX00olH0?oooo]Zool60003oookJP05on_o0?oonf[oo`3foookJ_nDo`000ooonfX01?nX0?oo
oo]ZoookJ_nDo`02oookJP06o`1goooonf[oof`0oookJ_l0olcooh400_oonfX01?lko`3ooo]Zoook
J_l0nol6oookJP08ool30?oonf[ooo]Zool0gOmi0?oooo]Zo`2Soonco`06oookJP04o`3og_oUo`3o
oo]Zool0K0?ooo]Z00KoC@3oool^0?oonf[o0?l<oookJ_l0odD4oookJP03onGo0?oonf[o0?n@00;o
oo]Z00?oA?l0oookJ_oonfX01OoonfX01omX0?oooo]ZoookJ_oonf[o603ooookJ_oVo`000_oonfX0
0oooT03ooo]ZoookJP08oookJP05oonn0?oonf[ooo]Zon/0oom`0?l01_oonfX00oooE`3ooo]Zoook
JP03oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?oiOl0oookJ_oonfX01_oonfX00ol0o`cooo]Zo`04
o`02oookJP08o`2Yoooonf[ooo]ZoookJ_m4o`3oiOl0oookJ_l0oc@7oookJP04o`3Qool0oagooo]Z
o`3oD`Gooo]Z00Goo`1io`2]oooonf[oo`1AoaD0o`02oookJP08oa00oooo06[oT_l0ool0mOoonf[o
1P3ooookJ_l0odd4ooo90003o`3oFooob@3o<Ol000_ooo]Z00Co0000obH0oonDo`3oolT00_oonfX0
0ooob@3of_l0ooo90004oookJP03ool04ooo09?oo`2C00Cooo]Z0_oobP03o`3o6`_ooo]Z1?mho`05
o`3Lo`03oookJ_loo`3o?ol000;o?ol00_oonfX4ooo900OoA?l000?ooo]Zooo90?oob@003?oob@05
o`3Lo`03oookJ_mho`3oN?l000;o0?oO0_lm0?l>oookJP04oa80ool0oa_o0?lKoookJP;oolX01Ooo
nfX01Ol0nOoooo]Zool0Tooonf[oo`0C00Oooo]Z0_oJo`04oookJP03obH0oolPo`3ooo]Z01Gooo]Z
00?o<Ol0o`3oFooonfX01?oonfX01_n2o`3ooo]Zo`0`oooonf[o0>Soo`3oC@;ooo]Z00Go1P3ooook
J_oonf[oo`3eodCo0003oookJP03ool0J_l@0?oooo]Z00Gooo]Z00Coo`1AoookJ_oonf[o0:go0_oo
nfX00ooo07Wooo]ZoookJP06oookJP03o`3oDooonf[ooo]Z00;ooo]Z00Co0?lMoookJ_l0o`So0>7o
D?oonfX00ooo0?cooo]ZoookJP04oookJP04oaP0oooonf[ooo]Zool600;ooo]Z00Gojol0oookJ_oo
0?Kooo]Zo`2Vo`03oookJP0?ojP0oooonf[ooo]ZoookJ_oo0?Wooo]Zo`1goooonf[o0?nJoom/0?oo
nf[o0?o<oon10?oonf[o>ol000?ooo]Z00?o0?_ooookJ_oonfX00ooonfX02Ooo0`3ooo]ZoookJ_oo
0=goN@3ooookJ_l0Xooo/ol0oil0o`06oookJP04o`3og_oo08Oooo]Zool0K0;ooo]Z00KoC@3ooook
J_oo;P3ooo]Zof40ool0odD5oookJP05on80ool0oi3ooo]ZoookJ_l0oi801ooonfX00omX0?oooo]Z
oookJP02oookJP03oaP0ool0M?ooi_l000;ooo]Z00?ooi00oookJ_oonfX02?oonfX01?oo_P3ooo]Z
oookJ_o[0?l6oookJP03oomG0?oonf[ooo]Z00Cooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3o
oo]ZoookJP07oookJP06o`3Doooonf[o00CooookJ_l0ZOoo08So0ooonfX01?l0odkooo]ZoookJ_l0
oc@6oookJP04o`3Qool0oagooo]Zo`3oD`Gooo]Z00Goo`1io`2]oooonf[oo`1AoaD0o`02oookJP0?
o`1Mool@0?ooo`1Zoi;o0?oo0?Go1P3ooookJ_l0j?oo0?m=o`3o/Ooonf[oP_l0oookJ_l0oe_o<Ol0
00_ooo]Z00?o0000obH0oolV0?l00_n40?l2oookJP03om[o0?oonf[ooo]Z00Cooo]Z0_oo09<4oook
JP;oolX000Co4P3oo`3o6ol0oa_o0?lK2_oonfX4ogSo0003o`3ogol0g?oo0=co00?o0=co1?loo`0I
oookJPCo?ol01Ol0g?l00ooonf[oN?l0ogSo0002o`3og`03ocd0oooonf[ooo]Z00cooo]Z00Co08ko
o`3o6ol0oa_ooo]Z0_oobP06oookJP04o`3ioooo09?ooo]Zool04`Sooo]Z00?of_l0oookJ_oonfX0
0_oonfX00olV0?oo8?l0oookJP0EoookJP03oc7o0?oonf[o0?mK00Cooo]Z00Wo0?n`oh;o0?l0<?oo
0?naoookJ_l0j?oo0?m=oookJ_l60?l00_oonfX00ooo0?GoT_l0oookJP03oookJP03oa00oooonf[o
oo]Z00Cooo]Z00Goo`1AoookJ_oonf[ooo]Zo`2]o`02oookJP03ool0NOoonf[ooo]Z00Kooo]Z00?o
0?mCoookJ_oonfX00_oonfX01?l0oago0?l8oookJ_l0hOlVoookJP00;OoonfX00ooo0?cooo]Zoook
JP03oookJP04oaP0oooonf[ooo]Zool600?ooo]Z00Gojol0ool0m_oonf[ooo]ZoiCo0002oookJP0?
ojP0oooonf[ooo]ZoookJ_nDo`3ooo]Zo`1goooonf[oU?l0oom/0?l0olcooo]Zoon10?oonf[o>ol0
00?ooo]Z00?o0?_ooookJ_oonfX00ooonfX02?oo0`3ooo]ZoookJ_oo0=goN@3ooookJ_l0Xooo/ol0
1ooonfX01?oUo`3ooo]ZoookJ_oo06`3oookJP03odd0oooo;P3o0?l<00;ooo]Z00?o0?m5oookJ_oo
nfX00_oonfX01OoUo`3o0?n@oookJ_oonf[oA?l000Oooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH
0?ooi_l0oookJP02oookJP03oon@0?oonf[ooo]Z00Sooo]Z00Gookh0oookJ_o[0?oo0?l5og00o`05
oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01_oonfX00ooUo`3ooo]ZoookJP06
oookJP03o`3o3?oonf[o00Co00;ooo]Z00Co0:WooiCo0?oonf[ooo]Z0_m4o`000ooonf[o0?ldoook
JP06oookJP04o`3Qool0oagooo]Zo`3oD`Kooo]Z00Coo`1io`2]oooo057o5@3o0_oonfX02Ol@0?oo
o`1Zoi;o0?oo0?Gooo]Zo`H0oooonf[o0?m=onGo0003ooo90004o`3oFooob@3oolT0oc7o00_ooo]Z
00Go9P3oob3o0?l0003o0000oookJP02om[o0004ooo90?oonf[ooo]ZoookJP;oo`0C00?oo`2Cooo9
0?oob@000ooonfX00ooobP3o0?lKo`3o6`02o`2>o`Wooo]Z00?o0?oOogSo0?mho`000ol0g?l00ooo
nf[oiOl0onGo0007onGo00Oo02[o2_m4o`07o`0Zo`CoolT01?oonfX2ocoo00?o0=co0_mho`03o`3o
g`;o?@3o3?oonfX00ol0S_oo4P3oo`3o6`02oookJP03ooo:0?oonf[ooo]Z00?ooo]Z00Go0?Wooook
J_oo09?oo`2Cool04`08oookJP03om[o0?oonf[ooo]Z00;ooo]Z00?o9P3ooh@0oooonfX05?oonfX0
0olao`3ooo]Zo`3oF`04oookJP06oh;o0?oonf[ooo]Zo`0`oooonf[o0?m=0ooonfX01Ol60?oooo]Z
oookJ_oo0?GoA?l000;ooo]Z00?oo`1Zo`1Mool@0?l01OoonfX01?oo057ooo]ZoookJ_l0[Ol3oook
JP03ool0NOoonf[ooo]Z00Kooo]Z00?o0?mCoookJ_oonfX00_oonfX00ol0oago0?l8o`3Qo`1@oook
JP03ool0o?oonf[ooo]Z00Cooo]Z00?o603ooookJ_oo1P000ooonfX01Oo[o`3ooo]Zool0m_oonf[o
0:Ko00?ooo]Z00KoZ03ooookJ_oonf[oo`3ioookJ_l0Mol2oookJP07o`3oV_ooK03o0?o<oookJ_oo
P@3ooo]Zoc_o0003oookJP03o`3koooonf[ooo]Z00;ooo]Z00Woo`<0oookJ_oonf[oo`3MogT0oooo
nf[o0:?ook?o0?nO0?l01_oonfX01OoMo`3oo`27oookJ_oonf[oo`1/00;ooo]Z00KoC@3ooookJ_oo
;P3oH@3ooookJ_l0odD4oookJP05on80ool0oi3ooo]ZoookJ_l0oi801ooonfX00omX0?oooo]Zoook
JP02oookJP03oaP0ool0M?ooi_l000?ooo]Z00?ooi00oookJ_oonfX02?oonfX01?oo_P3ooo]Zon/0
oom`0?l5oookJP03oomG0?oonf[ooo]Z00Cooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]Z
oookJP07oookJP07o`3Doooonf[o00CooookJ_l0ZOoooo]Zo`28o`02oookJP04o`3o;_l0odkooo]Z
o`3o=0Kooo]Z00Go0>7oo`3o7Ooonf[ooo]Zo`3oD`05oookJP04ool0NOl0[Oooo`1AoaD0o`;ooo]Z
013o05gooa00oooo06[oT_l0ool0mOl60?oooo]Zo`3Xool0odgo0?naoookJ_n2o`3ooo]Zo`3oFooo
nf[o<Ol02ooonfX01OlV0?oo8?l0oh@0ool0003ooo]Z00;of_l01OoonfX00ooo01?oo`2CoookJP04
oookJP05ooo:0?oonf[o0?lKo`3o6ol0S_l02OoonfX01?l0omooN?l0ogSo0?l0oml3o`3Lo`;ooo]Z
1?loo`0Ko`0Zo`Wooo]Z0_loo`02o`3Lo`03oookJ_mho`3oN?l000?o0?oO00?o?@3ooookJ_oonfX0
2_oonfX00ol0S_oooo]Zo`3o6`02oookJP03ooo:0?oonf[ooo]Z00Cooo]Z00Co0?Woool0Tooo09?o
o`0C2?oonfX2om[o00?ooo]Z00?o9P3oob3o0?oonfX05?oonfX01?lao`3ooo]ZoookJ_l0oe/3oook
JP07o`3o/?n2o`3ooo]Zo`0`ool0ok7o0>Soo`3oC@02oookJP05o`H0oooonf[ooo]Zool0mOnBo`00
0ooonfX00ooo06[o403ooookJP04oookJP05ool0DOlE0?oooo]ZoookJ_l0[Ol00ooonfX00ooo07Wo
oo]ZoookJP06oookJP08o`3oDooonf[ooo]ZoookJ_l0oago0?l8oookJ_l0hOlVoookJP00;OoonfX0
0ooo0?cooo]ZoookJP03oookJP04oaP0oooonf[ooo]Zool600;ooo]Z00Cojol0oookJ_oo0?Kooo]Z
0_nDo`02oookJP04ojP0oooonf[ooo]ZoiCo00;ooo]Z00Wo07OooiCo0?ooK03oU?l0o`3oc?oonf[o
oh40oookJ_lko`000_oonfX00ol0nooooo]ZoookJP04oookJP08ool30?oonf[ooo]Zool0gOmi0?oo
oo]Zo`2Soonco`06oookJP04o`3og_oUo`3ooo]Zool0K0Cooo]Z00?oC@3ooookJ_l0o``00_oonfX0
1ol0odGooo]ZoookJ_oonf[oiOl0oookJ_l0oi000_oonfX00om4o`3ooo]ZoookJP05oookJP07ofP0
oooonf[ooo]ZoookJ_lH0?oo07CoonKo0002oookJP03oon@0?oonf[ooo]Z00Sooo]Z00Gookh0oook
J_oonf[oj`3oog00o`06oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01OoonfX0
0ooUo`3ooo]ZoookJP07oookJP06o`3o3?oonf[o00CooookJ_l0ZOooU?l00_oonfX2odCo0003oook
J_l0ocCooo]Z00Kooo]Z00Go0>7oo`3o7Ooonf[ooo]Zo`3oD`05oookJP04ool0NOl0[Oooo`1AoaD0
o`;ooo]Z00Wo403oool0J_nBo`3oo`3eoookJ_l60?oooo]Zo`3oCOoUo`000_oonfX01Ooob@3o0?mK
ooo90?oob@3o<Ol000_ooo]Z00Ko9P3oooo90?l0003o0000on7o0?oJo`04oookJP;oo`0C0_oo09<2
ooo900;ooo]Z00GoolX0o`3o6ol0oa_o4P3oo`2>o`08oookJP03o`3ogomho`3oiOl000koiOl00ooo
nfX6o`3o<`koA?l00_oob@001?oonf[o02[oo`0Zool0:_l8oookJP;o?ol00_l0g?l2ogSo0004oook
J_l0omoo0?oOo`3og`cooo]Z00?o08kooa80ool0oa/00_oonfX00ooobP3ooo]ZoookJP03oookJP05
o`3ioooonf[ooo]Zool0Tooo01<01ooonfX00ooQo`3of_l0oookJP03oookJP03obH0oon40?oooo]Z
01Cooo]Z00?o<Ol0oookJ_l0oe/01?oonfX01_n2o`3ooo]ZoookJ_l0<?oooo]Zo`3oC@;ooo]Z00Go
1P3ooookJ_oonf[oo`3eodCo0003oookJP03ool0J_l@0?oooo]Z00Gooo]Z00Coo`1AoookJ_oonf[o
0:go0_oonfX00ooo07Wooo]ZoookJP06oookJP03o`3oDooonf[ooo]Z00;ooo]Z00Co0?lMoookJ_l0
o`So0>7oCooonfX00ooo0?cooo]ZoookJP04oookJP03oaP0oooonf[oo`H000;ooo]Z00?ojol0oook
J_oo0?H00_oonfX01?l0Y_oooo]ZoookJ_nX0?l3oookJP0;ool0nOoonf[o07OooookJ_l0oi[oof`0
oookJ_l0olcooh40oookJ_lko`000ooonfX00ol0nooooo]ZoookJP03oookJP09ool30?oonf[ooo]Z
ool0gOmi0?oooo]Zo`2Soonco`3oW`3o00Kooo]Z00Co0?oNool0Qooonf[oo`1/0ooonfX01_m=0?oo
obh0oookJ_mQ0?oooo]Zo`3oA@Cooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP07oookJP08ofP0oooo
nf[ooo]ZoookJ_lH0?oo07CooookJ_oVo`02oookJP03oon@0?oonf[ooo]Z00Sooo]Z00Cookh0oook
J_l0o`Goj`3o1_oonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40
oookJ_oonfX02?oonfX01_l0e?oo00CooookJ_l0ZOoooo]Zo`28o`;ooo]Z00Co0?l^o`3oC_oonf[o
0?ld1_oonfX01Ol0hOoo0?lMoookJ_oonf[o0?mC00Gooo]Z00Coo`1io`2]oooo057o5@3o0ooonfX0
3ol@0?ooo`1Zoi;o0?oo0?Go1P3ooookJ_l0j?oo0?m=o`3o/Ooonf[oP_l0oookJ_l0oe_ooo]Zoc7o
000;oookJP06obH0oon40?ooQ03oo`000?oQo`3of_l01OoonfX00ooo01?oo`2Cool0T`04oookJP;o
olX00_l0oa/00ol0S_oooo]ZoookJP06oookJP04o`3ogomho`3oN?l0ogSo00;o0=co00?ooo]Zocoo
0?loo`000oloo`001?oonf[o02[oo`0Zool0:_l5oookJPko0?lc2?oonfX3o`0Zo`Sooo]Z0_loo`03
o`3Lo`;oN?l000Cooo]Zo`3ogol0omoo0?oO2ooonfX2o`2>o`04o`3o6olB0?oooo]Zooo:00Kooo]Z
00Co0?WooookJ_oo09?oo`0C2?oonfX00ooQo`3of_l0oookJP02oookJP03obH0oolPo`3ooo]Z01Co
oo]Z00?o<Ol0oookJ_l0oe/01?oonfX02Ol0ok3oP_l0oookJ_l0<?oo0?nao`3Xool0odgooo]Zo`H0
o`02oookJP03ool0mOnBo`3ooo]Z00?ooo]Z00?o403ooookJ_oonfX01?oonfX01?oo057ooo]Zoook
J_l0[Ol3oookJP03ool0NOoonf[ooo]Z00Kooo]Z00?o0?mCoookJ_oonfX00_oonfX00ol0oago0?l8
o`3Qo`0VoookJP00;?oonfX00ooo0?cooo]ZoookJP04oookJP03oaP0oooonf[oo`H000?ooo]Z00Co
jol0oookJ_oo0?Kooo]Z0_nDo`02oookJP04ojP0oooonf[ooo]ZoiCo00;ooo]Z00Ko07OooiCo0?oo
K03oU?l0oookJ_ooP@02oookJP04oc_o0?oonf[ooo]Zo`3ko`Kooo]Z00Soo`<0oookJ_oo0=goN@3o
oookJ_l0Xooo/ol0oil0o`Kooo]Z00Co0?oNonGo0?oonf[oo`1/0ooonfX00om=0?ooobh0o`3o3002
oookJP03o`3oAOoonf[ooo]Z00;ooo]Z00GoiOl0o`3oT?oonf[ooo]ZodCo0007oookJP03ofP0oooo
nf[ooo]Z00;ooo]Z00?o603oonKo0?oonfX00_oonfX00oooT03ooo]ZoookJP07oookJP05oonn0?oo
nf[ooo]Zon/0oom`0?l01_oonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Kooo]Z
00?ooh40oookJ_oonfX01_oonfX00ol0o`cooo]Zo`04o`02oookJP03o`2Yoooonf[ooo]Z00?oA?l0
00?o0?ldoookJ_oonfX01OoonfX01Ol0hOoo0?lMoookJ_oonf[o0?mC00Gooo]Z00Coo`1io`2]oooo
057o5@3o0_oonfX02Ol@0?oo01Wooi;o0?oo0?Gooo]Zo`H0oooonf[o0?m=onGo0002oookJP05ooo9
0?l0oe_oolT0ooo90?lao`002ooonfX01_lV0?oooo]Zo`000?l0003ohOl0om[o00;ooo]Z00?oolT0
ool04ooo01<00_oo09<3ooo90006oookJ_oobP3o0?lKo`3o6olB0?oo08ko2?oonfX01?l0omooN?l0
ogSo0?l0g?l=onGo00;ooo]Z00?o0?lcoomB0?ooDP005_m4o`02oomB00;o0?lc1?l0:_l6oookJP;o
?ol00_l0g?l2ogSo00;ooo]Z0ol0oml;oookJP05o`2>ool0oa_ooo]ZoookJ_oobP001OoonfX01Ol0
nOoooo]ZoookJ_oo09?oo`0C00Oooo]Z00?ohOl0om[o0?oonfX00ooonfX00olV0?ooQ03ooookJP0C
oookJP03oc7o0?oonf[o0?mK00Cooo]Z00KoP_l0oookJ_oonf[o033ooookJ_l0odd3oookJP04o`H0
oooonf[ooo]ZodCo00?ooo]Z00?oo`1Zoa00ool06Ol01OoonfX01?oo057o5@3ooookJ_l0[Ol2oook
JP03ool0NOoonf[ooo]Z00Oooo]Z00So0?mCoookJ_oonf[ooo]Zo`3o7Ooonf[o0?l8o`3Qodkooo]Z
00?oo`3loookJ_oonfX01?oonfX01?lH0?oooo]ZoookJ_oo1P02oookJP05on_o0?oonf[oo`3foook
J_l0Y_l00ooonfX01?nX0?oooo]ZoookJ_oo0?T2oookJP09o`1goooonf[o0?nJoom/0?l0olcooo]Z
oon10?oonf[o>ol000?ooo]Z00?o0?_ooookJ_oonfX00ooonfX02Ooo0`3ooo]Zool0gOmi0?oooo]Z
o`2Soonco`3ooo]Zoil0o`05oookJP05omgo0?l0omkoo`27oookJ_oo06`00_oonfX01_m=0?oooo]Z
ool^0?mQ0?oooo]Zo`3oA@Cooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP07oookJP03ofP0oooonf[o
oo]Z00;ooo]Z00?o603oo`1doooVo`000ooonfX00oooT03ooo]ZoookJP07oookJP04oonn0?oonf[o
oo]Zon/0o`Kooo]Z00?ooeL0oookJ_oonfX01?oonfX00ooo02gooo]ZoookJP05oookJP03oon10?oo
nf[ooo]Z00Oooo]Z00Ko0=CooookJ_l01?oooo]Zo`2Yool0R?l2oookJP04o`3o;_l0odkooo]Zo`3o
=0Kooo]Z00Go0>7oo`3o2?l0oagooo]Zo`3oD`05oookJP04ool0NOl0[Oooo`1AoaD0o`?ooo]Z00oo
403oo`0IoonBo`3oo`3eo`H0oooonf[o0>Soo`3oCOl0ok7ooo]Zoh;o0?oonf[o0?mKoookJ_lao`00
2ooonfX01_lV0?ooQ03oo`000?l0003ohOl0om[o00Cooo]Z00Coo`0Cool0Tooo09?o0?Wo0ooonfX2
ooo:00;o0?lK00?o08kooookJ_oonfX01_oonfX00ol0omooN?l0ogSo0003o`3Lo`?o?ol00ooonfX3
o`0Zo`Cooo]Z00?o0?lcoomB0?ooDP006?ooDP02o`3o<`Co02[o1ooonfX2ocoo00;o0=co0_mho`00
0ooonf[o?@3oo`3og`02o`3og`[ooo]Z00Go08koo`3o6olB0?oooo]Zooo:0006oookJP04o`3ioooo
nf[oo`2Cool04`Oooo]Z00?ohOl0oookJ_oJo`000ooonfX00olV0?oo8?l0oookJP0CoookJP04oc7o
0?oonf[ooo]Zo`3oF`?ooo]Z00Oo0?n`oh;o0?oonf[o033oo`3o/Ooonf[o0?m=00;ooo]Z00Go1P3o
oookJ_oonf[oo`3eoi;o0003oookJP03oa00ool06Ooooo]Z00Cooo]Z00Goo`1AoaD0oooonf[ooo]Z
o`2]o`02oookJP03ool0NOoonf[ooo]Z00Oooo]Z00So0?mCoookJ_oonf[ooo]Zo`3o7Ol0o`Sooo]Z
o`3QobGooo]Z000/oookJP03ool0o?oonf[ooo]Z00?ooo]Z00Co603ooookJ_oonf[oo`H00ooonfX0
0oo[o`3oo`3foookJP03oiCo0003oookJ_nX0?oooo]Z00;ooo]Z00?oU?l0oookJ_l0Mol00_nDo`00
1_ooK03oU?l0oookJ_ooP@3ooo]Zoc_o00?ooo]Z00?o0?_ooookJ_oonfX00ooonfX02?oo0`3ooo]Z
oookJ_oo0=goN@3ooookJ_l0Xooo/ol01_oonfX01?l0omkoiOl0oookJ_oo06`4oookJP03odd0oooo
;P3o0?l<00;ooo]Z00Oo0?m5oookJ_oonf[ooo]ZonGo0?oonf[o0?n@00;ooo]Z00?oA?l0oookJ_oo
nfX01OoonfX01omX0?oooo]ZoookJ_oonf[o603oo`1doooVo`000_oonfX00oooT03ooo]ZoookJP08
oookJP05oonn0?oonf[ooo]Zon/0oom`0?l01_oonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooo
nf[ooo]Z00Kooo]Z00?ooh40oookJ_oonfX01_oonfX00ol0o`cooo]Zo`04o`02oookJP03o`2Yoooo
nf[ooo]Z00CoA?l01ooonfX01Ol0hOoo0?lMoookJ_oonf[o0?mC00Gooo]Z00Coo`1io`2]oooo057o
5@3o0ooonfX02?l@0?ooT_l0ool0mOoonf[o1P3ooookJ_l0odgoiOl00_oonfX01Ooob@3o0?mKoook
J_oonf[o<Ol000_ooo]Z00Co9P3ooookJ_oonf[ohOl00_oJo`001_l0003oolT0ooo90?oo01?oolT0
ool0T`CoolT000GoolX0o`3o6ol0oa_o4P3oo`2>o`07oookJP04ocd0ool0omooN?l0ogSo00;o0=co
00?ooo]ZonGo0?oUo`002_oUo`04oomB00SoolT03Om4o`000onio`3ooo]ZoookJP02oookJP?ooe80
0_l0oc<01?oonf[o02[oo`0Zool0:_l5oookJP;o?ol00_l0g?l3ogSo0003oookJ_lm0?oo0?oO00;o
iOl02OoonfX01?l0S_oo0?lKoa80oooonfX2ooo:00Cooo]Z00Co0?WooookJ_oo09?ooo]Z0_oo01<6
oookJP03on7o0?oJo`3ooo]Z00;ooo]Z00?o9P3oob3o0?n40?l05?oonfX00olao`3ooo]Zo`3oF`04
oookJP06oh;o0?oonf[ooo]Zo`0`ool0odgo0>So0_oonfX01Ol60?oooo]ZoookJ_oo0?GoA?l000?o
oo]Z00?oo`1Zoa00ool06Ol01?oonfX01?oo057o5@3ooookJ_l0[Ol3oookJP03ool0NOoonf[ooo]Z
00Kooo]Z00?o0?mCoookJ_oonfX00_oonfX00ol0oago0?l8o`3Qo`1>oookJP03ool0o?oonf[ooo]Z
00Cooo]Z00?o603ooookJ_oo1P000ooonfX01Oo[o`3ooo]Zool0m_oonf[o0:Ko00;ooo]Z00OoZ03o
oookJ_oonf[ooo]Zool0nOoonf[o07Oo00;ooo]Z00Ooof`0oookJ_l0olcooo]Zoon10?oonf[o>ol0
00?ooo]Z00?o0?_ooookJ_oonfX00_oonfX02Ooo0`3ooo]ZoookJ_oo0=goN@3ooookJ_l0Xooo/ol0
oil0o`06oookJP04o`3og_oo08Oooo]Zool0K0?ooo]Z00KoC@3ooookJ_oo;P3oH@3ooookJ_l0odD4
oookJP05on80ool0oi3ooo]ZoookJ_l0oi801ooonfX02?mX0?oooo]ZoookJ_oonf[o603oo`1doooo
nf[oi_l00_oonfX00oooT03ooo]ZoookJP08oookJP04oonn0?oonf[o0?l5on/0o`Kooo]Z00?ooeL0
oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP05oookJP03oon10?oonf[ooo]Z00Oooo]Z00Ko0=Co
oookJ_l01?oooo]Zo`2Yool0R?l3oookJP03o`3o;_l0odko0?ld00Oooo]Z00Co0>7oo`3o7Ooonf[o
0?mC1OoonfX01?oo07Wo0:goool0DOlE0?l3oookJP0?o`1Mool@0?ooT_l0ool0mOl60?oooo]Zo`3X
ool0odgo0?naoookJ_n2o`3ooo]Zo`3oFooonf[o<Ol000_ooo]Z00?o9P3ooh@0oooonfX00_oQo`00
0ooJo`3o0000oookJP02oookJP03ool04ooo09?o0?Wo00?ooo]Z0_oobP02o`3o6`;o08ko1_oonfX0
1?lm0?oo0?oOogSo0?mho`02o`3Lo`03oookJ_loo`3o?ol000?ooo]Z0ol0:_l4oookJP04o`3o<ooo
DP3ooe80oomB01Oo^Ol00ooonfX3oomB00;o0?lc00Cooo]Zo`0Zool0:_oo02[o1_oonfX2ocoo00;o
0=co0_mho`000ooonf[o?@3ooookJP02o`3og`Wooo]Z00Co08koo`3o6olB0?oo4P3o0_oobP05oook
JP03o`3ioooo09?ooo]Z00;oo`0C1_oonfX00ooQo`3ooo]Zom[o0002oookJP03obH0oooonf[o8?l0
01Cooo]Z00?o<Ol0oookJ_l0oe/01?oonfX01_l0ok3oP_l0oookJ_l0<?oo0?nao`3oC@;ooo]Z00Go
1P3ooookJ_oonf[oo`3eoi;o0004oookJP03oa00ool06Ooooo]Z00?ooo]Z00Goo`1AoaD0oooonf[o
oo]Zo`2]o`03oookJP03ool0NOoonf[ooo]Z00Kooo]Z00?o0?mCoookJ_oonfX00_oonfX00ol0oago
oo]Zo`3Qo`0UoookJP00:ooonfX00ooo0?cooo]ZoookJP04oookJP04oaP0oooonf[ooo]Zool600;o
oo]Z00?ojol0oookJ_oo0?H01?nDo`001Ooonf[oZ03ooookJ_oonf[oU?l000;ooo]Z00?o07OooiCo
0?ooK0000_nDo`001?oonf[ooh40oookJ_lko`02oookJP03o`3koooonf[ooo]Z00Cooo]Z00Soo`<0
oookJ_oo0=gooo]ZogT0ool0Xooo/ol0oil0o`Kooo]Z00Co0?oNonGo0?oonf[oo`1/0ooonfX00om=
0?ooobh0o`3o3002oookJP03o`3oAOoonf[ooo]Z00;ooo]Z00GoiOl0o`3oT?oonf[ooo]ZodCo0007
oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603oo`1doooVo`3ooo]Zoon@000:oookJP05oonn0?oo
nf[ooo]Zon/0oom`0?l01_oonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Kooo]Z
00?ooh40oookJ_oonfX01OoonfX00ol0o`cooo]Zo`04o`02oookJP03o`2YoonDo`3ooo]Z00CoA?l0
00?o0?ldoookJ_oonfX01?oonfX01OnDo`3o0>7oo`3o7Ooonf[o0?mC00Gooo]Z00Coo`1io`2]oooo
nf[oo`1A0ooonfX2oiCo0006ool0mOoonf[o1P3ooookJ_l0odgoiOl00_oonfX01Ooob@3ooo]Zo`3o
Fooonf[o<Ol000[ooo]Z00KoolT0obH0oooonf[ooo]Zon7o0?oJo`04ooo90003ool04ooo09?oo`2C
00?oolT000?oolX0o`3o6ol0oa/00_lB0?l7oookJP04ocd0ool0omooN?l0ogSo00;o0=co0oloo`00
0ooonf[oiOl0onGo0006onGo00?ooe8000?o^Ol0oookJ_oonfX01_oonfX3ooo900WoA?l01OoonfX3
okWo00Cooo]Z0oooDP000ol0oc?ooo]ZoookJP04o`0Zo`Cooo]Z0_loo`02o`3Lo`;oN?l000Co?@3o
oookJ_oonf[oiOl02OoonfX01_l0S_oo0?lKoa80oolB0?oooo]Zooo:00Cooo]Z00?o0?WooookJ_oo
09<00_oonfX00ooo01?ooo]ZoookJP04oookJP03on7o0?oJo`3ooo]Z00;ooo]Z00?o9P3oob3o0?n4
0?l04ooonfX01?lao`3ooo]ZoookJ_l0oe/3oookJP07oh;o0?oonf[ooo]Zo`3o/Ol0<?oo0?m=o`3X
o`02oookJP04o`H0oooonf[ooo]ZodCo00?ooo]Z00?oo`1Zoa00ool06Ol01OoonfX01?oo057o5@3o
oookJ_l0[Ol2oookJP03ool0NOoonf[ooo]Z00Oooo]Z00So0?mCoookJ_oonf[ooo]Zo`3o7Ol0o`So
oo]Zo`3Qodcooo]Z00?oo`3loookJ_oonfX01OoonfX00olH0?oooo]Zool60002oookJP03on_o0?oo
nf[oo`3f00;ooo]Z00Co0:KooookJ_oonf[oZ03o0ooonfX02ooo0?Wooo]Zo`1goooonf[o0?nJoom/
0?oonf[o0?o<oon10?oonf[o>ol000?ooo]Z00?o0?_ooookJ_oonfX00ooonfX02Ooo0`3ooo]Zool0
gOoonf[oN@3oo`2Soonco`3ooo]Zoil0o`06oookJP04o`3og_oo08Oooo]Zool0K0?ooo]Z00GoC@3o
ool^0?mQ0?oooo]Zo`3oA@04oookJP05on80ool0oi3ooo]ZoookJ_l0oi801ooonfX00omX0?oooo]Z
oookJP02oookJP03oaP0ool0M?ooi_l000;ooo]Z00?ooi00oookJ_oonfX02?oonfX01?oo_P3ooo]Z
oookJ_o[0?l6oookJP03oomG0?oonf[ooo]Z00Cooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3o
oo]ZoookJP06oookJP07o`3Doooonf[o00CooookJ_l0ZOoooo]Zo`28o`02oookJP04o`3o;_l0odko
oo]Zo`3o=0Kooo]Z00Go0>7oo`3o7Ooonf[ooo]Zo`3oD`04oookJP04ool0NOl0[Ooooo]Zool0D@?o
oo]Z00_o05gooa00oonBo`3oo`3eo`H0oooonf[o0>Soo`3oCOl0ok7ooo]Zoh;o0002oookJP03o`3o
Folao`3ooo]Z00[ooo]Z00Ko9P3ooh@0oooonf[ohOl0o`000?oJo`02o`0000;ooo]Z0_oo09<00ol0
nOoooo]ZoookJP02ooo:00;o0?lK00?o4P3oo`2>oooonfX01OoonfX01?lm0?oo0?oOogSo0?mho`02
o`3Lo`?o?ol00_oonfX3o`0Zo`?ooo]Z00?o0?lcoomB0?ooDP000_ooDP0JoookJP?o^Ol00ooonfX3
oomB0003o`3o<ooonf[ooo]Z00Co02[o1?oonfX2ocoo00;o0=co0_mho`001?lm0?oooo]ZoookJ_l0
oml9oookJP03o`2>ool0oa_ooo]Z00;o4P3o00?oolX0oookJ_oonfX00ooonfX01Ol0nOooo`2Coook
J_oonf[oo`0C00Kooo]Z00?ohOl0oookJ_oJo`000_oonfX00olV0?oo8?l0oh@0o`0CoookJP04oc7o
0?oonf[ooo]Zo`3oF`?ooo]Z00Oo0?n`oh;o0?oonf[ooo]Zo`0`oooonf[o0?m=00;ooo]Z00Go1P3o
oookJ_oonf[oo`3eoi;o0003oookJP03oa00ool06Ooooo]Z00Cooo]Z00Goo`1AoaD0oooonf[ooo]Z
o`2]o`02oookJP03ool0NOoonf[ooo]Z00Oooo]Z00Oo0?mCoookJ_oonf[ooo]Zo`3o7Ol0o`So0>7o
02Gooo]Z000[oookJP03ool0o?oonf[ooo]Z00Cooo]Z00?o603ooookJ_oo1P000ooonfX00oo[o`3o
oo]Zool0mP04oiCo0007ojP0oooonf[ooo]ZoookJ_nDo`3ooo]Zo`1go`02oiCo0006oom/0?nDo`3o
U?l0oon10?oonf[o>ol00ooonfX00ol0nooooo]ZoookJP03oookJP08ool30?oonf[ooo]Zool0gOmi
0?oooo]Zo`2Soonco`06oookJP04o`3og_oUo`3ooo]Zool0K0Cooo]Z00?oC@3oool^0?l0o``00_oo
nfX01ol0odGooo]ZoookJ_oonf[oiOl0oookJ_l0oi000_oonfX00om4o`3ooo]ZoookJP05oookJP07
ofP0oooonf[ooo]ZoookJ_lH0?oo07CoonKo0002oookJP03oon@0?oonf[ooo]Z00Sooo]Z00Gookh0
oookJ_oonf[oj`3oog00o`06oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01_oo
nfX00oooP@3ooo]ZoookJP06oookJP03o`3Doooonf[o00Co00;ooo]Z00?o0:WooookJ_m4o`001?m4
o`06oookJP03oiCo0?l0hOoo0?lM00;ooo]Z00?o0?mCoookJ_oonfX00ooonfX01?oo07Wo0:goool0
DOlE0?l2oookJP?oU?l000cooo]Zo`H0oooonf[o0?m=o`3o/Ol0<?oooo]Zooo90?oonf[o0?mKoook
J_lao`0:oookJP06ooo90?lV0?oooo]ZoookJ_oQo`3of_l01?oob@02ool0T`?oolT000GoolX0ooo9
0?oob@3ooo]Zoa80o`07oookJP04ocd0ool0omooN?l0ogSo00;o0=co0_loo`02oookJPKoiOl01?oo
DP000onio`3ooo]ZoookJP09oookJP?oolT01_m4o`0;oookJPCo^Ol00ooonfX3oomB0004o`3o<ooo
nf[ooo]ZoookJP?o02[o0ooonfX2ocoo00;o0=co0_mho`000olm0?oooo]ZonGo0009oookJP06o`2>
ool0oa_ooo]Zoa80oooonf[oolX01?oonfX00ol0nOoooo]Zool0T`02oookJP03ool04ooonf[ooo]Z
00?ooo]Z00?ohOl0oookJ_oJo`000ooonfX00olV0?oo8?l0oh@0o`0CoookJP03oc7o0?oonf[o0?mK
00Cooo]Z00KoP_l0oookJ_oonf[o0?nao`3oCOl0j?l2oookJP05o`H0oooonf[ooo]Zool0mOm4o`00
0ooonfX00ol@0?oooo]Zo`0Io`04oookJP04ool0DOoonf[o5@3oo`2]o`;ooo]Z00?oo`1ioookJ_oo
nfX01ooonfX00ol0oe?ooo]ZoookJP02oookJP03o`3o7Ooonf[o0>7o04cooo]Z00?oo`3loookJ_oo
nfX01?oonfX01?lH0?oooo]ZoookJ_oo1P02oookJP05on_o0?oonf[oo`3foookJ_l0Y_l00ooonfX0
1_nX0?oooo]ZoookJ_oo0?Wooo]Zo`1go`;ooo]Z00Oo0?nJoom/0?l0olcooo]Zoon10?oonf[o>ol0
00?ooo]Z00?o0?_ooookJ_oonfX00_oonfX02Ooo0`3ooo]ZoookJ_oo0=goN@3ooookJ_l0Xooo/ol0
oil0o`06oookJP04o`3og_oo08Oooo]Zool0K0?ooo]Z00KoC@3ooookJ_oo;P3oH@3ooookJ_l0odD4
oookJP05on80ool0oi3ooo]ZoookJ_l0oi801ooonfX02?mX0?oooo]ZoookJ_oonf[o603oo`1doooo
nf[oi_l00_oonfX00oooT03ooo]ZoookJP08oookJP04oonn0?oonf[o0?l5on/0o`Kooo]Z00?ooeL0
oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP05oookJP03oon10?oonf[ooo]Z00Oooo]Z00Ko0=Co
o`04oooonf[ooo]Zo`2Yool0R?l2oookJP04o`3o;_oonf[o0?m>o`3o=0Kooo]Z00Go0>7oo`3o7Ooo
nf[ooo]Zo`3oD`05oookJP04ool0NOl0[Oooo`1AoaD0o`;ooo]Z00_o05gooa00oooonf[oT_l0o`H0
oooonf[o0>Soo`3oCOl0<?oooo]Zoh;o0002oookJP03o`3oFolao`3ooo]Z00[ooo]Z00Co9P3ooook
J_oonf[ohOl00_oJo`03o`0000;oo`2C00?o0?WooookJ_oonfX00_oobP02o`3o6`03oa80ool0S_oo
oo]Z00Kooo]Z00?o0?oOogSo0?mho`000_l0g?l2ocoo00;ooo]Z0ol0:_l2oookJP;o0?lc0oooDP00
0onio`3ooo]ZoookJP0NoookJP?o^Ol00ooonfX3oomB0004o`3o<ooonf[ooo]ZoookJP?o02[o0ooo
nfX2ocoo00;o0=co0_mho`000olm0?oooo]Zo`3og`09oookJP06o`2>ool0oa_ooo]ZoookJ_lB0?oo
olX01OoonfX01Ol0nOooo`2CoookJ_oonf[oo`0C00Kooo]Z00?ohOl0oookJ_oJo`000_oonfX00olV
0?oo8?l0oh@0o`0CoookJP04oc7o0?oonf[ooo]Zo`3oF`?ooo]Z00Ko0?n`oh;o0?oonf[o0?nao`0`
ool0odd2oookJP05o`H0oooonf[ooo]Zool0mOnBo`000ooonfX00ol@0?ooo`1Zo`0Io`04oookJP05
ool0DOoonf[o5@3ooookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP07oookJP08o`3oDooonf[ooo]Z
oookJ_l0oago0?l8oookJ_l0hOlToookJP00:ooonfX00ooo0?cooo]ZoookJP03oookJP04oaP0oooo
nf[ooo]Zool600?ooo]Z00?ojol0ool0m_nDo`001?nDo`002OnX0?oooo]ZoookJ_oonf[oU?l0oook
J_l0MoooU?l0oom/0002oiCo0004oookJ_ooP@3ooo]Zoc_o00?ooo]Z00?o0?_ooookJ_oonfX00ooo
nfX02?oo0`3ooo]ZoookJ_oo0=goN@3oo`2Soonco`3oW`3o1_oonfX01?l0omkoiOl0oookJ_oo06`4
oookJP05odd0ool0o`cooo]ZoookJ_l0odD01?oonfX01OoUo`3o0?n@oookJ_oonf[oA?l000Oooo]Z
00?oJ03ooookJ_oonfX00_oonfX01OlH0?oo07CoonKo0?oonf[ooi0000[ooo]Z00Gookh0oookJ_oo
nf[o0?l5on/0o`06oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01ooonfX00ooo
P@3ooo]ZoookJP05oookJP03o`3Doooonf[o00Co00;ooo]Z00?o0:WooookJ_m4o`001Om4o`05oook
JP06oiCo0?l0hOoo0?lMoiCo0?oonf[o0?mC1OoonfX01?oo07Wo0:goool0DOlE0?l2oookJP?oU?l0
00cooo]Zo`H0oooonf[o0?m=o`3Xool0<?oooo]Zooo90?oonf[o0?mKoookJ_lao`0:oookJP07ob3o
0?lV0?oooo]ZoookJ_oQo`3of_l0oookJP02ooo90003ool04ooo09?oolT000;oolT000?oolX0ooo9
0?oob@000_oob@000olB0?oooo]ZoookJP05oookJP?oN?l000Go0=cooookJ_loo`3o?ol0oookJP03
onGo00;ooo]Z1?ooDP000ooUo`3o^Ol0oookJP0=oookJP?oolT00_m4o`0CoookJP?o^Ol00ooonfX3
oomB00Cooo]Z0ol0:_l2oookJP;o?ol00_l0g?l2ogSo0003oookJ_oUo`3ooo]Z00Wooo]Z00Go0?lK
oookJ_lB0?oooo]Zooo:0004oookJP03o`3ioooonf[oo`2C00;ooo]Z00?oo`0CoookJ_oonfX00ooo
nfX00ooQo`3of_l0oookJP03oookJP03obH0oooonf[oQ03o01?ooo]Z00?o<Ol0oookJ_l0oe/00ooo
nfX01on2o`3ooo]ZoookJ_l0ok7o033oo`3oCOl0j?l00_oonfX01?l60?oooo]ZoookJ_m4o`03oook
JP03ool0J_l@0?oo01Wo00Gooo]Z00Coo`1AoaD0oooonf[o0:go0_oonfX00ooo07Wooo]ZoookJP07
oookJP06o`3oDooonf[ooo]ZoookJ_l0oago0?l8COoonfX00ooo0?cooo]ZoookJP04oookJP03oaP0
oooonf[oo`H000?ooo]Z00Gojol0oookJ_oo0?Kooo]Zo`2Vo`02oookJP07ojP0oooonf[ooo]Zoook
J_oo0?Wooo]Zo`1go`02oookJP04oom/0?oonf[o0?o<oon100;ooo]Z00Go>ol0oookJ_oonf[ooo]Z
o`3ko`04oookJP09ool30?oonf[ooo]Zool0gOmi0?oo0:?ook?o0?l05oooW`3o00Kooo]Z00Co0?oN
ool0Qooonf[oo`1/0ooonfX01Om=0?ooobh0of40oooonf[o0?m500Cooo]Z00GohP3oo`3oT?oonf[o
oo]Zo`3oTP07oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603oo`1doooVo`000_oonfX00oooT03o
oo]ZoookJP08oookJP04oonn0?oonf[o0?l5on/0o`Kooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo
02gooo]ZoookJP06oookJP03oon10?oonf[ooo]Z00Kooo]Z00Ko0=CooookJ_l01?oooo]Zo`2Yool0
R?l3oookJP03o`3o;_l0odko0?ld00Kooo]Z00Go0>7oo`3o7Ol0o`Sooo]Zo`3oD`05oookJP04ool0
NOl0[Oooo`1AoaD0o`?ooo]Z00Co403ooookJ_nBo`3o1P3o0_oonfX01?l0odgo033ooookJ_n2o`02
oookJP03o`3oFolao`3ooo]Z00Wooo]Z00Oo8?l0obH0oooonf[ooo]Zon7o0?oJo`3ooo]Z00?o0000
00Coo`2CoookJ_l0nOoooo]Z0_oobP001?oonf[o0?lKoa80oolB0?l7oookJP?oN?l00_l0g?l2ocoo
0004oookJ_l0:_oo02[oo`0Zo`;ooo]Z00?o0?lcoomB0?ooDP000_ooDP000onio`3ooo]ZoookJP0T
oookJPCo^Ol00_oonfX3oomB00Cooo]Z0ol0:_l2oookJP;o?ol00_l0g?l2ogSo0003oookJ_l0omoo
oo]Z00Wooo]Z00Go0?lKoookJ_oonf[o4P3oooo:0005oookJP05o`3ioooo09?ooo]ZoookJ_oo01<0
1_oonfX00ooQo`3of_l0oookJP02oookJP03obH0oolPo`3oQ03o01?ooo]Z00?o<Ol0oookJ_l0oe/0
0ooonfX01ol0ok3oP_l0oookJ_oonf[o033ooookJ_l0odd00_oonfX01?l60?oooo]ZoookJ_nBo`04
oookJP03oa00ool06Ooooo]Z00Cooo]Z00Coo`1AoaD0oooonf[o0:go0ooonfX00ooo07Wooo]Zoook
JP07oookJP05o`3oDooonf[ooo]ZoookJ_l0oad09_oonfX002[ooo]Z00?oo`3loookJ_oonfX01?oo
nfX00olH0?oooo]Zool60003oookJP03on_o0?oonf[oo`3f00GoU?l000CoZ03ooookJ_oonf[oU?l0
0_oonfX00ol0MoooU?l0oom/0002oiCo0004oon10?oonf[ooo]Zoc_o00;ooo]Z00?o0?_ooookJ_oo
nfX00ooonfX02Ooo0`3ooo]ZoookJ_oo0=gooo]ZogT0ool0Xooo/ol0oil0o`06oookJP04onGo0?oo
nf[ooo]Zool0K0?ooo]Z00?oC@3oool^0?l0o``00_oonfX00ol0odGooo]ZoookJP02oookJP05onGo
0?l0oi3ooo]ZoookJ_m4o`001_oonfX00omX0?oooo]ZoookJP02oookJP03oaP0ool0M?ooi_l000;o
oo]Z00?ooi00oookJ_oonfX02?oonfX01Ooo_P3ooo]ZoookJ_o[0?ooL03o00Kooo]Z00?ooeL0oook
J_oonfX00_oonfX00ooo02gooo]ZoookJP06oookJP03oon10?oonf[ooo]Z00Kooo]Z00Ko0=Coo`04
oooonf[ooo]ZoiCo0?l0ZOl6odCo00Gooo]Z00KoU?l0o`3Qool0oagoU?l0oookJ_l0oe<5oookJP04
ool0NOl0[Oooo`1AoaD0o`;ooo]Z1?nDo`002ol60?oooo]Zo`3oCOl0j?oo033ooookJ_oob@3ooo]Z
o`3oFooonf[o<Ol000[ooo]Z00Co8?l0obH0oooonf[ooo]Z0_oJo`02oookJP03o`000?oo09?oo`2C
00SoolT01ooonfX2ogSo00;o0=co00Cooo]Zocoo0?loo`3o02[o0_oUo`02oookJP?ooe8000Co^Ol0
onGo0?oUo`3oiOl04?oonfX2ooo901Wooo]Z1?nio`02oookJP?ooe801?oonfX00ol0:_oooo]Zoook
JP02oookJP;o?ol000Co0=coogSo0?mho`3oiOl00ooonfX00ooUo`3ooo]ZoookJP04oookJP;o0?lK
0_oonfX2ooo:00?ooo]Z00?o0?WooookJ_oo09<00_oonfX00ooo01?ooo]ZoookJP03oookJP03on7o
0?oJo`3ooo]Z00?ooo]Z00?o9P3ooookJ_n40?l04_oonfX01?lao`3ooo]ZoookJ_l0oe/3oookJP09
oh;o0?oonf[o0?naoookJ_l0odgooo]Zo`3Xoooonf[o1P3o00;ooo]Z00?oo`3eodCo0?oonfX00_oo
nfX00ol@0?oooo]Zo`0Io`04oookJP04ool0DOlE0?oooo]Zo`2]o`;ooo]Z00?oo`1ioookJ_oonfX0
1ooonfX01_l0oe?ooo]ZoookJ_oonf[o0?lMo`3o24cooo]Z00?oo`3loookJ_oonfX01OoonfX00olH
0?oooo]Zool60002oookJP03on_o0?oonf[oo`3f00;ooo]Z00Co0:KooookJ_oonf[oZ03o0ooonfX0
2ooo0?Wooo]Zo`1goooonf[o0?nJoom/0?l0olcooo]Zoon10?oonf[o>ol000?ooo]Z00?o0?_ooook
J_oonfX00_oonfX02_oo0`3ooo]ZoookJ_oo0=gooo]ZogT0ool0Xooo/ol0oookJ_nO0?l5oookJP05
omgo0?oo08Oooo]ZoookJ_oo06`00_oonfX01_m=0?oooo]Zool^0?mQ0?oooo]Zo`3oA@Cooo]Z00Go
hP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Co603oo`1doooonf[o
i_l00_oonfX00oooT03ooo]ZoookJP08oookJP04oonn0?oonf[o0?l5on/0o`Kooo]Z00?ooeL0oook
J_oonfX00ooonfX00ooo02gooo]ZoookJP05oookJP03oon10?oonf[ooo]Z00Oooo]Z00Go0=Coo`04
oooonf[ooo]Zo`2Yo`03oookJP03o`3o;_l0odko0?ld00Kooo]Z00?o0>7ooookJ_l0oad00_oonfX0
0ol0oe?ooo]ZoookJP02oookJP04ool0NOl0[Oooo`1AoaD0o`?ooo]Z00Co01Wooa00oonBo`3o1P3o
0_oonfX01?l0odgo033ooookJ_n2o`02oookJP03o`3oFolao`3ooo]Z00Wooo]Z00Ko8?l0obH0oooo
nf[ooo]Zon7o0?oJo`02oookJP03o`000?oo09?oo`2C00;o0?Wo00Kooo]Zooo:0?oonf[ooo]Zo`3o
6olB0?l7oookJP;oN?l00ol0g?l2ocoo00?o02[o0_oonfX01?l0oc?ooe80oomB0?ooDP02okWo02go
oo]Z0onio`02oookJP?ooe801?oonfX00ol0:_oooo]ZoookJP02oookJP;o?ol000Co0=coogSo0?mh
o`3o0?oO2_oonfX2o`3o6`04oa80oooonf[oolX0ooo:00Cooo]Z00Go0?Woool0Tooonf[ooo]Zool0
4`05oookJP03on7o0?oonf[of_l000?ooo]Z00?o9P3oob3o0?n40?l04_oonfX01?lao`3ooo]Zoook
J_l0oe/3oookJP09o`3o/?n2o`3ooo]Zo`3o/Ol0<?oo0?m=o`3Xoooonf[o1P3o00;ooo]Z00?oo`3e
oi;o0?oonfX00_oonfX00ol@0?ooo`1Zo`0Io`04oookJP05ool0DOlE0?oooo]ZoookJ_l0[Ol00_oo
nfX00ooo07Wooo]ZoookJP07oookJP05o`3oDooonf[ooo]ZoookJ_l0oad09_oonfX0037ooo]Z00?o
603ooookJ_oo1P000ooonfX00oo[o`3oo`3foiCo0004oiCo0009ojP0oooonf[ooo]ZoookJ_nDo`3o
oo]Zo`1goonDo`3oof`000?oU?l000?ooh40oookJ_lko`000ooonfX00ol0nooooo]ZoookJP03oook
JP08ool30?oonf[ooo]Zool0gOmi0?oo0:?ook?o0?nO0?l6oookJP04o`3og_oUo`3ooo]Zool0K0Co
oo]Z00GoC@3oo`3o3?oonf[ooo]Zo`3oA@04oookJP05onGo0?l0oi3ooo]ZoookJ_m4o`001ooonfX0
2_mX0?oooo]ZoookJ_oonf[o603ooookJ_l0M?ooi_l0oookJ_ooT00;oookJP04oonn0?oonf[o0?l5
on/0o`Kooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP07oookJP03oon10?oonf[o
oo]Z00Gooo]Z00?o0=Coo`04oooonfX00_oonfX00ol0ZOooA?l0odCo0005odCo00Cooo]Z00KoU?l0
o`3QoonDo`3o0?lMoiCo0?l0oe<5oookJP04ool0NOl0[Ooooo]Zool0D@;ooo]Z1OnDo`002_oonf[o
0?m=o`3Xool0<?oooo]Zooo90?oonf[o0?mKoookJ_lao`0:oookJP05ob3o0?lV0?oooo]ZoookJ_oJ
o`001?oonfX00ooo09?o0000ooo90007ooo900Kooo]Z0_mho`02o`3Lo`03oookJ_loo`3o?ol000;o
02[o0_oonfX3oomB00?o^Ol000?ooo]ZonGo0?oonfX0<?oonfX3okWo00;ooo]Z0oooDP02oookJP03
o`0Zoooonf[ooo]Z00?ooo]Z00Ko?ol0oookJ_l0g?ooN?l0onGo0?oonfX2onGo00Oooo]Z00?o08ko
o`3o6ooonfX00_oonfX01_oobP3ooo]ZoookJ_oonf[o0?Woool0T`;ooo]Z00?oo`0CoookJ_oonfX0
1?oonfX00ooJo`3ooo]ZoookJP02oookJP04obH0oolPo`3ooo]Zoh@0oa;ooo]Z00Co<Ol0oookJ_oo
nf[o0?mK0_oonfX01on2o`3o0?n`oookJ_l0ok7o033oo`3oCOl0j?l00_oonfX01?l60?oooo]Zoook
J_m4o`03oookJP04oa00oooonf[ooo]Zo`0Io`Cooo]Z00?oo`1AoaD0ool0[Ol00_oonfX00ooo07Wo
oo]ZoookJP08oookJP05o`3oDooonf[ooo]ZoookJ_l0oad0DooonfX00olH0?oooo]Zool60003oook
JP05on_o0?oonf[oo`3foookJ_l0Y_l00_oonfX01onX0?oooo]ZoookJ_oonf[oo`3ioookJ_l0Mol0
0_oonfX01oooK03ooo]Zo`3oc?oonf[ooh40oookJ_lko`000ooonfX00ol0nooooo]ZoookJP02oook
JP09ool30?oonf[ooo]Zool0gOmi0?oo0:?ooookJ_nco`3oW`3o00Kooo]Z00Co0?oNool0Qooonf[o
o`1/0ooonfX01Om=0?oooo]Zof40oooonf[o0?m500Gooo]Z00CohP3ooookJ_oonf[o0?nB1ooonfX0
2?mX0?oooo]ZoookJ_oonf[o603ooookJ_l0M?ooi_l00_oonfX00oooT03ooo]ZoookJP09oookJP03
oonn0?l0o`Goj`3o00Kooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP06oookJP03
oon10?oonf[ooo]Z00Kooo]Z00Ko0=Coo`04oooonf[ooo]Zo`2Yool0R?l3oookJP03o`3o;_l0odko
0?ld00Gooo]Z00?o0>7ooookJ_l0oad00_oonfX00ol0oe?ooo]ZoookJP02oookJP04ool0NOl0[Ooo
oo]Zool0D@?ooo]Z00Co01Wooa00oonBo`3o1P3o0_oonfX01?l0odgo033oo`3o/On2o`02oookJP03
o`3oFolao`3ooo]Z00Wooo]Z00Ko8?l0obH0oooonf[ooo]Zon7o0?oJo`03oookJP07ool0Tooo01?o
0?Woo`000?oonf[oolX0oookJP02o`3o6`03oa80oooonf[ooo]Z00Cooo]Z0_mho`02o`3Lo`03oook
J_loo`3o?ol000;o02[o0ooonfX3oomB00;o^Ol0<ooonfX3okWo00;ooo]Z0oooDP02oookJP03o`0Z
oooonf[ooo]Z00?ooo]Z0_loo`001?l0g?ooN?l0ogSo0?l0oml9oookJP03o`2>ool0oa_o4P3o00;o
oo]Z00?oolX0oookJ_oonfX00_oonfX01?oo09?ooo]ZoookJ_oo01<6oookJP03on7o0?oJo`3ooo]Z
00;ooo]Z00Co9P3oob3o0?oonf[oQ03o4_oonfX01?lao`3ooo]ZoookJ_l0oe/3oookJP06oh;o0?oo
nf[ooo]Zo`0`oooonf[o0?m=0_oonfX01?l60?oooo]ZoookJ_nBo`03oookJP04oa00oooo06[ooo]Z
o`0Io`Cooo]Z00Coo`1AoaD0oooonf[o0:go0_oonfX00ooo07Wooo]ZoookJP08oookJP05o`3oDooo
nf[ooo]ZoookJ_l0oad09OoonfX0037ooo]Z00?o603ooookJ_oo1P000ooonfX00oo[o`3oo`3foiCo
0004oiCo0004ojP0oooonf[ooo]ZoiCo00;ooo]Z00?o07OooiCo0?ooK0000onDo`000oooP@3ooo]Z
oc_o0003oookJP03o`3koooonf[ooo]Z00?ooo]Z00Soo`<0oookJ_oonf[oo`3MogT0ool0Xooo/ol0
oil0o`Kooo]Z00CoiOl0oookJ_oonf[oo`1/0ooonfX00om=0?ooobh0of40o`02oookJP03o`3oAOoo
nf[ooo]Z00;ooo]Z00GoiOl0o`3oT?oonf[ooo]ZodCo0006oookJP03ofP0oooonf[ooo]Z00;ooo]Z
00?o603oo`1doooVo`000_oonfX00oooT03ooo]ZoookJP08oookJP05oonn0?oonf[ooo]Zon/0oom`
0?l01_oonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00Wooo]Z00?ooh40oookJ_oonfX01OoonfX00ol0
e?oooo]Zo`04o`02oookJP03o`2Yoom4o`3oA?l000KoA?l00ooonfX01?nDo`3o0>7ooiCo0?l0oad2
oiCo0003o`3oDooonf[ooo]Z00;ooo]Z00Goo`1io`2]oooonf[oo`1AoookJP06oiCo000:oookJ_l0
odgo0>Soo`0`oooonf[oolT0oookJ_l0oe_ooo]Zoc7o00[ooo]Z0_lV0?l00ooonf[ohOl0om[o0004
oookJP03ool0Tol0003oolT000SoolT01?oonfX2ogSo00;o0=co0oloo`02o`0Zo`;ooo]Z0_ooDP00
0ol0oc?o^Ol0okWo000ioookJP?o^Ol000Gooo]Zo`3o<oooDP3ooe80oookJP02o`0Zo`Cooo]Z00Co
?ol0o`3Loooonf[oN?l01?oUo`07oookJP03o`2>ool0oa_ooo]Z00;ooo]Z00KoolX0oookJ_oonf[o
oo]Zo`3ioooo09<2oookJP03ool04ooonf[ooo]Z00?ooo]Z00?ohOl0om[o0?oonfX00ooonfX00olV
0?oo8?l0oh@0o`0BoookJP04oc7o0?oonf[ooo]Zo`3oF`?ooo]Z00WoP_l0oookJ_l0ok7o033oo`3o
COoonf[o0>SooookJ_l60?l00_oonfX00om4o`3ooo]ZoookJP02oookJP03oa00oooonf[o01Wo00Co
oo]Z00Coo`1AoaD0oooonf[o0:go0_oonfX00ooo07Wooo]ZoookJP07oookJP05o`3oDooonf[ooo]Z
oookJ_l0oad0DooonfX00olH0?oooo]Zool60003oookJP05on_o0?oonf[oo`3foookJ_l0Y_l00_oo
nfX01onX0?oooo]ZoookJ_oonf[oo`3ioookJ_l0Mol00_oonfX01_ooK03o0?o<oookJ_ooP@3ooo]Z
oc_o00Cooo]Z00?o0?_ooookJ_oonfX00_oonfX02Ooo0`3ooo]ZoookJ_oo0=goN@3oo`2Soonco`3o
01Oooil0o`05oookJP05omgo0?oo08Oooo]ZoookJ_oo06`00ooonfX01Om=0?ooobh0of40oooonf[o
0?m500Cooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Co
603oo`1doooonf[oi_l00_oonfX00oooT03ooo]ZoookJP08oookJP04oonn0?oonf[o0?l5on/0o`Ko
oo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP06oookJP03oon10?oonf[ooo]Z00Ko
oo]Z00Ko0=CooookJ_l01?oooo]Zo`2Yool0R?l3oookJP03o`3o;_l0odko0?ld00Gooo]Z00Ko0>7o
oookJ_l0oago0?l8oookJ_l0oe<4oookJP04ool0NOl0[Ooooo]Zool0D@?ooo]Z00Co01Wooa00oooo
nf[oT_l00_oonfX01?l0odgooo]Zo`0`oon2o`02oookJP03o`3oFolao`3ooo]Z00Wooo]Z0_lV0?l2
oookJP;of_l00ooonfX00ooo09?oo`0Co`3io`02o`000004ooo:0?oonf[o0?lKoa80o`Kooo]Z0_mh
o`000olm0?oo0=coocoo0002ocoo00;o02[o0ooonfX2oomB00;o^Ol0>OoonfX3okWo0005oookJ_l0
oc?ooe80oomB0?oonfX00_l0:_l5oookJP05ocoo0?l0g?oo?@3oogSo0?l0oml02OoonfX00ol0S_oo
0?lKoa80o`02oookJP03ooo:0?oonf[ooo]Z00;ooo]Z00Coo`2CoookJ_oonf[oo`0C1_oonfX00ooQ
o`3of_l0oookJP02oookJP03obH0oolPo`3oQ03o01;ooo]Z00Co<Ol0oookJ_oonf[o0?mK0ooonfX0
2Ol0ok3oP_l0oookJ_l0<?oooo]Zo`3oCOl0j?oooo]Zo`H0o`02oookJP03ool0mOnBo`3ooo]Z00;o
oo]Z00?o403oool0J_l06Ol01?oonfX01?oo057o5@3ooookJ_l0[Ol3oookJP03ool0NOoonf[ooo]Z
00Oooo]Z00Go0?mCoookJ_oonf[ooo]Zo`3o7@0UoookJP00<?oonfX00olH0?oooo]Zool60003oook
JP03on_o0?oonf[oU?l000CoU?l000WoZ03ooookJ_oonf[ooo]ZoiCo0?oonf[oU?l0o`1gooooK000
0onDo`001?ooP@3ooo]ZoookJ_lko`02oookJP03o`3koooonf[ooo]Z00?ooo]Z00Soo`<0oookJ_oo
nf[oo`3MogT0oooonf[o/ol0oil0o`Kooo]Z00Go0?oNonGo0?oonf[ooo]Zool0K003oookJP05odd0
oooo;P3oH@3ooookJ_l0odD01?oonfX01OoUo`3o0?n@oookJ_oonf[oA?l000Oooo]Z00[oJ03ooook
J_oonf[ooo]ZoaP0ool0M?oooo]ZonKo0?oonf[ooi002ooonfX01?oo_P3ooo]Zo`3o1Oo[0?l6oook
JP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01ooonfX00oooP@3ooo]ZoookJP05oook
JP05o`3Dool01?oooo]ZoookJ_nDo`002?m4o`03oookJP;oU?l000Go0>7oo`3o7OnDo`3oU?l0o`3o
D`04oookJP05ool0NOoonf[o0:goool0DOoonfX01onDo`002Ol0odgo0>Soo`3o/Ol0<?ooolT0oook
J_l0oe_ooo]Zoc7o000:oookJP03obH0oon40?oooo]Z00;of_l00ooonfX00ooo01?oo`2Cooo90009
ooo900?ooo]Z00Co0?oOogSo0?lm0?oo0?l<0_loo`000ooonf[o02[oo`0Zo`02oookJP;ooe8000?o
0?lcokWo0?oonfX0?_oonfX02?nio`3ooo]ZoookJ_oonf[ooe80o`3o<ooonf[o02[o1?oonfX01?lo
o`3o0=coonGo0?mho`04onGo00Sooo]Z00Go0?lKoookJ_oonf[ooo]Zooo:0003oookJP05o`3ioooo
09?ooo]ZoookJ_oo01<01OoonfX00ooQo`3of_l0oookJP03oookJP03obH0oolPo`3oQ03o01;ooo]Z
00Co<Ol0oookJ_oonf[o0?mK0_oonfX02_n2o`3o0?n`oookJ_l0ok7o033oo`3oCOoonf[o0>Sooook
J_l60?l2oookJP08odCo0?oonf[ooo]ZoookJ_l@0?ooo`1ZoookJ_l06Ol4oookJP03ool0DOoonf[o
0:go00;ooo]Z00?oo`1ioookJ_oonfX02?oonfX01?l0oe?ooo]ZoookJ_l0oaeCoookJP03oaP0oooo
nf[oo`H000;ooo]Z00?ojol0oookJ_oo0?H00_oonfX01?l0Y_oooo]ZoookJ_nX0?l3oookJP0;ool0
nOoonf[o07OooookJ_ooK03ooo]Zo`3oc?oonf[ooh40oookJ_lko`000ooonfX00ol0nooooo]Zoook
JP02oookJP09ool30?oonf[ooo]Zool0gOmi0?oooo]Zo`2Soonco`3oW`3o00Kooo]Z00Go0?oNool0
Qooonf[ooo]Zool0K002oookJP05odd0oooonf[oH@3ooookJ_l0odD01OoonfX01?oR0?oooo]Zoook
J_l0oi87oookJP08ofP0oooonf[ooo]ZoookJ_lH0?oo07CooookJ_oVo`02oookJP03oon@0?oonf[o
oo]Z00Wooo]Z00Cookh0o`3o1Oo[0?ooL03o1OoonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooo
nf[ooo]Z00Kooo]Z00?ooh40oookJ_oonfX01_oonfX01Ol0e?oo00CooookJ_oonf[o0:Wo00?ooo]Z
00?o0?l^o`3oC_l0oc@01_oonfX01Ol0hOoo0?lMo`3o2?oonf[o0?mC00Cooo]Z00Coo`1ioookJ_l0
[Oooo`1A0ooonfX01?l06Ooo403ooookJ_nBo`02oookJP04o`3oCOoonf[o033ooh;o00;ooo]Z00?o
0?mKoc7o0?oonfX02OoonfX01OlV0?ooQ03ooookJ_oonf[of_l000Cooo]Z00?oo`2Co`3iool0nOl0
0_l000000ooobP3ooo]Zo`3o6`06oookJP04o`3ogomho`3o?@3oo`3Lo`;o?ol00_oonfX01?l0:_oo
oo]ZoookJ_oonfX2oomB0003okWo0?oonf[ooo]Z03gooo]Z00So^Ol0oookJ_oonf[ooo]ZoomB0?l0
oc?ooo]Zo`0Zo`Gooo]Z00Go?ol0o`3Loooonf[oN?l0o`3og`0:oookJP05o`3o6olB0?oooo]Zoook
J_oobP001?oonfX01?oo09?ooo]ZoookJ_oo01<6oookJP03on7o0?oJo`3ooo]Z00;ooo]Z00?o9P3o
ob3o0?n40?l04_oonfX01?lao`3ooo]ZoookJ_l0oe/3oookJP09oh;o0?oonf[o0?nao`0`oooonf[o
0?m=o`3Xoooonf[o1P3o00;ooo]Z00SoT_l0oookJ_oonf[ooo]Zoa00ool0GOooo`1Zo`0Io`Cooo]Z
00Coo`1AoookJ_oonf[o0:go0_oonfX00ooo07Wooo]ZoookJP08oookJP04o`3oDooonf[ooo]Zo`3o
7BGooo]Z000`oookJP03oaP0oooonf[oo`H000?ooo]Z00?ojol0oiCo0?nDo`001?nDo`001?nX0?oo
oo]ZoookJ_oonfX2oiCo0003o`1goonDo`3oof`000?oU?l000?ooh40oookJ_lko`000ooonfX00ol0
nooooo]ZoookJP03oookJP08ool30?oonf[ooo]Zool0gOmi0?oo0:?ook?o0?nO0?l6oookJP04onGo
0?nDo`3ooo]Zool0K0Cooo]Z00GoC@3oof40oooonf[ooo]Zo`3oA@04oookJP05onGo0?l0oi3ooo]Z
oookJ_m4o`001_oonfX00omX0?oooo]ZoookJP02oookJP03oaP0ool0M?ooi_l000;ooo]Z00?ooi00
oookJ_oonfX02?oonfX01Ooo_P3ooo]Zo`3o1Oo[0?ooL03o00Kooo]Z00GooeL0oookJ_oonf[ooo]Z
ool0;@09oookJP03oon10?oonf[ooo]Z00Gooo]Z00Ko0=Coo`04oooonf[ooo]ZoiCo0?l0ZOl2oook
JPKoA?l00_oonfX2oiCo0005o`3Qool0oagoU?l0oiCo0?l0oe<01OoonfX01?oo07Wo0:gooaD0oooo
0547oiCo0009o`3oCOl0j?oo0?nao`0`oooob@3ooo]Zo`3oFooonf[o<Ol000[ooo]Z00Co9P3ooh@0
oooonf[of_l01?oonfX00ooo01?oo`2Cooo90009ooo900;ooo]Z00?o0?oOogSo0?mho`000ol0o``0
0ooonf[o02[oo`0Zo`03oookJP03oomB0?l0oc?ooo]Z01Cooo]Z3Ol0LolQoookJP08okWo0?oonf[o
oo]ZoookJ_ooDP3o0?lcoookJ_l0:_l4oookJP?oiOl000?oN?l0onGo0?oUo`000_oUo`07oookJP03
oa80ool0oa_ooo]Z00;ooo]Z00SoiOl0oookJ_oonf[ooo]Zo`3ioooo09?ooo]Zool04`Kooo]Z00?o
f_l0oookJ_oonfX00ooonfX00olV0?oo8?l0oookJP0AoookJP05oc7o0?oonf[ooo]ZoookJ_l0oe/0
0_oonfX02On2o`3ooo]Zo`3o/Ol0<?oo0?m=oookJ_l0j?oooo]Zo`H0o`02oookJP03odCo0?oonf[o
oo]Z00;ooo]Z00?o403ooookJ_l06Ol01?oonfX01_oo057o5@3ooookJ_l0[Ooooo]Zool0N@[ooo]Z
00Go0?mCoookJ_oonf[ooo]Zo`3o7@1AoookJP03oaP0oooonf[oo`H000?ooo]Z00?ojol0oookJ_oo
0?H00_oonfX00ol0Y_oooo]ZojP0o`03oookJP03ool0nOoonf[o07Oo00;ooo]Z00Ooof`0oookJ_l0
olcooo]Zoon10?oonf[o>ol000?ooo]Z00?o0?_ooookJ_oonfX00_oonfX02Ooo0`3ooo]ZoookJ_oo
0=goN@3oo`2Soonco`3o01Oooil0o`06oookJP04ool0Qooonf[ooo]Zool0K0?ooo]Z00GoC@3ooook
J_mQ0?oooo]Zo`3oA@04oookJP05on80ool0oi3ooo]ZoookJ_l0oi801_oonfX00omX0?oooo]Zoook
JP02oookJP04oaP0ool0M?oooo]ZonKo00;ooo]Z00?ooi00oookJ_oonfX02?oonfX01?oo_P3o0?l5
oookJ_o[0?l6oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01_oonfX00oooP@3o
oo]ZoookJP06oookJP05o`3Dool01?oooo]ZoookJ_l0ZOl01?oonfX00ol0obko0?m>oookJP05oook
JP06o`3Qool0oagooo]Zo`3o2?oonf[o0?mC1?oonfX01?oo07Wo0:gooaD0oooo0542oookJP04o`0I
ool@0?oooo]Zoi;o00;ooo]Z00Co0?m=oookJ_l0<?ooP_l00_oonfX00ol0oe_o<Ol0oookJP09oook
JP05obH0oon40?oooo]ZoookJ_oJo`001?oonfX00ooo09?o0?WooookJP02o`000003ooo:0?l0oa_o
0?lK00Gooo]Z00Co0?oOogSo0?mho`3o0=co0_loo`02oookJP;o02[o0_oonfX2oomB01Kooo]Z3Ol0
LolPoookJP08okWo0?oonf[ooo]ZoookJ_ooDP3o0?lcoookJ_l0:_l5oookJP05ocoo0?l0g?oooo]Z
ogSo0?l0oml02_oonfX01Ol0oa_ooo]ZoookJ_oonf[oolX000Cooo]Z00?oo`2CoookJ_oo01<01_oo
nfX00ooQo`3of_l0oookJP03oookJP03obH0oolPo`3ooo]Z017ooo]Z00Go<Ol0oookJ_oonf[ooo]Z
o`3oF`02oookJP09o`3o/?n2o`3ooo]Zo`0`oooonf[o0?m=o`3Xoooonf[o1P3o00;ooo]Z00?oo`3e
oi;o0?oonfX00_oonfX00ol@0?ooo`1Zo`0Io`04oookJP04ool0DOlE0?oooo]Zo`2]o`;ooo]Z00?o
o`1ioookJ_oonfX02?oonfX01Ol0oe?ooo]ZoookJ_oonf[o0?lM02Cooo]Z000`oookJP03oaP0oooo
nf[oo`H000?ooo]Z00?ojol0oiCo0?nDo`001?nDo`001?nX0?oooo]ZoookJ_nDo`02oookJP03o`1g
oooonf[oof`000?oU?l000?ooh40oookJ_lko`000ooonfX00ol0nooooo]ZoookJP02oookJP09ool3
0?oonf[ooo]ZoookJ_oo0=goN@3oo`2Soonco`3oW`3o00Gooo]Z00Go0?oNonGo0?oonf[ooo]Zool0
K003oookJP03odd0oooo;P3oH@3o00;ooo]Z00Ko0?m5oookJ_oonf[ooo]ZonGo0?l0oi02oookJP03
odCo0?oonf[ooo]Z00Gooo]Z00[oJ03ooookJ_oonf[ooo]ZoaP0ool0M?oooo]ZonKo0?oonf[ooi00
2ooonfX01?oo_P3ooo]Zo`3o1Oo[0?l6oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oo
nfX01_oonfX00oooP@3ooo]ZoookJP06oookJP05o`3Doooonf[ooo]ZoookJ_l0ZOl01?oonfX5odCo
0005oookJ_nDo`3oU?l0o`3Qool0oad00_nDo`000ol0oe?oU?l0oookJP03oookJP04ool0NOl0[Ooo
5@3oool0D@SoU?l000Co0?m=o`3Xool0<?ooolT00_oonfX00ol0oe_ooo]Zoc7o0009oookJP04obH0
oon40?oooo]Zom[o00Cooo]Z00?oo`0Cool0Tooob@002Ooob@001?oonf[o0?oOo`3ogomho`04o`3o
30;o02[o0_oonfX00ol0oc?ooe80oomB000CoookJPCo07?o3OoonfX;o`1coaOooo]Z0_nio`02oook
JP04oomB0?l0oc?ooo]Zo`0Zo`;ooo]Z1OoUo`001?mho`3oiOl0onGo0?oUo`08oookJP05oa80ool0
oa_ooo]ZoookJ_oUo`001?oonfX01?oo09?ooo]ZoookJ_oo01<6oookJP03om[o0?oonf[ooo]Z00;o
oo]Z00?o9P3oob3o0?n40?l04_oonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP07oh;o0?l0ok3ooo]Z
o`0`oooonf[o0?m=o`3Xo`02oookJP04o`H0oooonf[oo`3eodCo00?ooo]Z00?o403oool0J_l06Ol0
1OoonfX00ooo057ooo]Zo`2]o`02oookJP03ool0NOoonf[ooo]Z00Sooo]Z00Co0?mCoookJ_oonf[o
0?l8DOoonfX00olH0?oooo]Zool60003oookJP05on_o0?oonf[oo`3foookJ_l0Y_l00_oonfX01onX
0?oooo]ZoookJ_oonf[oo`3ioookJ_l0Mol00_oonfX01_ooK03o0?o<oookJ_ooP@3ooo]Zoc_o00Co
oo]Z00Go0?_ooookJ_oonf[ooo]Zool30003oookJP06ool0gOmi0?oo0:?ook?o0?oonf[oW`3o1Ooo
nfX01Ol0omkoo`27oookJ_oonf[oo`1/00?ooo]Z00GoC@3oool^0?mQ0?oooo]Zo`3oA@04oookJP04
on80oooonf[ooo]Zo`3oTPOooo]Z00SoJ03ooookJ_oonf[ooo]ZoaP0ool0M?oooo]ZonKo00;ooo]Z
00?ooi00oookJ_oonfX02OoonfX01?oo_P3o0?l5oookJ_o[0?l5oookJP03oomG0?oonf[ooo]Z00?o
oo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP07oookJP05o`3Doooonf[ooo]Zo`2Y
ool0R?l00ooonfX00ol0obko0?m>o`3o=005oookJP06o`3Qoooonf[o0?lMo`3o2?oonf[o0?mC1?oo
nfX01?oo07Wo0:gooaD0oooo0542oookJP05o`0Ioooo06[o403ooi;o0?l60?l00_oonfX00ol0odgo
033ooh;o0002oookJP03o`3oFooonf[o<Ol000Wooo]Z00Go9P3ooh@0oooonf[ohOl0om[o0003oook
JP03ool04ooo09?o0?Wo00;ooo]Z0_oobP000ol0oa_o08kooookJP03oookJP;o0?oO00CoN?l0ocd0
ool0g?oo?ol00_oonfX2o`0Zo`04oookJ_l0oc?ooe80oomB01Cooo]Z1?l0Lol=oookJP[o07?o5ooo
nfX2okWo00;ooo]Z00?ooe80o`3o<ooonfX00_l0:_l4oookJP05ocoo0?l0g?oooo]ZogSo0?l0oml0
2_oonfX01?l0oa_ooo]ZoookJ_oobP04oookJP04ool0Tol0nOoooo]Zool04`Kooo]Z00?ohOl0om[o
0?oonfX00_oonfX00olV0?oooo]Zob3o000BoookJP04oc7o0?oonf[ooo]Zo`3oF`?ooo]Z00KoP_l0
oookJ_l0ok7o033ooookJ_l0odd2oookJP04o`H0oooonf[oo`3eoi;o00?ooo]Z00?o403ooookJ_l0
6Ol01OoonfX01?oo057ooo]ZoookJ_l0[Ol2oookJP03ool0NOoonf[ooo]Z00Sooo]Z00Co0?mCoook
J_oonf[o0?l89?oonfX002oooo]Z00?o603ooookJ_oo1P000ooonfX00oo[o`3oU?l0oiCo0004oiCo
0005ojP0oonDo`3ooo]ZoookJ_nDo`000_oonfX02?l0Moooof`0oiCo0?l0olcooo]Zoon10?nDo`3o
>ol00ooonfX00ol0nooooo]ZoookJP03oookJP08ool30?oonf[ooo]Zool0gOmi0?oooo]Zok?o0?nO
0?l6oookJP05onGo0?nDo`3ooo]ZoookJ_oo06`00ooonfX01Om=0?ooobh0of40oooonf[o0?m500Co
oo]Z00GoiOl0o`3oT?oonf[ooo]ZodCo0006oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603oo`1d
oooVo`3ooo]Zoon@000;oookJP05oonn0?oonf[o0?l5on/0oom`0?l01OoonfX00oooE`3ooo]Zoook
JP02oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooh40oookJ_oonfX01OoonfX01_l0e?oo00Cooook
J_oonf[o08Soo`2Yo`Cooo]Z00GoA?l0oookJ_m4o`3oA?l0oookJP03oiCo0005o`3Qool0oagoU?l0
oiCo0?l0oe<01?oonfX01?oo07Wo0:gooaD0oooo0548oiCo0004o`3oCOl0j?oo033oooo900;ooo]Z
00?o0?mKoookJ_lao`002?oonfX01OlPo`3o9P3ooh@0oooonf[of_l000Cooo]Z00?oo`0Cool0Tooo
nfX02_oob@000ol0omoo?@3oogSo0004o`3o3004o`0Zoooonf[ooo]Zo`3o<`;ooe804OoonfX4o`1c
oacooo]Z0ol0LolFoookJP06okWo0?oonf[ooo]ZoomB0?l0oc?ooo]Z0_l0:_l2oookJPCoiOl000Co
N?l0onGo0?oUo`3oiOl02?oonfX01OlB0?oo0?lKoookJ_oonf[oiOl000Cooo]Z00?oo`2CoookJ_oo
01<01_oonfX00ooJo`3ooo]ZoookJP03oookJP03obH0oolPo`3ooo]Z01;ooo]Z00Co<Ol0oookJ_oo
nf[o0?mK0_oonfX02On2o`3ooo]Zo`3o/Ol0<?oo0?m=oookJ_l0j?oooo]Zo`H0o`02oookJP08odCo
0?oonf[ooo]ZoookJ_l@0?ooo`1ZoookJ_l06Ol4oookJP06ool0DOoonf[ooo]Zo`2]oooonf[oo`1i
2_oonfX00ol0oe?ooo]ZoookJP1BoookJP03oaP0oooo1P3ooo]Z00;ooo]Z00?ojol0oookJ_oo0?H0
0_oonfX00ol0Y_oooo]ZojP0o`04oookJP0;ool0nOoonf[o07OooookJ_ooK03ooo]Zo`3oc?oonf[o
oh40oookJ_lko`000ooonfX00ol0nooooo]ZoookJP02oookJP09ool30?oonf[ooo]Zool0gOmi0?oo
oo]Zok?o0?l05oooW`3o00Kooo]Z00Goo`27oookJ_oonf[ooo]Zool0K002oookJP05odd0oooonf[o
H@3ooookJ_l0odD01?oonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Kooo]Z00?oJ03ooookJ_oonfX0
0_oonfX01_lH0?oo07CooookJ_oVo`3ooo]Zoon@00_ooo]Z00Cookh0o`3o1Ooonf[oj`3o1OoonfX0
0oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooh40oookJ_oonfX01_oonfX0
1Ol0e?oo00CooookJ_oonf[o0:Wo00Cooo]Z00?o0?l^o`3oC_oonfX01OoonfX01Ol0hOoo0?lMo`3o
2?oonf[o0?mC00Cooo]Z00Coo`1io`2]oolE0?ooo`1A0_oonfX01Ol06Oooo`1Zoa00oooonf[oT_l0
00;ooo]Z00?o0?m=o`0`oon2o`000_oonfX00ol0oe_ooo]Zoc7o0008oookJP06ob3o0?lV0?ooQ03o
oookJ_oQo`3of_l00ooonfX00ooo01?oo`2CoookJP02oookJP05ooo:0?lB0?oo0?lKo`2>ool00000
0ooonfX01Ol0omoooo]ZogSo0?l0g?oo?ol000;ooo]Z0_l0:_l01?oonf[o0?lcoomB0?ooDP0Boook
JPCo07?o6ooonfX3o`1coaKooo]Z00Go^Ol0oookJ_oonf[ooe80o`3o<`02oookJP03o`0Zoooonf[o
oo]Z00;ooo]Z00Go?ol0o`3Loooonf[oN?l0o`3og`0:oookJP04o`3o6ooonf[ooo]Zooo:00Cooo]Z
00Coo`2Co`3ioooonf[oo`0C1_oonfX00ooJo`3ooo]ZoookJP02oookJP03obH0oolPo`3ooo]Z01;o
oo]Z00Co<Ol0oookJ_oonf[o0?mK0_oonfX02Ol0ok3oP_l0oookJ_l0<?oooo]Zo`3oCOl0j?oooo]Z
o`H0o`02oookJP08ool0mOnBo`3ooo]ZoookJ_l@0?oo05goool0J_l06Ol4oookJP04ool0DOoonf[o
oo]Zo`2]o`;ooo]Z00?oo`1ioookJ_oonfX02?oonfX00ol0oe?ooo]ZoookJP0UoookJP00;ooonfX0
0olH0?oooo]Zool60003oookJP04on_o0?oo0?Kooo]ZoookJP?oU?l000ooZ03ooiCo0?oonf[ooo]Z
oiCo0?oonf[o07OooookJ_ooK03oU?l0o`3oc?oonf[ooh40oookJ_lko`000ooonfX00ol0nooooo]Z
oookJP03oookJP08ool30?oonf[ooo]Zool0gOmi0?oo0:?ook?o0?nO0?l5oookJP05o`3og_oUo`3o
oo]ZoookJ_oo06`01?oonfX01Om=0?ooH@3ooookJ_oonf[o0?m500?ooo]Z00GoiOl0o`3oT?oonf[o
oo]ZodCo0007oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603ooookJ_oVo`3ooo]Zoon@000;oook
JP04oonn0?oonf[o0?l5on/0o`Kooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP06
oookJP03oon10?oonf[ooo]Z00Kooo]Z00Go0=CooookJ_oonf[ooo]Zo`2Yo`04oookJP05odCo0?l0
ocCooo]ZoookJ_m4o`000ooonfX01_l0hOoo0?lMoiCo0?nDo`3o0?mCoiCo00?ooo]Z00Coo`1ioook
J_l0[Oooo`1A2?nDo`001?l0odgo0>Soo`0`oooob@02oookJP03o`3oFooonf[o<Ol000Sooo]Z00Go
8?l0obH0oon40?oooo]Zom[o0004oookJP05ool04ooo09?ooo]ZoookJ_oobP002?oob@000ol0omoo
N?l0ogSo0003o`3o30;o02[o00Gooo]Zo`3o<oooDP3ooe80okWo000>oookJPCo07?o8ooonfX3o`1c
oaCooo]Z0_nio`000ooonf[ooe80o`3o<`02oookJP04o`0Zoooonf[ooo]ZoookJP?oiOl000CoN?l0
onGo0?oUo`3oiOl02?oonfX01OlB0?oo0?lKoookJ_oonf[oiOl000Cooo]Z00?oo`2CoookJ_oo01<0
1_oonfX00ooJo`3ooo]ZoookJP03oookJP03obH0oolPo`3ooo]Z017ooo]Z00go<Ol0oookJ_oonf[o
oo]Zo`3oFooonf[oP_l0o`3o/?l0ok7o033ooookJ_l0odgo0>So00;ooo]Z00?o1P3ooookJ_m4o`00
1?oonfX00ol@0?ooo`1Zo`0Io`04oookJP06oaD0oooo057ooo]Zo`2]oooonf[oo`1i2_oonfX00ol0
oe?ooo]ZoookJP1AoookJP03oaP0oooonf[oo`H000?ooo]Z00?ojol0oookJ_oo0?H00_oonfX00ol0
Y_oooo]ZojP0o`03oookJP03ool0nOoonf[o07Oo00;ooo]Z00Coof`0oookJ_l0olcooh400_oonfX0
1Olko`3ooo]ZoookJ_oonf[o0?_o00Cooo]Z00Woo`<0oookJ_oonf[oo`3MogT0ool0Xooo/ol0o`0G
oonO0?l01OoonfX01Ol0omkoo`27oookJ_oonf[oo`1/00?ooo]Z00GoC@3oool^0?mQ0?oooo]Zo`3o
A@04oookJP04on80oooonf[ooo]Zo`3oTPOooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?oooo]Z
onKo0002oookJP03oon@0?oonf[ooo]Z00Wooo]Z00Cookh0o`3o1Ooonf[oj`3o1OoonfX00oooE`3o
oo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX01ooonfX01Ol0e?oo
oo]ZoookJ_l0ZOoo08So00?ooo]Z00?o0?l^o`3oC_l0oc@01OoonfX01_l0hOoo0?lMoookJ_l0o`So
oo]Zo`3oD`?ooo]Z00Coo`1ioookJ_l0[Oooo`1A0_oonfX01Ol06Oooo`1Zoa00oooonf[oT_l000;o
oo]Z00?o0?m=oookJ_n2o`000_oonfX00ol0oe_ooo]Zoc7o0008oookJP06ob3o0?lV0?ooQ03ooook
J_oQo`3of_l00ooonfX00ooo01?oo`2CoookJP02oookJP04ooo:0?lB0?oo0?lKo`2>o`;o00000_oo
nfX01_l0omooN?l0ogSo0?l0g?oo?ol0oookJP;o02[o00Gooo]Zo`3o<ol0oc?ooe80okWo000?oook
JPCo07?o8_oonfX3o`1coaCooo]Z0_nio`000ooonf[ooe80oomB0002oookJP;o02[o0ooonfX01?lo
o`3o0=cooookJ_mho`02o`3og`Sooo]Z00Go08koo`3o6ooonf[ooo]Zooo:0004oookJP03ool0Tol0
nOooo`0C00Oooo]Z00?of_l0oookJ_oonfX00_oonfX00olV0?oo8?l0oookJP0AoookJP05oc7o0?oo
nf[ooo]ZoookJ_l0oe/00_oonfX00on2o`3ooo]Zo`0`o`02oookJP07o`3oCOoonf[ooo]Zo`H0oooo
nf[oo`3eoi;o0003oookJP03oa00oooonf[o01Wo00Cooo]Z00Co5@3oool0DOoonf[o0:go0_oonfX0
0ooo07Wooo]ZoookJP08oookJP03o`3oDooonf[ooo]Z02Gooo]Z000_oookJP03oaP0oooonf[oo`H0
00?ooo]Z00Oojol0ool0m_oonf[ooo]ZoiCo0?oonf[oZ03o00;oU?l000Sooo]ZoiCo0?oonf[ooo]Z
o`1gooooK03ooo]ZoiCo00;ooo]Z00?ooh40oookJ_lko`000ooonfX00ol0nooooo]ZoookJP02oook
JP09ool30?oonf[ooo]ZoookJ_oo0=gooo]Zok?o0?l05oooW`3o00Gooo]Z00Go0?oNonGo0?oonf[o
oo]Zool0K003oookJP05odd0oooo;P3oH@3ooookJ_l0odD01?oonfX01OoUo`3o0?n@oookJ_oonf[o
A?l000Kooo]Z00?oJ03ooookJ_oonfX00_oonfX01OlH0?oo07CoonKo0?oonf[ooi0000_ooo]Z00Go
okh0oookJ_l0o`Goj`3oog00o`05oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX0
1_oonfX00oooP@3ooo]ZoookJP05oookJP06o`3Dool01?oooo]ZoookJ_l0R?oo0:Wo0ooonfX00om4
o`3o0?ldoookJP06oookJP04o`3o7OnDo`3oU?l0o`3oD`;oU?l00_oonfX01ooo07Wooo]Zo`2]oolE
0?ooo`1AoookJ_l06Ol01_nDo`002?l0odgo0?nao`3o/?n2o`3ooo]Zo`3oFooonf[o<Ol02?oonfX0
1_lPo`3o9P3ooh@0oooonf[ohOl0om[o00;ooo]Z0_oo01<01Ooo09?ooo]ZoookJ_oobP3ooo]Z00Oo
olT000?o0?oOogSo0?l0o``00_l0o``2o`0Zo`05oookJ_l0oc?ooe80oomB0?nio`003?oonfX4o`1c
ob[ooo]Z0ol0LolCoookJP04okWo0?oonf[ooe80o`3o<`;ooo]Z00Go02[ooookJ_oonf[ooo]Zocoo
0002onGo0004ogSo0?oUo`3oiOl0onGo00Sooo]Z00Co4P3oo`3o6ooonf[oiOl01OoonfX00ooo09?o
oo]Zool04`05oookJP03om[o0?oQo`3ooo]Z00Cooo]Z00?o9P3oob3o0?oonfX04OoonfX03?lao`3o
oo]ZoookJ_l0oe_ooo]Zoh;o0?l0ok3ooo]Zo`0`oooonf[o0?m=o`3Xo`;ooo]Z00Co1P3ooookJ_oo
nf[oA?l00ooonfX00ol@0?ooo`1Zo`0Io`05oookJP03ool0DOoonf[o0:go00;ooo]Z00?oo`1ioook
J_oonfX02?oonfX00ol0oe?ooo]ZoookJP1@oookJP03oaP0oooonf[oo`H000?ooo]Z00Gojol0oook
J_oo0?Kooo]Zo`2Vo`02oookJP0?ojP0oooonf[ooo]ZoookJ_oo0?Wooo]Zo`1goooonf[oof`0o`3o
V_l0olcooo]Zoon10?oonf[o>ol000Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30003oookJP06ool0
gOoonf[o/ol0o`0Goooonf[oW`3o1OoonfX01Ol0omkoo`27oookJ_oonf[oo`1/00;ooo]Z00GoC@3o
oookJ_oo;P3oH@3oo`3oA@05oookJP04on80oooonf[ooo]Zo`3oTPKooo]Z00?oJ03ooookJ_oonfX0
0_oonfX01_lH0?oo07CooookJ_oVo`3ooo]Zoon@00_ooo]Z00Cookh0o`3o1Ooonf[oj`3o1OoonfX0
0oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooh40oookJ_oonfX01_oonfX0
1Ol0e?oo00CooookJ_oonf[o0:Wo00?ooo]Z00?o0?l^o`3oC_l0oc@01_oonfX01Ol0oagooo]Zo`3o
2?oonf[o0?mC00?ooo]Z00Goo`1ioookJ_l0[Ooo5@3oool0D@02oookJP0>o`0Iool@0?oooo]Zoi;o
0?l60?oooo]Zo`3oCOoonf[o0?n`oh;o0?oonf[o0?mKoookJ_lao`08oookJP07ob3o0?lV0?ooQ03o
oookJ_oQo`3ooo]Zom[o0002oookJP03ool04ooo09?ooo]Z00;ooo]Z00?oolX0o`3o6ol0oa/01?l0
00000ooonf[o0?oOogSo0002o`3Lo`04ocoo0?oonf[o02[ooookJP;o0?lc0_ooDP0=oookJPCo07?o
:OoonfX3o`1coa?ooo]Z00Co^Ol0oookJ_oonf[ooe800ooonfX02_l0:_oooo]ZoookJ_oonf[o?ol0
o`3Loooonf[oN?l0oookJ_l0oml8oookJP04o`2>ool0oa_ooo]Zooo:00Gooo]Z00?oo`2Co`3ioooo
01<01_oonfX00ooJo`3ohOl0oookJP03oookJP03obH0oolPo`3ooo]Z017ooo]Z00Co<Ol0oookJ_oo
nf[o0?mK0_oonfX01_n2o`3ooo]Zo`3o/Ol0<?oooo]Zo`3oC@;ooo]Z00Co1P3ooookJ_oonf[oT_l0
0ooonfX00ol@0?oo05goo`0Io`05oookJP04ool0DOoonf[ooo]Zo`2]o`;ooo]Z00?oo`1ioookJ_oo
nfX02?oonfX00ol0oe?ooo]ZoookJP0ToookJP00;_oonfX00olH0?oooo]Zool60003oookJP03on_o
0?oonf[oo`3f00;ooo]Z00?oU?l0oookJ_nX0?l00ooonfX02onDo`3ooo]Zo`1goooonf[oof`0oiCo
0?l0olcooo]Zoon10?oonf[o>ol000Cooo]Z00?o0?_ooookJ_oonfX00_oonfX02?oo0`3ooo]Zoook
J_oo0=goN@3ooookJ_nco`3oW`3o1_oonfX01OoUo`3ooo]ZoookJ_oonf[oo`1/00?ooo]Z00GoC@3o
ool^0?mQ0?oooo]Zo`3oA@03oookJP05onGo0?l0oi3ooo]ZoookJ_m4o`001ooonfX00omX0?oooo]Z
oookJP02oookJP05oaP0ool0M?ooi_l0oookJ_ooT0002ooonfX01Ooo_P3ooo]Zo`3o1Oo[0?ooL03o
00Gooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP06oookJP03oon10?oonf[ooo]Z
00Gooo]Z00?o0=Coo`04oooonfX00_oonfX00ol0ZOoooo]ZoookJP02oookJP03odCo0?oonf[ooo]Z
00Gooo]Z00Ko0?lMoiCo0?oonf[ooo]Zo`3oDonDo`02oookJP09ool0NOoonf[o0:gooaD0oooo057o
oo]Zo`0Iool@0?oo05go00CoU?l000So0?m=o`3o/Ol0ok3oP_l0oookJ_l0oe_ooo]Zoc7o00Sooo]Z
00?o8?l0obH0oon40?l00_oQo`001?oJo`3ooo]ZoookJ_oo01<2ool0T`07o`3ioooonf[oolX0oook
J_oob@3o08kooookJP05ooo90003ogSo0?l0o`co0?l<00;o02[o00Go0?l<o`3o<ol0oc?ooe80okWo
000:oookJP?oolT000?o07?ooookJ_oonfX0;ooonfX2o`1coa;ooo]Z00Co^Ol0oookJ_ooDP3ooe80
0_oonfX2o`0Zo`;ooo]Z00Co?ol0o`3LoooUo`3oN?l00_oUo`08oookJP05oa80ool0S_oo0?lKoook
J_oUo`001?oonfX00ol0nOooo`2Cool04`06oookJP03om[o0?oQo`3ooo]Z00?ooo]Z00?o9P3ooh@0
oolPo`004OoonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP07oh;o0?l0ok3o0?nao`0`oooonf[o0?m=
o`3Xo`02oookJP03o`H0oooonf[oA?l000?ooo]Z00?o403oo`1Mool06Ol01OoonfX01_lE0?ooo`1A
oookJ_l0[Ooooo]Zool0N@[ooo]Z00?o0?mCoookJ_oonfX0D?oonfX00olH0?ooo`H0oookJP02oook
JP03on_o0?oonf[oo`3f00;ooo]Z00?o0:KooookJ_nX0?l01?oonfX02ooo0?Wo07OooookJ_oonf[o
of`0oookJ_l0olcooo]Zoon10?oonf[o>ol000?ooo]Z00?o0?_ooookJ_oonfX00_oonfX02Ooo0`3o
oo]ZoookJ_oo0=goN@3ooookJ_nco`3o01Oooil0o`05oookJP03omgo0?oo08Oooo]Z00;ooo]Z00So
o`1/oookJ_oonf[oC@3ooookJ_mQ0?oooo]Zo`3oA@Cooo]Z00CohP3ooookJ_oonf[o0?nB1ooonfX0
0omX0?oooo]ZoookJP02oookJP03oaP0ool0M?ooi_l000;ooo]Z00?ooi00oookJ_oonfX02OoonfX0
1?oo_P3o0?l5oookJ_o[0?l5oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01Ooo
nfX00oooP@3ooo]ZoookJP06oookJP06o`3Dool01?oooo]ZoookJ_l0ZOoo08So0ooonfX00ol0obko
0?m>oookJP05oookJP05o`3o7Ooonf[o0?l8oookJ_l0oe<00ooonfX01Ooo07Wooo]Zo`2]oolE0?oo
o`1A00;ooo]Z00[o01Wooa00oooonf[oT_l0o`H0oooonf[o0>Soo`3oCOl0ok3oP_l00_oonfX00ol0
oe_o<Ol0oookJP07oookJP08ob3o0?lV0?ooQ03ooookJ_oQo`3ooo]Zom[o0?oonfX2ool04`08ool0
Tol0nOoooo]ZoookJ_oobP3o0?lKo`2>oooonfX4o`0000;oN?l000?o0=coocoo0?oonfX00_l0:_l2
o`3o<`;ooe803?oonfX3o`1coc3ooo]Z0_l0LolBoookJP04okWo0?oonf[ooo]ZoomB00?ooo]Z00[o
02[ooookJ_oonf[ooo]Zocoo0?l0g?oooo]ZogSo0?oonf[o0?oO2?oonfX01?lB0?oo0?lKoookJ_oo
bP05oookJP03ool0Tooonf[oo`0C00Kooo]Z00?of_l0oookJ_oonfX00_oonfX00olV0?ooQ03oob3o
000AoookJP04oc7o0?oonf[ooo]Zo`3oF`?ooo]Z00?oP_l0oookJ_l0<?l00_oonfX01ol0odgooo]Z
oookJ_l60?oooo]Zool0mOnBo`000_oonfX01?l@0?oo05gooookJ_l06Ol4oookJP04oaD0oooo057o
oo]Zo`2]o`;ooo]Z00?oo`1ioookJ_oonfX02?oonfX00ol0oe?ooo]ZoookJP0ToookJP00;_oonfX0
0olH0?oooo]Zool60003oookJP03on_o0?oo0?Kooo]Z00;ooo]Z00?oU?l0oookJ_nX0?l00ooonfX0
2onDo`3ooo]Zo`1goooonf[oof`0oiCo0?l0olcooo]Zoon10?oonf[o>ol000?ooo]Z00?o0?_ooook
J_oonfX00_oonfX02Ooo0`3ooo]ZoookJ_oonf[oo`3MogT0oonco`3o01Oooil0o`05oookJP05o`3o
g_oUo`3ooo]ZoookJ_oo06`00ooonfX01Om=0?ooobh0of40oooonf[o0?m500Cooo]Z00GoiOl0o`3o
T?oonf[ooo]ZodCo0006oookJP03ofP0oooonf[ooo]Z00?ooo]Z00Co603ooookJ_oVo`3ooi003?oo
nfX01?oo_P3ooo]Zo`3o1Oo[0?l5oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX0
1_oonfX00oooP@3ooo]ZoookJP05oookJP05o`3Dool01?oooo]ZoookJ_l0ZOl01?oonfX00om4o`3o
0?ldoookJP05oookJP07o`3Qool0oagoU?l0oookJ_l0oe?ooo]ZoiCo0002oookJP09ool0NOl0[Ooo
oo]Zool0DOoonf[o01WooookJ_l@0?oooo]Z00?oU?l000So0?m=oiCo0?l0ok3oP_l0oookJ_l0oe_o
oo]Zoc7o00Sooo]Z00Ko8?l0obH0oon40?oohOl0oookJ_oJo`02oookJP06ool04ooo09?ooo]Zo`3i
oooonf[oolX00_oob@001?l0S_oooo]ZoookJ_l0o``3ooo900;o0?l<0_l0:_l00ol0o`coiOl0onGo
0002oomB00Sooo]Z1Ooob@0foookJP?o07?o4?oonfX2okWo0003oookJ_ooDP3ooo]Z00;ooo]Z00Oo
02[ooookJ_oonf[o?ol0o`3Loooonf[oN?l000;oiOl02?oonfX01OlB0?oo0?lKoookJ_oonf[oiOl0
00Cooo]Z00?oo`2CoookJ_oo01<01_oonfX00ooJo`3ooo]ZoookJP03oookJP03obH0oooonf[o8?l0
017ooo]Z00co<Ol0oookJ_oonf[o0?mKoookJ_n2o`3o0?n`oookJ_l0<?oooo]Zo`3oCOl0j?l2oook
JP04o`H0oooonf[ooo]ZodCo00;ooo]Z0_m4o`000ooo06[o01WooookJP03oookJP06oaD0oooo057o
oo]Zo`2]oooonf[oo`1i2_oonfX00ol0oe?ooo]ZoookJP1?oookJP03oaP0oooonf[oo`H000?ooo]Z
00?ojol0oookJ_oo0?H00_oonfX00ol0Y_oooo]ZojP0o`03oookJP03ool0nOoonf[o07Oo00;ooo]Z
00Koof`0oookJ_l0olcooh40oookJ_lko`04oookJP05o`3koooonf[ooo]ZoookJ_oo0`000ooonfX0
1_oo0=goN@3ook?o0?oonf[o01Oooil0o`Gooo]Z00Go0?oNool0Qooonf[ooo]Zool0K003oookJP04
odd0oooo;P3oH@3oo`3oA@Gooo]Z00CohP3ooookJ_oonf[o0?nB1_oonfX00omX0?oooo]ZoookJP03
oookJP05oaP0oooonf[oi_l0oookJ_ooT0003?oonfX00ooo_P3o0?l5on/0o`05oookJP03oomG0?oo
nf[ooo]Z00Cooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP06oookJP05o`3Dool0
1?oooo]Zo`2Yool0R?l00ooonfX00ol0obko0?m>o`3o=005oookJP05o`3Qool0oagooo]Zo`3o2?l0
oe<01?oonfX01?oo07Wo0:gooookJ_oo0542oookJP0:o`0Ioooo06[o403ooookJ_nBo`3ooo]Zo`3X
ool0odgo0?n`oh;o00;ooo]Z00?o0?mKoc7o0?oonfX01ooonfX03OlPo`3o9P3ooh@0oooonf[ohOl0
oookJ_oJo`3ooo]Zool04ooonf[oo`2Co`3ioooonfX00_oobP001?l0oa_o08kooookJ_oonfX2o`00
0005o`3ogomho`3o0=coo`3Looloo`000_l0:_l2o`3o<`;ooe803?oonfX2o`1cocGooo]Z0ol0Lol@
oookJP;o^Ol000?ooo]ZoomB0?oonfX00_oonfX2o`0Zo`;ooo]Z00Ko?ol0o`3Loooonf[oN?l0oook
J_l0oml7oookJP05o`2>ool0oa_ooo]ZoookJ_oobP001?oonfX00ooo09?o0?Woool04`07oookJP03
om[o0?oonf[ooo]Z00;ooo]Z00?o9P3ooookJ_lPo`004OoonfX01?lao`3ooo]ZoookJ_l0oe/2oook
JP03oh;o0?oonf[o033o00;ooo]Z00Co0?m=oookJ_oonf[o1P3o0_oonfX01onBo`3ooo]ZoookJ_oo
nf[o403oo`1Mool06Ol01?oonfX01?lE0?ooo`1AoookJ_l0[Ol2oookJP03ool0NOoonf[ooo]Z00So
oo]Z00?o0?mCoookJ_oonfX09?oonfX002kooo]Z00?o603oool60?oonfX00ooonfX00oo[o`3oo`3f
oookJP02oookJP03oiCo0?nX0?oooo]Z00;ooo]Z00_oU?l0oookJ_oonf[o07Oooom/0?oonf[oU?l0
o`3oc?oonf[ooh40oc_o0004oookJP03o`3koooonf[ooo]Z00;ooo]Z00Soo`<0oookJ_oonf[ooo]Z
ool0gOoonf[o/ol0oil0o`Kooo]Z00GoiOl0oiCo0?oonf[ooo]Zool0K003oookJP05odd0oooo;P3o
H@3ooookJ_l0odD01?oonfX01OoUo`3ooo]ZoookJ_oonf[oA?l000Kooo]Z00?oJ03ooookJ_oonfX0
0_oonfX01OlH0?oo07CoonKo0?oonf[ooi0000_ooo]Z00Gookh0oookJ_l0o`Goj`3oog00o`05oook
JP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01_oonfX00oooP@3ooo]ZoookJP05oook
JP03o`3Dool01?oooo]Z00;ooo]Z00Ko0:WooookJ_oonf[ooo]ZodCo0?l0oc@7oookJP04o`3o7OnD
o`3ooo]Zo`3oD`Cooo]Z00Coo`1io`2]oooonf[oo`1A0_oonfX01ol06Ooo403ooookJ_nDo`3o1P3o
oookJ_l0odd00_nDo`001On2o`3ooo]Zo`3oFooonf[o<Ol000Sooo]Z00Ko8?l0obH0oon40?oohOl0
oookJ_oJo`02oookJP09ool04ooo09?ooo]Zo`3ioooonf[oolX0ooo90?lB0?oo08ko00?ooo]Z00Co
?@3oogSo0?oob@3o0?l<0_l0:_l3onGo00;ooe801ooonfX7ooo901Gooo]Z0ooob@0RoookJP?o07?o
3ooonfX00onio`3ooo]ZoomB0003oookJP07o`0Zoooonf[ooo]Zocoo0?l0g?oooo]ZogSo0002onGo
00Sooo]Z00Co4P3oo`3o6ooonf[oiOl01?oonfX00ol0nOooo`2Cool04`06oookJP03om[o0?oQo`3o
oo]Z00Cooo]Z00?o9P3oob3o0?oonfX04?oonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP03oh;o0?l0
ok3o033o00;ooo]Z00Ko0?m=oookJ_oonf[ooo]Zo`H0oooonfX5odCo0003oookJ_l06Ooooo]Z00Co
oo]Z00Ko5@3oool0DOoonf[o0:gooookJ_oo07T9oookJP03o`3oDooonf[ooo]Z04oooo]Z00?o603o
oookJ_oo1P000ooonfX00oo[o`3ooo]Zool0mP02oookJP03o`2VoonX0?oooo]Z00?ooo]Z00_oo`3i
oookJ_l0Mooooo]Zoom/0?l0oi[o0?o<oookJ_ooP@3ooo]Zoc_o0004oookJP05o`3koooonf[ooo]Z
oookJ_oo0`000ooonfX01Ooo0=gooo]Zok?o0?l05oooW`3o00Kooo]Z00Goo`27oookJ_oonf[ooo]Z
ool0K002oookJP05odd0oooonf[oobh0of40ool0odD01?oonfX01OoR0?oooo]ZoookJ_oonf[o0?nB
00Kooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?oo07CoonKo0002oookJP03oon@0?oonf[ooo]Z
00Wooo]Z00Cookh0o`3o1Ooonf[oj`3o1OoonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[o
oo]Z00Gooo]Z00?ooh40oookJ_oonfX01_oonfX01Ol0e?oo00CooookJ_oonf[o0:Wo00Cooo]Z00?o
0?m>o`3o=?oonfX01OoonfX01Ol0oagooo]Zo`3o2?oonf[o0?mC00?ooo]Z00Coo`1io`2]oooonf[o
o`1A0ooonfX02Ol06Ooo403ooookJ_nBo`3o1P3oo`3Xool0odgo0?n`oh;o0002oookJP03o`3oFola
o`3ooo]Z00Oooo]Z00ko8?l0obH0oon40?oooo]Zon7o0?oonf[of_l0oookJ_oo01?ooo]Zool0Tol0
nOoooo]Zooo:00;o0?lK00Go08kooookJ_oonf[ooo]Zo`000002ogSo0006o`3Looloo`3o02[oo`0Z
oooonf[o0?lc0_ooDP0<oookJP;o07?o>_oonfX3o`1co`oooo]Z00Co^Ol0oookJ_ooDP3o0?lc0ooo
nfX02Ol0:_oooo]ZoookJ_loo`3o0=cooookJ_mho`3ooo]Zo`3og`07oookJP04o`2>ool0oa_ooo]Z
ooo:00Gooo]Z00?oo`2CoookJ_oo01<01_oonfX00ooJo`3ohOl0oookJP03oookJP03obH0oolPo`3o
oo]Z013ooo]Z00Co<Ol0oookJ_oonf[o0?mK0ooonfX01_n2o`3ooo]Zo`0`oooonf[o0>Soo`3oC@;o
oo]Z00Co1P3ooookJ_oo0?GoT_l00_oonfX01?l@0?oo05goo`0Ioooo06X4oookJP04oaD0oooo057o
oo]Zo`2]o`;ooo]Z00?oo`1ioookJ_oonfX01ooonfX00ol0oe?ooo]ZoookJP0ToookJP00;_oonfX0
0olH0?ooo`H0oookJP02oookJP03on_o0?oonf[oo`3f00;ooo]Z00?oU?l0oookJ_nX0?l00ooonfX0
2onDo`3ooo]Zo`1goooonf[oof`0oookJ_nDo`3ooo]Zoon10?oonf[o>ol000Cooo]Z00?o0?_ooook
J_oonfX00_oonfX02?oo0`3ooo]ZoookJ_oo0=goN@3ooookJ_nco`3oW`3o1OoonfX00ol0omkoiOl0
oookJP02oookJP08ool0K?oonf[ooo]ZoookJ_m=0?oooo]Zof40ool0odD4oookJP05onGo0?l0oi3o
oo]ZoookJ_m4o`001_oonfX00omX0?oooo]ZoookJP03oookJP05oaP0ool0M?ooi_l0oookJ_ooT000
2ooonfX01?oo_P3ooo]Zo`3o1Oo[0?l5oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oo
nfX01_oonfX00oooP@3ooo]ZoookJP05oookJP05o`3Dool01?oooo]ZoookJ_l0ZOl01?oonfX00om4
o`3o0?ldoookJP05oookJP04o`3Qool0oagooo]Zo`3oD`Cooo]Z01Coo`1ioookJ_l0[Ooooo]Zool0
DOoonf[o01Wooa00oooonf[oo`3eoiCo0?l60?oooo]Zo`3oCOnDo`3o0?n`oh;o0?l0oe_ooo]Zoc7o
00Sooo]Z00Oo8?l0obH0oon40?oohOl0oookJ_oJo`3ooo]Z00;oolT000?oo`2CoookJ_l0nOl00_oo
bP000ooob@3o4P3oo`2>o`03oookJP05ocd0oomho`3o0?l<o`3o3?l0:_l00ooUo`02oomB0003onGo
0?oonf[ooo]Z00;ooo]Z2_oob@0FoookJPKoolT08_oonfX2o`1co`kooo]Z0_nio`001OooDP3ooo]Z
oookJ_oonf[o02[o00;ooo]Z00Ko?ol0o`3Loooonf[oN?l0oookJ_oUo`07oookJP05o`2>ool0oa_o
oo]ZoookJ_oUo`001?oonfX00ol0nOooo`2Cool04`06oookJP03om[o0?oQo`3ooo]Z00?ooo]Z00?o
Q03oobH0oolPo`004OoonfX00olao`3ooo]Zo`3oF`02oookJP07oh;o0?oonf[o0?n`o`0`oooonf[o
0?m=o`3Xo`02oookJPOoA?l000?o403oo`0IoooonfX01?oonfX01_lE0?ooo`1AoookJ_l0[Ooooo]Z
ool0N@Wooo]Z00?o0?mCoookJ_oonfX0CooonfX00olH0?ooo`H0oookJP02oookJP03on_o0?oonf[o
o`3f00;ooo]Z00?o0:KooookJ_nX0?l00ooonfX00ooo0?Wooo]Zo`1go`02oookJP07oom/0?l0oi[o
0?o<oookJ_ooP@3ooo]Zoc_o0003oookJP03o`3koooonf[ooo]Z00;ooo]Z00Woo`<0oookJ_oonf[o
o`3MogT0oooonf[o/ol0o`0GoonO0?l01OoonfX00ol0omkoo`27oookJP02oookJP07ool0K?oonf[o
oo]Zodd0oooo;P3oH@3oo`3oA@05oookJP04on80oooonf[ooo]Zo`3oTPKooo]Z00?oJ03ooookJ_oo
nfX00ooonfX00olH0?oo07CoonKo0002oookJP03oon@0?oonf[ooo]Z00Wooo]Z00?ookh0o`3o1Oo[
0?l01OoonfX00oooE`3ooo]ZoookJP04oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oo
nfX01_oonfX01Ol0e?oo00CooookJ_l0ZOoo08So00?ooo]Z00?o0?l^o`3oC_l0oc@01OoonfX01Ol0
hOoo0?lMo`3o2?oonf[o0?mC00?ooo]Z00Goo`1ioookJ_l0[Ooooo]Zool0D@02oookJP0=o`0Iool@
0?oooo]Zoi;o0?l60?oooo]Zo`3oCOoonf[o0?n`oh;o0?oonf[o0?mKoc7o0008oookJP0Aob3o0?lV
0?ooQ03ooookJ_oQo`3ooo]Zom[o0?oonf[oo`0CoookJ_oo09?o0?WooookJ_oobP3o0?lKoa80ool0
S_l01?oonfX01Omho`3o0=coo`3Looloo`3o02[o00;ooo]Z0_ooDP000onio`3ooo]ZoookJP09oook
JP;o07?o?ooonfX2o`1co`kooo]Z0_nio`02oomB00?ooo]Z00Wo02[ooookJ_oonf[o?ol0o`3Loolm
0?ooN?l0oookJ_l0oml01ooonfX01?l0oa_o4P3ooookJ_oobP05oookJP03ool0Tooonf[oo`0C00Ko
oo]Z00?of_l0on7o0?oonfX00_oonfX00on40?oo9P3oob3o000AoookJP03oc7o0?oonf[o0?mK00?o
oo]Z00?oP_l0o`3o/?l0<?l00_oonfX01?l0odgooo]ZoookJ_l60?l2oookJP07oi;o0?oonf[ooo]Z
oookJ_l@0?oo01Woool0JP04oookJP04oaD0oooo057ooo]Zo`2]o`;ooo]Z00?oo`1ioookJ_oonfX0
1ooonfX00ol0oe?ooo]ZoookJP0ToookJP00;OoonfX00olH0?oooo]Zool60003oookJP03on_o0?oo
0?Kooo]Z00;ooo]Z00?oU?l0ojP0oooonfX00_oonfX03?nDo`3ooo]ZoookJ_l0Mooooo]Zoom/0?nD
o`3o0?o<oookJ_ooP@3ooo]Zoc_o00?ooo]Z00?o0?_ooookJ_oonfX00_oonfX02Ooo0`3ooo]Zoook
J_oonf[oo`3MogT0oonco`3o01Oooil0o`05oookJP05onGo0?nDo`3ooo]ZoookJ_oo06`00ooonfX0
1Om=0?ooobh0of40oooonf[o0?m500Cooo]Z00GoiOl0oookJ_oonf[ooo]ZodCo0006oookJP03ofP0
oooonf[ooo]Z00;ooo]Z00Go603oo`1doooVo`3ooo]Zoon@000;oookJP05oonn0?oonf[o0?l5on/0
oom`0?l01OoonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooh40oook
J_oonfX01OoonfX00ol0e?oo00CooookJP02oookJP06o`2Yoooonf[ooo]ZoookJ_m4o`3o0?ld1ooo
nfX01?l0oagoU?l0oookJ_l0oe<4oookJP0Cool0NOl0[Ooooo]Zool0DOoonf[o01Wooa00oooo06[o
oo]ZoiCo0?l60?oooo]Zo`3oCOl0<?oo0?n`oh;o0?oonf[o0?mKoc7o0009oookJP06ob3o0?lV0?oo
hOl0oookJ_oJo`3ooo]Z0_oob@001ooo09?ooo]Zo`3ioooobP3ooo]Zooo90?l0S_l01?oonfX01Ol0
omooN?l0o`3o3?loo`3o02[o00?oiOl000?ooe80onGo0?oUo`000ooonfX;ooo901Oooo]Z2Ooob@0Q
oookJP03o`1coooonf[ooo]Z00gooo]Z00?o^Ol0oomB0?oonfX00_oonfX02?l0:_oooo]ZoookJ_lo
o`3o0=cooookJ_mho`3o0?oO2?oonfX01?lB0?oo0?lKoookJ_oUo`05oookJP03o`3ioooo09?oo`0C
00Gooo]Z00?of_l0oookJ_oUo`001?oonfX00olV0?oo8?l0oookJP0@oookJP04oc7o0?oonf[ooo]Z
o`3oF`;ooo]Z00?oP_l0o`3o/?l0<?l00_oonfX00ol0odgooo]ZodCo0007odCo0003oa00oooo06[o
01Wo00Cooo]Z00Ko5@3ooookJ_oo057o0:gooookJ_oo07T:oookJP03o`3oDooonf[ooo]Z04gooo]Z
00?o603ooookJ_oo1P000ooonfX00oo[o`3ooo]Zool0mP02oookJP03o`2VoonX0?oooo]Z00?ooo]Z
00?oo`3ioookJ_l0Mol00_oonfX01_ooK03ooo]Zo`3oc?ooP@3ooo]Zoc_o00Cooo]Z00Go0?_ooook
J_oonf[ooo]Zool30003oookJP06ool0gOmi0?oo/ol0o`0Goooonf[oW`3o1OoonfX01Ooo08Oooo]Z
oookJ_oonf[oo`1/00?ooo]Z00CoC@3oool^0?mQ0?oo0?m51?oonfX01OoR0?oooo]ZoookJ_oonf[o
0?nB00Kooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?oo07CoonKo0002oookJP03oon@0?oonf[o
oo]Z00Wooo]Z00Cookh0o`3o1Ooonf[oj`3o1OoonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooo
nf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX01_oonfX01Ol0e?oo00CooookJ_oonf[o0:Wo00?ooo]Z
00?o0?l^o`3oC_l0oc@01_oonfX01?l0oagooo]Zo`3o2?l0oe<4oookJP04ool0NOl0[Ooooo]Zool0
D@;ooo]Z00go01Wooa00oooonf[oT_l0o`H0oooonf[o0>Soo`3oCOl0ok3oP_l0oookJ_l0oe_o<Ol0
00Wooo]Z00Ko8?l0obH0oooonf[ohOl0oookJ_oJo`02oookJP07ool04ooo09?o0?WooookJ_oobP3o
0?lKoa80o`05oookJP09ogSo0?l0g?oo?ol0ocoo0?l0:_oooo]Zo`3o<oooDP3o^Ol000_ooo]Z0_l0
Lom3oookJP03o`1coooonf[ooo]Z00gooo]Z00?o^Ol0oookJ_ooDP000ooonfX02?l0:_oooo]Zoook
J_loo`3o0=coocd0oomho`3o0?oO1ooonfX01?l0S_oo0?lKoookJ_oobP05oookJP03o`3ioooo09?o
o`0C00Kooo]Z00?of_l0oookJ_oQo`000ooonfX00olV0?oo8?l0oookJP0@oookJP04oc7o0?oonf[o
oo]Zo`3oF`?ooo]Z00KoP_l0oookJ_l0<?oooo]Zo`3Xool0odd2oookJP04o`H0oooonf[oo`3eoi;o
00;ooo]Z00?o403oo`1Mool06Ol01?oonfX01olE0?oooo]Zool0DOoonf[o0:gooookJ_oo07T02_oo
nfX00ol0oe?ooo]ZoookJP0SoookJP00;OoonfX00olH0?ooo`H0oookJP03oookJP03on_o0?oo0?Ko
oo]Z00;ooo]Z00?oU?l0ojP0oooonfX00_oonfX02onDo`3ooo]ZoookJ_l0Mooooo]Zoom/0?nDo`3o
0?o<oon10?oonf[o>ol000Cooo]Z00?o0?_ooookJ_oonfX00_oonfX02?oo0`3ooo]ZoookJ_oonf[o
o`3MoookJ_nco`3oW`3o1OoonfX00ol0omkoo`27oookJP02oookJP08ool0K?oonf[ooo]ZoookJ_m=
0?ooobh0of40ool0odD4oookJP05onGo0?l0oi3ooo]ZoookJ_m4o`001_oonfX00omX0?oooo]Zoook
JP03oookJP05oaP0ool0M?ooi_l0oookJ_ooT0002ooonfX01?oo_P3ooo]Zo`3o1Oo[0?l5oookJP03
oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01_oonfX00oooP@3ooo]ZoookJP05oookJP05
o`3Dool01?oooo]ZoookJ_l0ZOl00ooonfX00om4o`3o0?l^o`3o=006oookJP04o`3Qool0oagooo]Z
o`3oD`Cooo]Z00Coo`1io`2]oooonf[oo`1A0_oonfX03Ol06Ooo403ooookJ_nDo`3o1P3ooookJ_l0
odgooo]Zo`3o/?n2o`3ooo]Zo`3oFolao`002OoonfX01OlPo`3o9P3oon7o0?oonf[of_l000?oolT0
00Ooo`2CoookJ_l0nOooolX0oookJ_oob@3o08ko00Cooo]Z0_mho`02onGo0005o`0ZoooUo`3oiOl0
onGo0?ooDP000_oUo`04oookJP[oolT06?oonfX<ooo901oooo]Z00?o07?ooookJ_oonfX03OoonfX0
1Onio`3ooe80oookJ_oonf[o02[o00?ooo]Z00Go?ol0o`3Loooonf[oN?l0o`3og`08oookJP04oa80
ool0oa_ooo]ZonGo00?ooo]Z0_oUo`000ooo09?oo`0CoookJP05oookJP03om[o0?oUo`3ooo]Z00?o
oo]Z00?oQ03oobH0oooonfX04OoonfX00olao`3ooo]Zo`3oF`02oookJP07oh;o0?oonf[o0?n`o`0`
oooonf[o0?m=oookJP08odCo0003oa00ool0GOoo01Wo00Cooo]Z00Oo5@3ooookJ_oo057ooo]Zo`2]
oooonf[oo`1i00Wooo]Z00?o0?mCoookJ_oonfX0COoonfX00olH0?ooo`H0oookJP03oookJP03on_o
0?oo0?Kooo]Z00;ooo]Z00?o0:KoojP0oooonfX00ooonfX02ooo0?Wooo]Zo`1goooonf[oof`0o`3o
V_oonf[o0?o<oon10?oonf[o>ol000Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30003oookJP05ool0
gOoonf[o/ol0o`0GoonO0?l01OoonfX00ol0omkoo`27oookJP02oookJP07ool0K?oonf[ooo]Zodd0
oooonf[oobh0of40o`05oookJP04on80oooonf[ooo]Zo`3oTPKooo]Z00?oJ03ooookJ_oonfX00ooo
nfX00olH0?oo07CoonKo0002oookJP03oon@0?oonf[ooo]Z00Wooo]Z00Cookh0o`3o1Oo[0?ooL03o
1?oonfX00oooE`3ooo]ZoookJP04oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX0
1_oonfX01Ol0e?oo00CooookJ_l0ZOoo08So00?ooo]Z00?o0?m>o`3o=?oonfX01OoonfX01Ol0hOoo
0?lMo`3o2?oonf[o0?mC00?ooo]Z00Coo`1io`2]oooonf[oo`1A0ooonfX03?l06Ooo403oool0mOnB
o`3o1P3oo`3Xool0odgo0?n`oh;o0?oonf[o0?mKoc7o00Wooo]Z00Ko8?l0obH0oooonf[ohOl0oook
J_oJo`02oookJP07ool04ooo09?o0?WooookJ_oobP3o0?lKoa80o`04oookJP;oN?l000Oo0=coocoo
0?l0003o02[oo`000?l0oc?ooe8000cooo]Z00?o07?ooookJ_oonfX0A?oonfX00ol0Looooo]Zoook
JP0=oookJP03okWo0?oonf[ooe8000;ooo]Z00Wo02[ooookJ_oonf[ooo]Zocoo0?l0g?oo?@3oogSo
0?l0oml01ooonfX01?l0S_oo0?lKoookJ_oobP05oookJP03ool0Tooonf[oo`0C00Kooo]Z00?of_l0
on7o0?oonfX00_oonfX00on40?oo9P3ooookJP0AoookJP03oc7o0?oonf[o0?mK00?ooo]Z00KoP_l0
o`3o/?l0<?oooo]Zo`3Xool0odd2oookJP04o`H0oooonf[ooo]Zoi;o00;ooo]Z00Co403oo`1Mool0
6Oooo`1Z0ooonfX01OlE0?oooo]Zool0DOoonf[o0:go00;ooo]Z00?oo`1ioookJ_oonfX01ooonfX0
0ol0oe?ooo]ZoookJP0SoookJP00;OoonfX00olH0?ooo`H0oookJP02oookJP03on_o0?oo0?Kooo]Z
00;ooo]Z00?oU?l0oookJ_nX0?l00ooonfX02onDo`3ooo]Zo`1goooonf[oof`0oookJ_nDo`3o0?o<
oon10?oonf[o>ol000Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30004oookJP04ool0gOoonf[o/ol0
oil0o`Gooo]Z00?o0?oNool0QooonfX00_oonfX02?oo06cooo]ZoookJ_m=0?ooobh0oookJ_mQ0?oo
0?m51?oonfX01OoUo`3ooo]ZoookJ_oonf[oA?l000Kooo]Z00?oJ03ooookJ_oonfX00ooonfX01OlH
0?ooi_l0oookJ_oonf[ooi0000[ooo]Z00Gookh0oookJ_l0o`Goj`3oog00o`05oookJP03oomG0?oo
nf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01_oonfX00oooP@3ooo]ZoookJP05oookJP06o`3Dool0
1?oooo]ZoookJ_l0ZOoo08So0ooonfX00om4o`3o0?ldoookJP05oookJP04o`3Qool0oagoU?l0o`3o
D`Gooo]Z01;oo`1ioookJ_oonf[oo`1AoookJ_l06Ooo403ooookJ_nDo`3o1P3ooookJ_l0j?oo0?m=
o`0`ool0ok3oP_l0o`3oFolao`09oookJP05ob3o0?lV0?ooolT0oookJ_oJo`000ooob@001ooo09?o
olT0o`3ioooobP3ooo]Zoa80ool0oa/01?oonfX01Omho`3oiOl0onGo0?oUo`3o02[o00;oiOl00_oo
DP02onGo00Kooo]Z2?oob@0DoookJP;oo`3Z4_oob@0MoookJP03o`1coooonf[ooo]Z00gooo]Z00Go
^Ol0oomB0?oonf[ooo]Zo`0Zo`03oookJP05ocoo0?l0g?oo?@3oogSo0?l0oml01ooonfX01?l0S_oo
0?lKoookJ_oonfX5onGo0003o`3ioooo09?oo`0C00Gooo]Z00?of_l0oookJ_oUo`001?oonfX00olV
0?oo8?l0oookJP0AoookJP03oc7o0?l0oe_ooo]Z00;ooo]Z00OoP_l0o`3o/?l0<?oooo]Zo`3oCOl0
j?oooo]Z00SoA?l000?o403oo`0IoooonfX01?oonfX01_lE0?ooo`1AoookJ_l0[Ooooo]Zool0N@Wo
oo]Z00?o0?mCoookJ_oonfX0COoonfX00olH0?ooo`H0oookJP02oookJP03on_o0?oonf[oo`3f00;o
oo]Z00?o0:KooookJ_nX0?l00ooonfX00ooo0?Wooo]Zo`1go`02oookJP04oom/0?l0oi[o0?o<oon1
00;ooo]Z00Go>ol0oookJ_oonf[ooo]Zo`3ko`03oookJP03ool30?oonf[ooo]Z00;ooo]Z00Goo`3M
oookJ_nco`3o01Oooil0o`05oookJP03o`3og_oo08Oooo]Z00;ooo]Z00Ooo`1/oookJ_oonf[oC@3o
ool^0?mQ0?oo0?m500Cooo]Z00GohP3ooookJ_oonf[ooo]Zo`3oTP06oookJP03ofP0oooonf[ooo]Z
00?ooo]Z00?o603oonKo0?oonfX00_oonfX00oooT03ooo]ZoookJP08oookJP04oonn0?l0o`Gooo]Z
on/0o`Gooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP05oookJP03oon10?oonf[o
oo]Z00Kooo]Z00Go0=Coo`04oooonf[o0:Woo`28o`03oookJP03o`3o;_l0odko0?ld00Gooo]Z00Go
0>7oo`3o7Ooonf[o0?l8o`3oD`04oookJP04ool0NOoonf[ooo]Zool0D@;ooo]Z00co01Wooa00oooo
nf[oT_l0o`H0ool0j?oo0?m=o`3o/Ol0ok3oP_l0o`3oFolao`09oookJP06ob3o0?lV0?oooo]Zon7o
0?oonf[of_l00_oonfX01ooo01?oo`2Co`3ioooonf[oolX0oa80ool0oa/01?oonfX01omho`3o0?oO
o`3Looloo`3o0000o`0Zool000000_ooDP0;oookJP;o07?o5ooonfX<ool0jRGooo]Z00?o07?ooook
J_oonfX03OoonfX00onio`3ooo]ZoomB0002oookJP08o`0Zoooonf[ooo]ZoookJ_loo`3o0=coocd0
oomho`08oookJP04o`3o6olB0?oooo]Zooo:00Cooo]Z00?o0?Woool0Tooo01<01_oonfX00ooJo`3o
oo]Zon7o0003oookJP03obH0oolPo`3ooo]Z017ooo]Z00?o<Ol0o`3oFooonfX00ooonfX01On2o`3o
033ooookJ_oonf[o0?m=00?ooo]Z00?o1P3ooookJ_nBo`000ooonfX00ol@0?oo01Woool0JP04oook
JP04oaD0oooo057ooo]Zo`2]o`;ooo]Z00?oo`1ioookJ_oonfX01ooonfX00ol0oe?ooo]ZoookJP0S
oookJP00;?oonfX00olH0?oooo]Zool60003oookJP03on_o0?oo0?Kooo]Z00;ooo]Z00?oU?l0ojP0
oooonfX00_oonfX03?nDo`3ooo]ZoookJ_l0Mooooo]Zoom/0?nDo`3o0?o<oookJ_ooP@3ooo]Zoc_o
00?ooo]Z00?o0?_ooookJ_oonfX00_oonfX02?oo0`3ooo]ZoookJ_oonf[oo`3MoookJ_nco`3oW`3o
1OoonfX00ol0omkoo`27oookJP02oookJP09ool0K?oonf[ooo]ZoookJ_m=0?ooobh0of40oooonf[o
0?m500?ooo]Z00GoiOl0o`3oT?oonf[ooo]ZodCo0007oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go
603oo`1doooVo`3ooo]Zoon@000;oookJP04oonn0?oonf[o0?l5on/0o`Gooo]Z00?ooeL0oookJ_oo
nfX00ooonfX00ooo02gooo]ZoookJP06oookJP03oon10?oonf[ooo]Z00Cooo]Z00?o0=CooookJ_l0
1?l00_oonfX01ol0ZOoooo]ZoookJ_oonf[oA?l0o`3o;_l0oc@01_oonfX00ol0oagoU?l0o`3oD`05
oookJP0Bool0NOoonf[ooo]Zool0DOoonf[o01Wooa00oooo06[ooo]ZoiCo0?l60?oo0>Soo`3oCOl0
<?oo0?n`oh;o0?l0oe_o<Ol02OoonfX01OlPo`3o9P3oooo90?oob@3of_l000?oolT000Ooo`2Cooo9
0?l0nOooolX0oookJ_lB0?oo0?lK00Cooo]Z00GoN?l0onGo0?oUo`3oiOl0o`0Zo`02onGo0004oomB
0?oUo`3oiOl0onGo00Oooo]Z1ooob@0@oookJPGoo`3Z1OoonfX@ooo90003ool0j_oonf[ooo]Z01[o
oo]Z00?o07?ooookJ_oonfX03?oonfX00onio`3ooo]ZoomB0002oookJP08o`0Zoooonf[ooo]Zoook
J_loo`3o0=coocd0oomho`08oookJP03o`2>ool0oa_ooo]Z00KoiOl000?ooo]Zool0Tooo01<01Ooo
nfX00ooJo`3oiOl0oookJP03oookJP03obH0oolPo`3ooo]Z017ooo]Z00?o<Ol0oookJ_l0oe/00_oo
nfX00on2o`3ooo]Zo`3o/002oookJP03o`3oCOoonf[ooo]Z00OoA?l000?o403oo`0IoooonfX01?oo
nfX01_lE0?ooo`1AoookJ_oonf[o0:goool0N@Wooo]Z00?o0?mCoookJ_oonfX0C?oonfX00olH0?oo
oo]Zool60003oookJP03on_o0?oonf[oo`3f00;ooo]Z00?o0:KoojP0oooonfX00ooonfX00ooo0?Wo
oo]Zo`1go`02oookJP06oom/0?oonf[o0?o<oon10?oonf[o>ol01?oonfX01Ol0nooooo]ZoookJ_oo
nf[oo`<000?ooo]Z00Goo`3MoookJ_l0Xooo/ol0oil0o`05oookJP03o`3og_oo08Oooo]Z00;ooo]Z
00Soo`1/oookJ_oonf[ooo]Zodd0oooo;P3oH@3oo`3oA@Cooo]Z00CohP3ooookJ_oonf[o0?nB1ooo
nfX00omX0?oooo]ZoookJP02oookJP03oaP0ool0M?ooi_l000;ooo]Z00?ooi00oookJ_oonfX02Ooo
nfX01?oo_P3o0?l5on/0oom`0?l4oookJP03oomG0?oonf[ooo]Z00Cooo]Z00?oo`0]oookJ_oonfX0
1OoonfX00oooP@3ooo]ZoookJP05oookJP06o`3Doooonf[o00CooookJ_l0ZOoo08So0ooonfX00ol0
odko0?ldoookJP05oookJP04o`3o7Ooonf[o0?l8o`3oD`Cooo]Z00Coo`1ioookJ_oonf[oo`1A0_oo
nfX03?l06Ooo403ooookJ_nBo`3o1P3oo`3Xool0odgo0?nao`3o/?n2o`3o0?mKoc7o00Wooo]Z00Ko
8?l0obH0oooonf[ooo]Zon7o0?oJo`02oookJP07ool04ooo09?o0?WooookJ_oobP3o4P3oo`3o6`04
oookJP04ogSo0?l0omoo?ol0ocoo00;o02[o00?o0000oomB0?l000002_oonfX2o`1coaGooo]Z1?oo
0>X<oookJP[oo`3Z7?oonfX00ol0Looooo]ZoookJP0<oookJP04okWo0?oonf[ooo]ZoomB00;ooo]Z
00So02[ooookJ_oonf[ooo]Zocoo0?lm0?oooo]ZogSo00Oooo]Z00Co08koo`3o6olB0?ooolX01Ooo
nfX00ol0nOooo`2Cool04`06oookJP03om[o0?oQo`3ooo]Z00;ooo]Z00?o9P3oob3o0?oonfX04Ooo
nfX00olao`3ooo]Zo`3oF`03oookJP06oh;o0?l0ok3o033ooookJ_l0j?oo0?m=0_oonfX01?l60?oo
oo]Zool0mOnBo`02oookJP03oa00ool0GOoo01Wo00Cooo]Z00Oo5@3ooookJ_oo057ooo]Zo`2]oooo
nf[oo`1i00Wooo]Z00?o0?mCoookJ_oonfX08ooonfX002cooo]Z00?o603oool60?oonfX00ooonfX0
0oo[o`3oo`3foookJP02oookJP03oiCo0?nX0?oooo]Z00;ooo]Z00?oU?l0oookJ_l0Mol00_oonfX0
1_ooK03oU?l0o`3oc?ooP@3ooo]Zoc_o00Cooo]Z00?o0?_ooookJ_oonfX00_oonfX02?oo0`3ooo]Z
oookJ_oonf[oo`3MoookJ_nco`3oW`3o1OoonfX00ol0omkoo`27oookJP02oookJP08ool0K?oonf[o
oo]ZoookJ_m=0?ooobh0of40ool0odD4oookJP05onGo0?l0oi3ooo]ZoookJ_m4o`001_oonfX00omX
0?oooo]ZoookJP03oookJP05oaP0oooVo`3ooo]ZoookJ_ooT0002_oonfX01Ooo_P3ooo]ZoookJ_o[
0?ooL03o00Gooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP05oookJP03oon10?oo
nf[ooo]Z00Gooo]Z00Ko0=Coo`04oooonf[ooo]Zo`2Yool0R?l3oookJP03odCo0?l0ocCooo]Z00Go
oo]Z00Co0>7oo`3o7Ooonf[o0?mC1?oonfX01?oo07WoolT0oookJ_oo0542oookJP0=oa00oooo06[o
oo]ZoiCo0?l60?oo0>Soo`3oCOl0<?oo0?n`oh;o0?l0oe_ooo]Zoc7o0008oookJP05ob3o0?lV0?oo
olT0ooo90?oJo`000ooob@001ooo09?oolT0ooo90?oonf[oolX0oa80ool0oa/00ooonfX00ol0omoo
N?l0o`3o3002onGo0004o`0ZoooUo`3oiOl0oomB00CoiOl01OoonfX2ooo90003oookJ_oob@3oolT0
00?oolT03OoonfX4ool0jP[ooo]Z3Ooob@04oookJP?oo`3Z6_oonfX00ol0Looooo]ZoookJP0<oook
JP03okWo0?oonf[ooe8000;ooo]Z00So02[ooookJ_oonf[ooo]Zocoo0?l0g?oo?@3oogSo00Sooo]Z
00?o0?lKonGo0?oUo`001OoUo`000ol0nOoooo]Zool0T`06oookJP03om[o0?oonf[ooo]Z00?ooo]Z
00?o9P3ooookJ_oonfX04OoonfX00olao`3o0?mKoookJP02oookJP05oh;o0?l0ok3o033ooookJ_l0
odd00ooonfX6odCo0003oa00oooo06[o01Wo00Cooo]Z00Oo5@3ooookJ_oo057ooo]Zo`2]oooonf[o
o`1i00Sooo]Z00?o0?mCoookJ_oonfX0C?oonfX00olH0?ooo`H0oookJP03oookJP03on_o0?oo0?Ko
oo]Z00;ooo]Z00?o0:KoojP0oooonfX00ooonfX00ooo0?Wo07OooookJP02oookJP06oom/0?oonf[o
0?o<oon10?oonf[o>ol01?oonfX01Ol0nooooo]ZoookJ_oonf[oo`<000?ooo]Z00Goo`3MoookJ_nc
o`3o01Oooil0o`05oookJP03o`3og_oo08Oooo]Z00;ooo]Z00Ooo`1/oookJ_oonf[oC@3ooookJ_oo
;P3oH@3o00Gooo]Z00CohP3ooookJ_oonf[o0?nB1_oonfX00omX0?oooo]ZoookJP03oookJP03oaP0
ool0M?ooi_l000;ooo]Z00?ooi00oookJ_oonfX02?oonfX01?oo_P3ooo]Zo`3o1Oo[0?l5oookJP03
oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP06oookJP05
o`3Dool01?oooo]Zo`2Yool0R?l00ooonfX00ol0obko0?m>o`3o=005oookJP04o`3Qool0oago0?l8
o`3oD`Cooo]Z00Coo`1io`2]oooonf[oo`1A0ooonfX03?l@0?oooo]Zoi;o0?oonf[o0>SooookJ_l0
odgo0?n`oh;o0?l0oe_ooo]Zoc7o00Sooo]Z00Ko8?l0obH0oooonf[ooo]Zon7o0?oJo`02oookJP03
ool04ooo09?o0?Wo00;ooo]Z00?oolX0o`3o6ooonfX00ooonfX02?l0omooN?l0ocoo0?oonf[o02[o
oookJ_l0oc?ooe800_l00008oookJP;o07?o4_oonfX5ool0jQ[ooo]Z0ooo0>XJoookJP03o`1coooo
nf[ooo]Z00cooo]Z00Ko^Ol0oookJ_oonf[ooe80oookJ_l0:_l4oookJP04ocoo0?lm0?oooo]ZogSo
00Oooo]Z00Co0?lKoookJ_lB0?ooolX01?oonfX01?l0nOoooo]Zool0Tooo01<6oookJP03om[o0?oo
nf[ooo]Z00;ooo]Z00?o9P3ooookJ_oonfX04OoonfX00olao`3o0?mKoookJP03oookJP05oh;o0?l0
<?oooo]Zo`3Xool0odd00ooonfX00ol60?oooo]Zoi;o0002oookJP03oa00oooonf[o01Wo00Cooo]Z
00Go5@3ooookJ_oo057ooo]Zo`2]o`02oookJP03ool0NOoonf[ooo]Z00Kooo]Z00?o0?mCoookJ_oo
nfX08ooonfX002cooo]Z00?o603oool60?oonfX00_oonfX00oo[o`3oo`3foookJP02oookJP03oiCo
0?oonf[oZ03o00?ooo]Z00?oU?l0oookJ_l0Mol00_oonfX01_ooK03oU?l0o`3oc?ooP@3ooo]Zoc_o
00Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30004oookJP04ool0gOoonf[o/ol0oil0o`Gooo]Z00?o
0?oNool0QooonfX00_oonfX02?oo06cooo]ZoookJ_m=0?ooobh0oookJ_mQ0?oo0?m50ooonfX01OoU
o`3o0?n@oookJ_oonf[oA?l000Oooo]Z00?oJ03ooookJ_oonfX00ooonfX01OlH0?ooi_l0oookJ_oo
nf[ooi0000[ooo]Z00Cookh0oookJ_l0o`Goj`3o1OoonfX00oooE`3ooo]ZoookJP03oookJP03ool0
;Ooonf[ooo]Z00Kooo]Z00?ooh40oookJ_oonfX01?oonfX01_l0e?oooo]Zo`04oooonf[o0:Woo`28
o`?ooo]Z00?oA?l0o`3o=?oonfX01_oonfX00ol0oagoU?l0o`3oD`04oookJP0Cooo90?oo07WoolT0
ool0DOlE0?oooo]Zo`3oGOoo06[ooo]ZoiCo0?l60?oooo]Zo`3oCOl0<?oo0?n`oh;o0?l0oe_ooo]Z
oc7o0009oookJP04ob3o0?lV0?ooolT0om[o00?oolT000Ooo`2Cooo90?oob@3ooo]Zooo:0?oonf[o
0?lK00?ooo]Z00?o0?oOogSo0?l0g?l00_oonfX01?l0:_ooiOl0oomB0?ooDP04onGo00Cooo]Z0_oo
b@04oookJP?oolT02OoonfX5ool0jPkooo]Z2?oob@0<oookJP?oo`3Z6?oonfX00ol0Looooo]Zoook
JP0<oookJP05okWo0?ooDP3o0?lcoookJ_l0:_l01?oonfX01?loo`3o0=coo`3ogomho`06oookJP;o
iOl000?o0?lKonGo0?oUo`001?oUo`001?l0nOoooo]ZoookJ_oo09<5oookJP03om[o0?oUo`3ooo]Z
00?ooo]Z00?o9P3oob3o0?oonfX04OoonfX00olao`3o0?mKoookJP02oookJP03oh;o0?l0ok3o033o
00;ooo]Z00?o0?m=oookJ_oonfX01_m4o`000ooonf[o403oo`0Io`05oookJP06oaD0oooo057ooo]Z
o`2]oooonf[oo`1i2OoonfX00ol0oe?ooo]ZoookJP1;oookJP03oaP0oooo1P3ooo]Z00;ooo]Z00?o
jol0oookJ_oo0?H00_oonfX00ol0Y_oooo]ZojP0o`03oookJP03ool0nOoonf[o07Oo00;ooo]Z00Ko
of`0o`3oV_l0olcooh40oookJ_lko`04oookJP05o`3koooonf[ooo]ZoookJ_oo0`001?oonfX01Ooo
0=gooo]Zok?o0?l05oooW`3o00Gooo]Z00Go0?oNool0Qooonf[ooo]Zool0K003oookJP04odd0oooo
;P3oH@3oo`3oA@Cooo]Z00CohP3ooookJ_oonf[o0?nB1ooonfX00omX0?oooo]ZoookJP03oookJP05
oaP0oooVo`3ooo]ZoookJ_ooT0002ooonfX01?oo_P3o0?l5on/0oom`0?l4oookJP03oomG0?oonf[o
oo]Z00Cooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP05oookJP06o`3Doooonf[o
00Coo`2Yoooonf[o08So0_oonfX00ol0obko0?m>o`3o=006oookJP04o`3o7Ooonf[o0?l8o`3oD`Co
oo]Z00Coo`1ioookJ_oo057o5@3o0_oonfX03?l@0?ooo`1Zool0mOnBo`3o1P3oo`3Xool0odgo0?n`
oh;o0?l0oe_ooo]Zoc7o00Wooo]Z00Go8?l0obH0oooonf[ohOl0om[o0002oookJP03ool04ooo09?o
0?Wo00;ooo]Z00?oolX0o`3o6ooonfX00ooonfX02?l0omooN?l0o`3Loooonf[o02[ooookJ_l0oc?o
oe800ol00006oookJP;o07?o4?oonfX4ool0jR;ooo]Z0ooo0>XHoookJP03o`1coooonf[ooo]Z00co
oo]Z00Ko^Ol0oookJ_ooDP3o0?lcoookJ_l0:_l4oookJP04ocoo0?lm0?oo0?oOogSo00Oooo]Z00Co
0?lKoa80oooonf[oolX01?oonfX00ol0nOoooo]Zool0T`06oookJP03om[o0?oQo`3ooo]Z00;ooo]Z
00?o9P3oob3o0?oonfX04OoonfX00olao`3o0?mKoookJP03oookJP06oh;o0?oonf[o033ooookJ_l0
j?oo0?m=0_oonfX01?l60?oooo]Zool0mOnBo`02oookJP03oa00ool06Ooooo]Z00Cooo]Z00Oo5@3o
ool0DOoonf[ooo]Zo`2]oooonf[oo`1i00Wooo]Z00?o0?mCoookJ_oonfX08_oonfX002_ooo]Z00?o
603oool60?oonfX00ooonfX00oo[o`3oo`3foookJP02oookJP03oiCo0?nX0?oooo]Z00;ooo]Z00_o
U?l0oookJ_oonf[o07OooookJ_ooK03oU?l0o`3oc?oonf[ooh40oc_o0004oookJP03o`3koooonf[o
oo]Z00;ooo]Z00Goo`<0oookJ_oonf[ooo]Zool0g@02oookJP03ok?o0?oonf[ooo]Z00?ooo]Z00?o
0?oNool0QooonfX00_oonfX02?oo06cooo]ZoookJ_oonf[oC@3oool^0?mQ0?oo0?m51?oonfX01OoU
o`3o0?n@oookJ_oonf[o0?nB00Oooo]Z00?oJ03ooookJ_oonfX00_oonfX01OlH0?ooi_l0oookJ_oo
nf[ooi0000[ooo]Z00Gookh0oookJ_oonf[oj`3oog00o`05oookJP03oomG0?oonf[ooo]Z00?ooo]Z
00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP05oookJP06o`3Dool01?oooo]ZoookJ_l0
ZOoo08So0_oonfX00om4o`3o0?l^o`3o=006oookJP03o`3Qool0oago0?mC00Cooo]Z00KoolT0ool0
NOoob@3ooo]Zool0DOoonfX2o`3oG@0;oookJ_oo0?GoU?l0o`H0ool0j?oo0?m=o`0`ool0ok3o0?mK
oookJ_lao`002OoonfX01OlPo`3o9P3oooo90?oob@3of_l000;oolT000Soo`2Cooo90?oob@3oolT0
ooo:0?oonf[o0?lKo`2>o`;ooo]Z00Co0?oOogSo0?l0g?oooo]Z0_l0:_l00ooUo`3ooe80onGo0004
onGo00?ooo]Z00?o07?oooo90?oonfX01_oonfX00ooob@3ooo]ZoookJP05oookJP?oo`3Z4OoonfX0
0ooo5P3ooi80ooo90002ooo900Cooi803ooonfX00ooob@3oo`3Zool0jP0GoookJP;o07?o3?oonfX0
1_nio`3ooo]ZoomB0?l0oc?ooo]Zo`0Zo`?ooo]Z00Co?ol0oookJ_lm0?ooN?l02?oonfX00ol0oa_o
iOl0onGo0005onGo0003o`3ioooonf[oo`2C00Kooo]Z00?of_l0oookJ_oonfX00_oonfX00olV0?oo
8?l0oookJP0AoookJP03oc7o0?l0oe_ooo]Z00?ooo]Z00GoP_l0o`3o/?l0ok7ooo]Zo`3oC@03oook
JPGoA?l000?ooo]Zoa00ool06Ol01OoonfX01_lE0?ooo`1AoookJ_oonf[o0:goool0N@Wooo]Z00?o
0?mCoookJ_oonfX0B_oonfX00olH0?ooo`H0oookJP03oookJP03on_o0?oonf[oo`3f00;ooo]Z00?o
0:KoojP0oooonfX00ooonfX00ooo0?Wooo]Zo`1go`02oookJP06oom/0?oonf[o0?o<oon10?oonf[o
>ol01?oonfX01Ol0nooooo]ZoookJ_oonf[oo`<000?ooo]Z00Goo`3MoookJ_oonf[o/ol0oil0o`05
oookJP03o`3og_oo08Oooo]Z00;ooo]Z00Ooo`1/oookJ_oonf[oC@3ooookJ_oo;P3oH@3o00Gooo]Z
00CohP3ooookJ_oonf[o0?nB1ooonfX00omX0?oooo]ZoookJP02oookJP03oaP0ool0M?ooi_l000;o
oo]Z00?ooi00oookJ_oonfX02?oonfX01?oo_P3ooo]Zo`3o1Oo[0?l5oookJP03oomG0?oonf[ooo]Z
00?ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP06oookJP05o`3Dool01?oooo]Z
o`2Yool0R?l00ooonfX00ol0odko0?ldoookJP05oookJP04o`3Qool0oago0?l8o`3oD`Cooo]Z00Co
o`1io`2]oooonf[oo`1A0_oonfX03?l06Ooo403ooookJ_nBo`3o1P3oo`3Xool0odgo033oo`3o/?l0
oe_ooo]Zoc7o00Wooo]Z00Go8?l0obH0oooonf[ohOl0om[o0002oookJP03ool04ooo09?o0?Wo00;o
oo]Z00?oolX0o`3o6ol0S_l00ooonfX01_l0omooN?l0o`3Loooonf[o02[ooookJP;ooe801?l00004
oookJP;o07?o3ooonfX3ool0jQ3ooo]Z00?ooaH0oonB0?ooTP001_ooTP0@oookJP?oo`3Z5_oonfX2
o`1co`gooo]Z00Ko^Ol0oookJ_ooDP3o0?lcoookJ_l0:_l3oookJP04ocoo0?oonf[o?@3oogSo00Oo
oo]Z00Co0?lKoookJ_lB0?ooolX01?oonfX01?l0nOoooo]Zool0Tooo01<6oookJP06om[o0?oonf[o
oo]ZoookJ_lV0?oo8?l04_oonfX00olao`3ooo]Zo`3oF`04oookJP05oh;o0?l0<?oooo]Zo`3Xool0
odd00_oonfX01?l60?oooo]ZoookJ_nBo`02oookJP03oa00ool06Oooo`1Z00Cooo]Z00Oo5@3oool0
DOoonf[ooo]Zo`2]oooonf[oo`1i00Wooo]Z00?o0?mCoookJ_oonfX08_oonfX002_ooo]Z00?o603o
ool60?oonfX00ooonfX00oo[o`3oo`3foookJP02oookJP03oiCo0?nX0?oooo]Z00;ooo]Z00?oU?l0
oookJ_l0Mol00_oonfX01_ooK03oU?l0o`3oc?ooP@3ooo]Zoc_o00Cooo]Z00Go0?_ooookJ_oonf[o
oo]Zool30004oookJP04ool0gOoonf[o/ol0oil0o`Gooo]Z00?o0?oNool0QooonfX00_oonfX02?oo
06cooo]ZoookJ_oonf[oC@3ooookJ_mQ0?oo0?m50ooonfX00ooUo`3ooo]Zo`3oT002oookJP03o`3o
T_oonf[ooo]Z00Cooo]Z00?oJ03ooookJ_oonfX00ooonfX01OlH0?ooi_l0oookJ_oonf[ooi0000[o
oo]Z00Cookh0oookJ_l0o`Goj`3o1OoonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z
00Kooo]Z00?ooh40oookJ_oonfX01?oonfX01_l0e?oooo]Zo`04oooonf[o0:Woo`28o`?ooo]Z00?o
A?l0o`3o=?oonfX01OoonfX00ol0hOoo0?lMo`3oD`04oookJP06ooo90?oo07WoolT0ooo90?oo057o
oo]Z0ol0oed02?oonf[oU?l0o`H0ool0j?oo0?m=o`0`ool0ok3o0?mK0_oonfX00olao`3ooo]Zoook
JP05oookJP03ooo90?lPo`3o9P3o00;oolT000Gof_l0ooo90?oob@3oolT0ool0T`02ooo90004ooo:
0?oonf[o0?lKo`2>o`;ooo]Z00Ko0?oOogSo0?l0g?oo?ol0o`0ZoooonfX2oomB00GoiOl000Co0000
oookJ_oonf[o07?o3ooonfX2ool0jP_ooo]Z00?ooaH0oonB0?ooTP001oooTP08oookJPGooi800ooo
5P07oookJP?oolT00ooo0>XFoookJP03o`1coooonf[ooo]Z00[ooo]Z00?o^Ol0oookJ_ooDP000_oo
nfX02?l0:_oooo]ZoookJ_oonf[o?ol0o`3Loolm0?ooN?l01ooonfX00ol0S_oo0?lKonGo0005onGo
0004o`3ioooonf[ooo]Zool0T`Gooo]Z00?of_l0onGo0?oonfX00ooonfX00olV0?oooo]ZoookJP0A
oookJP03oc7o0?l0oe_ooo]Z00;ooo]Z00KoP_l0o`3o/?l0<?oooo]Zo`3Xool0odd2oookJP03o`H0
oom4o`3oA?l000;oA?l000?ooo]Zoa00ool06Ol01OoonfX01olE0?ooo`1AoookJ_oonf[o0:gooook
J_oo07T02?oonfX00ol0oe?ooo]ZoookJP1:oookJP03oaP0oooo1P3ooo]Z00?ooo]Z00?ojol0ool0
m_oonfX00_oonfX00ol0Y_ooZ03ooookJP03oookJP03ool0nOl0Mooooo]Z00;ooo]Z00Koof`0oook
J_l0olcooh40oookJ_lko`04oookJP04o`3koooonf[ooo]Zool300Cooo]Z00Goo`3MoookJ_nco`3o
01Oooil0o`05oookJP03o`3og_oo08Oooo]Z00;ooo]Z00Ooo`1/oookJ_oonf[oC@3oool^0?oonf[o
H@3o00Cooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP03ofP0oooonf[ooo]Z00?ooo]Z00?o
603oonKo0?oonfX00_oonfX00oooT03ooo]ZoookJP08oookJP04oonn0?l0o`Goj`3oog00o`Cooo]Z
00?ooeL0oookJ_oonfX01?oonfX00ooo02gooo]ZoookJP05oookJP03oon10?oonf[ooo]Z00Gooo]Z
00Ko0=CooookJ_l01?oo0:WooookJ_l0R?l2oookJP03o`3o;_l0odko0?ld00Gooo]Z00Co0>7oo`3o
7Ol0o`So0?mC1OoonfX00ooo07Wooo]Zool0D@02oookJP0:o`1Mool@0?oooo]Zoi;o0?l60?oo0>So
oookJ_l0odgo0?n`o`3oF`;ooo]Z00?o<Ol0oookJ_oonfX01_oonfX01OlPo`3o9P3ooookJ_oQo`3o
f_l000;ooo]Z00?oo`0CoookJ_oo09<00_oonfX00ooobP3o0?lKo`2>o`03oookJP09o`3ogomho`3o
0=coocoo0?l0:_oo0?lcoomB0?nio`3ooo]Z00Co00000ooonfX00ol0Looooo]ZoookJP0=oookJP;o
o`3Z2_oonfX00ooo5P3ooi80oonB0007oonB00Sooo]Z1_ooTP03oolF00[ooo]Z0ooo0>XEoookJP03
o`1coooonf[ooo]Z00[ooo]Z00Ko^Ol0oookJ_oonf[ooe80oookJ_l0:_l4oookJP04ocoo0?l0g?oo
0?oOogSo00Oooo]Z00Co0?lKoookJ_lB0?ooolX01?oonfX01?l0nOoooo]Zool0Tooo01<5oookJP03
om[o0?oonf[ooo]Z00;ooo]Z00?o9P3oob3o0?oonfX04OoonfX00olao`3o0?mKoookJP03oookJP06
oh;o0?l0<?oooo]Zo`3Xoooonf[o0?m=0_oonfX02?l60?oooo]Zool0mOnBo`3ooo]Zoa00oooonf[o
01Wo1?oonfX01OlE0?ooo`1AoookJ_oonf[o0:go00;ooo]Z00?oo`1ioookJ_oonfX01_oonfX00ol0
oe?ooo]ZoookJP0RoookJP00:ooonfX00olH0?ooo`H0oookJP02oookJP03on_o0?oo0?Kooo]Z00?o
oo]Z00GoU?l0ojP0oooonf[ooo]ZoiCo0002oookJP09o`1goooonf[ooo]Zoom/0?nDo`3o0?o<oon1
0?oonf[o>ol000Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30003oookJP04ogT0oooo0=gooo]Zok?o
00Gooo]Z00?o0?oNoiCo0?oo08L00ooonfX01ooo06cooo]ZoookJ_m=0?ooobh0oookJ_mQ0?l01?oo
nfX01OoUo`3o0?n@oookJ_oonf[o0?nB00Oooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?ooi_l0
oookJP02oookJP03oon@0?oonf[ooo]Z00Sooo]Z00Cookh0oookJ_l0o`Goj`3o1OoonfX00oooE`3o
oo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX01OoonfX01_l0e?oo
00CooookJ_oonf[o0:Woo`28o`;ooo]Z00?oA?l0o`3o;_l0oc@01_oonfX00ol0hOoo0?lMo`3oD`03
oookJP;oolT000Coo`1iooo90?oo057o5@3o0ol0oed02ooonf[oU?l0o`H0oooonf[o0?m=o`0`ool0
ok3oP_l0o`3oFooonf[o<Ol000Oooo]Z00?oolT0ob3o0?lV0?l00_oob@001OoJo`3oolT0ooo90?oo
b@3oo`2C00;oolT000CoolX0oookJ_l0oa_o08ko0_oonfX02_l0omooN?l0o`3Looloo`3o02[oonGo
0?ooDP3ooo]ZokWo0?oonfX3onGo00;o000000?ooo]Zo`1coooonfX03OoonfX2ool0jPOooo]Z0_oo
5P05oonB00Gooo]Z1ooo0?`:oookJPGooi8000CooaH0ooo90?oob@3ooo]Z1Ooob@02oookJP?oo`3Z
5?oonfX00ol0Looooo]ZoookJP0:oookJP05okWo0?ooDP3o0?lcoookJ_l0:_l00ooonfX01?loo`3o
oo]Zo`3Loomho`08oookJP03o`2>ool0oa_oiOl000CoiOl000Gooo]Zo`3ioooonf[oo`2Cool04`05
oookJP03om[o0?oonf[ooo]Z00;ooo]Z00?o9P3oob3o0?oonfX04OoonfX00olao`3o0?mKoookJP03
oookJP05oh;o0?l0<?oooo]ZoookJ_l0odd00ooonfX01?l60?ooA?l0odCo0?m4o`02oookJP03oa00
ool06Ooooo]Z00?ooo]Z00?o5@3oool0DOoonfX00_oonfX00ol0[Oooo`1ioookJP1DoookJP03oaP0
oooo1P3ooo]Z00;ooo]Z00?ojol0oookJ_oo0?H00ooonfX00ol0Y_ooZ03ooookJP02oookJP03ool0
nOoonf[o07Oo00?ooo]Z00Goof`0oookJ_ooP@3ooo]Zoc_o0004oookJP05o`3koooonf[ooo]Zoook
J_oo0`000ooonfX01Omi0?ooo`3MoookJ_nco`3oW`3o00Gooo]Z00?o0?oNoookJ_oo08L00_oonfX0
1ooo06cooo]ZoookJ_oonf[oC@3oool^0?mQ0?l01OoonfX01?oR0?oooo]ZoookJ_l0oi87oookJP03
ofP0oooonf[ooo]Z00;ooo]Z00?o603oo`1doooVo`000_oonfX00oooT03ooo]ZoookJP09oookJP03
oonn0?l0o`Goj`3o00Gooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP05oookJP03
oon10?oonf[ooo]Z00Kooo]Z00Go0=Coo`04oooonf[o0:Woo`28o`03oookJP03o`3oC_l0ocCooo]Z
00Gooo]Z00Co0>7oo`3o7Ol0o`So0?mC1?oonfX04_oo07Wo0:goool0DOlE0?oooo]Zo`1Mool06Ooo
403ooi;o0?oonf[o1P3oo`3Xool0odgo0?n`oh;o0?l0oe_ooo]Zoc7o00Sooo]Z00Go8?l0obH0oooo
nf[ohOl0om[o0002oookJP03ool04ooonf[oo`2C00;ooo]Z00?oolX0o`3o6ol0S_l00_oonfX02Olm
0?oo0?oOogSo0?l0g?oo?ol0o`0Zool0oc?ooe80okWo0002oookJPCo00000_oonfX00ol0Looooo]Z
oookJP0<oookJP;oo`3Z1ooonfX00ooo5P3ooi80oonB0003oonB00Gooo]Z1ooo0?`;oookJPGooi80
0ooo5P08oookJP?oo`3Z4ooonfX00ol0Looooo]ZoookJP0:oookJP06okWo0?oonf[ooe80o`3o<ooo
nf[o02[o0ooonfX01?loo`3ooo]Zocd0oomho`08oookJP04o`3o6ooonf[o4P3oooo:00?ooo]Z00Co
0?WooookJ_oo09?oo`0C1_oonfX01_oJo`3ooo]ZoookJ_oonf[o9P3oob3o01;ooo]Z00?o<Ol0o`3o
FooonfX00ooonfX01_l0ok3oP_l0o`0`oooonf[o0>Soo`3oC@;ooo]Z00Co1P3ooookJ_oonf[oT_l0
0_oonfX00ol@0?oo01WooookJP03oookJP03oaD0oooonf[oo`1A00;ooo]Z00?o0:gooookJ_oo07T0
;OoonfX002[ooo]Z00?o603oool60?oonfX00ooonfX00oo[o`3oo`3foookJP02oookJP03oiCo0?oo
nf[oZ03o00;ooo]Z00_oU?l0oookJ_oonf[o07OooookJ_ooK03oU?l0oookJ_l0olcooh40oc_o0004
oookJP05o`3koooonf[ooo]ZoookJ_oo0`001?oonfX01?oo0=gooo]ZoookJ_nco`05oookJP03o`3o
g_nDo`3oo`2700;ooo]Z00Soo`1/oookJ_oonf[ooo]Zodd0oooo;P3oH@3oo`3oA@Cooo]Z00GoiOl0
o`3oT?oonf[ooo]Zo`3oTP07oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603oonKo0?oonf[ooo]Z
oon@000:oookJP04oonn0?oonf[ooo]Zon/0o`Gooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02go
oo]ZoookJP06oookJP03oon10?oonf[ooo]Z00Cooo]Z00Ko0=CooookJ_l01?oooo]Zo`2Yool0R?l2
oookJP03odCo0?l0obko0?ld00Kooo]Z00?o0>7oo`3o7Ol0oe<00ooonfX2ooo90004ool0NOoob@3o
olT0ool0D@Co0?mM00[oU?l0o`H0oooonf[o0>Soo`3oCOoonf[oP_l0o`3oFooonf[o<Ol01ooonfX2
ooo90004ob3o0?lV0?ooolT0om[o00?oolT000Ooo`2Cooo90?oob@3oolX0oookJ_l0oa_o08ko00;o
oo]Z00Oo?@3oogSo0?l0g?oo?ol0o`0ZoooUo`3ooe8000;o^Ol00ooonfX01OoUo`3o0000o`000?l0
003o07?o00gooo]Z0_oo0>X7oookJP04oolF0?ooTP3ooi80oonB00Kooo]Z1?oo0?`7oookJPSoo`3l
0_oob@05oookJP;ooi802?oob@04oookJP;oo`3Z4ooonfX00ol0Looooo]ZoookJP0:oookJP05okWo
0?ooDP3ooo]ZoookJ_l0:_l00ooonfX01?loo`3o0=coocd0oomho`08oookJP03o`3o6ooUo`3oiOl0
00CoiOl000Cooo]Zo`3ioooo09?oo`0C1OoonfX00ooJo`3ooo]ZoookJP02oookJP03obH0oolPo`3o
oo]Z017ooo]Z00?o<Ol0o`3oFooonfX00ooonfX01_n2o`3o033oo`3o/Ooonf[o0>Soo`3oC@;ooo]Z
00?o1P3oodCo0?m4o`000_m4o`000ooonf[o403oo`0Io`05oookJP06oaD0oooo057ooo]ZoookJ_l0
[Oooo`1iE?oonfX00olH0?ooo`H0oookJP03oookJP03on_o0?oonf[oo`3f00;ooo]Z00?o0:Kooook
J_nX0?l00ooonfX00ooo0?Wooo]Zo`1go`02oookJP06oom/0?oonf[o0?o<oon10?oonf[o>ol01?oo
nfX01?l0nooooo]ZoookJ_oo0`04oookJP05ool0gOoonf[ooo]Zok?o0?nO0?l01OoonfX00ol0omko
o`27oookJP02oookJP07ool0K?oonf[ooo]Zodd0oooonf[oobh0of40o`04oookJP05on80ool0oi3o
oo]ZoookJ_l0oi801ooonfX00omX0?oooo]ZoookJP02oookJP03oaP0oooVo`3ooo]Z00;ooo]Z00?o
oi00oookJ_oonfX02?oonfX01?oo_P3ooo]Zon/0oom`0?l4oookJP03oomG0?oonf[ooo]Z00Cooo]Z
00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP05oookJP06o`3Doooonf[o00Coo`2Yoooo
nf[o08So0_oonfX00ol0odkooo]Zo`3o=005oookJP04o`3Qool0oago0?l8o`3oD`Cooo]Z00Coo`1i
o`2]oooonf[oo`1A0_oonfX03?l06Ooo403oool0mOnBo`3o1P3oo`3Xool0odgo033ooh;o0?l0oe_o
oo]Zoc7o00Wooo]Z00Co8?l0obH0oooonf[of_l00_oonfX00ooo01?ooo]Zool0T`02oookJP03ooo:
0?l0oa_o08ko00;ooo]Z00Co?@3ooookJ_mho`3o0=co0_l0:_l2oomB0004okWo0?oonf[ooo]Zoook
JPCo00000_l0Lol=oookJP;oo`3Z1_oonfX01?oo5P3ooi80oonB0?ooTP06oookJPCoo`3l1ooonfX8
ool0o0Sooo]Z1?ooTP000ooo5P3ooo]ZoookJP07oookJP;oo`3Z4_oonfX00ol0Looooo]ZoookJP0:
oookJP03okWo0?oonf[ooe8000;ooo]Z00So02[ooookJ_oonf[ooo]Zocoo0?l0g?oo?@3oogSo00Oo
oo]Z00Co0?lKoookJ_lB0?ooolX01?oonfX01?l0nOooo`2CoookJ_oo01<5oookJP06om[o0?oonf[o
oo]ZoookJ_lV0?oo8?l04_oonfX00olao`3ooo]Zo`3oF`03oookJP09o`3o/?n2o`3o033ooookJ_l0
j?oooo]Zo`3oCOoonf[o1P3o00;ooo]Z00KoT_l0oookJ_oonf[o403oo`0Iool0GOl4oookJP07oaD0
oooo057ooo]ZoookJ_l0[Ooooo]Zool0N@0]oookJP00:_oonfX00olH0?ooo`H0oookJP03oookJP03
on_o0?oo0?Kooo]Z00;ooo]Z00?oU?l0ojP0oooonfX00_oonfX00onDo`3ooo]Zo`1go`02oookJP06
oom/0?nDo`3o0?o<oon10?oonf[o>ol01?oonfX01Ol0nooooo]ZoookJ_oonf[oo`<000Cooo]Z00Co
o`3MoookJ_nco`3oW`3o1OoonfX00ol0omkoo`27oookJP02oookJP08ool0K?oonf[ooo]Zodd0oooo
;P3ooo]Zof40ool0odD3oookJP03onGo0?oonf[o0?n@00;ooo]Z00?o0?nBoookJ_oonfX01?oonfX0
0omX0?oooo]ZoookJP03oookJP05oaP0oooVo`3ooo]ZoookJ_ooT0002_oonfX01?oo_P3ooo]Zo`3o
1Oo[0?l5oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]Z
oookJP05oookJP05o`3Dool01?oooo]Zo`2Yool0R?l00ooonfX00om4o`3ooo]Zo`3o=006oookJP03
o`3Qool0oago0?mC00;ooo]Z0_oob@001?oo07WoolT0ooo90?oo0545o`3oG@07oiCo0?l60?oooo]Z
o`3oCOl0ok7o0?n`o`3oF`02oookJP03oc7o0?oonf[ooo]Z00Cooo]Z0_oob@001?lPo`3o9P3oooo9
0?oJo`03ooo90007ool0Tooob@3oolT0ooo:0?oob@3o0?lKo`2>o`02oookJP05ocd0oomho`3o0=co
ocoo0?l0:_l00_ooDP000onio`3ooo]ZoookJP03oookJP;o00000_l0Lol<oookJP;oo`3Z1_oonfX2
oolF00;ooi801?oonfX5ool0o0oooo]Z0_l0o``2oookJPGoo`3l1OoonfX8ooo900Gooo]Z00?oo`3Z
oookJ_oonfX04OoonfX00ol0Looooo]ZoookJP09oookJP03okWo0?oonf[ooe8000;ooo]Z00So02[o
oookJ_oonf[o?ol0oookJ_l0g?ooN?l0o`3og`Oooo]Z00?o08koo`3o6ooUo`001?oUo`001Ooonf[o
0?WooookJ_oo09?oo`0C00Gooo]Z00?of_l0oookJ_oonfX00_oonfX00olV0?ooQ03ooookJP0@oook
JP03oc7o0?oonf[o0?mK00?ooo]Z00Ko0?n`onGo0?l0<?oooo]Zo`3Xool0odd2oookJP03o`H0oooo
nf[oA?l000;oA?l00_oonfX00ol@0?oooo]ZoookJP03oookJP07oaD0oooo057ooo]ZoookJ_l0[Ooo
oo]Zool0N@1CoookJP03oaP0oooo1P3ooo]Z00?ooo]Z00?ojol0ool0m_oonfX00_oonfX00ol0Y_oo
Z03ooookJP03oookJP03ool0nOl0Mooooo]Z00;ooo]Z00?oof`0oookJ_ooP@000_oonfX00olko`3o
oo]ZoookJP02oookJP04o`3koooonf[ooo]Zool300Cooo]Z00Goo`3MoookJ_l0Xooo/ol0oil0o`04
oookJP03omgo0?l0omkoo`2700?ooo]Z00Ooo`1/oookJ_oonf[oC@3oool^0?oonf[oH@3o00Cooo]Z
00GohP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP03ofP0oooonf[ooo]Z00?ooo]Z00?o603oonKo0?oo
nfX00_oonfX00oooT03ooo]ZoookJP08oookJP03oonn0?l0o`Goj`3o00Gooo]Z00?ooeL0oookJ_oo
nfX00ooonfX00ooo02gooo]ZoookJP05oookJP03oon10?oonf[ooo]Z00Kooo]Z00Go0=Coo`04ool0
ZOoooo]Zo`28o`02oookJP03o`3o;_l0odko0?ld00Kooo]Z00Co0>7oo`3o7Ooonf[o0?mC1?oonfX0
4_oo07Wooo]Zool0DOlE0?oooo]Zo`1Mool@0?ooo`3eoi;o0?l60?oooo]Zo`3oCOl0<?oo0?n`oh;o
0?l0oe_ooo]Zoc7o00Sooo]Z00Co8?l0obH0oooonf[of_l00ooonfX01ooo01?oo`2CoookJ_oonf[o
olX0o`3o6ol0S_l00_oonfX02?lm0?oooo]ZogSo0?l0g?oo02[ooookJ_ooDP3o^Ol01OoonfX3o`00
0003o`1coooonf[ooo]Z00_ooo]Z0_oo0>X6oookJP03oolF0?ooTP3ooi8000Cooo]Z1Ooo0?`Coook
JPGoo`3l1ooonfX2oonB0003oolF0?oonf[ooo]Z00Oooo]Z00?oo`3ZoookJ_oonfX04?oonfX00ol0
Looooo]ZoookJP0:oookJP05okWo0?oonf[ooe80oookJ_l0:_l00ooonfX01?loo`3ooo]Zo`3Loomh
o`08oookJP04o`3o6ooonf[o4P3oooo:00Cooo]Z00Co0?Woool0Tooonf[oo`0C1OoonfX01_oJo`3o
oo]ZoookJ_oonf[o9P3oob3o017ooo]Z00?o<Ol0oookJ_l0oe/00ooonfX02Ol0ok3ooo]Zoh;o0?l0
ok7o0>SooookJ_l0odgooo]Zo`H0o`02oookJP06ool0mOnBo`3ooo]ZoookJ_l@0?oo01Wo1?oonfX0
1OlE0?ooo`1AoookJ_oonf[o0:go00;ooo]Z00?oo`1ioookJ_oonfX0:_oonfX002_ooo]Z00Koo`H0
oookJ_oonf[ooo]Zon_o0?oo0?H4oookJP05oiCo0?nX0?oooo]ZoookJ_nDo`000_oonfX02?l0Mooo
oo]ZoookJ_ooK03oU?l0o`3oc?ooP@3o>ol01OoonfX01Ol0nooooo]ZoookJ_oonf[oo`<000?ooo]Z
00CoN@3oool0gOoonf[o/ol01OoonfX00ol0omkoU?l0ool0Q`03oookJP07ool0K?oonf[ooo]Zodd0
oooo;P3ooo]Zof40o`04oookJP05onGo0?l0oi3ooo]ZoookJ_l0oi801ooonfX00omX0?oooo]Zoook
JP02oookJP03oaP0oooVo`3ooo]Z00;ooo]Z00?ooi00oookJ_oonfX01ooonfX01?oo_P3ooo]Zoook
J_o[0?l5oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01_oonfX00oooP@3ooo]Z
oookJP04oookJP06o`3Dool01?oooo]ZoookJ_l0ZOoo08So0_oonfX00om4o`3o0?l^o`3o=006oook
JP03o`3Qool0oago0?mC00;ooo]Z0ooob@000ooo07WoolT0ool0D@05o`3oG@0:oiCo0?l60?oooo]Z
o`3oCOl0<?oo0?n`oh;o0?l0oe_ooo]Zoc7o00Kooo]Z0_oob@001?lPo`3o9P3oooo90?oJo`03ooo9
0007ool0Tooob@3oolT0ooo90?oobP3o0?lKo`2>o`02oookJP08ocd0oomho`3o0=coocoo0?l0:_oo
oe80oookJ_nio`06oookJP04o`000?l0Looo0000o`0000_ooo]Z00?oo`3ZoookJ_oonfX01?oonfX0
1?oo5P3ooi80oonB0?ooTP02oookJPCoo`3l2OoonfX;oaP0o`Co0?l<1Ooob@02ool0o0?ooo]Z2_oo
b@04oookJP03ool0j_oonf[ooo]Z017ooo]Z00?o07?ooookJ_oonfX02OoonfX00onio`3ooe80o`3o
<`02oookJP07o`0Zoooonf[ooo]Zocoo0?l0g?oooo]ZogSo0008oookJP03o`3o6olB0?ooiOl000?o
iOl00_oonfX00ol0nOooo`2Cool04`05oookJP03onGo0?oJo`3ooo]Z00;ooo]Z00?o9P3oob3o0?oo
nfX04OoonfX00olao`3o0?mKoookJP03oookJP05onGo0?l0<?oo0?naoookJ_l0odd00_oonfX00ol6
0?oooo]ZoookJP02odCo00;ooo]Z00?o403oo`1MoooonfX00ooonfX00olE0?ooo`1AoookJP02oook
JP03o`2]oooo07Wooo]Z05?ooo]Z00Ooo`H0oookJ_oonf[ooo]Zon_o0?oonf[oo`3f00?ooo]Z00?o
0:KoojP0oooonfX00_oonfX00ooo0?Wooo]Zo`1go`03oookJP05oom/0?oonf[ooh40oookJ_lko`00
1?oonfX01Ol0nooooo]ZoookJ_oonf[oo`<000?ooo]Z00GoN@3oool0gOoonf[o/ol0oil0o`05oook
JP03o`3og_oonf[oo`2700;ooo]Z00Ooo`1/oookJ_oonf[ooo]Zodd0oooo;P3oH@3o00Gooo]Z00Co
hP3ooookJ_oonf[o0?nB1ooonfX00omX0?oooo]ZoookJP02oookJP03oaP0oooVo`3ooo]Z00;ooo]Z
00?ooi00oookJ_oonfX02?oonfX01?oo_P3ooo]Zon/0oom`0?l4oookJP03oomG0?oonf[ooo]Z00Co
oo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP05oookJP05o`3Dool01?oooo]Zo`2Y
ool0R?l00ooonfX00ol0odkooo]Zo`3o=005oookJP04o`3Qool0oago0?l8o`3oD`Cooo]Z00Coo`1i
o`2]oooo057o5@3o0_oonfX03?l06Ooo403ooi;o0?oonf[o1P3oo`3Xool0odgo0?n`oh;o0?l0oe_o
oo]Zoc7o00Sooo]Z00Co8?l0obH0oooonf[of_l00ooonfX01ooo01?oo`2CoookJ_oonf[oolX0o`3o
6ol0S_l00_oonfX02?lm0?oooo]ZogSo0?l0g?oo02[ooookJ_ooDP3o^Ol01_oonfX2o`000003o`1c
ool0003ooo]Z00_ooo]Z00?oo`3ZoookJ_oonfX00ooonfX01?oo5P3ooi80oonB0?ooTP02oookJPCo
o`3l2_oonfX;oaP0o`Sooo]Z0_oo0?`7oookJP03oonB0?oo5P3ooaH000Sooo]Z00?oo`3ZoookJ_oo
nfX04?oonfX00ol0Looooo]ZoookJP09oookJP06okWo0?oonf[ooe80o`3o<ooonf[o02[o0ooonfX0
1?loo`3o0=cooookJ_mho`07oookJP04o`3o6ol0S_oo4P3oooo:00Cooo]Z00Co0?Woool0Tooonf[o
o`0C1OoonfX01_oQo`3of_l0oookJ_oonf[o9P3oob3o01;ooo]Z00?o<Ol0o`3oFooonfX00ooonfX0
2?l0ok3oP_l0o`0`oooonf[o0>Soo`3oCOoonf[o1P3o0_oonfX01ooo0?GoT_l0oookJ_oonf[o403o
o`0Iool0GOl00ooonfX00olE0?ooo`1AoookJP02oookJP03o`2]oooonf[oo`1i02cooo]Z000Zoook
JP03ool60?oonf[ooo]Z00;ooo]Z00?ojol0ool0m_oonfX00_oonfX00onDo`3ooo]ZojP0o`02oook
JP04oiCo0?oonf[ooo]Zo`1go`;ooo]Z00Goof`0oookJ_l0olcooh40oc_o0004oookJP05o`3koooo
nf[ooo]ZoookJ_oo0`001?oonfX01?oo0=gooo]ZoookJ_nco`05oookJP03o`3og_nDo`3oo`2700;o
oo]Z00Soo`1/oookJ_oonf[ooo]Zodd0oooonf[oH@3oo`3oA@?ooo]Z00?oiOl0oookJ_l0oi000_oo
nfX00ol0oi;ooo]ZoookJP05oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603oonKo0?oonf[ooo]Z
oon@000:oookJP04oonn0?oonf[o0?l5on/0o`Gooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02go
oo]ZoookJP05oookJP03oon10?oonf[ooo]Z00Cooo]Z00Ko0=CooookJ_l01?oooo]Zo`2Yool0R?l3
oookJP03odCo0?oonf[o0?ld00Gooo]Z00Go0>7ooiCo0?l0oago0?mCoookJP03ooo90003ool0NOoo
b@3oo`1A00Go0?mM00[oU?l0o`H0oooonf[o0>Soo`3oCOoonf[oP_l0o`3oFooonf[o<Ol01_oonfX2
ooo90004ob3o0?lV0?ooolT0om[o00CoolT000Koo`2CoookJ_oob@3oolX0o`3o6ol0S_l2oookJP08
ocd0oomho`3o0=coocoo0?l0:_oooe80o`3o<onio`07oookJP04o`1cool0003o0000o`0000Wooo]Z
0_oo0>X5oookJP03oolF0?ooTP3ooi8000;ooo]Z0ooo0?`3oookJPGo603o4_oo1P08ooo90004oook
J_oo0?coo`3loookJP_oolT01?oonfX00ooo0>[ooo]ZoookJP0AoookJP03o`1coooonf[ooo]Z00Wo
oo]Z00Go^Ol0oomB0?oonf[ooo]Zo`0Zo`02oookJP05ocoo0?oonf[o0=coogSo0?l0oml02?oonfX0
0ol0oa_ooo]ZonGo0003onGo0005oookJ_l0nOooo`2CoookJ_oo01<01OoonfX00ooJo`3ooo]Zoook
JP02oookJP03obH0oon40?oooo]Z013ooo]Z00?o<Ol0o`3oFooonfX00ooonfX01OoUo`3ooo]Zo`0`
oooonf[o0?m=00;ooo]Z00Go1P3ooookJ_oonf[ooo]ZodCo0002oookJP03oa00ool06Ooooo]Z00?o
oo]Z00?o5@3oool0DOoonfX00_oonfX00ol0[Oooo`1ioookJP1BoookJP03ool60?oonf[ooo]Z00;o
oo]Z00?ojol0oookJ_oo0?H00_oonfX00ol0Y_oooo]ZojP0o`03oookJP03ool0nOoonf[o07Oo00;o
oo]Z00Koof`0oookJ_l0olcooh40oookJ_lko`04oookJP04o`3koooonf[ooo]Zool300Cooo]Z00Go
o`3MoookJ_oonf[o/ol0oil0o`05oookJP03o`3og_oonf[oo`2700;ooo]Z00Ooo`1/oookJ_oonf[o
C@3oool^0?oonf[oH@3o00Cooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP07oookJP03ofP0oooonf[o
oo]Z00;ooo]Z00?o603oonKo0?oonfX00_oonfX00oooT03ooo]ZoookJP08oookJP04oonn0?l0o`Go
j`3oog00o`Cooo]Z00?ooeL0oookJ_oonfX01?oonfX00ooo02gooo]ZoookJP04oookJP03oon10?oo
nf[ooo]Z00Gooo]Z00Ko0=CooookJ_l01?oo0:WooookJ_l0R?l2oookJP03o`3o;_l0odko0?ld00Go
oo]Z00Go0>7ooookJ_l0oagooo]Zo`3oD`04oookJP03ool0NOoo057o5@3o00;ooo]Z00co05gooa00
oonBo`3ooo]Zo`H0ool0j?oo0?m=o`0`oon2o`3o0?mKoookJ_lao`08oookJP04ob3o0?lV0?oooo]Z
om[o00?ooo]Z00Ooo`0Co`3ioooo09?ooo]Zooo:0?l0oa_o08ko00;ooo]Z00So?@3ooookJ_mho`3o
0=coo`0Zoooonf[ooe80o`3o<`Oooo]Z0_l0Lol2o`0000[ooo]Z0_oo0>X4oookJP03oolF0?ooTP3o
oi8000;ooo]Z0ooo0?`3oookJPKo603o5?oo1P06oookJP?oo`3l1OoonfX2oonB0003oolF0?oonf[o
oo]Z00Kooo]Z00?oo`3ZoookJ_oonfX04?oonfX00ol0Looooo]ZoookJP09oookJP03okWo0?oonf[o
oe8000;ooo]Z00Oo02[ooookJ_oonf[o?ol0oookJ_l0g?ooN?l000Sooo]Z00Co0?lKoa80oooonf[o
olX01?oonfX01?l0nOooo`2CoookJ_oo01<4oookJP03on7o0?oJo`3ooo]Z00;ooo]Z00?o9P3oob3o
0?oonfX04?oonfX00olao`3ooo]Zo`3oF`03oookJP06o`3o/?n2o`3o033ooookJ_l0j?oo0?m=0_oo
nfX02Ol60?oooo]ZoookJ_oo0?GoT_l0oookJ_l@0?oo01Woo`1Mo`03oookJP03oaD0oooo057ooo]Z
00;ooo]Z00?o0:gooookJ_oo07T0;?oonfX002oooo]Z00?ojol0oookJ_oonfX00_oonfX00onDo`3o
oo]ZojP0o`02oookJP03oiCo0?oonf[o07Oo00;ooo]Z00Koof`0oiCo0?l0olcooh40oookJ_lko`04
oookJP05o`3koooonf[ooo]ZoookJ_oo0`001?oonfX01?oo0=gooo]Zo`2Soonco`05oookJP03o`3o
g_oo08Oooo]Z00;ooo]Z00Soo`1/oookJ_oonf[oC@3oool^0?oonf[oH@3oo`3oA@?ooo]Z00?oiOl0
oookJ_l0oi000_oonfX00ol0oi;ooo]ZoookJP04oookJP03ofP0oooonf[ooo]Z00?ooo]Z00Go603o
o`1doooonf[ooo]Zoon@0009oookJP04oonn0?oonf[ooo]Zon/0o`Gooo]Z00?ooeL0oookJ_oonfX0
1?oonfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Gooo]Z00Ko0=Coo`04oooonf[o
oo]Zo`2Yool0R?l2oookJP03odCo0?l0obko0?ld00Kooo]Z00Co0>7oo`3o7Ol0oe?ooo]Z1?oob@00
0ooo07WoolT0ool0D@05o`3oG@0:oi;o0?l60?oooo]Zo`3oCOl0<?ooP_l0oookJ_l0oe_ooo]Zoc7o
00Oooo]Z00Co8?l0obH0oooob@3of_l01?oob@001_oo09?ooo]ZoookJ_oobP3o0?lKo`2>o`;ooo]Z
00So?@3oogSo0?l0g?oo?ol0o`0ZooooDP3o0?lcokWo00Oooo]Z00?o07?oo`000?l000000_l00007
oookJP;oo`3Z1?oonfX2oolF00;ooi800_oonfX2ool0o0?ooo]Z0olH0?l00ooonf[oo`H0ool60002
ool600Kooo]Z2oo[o`02o`3o30WoolT000Cooo]Zool0o?oo0?coo`3l2_oob@04oookJP03ool0j_oo
nf[ooo]Z017ooo]Z00?o07?ooookJ_oonfX02?oonfX00onio`3ooe80o`3o<`02oookJP07o`0Zoooo
nf[ooo]Zocoo0?l0g?oooo]ZogSo0008oookJP03o`2>ool0oa_ooo]Z00?oiOl00_oonfX01?l0nOoo
o`2CoookJ_oUo`04oookJP03onGo0?oJo`3ooo]Z00;ooo]Z00?o9P3ooh@0oooonfX04?oonfX00ola
o`3ooo]Zo`3oF`03oookJP06o`3o/?oUo`3o033oo`3o/Ol0j?oo0?m=0_oonfX01?l60?oooo]Zoook
J_nBo`02oookJP03ool0J_l@0?oooo]Z00Cooo]Z00Ooo`1AoookJ_oonf[ooo]Zo`2]oooonf[oo`1i
05Oooo]Z00?ojol0ool0m_oonfX00_oonfX00ol0Y_oooo]ZojP0o`02oookJP03ool0nOoonf[o07Oo
00?ooo]Z00?oof`0oookJ_ooP@000_oonfX00olko`3ooo]ZoookJP02oookJP04o`3koooonf[ooo]Z
ool300Cooo]Z00Coo`3MoookJ_l0Xooo/ol01OoonfX00ooMo`3o0?oNool0Q`03oookJP07ool0K?oo
nf[ooo]Zodd0oooo;P3ooo]Zof40o`04oookJP05on80ool0oi3ooo]ZoookJ_l0oi801_oonfX00omX
0?oooo]ZoookJP03oookJP05oaP0ool0M?oooo]ZoookJ_ooT0002_oonfX01?oo_P3ooo]Zon/0oom`
0?l4oookJP03oomG0?oonf[ooo]Z00Cooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3ooo]Zoook
JP06oookJP05o`3Dool01?oooo]Zo`2Yool0R?l00ooonfX00ol0odko0?ldoookJP05oookJP04o`3Q
ool0oago0?l8o`3oD`Cooo]Z00Coo`1io`2]oooo057o5@3o0_oonfX03?l06Ooo403ooi;o0?l60?oo
oo]Zo`3oCOl0<?ooP_l0oookJ_l0oe_ooo]Zoc7o00Oooo]Z00Co8?l0obH0oooonf[of_l00ooonfX0
1ooo01?o0?Woool0Tooonf[oolX0o`3o6ol0S_l00_oonfX02?lm0?oooo]ZogSo0?l0g?oo02[ooook
J_ooDP3o0?lc1ooonfX00ol0Looo0000o`000002o`0000Sooo]Z0_oo0>X4oookJP03oolF0?ooTP3o
oi8000;ooo]Z0_oo0?`3oookJP?o603o0_oonfX4ool600Gooo]Z2oo[o`04oookJP?oo`H01_oonfX2
ool0o0Gooo]Z0_ooTP000ooo5P3ooo]ZoookJP05oookJP03ool0j_oonf[ooo]Z013ooo]Z00?o07?o
oookJ_oonfX02OoonfX01Onio`3ooe80o`3o<ooonf[o02[o00?ooo]Z00Co?ol0o`3Loooonf[oN?l0
2?oonfX01?l0oa_o4P3ooookJ_oobP03oookJP05o`3ioooo09?ooo]ZoookJ_oo01<01?oonfX01_oQ
o`3of_l0oookJ_oonf[o9P3oob3o017ooo]Z00?o<Ol0oookJ_l0oe/00ooonfX02Ol0ok3oP_l0oook
J_l0<?oo0>SooookJ_l0odgooo]Zo`H0o`02oookJP06ool0mOnBo`3ooo]ZoookJ_l@0?oo01Wo1?oo
nfX01OlE0?ooo`1AoookJ_oonf[o0:go00;ooo]Z00?oo`1ioookJ_oonfX0:OoonfX002kooo]Z00?o
jol0ool0m_oonfX00ooonfX01OnDo`3oZ03ooookJ_oonf[oU?l000;ooo]Z00So07OooookJ_oonf[o
of`0oiCo0?l0olcooh40oc_o00Gooo]Z00Co0?_ooookJ_oonf[oo`<01?oonfX01?mi0?ooo`3Moook
J_nco`06oookJP03o`3og_oo08Oooo]Z00;ooo]Z00Ooo`1/oookJ_oonf[oC@3oool^0?oonf[oH@3o
00?ooo]Z00?oiOl0oookJ_l0oi000_oonfX00ol0oi;ooo]ZoookJP05oookJP03ofP0oooonf[ooo]Z
00;ooo]Z00Go603oonKo0?oonf[ooo]Zoon@000:oookJP04oonn0?oonf[ooo]Zon/0o`Gooo]Z00?o
oeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP05oookJP03oon10?oonf[ooo]Z00Cooo]Z00Ko
0=CooookJ_l01?oooo]Zo`2Yool0R?l2oookJP03odCo0?l0obko0?ld00Kooo]Z00Co0>7oo`3o7Ooo
nf[o0?mC1?oob@000ooo07WoolT0ool0D@05o`3oG@0:oi;o0?l60?oooo]Zo`3oCOl0<?oo0?n`oh;o
0?l0oe_ooo]Zoc7o00Sooo]Z00?o8?l0obH0oooJo`001?oob@001_oo09?ooo]ZoookJ_oobP3o0?lK
o`2>o`?ooo]Z00OoN?l0o`3Looloo`3o02[ooookJ_ooDP3o^Ol000Oooo]Z00?o07?ooookJ_l00000
0ol00005oookJP;oo`3Z1?oonfX01Ooo5P3ooi80oonB0?ooTP3ooo]Z00?oo`3l0_oonfX3oaP0o`Co
o`H02_o[o`09ool0mP;o0?l<0_o[o`0=ooo900;oo`3l2Ooob@04oookJP03ool0j_oonf[ooo]Z013o
oo]Z00?o07?ooookJ_oonfX02OoonfX00onio`3ooe80oookJP02oookJP07o`0Zoooonf[o?ol0oook
J_l0g?ooN?l0o`3og`08oookJP03o`3o6ooonf[ooo]Z00;oiOl00_oonfX01?l0nOooo`2CoookJ_oU
o`04oookJP03onGo0?oJo`3ooo]Z00;ooo]Z00?o9P3oob3o0?n40?l04?oonfX00olao`3ooo]Zo`3o
F`03oookJP06o`3o/?oUo`3o033oo`3o/Ol0j?oo0?m=0_oonfX01?l60?oooo]ZoookJ_nBo`03oook
JP03oa00ool0GOoooo]Z00?ooo]Z00Ooo`1AoookJ_oonf[ooo]Zo`2]oooonf[oo`1i05Kooo]Z00?o
jol0oookJ_oo0?H00ooonfX00ol0Y_ooZ03ooookJP02oookJP03ool0nOoonf[o07Oo00?ooo]Z00Go
of`0oookJ_ooP@3ooo]Zoc_o0004oookJP04o`3koooonf[ooo]Zool300Cooo]Z00GoN@3oool0gOoo
nf[o0:?ook?o0005oookJP03omgo0?l0omkoo`2700;ooo]Z00Ooo`1/oookJ_oonf[ooo]Zodd0oooo
;P3oH@3o00Cooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP07oookJP03ofP0oooonf[ooo]Z00;ooo]Z
00?o603oonKo0?oonfX00_oonfX00oooT03ooo]ZoookJP08oookJP04oonn0?oonf[oj`3oog00o`Co
oo]Z00?ooeL0oookJ_oonfX01?oonfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Go
oo]Z00Ko0=CooookJ_l01?oo0:WooookJ_l0R?l2oookJP03o`3oC_oonf[o0?ld00Gooo]Z00Go0>7o
o`3o7Ol0o`Sooo]Zo`3oD`03oookJP04ool0NOl0[Oooo`1AoaD0o`;ooo]Z00co01Wooa00oonBo`3o
oo]Zo`H0ool0odgo0?nao`3o/?n2o`3o0?mKoookJ_lao`08oookJP04ob3o0?lV0?oof_l0on7o00;o
oo]Z00?oo`0Co`3ioooo09<00_oonfX00ol0oa_o08kooookJP02oookJP04ocd0oomho`3o0=coo`0Z
o`;ooo]Z00?ooe80oookJ_oonfX01OoonfX00ol0Looooo]Zo`000003o`0000Kooo]Z0_oo0>X3oook
JP05oolF0?ooTP3ooi80oonB0?oonfX00ooo0?`2oookJP?o603o00?ooo]Zool60?oo1P000_oo1P09
on_o00_oo`3f1?o[o`03oookJP;oo`H00_lH0?l4oookJP;oo`3l1OoonfX00oooTP3ooaH0oolF0006
oookJP03ool0j_oonf[ooo]Z00oooo]Z00?o07?ooookJ_oonfX02_oonfX01Onio`3ooe80oookJ_oo
nf[o02[o00;ooo]Z00Go?ol0o`3Loooonf[oN?l0ocd0o`07oookJP04o`3o6olB0?oooo]Zooo:00Co
oo]Z00Coo`2CoookJ_oonf[oo`0C1?oonfX01ooQo`3of_l0oookJ_oonf[o9P3oob3o0?n40?l04?oo
nfX00olao`3ooo]Zo`3oF`03oookJP09o`3o/?oonf[oP_l0o`0`ool0j?oooo]Zo`3oCOoonf[o1P3o
00;ooo]Z00Ooo`3eoi;o0?oonf[ooo]Zoa00ool06Ooo05go00?ooo]Z00Go5@3oool0DOoonf[ooo]Z
o`2]o`02oookJP03ool0NOoonf[ooo]Z02Wooo]Z000^oookJP03on_o0?oo0?Kooo]Z00?ooo]Z00Oo
U?l0ojP0oooonf[ooo]ZoiCo0?oonf[o07Oo00?ooo]Z00Goof`0oiCo0?ooP@3ooo]Zoc_o0005oook
JP04o`3koooonf[ooo]Zool300Cooo]Z00Coo`3MoookJ_oonf[o/ol01OoonfX00ol0omkogOl0ool0
Q`02oookJP08ool0K?oonf[ooo]Zodd0oooo;P3ooo]Zof40ool0odD3oookJP03on80oooonf[o0?n@
00;ooo]Z00?o0?nBoookJ_oonfX01OoonfX00omX0?oooo]ZoookJP02oookJP05oaP0ool0M?oooo]Z
oookJ_ooT0002OoonfX01?oo_P3ooo]ZoookJ_o[0?l5oookJP03oomG0?oonf[ooo]Z00Cooo]Z00?o
o`0]oookJ_oonfX01?oonfX00oooP@3ooo]ZoookJP05oookJP06o`3Dool01?oooo]ZoookJ_l0ZOoo
08So0_oonfX00ol0odkooo]Zo`3o=006oookJP03o`3Qool0oago0?mC00?ooo]Z00GoolT0ool0NOoo
b@3o0?mMool0D@05o`3oG@09oi;o0?oonf[o0?m=o`0`oooonf[oP_l0o`3oFooonf[o<Ol000Sooo]Z
00Co8?l0obH0oooJo`3ooo]Z0ooob@001_oo09?ooo]ZoookJ_oobP3o0?lKo`2>o`?ooo]Z00OoN?l0
o`3Looloo`3ooo]Zo`0ZooooDP3o^Ol000Kooo]Z0_l0Lol2oookJPCo00000ooonfX2ool0jPCooo]Z
00?ooaH0oonB0?ooTP000_oonfX2ool0o0;ooo]Z0_lH0?l4ool60004oookJ_o[o`3ojol0on_o00;o
o`3f0ooonfX7ojP0o`Go0:Ko0_oonfX3o`3o30coolT000Co603ooookJ_oob@3oolT00_oo0?`8ooo9
00Cooo]Z0_oo0>XAoookJP03o`1coooonf[ooo]Z00Wooo]Z00Go^Ol0oomB0?oonf[ooo]Zo`0Zo`02
oookJP05ocoo0?l0g?oooo]ZogSo0?l0oml01ooonfX01?l0S_oo0?lKoookJ_oonfX2onGo00;ooo]Z
00?oo`2CoookJ_oUo`001OoonfX00ooJo`3ooo]ZoookJP02oookJP03obH0oon40?oooo]Z013ooo]Z
00?o<Ol0o`3oFooonfX00ooonfX01OoUo`3ooo]Zo`0`oooonf[o0?m=00;ooo]Z00Co1P3ooookJ_oo
nf[oT_l00ooonfX00ol@0?oo01WooookJP03oookJP07oaD0oooo057ooo]ZoookJ_l0[Ooooo]Zool0
N@1FoookJP03on_o0?oonf[oo`3f00?ooo]Z00?o0:KoojP0oooonfX00_oonfX00ooo0?Wo07Oooook
JP03oookJP05oom/0?l0olcooh40oookJ_lko`001?oonfX01?l0nooooo]ZoookJ_oo0`04oookJP05
ool0gOoonf[ooo]Zok?o0?nO0?l01OoonfX00ol0omkooo]Zool0Q`02oookJP07ool0K?oonf[ooo]Z
odd0oooo;P3ooo]Zof40o`04oookJP05on80ool0oi3ooo]ZoookJ_l0oi801ooonfX00omX0?oooo]Z
oookJP02oookJP03oaP0ool0M?oooo]Z00;ooo]Z00?ooi00oookJ_oonfX01ooonfX01?oo_P3ooo]Z
o`3o1Oo[0?l4oookJP03oomG0?oonf[ooo]Z00Cooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3o
oo]ZoookJP06oookJP05o`3Dool01?oooo]Zo`2Yool0R?l00_oonfX00ol0obko0?m>o`3o=006oook
JP04o`3Qool0oagooo]Zo`3oD`Cooo]Z00?oo`1io`2]oooo05400_oonfX03?oo06[o403oool0mOnB
o`3o1P3oo`3Xool0odgo033ooh;o0?oonf[o0?mKoc7o00Sooo]Z00Co8?l0obH0oooJo`3ohOl00_oo
nfX00ooo01?o0?Woool0T`02oookJP03o`3o6ol0S_oooo]Z00;ooo]Z00Oo?@3oogSo0?l0g?oo?ol0
o`0Zoooonf[ooe8000Oooo]Z00?o07?ooookJ_oonfX01?l00004oookJP;oo`3Z0ooonfX00ooo5P3o
oi80oonB0002oookJP;oo`3l0_oonfX3oaP0o`Coo`H000Gooo]Zon_o0?o[o`3ojol0ool0mP03oook
JP03o`2VoonX0?ooZ03o00GoZ03o1Ol0Y_l4oookJP?oo`3f0oo[o`02oookJP?oo`H00_lH0?l3oook
JP?oo`3l0ooonfX2oonB00;ooaH01OoonfX00ooo0>[ooo]ZoookJP0?oookJP03o`1coooonf[ooo]Z
00Wooo]Z00?o^Ol0oookJ_ooDP000_oonfX02?l0:_oooo]ZoookJ_loo`3o0=cooookJ_mho`3o?@3o
1ooonfX01?l0oa_ooo]ZoookJ_oobP03oookJP04o`3ioooo09?ooo]Zool04`Cooo]Z00?ohOl0om[o
0?oonfX00_oonfX00olV0?oo8?l0oookJP0@oookJP03oc7o0?oonf[o0?mK00?ooo]Z00So0?n`oh;o
0?l0<?oo0?nao`3Xool0odgooo]Zo`H0o`;ooo]Z00Ooo`3eoi;o0?oonf[ooo]Zoa00ool06Ooo05go
00?ooo]Z00Go5@3oool0DOoonf[ooo]Zo`2]o`02oookJP03ool0NOoonf[ooo]Z02Wooo]Z000^oook
JP03on_o0?oonf[ooo]Z00;ooo]Z00?oU?l0oookJ_nX0?l00_oonfX00onDo`3ooo]Zo`1go`03oook
JP05oom/0?oonf[ooh40oookJ_lko`001?oonfX01Ol0nooooo]ZoookJ_oonf[oo`<000?ooo]Z00Go
N@3oool0gOoonf[o0:?ook?o0005oookJP03o`3og_oonf[oo`2700;ooo]Z00Soo`1/oookJ_oonf[o
C@3oool^0?oonf[oH@3oo`3oA@?ooo]Z00?ohP3ooookJ_l0oi000_oonfX00ol0oi;ooo]ZoookJP04
oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603oonKo0?oonfX00_oonfX00oooT03ooo]ZoookJP07
oookJP04oonn0?oonf[ooo]Zon/0o`Gooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]Zoook
JP05oookJP03oon10?oonf[ooo]Z00Cooo]Z00?o0=CooookJ_l01?l00_oonfX01_l0ZOoooo]Zoook
J_l0odko0?l^o`3o=0Kooo]Z00Co0>7oo`3o7Ooonf[o0?mC1?oonfX00ooo07Wo0?mMool0D@05o`3o
G@09oi;o0?l0oegooo]Zo`3oCOl0<?ooP_l0oookJ_l0oe_o<Ol000Sooo]Z00Co8?l0obH0oooonf[o
f_l00_oonfX01ooob@3oo`2Cooo90?oonf[oolX0o`3o6ol0S_l00ooonfX01omho`3o0=cooookJ_lo
o`3o02[ooomB0?nio`001_oonfX00ol0Looooo]ZoookJP02oookJPCo00000_oonfX00ooo0>[ooo]Z
oookJP03oookJP04oolF0?ooTP3ooo]ZoookJP;oo`3l00?ooo]ZoaP0oolH0?l00ooo1P02oookJP?o
jol01?l0Y_l4ojP0o`Oooo]Z2?nX0?l2o`2Vo`koolT01?oonfX2ool0o0OoolT01OoonfX00ooo0>[o
oo]ZoookJP0?oookJP03o`1coooonf[ooo]Z00Sooo]Z00?o^Ol0oomB0?oonfX00_oonfX01ol0:_oo
oo]Zocoo0?oonf[o0=coogSo0?l0oml02?oonfX01Ol0oa_ooo]ZoookJ_oonf[oiOl000;ooo]Z00Co
0?Woool0Tooonf[oiOl01?oonfX00ooUo`3of_l0oookJP02oookJP03obH0oolPo`3oQ03o013ooo]Z
00?o<Ol0o`3oFooonfX00ooonfX01OoUo`3ooo]Zo`0`ool0ok7o0?m=00;ooo]Z00Go1P3ooookJ_oo
nf[oo`3eoi;o0002oookJP03ool0J_l@0?oooo]Z00Cooo]Z00Ooo`1AoookJ_oonf[ooo]Zo`2]oooo
nf[oo`1i05Gooo]Z00?ojol0ool0m_oonfX00_oonfX00ol0Y_oooo]ZojP0o`02oookJP03ool0nOoo
nf[o07Oo00?ooo]Z00Goof`0oookJ_ooP@3ooo]Zoc_o0005oookJP04o`3koooonf[ooo]Zool300?o
oo]Z00GoN@3oool0gOoonf[o0:?ook?o0005oookJP03omgo0?l0omkoo`2700?ooo]Z00Ooo`1/oook
J_oonf[oC@3oool^0?oonf[oH@3o00Cooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP03ofP0
oooonf[ooo]Z00;ooo]Z00?o603oonKo0?oonfX00_oonfX00oooT03ooo]ZoookJP08oookJP04oonn
0?oonf[oj`3oog00o`Cooo]Z00?ooeL0oookJ_oonfX01?oonfX00ooo02gooo]ZoookJP04oookJP03
oon10?oonf[ooo]Z00Gooo]Z00Ko0=CooookJ_l01?oooo]Zo`2Yool0R?l2oookJP03o`3oC_oonf[o
0?ld00Gooo]Z00Go0>7oo`3o7Ol0o`Sooo]Zo`3oD`03oookJP04ool0NOl0[Oooo`1AoaD0o`;ooo]Z
00_o01Wooa00oonBo`3o1P3ooookJ_l0odgo0?naoh;o0?oonf[o0?mKoc7o0008oookJP04ob3o0?lV
0?oooo]Zom[o00;ooo]Z00?oo`0CoookJ_oo09<00_oonfX00ol0oa_o4P3oo`2>o`02oookJP07ocd0
oomho`3o0=coocoo0?l0:_oooo]ZoomB0006oookJP;o07?o0ooonfX4o`0000?ooo]Z00?oo`3Zoook
J_oonfX00_oonfX01?oo5P3ooi80oookJ_oonfX2ool0o004oookJ_lH0?oo603ooaP0o`?oo`H00_oo
nfX3on_o00Co0:Ko1?nX0?l7oookJPOoZ03o1Ol0Y_l00ooonf[oo`3fool0mP04on_o0004oookJ_oo
1P3oo`H0oaP0o`Gooo]Z0_oo0?`3oookJP;ooi8000?ooaH0oookJ_oonfX00ooonfX00ooo0>[ooo]Z
oookJP0?oookJP03o`1coooonf[ooo]Z00Wooo]Z00Go^Ol0oomB0?oonf[ooo]Zo`0Zo`02oookJP05
ocoo0?l0g?oooo]ZogSo0?l0oml01ooonfX01Ol0oa_o4P3ooookJ_oonf[oolX000?ooo]Z00Coo`2C
oookJ_oonf[oo`0C1?oonfX01ooQo`3of_l0oookJ_oonf[o9P3oob3o0?n40?l04?oonfX00olao`3o
oo]Zo`3oF`03oookJP06o`3o/?n2o`3ooo]Zo`0`ool0j?oo0?m=0_oonfX01Ol60?oooo]Zool0mOoo
nf[oT_l000;ooo]Z00?o403oo`1MoooonfX00ooonfX01Ooo057ooo]ZoookJ_oonf[o0:go00;ooo]Z
00?oo`1ioookJ_oonfX0:?oonfX002gooo]Z00?ojol0ool0m_oonfX00ooonfX01OnDo`3ooo]ZojP0
oooonf[oU?l000;ooo]Z00So07OooookJ_oonf[oof`0oiCo0?l0olcooh40oc_o00Gooo]Z00Co0?_o
oookJ_oonf[oo`<01?oonfX01?mi0?ooo`3MoookJ_nco`06oookJP03o`3og_oo08Oooo]Z00;ooo]Z
00Soo`1/oookJ_oonf[oC@3oool^0?oonf[oH@3oo`3oA@;ooo]Z00KohP3ooookJ_oonf[o0?n@oook
J_l0oi87oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603oonKo0?oonf[ooo]Zoon@000:oookJP03
oonn0?oonf[oj`3o00Gooo]Z00?ooeL0oookJ_oonfX01?oonfX00ooo02gooo]ZoookJP04oookJP03
oon10?oonf[ooo]Z00Gooo]Z00Ko0=Coo`04oooonf[ooo]Zo`2Yool0R?l2oookJP03o`3oC_oonf[o
0?ld00Gooo]Z00Co0>7oo`3o2?l0oago0?mC1?oonfX01?oo07Wooo]Zooo90?oo0544o`3oG@0:oi;o
0?l60?oo0?mMo`3oCOl0<?oo0?n`oh;o0?l0oe_ooo]Zoc7o00Oooo]Z00Co8?l0obH0oooonf[of_l0
0_oonfX00ooob@3oo`2Cooo90002oookJP03o`3o6ol0S_oooo]Z00;ooo]Z00OoN?l0o`3Loooonf[o
?ol0o`0ZooooDP3o^Ol000Kooo]Z00?o07?ooookJ_oonfX00ooonfX4o`000003oookJ_oo0>[ooo]Z
00?ooo]Z00?ooaH0oonB0?ooTP000ooo0?`3oaP0o`;oo`H00_oonfX3on_o00;o0:Ko0_oonfX2ojP0
o`;oo`3i0oooN@0?ool0n@GoZ03o0_l0Y_l:ooo90003oaP0oooonf[ooo]Z00;ooo]Z0_oo0?`4ooo9
0003oolF0?oonf[ooo]Z00Cooo]Z00?oo`3ZoookJ_oonfX03_oonfX00ol0Looooo]ZoookJP09oook
JP03okWo0?ooDP3ooo]Z00;ooo]Z00Oo02[ooookJ_loo`3o0=cooookJ_mho`3o0?oO00Oooo]Z00Go
4P3oo`3o6ooonf[ooo]Zooo:0003oookJP03ool0Tooonf[oiOl000Gooo]Z00Oof_l0oookJ_oUo`3o
iOl0obH0oolPo`3oQ03o013ooo]Z00?o<Ol0oookJ_l0oe/00ooonfX01OoUo`3ooo]Zo`0`ool0ok7o
0?m=00;ooo]Z00Go1P3ooookJ_oonf[oo`3eoi;o0002oookJP03ool0J_l@0?oooo]Z00Cooo]Z00Oo
o`1AoookJ_oonf[ooo]Zo`2]oooonf[oo`1i05Cooo]Z00?ojol0oookJ_oo0?H00ooonfX00ol0Y_oo
oo]ZojP0o`02oookJP03ool0nOoonf[o07Oo00?ooo]Z00Goof`0oookJ_ooP@3ooo]Zoc_o0004oook
JP04o`3koooonf[ooo]Zool300Cooo]Z00GoN@3oool0gOoonf[o0:?ook?o0005oookJP03omgo0?l0
omkoo`2700;ooo]Z00Soo`1/oookJ_oonf[oC@3ooookJ_oo;P3oH@3oo`3oA@?ooo]Z00?ohP3ooook
J_l0oi000_oonfX00ol0oi;ooo]ZoookJP04oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603oonKo
0?oonfX00_oonfX00oooT03ooo]ZoookJP08oookJP03oonn0?l0o`Goj`3o00Cooo]Z00?ooeL0oook
J_oonfX01?oonfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Kooo]Z00Go0=Coo`04
oooonf[o0:Woo`28o`02oookJP03o`3o;_l0odko0?ld00Gooo]Z00Go0>7ooookJ_l0oagooo]Zo`3o
D`04oookJP03ool0NOl0[Oooo`1A00;ooo]Z00co01Wooa00oonBo`3ooo]Zo`H0ool0odgo0?nao`3o
/?n2o`3o0?mKoookJ_lao`07oookJP04ob3o0?lV0?oooo]Zom[o00;ooo]Z00?oo`0CoookJ_oo09<0
0_oonfX00ol0oa_o4P3oo`2>o`02oookJP07ocd0oomho`3o0=coocoo0?l0:_oooo]ZoomB0006oook
JP03o`1coooonf[ooo]Z00?ooo]Z1?l00002oookJP05ool0j_oonf[ooo]ZoookJ_oo5P000_ooTP03
ool0o0?o603o00?ooo]Zool60?oo1P000_oonfX3on_o0004o`2Voooonf[ooo]ZoookJP;oZ03o4ooo
0?T5ojP0o`Go0:Ko0_oo0?H3on_o00?oo`H01OoonfX00ooo0?cooo]ZoookJP02oookJP03oonB0?oo
nf[ooo]Z00Cooo]Z00?oo`3ZoookJ_oonfX03_oonfX00ol0Looooo]ZoookJP0:oookJP05okWo0?oo
DP3ooo]ZoookJ_l0:_l00_oonfX01Oloo`3o0=cooookJ_mho`3o?@3o00Oooo]Z00Co0?lKo`2>oooo
nf[oolX00ooonfX01?oo09?ooo]ZoookJ_oo01<4oookJP07on7o0?oJo`3ooo]ZoookJ_lV0?oo8?l0
oh@0o`0@oookJP03oc7o0?oonf[o0?mK00?ooo]Z00Ko0?n`oh;o0?oonf[o033oo`3Xool0odd2oook
JP05o`H0oooonf[ooo]Zool0mOnBo`000_oonfX00ol@0?oo01WooookJP03oookJP05ool0DOoonf[o
oo]ZoookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP0XoookJP00;OoonfX00oo[o`3oo`3foookJP03
oookJP07oiCo0?nX0?oooo]ZoookJ_nDo`3ooo]Zo`1go`03oookJP05oom/0?nDo`3ooh40oookJ_lk
o`001OoonfX01?l0nooooo]ZoookJ_oo0`04oookJP04ogT0oooo0=go01Oook?o00Gooo]Z00?o0?oN
omgo0?oo08L00_oonfX02?oo06cooo]ZoookJ_m=0?ooobh0oookJ_mQ0?oo0?m50ooonfX00ooR0?oo
oo]Zo`3oT002oookJP03o`3oT_oonf[ooo]Z00Gooo]Z00?oJ03ooookJ_oonfX00_oonfX01OlH0?oo
07CooookJ_oonf[ooi0000Wooo]Z00Cookh0oookJ_oonf[oj`3o1OoonfX00oooE`3ooo]ZoookJP03
oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX01?oonfX00ol0e?oooo]Zo`04o`02
oookJP06o`2Yoooonf[ooo]Zo`3oC_l0obko0?ld1_oonfX01?l0hOoo0?lMoookJ_l0oe<3oookJP04
ool0NOoonf[oolT0ool0D@;ooo]Z00co01Woo`3oGOl0oegoT_l0o`3oGOl0odgooo]Zo`3o/?n2o`3o
0?mKoookJ_lao`08oookJP03ob3o0?lV0?oof_l000;ooo]Z00?oolT0oookJ_oo09<00_oonfX00ol0
oa_o08kooookJP02oookJP08ogSo0?l0omoooo]Zocoo0?l0:_oooe80oookJ_nio`05oookJP03o`1c
oooonf[ooo]Z00Cooo]Z1?l000001?oo0>[ooo]ZoookJ_oonfX2oolF0004oonB0?oo0?coo`3loook
JP;o603o00Cooo]Zool60?oo1P3ooo]Z0oo[o`02o`2Vo`03oookJ_nX0?ooZ03o00Coo`3i00?ooo]Z
o`1gooooN@001_ooN@0;o`1go`?oo`3i0_l0o``2ojP0o`;o0?l<0_l0Y_l3o`3o30CoolT000?oo`H0
oookJ_oonfX00ooonfX00ooo0?cooo]ZoookJP02ooo90003oolF0?oonf[ooo]Z00Cooo]Z00?oo`3Z
oookJ_oonfX03_oonfX00ol0Looooo]ZoookJP09oookJP03okWo0?ooDP3ooo]Z00;ooo]Z00Oo02[o
oookJ_loo`3o0=coogSo0?lm0?oo0?oO00Oooo]Z00Co0?lKoookJ_oonf[oolX00ooonfX00ooo09?o
0?WoonGo0004oookJP03onGo0?oJo`3oiOl000?oiOl000?o9P3ooookJ_n40?l03ooonfX00olao`3o
oo]Zo`3oF`03oookJP06o`3o/?oUo`3ooo]Zo`0`ool0ok7o0?m=0_oonfX01?l60?oooo]ZoookJ_nB
o`03oookJP03oa00oooonf[ooo]Z00?ooo]Z00Ooo`1AoookJ_oonf[ooo]Zo`2]oooonf[oo`1i05Co
oo]Z00?ojol0oookJ_oo0?H00ooonfX00ol0Y_ooZ03ooookJP02oookJP03ool0nOl0Mooooo]Z00?o
oo]Z00Goof`0oookJ_ooP@3ooo]Zoc_o0004oookJP04o`3koooonf[ooo]Zool300Cooo]Z00GoN@3o
ool0gOoonf[o/ol0oil0o`05oookJP03o`3og_oonf[oo`2700;ooo]Z00Ooo`1/oookJ_oonf[oC@3o
ool^0?oonf[oH@3o00Cooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP07oookJP03ofP0oooonf[ooo]Z
00;ooo]Z00?o603oo`1doooonfX00_oonfX00oooT03ooo]ZoookJP07oookJP04oonn0?oonf[oj`3o
og00o`Cooo]Z00?ooeL0oookJ_oonfX01?oonfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[o
oo]Z00Gooo]Z00Ko0=CooookJ_l01?oooo]Zo`2Yool0R?l2oookJP03o`3oC_l0ocCooo]Z00Gooo]Z
00Go0>7oo`3o7Ol0o`Sooo]Zo`3oD`03oookJP03ool0NOl0[Oooo`1A00;ooo]Z00coo`1Zo`0Iool@
0?ooT_l0o`H0ool0odgooo]Zo`3o/?n2o`3ooo]Zo`3oFolao`08oookJP03ob3o0?lV0?oof_l000;o
oo]Z00Soo`0CoookJ_l0nOooo`2CoookJ_l0oa_o4P3oo`2>o`;ooo]Z00So?@3oogSo0?l0g?oo?ol0
o`0Zoooonf[ooe80okWo00Gooo]Z00?o07?ooookJ_oonfX01?oonfX4o`0000;oo`3Z0ooonfX01?oo
5P3ooi80ool0o?oo0?`2oookJP03oaP0oooonf[ooo]Z00;oo`H000Gooo]Zon_o0?o[o`3ojol0o`2V
o`02oookJP;oZ03o1?oo0?T00ooonf[o07Ooo`1go`0@o`1go`?oo`3i0_oonfX3ojP0o`;ooo]Z00?o
0:KooookJ_oonfX00_oo0?H00oo[o`3ooo]ZoookJP02ool600Cooo]Z00?oo`3loookJ_oonfX00_oo
nfX00oooTP3ooo]ZoookJP04oookJP03ool0j_oonf[ooo]Z00kooo]Z00?o07?ooookJ_oonfX02_oo
nfX02onio`3ooe80oookJ_oonf[o02[ooookJ_loo`3o0=cooookJ_mho`3o0?oO00Oooo]Z00Co0?lK
o`2>oooonf[oolX01?oonfX00ooo09?ooo]Zool04`05oookJP07om[o0?oonf[ooo]ZoookJ_lV0?oo
8?l0oh@0o`0?oookJP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00Ko0?n`oh;o0?oonf[ooo]Zo`0`ool0
odd2oookJP05o`H0oooonf[ooo]Zool0mOnBo`000_oonfX00ol@0?oo01WooookJP03oookJP05oaD0
oooo057ooo]ZoookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP0XoookJP00;OoonfX00oo[o`3ooo]Z
oookJP02oookJP05oiCo0?oonf[oZ03ooookJ_nDo`000_oonfX02?l0Mooooo]ZoookJ_oonf[oof`0
oookJ_ooP@3o>ol01OoonfX01Ol0nooooo]ZoookJ_oonf[oo`<000?ooo]Z00GoN@3oool0gOoonf[o
0:?ook?o0005oookJP03o`3og_oMo`3oo`2700;ooo]Z00Soo`1/oookJ_oonf[oC@3oool^0?oonf[o
H@3oo`3oA@?ooo]Z00?ohP3ooookJ_l0oi000_oonfX00ol0oi;ooo]ZoookJP04oookJP03ofP0oooo
nf[ooo]Z00;ooo]Z00?o603oonKo0?oonfX00_oonfX00oooT03ooo]ZoookJP07oookJP04oonn0?oo
nf[o0?l5on/0o`Gooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP04oookJP03oon1
0?oonf[ooo]Z00Cooo]Z00?o0=CooookJ_l01?l00_oonfX01ol0ZOoo08SooookJ_oonf[o0?m>oook
J_l0oc@01OoonfX01?l0hOoo0?l8o`3o7Ol0oe<4oookJP0Aool0NOoob@3ooo]Zool0DOoonf[o01Wo
o`3oGOoonf[oT_l0oookJ_l0oego0?m=o`0`oon2o`3ooo]Zo`3oFolao`002?oonfX02?lPo`3o9P3o
ooo90?oJo`3ooo]Zooo90?oonf[oo`2C0_oonfX00ol0oa_o08kooookJP02oookJP08ogSo0?l0omoo
oo]Zocoo0?l0:_oooe80oookJ_nio`05oookJP03o`1coooonf[ooo]Z00Gooo]Z0_l00002ool0jP?o
oo]Z00CooaH0oonB0?oo0?coo`3l0_oonfX01?lH0?oooo]Zool60?oo1P02oomi0003on_o0?l0Y_oo
0:Ko00?oogT00ooo0?T00ooonf[o07Ooo`1go`02o`1go`03oookJ_ooN@3oogT000SoogT000?oof`0
o`3oV_l0oiX01OoonfX3o`1go`?oo`3i00?ooo]ZojP0oonX0?l00_oonfX00ol0Y_oooo]ZoookJP02
oookJP05on_o0?oonf[ooo]Zool60?lH0?l01?oonfX01_oo0?cooo]ZoookJ_ooTP3ooo]ZoolF00Ko
oo]Z00?oo`3ZoookJ_oonfX03OoonfX00ol0Looooo]ZoookJP0:oookJP0;oomB0?oonf[ooo]Zoook
J_l0:_oooo]Zocoo0?l0g?oooo]ZogSo0?l0oml01ooonfX01OlB0?oo0?lKoookJ_oonf[oolX000?o
oo]Z00Coo`2CoookJ_oUo`3ooo]Z1?oUo`001ooJo`3oiOl0onGo0?oUo`3o9P3oob3o0?n40?l04?oo
nfX00olao`3o0?mKoookJP03oookJP05onGo0?oonf[o033oo`3o/Ol0odd00_oonfX01?l60?oooo]Z
oookJ_nBo`03oookJP03ool0J_l@0?oooo]Z00?ooo]Z00Goo`1AoookJ_oonf[ooo]Zo`2]o`02oook
JP03ool0NOoonf[ooo]Z057ooo]Z00?ojol0ool0m_oonfX00_oonfX00ol0Y_oooo]ZojP0o`02oook
JP03ool0nOoonf[o07Oo00?ooo]Z00Go0?nJoom/0?ooP@3ooo]Zoc_o0005oookJP04o`3koooonf[o
oo]Zool300?ooo]Z00GoN@3oool0gOoonf[o0:?ook?o0006oookJP03o`3og_oo08Oooo]Z00;ooo]Z
00Ooo`1/oookJ_oonf[oC@3oool^0?oonf[oH@3o00Cooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP06
oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603oonKo0?oonfX00_oonfX00oooT03ooo]ZoookJP08
oookJP03oonn0?l0o`Goj`3o00Gooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP04
oookJP03oon10?oonf[ooo]Z00Gooo]Z00Ko0=CooookJ_l01?oooo]Zo`2Yool0R?l2oookJP03o`3o
;_l0odko0?ld00Gooo]Z00Go0>7ooookJ_l0oagooo]Zo`3oD`03oookJP04ool0NOl0[Ooooo]Zool0
D@;ooo]Z00_o01Wooa00oonBo`3o1P3ooookJ_l0odgo0?naoh;o0?oonf[o0?mKoc7o0008oookJP0=
ob3o0?lV0?oohOl0om[o0?oonf[oo`0CoookJ_l0nOooo`2CoookJ_l0oa_o4P3oo`2>o`03oookJP07
ogSo0?l0g?oo?ol0o`0Zoooonf[ooe80okWo0005oookJP03o`1coooonf[ooo]Z00Gooo]Z0ol00000
1_oo0>[ooo]ZoookJ_oonf[ooaH0oonB00;oo`3l0_oonfX2oaP0o`03oookJ_oo1P3oo`H000?ojol0
0_l0Y_l00ooonf[oZ03oojP0o`03ool0n@03oookJ_l0Mooo07Oo00;o07Oo0ooonfX9oom/0003o`3o
V_oonf[ooo]Z00?ooo]Z0ol0Mol3ool0n@;ooo]Z0_nX0?l00ooonf[o0:Koo`2Vo`03oookJP;ojol0
00?ooo]ZoaP0oooo1P001?oonfX01_oo0?cooo]ZoookJ_oonf[ooi80oolF00Kooo]Z00?oo`3Zoook
J_oonfX03OoonfX00ol0Looooo]ZoookJP0:oookJP0;okWo0?ooDP3ooo]ZoookJ_l0:_oooo]Zocoo
0?oonf[o0=cooookJ_mho`002?oonfX01?l0oa_ooo]ZoookJ_oobP03oookJP03ool0Tooonf[oo`0C
00Gooo]Z00Oof_l0oookJ_oonf[ooo]ZobH0oolPo`3oQ03o013ooo]Z00?o<Ol0oookJ_l0oe/00ooo
nfX02?l0ok3oP_l0oookJ_l0<?oo0>Soo`3oCOoonf[o1P3o0_oonfX01ooo0?GoT_l0oookJ_oonf[o
o`1Zoa00ool0GOl00ooonfX01OlE0?ooo`1AoookJ_oonf[o0:go00?ooo]Z00?oo`1ioookJ_oonfX0
9ooonfX002cooo]Z00?ojol0ool0m_oonfX00ooonfX01OnDo`3ooo]ZojP0oooonf[oU?l000;ooo]Z
00So07OooookJ_oonf[ooo]Zoom/0?l0olcooh40oc_o00Gooo]Z00Co0?_ooookJ_oonf[oo`<01?oo
nfX01Omi0?ooo`3MoookJ_l0Xooo/ol000Gooo]Z00?o0?oNool0QooonfX00_oonfX01?oo06cooo]Z
oookJ_m=0?l2oookJP05of40ool0odGooo]ZoookJ_oR0?l00_oonfX00ol0oi3ooo]Zo`3oTP07oook
JP03ofP0oooonf[ooo]Z00;ooo]Z00Go603oonKo0?oonf[ooo]Zoon@0009oookJP04oonn0?oonf[o
oo]Zon/0o`Gooo]Z00?ooeL0oookJ_oonfX01?oonfX00ooo02gooo]ZoookJP04oookJP03oon10?oo
nf[ooo]Z00Cooo]Z00?o0=CooookJ_l01?l00_oonfX01_l0ZOoooo]ZoookJ_oonf[o0?m>o`3o=0Ko
oo]Z00Co0>7oo`3o7Ooonf[o0?mC0ooonfX04_oo07Wooo]Zooo90?oo057ooo]Zo`0Iool0oego05go
ool0mOnBo`3ooo]Zo`3oCOl0<?ooP_l0oookJ_l0oe_ooo]Zoc7o00Oooo]Z00Co8?l0obH0oooob@3o
f_l00_oonfX01_oo01?oo`2Co`3ioooonf[o0?lKo`2>o`?ooo]Z00SoN?l0o`3ogooonf[o?ol0o`0Z
ool0oc?ooe80okWo00Kooo]Z00?o07?ooookJ_oonfX01OoonfX01Ol0003oo`3Zo`000?l0003ooo]Z
00;ooaH000Cooi80ool0o?oonf[ooo]Z0_lH0?l00oooN@3oo`H0oomi0005oomi00Coo`3i00Kooo]Z
o`1gool0Mooo07Ooo`3oV_ooK003oon100koogT00_ooP@02oom/00?ooo]Z0ol0Mol3ool0n@?oZ03o
0_l0Y_l3oookJP;ojol000Cooo]Zool60?lH0?oo603o0ooonfX01_oo0?cooo]ZoookJ_ooTP3ooo]Z
oolF00Kooo]Z00?oo`3ZoookJ_oonfX03OoonfX00ol0Looooo]ZoookJP09oookJP03okWo0?ooDP3o
oo]Z00;ooo]Z00Oo02[ooookJ_loo`3o0=coogSo0?lm0?oo0?oO00Oooo]Z00Co4P3oo`3o6ooonf[o
olX00ooonfX01?oo09?o0?WoonGo0?oonfX4onGo0007om[o0?oUo`3oiOl0onGo0?lV0?oo8?l0oh@0
o`0@oookJP03oc7o0?oonf[o0?mK00?ooo]Z00GoiOl0oookJ_l0<?oo0?nao`3oC@02oookJP04o`H0
oooonf[ooo]Zoi;o00?ooo]Z00?oo`1Zoa00oooonfX01?oonfX01?oo057ooo]ZoookJ_l0[Ol2oook
JP03ool0NOoonf[ooo]Z053ooo]Z00?ojol0oookJ_oo0?H00ooonfX00ol0Y_oooo]ZojP0o`02oook
JP03ool0nOoonf[o07Oo00?ooo]Z00Goof`0oookJ_ooP@3ooo]Zoc_o0004oookJP04o`3koooonf[o
oo]Zool300Cooo]Z00GoN@3oool0gOoonf[o0:?ook?o0005oookJP03omgo0?l0omkoo`2700;ooo]Z
00Soo`1/oookJ_oonf[oC@3oool^0?oonf[oH@3oo`3oA@?ooo]Z00?ohP3ooookJ_l0oi000_oonfX0
0ol0oi;ooo]ZoookJP04oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603oonKo0?oonfX00_oonfX0
0oooT03ooo]ZoookJP07oookJP04oonn0?oonf[oj`3oog00o`Cooo]Z00?ooeL0oookJ_oonfX01?oo
nfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Gooo]Z00Ko0=CooookJ_l01?oooo]Z
o`2Yool0R?l2oookJP03o`3o;_l0odkooo]Z00Gooo]Z00Go0>7oo`3o7Ol0o`Sooo]Zo`3oD`03oook
JP03ool0NOl0[Oooo`1A00;ooo]Z00So01Wooa00oooo0?GoT_l0o`H0ool0odgooo]Zoh;o00;ooo]Z
00?o0?mKoc7o0?oonfX01_oonfX01?lPo`3o9P3ooookJ_oJo`02oookJP07ool04ooonf[oo`2Coook
J_l0oa_o4P3oo`2>o`03oookJP07ogSo0?l0g?oo?ol0o`0Zoooonf[ooe80okWo0006oookJP03o`1c
oooonf[ooo]Z00Gooo]Z0_l000001ooo0>[o0000oookJ_oonf[ooaH0oonB0?oo0?`00ooonfX01?lH
0?oooo]ZoookJ_oo1P02on_o00;o0:Ko00?ooo]ZojP0oooo0?T00ooo0?T01?oonf[o07Ooo`1gool0
Mol2oom/01;ooh400oooK002oookJP?o07Oo0ooo0?T01?oonf[oZ03oojP0oooonfX2o`2Vo`;ooo]Z
00Koo`3fon_o0?oonf[ooo]Zool60?lH0?l3oookJP06ool0o?oonf[ooo]ZoookJ_ooTP3ooaH01_oo
nfX00ooo0>[ooo]ZoookJP0=oookJP03o`1coooonf[ooo]Z00[ooo]Z00_o^Ol0oomB0?oonf[ooo]Z
o`0Zoooonf[o?ol0o`3Loooonf[oN?l0o`3og`07oookJP04oa80ool0oa_ooo]Zooo:00Cooo]Z00?o
o`2CoookJ_oo01<01?oonfX01ooQo`3of_l0oookJ_oonf[o9P3ooookJ_lPo`004?oonfX00olao`3o
oo]Zo`3oF`03oookJP08o`3o/?n2o`3ooo]Zo`0`ool0j?oo0?m=oookJ_l60?l2oookJP03ool0mOnB
o`3ooo]Z00;ooo]Z00?o403oo`0IoooonfX00ooonfX01?oo057ooo]ZoookJ_l0[Ol3oookJP03ool0
NOoonf[ooo]Z02Oooo]Z000/oookJP03on_o0?oo0?Kooo]Z00?ooo]Z00OoU?l0oookJ_nX0?oooo]Z
oiCo0?oonf[o07Oo00?ooo]Z00Goof`0oiCo0?ooP@3ooo]Zoc_o0005oookJP04o`3koooonf[ooo]Z
ool300?ooo]Z00GoN@3ooookJ_oo0=goW`3ook?o0006oookJP05o`3og_oo08Oooo]ZoookJ_oo06`0
0_oonfX01Om=0?ooobh0oookJ_oonf[oH@3o00?ooo]Z00?ohP3ooookJ_l0oi000_oonfX00ol0oi;o
oo]ZoookJP05oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603oo`1doooonf[ooo]Zoon@0009oook
JP04oonn0?oonf[ooo]Zon/0o`Gooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP04
oookJP03oon10?oonf[ooo]Z00Cooo]Z00?o0=CooookJ_l01?l00_oonfX01ol0ZOoo08SooookJ_oo
nf[o0?m>oookJ_l0oc@01OoonfX01?l0hOoo0?l8o`3o7Ol0oe<3oookJP0:ool0NOoonf[oolT0ool0
DOlE0?oooo]Zo`0Iool0oegooo]Zoi;o00;ooo]Z00Ko0?m=o`3o/?n2o`3o0?mKoookJ_lao`07oook
JP04ob3o0?lV0?oooo]Zom[o00;ooo]Z00Koo`0Cool0Tol0nOoooo]Zooo:0?l0oa/3oookJP08ogSo
0?l0omoooo]Zocoo0?oonf[o02[ooomB0?nio`06oookJP03o`1coooonf[ooo]Z00Kooo]Z00Goo`3Z
o`000?l0003o0000oolF0002oonB0003ool0o?oonf[oogT000;oogT00_oo1P04oomi00?oo`3i00?o
ogT0o`1gool0Mol00_l0Mol2oom/00?ooh4000?ooo]Zoc_o0?lko`004?ooN@000olko`3ooh40oon1
0004oom/0004oookJ_l0Mooo07Ooo`1go`?oo`3i0_nX0?l2o`2Vo`;ooo]Z00Koo`3fon_o0?oonf[o
o`H0oookJ_lH0?l3oookJP06ool0o?oonf[ooo]ZoonB0?oonf[ooaH01_oonfX00ooo0>[ooo]Zoook
JP0=oookJP03o`1coooonf[ooo]Z00Wooo]Z00?o0?lcoomB0?oonfX00_oonfX01_l0:_oo?ol0o`3L
oooonf[oN?l0o`3og`Oooo]Z00Co4P3oo`3o6ooonf[oolX01?oonfX01?oo09?oiOl0oookJ_oonfX3
onGo0008om[o0?oUo`3oiOl0onGo0?oonf[o9P3ooookJ_n40?l?oookJP03oc7o0?oonf[o0?mK00?o
oo]Z00SoiOl0oookJ_oonf[o033oo`3oCOl0j?oooo]Zo`H0o`;ooo]Z00KoT_l0oookJ_oonf[ooo]Z
ool0J_l@0?l5oookJP04ool0DOoonf[ooo]Zo`2]o`;ooo]Z00?oo`1ioookJ_oonfX0D?oonfX00oo[
o`3ooo]Zool0mP03oookJP03o`2Voooonf[oZ03o00;ooo]Z00?oo`3io`1goooonfX00ooonfX01Ooo
K03ooh40o`3oc?oonf[o>ol000Cooo]Z00Co0?_ooookJ_oonf[oo`<00ooonfX01_mi0?oooo]Zool0
gOoonf[o0:?ook?o00Gooo]Z00?ogOl0o`3og_oo08L00_oonfX01ooo06cooo]ZoookJ_m=0?ooobh0
oookJ_mQ0?l01?oonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Oooo]Z00?oJ03ooookJ_oonfX00_oo
nfX01OlH0?oo07CooookJ_oonf[ooi0000[ooo]Z00?ookh0oookJ_o[0?l01OoonfX00oooE`3ooo]Z
oookJP03oookJP03ool0;Ooonf[ooo]Z00Cooo]Z00?ooh40oookJ_oonfX01OoonfX01_l0e?oooo]Z
o`04oooonf[o0:Woo`28o`?ooo]Z00?o0?m>o`3o=?oonfX01?oonfX01Ol0hOoooo]Zo`3o7Ooonf[o
0?mC00?ooo]Z00Coo`1io`2]oooo057o5@3o0_oonfX02ol06Ooo403ooi;o0?l60?oooo]Zo`3oCOl0
ok3oP_l0oookJ_l0oe_o<Ol000Oooo]Z00Co8?l0obH0oooonf[of_l00_oonfX01ooo01?ooo]Zool0
Tooonf[oolX0o`3o6olB0?l00ooonfX01omho`3o0=coocoo0?oonf[o02[ooomB0?l0oc<01_oonfX0
0ol0Looooo]ZoookJP06oookJP;oo`3Z0_l000001?oo5P3ooi80oonB0?oo0?`2oookJP;o603o00Co
oo]Zool60?oo1P3ojol00_l0Y_l01Ooonf[oo`3iool0nOoo0?Wooo]Z00Co07Oo00?oof`0oon10?oo
P@000_ooP@000ooonf[o>ol0oc_o000@oc_o00;ooh401?ooK0001?oonf[o07Ooo`1gool0Mol3ool0
n@?oZ03o00Go0:KooookJ_oonf[oo`3fon_o0002oookJP03ool60?lH0?oooo]Z00;ooo]Z00Koo`3l
oookJ_oonf[ooo]ZoonB0?oo5P06oookJP03ool0j_oonf[ooo]Z00gooo]Z00?o07?ooookJ_oonfX0
2_oonfX02ol0oc?ooe80oookJ_oonf[o02[oocoo0?oonf[o0=cooookJ_mho`3o0?oO00Oooo]Z00?o
0?lKoookJ_oobP001?oonfX00ooo09?ooo]Zool04`05oookJP07om[o0?oonf[ooo]ZoookJ_lV0?oo
8?l0oh@0o`0?oookJP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00Ko0?n`oh;o0?oonf[o0?nao`0`ool0
odd2oookJP04o`H0oooonf[oo`3eoi;o00?ooo]Z00?o403oo`0IoooonfX00ooonfX01?oo057ooo]Z
oookJ_l0[Ol3oookJP03ool0NOoonf[ooo]Z02Oooo]Z000/oookJP03on_o0?oonf[ooo]Z00;ooo]Z
00GoU?l0oookJ_oonf[oZ03ooiCo0002oookJP08o`1goooonf[ooo]ZoookJ_ooK03ooo]Zoon10?lk
o`05oookJP05o`3koooonf[ooo]ZoookJ_oo0`000ooonfX01Omi0?ooo`3MoookJ_nO0?oo/ol000Go
oo]Z00?o0?oNomgo0?oo08L00_oonfX02?oo06cooo]ZoookJ_m=0?ooobh0oookJ_mQ0?oo0?m50ooo
nfX00ooR0?oooo]Zo`3oT002oookJP03o`3oT_oonf[ooo]Z00Cooo]Z00?oJ03ooookJ_oonfX00_oo
nfX00olH0?ooi_l0oookJP02oookJP03oon@0?oonf[ooo]Z00Kooo]Z00Cookh0oookJ_oonf[oj`3o
1_oonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Cooo]Z00?ooh40oookJ_oonfX0
1?oonfX00ol0e?oooo]Zo`04o`02oookJP06o`2Yoooonf[ooo]ZoookJ_l0odko0?ld1OoonfX01Ol0
hOoooo]Zo`3o7Ooonf[o0?mC00?ooo]Z017oo`1ioookJ_oob@3oo`1AoookJ_l06Ooo0?mMo`1Moooo
0?GoT_l0oookJ_l0odgo033ooh;o0?oonf[o0?mKoc7o0007oookJP0<ob3o0?lV0?oooo]Zooo90?oJ
o`3ooo]Zool04ooo09?o0?WooookJ_oobP3o0?lK0_oonfX2o`00O`07ogSo0?l007oo?ol0o`00Ool0
:_oooe80okWo0003oookJP?o001o00?o07?oo`00OooonfX01_oonfX00ooo0>[o0000o`000002oolF
0003oonB0?oonf[oo`3l00?oogT00_oo1P04oomi00;oo`3i0oooN@000ol0Moooof`0oom/0003oon1
00Go>ol03oooN@04oookJP?o>ol00_ooP@001Ol0olcoof`0oom/0?l0oi[ooo]Z00?o07Oo0_oo0?T2
ojP0o`;o0:Ko0_oonfX01?o[o`3ooo]Zool60?oonfX2oaP0o`;ooo]Z00Goo`3loookJ_oonf[ooi80
oolF0007oookJP03ool0j_oonf[ooo]Z00cooo]Z00?o07?ooookJ_oonfX02_oonfX02oooDP3ooo]Z
oookJ_oonf[o02[ooookJ_loo`3o0=coogSo0?lm0?oo0?oO00Kooo]Z00Go4P3ooookJ_l0oa_ooo]Z
ooo:0003oookJP03ool0Tol0nOooiOl000;ooo]Z0_oUo`000ooJo`3oiOl0onGo0002onGo0003obH0
oolPo`3oQ03o00oooo]Z00?o<Ol0oookJ_l0oe/00ooonfX02?oUo`3ooo]ZoookJ_l0<?oo0?m=o`3X
oooonf[o1P3o0_oonfX00ooo0?GoT_l0oookJP02oookJP03oa00oooonf[ooo]Z00?ooo]Z00Coo`1A
oookJ_oonf[o0:go0_oonfX00ooo07Wooo]ZoookJP1@oookJP03on_o0?oo0?Kooo]Z00;ooo]Z00So
0:KooookJ_oonf[oZ03ooookJ_oo0?Wooo]Zo`1go`?ooo]Z00Go0?nJoom/0?ooP@3ooo]Zoc_o0005
oookJP04o`3koooonf[ooo]Zool300?ooo]Z00GoN@3oool0gOoonf[o01Oook?o0006oookJP03o`3o
g_oonf[oo`2700;ooo]Z00Ooo`1/oookJ_oonf[oC@3oool^0?oonf[oH@3o00Cooo]Z00GohP3oo`3o
T?oonf[ooo]Zo`3oTP06oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603oonKo0?oonfX00_oonfX0
0oooT03ooo]ZoookJP07oookJP04oonn0?oonf[oj`3oog00o`Gooo]Z00?ooeL0oookJ_oonfX00ooo
nfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Gooo]Z00Ko0=CooookJ_l01?oooo]Z
o`2Yool0R?l2oookJP03o`3o;_l0odkooo]Z00Cooo]Z00Ko0>7ooookJ_l0oago0?l8oookJ_l0oe<3
oookJP03ool0NOl0[Oooo`1A00;ooo]Z00_o01Wooa00oooo0?GoT_l0o`H0ool0odgo0?naoh;o0?oo
nf[o0?mKoc7o0007oookJP0>ob3o0?lV0?oooo]Zon7o0?oJo`3ooo]Zool04ooonf[oo`2CoookJ_oo
bP3o0?lKoa80oooonfX2o`00O`07o`3ogomho`3o?ol0o`00Ool0:_oooe80o`3o<`03oookJP?o001o
00?o07?oo`00OooonfX01_oonfX02Ooo0>[o0000o`000?l0003ooaH0oonB0?oonf[oo`3loookJP02
oaP0o`07oookJ_oo1P3oo`H0on_o0?l0Y_oooo]ZojP0o`02ool0n@04oookJ_l0Mooo07Ooo`1go`;o
of`00oooP@05oc_o00?ooo]Z2_l0nol5oookJP?o>ol00_ooP@001Ol0olcoof`0oom/0?l0oi[ooo]Z
00?o07Oo0_oo0?T01?oonf[oZ03oojP0ool0Y_l2oookJP;ojol000Cooo]Zool60?lH0?oo603o0_oo
nfX01_oo0?cooo]ZoookJ_oonf[ooi80oolF00Kooo]Z00?oo`3ZoookJ_oonfX03?oonfX00ol0Looo
oo]ZoookJP0;oookJP0:oomB0?oonf[ooo]Zo`0Zoooonf[o?ol0o`3Loooonf[oN?l0o`3og`Oooo]Z
00Co4P3oo`3o6ooonf[oolX00ooonfX00ooo09?o0?Woool04`05oookJP07om[o0?oonf[ooo]Zoook
J_lV0?oo8?l0oh@0o`0?oookJP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00Ko0?n`oh;o0?oonf[o0?na
o`0`ool0odd2oookJP04o`H0oooonf[ooo]Zoi;o00?ooo]Z00?o403oo`0IoooonfX00ooonfX01?oo
057ooo]ZoookJ_l0[Ol3oookJP03ool0NOoonf[ooo]Z02Oooo]Z000[oookJP03on_o0?oo0?Kooo]Z
00?ooo]Z00GoU?l0oookJ_nX0?oooo]ZoiCo0002oookJP08o`1goooonf[ooo]ZoookJ_ooK03ooo]Z
oon10?lko`05oookJP05o`3koooonf[ooo]ZoookJ_oo0`000ooonfX01Omi0?ooo`3MoookJ_l0Xooo
/ol000Gooo]Z00?o0?oNomgo0?oo08L00_oonfX01?oo06cooo]Zodd0oooo;P02oookJP03of40ool0
odGooo]Z00;ooo]Z00GohP3ooookJ_l0oi3ooo]Zo`3oTP07oookJP03ofP0oooonf[ooo]Z00;ooo]Z
00Go603oonKo0?oonf[ooo]Zoon@0009oookJP04oonn0?oonf[ooo]Zon/0o`Gooo]Z00?ooeL0oook
J_oonfX00ooonfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Cooo]Z00?o0=Cooook
J_l01?l00_oonfX01_l0ZOoo08SooookJ_oonf[o0?m>o`3o=0Kooo]Z00Co0>7oo`3o2?l0oago0?mC
0ooonfX04_oo07Wooo]Zooo90?oo057ooo]Zo`0Ioooonf[o0?mMoookJ_nBo`3ooo]Zo`3Xool0odgo
0?n`oh;o0?l0oe_ooo]Zoc7o00Oooo]Z00Co8?l0obH0oooob@3of_l00_oonfX01Ooo01?oo`2Cooo9
0?oob@3o0?lK00?ooo]Z00Wo001oogSo0?l0g?oo?ol0o`00Ool0:_oooe80okWo0?l007l00_oonfX3
o`00O`04o`1cool007oo001oo`00O`Cooo]Z0_oo0>X00ooonf[ooaH0oolF0002oonB00;oo`3l0_oo
N@02ool600WoogT000?o0?nJoom/0?ooP@001Olko`001?oonf[o0?_oo`3kool0nol;oomi0004ooo9
0?oonf[ooo]ZoookJPGo0?_o0ooonfX3oc_o0004oon10?l0olcoof`0oom/00?ooo]Z0_l0Mol01Ooo
0?Wooo]ZojP0oooonf[o0:Ko00;ooo]Z00Kojol0oookJ_oo1P3oo`H0oookJ_lH0?l2oookJP05ool0
o?oonf[ooo]ZoonB0?oo5P001_oonfX00ooo0>[ooo]ZoookJP0=oookJP03o`1coooonf[ooo]Z00Wo
oo]Z00co0?lcoomB0?oonf[ooo]Zo`0Zoooonf[o?ol0o`3Loooonf[oN?l0oookJ_l0oml6oookJP04
oa80ool0oa_ooo]Zooo:00?ooo]Z00?oo`2Co`3ioooUo`000_oonfX3onGo0007om[o0?oUo`3oiOl0
onGo0?oonf[o9P3ooh@0o`0@oookJP03oc7o0?oonf[o0?mK00;ooo]Z00Ko0?n`onGo0?oonf[o033o
o`3o/Ol0odd2oookJP04o`H0oooonf[oo`3eoi;o00?ooo]Z00?o403oo`0IoooonfX00ooonfX01ooo
057o5@3ooookJ_oonf[o0:gooookJ_oo07T0DOoonfX00oo[o`3ooo]Zool0mP03oookJP03o`2Voooo
nf[oZ03o00;ooo]Z00?oo`3ioookJ_l0Mol00ooonfX01OooK03ooo]Zoon10?oonf[o>ol000Cooo]Z
00Go0?_ooookJ_oonf[ooo]Zool30003oookJP05ogT0oooo0=gooo]Zo`2Soonco`001_oonfX01Ol0
omkoo`27oookJ_oonf[oo`1/00;ooo]Z00GoC@3oool^0?oonf[oH@3oo`3oA@04oookJP05on80ool0
oi3ooo]ZoookJ_l0oi801_oonfX00omX0?oooo]ZoookJP02oookJP03oaP0oooVo`3ooo]Z00;ooo]Z
00?ooi00oookJ_oonfX01ooonfX01?oo_P3ooo]Zon/0oom`0?l4oookJP03oomG0?oonf[ooo]Z00?o
oo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3ooo]ZoookJP05oookJP06o`3Doooonf[o00Cooook
J_l0ZOoo08So0ooonfX00ol0odkooo]ZoookJP04oookJP05o`3Qoooonf[o0?lMoookJ_l0oe<00ooo
nfX00ooo07Wo0:goool0D@02oookJP0<o`0Ioooo06[o403ooi;o0?l60?oo0>Soo`3oCOl0ok3oP_l0
oookJ_l0oe_o<Ol01ooonfX01?lPo`3o9P3oon7o0?oJo`02oookJP06ool04ooonf[oo`2Cooo:0?l0
oa_o4P3o0_oonfX02Ol007oo0?oOogSo0?l0g?oo001oo`0Zool007oooe80o`00O`02oookJP?o001o
00Co07?oo`00Ool007oo001o1OoonfX01?oo0>[ooo]Zo`000?oo5P02oonB00;oo`3l00?ooo]ZoaP0
oooonfX00_oo1P000oo[o`3o0:KooookJP02ojP0o`05ool0nOoonf[o07Ooo`1gooooK0000_ooP@05
oc_o00So0?_o2_oonfX5o`3ko`?ooo]Z0olko`02oon100;oof`00ooonfX2o`1go`04ool0nOoonf[o
oo]ZojP0o`;o0:Ko00Oooo]Zool0m_o[o`3ooo]Zool60?oonf[o603o00;ooo]Z00Koo`3loookJ_oo
nf[ooo]ZoonB0?oo5P05oookJP03ool0j_oonf[ooo]Z00gooo]Z00?o07?ooookJ_oonfX02_oonfX0
2ol0oc?ooe80oookJ_l0:_oooo]Zocoo0?oonf[o0=cooookJ_mho`3o0?oO00Kooo]Z00Co4P3oo`3o
6ooonf[oolX01?oonfX00ooo09?ooo]Zool04`04oookJP03om[o0?oonf[ooo]Z00;ooo]Z00?o9P3o
ob3o0?oonfX03ooonfX00olao`3ooo]Zo`3oF`02oookJP06o`3o/?n2o`3ooo]ZoookJ_l0<?oo0?m=
0_oonfX01Ol60?oooo]ZoookJ_oo0?GoT_l000;ooo]Z00?o403oo`0IoooonfX01?oonfX01?oo057o
oo]ZoookJ_l0[Ol2oookJP03ool0NOoonf[ooo]Z02Oooo]Z000[oookJP03on_o0?oo0?Kooo]Z00?o
oo]Z00OoU?l0oookJ_nX0?oooo]ZoiCo0?oonf[o07Oo00Cooo]Z00Coof`0oon10?oonf[o>ol01Ooo
nfX01Ol0nooooo]ZoookJ_oonf[oo`<000;ooo]Z00GoN@3ooookJ_oo0=goW`3ook?o0006oookJP05
o`3og_oo08Oooo]ZoookJ_oo06`00_oonfX01_m=0?ooobh0oookJ_oonf[oH@3oo`3oA@;ooo]Z00?o
hP3ooookJ_l0oi000_oonfX00ol0oi;ooo]ZoookJP05oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go
603ooookJ_oonf[ooo]Zoon@0008oookJP04oonn0?oonf[ooo]Zon/0o`Kooo]Z00?ooeL0oookJ_oo
nfX00ooonfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Cooo]Z00?o0=CooookJ_l0
1?l00_oonfX01_l0ZOoooo]ZoookJ_oonf[o0?m>o`3o=0Gooo]Z00Go0>7ooookJ_l0oagooo]Zo`3o
D`03oookJP0Aool0NOoonf[oolT0ool0DOoonf[o01Woo`3oGOoonf[oT_l0o`H0oooonf[o0?m=ooo9
0?n2o`3ooo]Zo`3oFolao`001ooonfX01?lPo`3o9P3oooo90?oJo`02oookJP03ool04ooo09?oolT0
00;oolT000_o0?lKoookJ_oonf[ooo]ZogSo0?l0g?oo?ol0o`00Ool0:_oooe80okWo0004oookJP;o
001o00?o07?ooookJ_l007l00_l007l3oookJP08ool0j_oonf[ooo]ZoolF0?l0003ooi80o`000?oo
0?`2oomi00;oo`H02_ooN@001?ooP@3o>ol0oc_o0?lko`03oookJP?o0?_o0ooonfX8oomi00KoolT0
1_oonfX5o`3ko`03oookJ_lko`3o>ol000;ooh400oooK002oookJP05o`1goooo0?Wooo]ZojP0oooo
nfX00_l0Y_l01ooonf[ojol0on_o0?oonf[oo`H0oookJ_lH0?l00_oonfX01Ooo0?cooo]ZoookJ_oo
TP3ooaH000Kooo]Z00?oo`3ZoookJ_oonfX03?oonfX00ol0Looooo]ZoookJP09oookJP03okWo0?oo
DP3ooo]Z00;ooo]Z00Oo02[ooookJ_loo`3o0=coogSo0?oonf[o0?oO00Kooo]Z00Co4P3oo`3o6ooo
nf[oolX01?oonfX00ooo09?oiOl0oookJP02oookJP;oiOl000Oof_l0onGo0?oUo`3oiOl0oookJ_lV
0?ooQ03o013ooo]Z00?o<Ol0oookJ_l0oe/00ooonfX02?oUo`3ooo]ZoookJ_nDo`3o0?m=o`3Xoooo
nf[o1P3o0_oonfX01_nBo`3ooo]ZoookJ_oonf[oo`1Zoa00o`Cooo]Z00Ooo`1AoaD0oooonf[ooo]Z
o`2]oooonf[oo`1i057ooo]Z00?ojol0oookJ_oo0?H00ooonfX00ol0Y_oooo]ZojP0o`02oookJP03
ool0nOoonf[o07Oo00?ooo]Z00Goof`0oon10?l0olcooo]Zoc_o0004oookJP05o`3koooonf[ooo]Z
oookJ_oo0`000_oonfX01_mi0?oooo]Zool0gOl05ooo0:?ook?o00Gooo]Z00?ogOl0o`3og_oo08L0
0_oonfX02?oo06cooo]ZoookJ_m=0?ooobh0oookJ_mQ0?oo0?m50ooonfX00ooR0?oo0?n@oookJP02
oookJP03o`3oT_oonf[ooo]Z00Cooo]Z00?oJ03ooookJ_oonfX00_oonfX01OlH0?oooo]ZoookJ_oo
nf[ooi0000Wooo]Z00Cookh0oookJ_o[0?ooL03o1OoonfX00oooE`3ooo]ZoookJP03oookJP03ool0
;Ooonf[ooo]Z00Cooo]Z00?ooh40oookJ_oonfX01OoonfX01Ol0e?oooo]Zo`04oooonf[o0:Wo00?o
oo]Z00?o0?l^o`3oC_oonfX01?oonfX01Ol0hOoooo]Zo`3o7Ol0o`So0?mC00?ooo]Z00Coo`1ioook
J_l0[Oooo`1A0_oonfX02ol06Ooo403ooi;o0?oonf[o1P3oo`3oCOl0ok3oP_l0oookJ_l0oe_o<Ol0
00Oooo]Z00Co8?l0obH0oooQo`3of_l00_oonfX01_oo01?ooo]Zool0Tooonf[oolX0o`3o6`?ooo]Z
00Oo0?oOogSo0?l0g?oo001oo`0Zoooonf[ooe8000Cooo]Z0_l007l00ol0Looooo]Zo`00O`02o`00
O`?ooo]Z0_oo0>X2oookJP05oolF0?ooTP3o0000ool0o?oonfX00_lH0?l2ool600;ojol00onX0?l2
ool0n@;o07Oo00?ooh40oc_o0?lko`000_lko`02oookJP?o0?_o1OoonfX:ool300Sooo]Z1Ol0nol0
0ooonf[o>ol0oc_o0003oon100;oof`00_oonfX02Ol0Moooo`3ioookJ_oonf[oZ03ooookJ_l0Y_oo
oo]Zool0mP02on_o0003ool60?oonf[o603o00;ooo]Z00Koo`3loookJ_oonf[ooi80oookJ_oo5P05
oookJP03ool0j_oonf[ooo]Z00cooo]Z00?o07?ooookJ_oonfX02_oonfX02onio`3ooe80oookJ_oo
nf[o02[ooookJ_loo`3o0=cooookJ_mho`3o0?oO00Oooo]Z00?o0?lKoookJ_oobP001?oonfX00ooo
09?ooo]Zool04`05oookJP06om[o0?oonf[ooo]ZoookJ_lV0?oo8?l04?oonfX01?lao`3ooo]Zoook
J_l0oe/2oookJP08oh;o0?oonf[ooo]Zo`3o/Ol0<?oo0?m=oookJ_l60?l2oookJP07ool0mOnBo`3o
oo]ZoookJ_oo06[o403oo`0Io`04oookJP04ool0DOoonf[ooo]Zo`2]o`;ooo]Z00?oo`1ioookJ_oo
nfX09ooonfX002_ooo]Z00?ojol0oookJ_oonfX00ooonfX01?nDo`3ooo]ZojP0oonDo`02oookJP08
o`1goooonf[ooo]ZoookJ_ooK03ooo]Zoon10?lko`05oookJP05o`3koooonf[ooo]ZoookJ_oo0`00
0ooonfX01Omi0?ooo`3MoookJ_nO0?oo/ol000Kooo]Z00Go0?oNool0Qooonf[ooo]Zool0K002oook
JP05odd0oooonf[ooo]Zof40ool0odD00ooonfX00ooR0?oooo]Zo`3oT002oookJP03o`3oT_oonf[o
oo]Z00Cooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?ooi_l0oookJP02oookJP03oon@0?oonf[o
oo]Z00Kooo]Z00Cookh0oookJ_oonf[oj`3o1_oonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooo
nf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX01?oonfX00ol0e?oo00CooookJP02oookJP05o`2Yoooo
nf[ooo]Zo`3oC_l0oc@01_oonfX01Ol0hOoo0?lMo`3o2?oonf[o0?mC00;ooo]Z017oo`1ioookJ_oo
b@3oo`1AoookJ_l06Ooooo]Zo`3oGOoonf[oT_l0oookJ_l0j?oo0?m=oh;o0?oonf[o0?mKoc7o0008
oookJP07obH0oooonf[ohOl0om[o0?l007ooo`0Cool0T`03ooo9000;o`3o6ol007oo001ooookJ_mh
o`3o0=coo`00Ooloo`3o02[ooomB0?nio`001?oonfX2o`00O`04o`1coooonf[ooo]ZoookJP?o001o
00Gooo]Zool0j_oonf[ooo]ZoolF0002oonB0004o`000?oo0?co603ooookJPcoogT00_lko`03oook
JP?o0?_o0ooonfX2ool30003ogT0ooooN@3oogT000;oogT02Ooo0=d3ooo900?oo`<00_oonfX2oiCo
00;ooo]Z0ol0nol3oc_o0009oon10?l0oi[oof`0oom/0?oonf[o07Ooool0nOoonf[oZ03o00;ooo]Z
00Oo0:KooookJ_oo0?Kojol0oookJ_oo1P3o603o00?ooo]Z00Goo`3loookJ_oonf[ooi80oolF0006
oookJP03ool0j_oonf[ooo]Z00cooo]Z00?o07?ooookJ_oonfX02OoonfX02ol0oc?ooe80oookJ_oo
nf[o02[ooookJ_loo`3o0=cooookJ_mho`3o0?oO00Kooo]Z00Co08kooa80ool0oa_oolX01?oonfX0
0ooo09?oiOl0oookJP03oookJP03onGo0?oJo`3oiOl000;oiOl000?ooo]ZobH0oolPo`004?oonfX0
0olao`3ooo]Zo`3oF`03oookJP08onGo0?oonf[ooo]ZoiCo0?l0odgo0>SooookJ_l60?l2oookJP06
oi;o0?oonf[ooo]ZoookJ_oo06[o403o1OoonfX01_oo057ooo]ZoookJ_l0[Ooooo]Zool0NE7ooo]Z
00?ojol0ool0m_oonfX00ooonfX01ol0Y_oooo]ZojP0oooonf[oo`3ioookJ_l0Mol00ooonfX01Ol0
oi[oof`0oon10?l0olco>ol000Gooo]Z00Co0?_ooookJ_oonf[oo`<00ooonfX01_mi0?ooo`3Moook
J_l05ooo0:?ook?o00Gooo]Z00GogOl0o`3og_oo08Oooo]Zool0K002oookJP05odd0oooo;P3ooo]Z
oookJ_mQ0?l01?oonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Kooo]Z00?oJ03ooookJ_oonfX00_oo
nfX00olH0?ooi_l0oookJP02oookJP03oon@0?oonf[ooo]Z00Oooo]Z00Cookh0oookJ_o[0?ooL03o
1OoonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX0
1OoonfX01Ol0e?oo00CooookJ_oonf[o0:Wo00?ooo]Z00?o0?m>oookJ_oonfX01?oonfX01Ol0hOoo
0?lMoookJ_l0o`So0?mC00?ooo]Z00?oo`1io`2]oooo05400_oonfX02ol06Oooo`1Zoa00oonBo`3o
1P3oo`3Xool0odgo0?n`oh;o0?oonf[o<Ol000Sooo]Z00Co9P3ooookJ_oQo`3of_l00_l007l03ooo
01?oo`2Co`00OooobP3o0?lKo`2>ool007oooo]Zo`3ogomho`3o0=coocoo0?l0:_oo001ooomB0004
oookJP;o001o00Co07?ooookJ_oonf[ooo]Z0ol007l01Ooonf[oo`3ZoookJ_oonf[ooaH000;ooi80
00Ko0000ool0o?l0003o603ooookJ_oo1P02on_o00;oZ03o00?ooo]Zool0nOoo0?T00_l0Mol00ooo
K03o>ol0oc_o0003oookJP?o0?_o0ooonfX3ool300CoN@3o2Ooo0=d6ool300Kooo]Z0ol0nol3oc_o
00;ooh400_ooK0000ooonf[o07Ooool0n@02oookJP04ojP0oooonf[o0:KooookJP;oo`3f00?ojol0
ool60?lH0?l00ooonfX01Ooo0?cooo]ZoookJ_ooTP3ooaH000Kooo]Z00?oo`3ZoookJ_oonfX03?oo
nfX00ol0Looooo]ZoookJP0:oookJP0:o`3o<oooDP3ooo]Zo`0Zoooonf[o?ol0oookJ_l0g?oo?@3o
ogSo00Oooo]Z00Co4P3oo`3o6ooonf[oolX01?oonfX00ooo09?oo`0CoookJP04oookJP07om[o0?oo
nf[ooo]ZoookJ_lV0?ooQ03oob3o000?oookJP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00So0?n`oh;o
0?oonf[o0?nao`0`ool0odgooo]Zo`H0o`;ooo]Z00?oo`3eoi;o0?oonfX00_oonfX00ol@0?oo01Wo
oookJP03oookJP04ool0DOoonf[ooo]Zo`2]o`;ooo]Z00?oo`1ioookJ_oonfX09ooonfX002[ooo]Z
00?ojol0ool0m_oonfX00ooonfX01OnDo`3ooo]ZoookJ_nX0?ooo`3i00;ooo]Z00So07OooookJ_oo
nf[ooo]Zoom/0?oonf[ooh40oc_o00Gooo]Z00Go0?_ooookJ_oonf[ooo]Zool30003oookJP05ogT0
oooo0=gooo]Zo`2Soonco`001OoonfX00ol0omkogOl0ool0Q`02oookJP04ool0K?oonf[oC@3oool^
00;ooo]Z00?oH@3oo`3oAOoonfX00_oonfX00ooR0?oooo]Zo`3oT002oookJP03o`3oT_oonf[ooo]Z
00Cooo]Z00?oJ03ooookJ_oonfX00_oonfX01OlH0?ooi_l0oookJ_oonf[ooi0000Wooo]Z00Cookh0
oookJ_m`0?ooj`3o1OoonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Cooo]Z00?o
oh40oookJ_oonfX01?oonfX00ol0e?oooo]Zo`04o`02oookJP06o`2Yoooonf[ooo]ZoookJ_l0odko
0?ld1_oonfX01?l0hOoo0?lMoookJ_l0oe<2oookJP0Bool0NOoonf[ooo]Zooo90?oo057ooo]Zo`0I
ool0oegooo]Zoi;o0?l60?oo0>Soo`3oCOoob@3oP_l0o`3oFooonf[o<Ol01ooonfX01?lPo`3o9P3o
on7o0?oJo`02o`00O`05ool0Tooob@3oolT0ooo90?l0oa/00ol007l01ol0omooN?l0o`3Looloo`3o
02[oo`3o<oooDP000_l007l3oookJP03o`00Ool0Looo001o00?ooo]Z0ol007l01_oo0>[ooo]Zoook
J_oo5P3ooi80oookJP;oo`3l00?o603oool60?oo1P002_ooN@02oc_o00;ooo]Z0ol0nol00ooonf[o
o`<0ool30002ool300Soo`3M1_nco`03ooo900Goo`3M00?ooo]Zool30?oo0`000onDo`04oookJP03
o`3koooonf[ooo]Z00;o>ol000[o0?o<o`3oV_ooK03oof`0o`1goooo0?Wooo]ZojP0oooonf[o0:Ko
0ooonfX01?o[o`3ooo]Zool60?lH0?l3oookJP05ool0o?oonf[ooo]ZoonB0?oo5P001OoonfX00ooo
0>[ooo]ZoookJP0=oookJP03o`1coooonf[ooo]Z00Sooo]Z00Go^Ol0o`3o<oooDP3ooo]Zo`0Zo`02
oookJP05ocoo0?l0g?ooN?l0oookJ_l0oml01_oonfX01?lB0?oo0?lKoookJ_oobP03oookJP03ool0
Tol0nOooiOl000Cooo]Z00Cof_l0onGo0?oUo`3oiOl00_oonfX00olV0?ooQ03ooookJP0>oookJP03
oc7o0?oonf[o0?mK00?ooo]Z00SoiOl0oookJ_oonf[oU?l0o`3oCOl0j?oooo]Zo`H0o`;ooo]Z00Ko
T_l0oookJ_oonf[ooo]Zool0J_l@0?l5oookJP06ool0DOoonf[ooo]Zo`2]oooonf[oo`1iD?oonfX0
0oo[o`3ooo]Zool0mP03oookJP08o`2Voooonf[ooo]ZojP0oooonf[oo`3ioookJ_l0Mol3oookJP05
o`3oV_ooK03ooh40oookJ_lko`001?oonfX01Ol0nooooo]ZoookJ_oonf[oo`<000?ooo]Z00GoN@3o
ool0gOoonf[o0:?ook?o0006oookJP05o`3og_oo08Oooo]ZoookJ_oo06`00_oonfX01Om=0?ooobh0
oookJ_mQ0?oo0?m500Cooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP03ofP0oooonf[ooo]Z
00;ooo]Z00?o603oonKo0?oonfX00_oonfX00oooT03ooo]ZoookJP07oookJP03oonn0?oonf[oj`3o
00Gooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z
00Gooo]Z00Go0=CooookJ_l01?oooo]Zo`2Yo`04oookJP03o`3oC_oonf[ooo]Z00Cooo]Z00Co0>7o
o`3o7Ol0o`So0?mC0ooonfX01?oo07Wooo]Zo`2]oooo0542oookJP0;o`0Iool@0?ooT_l0oookJ_l0
j?oo0?m=o`3o/?n2o`3ooo]Zo`3oFolao`001ooonfX01?lPo`3o9P3oon7o0?oJo`02o`00O`06ool0
4ooo09?o001oooo:0?l0oa_o4P3o0_l007l01ol0omoo?@3oogSo0?loo`3o02[oo`00OoooDP000_l0
07l3oookJP03o`00Ool0Looo001o00?ooo]Z0ol007l01_oo0>[ooo]ZoookJ_oo5P3ooi80oookJP;o
o`3l0_lH0?l2ool60004on_o0?l0Y_ooZ03ooookJP;oo`3i0_l0Mol00oooK03o>ol0oc_o0003oook
JP;o0?_o00?ooo]Zool30?oo0`000_oo0`08ool0g@Ko/ol00_l0Xol00omi0?ooo`3Mool0g@03ool0
g@04oookJ_oo0`3oo`<0ool300Kooo]Z00?o0?_ooookJ_oonfX00_lko`001_ooP@3o0?nJoom/0?oo
K03o07Ooool0n@;ooo]Z00?oZ03oo`2VoooonfX00_oonfX01?oo0?Kojol0ool60?lH0?l3oookJP05
ool0o?oonf[ooo]ZoonB0?oo5P001OoonfX00ooo0>[ooo]ZoookJP0=oookJP03o`1coooonf[ooo]Z
00Wooo]Z00Co^Ol0o`3o<oooDP3o02[o0_oonfX01Oloo`3o0=cooookJ_mho`3o0?oO00Kooo]Z00Co
4P3oo`3o6ooonf[oolX01?oonfX00ooo09?oo`0CoookJP04oookJP03om[o0?oQo`3ooo]Z00;ooo]Z
00?o9P3oob3o0?oonfX03_oonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP06o`3o/?n2o`3ooo]Zo`3o
/Ol0<?oo0?m=0_oonfX01?l60?oooo]Zool0mOnBo`03oookJP03oa00ool06Ooooo]Z00?ooo]Z00Co
o`1AoookJ_oonf[o0:go0_oonfX00ooo07Wooo]ZoookJP0WoookJP00:ooonfX00ooo0?Kooo]Zoook
JP02oookJP05oiCo0?oonf[oZ03ooookJ_oo0?T00_oonfX02?l0Mooooo]ZoookJ_oonf[oof`0onGo
0?l0olco>ol01OoonfX01Ol0nooooo]ZoookJ_oonf[oo`<000;ooo]Z00KoN@3ooookJ_oo0=goW`3o
o`2Soonco`05oookJP05o`3og_oo08Oooo]ZoookJ_oo06`00_oonfX01_m=0?ooobh0oookJ_oonf[o
H@3oo`3oA@?ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP03ofP0oooonf[ooo]Z00;ooo]Z
00?o603oo`1doooVo`000_oonfX00oooT03ooo]ZoookJP06oookJP04oonn0?oonf[ooo]Zon/0o`Ko
oo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP05oookJP03oon10?oonf[ooo]Z00Co
oo]Z00?o0=Coo`04oooonfX00_oonfX01Ol0ZOoooo]ZoookJ_oonf[o0?m>00Kooo]Z00Go0>7oo`3o
7Ol0o`Sooo]Zo`3oD`02oookJP0Aool0NOoonf[oolT0ool0DOoonf[o01Woo`3oGOoo06[ooo]Zoi;o
0?oonf[o0?m=ooo90?n2o`3oolT0o`3oFolao`001ooonfX01?lPo`3o9P3ooookJ_oJo`02oookJP03
ool0Tooob@3oolT000;oolT000_o0?lKoookJ_oonf[ooo]ZogSo0?l0g?oo?ol0oookJ_l0:_oooe80
okWo0003o`00O`;ooo]Z00?o07?oo`00Ool007l00ooonfX2o`00O`0=ool0j_oonf[ooo]ZoolF0?oo
TP3ooo]Zool0o?lH0?oo0000ool60?o[o`3oogT0o`2Vo`07oomi00;o>ol000Gooo]Zo`3kool0nooo
0?_ooomi0003ool30005oomi0?oo0=goo`3Mool0gOl0Xol01onco`03oomi00?oolT01Onco`03ooo9
00;oo`3M1OnDo`03oookJP07oomi0?l0nooo0?_ooookJ_ooN@3o>ol0o`3oc002o`3oVP07oom/0?l0
Moooo`3iool0nOnX0?oooo]Zo`2Vo`03oookJP04on_o0?oonf[oo`H0oaP0o`?ooo]Z00Coo`3loook
J_ooTP3ooaH01_oonfX00ooo0>[ooo]ZoookJP0<oookJP03o`1coooonf[ooo]Z00Sooo]Z00?o^Ol0
oookJ_ooDP000_oonfX01ol0:_oooo]Zocoo0?l0g?oooo]ZogSo0?l0oml01_oonfX01?lB0?oo0?lK
oookJ_oobP04oookJP03ool0TooUo`3ooo]Z00?ooo]Z00CoiOl0om[o0?oUo`3oiOl00_oonfX00olV
0?ooQ03ooookJP0>oookJP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00SoiOl0oookJ_oonf[oU?l0o`3o
COoonf[o0>Soo`H0o`;ooo]Z00?oT_l0oookJ_oonfX00_oonfX00ol@0?oo01WooookJP03oookJP04
ool0DOlE0?oooo]Zo`2]o`;ooo]Z00?oo`1ioookJ_oonfX0CooonfX01ooo0?Kooo]ZoookJ_oonf[o
0:KooookJ_nX0?l00_oonfX00ooo0?Wooo]Zo`1go`03oookJP05oom/0?ooP@3o0?o<oookJ_lko`00
1?oonfX01Ol0nooooo]ZoookJ_oonf[oo`<000;ooo]Z00KoN@3ooookJ_oo0=go01Ooo`2Soonco`06
oookJP05o`3og_oo08Oooo]ZoookJ_oo06`00_oonfX01Om=0?ooobh0oookJ_mQ0?oo0?m500Cooo]Z
00GohP3ooookJ_oonf[ooo]Zo`3oTP05oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603oo`1doooV
o`000_oonfX00oooT03ooo]ZoookJP07oookJP04oonn0?oonf[oj`3oog00o`Gooo]Z00?ooeL0oook
J_oonfX00ooonfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Gooo]Z00Go0=Coo`04
oooonf[ooo]Zo`2Yo`03oookJP03o`3o=?l0odkooo]Z00Cooo]Z00Go0>7oo`3o7Ooonf[o0?l8o`3o
D`03oookJP03ool0NOl0[Oooo`1A00;ooo]Z00_o01Wooa00oooonf[oT_l0o`H0ool0odgooo]Zo`3o
/?n2o`3o0?mKoc7o0008oookJP03obH0oooonf[of_l000;ooo]Z00Koo`0Cool0Tol0nOoooo]Zooo:
0?l0oa/3oookJP07o`3ogomho`3o0=cooookJ_l0:_oooe80okWo0003o`00O`;ooo]Z00?o07?oo`00
Ool007l00ooonfX2o`00O`0<ool0j_oonf[ooo]ZoolF0?ooTP3ooo]Zool0o?l0003o603oo`000?oo
1P3ojol00_l0Y_l00onX0?oooo]Zool0n@02o`1go`03oom/0?lko`3o>ol000;ooo]Z0ol0nol3ool3
0005oookJ_oo0=goo`3Mool0gOl0Xol01onco`06oil0o`Go/ol00_l0Xol00ooonf[oo`3Mool0g@02
ool0g@?oo`<01?oonfX2o`3ko`;ooo]Z00Ko>ol0oon10?l0oi[o0?nJoom/0?l0Mol2ool0n@03oook
J_nX0?oo0:Ko00?ooo]Z00Coo`3fon_o0?oo1P3o603o0ooonfX01Ooo0?cooo]ZoookJ_ooTP3ooaH0
00Gooo]Z00?oo`3ZoookJ_oonfX03?oonfX00ol0Looooo]ZoookJP09oookJP0;okWo0?oonf[ooe80
oookJ_l0:_oooo]Zocoo0?l0g?oooo]Zocd0oomho`001ooonfX00ol0oa_ooo]Zooo:0004oookJP03
ool0Tooonf[oo`0C00Cooo]Z00?of_l0on7o0?oonfX00_oonfX00olV0?oo8?l0oookJP0>oookJP0B
oc7o0?oonf[ooo]ZoookJ_l0oe_ooo]Zo`3o/?n2o`3ooo]Zo`3o/Ol0<?oo0?m=o`3Xoooonf[o1P3o
oookJ_oo0?GoT_l00ooonfX00ol@0?oo05goo`0Io`03oookJP04ool0DOlE0?oooo]Zo`2]o`;ooo]Z
00?oo`1ioookJ_oonfX09ooonfX002_ooo]Z00?oo`3foookJ_oonfX00_oonfX01OnDo`3ooo]ZojP0
oooonf[oo`3i00;ooo]Z00So07OooookJ_oonf[oU?l0oom/0?oUo`3ooo]Zoc_o00Cooo]Z00?o0?_o
oookJ_oonfX00_oonfX02?oo0`3ooo]ZoookJ_mi0?ooo`3MoookJ_nO0?oo/ol01_oonfX02?l0omko
o`27oookJ_oonf[oo`1/oookJ_m=0?ooobh00_oonfX00omQ0?oooo]Zo`3oA@02oookJP03on80oooo
nf[o0?n@00;ooo]Z00?o0?nBoookJ_oonfX01?oonfX00omX0?oooo]ZoookJP02oookJP03oaP0oooV
o`3ooo]Z00;ooo]Z00?ooi00oookJ_oonfX01_oonfX01?oo_P3ooo]Zo`3o3?o[0?l6oookJP03oomG
0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP04oookJP05o`3D
ool01?oooo]ZoookJ_l0ZOl00ooonfX00ol0odko0?ldoookJP05oookJP04o`3Qool0oagooo]Zo`3o
D`;ooo]Z017oo`1ioookJ_oonf[oolT0ool0DOoonf[o01Woo`3oGOoonf[oT_l0o`H0ool0j?oo0?m=
ooo90?n2o`3o0?mKoc7o0008oookJP06ob3o0?lV0?oohOl0om[o0?oonf[oo`0C1?oob@003?l0oa_o
oo]ZoookJ_oonf[oN?l0o`3Looloo`3ooo]Zo`0ZooooDP3o^Ol0oookJP?o001o00?ooo]Zo`1cool0
07l00_l007l3oookJP;o001o00_oo`3ZoookJ_oo5P3ooi80oookJ_oo0?co603oo`000?oo1P3ojol0
ool0mP02ojP0o`GoogT00_lko`001OooN@3o0?_oo`3koooonf[oogT000;oo`<000CoogT0ool0gOoo
0=goo`3M1?nco`09oomi00WoolT01?nco`07oiCo0003ool30?oonf[oogT000;ooo]Z00So0?_ooomi
0?oonf[o>ol0oon10?l0olcoof`0o`3oVP;o07Oo00Coo`3iojP0oooonf[o0:Ko0_oonfX01Oo[o`3o
o`3foookJ_oo1P3o603o00?ooo]Z00Coo`3loookJ_ooTP3ooaH01OoonfX00ooo0>[ooo]ZoookJP0=
oookJP03o`1coooonf[ooo]Z00Sooo]Z00Go^Ol0oomB0?oonf[ooo]Zo`0Zo`02oookJP04ocoo0?l0
g?ooN?l0o`3og`Kooo]Z00Co08koo`3o6ooonf[oolX01?oonfX00ooo09?oiOl0oookJP04oookJP03
om[o0?oUo`3oiOl000;ooo]Z00?o9P3oob3o0?oonfX03ooonfX00olao`3ooo]Zo`3oF`03oookJP0;
onGo0?oonf[oU?l0oookJ_l0odgo0>SooookJ_l60?oooo]Zool0mOnBo`000ooonfX00ol@0?oo01Wo
oookJP03oookJP04ool0DOlE0?oooo]Zo`2]o`;ooo]Z00?oo`1ioookJ_oonfX0C_oonfX00ooo0?Ko
oo]ZoookJP02oookJP03o`2Voooonf[oZ03o00;ooo]Z00?oo`3ioookJ_l0Mol00_oonfX01_l0oi[o
of`0oon10?l0olcooo]Zoc_o00Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30002oookJP06ogT0oooo
0=gooo]Zo`0Gool0Xooo/ol01OoonfX01OoMo`3o0?oNool0Qooonf[oo`1/00;ooo]Z00KoC@3oool^
0?oonf[ooo]Zof40ool0odD3oookJP05on80ool0oi3ooo]ZoookJ_l0oi801_oonfX00omX0?oooo]Z
oookJP02oookJP03oaP0oooVo`3ooo]Z00;ooo]Z00?ooi00oookJ_oonfX01ooonfX00ooo_P3ooo]Z
on/0o`06oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]Z
oookJP05oookJP04o`3Dool01?oooo]Zo`2Yo`Cooo]Z00?o0?m>oookJ_oonfX01?oonfX01?l0hOoo
0?lMo`3o2?l0oe<3oookJP04ool0NOoonf[o0:goool0D@;ooo]Z00[o01Wooa00oonBo`3ooo]Zo`3X
ool0odgo0?n`oh;o0?oonf[o<Ol02?oonfX01?lPo`3o9P3oon7o0?oJo`02oookJP06ool04ooo09?o
oo]Zooo:0?l0oa_o08ko0_oonfX02?l0omooN?l0o`3Loooonf[o02[ooomB0?nio`3ooo]Z0ol007l0
0ooonf[o07?oo`00O`02o`00O`?ooo]Z0_l007l03?oo0>[ooo]ZoolF0?ooTP3ooo]Zool0o?oonf[o
603oo`000?oo1P3oo`3fo`2Vo`;oZ03o00Koo`3io`1gool0Moooof`0o`3oc?lko`02oookJP;o0?_o
00Cooo]Zool30?oo0`3ooo]Z0ooo0=d4ok?o00?oW`3o3ooonfX4ok?o00;o0:?o00CoN@3oool0gOoo
0=goo`3M0_oo0`04oookJP04o`3koooonf[ooo]Zoc_o00;ooh4000Soof`0o`3oV_l0Mooo07Ooool0
nOoonf[oZ03oo`2Vo`?ooo]Z00Cojol0oookJ_oo1P3o603o0ooonfX01Ooo0?cooo]ZoookJ_ooTP3o
oaH000Cooo]Z00?oo`3ZoookJ_oonfX03OoonfX00ol0Looooo]ZoookJP09oookJP04okWo0?ooDP3o
oo]Zo`0Zo`;ooo]Z00Co?ol0o`3Loolm0?ooN?l01ooonfX00ol0oa_ooo]Zooo:0004oookJP03o`3i
oooo09?oo`0C00Gooo]Z00Oof_l0oookJ_oonf[ooo]ZobH0oon40?oo8?l000oooo]Z00Co<Ol0oook
J_oonf[o0?mK0_oonfX02?n2o`3ooo]Zo`3o/Ol0<?oo0?m=o`3Xoooonf[o1P3o0_oonfX01onBo`3o
oo]ZoookJ_oonf[o403oo`1Mool06Ol01?oonfX00ooo057ooo]Zo`2]o`03oookJP03ool0NOoonf[o
oo]Z02Kooo]Z000[oookJP05ool0m_oonf[ooo]ZoookJ_nDo`000_oonfX01OnX0?ooo`3ioookJ_oo
nf[o07Oo00?ooo]Z00Goof`0onGo0?oUo`3ooo]Zoc_o0004oookJP05o`3koooonf[ooo]ZoookJ_oo
0`000ooonfX01Omi0?ooo`3MoookJ_l0Xooo/ol000Kooo]Z00So0?oNool0Qooonf[ooo]Zool0K?oo
nf[oC@3oool^00;ooo]Z00?oH@3oo`3oAOoonfX00_oonfX00ooR0?oooo]Zo`3oT002oookJP03o`3o
T_oonf[ooo]Z00Cooo]Z00?oJ03ooookJ_oonfX00_oonfX01OlH0?ooi_l0oookJ_oonf[ooi0000So
oo]Z00Gookh0oookJ_oonf[o0?l<on/0o`05oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oook
J_oonfX01?oonfX00oooP@3ooo]ZoookJP04oookJP03o`3Dool01?oooo]Z00;ooo]Z00Ko0:Wooook
J_oonf[ooo]Zo`3oC_l0oc@5oookJP05o`3Qool0oago0?l8oookJ_l0oe<00_oonfX01?oo07Wooo]Z
ooo90?oo0542oookJP0;o`3oGOoo06[oo`3eoi;o0?oonf[o0?m=ooo90?n2o`3o0?mKoookJ_lao`00
1ooonfX01?lPo`3o9P3ooookJ_oJo`02oookJPCoolT000_o0?lKooo90?oonf[ooo]ZogSo0?oonf[o
0=coocoo0?l0:_oooe80okWo0003oookJP;o001o00?o07?ooookJ_l007l00_l007l3oookJP08o`00
Oooo0>[o001ooolF0?ooTP3ooo]Zool0o?lH0?l2ool60005on_o0?l0Y_ooZ03ooomi0?l0Mol00ooo
N@02oc_o00;oogT000?o0?_ooookJ_oonfX00_oo0`03ool0g@?o/ol02_ooN@07ool0Q`WoolT02?nD
o`03ool3000@oookJ_ooN@3o0?_oo`3koooonf[o>ol0oon10?oonf[oof`0o`3oV_oonf[o07Ooool0
nOnX0?oooo]Zo`2Vo`;ooo]Z00Cojol0oookJ_oonf[oo`H01?oonfX01?oUo`3ooo]ZoonB0?oo5P05
oookJP03ool0j_oonf[ooo]Z00cooo]Z00?o07?ooookJ_oonfX02?oonfX01Onio`3ooo]ZoomB0?oo
nf[o02[o00;ooo]Z00Co?ol0o`3Loolm0?ooN?l01ooonfX00olB0?oo0?lKooo:0004oookJP03ool0
Tooonf[oiOl000Cooo]Z00Cof_l0onGo0?oUo`3oiOl00_oonfX00olV0?oooo]ZoookJP0>oookJP03
oc7o0?oonf[o0?mK00?ooo]Z00_oiOl0oookJ_l0ok7oU?l0o`3oCOl0j?oooo]Zo`H0oooonf[oo`3e
oi;o0003oookJP03oa00ool06Ooooo]Z00?ooo]Z00Coo`1AoaD0oooonf[o0:go0_oonfX00ooo07Wo
oo]ZoookJP1>oookJP05ool0m_oonf[ooo]ZoookJ_l0Y_l00_oonfX00onX0?oooo]Zool0n@02oook
JP06o`1goooonf[ooo]Zo`3oV_ooK03ooh400_oonfX01Olko`3ooo]ZoookJ_oonf[o0?_o00?ooo]Z
00Woo`<0oookJ_oonf[ooo]ZogT0oooo0=gooo]Zo`2Soonco`001_oonfX01OoMo`3oo`27oookJ_oo
nf[oo`1/00;ooo]Z00GoC@3oool^0?oonf[oH@3oo`3oA@04oookJP05on80ool0oi3ooo]ZoookJ_l0
oi801_oonfX00omX0?oooo]ZoookJP02oookJP03oaP0oooVo`3ooo]Z00;ooo]Z00?ooi00oookJ_oo
nfX01_oonfX01?oo_P3ooo]Zo`3o1Oo[0?l5oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oook
J_oonfX01?oonfX00oooP@3ooo]ZoookJP05oookJP05o`3Dool01?oooo]ZoookJ_l0ZOl00ooonfX0
0ol0obko0?m>oookJP04oookJP05o`3Qool0oagooo]Zo`3o2?l0oe<00ooonfX04?oo07Wo0:goool0
DOlE0?oooo]Zo`0Iool@0?ooo`3eoi;o0?l60?oo0?m=o`0`ool0ok3oP_l0o`3oFolao`07oookJP04
ob3o0?lV0?oooo]Zom[o00;ooo]Z00Koo`0Cool0Tooonf[ooo]Zo`3o6ol0S_l2oookJP07o`3ogomh
o`3o0=coocoo0?l0:_oooe80okWo0003oookJP;o001o00?o07?ooookJ_l007l00_l007l3oookJP09
o`00Oooo0>[o001ooolF0?ooTP3ooo]Zool0o?oonf[o603o00;oo`H00_l0Y_l01?nX0?ooo`3io`1g
ool0Mol2oom/00;o>ol00_oonfX01Ol0nooooo]Zool30?oo0`3oN@3o00;oo`3M0onco`02oil0o`Ko
oo]Z00?ogOl0o`3og_oo08L01_oo08L00ooMo`3ooo]ZoookJP06oookJP?o/ol00_l0Xol00omi0?oo
o`3MogT0o`03ool300;ooo]Z0_l0nol03?oonf[o>ol0oookJ_ooP@3oof`0o`3oV_oonf[o07Ooool0
nOoonf[oZ03oo`2Vo`;ooo]Z00Coo`3fon_o0?oonf[oo`H01?oonfX01Ooo0?cooo]ZoonB0?oonf[o
oaH000Cooo]Z00?oo`3ZoookJ_oonfX03?oonfX00ol0Looooo]ZoookJP09oookJP04okWo0?oonf[o
oe80o`0Zo`;ooo]Z00Go?ol0o`3Loooonf[o0?oOogSo0006oookJP04o`2>ool0oa_ooo]Zooo:00?o
oo]Z00?o0?Woool0Tooo01<01OoonfX00ooJo`3ohOl0oookJP02oookJP03obH0oolPo`3ooo]Z00ko
oo]Z00Co<Ol0oookJ_oonf[o0?mK0_oonfX02?n2o`3ooo]Zo`3o/Ol0<?oo0?m=o`3Xoooonf[o1P3o
0_oonfX01onBo`3ooo]ZoookJ_oonf[o403oo`1Mool06Ol01?oonfX00ooo057ooo]Zo`2]o`03oook
JP03ool0NOoonf[ooo]Z02Kooo]Z000ZoookJP03ool0m_oonf[ooo]Z00;ooo]Z00GoU?l0oookJ_oo
nf[oZ03oool0n@02oookJP05o`1goooonf[ooo]ZoookJ_ooK0000_oUo`000olko`3ooo]ZoookJP03
oookJP05o`3koooonf[ooo]ZoookJ_oo0`000_oonfX01_mi0?oooo]Zool0gOl05ooo0:?ook?o00Go
oo]Z00Go0?oNomgo0?oo08Oooo]Zool0K002oookJP06odd0oooo;P3ooo]ZoookJ_mQ0?oo0?m50ooo
nfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Kooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?oo07Co
onKo0002oookJP03oon@0?oonf[ooo]Z00Kooo]Z00Cookh0oookJ_l0o`coj`3o1_oonfX00oooE`3o
oo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0e?oo
00CooookJ_oonf[o0:Wo00?ooo]Z00?o0?m>o`3o=?oonfX01OoonfX01?l0hOoo0?lMoookJ_l0oe<3
oookJP0@ool0NOoob@3ooo]Zool0DOoonf[o01Woo`3oGOoonf[oT_l0o`H0ool0j?oo0?m=ooo90?n2
o`3o0?mKoc7o00Oooo]Z00KoQ03oobH0oooonf[ohOl0om[o0?oonfX5ooo9000;o`3o6ooob@3ooo]Z
ocd0oomho`3o0=coocoo0?l0:_oooe80okWo0?l007l00ooonfX01?l007oo07?oo`00OooonfX3o`00
O`?ooo]Z00_oo`3Zo`00Oooo5P3ooi80oookJ_oo0?co603oool60?oonf[ojol0o`2Vo`02oomi0003
o`1gooooN@3oof`000;o>ol00oooN@000ol0noooo`<0ool30003ool0g@?o/ol01OooN@000ol0omko
o`27ool0Q`04ool0Q`CoogT01?oob@06ool0Q`03ooo90?oMo`3oU?l000WoU?l000?oN@3ooomi0?oo
N@000oooN@003Ol0nooooo]Zoc_o0?ooP@3o0?o<oom/0?l0oi[ooo]Zo`1goooo0?WoZ03ooookJ_l0
Y_l00_oonfX01?o[o`3ooo]Zool60?lH0?l3oookJP05onGo0?oonf[ooo]ZoonB0?oo5P001OoonfX0
0ooo0>[ooo]ZoookJP0<oookJP03o`1coooonf[ooo]Z00Oooo]Z00?o^Ol0oookJ_ooDP000_oonfX0
1ol0:_oooo]ZoookJ_loo`3o0=coogSo0?l0oml01_oonfX01?l0S_oo0?lKoookJ_oobP04oookJP03
ool0TooUo`3ooo]Z00Cooo]Z00?of_l0onGo0?oUo`000_oonfX00olV0?oooo]ZoookJP0>oookJP04
oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00SoiOl0oookJ_l0ok7oU?l0o`3oCOoonf[o0>Soo`H0o`;ooo]Z
00OoT_l0oookJ_oonf[ooo]Zoa00oooonf[o01Wo00?ooo]Z00Coo`1AoookJ_lE0?oo0:go0_oonfX0
0ooo07Wooo]ZoookJP1>oookJP05ool0m_oonf[ooo]ZoookJ_l0Y_l00_oonfX01OnX0?oooo]Zool0
nOoonf[o07Oo00?ooo]Z00Goof`0oookJ_ooP@3ooo]Zoc_o0004oookJP05o`3koooonf[ooo]Zoook
J_oo0`000ooonfX01Omi0?ooo`3Mo`0Gool0Xooo/ol000Kooo]Z00Go0?oNool0Qooonf[ooo]Zool0
K002oookJP05odd0oooo;P3ooo]Zof40ool0odD01?oonfX01OoR0?oooo]ZoookJ_oonf[o0?nB00Go
oo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?oo07CoonKo0002oookJP03oon@0?oonf[ooo]Z00Oo
oo]Z00Cookh0oookJ_o[0?ooL03o1OoonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z
00Gooo]Z00?ooh40oookJ_oonfX01OoonfX01?l0e?oo00CooookJ_l0ZOl4oookJP03o`3oC_oonf[o
oo]Z00Cooo]Z00Co0>7oo`3o7Ol0o`So0?mC1?oonfX00ooo07Wooo]Zool0D@02oookJP0:o`0Iool@
0?ooT_l0oookJ_l0j?oo0?m=o`3o/?n2o`3ooo]Zoc7o00Oooo]Z00GoQ03oobH0oooonf[ohOl0om[o
0002oookJP05ool04ooo09?ooo]Zooo:0?l0oa/00ooonfX01ol0omooN?l0ocoo0?l0:_oooe80o`3o
<ol007l00ooonfX01?l007oo07?oo`00OooonfX3o`00O`?ooo]Z017oo`3Zo`00Oooo5P3ooi80oook
J_oo0?cooo]ZoaP0oooo1P3ojol0o`2Vool0003oZ03oool0nOl0Mooooo]Zoom/0002oc_o00;ooo]Z
0_l0nol2ool300;oo`3M0onco`001OnO0?oooo]ZoookJ_oonf[ogOl000;o0?oN1_oo08L6oookJP03
o`3og_oo08Ooo`2700Goo`2700?ogOl0oookJ_oonfX00_oonfX2ok?o00;o0:?o0_oo0=d2ogT0o`;o
o`<00_oonfX03Ol0nooooo]Zoc_o0?oonf[ooh40oom/0?l0oi[ooo]Zo`1goooo0?Wooo]ZojP0ool0
Y_l00_oonfX01?oo0?Kojol0ool60?lH0?l3oookJP06ool0o?oonf[ooo]ZoonB0?oonf[ooaH01?oo
nfX00ooo0>[ooo]ZoookJP0<oookJP03o`1coooonf[ooo]Z00Sooo]Z00Go^Ol0oookJ_ooDP3ooo]Z
o`0Zo`02oookJP04ocoo0?l0g?oo?@3oogSo00Oooo]Z00?o0?lKoookJ_oobP001?oonfX00ooo09?o
o`0CoookJP04oookJP03om[o0?oQo`3ooo]Z00;ooo]Z00?o9P3oob3o0?oonfX03_oonfX04_lao`3o
oo]ZoookJ_oonf[o0?mKoookJ_n2o`3ooo]Zo`3o/Ooonf[o033oo`3oCOl0j?oooo]Zo`H0oooonf[o
o`3eoi;o00;ooo]Z00?o403oool0J_l06Ol01?oonfX00ooo057o5@3oo`2]o`03oookJP03ool0NOoo
nf[ooo]Z02Kooo]Z000ZoookJP03ool0m_oonf[ooo]Z00;ooo]Z00GoU?l0oookJ_nX0?oooo]Zool0
n@02oookJP04o`1goooonf[ooo]ZoiCo00?oiOl000?o>ol0oookJ_oonfX00ooonfX01Ol0nooooo]Z
oookJ_oonf[oo`<000;ooo]Z00GoN@3oool0gOoonf[o01Oook?o0006oookJP08o`3og_oo08Oooo]Z
oookJ_oo06cooo]Zodd0oooUo`02oookJP03of40oooonf[o0?m500;ooo]Z00?ohP3ooookJ_l0oi00
0_oonfX00ol0oi;ooo]ZoookJP04oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603oonKo0?oonf[o
oo]Zoon@0009oookJP04oonn0?oonf[o0?l<on/0o`Kooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo
02gooo]ZoookJP05oookJP03oon10?oonf[ooo]Z00Cooo]Z00Go0=Coo`04oooonf[ooo]Zo`2Yo`03
oookJP03o`3oC_l0ocCooo]Z00Cooo]Z00Go0>7oo`3o7Ol0o`Sooo]Zo`3oD`02oookJP04ool0NOoo
nf[oolT0ool0D@;ooo]Z00_o0?mMool0J_nBo`3o1P3oo`3Xool0odgoolT0oh;o0?l0oe_oolT0oc7o
0007oookJP05ob3o0?lV0?oohOl0om[o0?oonfX01Ooob@002_l0oa_oolT0oookJ_lm0?ooN?l0o`3L
ooloo`3o02[ooomB0?nio`02o`00O`?ooo]Z00Co07?oo`00Ool007oooo]Z0ol007l2oookJP06ool0
j_l007oooi80oonB0?oonf[oo`3l0_oo1P000ooonf[ojol0oomi0002oomi0005o`1gooooN@3o>ol0
oc_o0?ooP@000oooN@02ool300;oo`3M00?o0:?ook?o0?nco`001?ooN@001?l0omkoo`27ool0Qooo
08LAool0K0CoolT000?oo`27oiCo0?nDo`002_nDo`000omi0?ooogT0oomi0003oomi00;o0?_o0_lk
o`002?ooP@3oof`0oookJ_oonf[o07Ooool0nOnX0?oo0:Ko0ooonfX01?o[o`3ooo]Zool60?lH0?l3
oookJP05onGo0?oonf[ooo]ZoonB0?oo5P001?oonfX00ooo0>[ooo]ZoookJP0=oookJP03o`1coooo
nf[ooo]Z00Oooo]Z00Go^Ol0oomB0?oonf[ooo]Zo`0Zo`02oookJP04ocoo0?l0g?oo?@3oogSo00Ko
oo]Z00Co08koo`3o6ooonf[oolX01?oonfX00ooo09?oiOl0oookJP04oookJP03om[o0?oUo`3oiOl0
00;ooo]Z00?o9P3oob3o0?oonfX03_oonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP08onGo0?oonf[o
oo]ZoiCo0?l0odgooo]Zo`3Xool60?l2oookJP07oi;o0?oonf[ooo]ZoookJ_l@0?ooo`1Zo`0Io`04
oookJP06ool0DOlE0?oooo]Zo`2]oooonf[oo`1iD?oonfX01ooo0?Kooo]ZoookJ_oonf[o0:Kooook
J_nX0?l00_oonfX00ooo0?Wooo]Zo`1go`02oookJP06o`3oV_ooK03ooh40o`3oc?oonf[o>ol01?oo
nfX01Ol0nooooo]ZoookJ_oonf[oo`<000;ooo]Z00KoN@3oool0gOoonf[o01Ooo`2Soonco`06oook
JP04o`3og_oo08Oooo]Zool0K0;ooo]Z00KoC@3oool^0?oonf[ooo]Zof40ool0odD3oookJP05on80
ool0oi3ooo]ZoookJ_l0oi801_oonfX00omX0?oooo]ZoookJP02oookJP03oaP0oooVo`3ooo]Z00;o
oo]Z00?ooi00oookJ_oonfX01ooonfX00ooo_P3ooo]Zon/0o`06oookJP03oomG0?oonf[ooo]Z00;o
oo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP04oookJP05o`3Dool01?oooo]Zoook
J_l0ZOl01?oonfX00ol0odkooo]ZoookJP04oookJP04o`3o7Ooonf[o0?l8o`3oD`?ooo]Z013oo`1i
o`2]oooo057o5@3ooookJ_l06Ooo403ooi;o0?oonf[o0>Soo`3oCOl0<?oo0?n`oh;o0?l0oe_o<Ol0
1ooonfX01?lPo`3o9P3oon7o0?oJo`02oookJP06ool04ooo09?ooo]Zooo:0?l0oa_o08ko0_oonfX0
1_l0omooN?l0o`3Lool0:_oooe80o`3o<`;o001o0ooonfX01?l0Looo001oo`00OooonfX3o`00O`;o
oo]Z00Coo`3Zo`00Oooo5P3ooi800_oonfX02_oo0?coo`H0ool60?o[o`3o0:Koo`000?nX0?ooo`3i
o`1gooooK002oc_o00;ooo]Z0_l0nol01?oo0`3ooo]Zool0gOoo0=d2ok?o0005oil0oooonf[ooo]Z
omgo0?l0omh01?oo08LAool0K0;ooo]Z0_l0omh4ool0Q`?ooo]Z0_nco`001ol0Xooo01Ooool0gOoo
nf[oN@3ooookJ_oo0`000_oonfX2o`3ko`;o>ol00_ooP@02oookJP05o`1goooo0?Wooo]ZojP0ool0
Y_l00_oonfX01?o[o`3ooo]Zool60?lH0?l3oookJP06ool0o?oonf[ooo]ZoonB0?oonf[ooaH00ooo
nfX00ooo0>[ooo]ZoookJP0=oookJP03o`1coooonf[ooo]Z00Sooo]Z00Co^Ol0oomB0?oonf[o02[o
0_oonfX01Oloo`3o0=cooookJ_l0omooN?l000Kooo]Z00?o0?lKoookJ_oobP001?oonfX00ol0nOoo
o`2Cool04`04oookJP03om[o0?oQo`3ooo]Z00;ooo]Z00?o9P3ooh@0oolPo`003_oonfX04_lao`3o
oo]ZoookJ_oonf[o0?mKoookJ_l0ok3oP_l0oookJ_l0ok7o033oo`3oCOl0j?oooo]Zo`H0oooonf[o
o`3eoi;o00;ooo]Z00Co403oool0J_oonf[o01Wo0ooonfX01?oo057o5@3ooookJ_l0[Ol2oookJP03
ool0NOoonf[ooo]Z02Kooo]Z000ZoookJP03ool0m_oonf[ooo]Z00;ooo]Z00GoU?l0oookJ_nX0?oo
oo]Zool0n@02oookJP04o`1goooonf[ooo]Zoom/00?oiOl000?o>ol0oookJ_oonfX00_oonfX00ol0
nooooo]ZoookJP02oookJP08ool30?oonf[ooo]ZogT0oooo0=gooo]Zo`2Soonco`06oookJP08o`3o
g_oo08Oooo]ZoookJ_oo06cooo]Zodd0oooUo`02oookJP03of40ool0odGooo]Z00;ooo]Z00?ohP3o
oookJ_l0oi000_oonfX00ol0oi;ooo]ZoookJP04oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603o
onKo0?oonf[ooo]Zoon@0008oookJP05oonn0?oonf[o0?l<o`3o3?o[0?l01OoonfX00oooE`3ooo]Z
oookJP02oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX01?oonfX01_l0e?oo00Co
oookJ_oonf[o0:Woo`28o`;ooo]Z00?o0?m>o`3o;_l0oc@01OoonfX01?l0hOoo0?lMoookJ_l0oe<3
oookJP0@ool0NOoob@3ooo]Zool0DOoonf[o0?mMool0J_oonf[oT_l0o`H0ool0j?oo0?m=ooo90?n2
o`3o0?mKoc7o00Oooo]Z00Go8?l0obH0oooonf[of_l0oookJP05ooo9000:o`3o6ooob@3oolT0ocd0
oomho`3o0=coocoo0?l0:_oo0?lcoomB00Co001o00?ooo]Zo`1cool007l00_l007l2oookJP?o001o
00Woo`3Zo`00OoooTP3o001ooookJ_oo0?coo`H0oookJ_o[o`001?ooN@001?l0MoooogT0oc_o0?oo
P@02oookJP03o`3kooooN@3oo`<000;oo`3M0onco`02oookJP03oomi0?l0omkoo`2700;oo`270ooo
06`00ooonf[oogT0oomi000>oomi00Coo`1/0ooonfX00ol0omkoU?l0oiCo0008oiCo0003ool0gOoo
N@3oogT000?oogT000Kooo]Zo`3koooonf[o>ol0oon10?ooK002oookJP04o`1goooo0?WoZ03oo`2V
o`;ooo]Z00Gojol0oookJ_oo1P3ooo]ZoaP0o`02oookJP04onGo0?oonf[ooo]ZoookJP;oiOl01?oo
nfX00ooo0>[ooo]ZoookJP0<oookJP03o`1coooonf[ooo]Z00Oooo]Z00Go^Ol0oookJ_ooDP3ooo]Z
o`0Zo`02oookJP04ocoo0?oonf[o?@3oogSo00Oooo]Z00?o0?lKoookJ_oobP001?oonfX00ooo09?o
iOl0oookJP03onGo0004oookJ_oJo`3ooo]ZonGo00?ooo]Z00?o9P3ooookJ_oonfX03_oonfX00ola
o`3ooo]Zo`3oF`02oookJP08onGo0?oonf[ooo]ZoiCo0?l0odgooo]Zo`3Xool60?l2oookJP07oi;o
0?oonf[ooo]ZoookJ_l@0?ooo`1Zo`0Io`04oookJP06ool0DOlE0?oooo]Zo`2]oooonf[oo`1iD?oo
nfX01ooo0?Kooo]ZoookJ_oonf[o0:KooookJ_nX0?l00_oonfX00ooo0?Wooo]Zo`1go`02oookJP03
o`3oV_ooK03ooh4000;ooo]Z00Go>ol0oookJ_oonf[ooo]Zo`3ko`04oookJP09ool30?oonf[ooo]Z
ogT0oooo0=gooo]Zo`2SoonO0?oo/ol000Gooo]Z00GogOl0o`3og_oo08Oooo]Zool0K002oookJP05
odd0oooo;P3ooo]Zof40ool0odD01?oonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Kooo]Z00?oJ03o
oookJ_oonfX00_oonfX01OlH0?ooi_l0oookJ_oonf[ooi0000Wooo]Z00Cookh0oookJ_l0o`Goj`3o
1OoonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX0
1OoonfX01Ol0e?oo00CooookJ_l0ZOoo08So00?ooo]Z00?o0?m>o`3o=?oonfX01?oonfX01?l0hOoo
0?lMo`3o2?l0oe<4oookJP03ool0NOoonf[oo`1A00;ooo]Z00[o403ooookJ_nBo`3ooo]Zo`3Xool0
odgo0?naoh;o0?l0oe_o<Ol01ooonfX01?n40?oo9P3ooookJ_oJo`02oookJP06ool04ooo09?ooo]Z
oookJ_l0oa_o08ko0_oonfX01_l0omooN?l0o`3Lool0:_oooo]ZoomB00Co001o00?ooo]Zo`1cool0
07l00_l007l2oookJP?o001o00Coo`3Zo`00Oooo5P3ooi800_oonfX01ooo0?coo`H0on_o0?o[o`3o
0:KoojP0oooo0?T00_l0Mol00oooK03o>ol0oon10002oookJP04o`3koooo0`3oN@3oool0g@?o/ol0
00CoW`3ooookJ_oonf[o0?oN0ooo08L01Ooonf[oo`1/ool0K?oo06cooo]Z013oC@3o1?oo06`2oook
JP;o0?oN00?oo`27oookJ_oonfX00_oonfX2ok?o0006o`2Soooo0=goo`3MogT0oooonf[oo`<00ooo
nfX01Ol0nooooo]Zoc_o0?l0olcooh4000;ooo]Z00_o07Ooool0nOoonf[oZ03oo`2Voooonf[oo`3f
on_o0?oo1P3ooo]ZoaP0o`02oookJP06ool0o?oonf[ooo]ZoookJ_ooTP3ooaH01?oonfX00ooo0>[o
oo]ZoookJP0<oookJP03o`1coooonf[ooo]Z00Sooo]Z00Co^Ol0oookJ_ooDP3o02[o0_oonfX01Olo
o`3ooo]Zo`3Lool0omooN?l000Kooo]Z00Co0?lKoa80oooonf[oolX00ooonfX00ol0nOooo`2Cool0
4`05oookJP03om[o0?oQo`3ooo]Z00;ooo]Z00?o9P3oob3o0?oonfX03_oonfX04Olao`3ooo]Zoook
J_l0oe_ooo]Zo`3o/?n2o`3ooo]Zo`3o/Ol0<?oo0?m=o`3Xoooonf[o1P3ooookJ_oo0?GoT_l000;o
oo]Z00Co403oool0J_oonf[o01Wo0ooonfX01?oo057o5@3ooookJ_l0[Ol2oookJP03ool0NOoonf[o
oo]Z02Kooo]Z000ZoookJP05ool0m_oonf[ooo]ZoookJ_nDo`000_oonfX00onX0?oooo]Zool0n@02
oookJP03o`1goooonf[ooo]Z00CoiOl000?o>ol0oookJ_oonfX00_oonfX00ol0nooooo]ZoookJP02
oookJP08ool30?oonf[ooo]ZogT0oooo0=gooo]Zo`2Soonco`05oookJP05o`3og_oMo`3oo`27oook
J_oo06`00_oonfX01_m=0?ooiOl0oookJ_oonf[oH@3oo`3oA@?ooo]Z00GohP3ooookJ_l0oi3ooo]Z
o`3oTP06oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603oo`1doooVo`000_oonfX00oooT03ooo]Z
oookJP06oookJP05oonn0?oonf[o0?l<o`3o3?o[0?l01OoonfX00oooE`3ooo]ZoookJP02oookJP03
ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0e?oo00CooookJ_oonf[o0:Wo
00?ooo]Z00?o0?m>o`3o=?oonfX01OoonfX01?l0hOoo0?lMoookJ_l0oe<2oookJP0Aool0NOoonf[o
olT0ool0DOlE0?oooo]Zo`3oGOoonf[oT_l0o`H0ool0j?oo0?m=ooo90?n2o`3o0?mKooo90?lao`00
1ooonfX01?lPo`3o9P3oon7o0?oJo`06ooo90009o`3o6ooob@3oolT0ocd0oomho`3o0=coocoo0?l0
:_oooe8000;ooo]Z0ol007l01?l0Looo001oo`00Ool007l3oookJP;o001o00?oo`3Zo`00OoooTP00
0_l007l00ooo0?coo`H0oookJP05oomi0003o`1gooooN@3o>ol000;ooo]Z0_l0nol00ooo0`3oN@3o
ool0g@02ok?o0004oil0oooonf[ooo]Zo`3ogP?oo`270ooo06`2odd0o`OoH@3o2OooN@000omQ0?oo
ogT0oomi0003odd0o`Coo`1/1?oob@07oiCo0003ool0gOooN@3oogT000?oogT000Kooo]Zo`3koooo
nf[o>ol0oon10?ooK002oookJP04o`1goooonf[oZ03oo`2Vo`;ooo]Z00Cojol0oookJ_oo1P3o603o
0ooonfX5onGo00Cooo]Z00?oo`3ZoookJ_oonfX03OoonfX00ol0Looooo]ZoookJP06oookJP03okWo
0?oonf[ooe8000;ooo]Z00Ko02[ooookJ_oonf[o?ol0o`3Loomho`07oookJP04o`2>ool0oa_ooo]Z
ooo:00?ooo]Z00?oiOl0ool0TooUo`000ooUo`001?oonf[of_l0oookJ_oQo`03oookJP03obH0oooo
nf[ooo]Z00kooo]Z00Co<Ol0oookJ_oonf[o0?mK0_oonfX02_oUo`3ooo]ZoiCo0?oonf[o0?m=o`3X
oooonf[o1P3ooookJ_nBo`04oookJP03oa00ool06Ooooo]Z00?ooo]Z00Koo`1AoaD0oooonf[o0:go
oookJ_oo07U?oookJP05ool0m_oonf[ooo]ZoookJ_l0Y_l00_oonfX01_nX0?oooo]ZoookJ_oo0?Wo
oo]Zo`1go`;ooo]Z00?o0?nJoom/0?ooP@000_oonfX01Olko`3ooo]ZoookJ_oonf[o0?_o00Cooo]Z
00Soo`<0oookJ_oonf[oN@3oool0gOoonf[o0:?ook?o00Kooo]Z00Go0?oNool0Qooonf[ooo]Zool0
K002oookJP05odd0oooo;P3ooo]Zof40ool0odD01?oonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Go
oo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?oo07CoonKo0002oookJP03oon@0?oonf[ooo]Z00Oo
oo]Z00Cookh0oookJ_l0o`Goj`3o1OoonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z
00Gooo]Z00?ooh40oookJ_oonfX01OoonfX01?l0e?oo00CooookJ_l0ZOl4oookJP03o`3oC_oonf[o
oo]Z00Cooo]Z00Co0>7oo`3o7Ol0o`So0?mC0ooonfX04?oo07Wo0:goool0DOlE0?oooo]Zo`0Iool@
0?ooT_l0oookJ_l0j?oo0?m=o`0`ool0ok3oP_l0o`3oFolao`07oookJP04ob3o0?lV0?oohOl0om[o
00;ooo]Z00Goo`0Cool0Tooonf[oolX0o`3o6`03oookJP05o`3ogomho`3o?ol0o`0ZooooDP000_oo
nfX3o`00O`04o`1cool007oo001oo`00O`?ooo]Z0_l007l04Ooo0>[o001ooolF0?ooTP3o001ooook
J_oo0?coo`H0on_o0?oo0?Ko0:KoojP0oooo0?Wo07Ooo`3oc?ooK03o>ol000;ooo]Z0_l0nol01?mi
0?ooo`3Mok?o0?nco`02oil0o`;ooo]Z0ooo08L01?oonf[oo`1/ool0K?oo06`2odd0oa3oH@3o0_oo
nfX01?oo;P3oC@3oodd0oom=0?l3ool0K004oookJ_l0omkoo`27ool0Q`Cooo]Z0_nco`001Ol0Xooo
o`3MogT0oooonf[oo`<000?ooo]Z00Go0?_ooookJ_lko`3o0?o<oon10002oookJP04o`1goooonf[o
oo]ZojP0o`;ooo]Z00Coo`3fon_o0?oo1P3o603o0ooonfX01_oo0?cooo]ZoookJ_oonf[ooi80oolF
00?ooo]Z00?oo`3ZoookJ_oonfX03OoonfX00ol0Looooo]ZoookJP07oookJP05okWo0?oonf[ooe80
oookJ_l0:_l00_oonfX01?loo`3o0=coo`3ogomho`06oookJP04o`2>ool0oa_ooo]Zooo:00?ooo]Z
00?o0?WooookJ_oo09<01OoonfX00ooJo`3ohOl0oookJP02oookJP03obH0oolPo`3ooo]Z00kooo]Z
00ko<Ol0oookJ_oonf[ooo]Zo`3oFooonf[oP_l0oookJ_l0ok7o033oo`3oCOl0j?oooo]Zo`H0o`;o
oo]Z00OoT_l0oookJ_oonf[ooo]Zoa00oooonf[o01Wo00Cooo]Z00?oo`1AoookJ_l0[Ol00_oonfX0
0ooo07Wooo]ZoookJP0VoookJP00:_oonfX01Ooo0?Kooo]ZoookJ_oonf[oU?l000;ooo]Z00GoZ03o
oookJ_oo0?Wooo]Zo`1go`03oookJPCoiOl000?o>ol0oookJ_oonfX00_oonfX01Ol0nooooo]Zoook
J_oonf[oo`<000?ooo]Z00GoN@3oool0gOl05ooo0:?ook?o0005oookJP07o`3og_oMo`3oo`27oook
J_oo06cooo]Zodd0o`02onGo0004oookJ_mQ0?oooo]Zo`3oA@?ooo]Z00GohP3oo`3oT?oonf[ooo]Z
o`3oTP06oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603oonKo0?oonf[ooo]Zoon@0009oookJP05
oonn0?l0o`co0?l<on/0ool0o``01OoonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z
00Gooo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0e?oo00CooookJ_oonf[o0:Wo00?ooo]Z00?o0?m>
o`3o=?oonfX01?oonfX01?l0hOoo0?lMoookJ_l0oe<3oookJP0@ool0NOoob@3ooo]Zool0DOoonf[o
0?mMool0J_oonf[oT_l0o`H0ool0j?oo0?m=oh;o0?l0oe_oolT0oc7o00Oooo]Z00Co8?l0obH0oooo
nf[of_l00_oonfX01Ooo09?oolT0ooo90?oob@3o0?lK00;oolT000Ko?@3oogSo0?l0g?oo?ol0o`0Z
ooooDP04oookJP03o`00Ool0Looo001o00;o001o1OoonfX00ooo0>[o001ooonB0002o`00O`03ool0
o?oo1P3oogT000CoogT00_l0Mol00oooN@3o>ol0o`000002o`3ko`06ool30?mi0?ooo`3Mool0gOnc
o`3oW`3o0_oonfX3ool0Q`?oo`1/0_m=0?l3of40o`;o0?m50oooN@07on80o`KoogT00omQ0?l01?oo
;P3oC@3oodd0oom=0?l7ooo90003oomi0?nDo`3oU?l000?oU?l00_oo0=d5oomi00;ooo]Z00oo>ol0
oon10?ooK03ooo]Zo`1goooo0?Wooo]ZojP0ool0Y_oooo]Zool0m_o[o`3ooo]Zool60?lH0?l00_oo
nfX5onGo00Gooo]Z00?oo`3ZoookJ_oonfX03?oonfX00ol0Looooo]ZoookJP07oookJP05okWo0?oo
DP3ooo]ZoookJ_l0:_l00_oonfX01?loo`3o0=coocd0oomho`06oookJP05o`2>ool0oa_ooo]Zooo:
0?oonfX00ooUo`000ooo09?oiOl0onGo0002onGo00;ooo]Z00?of_l0on7o0?oonfX00_oonfX00olV
0?oooo]ZoookJP0>oookJP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00_oiOl0oookJ_nDo`3ooo]Zo`3o
COl0j?oooo]Zo`H0oooonf[oo`3eoi;o0003oookJP03oa00oooonf[o01Wo00?ooo]Z00Koo`1AoaD0
oooonf[o0:gooookJ_oo07U?oookJP05ool0m_oonf[ooo]ZoookJ_l0Y_l00_oonfX00onX0?oooo]Z
ool0n@02oookJP06o`1goooonf[ooo]Zoom/0?oonf[ooh400_oonfX01Olko`3ooo]ZoookJ_oonf[o
0?_o00?ooo]Z00Woo`<0oookJ_oonf[ooo]ZogT0oooo0=go01Ooo`2Soonco`001_oonfX01?l0omko
o`27oookJ_oo06`2oookJP06odd0oooo;P3ooo]ZoookJ_mQ0?oo0?m51?oonfX01OoR0?oooo]Zoook
J_oonf[o0?nB00Gooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?ooi_l0oookJP02oookJP03oon@
0?oonf[ooo]Z00Oooo]Z00?ookh0o`3o1Oo[0?l01_oonfX00oooE`3ooo]ZoookJP02oookJP03ool0
;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0e?oo00CooookJ_oonf[o0:Wo00?o
oo]Z00?o0?l^o`3oC_oonfX01?oonfX01?l0hOoo0?lMo`3o2?l0oe<4oookJP03ool0NOoonf[oo`1A
00;ooo]Z00[o403ooookJ_nBo`3ooo]Zo`3Xool0odgo0?naoh;o0?l0oe_o<Ol01ooonfX01?n40?oo
9P3ooookJ_oJo`02oookJP06ool04ooo09?ooo]Zooo:0?l0oa_o08ko0_oonfX01_l0omooN?l0o`3L
ool0:_oooe80o`3o<`?ooo]Z00?o001oo`1cool007l00_l007l5oookJP0>ool0j_l007oooaH0oonB
0?l007oooo]Zool0o?oo1P3ojol0ool0m_l0Y_ooZ03oool0nOl0Mol2oom/0005oc_o0?oonf[o0?_o
o`3koomi0?l00_oo0=d01?nco`3oW`3ooookJ_oonfX3ool0Q`04oookJ_oo06coo`1/ool0K0;oC@3o
0omQ0?l3o`3oA@03oookJ_oR0?oohP3o00GohP3o0_oonfX3o`3oA@CoH@3o00?ooo]Zool^0?m=0?l0
0_m=0?l3ool0K003o`3og_oo08Ooo`2700Cooo]Z0_nco`02ool0g@05oookJ_oo0`3ooo]ZoookJ_l0
nol00_oonfX01_lko`3o0?o<oon10?oonf[o07Ooool0n@;ooo]Z00OoZ03ooookJ_oo0?Kojol0oook
J_oo1P3o603o00?ooo]Z00Goo`3loookJ_oonf[ooi80oolF0004oookJP03ool0j_oonf[ooo]Z00co
oo]Z00?o07?ooookJ_oonfX02?oonfX01?nio`3ooe80oookJ_l0:_l2oookJP04ocoo0?l0g?oooo]Z
ogSo00Oooo]Z00?o0?lKoookJ_oobP001?oonfX00ol0nOooo`2CoookJP04oookJP03om[o0?oQo`3o
oo]Z00;ooo]Z00?o9P3oob3o0?oonfX03_oonfX03_lao`3ooo]ZoookJ_oonf[o0?mKoookJ_n2o`3o
oo]Zo`3o/Ol0<?oo0?m=o`3Xoooonf[o1P3o0_oonfX02?nBo`3ooo]ZoookJ_oonf[o403oool0J_oo
nf[o01Wo0ooonfX00ooo057ooo]Zo`2]o`02oookJP03ool0NOoonf[ooo]Z02Kooo]Z000^oookJP05
oiCo0?oonf[oZ03ooookJ_oo0?T00_oonfX00ol0Mooooo]ZoookJP04onGo0003oc_o0?oonf[ooo]Z
00;ooo]Z00?o0?_ooookJ_oonfX00_oonfX02?oo0`3ooo]ZoookJ_mi0?ooo`3MoookJ_l0Xooo/ol0
1_oonfX01ol0omkoo`27oookJ_oonf[oo`1/oookJ_m=0?l00_oUo`001?oonf[oH@3ooookJ_l0odD2
oookJP03on80oooonf[o0?n@00;ooo]Z00?o0?nBoookJ_oonfX01?oonfX01omX0?oooo]ZoookJ_oo
nf[o603oo`1doooVo`000_oonfX00oooT03ooo]ZoookJP07oookJP05oonn0?l0o`co0?l<on/0ool0
o``01?oonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oo
nfX01?oonfX01_l0e?oo00CooookJ_oonf[o0:Woo`28o`;ooo]Z00?o0?m>o`3o=?oonfX01OoonfX0
1?l0hOoo0?lMoookJ_l0oe<2oookJP0Aool0NOoonf[o0:goool0DOlE0?oooo]Zoa00oooonf[oT_l0
o`H0ool0j?oo0?m=ooo90?n2o`3o0?mKooo90?lao`001ooonfX00olV0?oooo]Zom[o0002oookJP05
ool04ooo09?ooo]Zooo90?l0oa/00ooob@001_mho`3o0=coocoo0?l0:_oo0?lcoomB00Cooo]Z00?o
07?ooookJ_oonfX01_oonfX00ooo0>[ooo]ZoonB0002oookJP03ool0o?ooN@3oo`H000CoogT000So
07Oooomi0?ooN@3o>ol0o`000?l0nooooo]ZogT0o`;oo`3M0_nco`001?oonf[oobP0oolX0?oo08L3
ool0K0;oC@3o0omQ0?l2oookJPKohP3o0_l0oi05oomi00GohP3o1?ooN@03of40o`WoolT01?ooN@02
oiCo0003ogT0oooo0=googT000?oogT000_o0?_ooookJ_oonf[o>ol0o`3oV_ooK03ooo]Zo`1goooo
0?Wooo]ZojP0o`02oookJP04ool0m_o[o`3oo`H0oookJPSoiOl01OoonfX00ooo0>[ooo]ZoookJP0;
oookJP03o`1coooonf[ooo]Z00Oooo]Z00Go^Ol0oomB0?oonf[ooo]Zo`0Zo`02oookJP04ocoo0?oo
nf[o0=coogSo00Kooo]Z00Go08koo`3o6olB0?ooolX0oookJP03onGo0003ool0TooUo`3oiOl000;o
iOl00_oonfX00ooJo`3ohOl0oookJP02oookJP03obH0oolPo`3ooo]Z00kooo]Z00Co<Ol0oookJ_oo
nf[o0?mK0_oonfX02ooUo`3ooo]ZoiCo0?oonf[o0?m=o`3Xoooonf[o1P3ooookJ_oo0?GoT_l000?o
oo]Z00?o403oool0J_l06Ol00ooonfX01_oo057o5@3ooookJ_l0[Ooooo]Zool0NE?ooo]Z00?o0:Ko
oookJ_nX0?l00_oonfX00ooo0?Wooo]Zo`1go`02oookJP06o`3oV_ooK03ooo]Zoon10?oonf[o>ol0
0ooonfX00ol0nooooo]ZoookJP02oookJP09ool30?oonf[ooo]ZoookJ_oo0=gooo]Zo`2Soooonf[o
/ol000Kooo]Z00Co0?oNool0Qooonf[oo`1/0_oonfX01_m=0?ooobh0oookJ_mQ0?oooo]Zo`3oA@?o
oo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP07ofP0oooonf[ooo]ZoookJ_lH0?oo07CoonKo
0002oookJP03oon@0?oonf[ooo]Z00Oooo]Z00Cookh0oookJ_l0o`Goj`3o1OoonfX00oooE`3ooo]Z
oookJP02oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX01OoonfX01Ol0e?oo00Co
oookJ_l0ZOoo08So00?ooo]Z00?o0?m>oookJ_oonfX01?oonfX01?l0hOoo0?lMo`3o2?l0oe<3oook
JP0@ool0NOl0[Oooo`1AoaD0oooonf[o01Wooa00oonBo`3ooo]Zo`3Xool0odgo033ooh;o0?oonf[o
0?mKoc7o00Oooo]Z00?o9P3ooookJ_oJo`000ooonfX01Ooo01?oo`2CoookJ_l0oa_o4P3o00;ooo]Z
00Ko0?oOogSo0?l0g?oo02[ooookJ_ooDP04oookJP03o`1coooonf[ooo]Z00Kooo]Z00Coo`3Zoook
J_oo5P3ooi800_oonfX03Ooo0?cooo]Zool60?oo0?Ko0:KoojP0oooo0?Wo07Oooom/0?ooP@3o>ol0
o`000?l0nol00_mi0?l01?oo0=go/ol0ok?o0?oonfX3ool0Q`04o`3og_oo06coo`1/ool0K0;oC@3o
0omQ0?l2oookJPGohP3o1ol0oi06on80o`;ooo]Z00Co0?m5of40oomQ0?ooH@3o0_oo;P03odd0o`05
ool0K?oonf[o0?oNool0QooMo`000ooonfX01_nO0?oo/ol0o`2Soooo0=gooo]Zool300;ooo]Z00Wo
0?_ooookJ_oonf[o>ol0oon10?ooK03ooo]Zo`1goooo0?T00_oonfX01onX0?oooo]Zool0m_o[o`3o
o`H0oookJ_lH0?l00_oonfX01_oo0?cooo]ZoookJ_oonf[ooi80oolF00Cooo]Z00?oo`3ZoookJ_oo
nfX02ooonfX00ol0Looooo]ZoookJP08oookJP04okWo0?ooDP3ooo]Zo`0Zo`;ooo]Z00Go?ol0oook
J_l0g?oo0?oOogSo0006oookJP04o`3o6olB0?oooo]Zooo:00?ooo]Z00?o0?Woool0Tooo01<01?oo
nfX00ooJo`3ohOl0oookJP02oookJP03obH0oolPo`3ooo]Z00kooo]Z00co<Ol0oookJ_oonf[ooo]Z
o`3oFooonf[oP_l0oookJ_l0ok7o033oo`3oCOl0j?l2oookJP03o`H0oooonf[oT_l000?ooo]Z00Co
403oool0J_oonf[o01Wo0ooonfX00ooo057ooo]Zo`2]o`02oookJP03ool0NOoonf[ooo]Z02Kooo]Z
000]oookJP06oiCo0?oonf[ooo]ZojP0oooonf[oo`3i0_oonfX00ol0Mooooo]ZoookJP04onGo0003
oc_o0?oUo`3ooo]Z00;ooo]Z00?o0?_ooookJ_oonfX00_oonfX02?oo0`3ooo]ZoookJ_mi0?ooo`3M
oookJ_l0Xooo/ol01_oonfX01?l0omkoo`27oookJ_oo06`2oookJP06odd0oooUo`3oiOl0oookJ_mQ
0?oo0?m50ooonfX01OoR0?oooo]Zo`3oT?oonf[o0?nB00Kooo]Z00?oJ03ooookJ_oonfX00_oonfX0
0olH0?oo07CoonKo0002oookJP03oon@0?oonf[ooo]Z00Kooo]Z00Kookh0o`3o3?l0o`co0?l<on/0
ool0o``4oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]Z
oookJP04oookJP05o`3Dool01?oooo]ZoookJ_l0ZOl00ooonfX00ol0odko0?ldoookJP04oookJP04
o`3Qool0oagooo]Zo`3oD`?ooo]Z017oo`1io`2]oooo057o5@3ooookJ_l@0?ooo`1ZoookJ_nBo`3o
1P3oo`3Xool0odgoP_l0o`3oFooob@3o<Ol0ooo90006oookJP07ob3o0?lV0?oooo]Zom[o0?oonf[o
o`0Cool0T`02oookJP03ooo90?l0oa_oolT000;oolT000Go0?oOo`3Looloo`3o02[ooomB0005oook
JP03o`1coooonf[ooo]Z00Gooo]Z00?oo`3ZoookJ_ooTP000_oonfX00ooo0?coogT0ool60004oomi
0004o`1gooooN@3o>ol0oc_o00;o0?_o00Goo`<0ogT0oooo0=go0:?ook?o0004oolX00;oo`1/0_m=
0?l3of40o`03oookJ_oR0?oohP3o00;ohP3o1_l0oi02o`3oTP[oogT01?oR0?l00oooN@3ooo]Zooo9
000:ooo90007oookJ_ooN@3oogT0oomi0?nco`3o0:?oogT0o`05oomi000;o`3koooonf[ooo]Zoc_o
0?l0oi[oof`0o`1goooo0?Wooo]ZojP0ool0Y_l00_oonfX00oo[o`3ooo]ZonGo0008onGo00Gooo]Z
00?oo`3ZoookJ_oonfX03?oonfX00ol0Looooo]ZoookJP06oookJP03okWo0?oonf[ooe8000;ooo]Z
00Ko02[ooookJ_loo`3ooo]Zo`3Loomho`07oookJP03o`3o6olB0?ooolX000;ooo]Z0ooUo`001?oo
09?oiOl0onGo0?oUo`02oookJP03om[o0?oQo`3ooo]Z00;ooo]Z00?o9P3oob3o0?oonfX03ooonfX0
0olao`3ooo]Zo`3oF`02oookJP08onGo0?oonf[oU?l0oookJ_l0odgo0>SooookJ_l60?l2oookJP07
oi;o0?oonf[ooo]ZoookJ_l@0?ooo`1Zo`0Io`04oookJP05ool0DOoonf[o0:gooookJ_oo07T0D_oo
nfX01?l0Y_oooo]ZoookJ_nX0?l2oookJP03ool0nOoonf[o07Oo00;ooo]Z00?o0?nJoom/0?ooP@00
0_oonfX01Olko`3ooo]ZoookJ_oonf[o0?_o00Cooo]Z00Woo`<0oookJ_oonf[oN@3oool0gOoonf[o
0:?ooookJ_nco`001OoonfX01OoMo`3oo`27oookJ_oonf[oo`1/00;ooo]Z00GoC@3oool^0?oonf[o
H@3oo`3oA@04oookJP05on80ool0oi3ooo]ZoookJ_l0oi801OoonfX00omX0?oooo]ZoookJP02oook
JP03oaP0ool0M?ooi_l000;ooo]Z00?ooi00oookJ_oonfX01ooonfX01?oo_P3o0?l5oookJ_o[0?l5
oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP05
oookJP04o`3Dool01?oooo]Zo`2Yo`Cooo]Z00?o0?m>oookJ_oonfX01?oonfX00ol0hOoo0?lMo`3o
D`04oookJP0?ool0NOoo057ooo]ZoaD0oooonf[o403ooookJ_nBo`3ooo]Zo`3Xool0odgo0?naoh;o
0?l0oe_o<Ol000Oooo]Z00CoQ03oobH0oooonf[of_l00_oonfX01Ooo01?oo`2CoookJ_oobP3o0?lK
00?ooo]Z00GoN?l0o`3Looloo`3o02[ooomB0005oookJP03o`1coooonf[ooo]Z00Gooo]Z00Coo`3Z
oookJ_oo5P3ooi800_oonfX01_oo0?cooo]Zool60?oo0?Ko0:Koool0n@;o07Oo00?oof`0oc_o0?lk
o`000_l0nol02Omi0?ooo`3Mool0gOnco`3o01OooookJ_oo08Oo0?oNomgo0002ool0K0;oC@3o0omQ
0?l00ooonf[ohP3oon80o`02on80o`Go0?n@2Ol0oi801?oonf[o0?n@o`3oT?l0oi04on80o`;ooo]Z
0omQ0?l2ool^0004odd0oooo06cooo]ZoookJP;oo`270ooonfX01_nco`3oW`3oo`2Soooo0=gooo]Z
ool300;ooo]Z00So0?_ooookJ_oonf[o>ol0oon10?ooK03ooo]Zo`1go`;ooo]Z00OoZ03oo`2Voooo
nf[oo`3fon_o0?oo1P3o603o00?ooo]Z00Goo`3loookJ_oonf[ooi80oolF0004oookJP03ool0j_oo
nf[ooo]Z00cooo]Z00?o07?ooookJ_oonfX01ooonfX02onio`3ooo]ZoomB0?oonf[o02[ooookJ_lo
o`3ooo]Zo`3Lool0omooN?l000Kooo]Z00Co0?lKoa80oooonf[oolX00ooonfX00ol0nOoooo]Zool0
T`05oookJP07om[o0?oonf[ooo]ZoookJ_lV0?ooQ03oob3o000?oookJP0;oc7o0?oonf[ooo]Zo`3o
Fooonf[o0?n`oh;o0?l0ok7o033ooookJ_l0odd00_oonfX00ol60?oooo]Zoi;o0003oookJP04oa00
oooo06[ooo]Zo`0Io`?ooo]Z00?oo`1AoookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP0VoookJP00
;OoonfX01_nDo`3ooo]ZoookJ_nX0?oooo]Zool0n@;ooo]Z00?o07OooookJ_oUo`001?oUo`000olk
o`3oiOl0oookJP02oookJP03o`3koooonf[ooo]Z00;ooo]Z00Soo`<0oookJ_oonf[oN@3oool0gOoo
nf[o0:?ook?o00Gooo]Z00Go0?oNomgo0?oo08Oooo]Zool0K002oookJP06odd0oooUo`3oiOl0of40
oooonf[o0?m50ooonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Kooo]Z00?oJ03ooookJ_oonfX00_oo
nfX01OlH0?oo07CoonKo0?oonf[ooi0000Wooo]Z00Cookh0o`3o3?l0o`coj`3o0_l0o``3oookJP03
oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP04oookJP05
o`3Dool01?oooo]Zo`2Yool0R?l00_oonfX00ol0odko0?l^o`3o=005oookJP04o`3Qool0oagooo]Z
o`3oD`?ooo]Z017oo`1io`2]oooo057o5@3ooookJ_l@0?oooo]Zoi;o0?l60?oooo]Zo`3oCOoob@3o
P_l0o`3oFooob@3o<Ol0ooo90006oookJP03obH0oooonf[of_l000;ooo]Z00Goo`2Co`3ioooonf[o
olT0o`3o6`02oookJP07ooo90?mho`3o0=coocoo0?l0:_oo0?lcoomB0004oookJP03o`1coooonf[o
oo]Z00Gooo]Z00?oo`3ZoookJ_ooTP000_oonfX00ooo0?co603oool60004oomi0003o`1gooooN@3o
>ol000;oogT000Co0000ool30?oo0=goo`3M0_nco`03oolX00;oo`1/00CoC@3oonGo0?oUo`3oiOl0
0_oonfX2on80o`?o0?n@0_nDo`04o`3oTP;ooo]Z3oooN@02on80o`03o`3oT?oonf[oolT000SoolT0
0_oo08L01?oonf[oogT0oomi0?nco`06oomi000@o`3koooonf[ooo]Zoc_o0?ooP@3o0?nJoom/0?l0
Moooo`3ioookJ_nX0?oo0:KooookJ_oo0?Kojol0ool600SoiOl01_oonfX00ooo0>[ooo]ZoookJP0;
oookJP03o`1coooonf[ooo]Z00Oooo]Z00[o^Ol0oomB0?oonf[ooo]Zo`0Zoooonf[o?ol0oookJ_l0
g?ooN?l01ooonfX01?l0S_oo0?lKoookJ_oobP02oookJP;oiOl000Coo`2ConGo0?oUo`3oiOl00ooo
nfX00ooJo`3ohOl0oookJP02oookJP03obH0oooonf[ooo]Z00kooo]Z00?o<Ol0oookJ_l0oe/00_oo
nfX02?oUo`3o0?n`o`3o/OnDo`3o0?m=o`3Xoooonf[o1P3o0_oonfX01onBo`3ooo]ZoookJ_oonf[o
403oool0J_l06Ol01?oonfX01Ooo057ooo]Zo`2]oooonf[oo`1i05;ooo]Z00Co0:KooookJ_oonf[o
Z03o0_oonfX00ooo0?Wooo]Zo`1go`02oookJP03o`3oV_ooK03ooh4000;ooo]Z00Go>ol0oookJ_oo
nf[ooo]Zo`3ko`04oookJP08ool30?oonf[ooo]ZogT0oooo0=gooo]Zo`2Soonco`06oookJP04o`3o
g_oo08Oooo]Zool0K0?ooo]Z00GoC@3oool^0?oonf[oH@3oo`3oA@04oookJP05on80oooonf[ooo]Z
oookJ_l0oi801OoonfX00omX0?oooo]ZoookJP02oookJP03oaP0ool0M?ooi_l000;ooo]Z00?ooi00
oookJ_oonfX01ooonfX01?oo_P3o0?l5on/0oom`0?l4oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?o
o`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP04oookJP05o`3Dool01?oooo]Zo`2Yool0R?l0
0ooonfX00ol0odko0?ldoookJP04oookJP04o`3Qool0oago0?l8o`3oD`Cooo]Z00ooo`1iool0DOlE
0?oooo]Zo`0Iool@0?ooT_l0oookJ_l60?oo0?m=o`3o/On2o`3ooo]Zo`3oFolao`001ooonfX00olV
0?oooo]Zom[o0002oookJP06ool04ooo09?ooo]ZoookJ_l0oa_o08ko0_oonfX01_l0omooN?l0ocoo
0?l0:_oooo]ZoomB00Cooo]Z00?o07?ooookJ_oonfX01OoonfX01?oo0>[ooo]ZoolF0?ooTP02oook
JP0=ool0o?oonf[oo`H0ool0m_l0Y_ooo`3io`1gooooK03o0?nJoc_o0?l0003o0?_oool30002ool0
g@;o/ol00_oonfX01Ooo08OogOl0ool0K?oo06coC@3o00?oH@3o00Cooo]Zon80oooR0?oohP3o0_l0
oi06o`3oTP[ooo]Z1Ol0oi800ooonf[o0?n@o`3oT002on80o`;ooo]Z00?o0?m5of40oooonfX00_oo
;P02ool0K0;ooo]Z00[oo`27oookJ_oonf[ooo]Zok?o0?l0Xoooo`3MogT0oooonf[oo`<00_oonfX0
2?l0nooooo]Zoc_o0?oonf[ooh40oom/0?l0Moooo`3i0_oonfX01onX0?oo0:Koool0m_o[o`3oo`H0
oookJ_lH0?l00_oonfX01Ooo0?cooo]ZoookJ_ooTP3ooaH000Gooo]Z00?oo`3ZoookJ_oonfX02ooo
nfX00ol0Looooo]ZoookJP08oookJP0:okWo0?ooDP3ooo]Zo`0Zoooonf[o?ol0oookJ_l0g?oo0?oO
ogSo00Kooo]Z00Co08koo`3o6ooonf[oolX00ooonfX00ol0nOoooo]Zool0T`05oookJP03om[o0?oQ
o`3ooo]Z00;ooo]Z00?o9P3oob3o0?oonfX03_oonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP05oh;o
0?l0ok7o033ooookJ_l0odd00_oonfX01?l60?oooo]Zool0mOnBo`02oookJP04oa00oooo06[ooo]Z
o`0Io`?ooo]Z00?oo`1AoookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP0VoookJP00;OoonfX01_nD
o`3ooo]ZoookJ_nX0?oooo]Zool0n@;ooo]Z00?o07OooookJ_oUo`001?oUo`001Olko`3oiOl0oook
J_oonf[o0?_o00Gooo]Z00Coo`<0oookJ_oonf[oo`3M0_oonfX00onco`3ooo]ZoookJP04oookJP07
o`3og_oo08Oooo]ZoookJ_oo06cooo]Zodd0o`03onGo0003of40oooonf[o0?m500?ooo]Z00GohP3o
o`3oT?oonf[ooo]Zo`3oTP06oookJP07ofP0oooonf[ooo]ZoookJ_lH0?oo07CoonKo0002oookJP03
oon@0?oonf[ooo]Z00Oooo]Z00Cookh0o`3o3?l0o`coj`3o0_l0o``3oookJP03oomG0?oonf[ooo]Z
00;ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP04oookJP06o`3Dool01?oooo]Z
oookJ_l0ZOoo08So0_oonfX00ol0odko0?ldoookJP04oookJP04o`3Qool0o`So0?lMo`3oD`?ooo]Z
017oo`1ioookJ_oo057o5@3ooookJ_l06Ooo403ooi;o0?oo0?Go1P3oo`3Xool0odgoP_l0ooo90?l0
oe_o<Ol0ooo90006oookJP0;ob3o0?lV0?oof_l0on7o0?oonf[oo`0Cool0Tooonf[oolT0o`3o6ol0
S_l00_oonfX01_mho`3o0?oOocoo0?oonf[o02[ooomB00Cooo]Z00?o07?ooookJ_oonfX01OoonfX0
2Ooo0>[ooo]ZoolF0?ooTP3oogT0ool0o?oob@3oo`H0on_o0003oomi0003o`1gooooN@3o>ol000;o
ogT000Go0000ool0gOoo0=goobP0ok?o0004oolX0003ool0K?oo:03oiOl000;oiOl000Cooo]Zon80
oooR0?oohP3o0_l0oi02o`3oTPOoU?l00_oonfX8oomi0003oookJ_oUo`3oiOl000;ooo]Z1?l0oi82
on80o`;ooo]Z00?o0?m5ooo90?oob@001Ooob@001_l0omkoo`27oookJ_oonf[oogT0ok?o00KoogT0
013o0?_ooookJ_oonf[o>ol0o`3oc?l0oi[oof`0o`1goooo0?WoZ03ooookJ_l0Y_oooo]Zool0m_o[
o`3oo`H01ooUo`000oooTP3ooo]ZoookJP03oookJP03ool0j_oonf[ooo]Z00_ooo]Z00?o07?ooook
J_oonfX01ooonfX01Onio`3ooe80oookJ_oonf[o02[o00;ooo]Z00Co?ol0o`3Loomho`3o0?oO1_oo
nfX01?l0S_oo0?lKoa80oooobP02oookJP;oiOl000Coo`2ConGo0?oUo`3oiOl00ooonfX00ooJo`3o
hOl0oookJP02oookJP03obH0oooonf[ooo]Z00kooo]Z00?o<Ol0oookJ_l0oe/00ooonfX01OoUo`3o
0?naoiCo0?oonf[o0?m=00;ooo]Z00?o1P3ooookJ_nBo`000ooonfX00ol@0?ooo`1Zo`0Io`04oook
JP06ool0DOoonf[ooo]Zo`2]oooonf[oo`1iDOoonfX01?l0Y_oooo]ZoookJ_nX0?l2oookJP08ool0
nOoonf[o07OooookJ_l0oi[oof`0oookJ_ooP@02oookJP04oc_o0?oonf[ooo]Zo`3ko`Gooo]Z00Co
o`<0oookJ_oonf[oo`3M0_oonfX00ol0Xooo/ol0oookJP05oookJP04o`3og_oo08Oooo]Zool0K0;o
oo]Z00KoC@3ooookJ_oo;P3oH@3ooookJ_l0odD4oookJP04on80oooonf[ooo]Zo`3oTPKooo]Z00Oo
J03ooookJ_oonf[ooo]ZoaP0ool0M?ooi_l000;ooo]Z00?ooi00oookJ_oonfX02?oonfX00ooo_P3o
0?l5on/0o`05oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3o
oo]ZoookJP05oookJP05o`3Dool01?oooo]Zo`2Yool0R?l00ooonfX00ol0odkooo]ZoookJP04oook
JP03o`3Qool0oago0?mC00Cooo]Z00ooo`1iool0DOoonf[o5@3ooookJ_l@0?ooT_l0ool0mOoonf[o
0>Soo`3oCOl0ok7oP_l0o`3oFolao`001ooonfX01?n40?oo9P3oom[o0?oQo`02oookJP05ool04ooo
09?ooo]Zo`3o6olB0?l00ooonfX01Omho`3o0=cooookJ_l0:_oooe8000Cooo]Z00?o07?ooookJ_oo
nfX01OoonfX05_oo0>[ooo]ZoolF0?oonf[ooi80oookJ_oo0?cooo]Zool60?oo0?Ko0:Koool0nOl0
Moooof`0oon10?lko`3ooo]Zo`3koooo0`3oo`3Mo`2Soonco`02oookJP;oo`270_oo06`01Om=0?oo
H@3oof40ool0odGooo]Z00;ohP3o0_l0oi02o`3oTQKooo]Z1?l0oi801Ooonf[ohP3ooookJ_oonf[o
0?m500;oH@3o00Oooo]Zool^0?m=0?ooo`1/oookJ_l0omkoo`2700?ooo]Z00So/ol0o`2Soooo0=go
N@3ooookJ_oo0`3ooo]Zo`3ko`;ooo]Z00oo>ol0oon10?l0oi[oof`0o`1goooo0?Wooo]ZojP0oooo
nf[o0:Koool0m_o[o`3oo`H0oookJ_lH0?l00_oonfX01Ooo0?cooo]ZoookJ_ooTP3ooaH000Cooo]Z
00?oo`3ZoookJ_oonfX02ooonfX00ol0Looooo]ZoookJP08oookJP04okWo0?ooDP3ooo]Zo`0Zo`;o
oo]Z00Co?ol0o`3Loooonf[oN?l01ooonfX01?l0oa_o4P3ooookJ_oobP02oookJP03o`3ioooonf[o
o`2C00Gooo]Z00?of_l0on7o0?oonfX00_oonfX00olV0?oo8?l0oookJP0>oookJP04oc7o0?oonf[o
oo]Zo`3oF`;ooo]Z00SoP_l0o`3o/Ol0<?oooo]Zo`3oCOl0j?oooo]Zo`H0o`;ooo]Z00OoT_l0oook
J_oonf[o403oool0J_oonf[o01Wo00?ooo]Z00Ko5@3oool0DOoonf[o0:gooookJ_oo07TXoookJP00
;?oonfX01?nDo`3ooo]ZoookJ_nX0?l2oookJP04ool0nOoonf[o07OooookJPKoiOl000Go>ol0onGo
0?oonf[ooo]Zo`3ko`04oookJP08ool30?oonf[ooo]ZoookJ_oo0=gooo]Zo`2Soonco`06oookJP04
o`3og_oo08Oooo]Zool0K0;ooo]Z00KoC@3oonGo0?oUo`3oiOl0of40ool0odD3oookJP05on80oooo
nf[o0?n@oookJ_l0oi801_oonfX00omX0?oooo]ZoookJP02oookJP03oaP0ool0M?ooi_l000;ooo]Z
00?ooi00oookJ_oonfX01_oonfX01Ooo_P3o0?l<o`3o3?l0o`coj`3o00;o0?l<0ooonfX00oooE`3o
oo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0e?oo
00CooookJ_l0ZOoo08So00;ooo]Z00?o0?m>o`3o;_l0oc@01OoonfX01?l0hOoo0?lMoookJ_l0oe<3
oookJP0Aool0NOl0[Oooo`1AoaD0oooonf[o403ooookJ_nBo`3o1P3ooookJ_l0odgo0?naoh;o0?l0
oe_oolT0oc7o0?oob@001OoonfX02olPo`3o9P3ooookJ_oJo`3ooo]Zool04ooo09?o0?WooookJ_oo
b@3o0?lK00;ooo]Z00KoN?l0o`3ogol0g?oooo]Zo`0ZooooDP05oookJP03o`1coooonf[ooo]Z00Co
oo]Z00[oo`3ZoookJ_oonf[ooi80oomi0?oo0?coolT0ool60?ooN@3ojol00_ooN@000ol0MoooogT0
oc_o0002oomi0003oolX0?oo0=goobP000;o/ol00ooo:002ool0K004oolX0?oUo`3oiOl0onGo00;o
hP3o0_l0oi02o`3oTP?ooo]Z2_nDo`06ofP0o`03oookJ_oUo`3oiOl000;oiOl01OooN@02o`3oTP03
on80ool0oi3ooo]Z00;o0?m51_oob@000ooo08Oooo]Zoomi0002oomi0003ok?o0?ooN@3oogT000?o
ogT0017ooo]Zo`3koooonf[ooo]Zoc_o0?l0olco0?nJo`1goooo0?Wooo]ZojP0oooonf[o0:Kooook
J_o[o`3ooo]Zool60007onGo00Kooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ol0Looooo]ZoookJP07
oookJP05okWo0?ooDP3o0?lcoookJ_l0:_l00_oonfX01?loo`3o0=cooookJ_mho`07oookJP03o`3o
6olB0?ooolX000?ooo]Z00?oiOl0ool0TooUo`000_oUo`03oookJP03om[o0?oQo`3ooo]Z00;ooo]Z
00?o9P3ooookJ_oonfX03_oonfX00olao`3ooo]Zo`3oF`03oookJP05onGo0?oonf[oU?l0oookJ_l0
odd00_oonfX00ol60?oooo]Zoi;o0003oookJP03oa00oooo06[o01Wo00Cooo]Z00Koo`1AoookJ_oo
nf[o0:gooookJ_oo07U@oookJP04o`2Voooonf[ooo]ZojP0o`;ooo]Z00_oo`3ioookJ_oonf[o07Oo
oookJ_l0oi[oof`0o`3oc?ooP@3ooo]Zoc_o0003oookJP03o`3koooonf[ooo]Z00;ooo]Z00Woo`<0
oookJ_oonf[ooo]Zool0gOoonf[o0:?ooookJ_nco`001_oonfX01?oo08Oooo]ZoookJ_oo06`2oook
JP05odd0oooo;P3ooo]Zof40ool0odD01?oonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Gooo]Z00?o
J03ooookJ_oonfX00_oonfX00olH0?oo07CoonKo0002oookJP03oon@0?oonf[ooo]Z00Oooo]Z00Co
okh0o`3o1Ooonf[oj`3o1OoonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Gooo]Z
00?ooh40oookJ_oonfX01OoonfX01?l0e?oo00Coo`2Yool0R?l3oookJP03o`3oC_l0ocCooo]Z00Co
oo]Z00Co0>7oo`3o7Ol0o`So0?mC1?oonfX03ooo07Woo`1AoaD0oooonf[oo`1Zoa00oonBo`3ooo]Z
o`H0ool0odgo0?naoh;o0?oonf[o0?mKoc7o0007oookJP03obH0oooonf[of_l000;ooo]Z00Goo`0C
ool0Tooonf[oolX0o`3o6`03oookJP05ogSo0?l0g?oooo]Zo`0ZooooDP001OoonfX00ol0Looooo]Z
oookJP04oookJP0Dool0j_oonf[ooo]ZoolF0?ooTP3ooo]Zool0o?lH0?ooo`H0on_o0?l0Y_ooo`3i
o`1gooooK03ooh40oc_o0?oonf[o0?_oool30?oo0=d2ok?o00;ooo]Z00Coo`27ool0K?oo06coC@3o
0_mQ0?l2oookJP;ohP3o00?o0?n@o`3oT_l0oi801OoonfX?ofP0o`Wooo]Z0_l0oi82on80o`;ooo]Z
00Go0?m5of40oomQ0?ooobh0odd0o`02ool0K003ool0QooMo`3ooo]Z00;ooo]Z00So/ol0o`2Soooo
0=goN@3ooookJ_oo0`3ooo]Zo`3ko`;ooo]Z00Go>ol0oon10?l0oi[o07Ooool0n@02oookJP0:ojP0
oooonf[o0:Koool0m_o[o`3oo`H0oookJ_lH0?oooo]Zool0o0;ooo]Z00?ooi80oolF0?oonfX01?oo
nfX00ooo0>[ooo]ZoookJP0:oookJP03o`1coooonf[ooo]Z00Sooo]Z00Co^Ol0oomB0?oonf[o02[o
0_oonfX01?loo`3o0=cooookJ_mho`07oookJP04o`3o6olB0?oooo]Zooo:00?ooo]Z00?o0?Woool0
Tooo01<01?oonfX00ooJo`3ohOl0oookJP02oookJP03obH0oolPo`3ooo]Z00kooo]Z00Co<Ol0oook
J_oonf[o0?mK0_oonfX01_n2o`3ooo]Zo`3o/Ol0<?oo0?m=o`3Xo`;ooo]Z00?o1P3ooookJ_nBo`00
0_oonfX01?l@0?oo05goool0J_l06Ol3oookJP06oaD0oooo057ooo]Zo`2]oooonf[oo`1i:?oonfX0
02cooo]Z00KoU?l0oookJ_oonf[oZ03ooookJ_oo0?T2oookJP03o`1goooonf[oiOl000CoiOl000?o
>ol0onGo0?oUo`000_oonfX00ol0nooooo]ZoookJP02oookJP08ool30?oonf[ooo]ZogT0oooo0=go
oo]Zo`2Soonco`06oookJP07o`3og_oo08Oooo]Zool0K?oonf[oiOl0odd0o`02onGo0003of40oooU
o`3o0?m500?ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP03ofP0oooonf[ooo]Z00;ooo]Z
00Go603oo`1doooVo`3ooo]Zoon@0009oookJP05oonn0?l0o`co0?l<o`3o3?o[0?l00_l0o``2oook
JP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP04oook
JP05o`3Dool01?oooo]Zo`2Yool0R?l00_oonfX00ol0odkooo]Zo`3o=005oookJP03o`3Qool0oago
0?mC00?ooo]Z00Coo`1ioookJ_oo057o5@3o0_oonfX03?l@0?ooT_l0ool0mOl60?oo0?m=o`0`oon2
o`3oolT0o`3oFolao`3ooo]Zooo900Gooo]Z00[o9P3ooookJ_oJo`3ohOl0oookJ_oo01?oo`2Coook
J_oob@3o0?lK0_oonfX01omho`3o0?oOo`3Looloo`3o02[oo`3o<oooDP001?oonfX00ol0Looooo]Z
oookJP04oookJP0@ool0j_oonf[ooo]ZoonB0?oonf[oo`3looo90?oo1P3oogT0on_o0?ooN@3oZ03o
ool0nOl0Mooo>ol0oomi00;oobP000?oo`3MoolX0?nco`000ooo:002ool0K0;oobP00_oUo`02on80
o`03o`3oT?l0oi;o0?nB00Cooo]Z0_mX0?l>oiCo00;ooo]Z1?mX0?l7oomi0004oookJ_l0oi;ohP3o
on80o`;ooo]Z00?o0?m5of40oooo;P001?oob@000ooo08Oooo]ZoookJP02oomi0003ok?o0?ooN@3o
ogT000?oogT0017ooo]Zo`3koooonf[o>ol0oon10?l0oi[oiOl0o`1goooo0?Wooo]ZojP0ool0Y_oo
oo]Zool0m_o[o`3oo`H0oookJP06onGo0003oonB0?oonf[ooo]Z00Cooo]Z00?oo`3ZoookJ_oonfX0
2_oonfX00ol0Looooo]ZoookJP07oookJP0;okWo0?ooDP3ooo]ZoookJ_l0:_oooo]Zocoo0?oonf[o
0=coogSo0?lm0?l01_oonfX00ol0oa_o4P3oooo:0003oookJP03onGo0?oo09?oiOl000?oiOl00_oo
nfX00ooJo`3ohOl0oookJP02oookJP03obH0oooonf[ooo]Z00oooo]Z00?o<Ol0o`3oFooonfX00_oo
nfX4onGo0006o`3oCOl0j?oooo]Zo`H0oooonf[oT_l00ooonfX00ol@0?oo05goo`0Io`04oookJP06
ool0DOoonf[ooo]Zo`2]oooonf[oo`1iD?oonfX01?l0Y_oooo]ZoookJ_nX0?l2oookJP03ool0nOoo
nf[o07Oo00;ooo]Z00Ko0?nJoom/0?l0olcooh40oookJ_lko`03oookJP03o`3koooonf[ooo]Z00;o
oo]Z00Woo`<0oookJ_oonf[ooo]Zool0gOoonf[o0:?ooookJ_nco`001OoonfX01?oMo`3oo`27oook
J_oo06`3oookJP05odd0oooo;P3ooo]Zof40ool0odD01?oonfX01OoR0?oooo]ZoookJ_oonf[o0?nB
00Gooo]Z00?oJ03ooookJ_oonfX00_oonfX01OlH0?oo07CoonKo0?oonf[ooi0000[ooo]Z00Cookh0
o`3o1Ooonf[oj`3o1?oonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?o
oh40oookJ_oonfX01?oonfX01Ol0e?oo00CooookJ_l0ZOoo08So00?ooo]Z00?o0?m>o`3o=?oonfX0
1?oonfX00ol0hOoo0?lMo`3oD`04oookJP0?ool0NOoo057ooo]ZoaD0oooonf[o01Wooi;o0?oo0?Go
oo]Zo`3oCOl0<?oo0?naoh;o0?l0oe_o<Ol000Oooo]Z00Co9P3oob3o0?oJo`3ohOl00_oonfX01Ooo
01?oo`2CoookJ_l0oa_o4P3o00;ooo]Z00KoN?l0ocd0ooloo`3o02[oo`3o<oooDP04oookJP03o`1c
oooonf[ooo]Z00Cooo]Z01Soo`3ZoookJ_oonf[ooaH0oonB0?oonf[oo`3loaP0oooo1P3ojol0o`2V
oonX0?ooo`3io`1gooooP@3o>ol0oookJ_l0nooooo]Zool0gOnco`3oW`3oo`000?oo08L2ool0K0;o
C@3o00?oH@3ooookJ_oR0?l00_oR0?l2o`3oTPGooo]Z0omX0?l9oaP0o`Kooo]Z0omX0?l8oookJP04
o`3oT_oonf[ohP3oon80o`;ooo]Z00?o0?m5of40oooo;P000_m=0?l00ooo06coo`27omgo0003oook
JP0?ok?o0?l0Xoooo`3MogT0oooonf[oo`<0oookJ_l0nooooo]Zoc_o0?ooP@3ooo]Zoom/0?l0Mooo
o`3i00;ooo]Z00OoZ03oo`2Voooo0?Kojol0ool60?oonf[o603o00;ooo]Z00Goo`3loookJ_oonf[o
oi80oolF0005oookJP03ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX02?oonfX02_l0oc?o
oe80oookJ_l0:_oooo]Zocoo0?oonf[o0=coo`3ogomho`06oookJP04o`3o6olB0?oooo]Zooo:00?o
oo]Z00?o0?Woool0Tooo01<01OoonfX01_oJo`3ooo]ZoookJ_oonf[o9P3oob3o013ooo]Z00?o<Ol0
oookJ_l0oe/00_oonfX01_n2o`3ooo]Zo`3o/Ol0<?oo0?m=o`3Xo`;ooo]Z00?o1P3ooookJ_nBo`00
0_oonfX01?l@0?oo05goool0J_l06Ol3oookJP06oaD0oooo057ooo]Zo`2]oooonf[oo`1i:?oonfX0
02cooo]Z00KoU?l0oookJ_oonf[oZ03ooookJ_oo0?T2oookJP03o`1goooUo`3oiOl000CoiOl000Go
>ol0onGo0?oUo`3ooo]Zo`3ko`05oookJP04ool30?oonf[ooo]Zool0g@;ooo]Z00?o0:?ook?o0?oo
nfX01?oonfX02?l0omkogOl0ool0Qooonf[oo`1/oookJ_oUo`3oC@3o0_oUo`000omQ0?ooiOl0o`3o
A@03oookJP05on80ool0oi3ooo]ZoookJ_l0oi801_oonfX01omX0?oooo]ZoookJ_oonf[o603oo`1d
oooVo`000_oonfX00oooT03ooo]ZoookJP06oookJP05o`3o3?oo_P3o0?l<o`3o3?o[0?l00ol0o``2
oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3ooo]ZoookJP04
oookJP05o`3Dool01?oooo]Zo`2Yool0R?l00ooonfX00ol0odko0?ldoookJP04oookJP04o`3Qool0
oagooo]Zo`3oD`?ooo]Z013oo`1io`2]oooo057o5@3ooookJ_l@0?oo05gooi;o0?l60?oooo]Zo`3o
COl0<?ooP_l0o`3oFooonf[o<Ol01_oonfX02olPo`3o9P3ooookJ_oJo`3ooo]Zool04ooo09?o0?Wo
ooo90?l0oa_o08ko00;ooo]Z00KoN?l0o`3ogoloo`3ooo]Zo`0ZooooDP04oookJP03o`1coooonf[o
oo]Z00Cooo]Z00ooo`3ZoookJ_oonf[ooi80ooo90?oo0?coolT0ool60?oob@3ojol0oomi0?nX0?oo
o`3io`1goolko`000_ooN@001?oo:03oo`3MoolX0?nco`02oolX00;oo`1/0ooo:0000ooUo`3oobP0
oolX0002ooo900CoiOl00omX0?l00olH0?ooU?l0oiCo000?oiCo00;o603o0_oUo`08oomi0003oook
J_l0oi;o0?nB00;ohP3o0_oonfX2of40o`05ool^0?oob@3oolT0ooo90?oo08L00_oonfX2oomi0003
ok?o0?ooN@3oogT000;oogT000[ooo]Zo`3koooonf[ooo]Zoc_o0?oonf[o0?nJo`1goooonf[oo`3i
0_oUo`001_l0Y_oooo]Zool0m_o[o`3oo`H0oookJPGoiOl000?ooi80oookJ_oonfX01?oonfX00ooo
0>[ooo]ZoookJP0:oookJP03o`1coooonf[ooo]Z00Oooo]Z00_o^Ol0oomB0?oonf[ooo]Zo`0Zoooo
nf[o?ol0oookJ_l0g?ooN?l0o`3og`06oookJP04o`3o6olB0?oooo]Zooo:00?ooo]Z00?oiOl0ool0
TooUo`000_oUo`03oookJP06om[o0?oonf[ooo]ZoookJ_lV0?ooQ03o4?oonfX00olao`3oiOl0o`3o
F`06onGo0007o`3oCOl0j?oooo]Zo`H0oooonf[oo`3eoi;o0003oookJP03oa00ool06Ooooo]Z00?o
oo]Z00Koo`1AoookJ_oonf[o0:gooookJ_oo07U@oookJP04o`2Voooonf[ooo]ZojP0o`;ooo]Z00_o
o`3ioookJ_l0Mooooo]Zo`3oV_ooK03ooo]Zo`3oc?ooP@3ooo]Zoc_o0002oookJP03o`3koooonf[o
oo]Z00?ooo]Z00Coo`<0oookJ_oonf[oo`3M0_oonfX00ol0Xooo/ol0oookJP05oookJP04o`3og_oo
08Oooo]Zool0K0?ooo]Z00GoC@3oool^0?mQ0?oooo]Zo`3oA@04oookJP04on80oooonf[ooo]Zo`3o
TPKooo]Z00OoJ03ooookJ_oonf[ooo]ZoaP0ool0M?ooi_l000;ooo]Z00?ooi00oookJ_oonfX02?oo
nfX00ooo_P3o0?l5on/0o`05oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01?oo
nfX00oooP@3ooo]ZoookJP05oookJP05o`3Dool01?oo0:WooookJ_l0R?l00ooonfX00ol0odkooo]Z
oookJP04oookJP03o`3Qool0oago0?mC00Cooo]Z00ooo`1iool0DOlE0?oooo]Zool0J_l@0?ooT_l0
oookJ_l60?oo0?m=o`0`oon2o`3ooo]Zo`3oFolao`001ooonfX00olV0?oooo]Zom[o0002oookJP05
ool04ooo09?ooo]Zo`3o6olB0?l00ooonfX01Omho`3o?ol0oookJ_l0:_oooe8000Cooo]Z00?o07?o
oookJ_oonfX01?oonfX04?oo0>[ooo]ZoookJ_oo5P3ooi80oookJ_oo0?co603oool60?o[o`3o0:Ko
ojP0oooo0?Wo07Oooon10?lko`02o`3ko`05oookJ_oo0=go/ol0o`0Gool000000_oo06`2odd0o`;o
H@3o0_oR0?l00ol0oi3o0?nBoookJP04oookJP?oJ03o0olH0?l3o`1do`Koi_l01olH0?l2oookJP?o
J03o1_oonfX2o`3oTP05o`3oT?oR0?oooo]ZoookJ_l0odD00_mQ0?l01Ooo;P3oC@3oool0K?oo08Oo
gOl000?ooo]Z00Go/ol0ool0gOmi0?oooo]Zool30002oookJP0Co`3koooonf[o>ol0oon10?oonf[o
of`0o`1goooo0?Wooo]ZojP0oooonf[o0:Koool0m_o[o`3oo`H0oookJ_lH0?oooo]Zool0o002oook
JP03oonB0?oo5P3ooo]Z00Cooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ol0Looooo]ZoookJP08oook
JP0:okWo0?ooDP3ooo]Zo`0Zoooonf[o?ol0oookJ_l0g?oooo]ZogSo00Kooo]Z00Co0?lKoa80oooo
nf[oolX00ooonfX00ol0nOooo`2Cool04`05oookJP06om[o0?oonf[ooo]ZoookJ_lV0?oo8?l04?oo
nfX00olao`3ooo]Zo`3oF`02oookJP06oh;o0?l0ok3o0?nao`0`ool0odgo0>So0_oonfX00ol60?oo
oo]Zoi;o0003oookJP03oa00oooo06[o01Wo00Cooo]Z00Goo`1AoookJ_l0[Ooooo]Zool0N@0Xoook
JP00;?oonfX01_nDo`3ooo]ZoookJ_nX0?oooo]Zool0n@;ooo]Z00Co07OooookJ_nDo`3oof`00ooU
o`001Olko`3oiOl0onGo0?oonf[o0?_o00Gooo]Z00Ooo`<0oookJ_oonf[oo`3MoookJ_l0Xooo/ol0
00Kooo]Z00Go0?oNool0Qooonf[oo`1/oookJP02onGo0006odd0oooUo`3oiOl0of40oooUo`3o0?m5
0_oonfX00ooR0?oooo]Zo`3oT002oookJP03o`3oT_oonf[ooo]Z00?ooo]Z00?oJ03ooookJ_oonfX0
0_oonfX00olH0?oo07CoonKo0002oookJP03oon@0?oonf[ooo]Z00Oooo]Z00Cookh0o`3o1Ol0o`co
j`3o0ol0o``2oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3o
oo]ZoookJP04oookJP05o`3Dool01?oooo]Zo`2Yool0R?l00_oonfX00ol0odkooo]Zo`3o=005oook
JP04o`3Qool0oagooo]Zo`3oD`;ooo]Z00Coo`1ioookJ_oo057o5@3o0_oonfX02_l@0?ooT_l0ool0
mOl60?oo0?m=o`0`oon2o`3oolT0o`3oFolao`07oookJP0:obH0oooonf[of_l0on7o0?oo01?oo`2C
o`3ioooonf[oolT0o`3o6`;ooo]Z00KoN?l0o`3ogol0g?oooo]Zo`0ZooooDP05oookJP03o`1coooo
nf[ooo]Z00Cooo]Z00Goo`3ZoookJ_oo5P3oolT0ool0o002ooo9000=ool60?o[o`3oogT0ojP0oooo
0?Wo07OooolX0?lko`3o0?_ooomi0?oo0=goobP0ok?o0002oolX0003ool0K?oo:03oobP000KoobP0
00?oolT0onGo0?oUo`000omX0?l3oaP0o`03oomi0?nDo`3oU?l000_oU?l000?ooi00onKo0?oVo`00
0ooUo`03oaP0o`SoogT00_oonfX03?l0oi;o0?n@on80oooonf[o0?m5oookJ_mQ0?ooobh0odd0oooo
nf[oolT0ool0Q`;ooo]Z00?oogT0ok?o0?ooN@000oooN@002_oo0`3ooo]Zo`3koooonf[o>ol0oon1
0?ooN@3oiOl0o`1goooo0?T2onGo0006o`2Voooonf[oo`3foookJ_oo1P3ooo]Z1_oUo`000ooo5P3o
oo]ZoookJP03oookJP03ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX01ooonfX01Onio`3o
oe80oookJ_oonf[o02[o00;ooo]Z00Co?ol0o`3Loomho`3o0?oO1ooonfX00ol0oa_ooo]Zooo:0003
oookJP03o`3ioooo09?oiOl000;oiOl00ooonfX01_oJo`3ooo]ZoookJ_oonf[o9P3oob3o013ooo]Z
00?o<Ol0onGo0?l0oe/01_oUo`001?l0odgo0>SooookJ_l60?l2oookJP06oi;o0?oonf[ooo]Zoook
J_l@0?oo01Wo1?oonfX01_lE0?ooo`1AoookJ_l0[Ooooo]Zool0NE3ooo]Z00Co0:KooookJ_oonf[o
Z03o0_oonfX02?oo0?Wooo]Zo`1goooonf[o0?nJoom/0?oonf[ooh400_oonfX01?lko`3ooo]Zoook
J_l0nol5oookJP08ool30?oonf[ooo]Zool0gOoonf[o0:?oo`0Goonco`06oookJP04o`3og_oo08Oo
oo]Zool0K0?ooo]Z00GoC@3oool^0?mQ0?oooo]Zo`3oA@03oookJP05on80ool0oi3ooo]ZoookJ_l0
oi801OoonfX00omX0?oooo]ZoookJP02oookJP03oaP0ool0M?ooi_l000;ooo]Z00?ooi00oookJ_oo
nfX01ooonfX01?oo_P3o0?l5oookJ_o[0?l5oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oook
J_oonfX01OoonfX00oooP@3ooo]ZoookJP04oookJP05o`3Doooonf[o00Coo`2Yool0R?l00ooonfX0
0ol0odko0?ldoookJP04oookJP04o`3Qool0oago0?l8o`3oD`?ooo]Z00ooo`1iool0DOoonf[o5@3o
oookJ_l06OooT_l0ool0mOoonf[o0?m=o`0`ool0ok7oP_l0oookJ_lao`001ooonfX01olV0?oooo]Z
om[o0?oQo`3ooo]Zool04ooo09<00_oonfX02_l0oa_o4P3ooookJ_oonf[oN?l0ocd0oooonf[o02[o
oomB0?nio`04oookJP03o`1coooonf[ooo]Z00Cooo]Z01Woo`3ZoookJ_oonf[ooaH0oonB0?oo0?co
603oool60?o[o`3o0:KoojP0oooo0?Wo07Ooo`3oc?lko`3o0?_oool30?oonf[oo`3Mok?o0?l0003o
0?oNool0K?l0003oC@3o00;oH@3o00Cooo]Zon80ool0oi3o0?n@1?oonfX3ofP0o`?o603o1_oVo`09
oon@00Coi_l00olH0?l2oookJP?oJ03o1OoonfX01Ol0oi;o0?n@on80oooonf[o0?m500;ooo]Z00Ko
H@3oool^0?m=0?ooo`1/ool0QooMo`03oookJP05ok?o0?oo0=goN@3ooookJ_oo0`000_oonfX01ol0
nooo>ol0oookJ_ooP@3oof`0o`1goooo0?T00_oonfX01onX0?oo0:Koool0m_oonf[oo`H0oookJ_lH
0?l00_oonfX01Ooo0?cooo]ZoonB0?oonf[ooaH000Cooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ol0
Looooo]ZoookJP08oookJP04okWo0?ooDP3ooo]Zo`0Zo`;ooo]Z00Co?ol0o`3Loooonf[oN?l01ooo
nfX01?l0oa_ooo]ZoookJ_oobP02oookJP04o`3ioooonf[oo`2Cool04`Cooo]Z00Kof_l0oookJ_oo
nf[ooo]ZobH0oolPo`0@oookJP03oc7o0?oonf[o0?mK00?ooo]Z00GoP_l0o`3o/Ol0<?oooo]Zo`3o
C@02oookJP03o`H0oooonf[oT_l000?ooo]Z00?o403oool0J_l06Ol01?oonfX00ooo057ooo]Zo`2]
o`02oookJP03ool0NOoonf[ooo]Z02Gooo]Z000[oookJP04oiCo0?oonf[ooo]ZojP0o`;ooo]Z00_o
o`3ioookJ_oonf[o07OooookJ_nDo`3oof`0o`3oc?oUo`3ooo]Zoc_o0002onGo0003oookJ_l0nooo
oo]Z00?ooo]Z00Soo`<0oookJ_oonf[ooo]Zool0gOoonf[o0:?ook?o00Kooo]Z00Oo0?oNool0Qooo
nf[oo`1/oookJ_oUo`3oC@3o00;oiOl000?oH@3oonGo0?l0odD00ooonfX01OoR0?oo0?n@oookJ_oo
nf[o0?nB00Kooo]Z00?oJ03ooookJ_oonfX00_oonfX01OlH0?oo07CoonKo0?oonf[ooi0000Wooo]Z
00Kookh0oookJ_l0o`Go0?l<on/0oooonfX2o`3o3003oookJ_ooE`3ooo]Z00Cooo]Z00?oo`0]oook
J_oonfX01?oonfX00oooP@3ooo]ZoookJP05oookJP05o`3Dool01?oooo]Zo`2Yool0R?l00_oonfX0
0ol0odko0?ldoookJP04oookJP04o`3Qool0o`So0?lMo`3oD`?ooo]Z013oo`1ioookJ_oo057o5@3o
oookJ_l06Ooo403ooi;o0?l60?oooo]Zo`3oCOn2o`3oolT0o`3oFooonf[o<Ol01_oonfX02olPo`3o
9P3ooookJ_oJo`3ooo]Zool04ooo09?ooo]Zooo90?l0oa_o08ko00;ooo]Z00KoN?l0o`3Loooonf[o
02[oo`3o<oooDP04oookJP03o`1coooonf[ooo]Z00Cooo]Z00?oo`3ZoookJ_oonfX01?oob@003Ooo
1P3ojol0oomi0?oo:03oo`3io`1goooo:03o>ol0o`3kooooN@3oo`3Mo`2Soonco`000_oo:0000ooo
06coobP0oolX0006oolX0004ooo90?oUo`3oJ03oofP0o`?o603o0ooVo`000oooN@3oU?l0oiCo0006
oiCo00Sooo]Z0ooUo`03oomi00?o603o1OooN@04oookJP0;o`3oT_oR0?oooo]Zo`3oAOoonf[oH@3o
ool^0?m=0?ooo`1/oookJ_oo08L00ooonfX00onco`3oogT0oomi0002oomi00;ooo]Z017o0?_ooook
J_lko`3ooh40onGo0?l0MoooiOl0ool0nOoUo`3ooo]Zo`2Voooonf[oo`3fon_o0?oo1P3oiOl0oook
JP04onGo0003oonB0?oonf[ooo]Z00Cooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ol0Looooo]Zoook
JP08oookJP0;okWo0?ooDP3ooo]ZoookJ_l0:_oooo]Zocoo0?l0g?ooN?l0o`3ogolm0?l01_oonfX0
0ol0oa_ooo]Zooo:0004oookJP04ool0TooUo`3oiOl0onGo00?ooo]Z00Kof_l0oookJ_oonf[ooo]Z
obH0oolPo`0@oookJP03oc7o0?oonf[o0?mK00OoiOl000Ko0?m=oookJ_oonf[o1P3ooookJ_nBo`03
oookJP03oa00ool06Ooooo]Z00?ooo]Z00Ko5@3oool0DOoonf[o0:gooookJ_oo07U?oookJP04o`2V
oooonf[ooo]ZojP0o`?ooo]Z00Soo`3ioookJ_l0Mooooo]Zo`3oV_ooK03o0?o<oon100;ooo]Z00Co
>ol0oookJ_oonf[o0?_o1?oonfX02Ooo0`3ooo]ZoookJ_oonf[oo`3MoookJ_l0Xooo01Oook?o0006
oookJP03ool0Qooonf[oo`1/00?ooo]Z00GoC@3ooookJ_oo;P3oH@3oo`3oA@04oookJP05on80oooo
nf[ooo]ZoookJ_l0oi801OoonfX00omX0?oooo]ZoookJP02oookJP05oaP0ool0M?ooi_l0oookJ_oo
T0002_oonfX01?oo_P3o0?l5oookJ_o[0?l4oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oook
J_oonfX01?oonfX00oooP@3ooo]ZoookJP05oookJP05o`3Dool01?oooo]Zo`2Yool0R?l00ooonfX0
0ol0odkooo]ZoookJP04oookJP03o`3Qool0oago0?mC00Cooo]Z00ooo`1iool0DOoonf[o5@3oool0
J_l@0?ooT_l0oookJ_l60?oo0?m=o`0`oon2o`3ooo]Zo`3oFolao`001ooonfX00olV0?oooo]Zom[o
0002oookJP05ool04ooo09?ooo]Zo`3o6olB0?l00_oonfX01_l0omooN?l0oookJ_l0:_oo0?lcoomB
00Cooo]Z00?o07?ooookJ_oonfX01?oonfX06?oo0>[ooo]ZoookJ_oo5P3ooi80ool0o?oonf[oo`H0
on_o0?l0Y_ooZ03oool0nOl0Mooo0?o<oc_o0?l0nooooo]Zool30?oo0=go/ol0oookJ_oo08Ooo`1/
o`0000;oH@3o00Gooo]Zon80oooR0?oo0?n@o`3oTP03oookJP;oJ03o0olH0?l2onKo00?ooi003_oo
nfX3oon@0003oookJ_oVo`3oi_l000?o603o0_oonfX00omX0?oooo]ZoookJP04oookJP04o`3oT_oR
0?oooo]Zo`3oA@;ooo]Z00KoH@3oool^0?oo06cooo]Zool0QooMo`03oookJP04ok?o0?oo0=goN@3o
ool300;ooo]Z013o0?_ooookJ_lko`3ooh40oookJ_ooK03o07Ooool0nOoonf[oZ03oo`2Voooonf[o
o`3fon_o0?oo1P3o603o0ooonfX01?oo0?cooo]ZoonB0?oo5P05oookJP03ool0j_oonf[ooo]Z00Wo
oo]Z00?o07?ooookJ_oonfX02OoonfX02_l0oc?ooe80oookJ_l0:_oooo]Zocoo0?l0g?oooo]ZogSo
0?lm0?l6oookJP04o`3o6olB0?oooo]Zooo:00?ooo]Z00?o0?Woool0Tooo01<01?oonfX01_oJo`3o
oo]ZoookJ_oonf[o9P3oob3o013ooo]Z00Co<Ol0oookJ_oonf[o0?mK0_oonfX01On2o`3o0?nao`0`
oooonf[o0?m=00;ooo]Z00?o1P3ooookJ_nBo`000ooonfX00ol@0?ooo`1Zo`0Io`04oookJP03oaD0
oooo057o0:go00;ooo]Z00?oo`1ioookJ_oonfX09OoonfX002_ooo]Z00CoU?l0oookJ_oonf[oZ03o
0_oonfX02ooo0?Wooo]Zo`1goooonf[oU?l0oom/0?oonf[o0?o<onGo0?oonf[o>ol000;ooo]Z00?o
0?_ooookJ_oonfX00ooonfX01?oo0`3ooo]ZoookJ_oo0=d2oookJP03o`2Soonco`3ooo]Z00Gooo]Z
00Oo0?oNool0Qooonf[oo`1/oookJ_oUo`3oC@3o00;oiOl000?oH@3oonGo0?l0odD00ooonfX01OoR
0?oo0?n@oookJ_oonf[o0?nB00Kooo]Z00OoJ03ooookJ_oonf[ooo]ZoaP0ool0M?ooi_l000;ooo]Z
00?ooi00oookJ_oonfX01ooonfX01?oo_P3ooo]Zo`3o1Oo[0?l5oookJP03oomG0?oonf[ooo]Z00?o
oo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3ooo]ZoookJP04oookJP05o`3Dool01?oooo]Zo`2Y
ool0R?l00_oonfX00ol0odko0?l^o`3o=005oookJP04o`3Qool0oagooo]Zo`3oD`?ooo]Z00?oo`1i
ool0DOlE0?l00_oonfX02ol@0?oo05gooi;o0?l60?oo0?m=o`3Xoon2o`3oolT0o`3oFooonf[o<Ol0
00Gooo]Z00_o8?l0obH0oooonf[of_l0oookJ_oo01?oo`2Co`3ioooob@3ooo]Zo`3o6`02oookJP06
ogSo0?l0omoo0=cooookJ_l0:_oooe801?oonfX00ol0Looooo]ZoookJP04oookJP03ool0j_oonf[o
olT000CoolT0013oo`H0on_o0?oo0?KoobP0ool0nOl0MoooobP0oc_o0?l0noooogT0ool0gOl0Xooo
/ol0ool0Qooo:03oo`1/2?oo:0000ooob@3oJ03oofP0o`02oaP0o`OoogT00onDo`04oomi00Sooo]Z
1ooUo`03oomi00;o603o1?ooN@04oookJP0;o`3oT_oR0?oooo]Zo`3oAOmQ0?oooo]Zool^0?m=0?oo
o`1/oookJ_oo08L00ooonfX01onco`3oogT0oomi0?ooN@3oo`<0oookJ_l0nol00_oUo`002?lko`3o
iOl0onGo0?l0MoooiOl0ool0nOoUo`3o0:Ko0_oonfX00oo[o`3ooo]Zool60005onGo0003oonB0?oo
5P3ooo]Z00Cooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ol0Looooo]ZoookJP07oookJP0;okWo0?oo
DP3ooo]ZoookJ_l0:_oooo]Zocoo0?oonf[o0=coogSo0?lm0?l01_oonfX01?l0oa_o4P3ooookJ_oo
bP03oookJP04ool0TooUo`3oiOl0onGo00?ooo]Z00Kof_l0oookJ_oonf[ooo]ZobH0oolPo`0Aoook
JP03oc7o0?l0oe_oiOl000KoiOl000Ko0?m=oookJ_oonf[o1P3ooookJ_nBo`03oookJP03oa00ool0
6Oooo`1Z00?ooo]Z00Ko5@3oool0DOoonf[o0:gooookJ_oo07U?oookJP04o`2Voooonf[ooo]ZojP0
o`;ooo]Z00_oo`3ioookJ_oonf[o07Ooo`3oV_oonf[oof`0o`3oc?ooP@3ooo]Zoc_o0002oookJP03
o`3koooonf[ooo]Z00?ooo]Z00Woo`<0oookJ_oonf[oo`3MogT0oooonf[o0:?ook?o0?nO0?l01Ooo
nfX01?oMo`3oo`27oookJ_oo06`3oookJP05odd0oooo;P3oH@3ooookJ_l0odD01?oonfX01OoR0?oo
oo]ZoookJ_oonf[o0?nB00Gooo]Z00OoJ03ooookJ_oonf[ooo]ZoaP0ool0M?ooi_l000;ooo]Z00?o
oi00oookJ_oonfX02?oonfX01?oo_P3o0?l5on/0oom`0?l4oookJP03oomG0?oonf[ooo]Z00?ooo]Z
00?oo`0]oookJ_oonfX01?oonfX00oooP@3ooo]ZoookJP05oookJP05o`3Dool01?oo0:WooookJ_l0
R?l00_oonfX00ol0odko0?ldoookJP05oookJP03o`3Qool0oago0?mC00Cooo]Z00ooo`1iool0DOlE
0?oooo]Zo`0Iool@0?ooT_l0oookJ_l0odgo0>Soo`3o/On2o`3ooo]Zo`3oFolao`001_oonfX00olV
0?oooo]Zom[o0002oookJP06ool04ooo09?ooo]Zooo:0?l0oa_o4P3o0_oonfX01Omho`3o0=cooook
J_l0:_oooe8000Cooo]Z00?o07?ooookJ_oonfX01?oonfX07_oo0>[ooo]ZoookJ_oo5P3ooi80oook
J_oo0?coo`H0on_o0?oo0?KoZ03oool0nOl0Mooo0?o<oc_o0?l0nooooo]Zool30?oo0=go/ol0oook
J_oo08Ooo`1/o`000?mQ0?oo0?m5o`000?oR0?oo0?n@o`3oTP?ooo]Z0_mX0?l2oaP0o`;oi_l00ooo
T00DoookJP;ooi000_oonfX2onKo00;o603o00?ooo]ZofP0oomX0?l01OoonfX03?l0oi;ohP3ooook
J_l0odGooo]Zof40oooonf[oobh0ool0K?oonf[oo`27omgo00;ooo]Z00GoW`3ook?o0?oo0=gooo]Z
ool30002oookJP0@o`3koooonf[o>ol0oon10?ooK03o0?nJo`1goooo0?Wooo]ZojP0ool0Y_oooo]Z
ool0m_o[o`3oo`H0oaP0o`;ooo]Z00Goo`3loookJ_ooTP3ooo]ZoolF0004oookJP03ool0j_oonf[o
oo]Z00[ooo]Z00?o07?ooookJ_oonfX02?oonfX02_l0oc?ooe80oookJ_l0:_oooo]Zocoo0?oonf[o
0=coogSo0?lm0?l6oookJP04o`3o6olB0?oooo]Zooo:00?ooo]Z00?o0?Woool0Tooo01<01?oonfX0
1ooQo`3of_l0oookJ_oonf[o9P3ooh@0oolPo`004?oonfX00olao`3ooo]Zo`3oF`02oookJP05oh;o
0?l0ok7o033ooookJ_l0odd00ooonfX00ol60?oooo]Zoi;o0002oookJP03oa00ool0GOoo01Wo00Co
oo]Z00?o5@3oool0DOl0[Ol00_oonfX00ooo07Wooo]ZoookJP0UoookJP00:ooonfX01?nDo`3ooo]Z
oookJ_nX0?l2oookJP0:ool0nOoonf[o07OooookJ_nDo`3oof`0o`3oc?oonf[oiOl0oc_o00?ooo]Z
00?oU?l0oookJ_oonfX00ooonfX02?oo0`3ooo]ZoookJ_oo0=gooo]Zo`2Soonco`3oW`3o1OoonfX0
1Ol0omkoo`27oookJ_oonf[oo`1/00;oiOl000KoC@3oonGo0?oUo`3oH@3oonGo0?l0odD3oookJP05
on80ool0oi3ooo]ZoookJ_l0oi801OoonfX00omX0?oooo]ZoookJP02oookJP03oaP0ool0M?ooi_l0
00;ooo]Z00?ooi00oookJ_oonfX01ooonfX01?oo_P3ooo]Zo`3o1Oo[0?l5oookJP03oomG0?oonf[o
oo]Z00;ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP04oookJP05o`3Dool01?oo
oo]Zo`2Yool0R?l00_oonfX00ol0odkooo]Zo`3o=004oookJP05o`3Qool0o`So0?lMoookJ_l0oe<0
0_oonfX04?oo07Wooo]Zool0DOlE0?oooo]Zo`0Iool@0?ooT_l0o`H0oooonf[o0?m=oh;o0?oob@3o
oo]Zo`3oFolao`06oookJP0:obH0oon40?oooo]Zom[o0?oonf[oo`0Cool0Tooonf[oolX0o`3o6`?o
oo]Z00GoN?l0o`3Loooonf[o02[ooomB0005oookJP03o`1coooonf[ooo]Z00Cooo]Z00?oo`3Zooo9
0?oob@000ooob@003_oo1P3ojol0oolX0?oo:03oo`3io`1goooo:03o>ol0o`3kooooN@3oo`3Mo`2S
oonco`3oobP00_oo06`8oolX0004ooo90?mX0?oo603ooaP0oa3oogT00ooo_P08oookJPOoiOl00_oo
N@000olH0?ooogT0oomi0002oomi00?ooo]Z00co0?nBo`3oT?oR0?oooo]Zo`3oAOmQ0?oooo]Zodd0
oooonf[oo`1/ool0Qol0omh2oookJP03oil0oonco`3oogT000;oogT00_oonfX02_l0noooiOl0oc_o
0?ooP@3oiOl0o`1goooUo`3oo`3ionGo0?l0Y_l2oookJP03onGo0?o[o`3oo`H000GoiOl000?ooo]Z
oonB0?oonfX01?oonfX00ooo0>[ooo]ZoookJP0:oookJP03o`1coooonf[ooo]Z00Oooo]Z00_o^Ol0
oomB0?oonf[ooo]Zo`0Zoooonf[o?ol0oookJ_l0g?ooN?l0o`3og`06oookJP04o`3o6olB0?oooo]Z
ooo:00?ooo]Z00Coo`2ConGo0?oUo`3oiOl01?oonfX01OoJo`3ooo]ZoookJ_lV0?oo8?l0017ooo]Z
00?o<Ol0o`3oFooUo`001_oUo`001_l0odgooo]ZoookJ_l60?oooo]Zoi;o00?ooo]Z00?o403oo`0I
oooo06X00ooonfX01_lE0?ooo`1AoookJ_l0[Ooooo]Zool0NDoooo]Z00Co0:KooookJ_oonf[oZ03o
0_oonfX02ooo0?Wooo]Zo`1goooonf[o0?nJoom/0?oonf[o0?o<oon10?oonf[o>ol000;ooo]Z00?o
0?_ooookJ_oonfX00ooonfX02Ooo0`3ooo]ZoookJ_oo0=goN@3oo`2Sool05ooo/ol0oil0o`05oook
JP04o`3og_oo08Oooo]Zool0K0?ooo]Z00GoC@3oool^0?mQ0?oooo]Zo`3oA@04oookJP04on80oooo
nf[ooo]Zo`3oTPGooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?oo07CoonKo0002oookJP03oon@
0?oonf[ooo]Z00Sooo]Z00?ookh0o`3o1Oo[0?l01OoonfX00oooE`3ooo]ZoookJP02oookJP03ool0
;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0e?oooo]Zo`04ool0ZOoo08So00?o
oo]Z00?o0?m>o`3o=?oonfX01?oonfX01?l0hOoo0?lMoookJ_l0oe<3oookJP0?ool0NOoo057ooo]Z
oaD0oooo06[o403ooi;o0?oonf[o1P3oo`3oCOl0<?ooP_l0oookJ_l0oe_o<Ol000Kooo]Z00Co9P3o
ob3o0?oonf[of_l00_oonfX01Ooo01?oo`2CoookJ_l0oa_o4P3o00;ooo]Z00Ko0?oOogSo0?oonf[o
02[ooomB0?nio`04oookJP03o`1coooonf[ooo]Z00Cooo]Z01Soo`3ZoookJ_oonf[ooi80oookJ_oo
0?coo`H0on_o0?oo0?KoZ03oool0nOl0Mooo0?nJoc_o0?l0nooooo]Zool30?oo0=go/ol0oookJ_oo
08Ooo`1/odd0oomQ0?l2o`000003on80ool0oi3o0?nB00;ooo]Z0_mX0?l2oaP0o`;oi_l00_ooT009
oookJPGookh02ooonfX3oon@0004oookJ_oVo`3oi_l0oaP0o`;ooo]Z00?oJ03ooookJ_oonfX00_oo
nfX03Ol0oi;o0?n@on80oooonf[o0?m5oookJ_mQ0?oooo]Zodd0oooo06coo`27o`3og_oMo`000_oo
nfX01?l0Xooo/ol0ogT0oooo0`03oookJP0?o`3koolko`3ooh40o`3oc?ooK03o07Ooool0nOoonf[o
Z03oo`2Voooonf[oo`3fon_o0?oo1P3o603o00?ooo]Z00Coo`3loookJ_ooTP3ooaH01?oonfX00ooo
0>[ooo]ZoookJP0:oookJP03o`1coooonf[ooo]Z00Sooo]Z00[o^Ol0oomB0?oonf[o02[ooookJ_lo
o`3ooo]Zo`3Loomho`3o0?oO1_oonfX01Ol0oa_o4P3ooookJ_oonf[oolX000;ooo]Z00?o0?Woool0
Tooo01<01OoonfX01_oJo`3ooo]ZoookJ_lV0?ooQ03oob3o013ooo]Z00?o<Ol0oookJ_l0oe/00_oo
nfX01On2o`3o0?nao`0`oooonf[o0?m=00?ooo]Z00?o1P3ooookJ_nBo`000_oonfX00ol@0?oo05go
o`0Io`04oookJP03oaD0oooo057o0:go00;ooo]Z00?oo`1ioookJ_oonfX09OoonfX002[ooo]Z00Oo
U?l0oookJ_oonf[ooo]ZojP0oooonf[oo`3i00;ooo]Z00So07OooookJ_nDo`3oof`0o`3oc?oonf[o
iOl0oc_o00?ooo]Z00?oU?l0oookJ_oonfX00ooonfX01ooo0`3ooo]ZoookJ_oo0=gooo]Zo`2Soonc
o`001_oonfX01Ol0omkoo`27oookJ_oonf[oo`1/00;ooo]Z00KoC@3oonGo0?mQ0?ooiOl0o`3oAOoU
o`02oookJP05on80oooonf[o0?n@oookJ_l0oi801_oonfX00omX0?oooo]ZoookJP02oookJP05oaP0
ool0M?ooi_l0oookJ_ooT0002_oonfX01?oo_P3o0?l5o`3o3?o[0?l4oookJP03oomG0?oonf[ooo]Z
00?ooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3ooo]ZoookJP05oookJP09o`3Dool01?oo0:Wo
oookJ_l0R?oooo]Zo`3oC_l0obko0?ld00Gooo]Z00Co0>7oo`3o7Ooonf[o0?mC0ooonfX00ooo07Wo
0:goool0D@02oookJP0;oa00ool0GOooT_l0o`H0ool0odgo0>Sooh;o0?oob@3o0?mKoookJ_lao`00
1OoonfX02ooUo`3o9P3ooookJ_oJo`3ooo]Zool04ooo09?o0?Woooo:0?oonf[o0?lK00;ooo]Z00Ko
N?l0ocd0ool0g?oo02[oo`3o<oooDP04oookJP03o`1coooonf[ooo]Z00Cooo]Z00?oo`3Zooo90?oo
b@000ooob@003ooo1P3oolT0oolX0?oo:03oo`3io`1goooo:03o>ol0oolX0?oonf[oo`3Mo`2Soonc
o`3oobP0ool0K009oolX0005ooo90?lH0?oo603oonKo0?ooT0003?ooN@07on/0o`Gookh01ooonfX6
onGo0003oaP0ooooN@3oogT000;oogT00ooonfX03?l0oi;o0?n@on80oooonf[o0?m5of40oooo;P3o
C@3oool0K?oonf[oo`27o`3ogP;ooo]Z017oW`3ook?o0?ooN@3oogT0ool30?oonf[oogT0ooo90?oU
o`3o>ol0oon10?oUo`3o07OoonGo0?oo0?WoZ03oo`2Vo`02onGo0003on_o0?oUo`3oo`H000GoiOl0
00?ooi80oolF0?oonfX00ooonfX00ooo0>[ooo]ZoookJP0:oookJP03o`1coooonf[ooo]Z00Sooo]Z
00[ooe80oookJ_oonf[ooo]Zo`0Zooloo`3ooo]Zo`3Loomho`3o0?oO1ooonfX00ol0oa_ooo]Zooo:
0003oookJP04ool0Tooonf[oiOl0onGo00Cooo]Z00Kof_l0oookJ_oonf[ooo]ZobH0oon40?l@oook
JP03oc7o0?l0oe_oiOl000KoiOl000Ko0?m=oookJ_oonf[o1P3ooookJ_nBo`03oookJP03oa00ool0
6Oooo`1Z00Cooo]Z00Goo`1AoookJ_oonf[o0:goool0N@1>oookJP05o`2Voooonf[ooo]ZoookJ_nX
0?l00_oonfX02ooo0?Wooo]Zo`1goooonf[o0?nJoom/0?l0olcooo]Zoon10?oonf[o>ol000;ooo]Z
00?o0?_ooookJ_oonfX00ooonfX02?oo0`3ooo]ZoookJ_oo0=gooo]Zo`2Sool05ooo/ol01_oonfX0
1?oo08Oooo]ZoookJ_oo06`3oookJP04odd0oooo;P3oH@3oo`3oA@Cooo]Z00GohP3oo`3oT?oonf[o
oo]Zo`3oTP05oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603oo`1doooVo`3ooo]Zoon@000:oook
JP04oonn0?oonf[o0?l5on/0o`Cooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP04
oookJP03oon10?oonf[ooo]Z00Gooo]Z00Go0=Coo`04ool0ZOoooo]Zo`28o`02oookJP03o`3oC_l0
ocCooo]Z00Gooo]Z00?o0>7oo`3o7Ol0oe<01?oonfX03ooo07Woo`1AoaD0oooonf[o01Wooa00oonB
o`3ooo]Zo`3oCOl0j?oo033ooh;o0?oonf[o0?mKoc7o0006oookJP03obH0oooonf[of_l000;ooo]Z
00goo`0Cool0Tooonf[oolX0o`3o6olB0?oooo]Zo`3ogomho`3o0=coo`0Zool0oc?ooe8000Cooo]Z
00?o07?ooookJ_oonfX01?oonfX06Ooo0>[ooo]ZoookJ_oo5P3ooi80ool0o?oo1P3o603oon_o0?nX
0?ooo`3io`1gool0oi[o>ol0o`3koooonf[oo`<0ool0gOnco`3ooo]Zool0Qooo06coC@3oof40ool0
00000_oR0?l2o`3oTP03oookJ_mX0?ooJ03o00;o603o00?oi_l0oon@0?ooT0001ooonfX3oonn00So
j`3o1?oo_P09oookJP;ooi0000?ooo]ZonKo0?lH0?l00_oonfX2ofP0o`?ooo]Z00go0?nBo`3oT?oR
0?oooo]Zo`3oAOoonf[oH@3oool^0?oo06cooo]Zool0Qol0omkogOl000;ooo]Z00Co0:?ook?o0?oo
nf[oo`<00ooonfX03ol0nooo>ol0oon10?ooK03o0?nJo`1goooo0?Wooo]ZojP0ool0Y_ooo`3fon_o
0?oonf[oo`H0oaP0o`02oookJP05ool0o?oonf[ooi80oookJ_oo5P000ooonfX00ooo0>[ooo]Zoook
JP0:oookJP03o`1coooonf[ooo]Z00Wooo]Z00Wooe80oookJ_oonf[o02[oocoo0?oonf[o0=cooook
J_mho`001ooonfX01?l0oa_ooo]ZoookJ_oobP02oookJP04o`3ioooo09?ooo]Zool04`Cooo]Z00Ko
f_l0oookJ_oonf[ooo]ZobH0oolPo`0@oookJP03oc7o0?oonf[o0?mK00;ooo]Z00GoP_l0o`3o/?l0
<?oooo]Zo`3oC@03oookJP03o`H0oooonf[oT_l000;ooo]Z00?o403oo`1Mool06Ol01?oonfX01_lE
0?ooo`1AoookJ_l0[Ooooo]Zool0NBOooo]Z000ZoookJP04oiCo0?oonf[ooo]ZojP0o`;ooo]Z00_o
o`3ioookJ_oonf[o07OooiCo0?oonf[oof`0o`3oc?oUo`3ooo]Zoc_o0002oookJP;oU?l01OoonfX0
1ooo0`3ooo]Zool0gOmi0?oooo]Zo`2Soonco`001_oonfX01?l0omkoo`27oookJ_oo06`3oookJP05
odd0oooUo`3oH@3ooookJ_l0odD00ooonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Kooo]Z00?oJ03o
oookJ_oonfX00_oonfX01OlH0?oooo]ZonKo0?oonf[ooi0000Wooo]Z00Cookh0oookJ_l0o`Goj`3o
1OoonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Cooo]Z00?ooh40oookJ_oonfX0
1?oonfX01Ol0e?oo00CooookJ_l0ZOoo08So00;ooo]Z00?o0?m>oookJ_l0oc@01OoonfX01?l0hOoo
0?lMoookJ_l0oe<2oookJP0@ool0NOoonf[oo`1AoaD0oooonf[o01Wooa00oooonf[oT_l0oookJ_l0
odgoP_l0o`3o/Ooob@3o0?mKoc7o00Kooo]Z00[o9P3ooh@0oooonf[of_l0oookJ_oo09?o0?Wooook
J_oobP3o0?lK0ooonfX01Omho`3o0=cooookJ_l0:_oooe8000Gooo]Z00?o07?ooookJ_oonfX00ooo
nfX00ooo0>[oolT0ooo90005ooo900?oobP000[o07OooolX0?lko`3oobP0oomi0?oo0=go0:?ook?o
0?oo:03oo`1/2Ooo:002oaP0o`04onKo0?ooT03ooi00oookJP?oogT01Ooo:004on/0o`03og00oooo
N@3oogT000CoogT01Oo[0?l3oonn00Oooo]Z1?oUo`000olH0?oooo]Zoomi0002oomi00?ooo]Z00co
0?nBo`3oT?oR0?oooo]Zof40oooonf[oobh0odd0oooo06cooo]Zool0Qol0omh2oookJP0:ok?o0?l0
XoooogT0ool30?oonf[oogT0ooo90?oUo`3o>ol0oon100;oiOl000Co07OoonGo0?oo0?Wo0:Ko0_oU
o`000oo[o`3oiOl0ool60003onGo0004oookJ_oUo`3ooi80oolF00Gooo]Z00?oo`3ZoookJ_oonfX0
2_oonfX00ol0Looooo]ZoookJP07oookJP0:okWo0?ooDP3ooo]ZoookJ_l0:_oooo]Zocoo0?l0g?oo
N?l0o`3og`Oooo]Z00?o0?lKoookJ_oobP000ooonfX01?oo09?ooo]ZoookJ_oUo`04oookJP06om[o
0?oonf[ooo]ZoookJ_lV0?ooQ03o4?oonfX00olao`3o0?mKoookJP06onGo0007o`3oCOoonf[ooo]Z
o`H0oooonf[oo`3eoi;o0002oookJP03oa00ool06Oooo`1Z00Cooo]Z00Go5@3oool0DOoonf[o0:go
ool0N@1>oookJP04o`2Voooonf[ooo]ZojP0o`?ooo]Z00Soo`3ioookJ_l0Mooo0?nJoookJ_ooK03o
0?o<oon100;ooo]Z00Co>ol0oookJ_oonf[o0?_o1OoonfX02?oo0`3ooo]Zool0gOmi0?oooo]Zo`2S
ool05ooo/ol01_oonfX00ooo08Oooo]Zool0K004oookJP04odd0oomQ0?oooo]Zo`3oA@Cooo]Z00Go
hP3ooookJ_oonf[ooo]Zo`3oTP05oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603oo`1doooVo`3o
oo]Zoon@000:oookJP04oonn0?l0o`Goj`3oog00o`Cooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo
02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Gooo]Z00Go0=Coo`04ool0ZOoooo]Zo`28o`02
oookJP03o`3oC_l0ocCooo]Z00Cooo]Z00Co0>7oo`3o7Ooonf[o0?mC0ooonfX03ooo07Wo0:goool0
DOlE0?ooo`1Zo`0Iool@0?ooT_l0o`H0ool0odgo033ooh;o0?l0ok3o0?mKoc7o0006oookJP04obH0
oolPo`3ooo]Zom[o00;ooo]Z00Goo`2Co`3ioooonf[o0?lKoa80o`02oookJP06o`3ogomho`3ooo]Z
o`0ZooooDP3o^Ol01?oonfX00ol0Looooo]ZoookJP03oookJP0Mool0j_oonf[ooo]ZoolF0?ooTP3o
o`3lool60?lH0?oojol0ojP0oooonf[o07Ooo`3oV_lko`3ooo]Zo`3koooo0`3oo`3Mok?o0?oonf[o
o`27ool0K?m=0?ooH@3oo`000?oR0?oo0?n@o`3oT_oonfX00_mX0?l2oaP0o`03onKo0?ooT03ooi00
00Gooo]Z00?ookh0on/0ooo[0?l01?o[0?l2og00o`Gooo]Z00?oL03oon/0ooo[0?l00oo[0?l2oonn
00Sooo]Z00Cooi00oookJ_oVo`3o603o0ooonfX04?mX0?oooo]ZoookJ_oonf[o0?nBo`3oT?oR0?oo
oo]Zo`3oAOmQ0?oooo]Zodd0oooo06cooo]Zool0Qol0omh2oookJP04oil0oonco`3oo`3Mool300?o
oo]Z00oo0?_ooc_o0?oonf[ooh40oom/0?l0Mooooo]Zool0nOnX0?oo0:KooookJ_oo0?Kojol0ool6
0?lH0?l00ooonfX01?oo0?cooi80oookJ_oo5P04oookJP03ool0j_oonf[ooo]Z00[ooo]Z00?o07?o
oookJ_oonfX02?oonfX02Ol0oc?ooe80oookJ_l0:_oooo]Zocoo0?l0g?oooo]ZogSo0007oookJP04
o`3o6ooonf[ooo]Zooo:00;ooo]Z00Co0?Woool0Tooonf[oo`0C1?oonfX01_oJo`3ooo]ZoookJ_oo
nf[o9P3oob3o013ooo]Z00?o<Ol0oookJ_l0oe/00_oonfX01_n2o`3o0?n`o`0`oooonf[o0>Soo`3o
C@;ooo]Z00?o1P3ooookJ_nBo`000_oonfX00ol@0?oo05goo`0Io`04oookJP06oaD0oooo057ooo]Z
o`2]oooonf[oo`1i9ooonfX002gooo]Z00koZ03ooookJ_oonf[oo`3ioookJ_l0Mooooo]ZoiCo0?oo
K03ooo]Zo`3oc?oUo`3ooo]Zoc_o00;ooo]Z0_nDo`04oookJP08ool30?oonf[ooo]Zool0gOmi0?oo
0:?ooookJ_nco`05oookJP05o`3og_oMo`3oo`27oookJ_oo06`00_oonfX01_m=0?oooo]ZonGo0?mQ
0?oooo]Zo`3oA@?ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP05oookJP03ofP0oooonf[ooo]Z00?o
oo]Z00Go603oonKo0?oonf[ooo]Zoon@0009oookJP04oonn0?oonf[o0?l5on/0o`Gooo]Z00?ooeL0
oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP05oookJP03oon10?oonf[ooo]Z00Cooo]Z00Go0=Co
o`04oooonf[o0:Woo`28o`02oookJP03o`3oC_oonf[o0?ld00Cooo]Z00Go0>7oo`3o7Ooonf[ooo]Z
o`3oD`02oookJP0@ool0NOoonf[oo`1AoaD0oooonf[o01Wooa00oonBo`3oolT0o`3oCOl0j?ooP_l0
ooo90?l0oe_ooo]Zoc7o00Gooo]Z00_oiOl0obH0oooonf[of_l0oookJ_oo01?oo`2Co`3ioooobP3o
4P3oo`3o6`02oookJP06ogSo0?oob@3o?ol0o`0Zool0oc?ooe801?oonfX00ol0Looooo]ZoookJP04
oookJPKoolT000Ooo`H0oolX0?oo:03oobP0o`1goooo:03o>ol000;oobP000Goo`3Mo`2Soonco`3o
o`27ool0K00:oolX0003onKo0?oo:03oobP000WoobP03?ooN@05ooo90004oookJ_o[0?ooj`3oon/0
o`;ookh01ooonfX01?ooT03ooo]ZonGo0?lH0?l2oookJP;oogT00ooonfX02ol0oi;o0?n@on80oooo
nf[oH@3ooookJ_m=0?oooo]Zool0K?oonf[oo`2700;ooo]Z017oW`3ook?o0?l0XoooogT0ool30?oo
nf[oogT0ooo90?oUo`3o>ol0oon10?oUo`3o07OoonGo0?oo0?WoZ03oo`2Vo`02onGo0003on_o0?oo
1P3oiOl000?oiOl000?oo`3loookJ_ooTP001OoonfX00ooo0>[ooo]ZoookJP0:oookJP03o`1coooo
nf[ooo]Z00Oooo]Z00_o^Ol0oomB0?oonf[ooo]Zo`0Zoooonf[o?ol0o`3Loooonf[oN?l0ocd0o`06
oookJP04o`3o6ol0S_oooo]Zooo:00;ooo]Z00Coo`2Co`3ioooonf[oo`0C1?oonfX01_oQo`3of_l0
oookJ_oonf[o9P3ooh@0oa3ooo]Z00?o<Ol0o`3oFooonfX01OoUo`000ooonf[o0>Soo`3oC@02oook
JP03o`H0oooonf[oT_l000;ooo]Z00?o403oo`0Ioooo06X01?oonfX01OlE0?ooo`1AoookJ_l0[Ooo
o`1i057ooo]Z00coZ03ooookJ_oonf[ooo]Zool0nOoonf[o07Ooo`3oV_oonf[oof`0o`3oc?ooP@02
oookJP04oc_o0?oonf[ooo]Zo`3ko`Cooo]Z00Woo`<0oookJ_oonf[oo`3MogT0ool0Xooooo]Zok?o
0?nO0?l01OoonfX01?l0omkoo`27oookJ_oo06`3oookJP05odd0oooo;P3oH@3ooookJ_l0odD01?oo
nfX01?oR0?oooo]ZoookJ_l0oi85oookJP03ofP0oooonf[ooo]Z00?ooo]Z00Go603oonKo0?oonf[o
oo]Zoon@000:oookJP03oonn0?l0o`Goj`3o00Gooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02go
oo]ZoookJP05oookJP03oon10?oonf[ooo]Z00Cooo]Z00Go0=Coo`04oooonf[o0:Woo`28o`03oook
JP03o`3oC_l0ocCooo]Z00Cooo]Z00Co0>7oo`3o7Ooonf[o0?mC0ooonfX03ooo07Woo`1AoaD0oooo
nf[o01Wooa00oonBo`3ooo]Zo`3oCOl0j?oo033ooh;o0?oonf[o0?mKoc7o0006oookJP03obH0oooo
nf[of_l000;ooo]Z00Goo`0Cool0Tooonf[oolX0o`3o6`02oookJP06o`3ogomho`3o0=coo`0Zool0
oc?ooe801?oonfX00ol0Looooo]ZoookJP04oookJP0Iool0j_oonf[ooo]ZoonB0?oonf[oo`3lool6
0?o[o`3ooo]ZojP0ool0Moooof`0oc_o0?oonf[o0?_oool30?oo0=go/ol0oookJ_oo08Ooo`1/odd0
oomQ0?oooo]Zon80o`02o`3oTP;oJ03o0_lH0?l00ooVo`3ooi00oon@0005oookJP03oonn0?o[0?oo
j`3o00?oL03o3ooonfX01Om`0?ooj`3oon/0ooo[0?oookh000Oooo]Z00Cooi00oookJ_oonf[o603o
0ooonfX04?mX0?oooo]ZoookJ_oonf[o0?nBo`3oT?oR0?oooo]Zo`3oAOmQ0?ooobh0odd0oooo06co
oo]Zool0QooMo`02oookJP04oil0oonco`3oo`3Mool300?ooo]Z00ko0?_ooc_o0?ooP@3oof`0o`3o
V_l0Moooo`3ioookJ_nX0?oooo]Zool0m_o[o`3oo`H0oaP0o`?ooo]Z00Coo`3loookJ_ooTP3ooaH0
1?oonfX00ooo0>[ooo]ZoookJP0:oookJP03o`1coooonf[ooo]Z00Sooo]Z00[o0?lcoomB0?oonf[o
02[ooookJ_loo`3o0=cooookJ_mho`3o?@3o1_oonfX01Ol0oa_o08kooookJ_oonf[oolX000;ooo]Z
00?oo`2CoookJ_oo01<01?oonfX01_oQo`3of_l0oookJ_oonf[o9P3oob3o013ooo]Z00?o<Ol0oook
J_l0oe/00ooonfX01On2o`3o033ooookJ_l0j?oo0?m=00;ooo]Z00?o1P3ooookJ_nBo`000_oonfX0
0ol@0?oo05goo`0Io`04oookJP06oaD0oooonf[oo`1Ao`2]oooonf[oo`1i9ooonfX002gooo]Z00oo
Z03ooookJ_oonf[oo`3ioookJ_l0Mooooo]Zo`3oV_ooK03o0?o<oookJ_oUo`3ooo]Zoc_o0?oonfX0
0onDo`04oookJP08ool30?oonf[ooo]Zool0gOoonf[o0:?ook?o0?nO0?l5oookJP05o`3og_oo08Oo
oo]ZoookJ_oo06`00_oonfX01_m=0?oooo]ZonGo0?mQ0?oooo]Zo`3oA@?ooo]Z00CohP3oo`3oT?oo
nf[o0?nB1_oonfX00omX0?oooo]ZoookJP02oookJP03oaP0ool0M?ooi_l000;ooo]Z00?ooi00oook
J_oonfX01ooonfX01?oo_P3ooo]Zo`3o1Oo[0?l4oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]
oookJ_oonfX01?oonfX00oooP@3ooo]ZoookJP05oookJP09o`3Dool01?oo0:WooookJ_l0R?oooo]Z
o`3oC_oonf[o0?ld00Gooo]Z00Co0>7oo`3o7Ooonf[o0?mC0ooonfX00ooo07Wo0:goool0D@02oook
JP0:oa00ool0GOooT_l0ooo90?l0odgoP_l0o`3o/Ooob@3o0?mKoc7o00Gooo]Z0_oUo`004OlV0?oo
oo]Zom[o0?oonf[oo`2Co`3ioooonf[oolX0oa80ool0oa_ooo]Zooo90?mho`3o0=cooookJ_l0:_oo
oe8000Cooo]Z00?o07?ooookJ_oonfX01?oonfX7ooo900?oobP000?o07OooolX0?lko`000_oo:000
1oooN@3oo`3Mok?o0?oo08Ooo`1/odd0oomQ0?l05?oo:006oomi0003oomG0?oob@3oolT000_oolT0
00Cooo]Zo`3o1Oo[0?ooj`3o0_oo_P06oookJP04oon@0?oonf[oi_l0oaP0o`;oogT0013oJ03ooook
J_oonf[ooo]Zo`3oT_oonf[o0?n@on80oooonf[oH@3oool^0?m=0?ooo`1/oookJ_oMo`3oo`270_oo
nfX05Onco`3o0:?oool0gOoonf[oo`<0oookJ_oob@3oogT0ooo90?lko`3oogT0onGo0?l0Moooo`3i
oookJ_nX0?oooo]ZonGo0?o[o`3oiOl0ool60003onGo0004ool0o?oonf[ooi80oolF00Cooo]Z00?o
o`3ZoookJ_oonfX02_oonfX00ol0Looooo]ZoookJP08oookJP0:oomB0?oonf[ooo]ZoookJ_l0:_oo
?ol0oookJ_l0g?ooN?l0o`3og`Kooo]Z00Co0?lKo`2>oooonf[oolX00ooonfX00ooo09?ooo]Zool0
4`04oookJP06on7o0?oJo`3ooo]ZoookJ_lV0?oo8?l04?oonfX01?lao`3o0?mKoookJ_oonfX4onGo
0003oookJ_l0j?oo0?m=00;ooo]Z00?o1P3ooookJ_nBo`000_oonfX00ol@0?oo01Woool0JP04oook
JP06oaD0oooo057ooo]Zo`2]oooonf[oo`1iD?oonfX03_nX0?oooo]ZoookJ_oonf[oo`3ioookJ_l0
Mooo0?nJoom/0?l0olcooo]Zoon10?oonf[o>ol00_oonfX00ol0nooooo]ZoookJP03oookJP09ool3
0?oonf[ooo]Zool0gOmi0?oo0:?oo`0Goonco`3oW`3o00Gooo]Z00Coo`27oookJ_oonf[oo`1/0ooo
nfX01Om=0?ooobh0of40oooonf[o0?m500Cooo]Z00CohP3ooookJ_oonf[o0?nB1OoonfX00omX0?oo
oo]ZoookJP02oookJP03oaP0ool0M?ooi_l000;ooo]Z00?ooi00oookJ_oonfX01ooonfX01?oo_P3o
oo]Zo`3o1Oo[0?l4oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01?oonfX00ooo
P@3ooo]ZoookJP05oookJP05o`3Dool01?oo0:WooookJ_l0R?l00_oonfX00ol0odko0?ldoookJP05
oookJP03o`3Qool0oago0?mC00Cooo]Z00koo`1iool0DOlE0?oooo]Zo`0Iool@0?ooT_l0o`H0ool0
odgo033ooh;o0?l0ok3o0?mKoc7o00Oooo]Z00?o9P3ooookJ_oJo`000_oonfX01Ooo09?o0?Wooook
J_oobP3o0?lK00;ooo]Z00Ko0?oOogSo0?loo`3o02[ooomB0?nio`03oookJP03o`1coooonf[ooo]Z
00Cooo]Z01koo`3ZoookJ_oonf[ooaH0oonB0?oo0?coo`H0on_o0?oonf[oZ03oo`1gooooK03o>ol0
oookJ_l0noooo`<0o`2Soonco`3ooo]Zool0Qooo06coC@3oof40oooonf[ohP3oo`3oT_l0003oJ03o
o`000?lH0?l2onKo0003oon@0?oonf[ooo]Z00;ooo]Z00Gookh0on/0ooo[0?ooj`3oog00o`03oook
JPgooeL01_oonfX00om`0?ooj`3ooonn0002oonn00Gooo]Z00Cooi00oookJ_oVo`3o603o0_oonfX0
3OmX0?oooo]ZoookJ_oonf[o0?nBoookJ_l0oi3ohP3ooookJ_l0odGoH@3oodd0oooo06`00_oonfX0
2?oo08Oooo]ZoookJ_nO0?oo/ol0ool0gOoonf[oo`<00_oonfX01ol0nooooo]Zoc_o0?ooP@3o0?nJ
oookJ_l0Mol00_oonfX01_nX0?ooo`3fon_o0?oonf[oo`H0oaP0o`;ooo]Z00Goo`3loookJ_ooTP3o
oo]ZoolF0003oookJP03ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX02OoonfX02OooDP3o
oo]ZoookJ_l0:_oo?ol0oookJ_l0g?ooN?l0o`3og`06oookJP05o`3o6ol0S_oooo]ZoookJ_oobP00
0_oonfX00ooo09?ooo]Zool04`04oookJP06on7o0?oJo`3ooo]ZoookJ_lV0?oo8?l04?oonfX00ola
o`3ooo]Zo`3oF`03oookJP05oh;o0?l0ok7o033oo`3Xool0odd00ooonfX01ol60?ooT_l0ool0mOoo
nf[o403oo`1Mool06Ol01?oonfX01_lE0?oooo]Zool0DOl0[Ooooo]Zool0NBOooo]Z000]oookJP0=
ojP0oooonf[ooo]Zool0nOoonf[o07OooookJ_l0oi[oof`0o`3oc?oonf[oiOl0oc_o0002oookJP?o
U?l01?oonfX02?oo0`3ooo]ZoookJ_oo0=gooo]Zo`2Soonco`3oW`3o1OoonfX01Ol0omkoo`27oook
J_oonf[oo`1/00;ooo]Z00GoC@3oonGo0?oonf[oH@3oo`3oA@03oookJP05on80ool0oi3ooo]Zoook
J_l0oi801_oonfX00omX0?oooo]ZoookJP02oookJP05oaP0ool0M?ooi_l0oookJ_ooT0002_oonfX0
1?oo_P3o0?l5o`3o3?o[0?l4oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01?oo
nfX00oooP@3ooo]ZoookJP04oookJP05o`3Dool01?oooo]Zo`2Yool0R?l00_oonfX00ol0odkooo]Z
o`3o=004oookJP05o`3Qool0o`So0?lMoookJ_l0oe<00_oonfX04?oo07Wooo]Zool0DOlE0?oooo]Z
o`0Iool@0?ooolT0oi;o0?oob@3o0?m=oh;o0?oob@3o0?mKoookJ_lao`05oookJP04onGo0?lV0?oo
iOl0om[o00;ooo]Z00coo`2Co`3ioooobP3o4P3oo`3o6ooonf[oolT0ogSo0?oob@3o?ol0o`0Zoooo
DP05oookJP03o`1coooonf[ooo]Z00?ooo]Z2?oob@02oolX0003o`1goooo:03o>ol000?oobP000So
o`3Mok?o0?oo08Ooo`1/oolX0?mQ0?oo0?m5on80oa7oobP000CoogT0oomG0?ooE`3ooeL01?oonfX?
ooo900;ooo]Z00?oL03oon/0ooo[0?l00_oo_P05oookJP04oon@0?ooN@3oi_l0oaP0o`;oogT000oo
J03ooookJ_oonf[ooo]Zo`3oT_l0oi3ooo]Zon80oomQ0?oo0?m5odd0oooonf[oo`1/oookJ_oo08L0
0_oonfX01OnO0?oo/ol0o`2Soooo0=goo`<000CoolT000co>ol0oomi0?oUo`3o07OoonGo0?oo0?Wo
Z03oo`2VoooUo`3ojol0onGo0?oo1P03onGo0004oookJ_oo0?cooo]ZoonB00Cooo]Z00?oo`3Zoook
J_oonfX02_oonfX00ol0Looooo]ZoookJP08oookJP0:oomB0?oonf[ooo]ZoookJ_l0:_oo?ol0oook
J_l0g?ooN?l0o`3og`Kooo]Z00Co4P3oo`3o6ooonf[oolX00ooonfX00ooo09?ooo]Zool04`04oook
JP06on7o0?oJo`3ooo]ZoookJ_lV0?oo8?l04?oonfX01?lao`3o0?mKoookJ_oonfX4onGo0003oook
J_l0j?oo0?m=00;ooo]Z00?o1P3ooookJ_nBo`000ooonfX00ol@0?oo01WooookJP03oookJP06oaD0
oooo057ooo]Zo`2]oooonf[oo`1iD?oonfX03_nX0?oooo]ZoookJ_oo0?Wooo]Zo`1goooonf[o0?nJ
oom/0?l0olcooo]Zoon10?oonf[o>ol00_oonfX00ol0nooooo]ZoookJP03oookJP09ool30?oonf[o
oo]Zool0gOmi0?oo0:?oo`0Goonco`3oW`3o00Gooo]Z00Coo`27oookJ_oonf[oo`1/0ooonfX01?m=
0?ooobh0of40ool0odD4oookJP05on80oooonf[ooo]ZoookJ_l0oi801OoonfX00omX0?oooo]Zoook
JP02oookJP05oaP0ool0M?ooi_l0oookJ_ooT0002_oonfX01?oo_P3ooo]Zo`3o1Oo[0?l4oookJP03
oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3ooo]ZoookJP04oookJP06
o`3Doooonf[o00Coo`2Yoooonf[o08So0_oonfX00ol0odko0?ldoookJP04oookJP04o`3Qool0oago
oo]Zo`3oD`?ooo]Z00ooo`1io`2]oooo057o5@3oo`0Iool@0?oooo]Zoi;o0?l60?oo0?m=o`0`oon2
o`3ooo]Zo`3oFolao`001_oonfX00olV0?oo8?l0om[o0003oookJP04ool0Tooonf[oolX0o`3o6`;o
oo]Z00Ko0?oOogSo0?l0g?oo02[ooomB0?nio`04oookJP03o`1coooonf[ooo]Z00?ooo]Z023oo`3Z
oookJ_oonf[ooaH0oonB0?oo0?coo`H0on_o0?oonf[oZ03oo`1gooooK03o>ol0oookJ_l0noooo`<0
ogT0oonco`3ooo]Zool0Qooo06cooo]Zof40oooonf[ohP3oo`3oT_l0003oJ03oo`000?lH0?ooi_l0
oon@00Cooo]Z00Cookh0on/0ooo[0?ooL03o0ooonfX3oomG00Cooo]Z1Ooo02d4oookJPGooeL00_oo
nfX01?m`0?ooj`3oon/0ool0o`D2oonn00Cooo]Z00Cooi00oookJ_oVo`3o603o0_oonfX04?mX0?oo
oo]ZoookJ_oonf[o0?nBo`3oT?oonf[ohP3ooookJ_mQ0?ooobh0odd0oooo06cooo]Zool0QooMo`02
oookJP04ok?o0?l0Xoooo`3Mool300;ooo]Z00oo0?_ooookJ_lko`3ooh40oom/0?oonf[o07Ooool0
nOoonf[oZ03ooookJ_oo0?Kojol0ool60?lH0?l00ooonfX01?oo0?cooo]ZoonB0?oo5P03oookJP03
ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX02OoonfX02OooDP3ooo]ZoookJ_l0:_oo?ol0
oookJ_l0g?ooN?l0o`3og`07oookJP04o`3o6ooonf[ooo]Zooo:00;ooo]Z00?oo`2CoookJ_oo01<0
1?oonfX01_oQo`3of_l0oookJ_oonf[o9P3oob3o013ooo]Z00?o<Ol0oookJ_l0oe/00ooonfX01On2
o`3o0?nao`0`ool0j?oo0?m=00?ooo]Z00?o1P3ooi;o0?oo0?D00_oonfX00ol@0?ooo`1Zo`0Io`03
oookJP06oaD0oooonf[oo`1Ao`2]oooonf[oo`1i9ooonfX002gooo]Z00goZ03ooookJ_oonf[oo`3i
oookJ_l0Mooooo]Zo`3oV_ooK03o0?o<oookJ_oUo`3o>ol000;ooo]Z0onDo`04oookJP07ool30?oo
nf[ooo]Zool0gOl0Xooooo]Zok?o0006oookJP05o`3og_oo08Oooo]ZoookJ_oo06`00_oonfX01Om=
0?ooiOl0of40oooonf[o0?m500?ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP05oookJP03ofP0oooo
nf[ooo]Z00?ooo]Z00Go603oonKo0?oonf[ooo]Zoon@0009oookJP04oonn0?oonf[o0?l5on/0o`Go
oo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Co
oo]Z00Go0=Coo`04oooonf[o0:Woo`28o`02oookJP03o`3oC_oonf[o0?ld00Cooo]Z00Go0>7oo`3o
7Ooonf[ooo]Zo`3oD`02oookJP03ool0NOl0[Oooo`1A00;ooo]Z00[o01Wooa00oonBo`3oolT0o`3o
COl0j?ooP_l0ooo90?l0oe_o<Ol01OoonfX2onGo000:obH0oooonf[of_l0oookJ_oo09?o0?Wooook
J_oobP3o4P3oo`3o6`;oolT000GoN?l0ooo90?l0:_oo0?lcoomB0004oookJP03o`1coooonf[ooo]Z
00?ooo]Z2Ooob@001?oo:03o07OooolX0?lko`03oolX0009ool0gOnco`3oo`27oolX0?oo06coH@3o
o`3oAOoR0?oo0?n@00GoobP000?ooi00oolX0?oo:0002?oo:002oomG00?ooo]Z1?oo02d@ooo90007
oomG0?oob@3oolT0og00ooo[0?oo0?l5oonn0003oookJPCoogT000Goi_l0oaP0ooooN@3oogT0ofP0
o`03oookJP0;o`3oT_l0oi3ooo]Zon80oomQ0?oo0?m5odd0oooonf[oo`1/omgo0?oo08L00_oonfX0
0onco`3o0:?oool0g@06ooo9000;oc_o0?oUo`3o07OoonGo0?oo0?Wooo]ZojP0oooonf[oiOl0on_o
0?oo1P000ooUo`001Ooonf[oo`3loookJ_ooTP3ooaH000Cooo]Z00?oo`3ZoookJ_oonfX02_oonfX0
0ol0Looooo]ZoookJP07oookJP0:okWo0?ooDP3ooo]ZoookJ_l0:_oo?ol0oookJ_l0g?ooN?l0o`3o
g`Kooo]Z00Co4P3oo`3o6ooonf[oolX00ooonfX00ooo09?ooo]Zool04`04oookJP07on7o0?oJo`3o
oo]ZoookJ_lV0?oo8?l0oh@0o`0?oookJP03oc7o0?l0oe_ooo]Z00;ooo]Z0ooUo`000ooonf[o0>So
o`3oC@02oookJP03o`H0oooonf[oT_l000?ooo]Z00?o403oo`0IoooonfX00ooonfX01_lE0?ooo`1A
oookJ_l0[Ooooo]Zool0NE3ooo]Z00koZ03ooookJ_oonf[oo`3ioookJ_l0Mooooo]Zo`3oV_ooK03o
0?o<oookJ_ooP@3ooo]Zoc_o00;ooo]Z00?o0?_ooookJ_oonfX00ooonfX02?oo0`3ooo]ZoookJ_oo
0=go0:?ooookJ_l05ooo/ol01_oonfX01?oo08Oooo]ZoookJ_oo06`3oookJP04odd0oomQ0?oooo]Z
o`3oA@Cooo]Z00GohP3ooookJ_oonf[ooo]Zo`3oTP04oookJP03ofP0oooonf[ooo]Z00?ooo]Z00Go
603oonKo0?oonf[ooo]Zoon@000:oookJP03oonn0?l0o`Goj`3o00Gooo]Z00?ooeL0oookJ_oonfX0
0ooonfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Cooo]Z00Go0=Coo`04oooonf[o
0:Woo`28o`03oookJP03o`3oC_l0ocCooo]Z00Cooo]Z00Co0>7oo`3o7Ooonf[o0?mC0ooonfX03_oo
07Woo`1AoaD0oooonf[o01Wooa00oonBo`3ooo]Zo`3oCOl0j?oo0?naoh;o0?l0oe_o<Ol01ooonfX0
0olV0?oooo]Zom[o0002oookJP05ool0Tol0nOoooo]Zooo:0?l0oa/00_oonfX01Omho`3o0=coo`0Z
ool0oc?ooe8000Cooo]Z00?o07?ooookJ_oonfX01?oonfX07_oo0>[ooo]ZoookJ_ooTP3ooo]Zool0
o?oo1P3oo`3fo`2Vool0Mooooo]Zoc_o0?l0olco0?_oool30?mi0?oo/ol0oookJ_oo08Oooo]Zool0
K?mQ0?oooo]Zon80ool0oi;ooo]ZofP0ool0003o603ooon@00Cooo]Z00?ookh0on/0ooo[0?l00ooo
nfX3oomG00;ooo]Z1Ooo02d5oookJPGoo`0]1?oonfX3oomG0006oookJ_m`0?ooj`3oon/0oooonf[o
okh01?oonfX01?ooT03ooo]ZonKo0?lH0?l2oookJP0?ofP0oooonf[ooo]ZoookJ_l0oi;o0?n@oook
J_oR0?oooo]Zof40oooo;P3oC@3oool0K?oonf[oo`2700;ooo]Z00GoW`3ook?o0?oo0=gooo]Zool3
0002oookJP0?o`3koooonf[o>ol0oom/0?l0oi[o07Ooool0nOoonf[o0:KoojP0oooo0?Kojol0ool6
0?oonf[o603o00;ooo]Z00Goo`3loookJ_ooTP3ooo]ZoolF0003oookJP03ool0j_oonf[ooo]Z00[o
oo]Z00?o07?ooookJ_oonfX02?oonfX02Ol0oc?ooe80oookJ_l0:_oo?ol0oookJ_l0g?oooo]ZogSo
0007oookJP04o`3o6ooonf[ooo]Zooo:00;ooo]Z00?oo`2CoookJ_oo01<01?oonfX01ooQo`3of_l0
oookJ_oonf[o9P3oob3o0?n40?l03ooonfX00olao`3ooo]Zo`3oF`03oookJP05oh;o0?l0ok7o033o
oookJ_l0odd00ooonfX00ol60?oooo]Zoi;o0002oookJP03oa00oooo06[o01Wo00?ooo]Z00Ko5@3o
oookJ_oo057o0:gooookJ_oo07TWoookJP00;?oonfX01?nX0?oooo]ZoookJ_oo0?T2oookJP09o`1g
oooonf[oof`0oookJ_l0olcooo]ZonGo0?lko`3ooo]Z00CoU?l00ooonfX02?oo0`3ooo]ZoookJ_oo
0=goN@3oo`2Soonco`3oW`3o1OoonfX01Ol0omkoo`27oookJ_oonf[oo`1/00?ooo]Z00GoC@3oonGo
0?mQ0?oooo]Zo`3oA@03oookJP04on80ool0oi3ooo]Zo`3oTPKooo]Z00?oJ03ooookJ_oonfX00ooo
nfX01OlH0?ooi_l0oookJ_oonf[ooi0000Wooo]Z00Cookh0oookJ_l0o`Goj`3o1?oonfX00oooE`3o
oo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Cooo]Z00?ooh40oookJ_oonfX01OoonfX02Ol0e?oo
00CooookJ_l0ZOoo08SooookJ_l0odkooo]Zo`3o=004oookJP05o`3Qoooonf[o0?lMoookJ_l0oe<0
0_oonfX04?oo07Wooo]Zo`2]oooo057ooo]Zo`0Iool@0?ooolT0oi;o0?oob@3o0?m=oh;o0?oob@3o
oo]Zo`3oFolao`04oookJP;oiOl000[o9P3oonGo0?oonf[of_l0oookJ_oo09?o0?WooookJ_oobP3o
0?lK0ooob@001?mho`3oolT0o`0ZooooDP04oookJP03o`1coooonf[ooo]Z00?ooo]Z2_oob@000ooo
0?Wo07Oooc_o0003oolX000;ool0gOoo003o/ol0oolX0?oo06coH@3oo`3oAOoR0?oo0?nBoookJ_mX
0?l00ooo:0000oooT03o0000oolX0007oolX0004oomG0?oonf[ooo]ZoookJP?oo`0]3_oonfX3ool0
;@?ooo]Z00GoolT0oomG0?oob@3oolT0oookJP02on/0o`03oonn0?oonf[oogT000GoogT000Coi_l0
oaP0ooooN@3oJ03o0ooonfX02ol0oi;ooo]Zo`3oT?oR0?oooo]Zof40oooo;P3oC@3oool0K?oonf[o
o`2700;ooo]Z00Co/ol0o`2Soooo0=goN@3o1Ooob@003?lko`3oogT0onGo0?l0Moooo`3ioookJ_nX
0?oo0:Koool0m_o[o`3oiOl0ool600;oiOl000Gooo]Zool0o?oonf[ooi80oolF0004oookJP03ool0
j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX01ooonfX02_nio`3ooe80oookJ_oonf[o02[ooook
J_loo`3o0=coogSo0?l0oml6oookJP04oa80ool0oa_ooo]Zooo:00?ooo]Z00?oo`2Co`3ioooo01<0
1?oonfX01ooQo`3of_l0oookJ_oonf[o9P3oob3o0?n40?l03ooonfX00olao`3o0?mKoookJP02oook
JP?oiOl000?ooo]Zo`3Xool0odd00_oonfX00ol60?oooo]Zoi;o0003oookJP03oa00ool06Ooooo]Z
00?ooo]Z00Ko5@3oool0DOoonf[o0:gooookJ_oo07U?oookJP0?ojP0oooonf[ooo]ZoookJ_oo0?Wo
oo]Zo`1goooonf[oof`0oookJ_l0olcooo]Zoon10?oonf[o>ol000;ooo]Z00?o0?_ooookJ_oonfX0
0_oonfX02Ooo0`3ooo]ZoookJ_oonf[oo`3Mo`2Soooonf[o/ol0oil0o`05oookJP05o`3og_oo08Oo
oo]ZoookJ_oo06`00ooonfX01?m=0?ooH@3ooookJ_l0odD4oookJP04on80oooonf[ooo]Zo`3oTPGo
oo]Z00?oJ03ooookJ_oonfX00ooonfX01OlH0?ooi_l0oookJ_oonf[ooi0000Wooo]Z00Cookh0oook
J_l0o`Goj`3o1?oonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Cooo]Z00?ooh40
oookJ_oonfX01OoonfX01Ol0e?oo00CooookJ_l0ZOoo08So00;ooo]Z00?o0?m>o`3o=?oonfX01?oo
nfX01?l0hOoooo]Zo`3o7Ol0oe<3oookJP0?ool0NOoonf[oo`1AoaD0ool06Ooo403ooookJ_nBo`3o
1P3oo`3oCOl0<?ooP_l0oookJ_l0oe_o<Ol000Kooo]Z00CoQ03oobH0oooonf[of_l00_oonfX01?oo
09?ooo]ZoookJ_l0oa/3oookJP05ogSo0?l0g?oo02[ooomB0?nio`000ooonfX00ol0Looooo]Zoook
JP04oookJP0Oool0j_oonf[ooo]ZoonB0?oonf[oo`3lool60?o[o`3o0:Koool0nOl0Mooo>ol0o`3o
c?l0noooo`<0ogT0oooo0=go/ol0ool0Qooonf[oo`1/of40oooonf[ohP3oo`3oT_oonf[oJ03oo`1d
oolH0?oooi00o`000002oookJP03o`3o1Ooo_P3oj`3o00;ooo]Z0oooE`02oookJP?oo`0]3ooonfX3
ool0;@Cooo]Z00KooeL0oookJ_oonf[oL03oon/0oooo_P05oookJP04oon@0?oonf[oi_l0oaP0o`;o
oo]Z00ooJ03ooookJ_oonf[o0?nBoookJ_l0oi3ohP3ooookJ_l0odGoH@3oodd0oooo06cooo]Zool0
QooMo`000_oonfX01?nco`3oo`3MogT0oooo0`02oookJP07o`3koooonf[o>ol0oon10?ooK03ooo]Z
o`1go`02oookJP06ojP0oooo0?Kojol0oookJ_oo1P3o603o0_oonfX01Ooo0?cooo]ZoonB0?oonf[o
oaH000?ooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ol0Looooo]ZoookJP08oookJP09o`3o<oooDP3o
oo]Zo`0Zoooonf[o?ol0o`3Loooonf[oN?l000Oooo]Z00Co0?lKoookJ_oonf[oolX00ooonfX00ooo
09?oo`0CoookJP03oookJP07on7o0?oJo`3ooo]ZoookJ_lV0?oooo]Zob3o000?oookJP03oc7o0?oo
nf[o0?mK00?ooo]Z00GoP_l0o`3o/Ol0<?oooo]Zo`3oC@03oookJP03o`H0oooonf[oT_l000;ooo]Z
00?o403oool0J_l06Ol00ooonfX01_lE0?oooo]Zool0DOl0[Ooooo]Zool0NBOooo]Z000/oookJP0?
ojP0oooonf[ooo]Zool0nOoonf[o07OooookJ_l0oi[oof`0o`3oc?oonf[oiOl0oookJ_lko`3ooo]Z
00CoU?l00ooonfX02?oo0`3ooo]ZoookJ_oo0=goN@3oo`2Soonco`3oW`3o1OoonfX01Ol0omkoo`27
oookJ_oonf[oo`1/00;ooo]Z00KoC@3ooookJ_oUo`3oH@3ooookJ_l0odD2oookJP05on80ool0oi3o
oo]ZoookJ_l0oi801_oonfX00omX0?oooo]ZoookJP03oookJP05oaP0oooVo`3ooo]ZoookJ_ooT000
2OoonfX01?oo_P3ooo]Zo`3o3?o[0?l4oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oo
nfX01?oonfX00oooP@3ooo]ZoookJP04oookJP05o`3Dool01?oooo]Zo`2Yool0R?l00_oonfX00ol0
odkooo]Zo`3o=004oookJP05o`3Qool0oagooo]ZoookJ_l0oe<00_oonfX00ooo07Wooo]Zool0D@02
oookJP0:o`0Iool@0?ooolT0oi;o0?oob@3o0?m=oh;o0?l0ok3o0?mKoc7o00Cooo]Z0ooUo`002_lV
0?ooiOl0om[o0?oonf[oo`0Cool0Tooonf[oolX0oa80ool0oa/2ooo90005ogSo0?oob@3o02[ookWo
0?ooDP001?oonfX00ol0Looooo]ZoookJP02oookJP[oolT000CoogT0o`1goooo:03o>ol00_oo:000
3ooo0=goo`00ok?o0?oo003oo`1/odd0oomQ0?oohP3oo`3oT_oonf[oJ03ooookJ_lH0?ooobP0oon@
0002o`000003o`3o1Ooo:03oobP000CoobP00_oonfX3ool0;@Oooo]Z1_ooP@07oookJP;oo`0]0ooo
b@001oooE`3oolT0oookJ_oonf[oL03oon/0oooo_P000_oonfX5oomi0004oaP0ooooN@3oogT0ofP0
o`?ooo]Z00_o0?nBoookJ_l0oi3ohP3oof40ool0odGoC@3ooookJ_oo06coo`27o`3ogP02oookJP04
ok?o0?l0Xoooo`3MogT0o`CoolT000co>ol0oomi0?oUo`3o07Oooomi0?oo0?WoZ03oo`2Voooonf[o
jol0onGo0?oo1P02onGo0005oookJ_oo0?cooo]ZoookJ_ooTP001?oonfX00ooo0>[ooo]ZoookJP0:
oookJP03o`1coooonf[ooo]Z00Oooo]Z00_o^Ol0oomB0?oonf[ooo]Zo`0Zoooonf[o?ol0o`3Loooo
nf[oN?l0o`3og`06oookJP03o`3o6ooonf[oolX000?ooo]Z00?oo`2Co`3ioooo01<01OoonfX01_oJ
o`3ooo]ZoookJ_lV0?oo8?l0oh@0o`oooo]Z00?o<Ol0oookJ_l0oe/00ooonfX2onGo0009oiCo0?l0
j?oooo]Zo`3oCOoonf[o1P3ooookJ_oo0?GoT_l000;ooo]Z00?o403oo`0IoooonfX00ooonfX01_lE
0?ooo`1AoookJ_l0[Ooooo]Zool0NDoooo]Z00koZ03ooookJ_oonf[ooo]Zool0nOoonf[o07Ooo`3o
V_ooK03o0?o<oookJ_ooP@3ooo]Zoc_o00?ooo]Z00?o0?_ooookJ_oonfX00_oonfX02Ooo0`3ooo]Z
oookJ_oo0=goN@3oo`2Soooonf[o/ol0oil0o`05oookJP04ool0Qooonf[ooo]Zool0K0?ooo]Z00Go
C@3oool^0?mQ0?oooo]Zo`3oA@03oookJP05on80oooonf[ooo]ZoookJ_l0oi801OoonfX00omX0?oo
oo]ZoookJP03oookJP05oaP0oooVo`3ooo]ZoookJ_ooT0002OoonfX01?oo_P3ooo]Zo`3o1Oo[0?l4
oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3ooo]ZoookJP04
oookJP06o`3Doooonf[o00Coo`2Yoooonf[o08So0_oonfX00ol0odko0?ldoookJP04oookJP04o`3Q
ool0oagooo]Zo`3oD`?ooo]Z00koo`1io`2]oooo057ooo]Zo`0Iool@0?oooo]Zoi;o0?l60?oo0?m=
o`0`oon2o`3o0?mKoc7o00Oooo]Z00?o9P3ooookJ_oJo`000_oonfX01Ooo01?oo`2CoookJ_oobP3o
0?lK00;ooo]Z00GoN?l0o`3Lool0:_oooo]ZoomB0004oookJP03o`1coooonf[ooo]Z00?ooo]Z01ko
o`3ZoookJ_oonf[ooaH0oonB0?oo0?coo`H0on_o0?oo0?KoZ03oo`1gooooP@3o>ol0oookJ_l0nooo
N@3oool0gOnco`3o0?oNool0Qooo06coC@3oof40oooR0?oo0?nBoookJ_mX0?oo07CooaP0ooooT002
o`000005oookJ_oo_P3oj`3oon/0oooonfX00_ooE`02oookJP?oo`0]2?oonfX6oon100Oooo]Z0_oo
02d3oookJP06oomG0?oonf[ooo]Zog00ooo[0?oookh01OoonfX00oooT03ooo]ZoaP0o`02oookJP0?
ofP0oooonf[ooo]ZoookJ_l0oi;ooo]Zo`3oT?oR0?oooo]Zof40oooo;P3oC@3oool0K?oonf[oo`27
00;ooo]Z01Go/ol0o`2Soooo0=goN@3oool30?oonf[o0?_ooookJ_lko`3ooh40oom/0?oonf[o07Oo
ool0nOoonf[oZ03ooookJ_oo0?Kojol0ool60?lH0?l00_oonfX01Ooo0?cooo]ZoookJ_ooTP3ooaH0
00?ooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ol0Looooo]ZoookJP08oookJP0:o`3o<oooDP3ooo]Z
o`0Zoooonf[o?ol0o`3Loooonf[oN?l0o`3og`Kooo]Z00Co0?lKoookJ_oonf[oolX00ooonfX00ooo
09?oo`0CoookJP04oookJP06om[o0?oonf[ooo]ZobH0oooonf[o8?l03ooonfX00olao`3ooo]Zo`3o
F`03oookJP06o`3o/?n2o`3o033ooookJ_l0j?oo0?m=0_oonfX00ol60?oooo]Zoi;o0002oookJP03
oa00oooo06[o01Wo00?ooo]Z00Ko5@3ooookJ_oo057o0:gooookJ_oo07TWoookJP00;?oonfX03_nX
0?oooo]ZoookJ_oo0?Wooo]Zo`1goooonf[o0?nJoom/0?l0olcooo]ZonGo0?oonf[o>ol01_nDo`02
oookJP08ool30?oonf[ooo]Zool0gOoonf[o0:?ook?o0?nO0?l5oookJP05o`3og_oo08Oooo]Zoook
J_oo06`00_oonfX01Om=0?oooo]ZonGo0?mQ0?oo0?m500?ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3o
TP06oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603oonKo0?oonfX00_oonfX00oooT03ooo]Zoook
JP06oookJP04oonn0?oonf[o0?l5on/0o`Gooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]Z
oookJP04oookJP03oon10?oonf[ooo]Z00Cooo]Z00Go0=Coo`04oooonf[o0:Woo`28o`02oookJP03
o`3oC_l0ocCooo]Z00Cooo]Z00[o0>7oo`3o7Ooonf[ooo]Zo`3oDooonf[oo`1ioookJ_l0[Oooo`1A
0_oonfX02_l@0?ooolT0oi;o0?oob@3o0?m=ooo90?n2o`3ooo]Zo`3oFolao`04oookJP;oiOl000Ko
9P3oonGo0?oUo`3of_l0oookJ_oo09<2oookJP03ooo:0?l0oa_oolT000;oolT000CoN?l0ooo90?l0
:_oooe801?oonfX00ol0Looooo]ZoookJP04oookJP03ool0j_oob@3oolT000GoolT001CoogT0o`1g
ooooN@3o>ol0oomi0?oo:03oo`3Mool00?nco`3oo`00ool0K?m=0?ooH@3oon80ool0oi;ooo]ZofP0
oooonf[o603oonKo00?o000000?ookh0on/0oooo:0003_oo:003oon100Kooo]Z0oooP@05oookJPGo
olT00_ooE`02oookJP03on/0ool0o`Gookh000;ooo]Z1?ooN@001OoVo`3o603ooomi0?oonf[oJ03o
00?ooo]Z00[o0?nBoookJ_oR0?oooo]Zof40oooo;P3oC@3ooookJ_oo06coo`270_oonfX01?nco`3o
0:?oool0gOmi0?l3ooo900;oogT000_o>ol0oomi0?l0MoooogT0ool0nOoonf[oZ03ooookJ_o[o`3o
iOl0ool60002onGo0005oookJ_oo0?cooo]ZoookJ_ooTP001?oonfX00ooo0>[ooo]ZoookJP0:oook
JP03o`1coooonf[ooo]Z00Oooo]Z00_o^Ol0oookJ_ooDP3ooo]Zo`0Zoooonf[o?ol0oookJ_l0g?oo
N?l0o`3og`06oookJP03oa80ool0oa_oolX000?ooo]Z00?oo`2Co`3ioooo01<01OoonfX01_oJo`3o
oo]ZoookJ_oonf[o9P3ooh@0o`oooo]Z00?o<Ol0oookJ_l0oe/00ooonfX2onGo0006oiCo0?l0j?oo
oo]Zo`3oCOoonf[o1P3o0_oonfX01OnBo`3ooo]ZoookJ_l@0?oo01Wo00Cooo]Z00Ko5@3oool0DOoo
nf[ooo]Zo`2]oooo07U?oookJP0>ojP0oooonf[ooo]ZoookJ_oo0?Wooo]Zo`1gool0oi[oof`0o`3o
c?oonf[ooh40oookJ_lko`03oookJP03o`3koooonf[ooo]Z00;ooo]Z00Woo`<0oookJ_oonf[oo`3M
ogT0ool0Xooo01Oook?o0?nO0?l01OoonfX01?oo08Oooo]ZoookJ_oo06`3oookJP04odd0oooo;P3o
H@3oo`3oA@Cooo]Z00GohP3ooookJ_oonf[ooo]Zo`3oTP05oookJP03ofP0oooonf[ooo]Z00;ooo]Z
00?o603oonKo0?oonfX00_oonfX00oooT03ooo]ZoookJP07oookJP04oonn0?oonf[oj`3oog00o`Co
oo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Co
oo]Z00Go0=Coo`04oooonf[o0:Woo`28o`03oookJP03o`3oC_oonf[ooo]Z00Cooo]Z00Co0>7oo`3o
7Ooonf[o0?mC0_oonfX03ooo07Wooo]Zo`2]oooo057ooo]Zo`0Iool@0?ooT_l0oookJ_l0odgo033o
o`3o/On2o`3o0?mKoc7o0006oookJP04oh@0oolV0?oooo]Zom[o00;ooo]Z00Coo`2CoookJ_oonf[o
0?lK0ooonfX01Omho`3o0=coo`0ZooooDP3o^Ol000?ooo]Z00?o07?ooookJ_oonfX01?oonfX07?oo
0>[ooo]ZoookJ_ooTP3oo`3loookJ_oo1P3ojol0ojP0ool0Moooof`0oc_o0?oonf[o0?_oogT0oooo
0=go/ol0o`3og_oo08Ooo`1/odd0oomQ0?oohP3oo`3oT_oonf[oJ03oo`1doolH0?l4o`000003oonn
0?o[0?oooo]Z00;ooeL000Cooo]Zool0;Ooo02goo`0]1?oonfX7oon100Kooo]Z0oooP@06oookJP05
ool0;Ooonf[ooo]ZoookJ_ooE`000_oonfX00oo[0?oo0?l5oonn0004oookJP04oon@0?oonf[ooo]Z
oaP0o`;ooo]Z00ooJ03ooookJ_oonf[ooo]Zo`3oT_oonf[ohP3ooookJ_l0odGoH@3oodd0oooonf[o
o`1/ool0QooMo`000_oonfX01?nco`3oo`3MogT0oooo0`02oookJP0Ao`3koooonf[o>ol0o`3oc?oo
K03o07Ooool0nOoonf[oZ03oo`2Voooo0?Kojol0ool60?oonf[o603ooookJ_oo0?`00_oonfX00ooo
TP3ooaH0oookJP02oookJP03ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX02?oonfX02_ni
o`3o0?lcoomB0?l0:_oooo]Zocoo0?oonf[o0=coogSo0?l0oml6oookJP04oa80ool0oa_ooo]Zooo:
00?ooo]Z00?oo`2Cool04ooonfX01?oonfX01_oJo`3ooo]ZoookJ_oonf[o9P3oob3o00oooo]Z00?o
<Ol0oookJ_l0oe/00ooonfX01_l0ok3oP_l0o`0`oooonf[o0>Soo`3oC@;ooo]Z00So1P3ooookJ_nB
o`3oo`3eoookJ_l@0?ooo`1Zo`0Io`?ooo]Z00Ko5@3ooookJ_oo057ooo]Zo`2]oooo07TWoookJP00
;?oonfX03_nX0?oooo]ZoookJ_oo0?Wooo]Zo`1goooonf[oof`0oookJ_l0olcooo]ZonGo0?lko`3o
oo]Z1_nDo`02oookJP07ool30?oonf[ooo]Zool0gOoonf[o0:?ook?o0006oookJP05o`3og_oo08Oo
oo]ZoookJ_oo06`00_oonfX01Om=0?ooiOl0oookJ_mQ0?oo0?m500?ooo]Z00CohP3oo`3oT?oonf[o
0?nB1_oonfX00omX0?oooo]ZoookJP03oookJP05oaP0oooVo`3ooo]ZoookJ_ooT0002OoonfX01?oo
_P3ooo]Zo`3o1Oo[0?l4oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01?oonfX0
0oooP@3ooo]ZoookJP05oookJP04o`3Dool01?oooo]Zo`2Yo`;ooo]Z00?o0?l^o`3oC_l0oc@01?oo
nfX01Ol0hOoooo]Zo`3o7Ooonf[o0?mC00;ooo]Z00Koo`1ioookJ_l0[Oooo`1AoookJ_l06Ol2ooo9
0007oi;o0?oob@3o0?m=oh;o0?l0ok3o0?mKoc7o0004oookJP?oiOl000[o9P3oonGo0?oJo`3ooo]Z
ool04ooo09?ooo]Zooo:0?lB0?oo0?lK0_oob@001Omho`3oolT0o`0Zoonio`3ooe8000Cooo]Z00?o
07?ooookJ_oonfX00ooonfX01?oo0>[ooo]ZoolF0?ooTP05ooo90003ool0nOl0Mooo>ol000;oogT0
00ooN@3oool0gOnco`3oo`00ool0K?m=0?ooH@3oon80ool0oi;ooo]ZofP0oooonf[o603oonKo0?oo
nfX00_l000000ooo_P3oj`3ooolX0005oolX00?oogT01Ooo:0000ooonf[oo`00ool0000;oookJP?o
oh4000?ooo]Zooo90?oob@001_oob@001_ooE`3ooo]ZoookJ_o[0?oo0?l5oonn00;ooo]Z1?ooN@00
1?oVo`3o603ooookJ_mX0?l4oookJP0:o`3oT_l0oi3ohP3ooookJ_mQ0?ooC@3ooookJ_oo06coo`27
o`3ogP;ooo]Z00Co/ol0ool0gOmi0?ooolT01?ooN@002olko`3oogT0oomi0?l0Moooo`3ioookJ_nX
0?oo0:Koool0m_o[o`3oo`H000;oiOl00_oonfX01?oo0?cooo]ZoonB0?oo5P03oookJP03ool0j_oo
nf[ooo]Z00_ooo]Z00?o07?ooookJ_oonfX01_oonfX02onio`3ooo]ZoomB0?oonf[o02[ooookJ_lo
o`3ooo]Zo`3Loomho`3o0?oO00Kooo]Z00?o4P3oonGo0?oobP000ooonfX00ooo09?o0?Woool04`05
oookJP06om[o0?oonf[ooo]ZoookJ_lV0?ooQ03o3ooonfX00olao`3ooo]Zo`3oF`03oookJP08o`3o
/?oUo`3oU?l0o`3Xoooonf[o0?m=oookJ_l60?l2oookJP05oi;o0?oonf[ooo]Zoa00ool06Ol01?oo
nfX01_lE0?ooo`1AoookJ_oonf[o0:goool0NDoooo]Z00koZ03ooookJ_oonf[oo`3ioookJ_l0Mooo
oo]Zo`3oV_ooK03o0?o<oookJ_ooP@3ooo]Zoc_o00?ooo]Z00?o0?_ooookJ_oonfX00_oonfX02?oo
0`3ooo]ZoookJ_oo0=goN@3oo`2Soonco`3oW`3o1_oonfX01?oo08Oooo]ZoookJ_oo06`3oookJP04
odd0oooo;P3oH@3oo`3oA@Cooo]Z00CohP3ooookJ_oonf[o0?nB1OoonfX00omX0?oooo]ZoookJP03
oookJP05oaP0oooVo`3ooo]ZoookJ_ooT0002_oonfX00ooo_P3o0?l5on/0o`04oookJP03oomG0?oo
nf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3ooo]ZoookJP05oookJP05o`3Dool0
1?oooo]Zo`2Yool0R?l00_oonfX00ol0obko0?m>oookJP04oookJP04o`3Qool0oago0?l8o`3oD`?o
oo]Z00koo`1io`2]oooo057o5@3oo`0Iool@0?oooo]Zoi;o0?l60?oo0?m=o`0`oon2o`3ooo]Zoc7o
00Oooo]Z00?o9P3ooookJ_oJo`000_oonfX01Ooo01?oo`2CoookJ_oobP3o0?lK00;ooo]Z00GoN?l0
o`3Looloo`3o02[ooomB0004oookJP03o`1coooonf[ooo]Z00?ooo]Z01goo`3ZoookJ_oonf[ooi80
oookJ_oo0?coo`H0on_o0?l0Y_ooo`3io`1goolko`3ooo]Zo`3koomi0?ooo`3Mok?o0?oonf[oo`27
ool0K?m=0?ooH@3oon80ool0oi;ooo]ZofP0ool0M?oo603ooookJP02o`000006oonn0?o[0?ooj`3o
oookJ_ooE`3ooo]Z0_oo02d3oookJPCooh404?oonfX2oon100Gooo]Z0_oo02d2oookJP06oomG0?oo
nf[ooo]Zon/0ool0o`Gookh01?oonfX01?ooT03ooo]ZoookJ_lH0?l2oookJP0>ofP0oooonf[ooo]Z
oookJ_l0oi;o0?n@on80oooonf[o0?m5of40oom=0?ooo`1/oookJ_oo08L2oookJP0=ok?o0?nO0?oo
o`3MoookJ_oo0`3ooo]Zo`3koooonf[o>ol0oon10?ooK03o07Ooool0n@02oookJP06ojP0oooo0?Ko
jol0ool60?oonf[o603o0_oonfX01Ooo0?cooo]ZoonB0?oonf[ooaH000;ooo]Z00?oo`3ZoookJ_oo
nfX02ooonfX00ol0Looooo]ZoookJP07oookJP0:okWo0?l0oc?ooe80o`0Zoooonf[o?ol0oookJ_l0
g?ooN?l0o`3og`Kooo]Z00Co4P3oo`3o6ooonf[oolX00ooonfX00ooo09?oo`0CoookJP04oookJP06
om[o0?oonf[ooo]ZoookJ_lV0?oo8?l03ooonfX00olao`3ooo]Zo`3oF`03oookJP06o`3o/?n2o`3o
033ooookJ_l0j?oo0?m=0_oonfX02?l60?oooo]Zoi;o0?oo0?Gooo]Zoa00oooo06[o01Wo0ooonfX0
1_lE0?oooo]Zool0DOoonf[o0:goool0NBOooo]Z000[oookJP0:ojP0oooonf[ooo]ZoookJ_oo0?Wo
oo]Zo`1goooonf[oof`0o`3oc0;ooo]Z00?oiOl0oc_o0?nDo`001_nDo`02oookJP07ool30?oonf[o
oo]Zool0gOoonf[o/ol0oil0o`05oookJP03o`3og_oo08Oooo]Z00;ooo]Z00Soo`1/oookJ_oonf[o
C@3oonGo0?oonf[oH@3oo`3oA@?ooo]Z00CohP3ooookJ_oonf[o0?nB1_oonfX00omX0?oooo]Zoook
JP03oookJP05oaP0oooVo`3ooo]ZoookJ_ooT0002OoonfX01?oo_P3ooo]Zo`3o1Oo[0?l4oookJP03
oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3ooo]ZoookJP04oookJP05
o`3Dool01?oooo]ZoookJ_l0ZOl00_oonfX00ol0odkooo]Zo`3o=004oookJP05o`3Qool0oago0?l8
oookJ_l0oe<00_oonfX00ooo07Wo0:goool0D@02oookJP0:o`0Ioooob@3oT_l0ooo90?l0j?oo0?m=
oh;o0?l0ok3o0?mKoc7o00?ooo]Z1?oUo`002OlV0?ooiOl0om[o0?oonf[oo`0Cool0Tooonf[oolX0
o`3o6`03ooo90004ogSo0?oob@3o02[ooomB00Cooo]Z00?o07?ooookJ_oonfX00ooonfX01_oo0>[o
oo]ZoookJ_ooTP3oolT0oookJPCoolT000?o07Oooon10?lko`000_ooN@003Ooo0=go/ol0ool00?oo
003oo`1/of40oooR0?oo0?n@oookJ_mX0?oooo]ZoaP0oooVo`000_oonfX00ol0003ookh0on/0o`03
onGo0003oolX0?oUo`3oiOl000_oiOl02Ol0e?l6oookJP;ooh400_nDo`06ooo90006oomG0?oonf[o
oo]Zon/0ool0o`Gookh00_oonfX4oomi0004oaP0ooooN@3ooo]ZofP0o`?ooo]Z00[o0?nBoookJ_oR
0?oooo]Zof40oooo;P3oC@3oool0K?oonf[oo`270_oonfX01?nco`3o0:?oool0gOmi0?l4oomi000<
oc_o0?ooN@3oogT0o`1gooooN@3oo`3iojP0ool0Y_ooo`3fon_o0?oonf[oo`H00_oUo`001Ooonf[o
o`3loookJ_ooTP3ooaH000Cooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ol0Looooo]ZoookJP06oook
JP05okWo0?oonf[ooe80oookJ_l0:_l00_oonfX01?loo`3o0=coogSo0?l0oml6oookJP03oa80oooU
o`3oolX000Cooo]Z00?oo`2Cool04ooonfX01?oonfX01ooJo`3ooo]ZoookJ_oonf[o9P3oob3o0?n4
0?l03_oonfX00olao`3ooo]Zo`3oF`03oookJP08o`3o/?n2o`3oU?l0o`3Xoooonf[o0?m=oookJ_l6
0?l2oookJP05oi;o0?oonf[ooo]Zoa00ool06Ol01?oonfX01_lE0?ooo`1AoookJ_oonf[o0:goool0
NDkooo]Z00[oZ03ooookJ_oonf[ooo]Zool0nOoonf[o07OooookJ_ooK03o0?o<0_oonfX00oooP@3o
oo]Zoc_o0002oookJP03o`3koooonf[ooo]Z00?ooo]Z00Soo`<0oookJ_oonf[oo`3MoookJ_l0Xooo
/ol0oil0o`Gooo]Z00Goo`27oookJ_oonf[ooo]Zool0K003oookJP04odd0oooo;P3oH@3oo`3oA@?o
oo]Z00Go0?n@on80oooonf[ooo]Zo`3oTP05oookJP03ofP0oooonf[ooo]Z00?ooo]Z00Go603oonKo
0?oonf[ooo]Zoon@0009oookJP04oonn0?oonf[o0?l5on/0o`Cooo]Z00?ooeL0oookJ_oonfX00ooo
nfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Cooo]Z00Ko0=CooookJ_l01?oooo]Z
o`2Yool0R?l2oookJP03o`3oC_l0ocCooo]Z00Cooo]Z00Co0>7oo`3o7Ol0o`So0?mC0ooonfX03_oo
07Wo0:goool0DOoonf[o01Wooa00oonBo`3oo`3eo`3Xool0odgooo]Zoh;o0?l0oe_o<Ol01_oonfX0
1?n40?oo9P3ooookJ_oJo`02oookJP04ool0Tooonf[ooo]Zo`3o6`?ooo]Z00GoN?l0o`3Lool0:_oo
oe80okWo0003oookJP03o`1coooonf[ooo]Z00?ooo]Z01coo`3ZoookJ_oonf[ooaH0oonB0?oo0?co
oo]Zool60?l0Y_ooZ03oo`1gooooP@3o>ol0o`3koooo0`3oo`3Mok?o0?oonf[oo`27ool0K?m=0?oo
H@3oon80ool0oi3ooo]ZofP0ool0M?oo603o0_oonfX01?l0003ookh0on/0ool00002oomG0004oook
J_oo02gooo]ZoookJP?ooh401?oonfX<o`3Do`Kooo]Z0_ooP@05oookJP04ool0;Ooonf[ooo]ZoomG
00;ooo]Z00?oj`3oo`3o1Ooo_P001?oonfX01_ooT03ooo]ZoaP0oooVo`3ooo]ZofP0o`?ooo]Z00_o
0?nBoookJ_oR0?oooo]Zo`3oAOmQ0?ooC@3oool0K?oonf[oo`27omgo0002oookJP0Kok?o0?oo0=go
N@3oool30?oonf[o0?_ooookJ_lko`3ooh40o`3oV_ooK03o07Ooool0nOoonf[oZ03oool0m_oonf[o
jol0ool60?oonf[o603ooookJ_oo0?cooo]ZoonB0?oonf[ooaH000?ooo]Z00?oo`3ZoookJ_oonfX0
2_oonfX00ol0Looooo]ZoookJP07oookJP04okWo0?l0oc?ooe80o`0Zo`;ooo]Z00Co?ol0o`3Loomh
o`3o0?oO1_oonfX01?lB0?oo0?lKoookJ_oobP03oookJP03ool0Tooo01?ooo]Z00Cooo]Z00Oof_l0
oookJ_oonf[ooo]ZobH0oolPo`3oQ03o00kooo]Z00?o<Ol0oookJ_l0oe/00ooonfX01_l0ok3oP_l0
o`0`oooonf[o0>Soo`3oC@;ooo]Z00So1P3ooookJ_nBo`3oo`3eoookJ_l@0?ooo`1Zo`0Io`?ooo]Z
00Oo5@3ooookJ_oo057ooo]Zo`2]oooonf[oo`1i02Kooo]Z000[oookJP0:ojP0oooonf[ooo]Zoook
J_oo0?Wooo]Zo`1goooonf[oof`0onGo00;ooo]Z00?oiOl0oc_o0?nDo`001_nDo`000ooonf[oo`<0
oookJP02oookJP04ool0gOl0Xooo/ol0oil0o`Gooo]Z00?o0?oNool0QooonfX00_oonfX01ooo06co
oo]ZoookJ_m=0?ooiOl0of40ool0odD00ooonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Kooo]Z00?o
J03ooookJ_oonfX00ooonfX01OlH0?ooi_l0oookJ_oonf[ooi0000Wooo]Z00Cookh0oookJ_l0o`co
j`3o1?oonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Cooo]Z00?ooh40oookJ_oo
nfX01?oonfX01Ol0e?oo00CooookJ_l0ZOoo08So00;ooo]Z00?o0?m>o`3o=?oonfX01?oonfX02_l0
hOoo0?lMoookJ_oonf[o0?mCoookJ_oo07Wooo]Zo`2]oooo0542oookJP;oolT000SoT_l0ooo90?l0
odgoolT0oh;o0?l0oe_ooo]Zoc7o00?ooo]Z0ooUo`002_lV0?ooiOl0om[o0?oUo`3oo`0Cool0Tooo
nf[oolX0oa80ool0oa/2ooo90005ogSo0?oob@3oolT0o`0ZooooDP001?oonfX00ol0Looooo]Zoook
JP03oookJP07ool0j_oonf[ooaH0ooo90?oonf[oolT0ool60002ooo90007ool0nOl0Mooo>ol0oomi
0?oo003oo`3Mok?o0002ool00009ool0K?oo003oo`00o`3oT?l0oi;ooo]ZofP0oooonf[o603o00;o
oo]Z00Cookh0ool00?oo003ooeL03ooUo`05ool00006oolX0?l0ZOoo0:Woo`28oooonf[o00Co0ol0
e?l4oookJP?oU?l01_oob@001ooonf[ooeL0oookJ_oonf[oj`3oo`3o1Ooo_P000_oonfX4oomi0003
oaP0oooonf[oJ03o00Cooo]Z00Wo0?nBon80oooonf[o0?m5of40oooo;P3oC@3oool0K?oo08L00ooo
nfX01?nco`3oo`3MogT0oooob@03oomi000<oc_o0?ooN@3oogT0o`1gooooN@3oo`3iojP0oooonf[o
olT0on_o0?oonf[oo`H00_oUo`001Ooonf[oo`3loookJ_oonf[ooi8000Cooo]Z00?oo`3ZoookJ_oo
nfX02_oonfX00ol0Looooo]ZoookJP07oookJP0:okWo0?ooDP3ooo]ZoookJ_l0:_oooo]Zocoo0?l0
g?ooN?l0o`3og`Kooo]Z00?o4P3oonGo0?oobP001?oonfX00ooo09?oo`0CoookJP04oookJP07om[o
0?oonf[ooo]ZoookJ_lV0?oo8?l0oh@0o`0>oookJP03oc7o0?oonf[o0?mK00?ooo]Z00So0?n`oh;o
0?nDo`3oU?l0o`3Xool0odgoU?l0o`H0o`;ooo]Z00GoT_l0oookJ_oonf[o403oo`0Io`04oookJP06
oaD0oooo057ooo]ZoookJ_l0[Oooo`1iC_oonfX02_nX0?oooo]ZoookJ_oonf[oo`3ioookJ_l0Mooo
oo]Zoom/0?l0ol`2oookJP03oon10?oonf[o>ol000;ooo]Z00?o0?_ooookJ_oonfX00_oonfX02Ooo
0`3ooo]ZoookJ_oonf[oo`3Mo`2Soooonf[o/ol0oil0o`05oookJP05ool0Qooonf[ooo]ZoookJ_oo
06`00ooonfX00om=0?ooH@3oo`3oA@04oookJP05on80oooonf[ooo]ZoookJ_l0oi801OoonfX00omX
0?oooo]ZoookJP03oookJP05oaP0oooVo`3ooo]ZoookJ_ooT0002OoonfX01?oo_P3ooo]Zo`3o1Oo[
0?l4oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3ooo]Zoook
JP04oookJP05o`3Dool01?oooo]Zo`2Yool0R?l00ooonfX00ol0odkooo]ZoookJP04oookJP04o`3Q
ool0oagooo]Zo`3oD`;ooo]Z00ooo`1ioookJ_l0[Oooo`1AoookJ_l@0?oo05gooi;o0?oonf[o0?m=
o`0`ool0ok7oP_l0o`3oFolao`001_oonfX02_n40?oo9P3oom[o0?oQo`3ooo]Zool04ooo09?ooo]Z
ooo:0?l0oa/2oookJP06ogSo0?lm0?oo?ol0o`0ZooooDP3o^Ol00ooonfX00ol0Looooo]ZoookJP03
oookJP0Kool0j_oonf[ooo]ZoonB0?oo0?cooo]Zool60?o[o`3oZ03oool0nOl0Mooo>ol0o`3koooo
nf[oo`3Mok?o0?oonf[oo`27ool0K?m=0?ooH@3oon80ool0oi3o0?nBoookJ_mX0?oo603o00?ooo]Z
00Gookh0on/0ooooE`3ooeL0oookJP02ool0;@03oookJ_ooP@3ooh4000Cooo]Z0ol0e?l5o`04o`Go
0:Wo00?ooo]Zo`04ool0e?l00_l0e?l5oookJP03oon10?oonf[ooo]Z00;ooo]Z00Goo`0]oookJ_oo
nf[ooo]ZoomG0002oookJP03on/0ool0o`Gookh000?ooo]Z00Oooi00oookJ_oonf[o603oonKo0?oo
nf[oJ03o00?ooo]Z00[o0?nBon80oooonf[o0?m5oookJ_mQ0?ooC@3oool0K?l0omkoo`270_oonfX0
1?nco`3o01Ooool0gOoo0`02oookJP0Ao`3koolko`3ooh40o`3oc?ooK03o07Ooool0nOoonf[oZ03o
o`2Voooo0?Kojol0ool60?oonf[o603ooookJ_oo0?`00_oonfX00oooTP3ooaH0oookJP02oookJP03
ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX02?oonfX02Ol0oc?ooe80oookJ_l0:_oooo]Z
ocoo0?l0g?oooo]ZogSo0006oookJP04o`2>ool0oa_ooo]Zooo:00?ooo]Z00?oo`2Cool04ooonfX0
1?oonfX01ooJo`3ooo]ZoookJ_oonf[o9P3oob3o0?n40?l03_oonfX00olao`3ooo]Zo`3oF`03oook
JP06o`3o/?n2o`3o033ooookJ_l0j?oo0?m=0_oonfX02?l60?oooo]Zoi;o0?oo0?Gooo]Zoa00oooo
06[o01Wo0ooonfX01olE0?oooo]Zool0DOoonf[o0:gooookJ_oo07T09_oonfX002_ooo]Z00KoZ03o
oookJ_oonf[oo`3ioookJ_l0Mol2oookJP06oom/0?oUo`3ooo]ZonGo0?oonf[o>ol01onDo`002Ooo
nf[oo`<0oookJ_oonf[oN@3oool0gOl0Xooo/ol0oil0o`05oookJP05o`3og_oo08Oooo]ZoookJ_oo
06`00_oonfX01Om=0?oooo]ZonGo0?mQ0?oo0?m500?ooo]Z00CohP3oo`3oT?oonf[o0?nB1ooonfX0
0omX0?oooo]ZoookJP03oookJP05oaP0oooonf[ooo]ZoookJ_ooT0002?oonfX01?oo_P3ooo]Zo`3o
1Oo[0?l4oookJP03oomG0?oonf[ooo]Z00Cooo]Z00?oo`0]oookJ_oonfX00ooonfX00oooP@3ooo]Z
oookJP05oookJP04o`3Dool01?oooo]Zo`2Yo`?ooo]Z00?o0?m>o`3o=?oonfX00ooonfX01Ol0hOoo
0?lMo`3o2?oonf[o0?mC00;ooo]Z00Koo`1ioookJ_l0[Oooo`1AoookJ_l06Ol2ooo90007oi;o0?oo
b@3o0?m=ooo90?l0ok3o0?mKoc7o0003oookJPCoiOl000Wo9P3oonGo0?oJo`3ooo]Zool04ooo09?o
oo]Zooo:0?l0oa/00ooob@001?mho`3oolT0o`0ZooooDP05oookJP03o`1coooonf[ooo]Z00;ooo]Z
00Soo`3ZoookJ_oonf[ooi80ool0o?oonf[oo`H0on_o00;oolT000Wo07Oooon10?lko`3oo`00ool0
gOoo003o/ol0ool00?oo06`00ooo00001ol0oi;ooo]ZofP0oooonf[o603ooon@0?oonfX01?oo0000
0oooN@3oiOl0onGo000;onGo00;oobP01?oo0003oolX0003oookJ_l0ZOoo0:Wo00?o0:Wo00?o00Co
o`3Dool0e?l01_nDo`06ooo90007oomG0?oonf[ooo]Zon/0oom`0?oo0?l5oonn0002oookJP?oogT0
00Coi_l0oaP0oooonf[oJ03o0ooonfX02_l0oi;o0?n@on80oooonf[oH@3ooookJ_m=0?ooo`1/ool0
Qol0omh2oookJP05ok?o0?oo0=goN@3ooookJ_oob@000oooN@002olko`3oogT0oomi0?l0Moooo`3i
ojP0oooonf[oolT0ool0m_o[o`3oo`H000;oiOl000Gooo]Zool0o?oonf[ooo]ZoonB0004oookJP03
ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX01ooonfX02_nio`3ooe80o`3o<ooonf[o02[o
oookJ_loo`3ooo]Zo`3Loomho`06oookJP03oa80oooUo`3oolX000Cooo]Z00?oo`2ConGo0?oo01<0
1?oonfX01ooJo`3ooo]ZoookJ_oonf[o9P3oob3o0?oUo`003_oonfX01?lao`3ooo]Zo`3oFooonfX2
oiCo0008o`3o/?n2o`3oU?l0oiCo0?l0j?oo0?m=oiCo0?l60?l2oookJP05oi;o0?oonf[ooo]Zoook
J_l@0?l01?oonfX01_lE0?ooo`1AoookJ_oonf[o0:goool0NDkooo]Z00koZ03ooookJ_oonf[ooo]Z
ool0nOoonf[o07OooookJ_ooK03o0?o<oookJ_ooP@3ooo]Zoc_o00?ooo]Z00?o0?_ooookJ_oonfX0
0_oonfX02Ooo0`3ooo]ZoookJ_oonf[oo`3Mo`2Soooonf[o/ol0oil0o`05oookJP05ool0Qooonf[o
oo]ZoookJ_oo06`00_oonfX01?m=0?ooobh0of40ool0odD4oookJP04on80oooonf[ooo]Zo`3oTPKo
oo]Z00?oJ03ooookJ_oonfX00ooonfX01OlH0?oooo]ZoookJ_oonf[ooi0000Wooo]Z00?ookh0oook
J_o[0?l01?oonfX00oooE`3ooo]ZoookJP04oookJP03ool0;Ooonf[ooo]Z00?ooo]Z00?ooh40oook
J_oonfX01OoonfX01Ol0e?oo00CooookJ_l0ZOoo08So00?ooo]Z00?o0?m>oookJ_oonfX00ooonfX0
1?l0hOoo0?lMo`3o2?l0oe<3oookJP0>ool0NOl0[Oooo`1AoaD0ool06Ooo403ooookJ_nBo`3o1P3o
o`3oCOl0<?ooP_l0o`3oFolao`07oookJP03obH0oooonf[of_l000;ooo]Z00Goo`0Cool0Tooonf[o
0?lKoa80o`02oookJP05ogSo0?l0g?oo02[ooomB0?nio`001?oonfX00ol0Looooo]ZoookJP02oook
JP0Lool0j_oonf[ooo]ZoolF0?ooTP3oo`3lool60?o[o`3o0:KoojP0ool0Mooooh40oc_o0?l0nooo
o`3Mo`2Soonco`3oo`27ool0K?m=0?ooH@3ooookJ_oR0?oo0?nBoookJ_mX0?oo603ooon@00;ooo]Z
00Cookh0on/0ooooE`3o00000_oo02d2oookJP04oon10?oonf[ooo]ZoookJP?o0=Co0_l01?l2o`2Y
o`Co08So1OoonfX4o`2Yo`04oookJ_l0e?oo0=Coo`04o`?ooo]Z0_ooP@03oookJP04ool0;Ooonf[o
oo]ZoomG00?ooo]Z00?oj`3oo`3o1Ooo_P000ooonfX01?ooT03ooo]Zo`1doolH0?l2oookJP0VofP0
oooonf[ooo]Zo`3oT_l0oi3ohP3ooookJ_l0odGoH@3oodd0oooo06cooo]Zool0QooMo`3ooo]Zok?o
0?nO0?ooo`3MoookJ_oo0`3ooo]Zo`3koooonf[o>ol0oon10?ooK03o07Ooool0nOoonf[oZ03oo`2V
oooo0?Kojol0ool60?oonf[o603ooookJ_oo0?`2oookJP03oonB0?oo5P3ooo]Z00;ooo]Z00?oo`3Z
oookJ_oonfX02_oonfX00ol0Looooo]ZoookJP08oookJP09okWo0?ooDP3ooo]Zo`0Zoooonf[o?ol0
oookJ_l0g?ooN?l000Kooo]Z00Co08koo`3o6ooonf[oolX00ooonfX00ooo09?o0?Woool04`04oook
JP07om[o0?oonf[ooo]ZoookJ_lV0?oo8?l0oh@0o`0>oookJP03oc7o0?oonf[o0?mK00?ooo]Z00Ko
0?n`oh;o0?l0<?oooo]Zo`3Xool0odd2oookJP04o`H0oooonf[ooo]Zoi;o00;ooo]Z00?o403oo`0I
oooonfX00_oonfX01olE0?oooo]Zool0DOoonf[o0:gooookJ_oo07T09_oonfX002_ooo]Z00koZ03o
oookJ_oonf[oo`3ioookJ_l0Mooooo]Zoom/0?l0oi[oiOl0oookJ_oUo`3ooo]Zoc_o00OoU?l000Wo
oo]Zool30?oonf[ooo]Zool0gOoonf[o/ol0o`0GoonO0?l01OoonfX01Ooo08OogOl0oookJ_oonf[o
o`1/00;ooo]Z00GoC@3ooookJ_oUo`3oH@3oo`3oA@03oookJP04on80ool0oi3ooo]Zo`3oTPOooo]Z
00?oJ03ooookJ_oonfX00_oonfX00olH0?ooi_l0oookJP02oookJP03oon@0?oonf[ooo]Z00Kooo]Z
00Cookh0oookJ_l0o`Goj`3o1?oonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Co
oo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0e?oo00CooookJ_oonf[o0:Wo00;ooo]Z00?o0?l^o`3o
C_l0oc@01?oonfX01Ol0hOoo0?lMo`3o2?oonf[o0?mC00;ooo]Z00?oo`1io`2]oooo05400_oonfX2
ooo90008oi;o0?oob@3o0>Soo`3oCOoob@3o0?n`o`3oFolao`02oookJPCoiOl000[o9P3oonGo0?oJ
o`3oiOl0ool04ol0nOooo`2Cooo:0?oonf[o0?lK0_oob@001Omho`3oolT0ooo90?l0:_oooe8000Co
oo]Z00?o07?ooookJ_oonfX00ooonfX04_oo0>[ooo]ZoolF0?oo0?cooo]ZoaP0oooo1P3o0:KoojP0
ool0MoooolT0oc_o0?oo003oobP0ool00?nco`3oo`00ool0K0?oo`0000Ko0?nBoolX0?mX0?oooo]Z
oaP0ooooT005ool00003o`000?ooN@3oogT000_oiOl000?oo`00oolX0?l0odh02ol0odh01Ooonf[o
08Soo`2Yool0ZOooU?l000;o0=Co1?nDo`000oooP@3ooo]Zooo90003ooo90008oookJ_ooE`3ooo]Z
oookJ_o[0?ooL03ooookJ_oo_P02oookJP?oogT000Co603ooookJ_oonf[oJ03o0_oonfX04Ol0oi;o
oo]Zon80oooonf[oH@3ooookJ_m=0?ooo`1/oomi0?oo08OoogT0oookJ_nco`3o0:?oool0gOoonf[o
olT000?oogT000oo>ol0oomi0?ooN@3o07Ooool0nOoonf[oZ03oooo90?oo0?Kojol0oookJ_oo1P3o
iOl0oookJ_oo0?`00_oonfX00oooTP3ooo]ZoookJP02oookJP03ool0j_oonf[ooo]Z00_ooo]Z00?o
07?ooookJ_oonfX01_oonfX02_nio`3ooe80oiCo0?oonf[o02[ooookJ_loo`3ooo]Zo`3Loomho`06
oookJP03oa80oooUo`3oolX000Cooo]Z00?oo`2ConGo0?oo01<01?oonfX01ooJo`3ooo]ZoookJ_oo
nf[o9P3oob3o0?oUo`003_oonfX01?lao`3ooo]Zo`3oFooonfX2oiCo0008o`3o/?n2o`3oU?l0oiCo
0?l0j?oo0?m=oiCo0?l60?l2oookJP05onGo0?nBo`3ooo]ZoookJ_l@0?l01?oonfX01_lE0?ooo`1A
oookJ_oonf[o0:goool0NDkooo]Z00koZ03ooookJ_oonf[ooo]Zool0nOoonf[o07OooookJ_ooK03o
0?o<oookJ_ooP@3ooo]Zoc_o00?ooo]Z00?o0?_ooookJ_oonfX00_oonfX02Ooo0`3ooo]ZoookJ_oo
nf[oo`3Mo`2Soonco`3ooo]Zoil0o`04oookJP03ool0Qol0omkooo]Z00;ooo]Z00Ooo`1/oookJ_oo
nf[oC@3oool^0?mQ0?oo0?m500Cooo]Z00CohP3ooookJ_oonf[o0?nB1_oonfX00omX0?oooo]Zoook
JP02oookJP03oaP0oooVo`3ooo]Z00;ooo]Z00?ooi00oookJ_oonfX01_oonfX01?oo_P3ooo]Zoook
J_o[0?l4oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3ooo]Z
oookJP04oookJP06o`3Doooonf[o00CooookJ_l0ZOoo08So0_oonfX00ol0odko0?ldoookJP04oook
JP04o`3Qool0oago0?l8o`3oD`?ooo]Z00koo`1io`2]oooo057ooo]Zoa00ool0GOooT_l0oookJ_l0
j?oo0?m=oookJ_n2o`3o0?mKoc7o00Kooo]Z00[oQ03oobH0oooJo`3ohOl0oookJ_oo01?oo`2Coook
J_oobP3o0?lK0_oonfX01_mho`3o?@3oocoo0?l0:_oooe80okWo00?ooo]Z00?o07?ooookJ_oonfX0
0ooonfX06ooo0>[ooo]ZoookJ_ooTP3oo`3loookJ_oo1P3ojol0ojP0ool0Moooof`0oc_o0?l0nooo
o`3Mo`2Soonco`3o0?oNool0K?m=0?ooH@3ooookJ_oR0?oo0?nBoookJ_mX0?oo603ooon@0002oook
JP07oonn0?o[0?oooeL0o`000?oo02go0000oookJP02oon100;ooo]Z0_l0e?l00ol01?oo0:Woo`28
o`02o`28o`;o0?ld3?l0odh01?l0R?oo0:Woo`2Yool0ZOl2o`3Do`Cooo]Z00Gooh40oookJ_oonf[o
oo]Zool0;@02oookJP07oomG0?oonf[ooo]ZoookJ_o[0?oooo]Zoonn0003oookJP04oon@0?oonf[o
603oonKo00;ooo]Z00goJ03ooookJ_l0oi;ooo]Zon80oooonf[o0?m5of40oom=0?ooo`1/oookJ_oo
08OogOl000;ooo]Z01Ko/ol0ool0gOoonf[oo`<0oookJ_l0nooooo]Zoc_o0?ooP@3oof`0o`1goooo
0?Wooo]ZojP0ool0Y_ooo`3foookJ_o[o`3oo`H0oookJ_lH0?ooo`3l0_oonfX00oooTP3ooaH0oook
JP02oookJP03ool0j_oonf[ooo]Z00_ooo]Z00?o07?ooookJ_oonfX01ooonfX02Onio`3ooe80oook
J_l0:_oooo]Zocoo0?oonf[o0=coogSo0006oookJP04o`2>ool0oa_ooo]Zooo:00?ooo]Z00?oo`2C
o`3ioooo01<01?oonfX01ooJo`3ooo]ZoookJ_oonf[o9P3oob3o0?n40?l03_oonfX01?lao`3ooo]Z
oookJ_l0oe/2oookJP06o`3o/?n2o`3o0?nao`0`ool0j?oo0?m=0_oonfX01?l60?oooo]ZoookJ_nB
o`02oookJP03oa00ool06Ooooo]Z00?ooo]Z00Ko5@3oool0DOoonf[o0:gooookJ_oo07TVoookJP00
:_oonfX03_nX0?oooo]ZoookJ_oonf[oo`3ioookJ_l0Mooooo]Zoom/0?l0oi[oiOl0oookJ_oUo`3o
>ol00ooonfX5oiCo0008oookJ_oo0`3ooo]ZoookJ_oo0=gooo]Zok?o0?nO0?l5oookJP03o`3og_oo
08Oooo]Z00;ooo]Z00Soo`1/oookJ_oonf[oC@3oonGo0?oonf[oH@3oo`3oA@?ooo]Z00CohP3oo`3o
T?oonf[o0?nB1ooonfX00omX0?oooo]ZoookJP02oookJP05oaP0oooVo`3ooo]ZoookJ_ooT0002Ooo
nfX01?oo_P3ooo]Zo`3o1Oo[0?l4oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX0
1?oonfX00oooP@3ooo]ZoookJP04oookJP05o`3Dool01?oooo]ZoookJ_l0ZOl00_oonfX00ol0obko
0?m>oookJP04oookJP0;o`3Qool0oagooo]ZoookJ_l0oe?ooo]Zool0NOoonf[o0:goool0DOoonfX0
0ooob@000onBo`3oolT0o`3oC@02ooo90003onGo0?oonf[o<Ol000Gooo]Z017oiOl0obH0oooUo`3o
f_l0onGo0?oo01?oo`2CoookJ_oobP3o4P3oo`3o6ooonf[oolT0ogSo0?oob@3o02[ooomB0005oook
JP03o`1coooonf[ooo]Z00;ooo]Z00goo`3ZoookJ_oonf[ooi80ool0o?oonf[oo`H0on_o0?nX0?oo
o`3io`1goolko`3oo`0000;oobP000?o/ol0ool00?oo06`01?oo00001?l0oi;oJ03ooookJ_lH0?l6
ool00004o`000?oo02goo`00ool000GoiOl01Ooob@03o`3oCPCoo`001_oo:002o`3o=0;o0?m>00?o
oo]ZoiCo0?nDo`000_nDo`000ol0e?ooU?l0oiCo0002oiCo0003oon10?oonf[oolT000?oolT000Oo
oo]ZoomG0?oonf[ooo]Zon/0oom`0?oookh000?ooo]Z0_ooN@001?oVo`3o603ooookJ_mX0?l3oook
JP0:o`3oT_l0oi3ohP3ooookJ_mQ0?ooogT0odd0oooo06coo`27oomi00;ooo]Z00Go/ol0ool0gOmi
0?ooo`<0ooo90002oomi000=oc_o0?ooN@3oogT0o`1goooonf[oo`3iojP0oooob@3ooo]Zon_o0?oo
nf[oo`H0oaP0o`02oookJP03ool0o?oonf[ooi8000Gooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ol0
Looooo]ZoookJP06oookJP0:okWo0?ooDP3oU?l0oookJ_l0:_oooo]Zocoo0?oonf[o0=coogSo00Ko
oo]Z00Co4P3oonGo0?oonf[oolX00ooonfX00ooo09?oiOl0ool04`04oookJP07om[o0?oonf[ooo]Z
oookJ_lV0?oo8?l0onGo000>oookJP03oc7o0?oonf[o0?mK00;ooo]Z00?oU?l0o`3o/?n2o`000_nD
o`001?l0j?oo0?m=oiCo0?l60?l2oookJP05onGo0?nBo`3ooo]ZoookJ_l@0?l01?oonfX01olE0?oo
o`1AoookJ_oonf[o0:gooookJ_oo07T0C?oonfX01OnX0?oooo]ZoookJ_oonf[oo`3i00;ooo]Z00So
07Oooom/0?l0oi[o0?o<oookJ_ooP@3ooo]Zoc_o00?ooo]Z00?o0?_ooookJ_oonfX00_oonfX02?oo
0`3ooo]ZoookJ_oo0=goN@3oo`2Soonco`3oW`3o1OoonfX01Ooo08Oooo]ZoookJ_oonf[oo`1/00?o
oo]Z00CoC@3oool^0?mQ0?oo0?m51?oonfX01?oR0?oooo]ZoookJ_l0oi86oookJP03ofP0oooonf[o
oo]Z00;ooo]Z00Go603oonKo0?oonf[ooo]Zoon@0009oookJP04oonn0?oonf[o0?l5on/0o`Cooo]Z
00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Cooo]Z
00Go0=Coo`04oooonf[ooo]Zo`2Yo`03oookJP03o`3oC_oonf[ooo]Z00Cooo]Z00Co0>7oo`3o7Ooo
nf[o0?mC0_oonfX03ooo07Wooo]Zo`2]oooo057ooo]Zoa00oooonf[oT_l0oookJ_l0odgo033oo`3o
/Ol0oe_ooo]Zoc7o0006oookJP03ob3o0?lV0?oof_l000;ooo]Z00Goo`0Cool0Tooonf[oolX0o`3o
6`02oookJP05ogSo0?l0g?oo?ol0oomB0?nio`001?oonfX00ol0Looooo]ZoookJP02oookJP0Kool0
j_oonf[ooo]ZoonB0?oonf[oo`3lool60?o[o`3oZ03oool0nOl0Mooo>ol0o`3koooonf[oo`3Mok?o
0?oonf[oo`1/oookJ_mQ0?oooo]Zon80ool0oi;ooo]ZofP0oolH0?oooi0000;ooo]Z00Kookh0on/0
ooooE`3o0000ool0;Ol00002oon100;ooo]Z0_l0e?l01?l0ZOoo08Soo`28ool0obh5o`3oCPWooo]Z
0ol0oc@01?l0odko0?l^o`28ool0R?l2o`2Yo`03o`3Doooonf[ooo]Z00;ooo]Z00Gooh40oookJ_oo
nf[ooo]Zool0;@02oookJP06oomG0?oonf[ooo]ZoookJ_o[0?oookh01?oonfX00oooT03ooo]ZoaP0
o`02oookJP0CofP0oooonf[ooo]Zo`3oT_l0oi3ohP3ooookJ_l0odGoH@3oodd0oooo06cooo]Zool0
QooMo`3ooo]Zok?o0?l05oooo`3Mool30002oookJP0Do`3koolko`3ooh40o`3oc?ooK03o07Ooool0
nOoonf[oZ03ooookJ_oo0?Kojol0ool60?oonf[o603ooookJ_oo0?cooo]ZoonB0?oo5P04oookJP03
ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX01ooonfX02Onio`3ooe80oookJ_l0:_oooo]Z
ocoo0?oonf[o0=coogSo0007oookJP04o`3o6ooonf[ooo]Zooo:00;ooo]Z00?oo`2Co`3ioooo01<0
1?oonfX01ooJo`3ooo]ZoookJ_oonf[o9P3oob3o0?n40?l03_oonfX01?lao`3ooo]ZoookJ_l0oe/2
oookJP06o`3o/?n2o`3o0?nao`0`ool0j?oo0?m=0_oonfX01?l60?oooo]ZoookJ_nBo`02oookJP03
oa00ool06Ooooo]Z00?ooo]Z00Ko5@3oool0DOoonf[o0:gooookJ_oo07TVoookJP00:_oonfX02OnX
0?oooo]ZoookJ_oonf[oo`3ioookJ_l0Mooooo]Zoom/0002onGo0003oookJ_oUo`3o>ol000Cooo]Z
00GoU?l0oookJ_nDo`3oU?l0ool30003oookJP04ool0gOoonf[o/ol0oil0o`Gooo]Z00?o0?oNool0
QooonfX00_oonfX01ooo06cooo]ZoookJ_m=0?ooiOl0oookJ_mQ0?l00ooonfX01OoR0?oooo]Zo`3o
T?oonf[o0?nB00Kooo]Z00?oJ03ooookJ_oonfX00ooonfX01OlH0?oo07CooookJ_oonf[ooi0000Wo
oo]Z00?ookh0oookJ_o[0?l01OoonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00?o
oo]Z00?ooh40oookJ_oonfX01OoonfX01?l0e?oo00CooookJ_l0ZOl3oookJP03o`3oC_l0ocCooo]Z
00Cooo]Z00CoiOl0o`3o2?oonf[o0?mC0_oonfX01?oo07Wo0:gooookJ_oo0542oookJP05oa00oooo
nf[oT_l0ooo90?l0odd00_oob@000ooUo`3o<Ol0oookJP06oookJP09obH0oooJo`3oiOl0onGo0?oo
01?oo`2Cooo:0?oonf[o0?lK00;ooo]Z00GoN?l0ocd0oooonf[o02[ooomB0004oookJP03o`1coooo
nf[ooo]Z00?ooo]Z00coo`3ZoookJ_ooTP3oo`3loookJ_oo1P3ojol0o`2VoonX0?oo07Oooon10?lk
o`02oolX0004ok?o0?oo003oo`00ool0K0?oo`0000?o0?nBofP0oooonfX02_oo000:ooo900Soo`00
2?oo:0001_oo003oobP0oolX0?l0odko0?l^oookJP?oU?l000Oo0=CooiCo0?nDo`3oU?l0oookJ_oo
P@3ooo]Z00?oolT00_oonfX01_ooE`3ooo]ZoookJ_o[0?oooo]Zoonn00?ooo]Z0_ooN@001?lH0?oo
oo]ZoookJ_mX0?l2oookJP0:o`3oT_l0oi3ohP3ooomi0?mQ0?ooogT0odd0oooo06coogT0ool0Q`;o
oo]Z00Go/ol0ool0gOmi0?ooo`<0oookJP03oomi000<oc_o0?ooN@3o07OooookJ_oo0?WoZ03oooo9
0?oonf[oo`3fon_o0?oo1P3o603o0_oonfX01?oo0?cooo]ZoonB0?oo5P04oookJP03ool0j_oonf[o
oo]Z00[ooo]Z00?o07?ooookJ_oonfX01_oonfX01Onio`3ooe80oiCo0?oonf[o02[o00;ooo]Z00?o
?ol0o`3Loomho`001_oonfX01?lB0?ooiOl0oookJ_oobP03oookJP03ool0TooUo`3oo`0C00Cooo]Z
00Oof_l0oookJ_oonf[ooo]ZobH0oolPo`3oiOl000kooo]Z00?o<Ol0oookJ_l0oe/00_oonfX00onD
o`3o0?n`oh;o0002oiCo0004o`3Xool0odgoU?l0o`H0o`;ooo]Z00KoiOl0oi;o0?oonf[ooo]Zoa00
ool0GOl3oookJP03oaD0oooo057ooo]Z00;ooo]Z00?o0:goool0NOoonfX0BooonfX03onX0?oooo]Z
oookJ_oonf[oo`3ioookJ_l0Mooooo]Zoom/0?oonf[o0?o<oookJ_ooP@3ooo]Zoc_o0003oookJP05
o`3koooonf[ooo]ZoookJ_oo0`000ooonfX01Ooo0=gooo]Zo`2Soonco`3oW`3o00Gooo]Z00Goo`27
oookJ_oonf[ooo]Zool0K003oookJP03odd0oooo;P3oH@3o00Cooo]Z00GohP3oo`3oT?oonf[ooo]Z
o`3oTP06oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603oo`1doooonf[ooo]Zoon@0009oookJP04
oonn0?oonf[oj`3oog00o`Cooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP03oook
JP03oon10?oonf[ooo]Z00Gooo]Z00Go0=Coo`04oooonf[o0:Woo`28o`03oookJP03o`3oC_oonf[o
oo]Z00Cooo]Z00?o0?lMo`3o2?l0oe<00ooonfX03_oo07Wo0:goool0DOlE0?oooo]Zoa00oooonf[o
T_l0o`H0ool0odgooo]Zoh;o0?l0oe_o<Ol01ooonfX00olV0?oof_l0on7o0002oookJP04ool0Tooo
nf[oolX0o`3o6`;ooo]Z00KoN?l0ocd0ooloo`3o02[ooomB0?nio`03oookJP03o`1coooonf[ooo]Z
00?ooo]Z01[oo`3ZoookJ_oo5P3ooi80ool0o?oo1P3o603oon_o0?nX0?oo07Oooon10?lko`3o0?_o
ool0gOnco`3ooo]Zool0Qooo06coH@3oo`3oAOoR0?oo0?n@oookJ_mX0?oo603oonKo00;ooo]Z00Wo
okh0on/0ooooE`3ooo]Zool0;Ol0003ooh40o`000?oonfX00_l0e?l00ol0ZOoo08Soo`3o;P03o`3o
CP?ooo]Z1_l0oad00ol0o`Sooo]ZoookJP05oookJP04o`3o=?l0odko0?m>o`3o;P;o08So00?o0:Wo
o`3DoooonfX00ooonfX01OooP@3ooo]ZoookJ_oonf[oo`0]00;ooo]Z00KooeL0oookJ_oonf[oL03o
on/0oooo_P03oookJP03oon@0?oonf[o603o00;ooo]Z01?oJ03ooookJ_oonf[o0?nBoookJ_oR0?oo
oo]Zo`3oAOmQ0?ooC@3oool0K?oonf[oo`27omgo0?oonf[o/ol0oil0oooo0=goo`<000;ooo]Z01Go
0?_ooookJ_lko`3ooh40oom/0?l0Moooo`3ioookJ_nX0?oo0:Koool0m_o[o`3oo`H0oookJ_lH0?oo
oo]Zool0o?oonf[ooi80oookJ_oo5P000ooonfX00ooo0>[ooo]ZoookJP0:oookJP03o`1coooonf[o
oo]Z00Oooo]Z00Co^Ol0oomB0?oonf[o02[o0_oonfX00oloo`3o0=coogSo0007oookJP04o`3o6ooo
nf[ooo]Zooo:00?ooo]Z00?oo`2Cool04ooonfX00ooonfX01ooQo`3of_l0oookJ_oonf[o9P3ooook
J_lPo`003_oonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP06o`3o/?n2o`3o0?nao`0`ool0j?oo0?m=
0_oonfX01?l60?oooo]ZoookJ_nBo`02oookJP03oa00ool06Ooooo]Z00?ooo]Z00Ko5@3oool0DOoo
nf[ooo]Zo`2]oooo07TVoookJP00;_oonfX01Ooo0?Wooo]Zo`1goooonf[oof`000CoiOl000?o>ol0
oookJ_oonfX00_oonfX01OnDo`3ooo]ZoookJ_oonf[oo`<000?ooo]Z00Coo`3MoookJ_nco`3oW`3o
1OoonfX00ol0omkoo`27oookJP02oookJP07ool0K?oonf[ooo]Zodd0oooUo`3ooo]Zof40o`03oook
JP05on80ool0oi3ooo]ZoookJ_l0oi801_oonfX00omX0?oooo]ZoookJP03oookJP05oaP0oooonf[o
oo]ZoookJ_ooT0002?oonfX01?oo_P3ooo]Zo`3o1Oo[0?l4oookJP03oomG0?oonf[ooo]Z00?ooo]Z
00?oo`0]oookJ_oonfX01?oonfX00oooP@3ooo]ZoookJP04oookJP05o`3Dool01?oooo]ZoookJ_l0
ZOl00ooonfX00ol0odko0?ldoookJP04oookJP04onGo0?l0o`Sooo]Zo`3oD`;ooo]Z00coo`1io`2]
oooo057o5@3ooookJ_l@0?oo05gooi;o0?oob@3o0>Soo`3oCOoob@02onGo0003oc7o0?oonf[ooo]Z
00Cooo]Z017o9P3ooookJ_oJo`3ohOl0ool04ooo09?ooo]Zooo:0?lB0?oo0?lKoookJ_oob@3oN?l0
ocoo0?l0:_oo0?lcoomB0004oookJP03o`1coooonf[ooo]Z00;ooo]Z00coo`3ZoookJ_oo5P3ooi80
ool0o?oonf[oo`H0ool0m_nX0?ooo`3io`1goolko`02oolX0004ok?o0?oo003oo`00ool0K0Coo`00
00?oobP0ool00?oo00001_oo000=ooo900[oo`001Ooo:002ool000?oobP000Gooo]Zo`3oC_l0odko
oo]ZoiCo0002oolX0005o`3DoonDo`3oU?l0oookJ_ooP@000ooonfX2ooo90007oookJ_ooE`3ooo]Z
oookJ_o[0?ooL03ooonn0004oookJP05oomi0?oVo`3o603ooookJ_mX0?l00_oonfX04_l0oi;ooo]Z
o`3oT?oR0?ooogT0of40oom=0?ooo`1/oomi0?oo08Oo0?oNoookJ_nO0?oo/ol0ool0gOoo0`3ooo]Z
ooo900;oogT000co>ol0oomi0?ooN@3o07Ooool0nOnX0?oooo]Zooo90?oo0?Kojol0ool60?lH0?l2
oookJP04ool0o?oonf[ooi80oolF00Cooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ol0Looooo]Zoook
JP06oookJP05okWo0?ooDP3oU?l0oookJ_l0:_l00_oonfX00oloo`3o0=coogSo0007oookJP03onGo
0?oonf[oolX000?ooo]Z00?oo`2ConGo0?oo01<01?oonfX00ooJo`3ohOl0oookJP02oookJP03obH0
oooUo`3ooo]Z00gooo]Z00?o<Ol0oookJ_l0oe/00ooonfX02?l0ok3oP_l0oiCo0?nDo`3o0>Soo`3o
COoonf[o1P3o0_oonfX01_oUo`3oT_l0oookJ_oonf[o403oo`1Mo`?ooo]Z00?o5@3oool0DOoonfX0
0_oonfX00ol0[Oooo`1ioookJP1?oookJP0:ool0nOoonf[o07OooookJ_ooK03ooo]Zo`3oc?oonf[o
oh40oc_o00Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30003oookJP05ool0gOoonf[o0:?ook?o0?nO
0?l01OoonfX01Ooo08Oooo]ZoookJ_oonf[oo`1/00?ooo]Z00?oC@3ooookJ_mQ0?l01?oonfX01OoR
0?oooo]ZoookJ_oonf[o0?nB00Gooo]Z00?oJ03ooookJ_oonfX00ooonfX01OlH0?oo07CooookJ_oo
nf[ooi0000Wooo]Z00?ookh0oookJ_o[0?l01?oonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooo
nf[ooo]Z00Cooo]Z00?ooh40oookJ_oonfX01?oonfX01_l0e?oooo]Zo`04oooonf[o0:Woo`28o`?o
oo]Z00?o0?m>oookJ_oonfX00ooonfX01?l0hOoo0?lMo`3o2?l0oe<3oookJP0>ool0NOl0[Oooo`1A
oaD0ool@0?oo05gooi;o0?oonf[o0>Soo`3oCOl0ok7oP_l0o`3oFolao`06oookJP0:oh@0oolV0?oo
f_l0on7o0?oonf[oo`0Cool0Tooonf[oolX0o`3o6`;ooo]Z00GoN?l0ocd0ooloo`3o02[ooomB0004
oookJP03o`1coooonf[ooo]Z00?ooo]Z01Woo`3ZoookJ_ooTP3ooo]Zool0o?oo1P3ojol0ojP0oooo
0?Wo07Oooc_o0?l0noooo`<0ok?o0?nO0?ooo`27ool0K?mQ0?oo0?m5on80ool0oi3o0?nBofP0oolH
0?ooi_l000;ooo]Z00Sookh0on/0ooooE`3ooo]Zool0;Ol0003ooh40o`0000;o0=Co00?o00Cooook
J_l0obh00_l0odh3oookJP;o0?lM2_l0oe<2o`3o7@;o0>7o0ooonfX01ol0ocCo0?m>o`3o;_oonf[o
0:WooookJ_l0e?l00ooonfX00oooP@3ooo]ZoookJP02oookJP03ool0;Ooonf[ooeL000?ooo]Z00?o
j`3ooonn0?oonfX00ooonfX00oooT03ooo]ZoaP0o`02oookJP0:ofP0oooonf[o0?nBoookJ_l0oi3o
hP3ooookJ_mQ0?ooC@3oool0K0;ooo]Z01goo`27oookJ_oonf[o/ol0ogT0oooo0=goo`<0oookJ_l0
nooooo]Zoc_o0?ooP@3oof`0o`1goooo0?Wooo]ZojP0ool0Y_ooo`3foookJ_oo1P3ooo]ZoaP0oooo
nf[oo`3loookJ_ooTP3ooo]ZoolF0003oookJP03ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oo
nfX01ooonfX01?nio`3ooe80oookJ_l0:_l2oookJP04ocoo0?l0g?oo0?oOogSo00Kooo]Z00Co0?lK
oookJ_oonf[oolX00ooonfX00ooo09?oo`0CoookJP04oookJP06om[o0?oonf[ooo]ZoookJ_lV0?oo
8?l03_oonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP06o`3o/?n2o`3o0?nao`0`ool0j?oo0?m=0_oo
nfX01?l60?oooo]ZoookJ_nBo`02oookJP03oa00ool06Ooooo]Z00?ooo]Z00Ko5@3oool0DOoonf[o
oo]Zo`2]oooo07TVoookJP00;_oonfX01Ooo0?Wo07OooookJ_ooK03o0?nJ00CoiOl000Go>ol0oook
J_oonf[ooo]ZoiCo0004oookJP08ool30?oonf[ooo]ZogT0oooo0=gooo]Zok?o0?nO0?l4oookJP03
o`3og_oonf[oo`2700?ooo]Z00Ooo`1/oookJ_m=0?oooo]ZonGo0?mQ0?oo0?m500?ooo]Z00GohP3o
o`3oT?oonf[ooo]Zo`3oTP06oookJP03ofP0oooonf[ooo]Z00?ooo]Z00Go603ooookJ_oonf[ooo]Z
oon@0008oookJP04oonn0?oonf[o0?l5on/0o`Cooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02go
oo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Cooo]Z00Go0=Coo`04oooonf[ooo]Zo`2Yo`03oook
JP03o`3oC_oonf[ooo]Z00?ooo]Z0_oUo`000ol0o`Sooo]Zo`3oD`02oookJP03ool0NOl0[Oooo`1A
00;ooo]Z00Oo403ooookJ_nBo`3oolT0o`3oCOl0<?ooP_l000;oiOl000?o<Ol0oookJ_oonfX01?oo
nfX02OlV0?oooo]Zom[o0?oonf[oo`0Cool0Tooonf[oolX0o`3o6`02oookJP05ogSo0?lm0?oooo]Z
o`0ZooooDP001?oonfX00ol0Looooo]ZoookJP03oookJP0<ool0j_oonf[ooi80ool0o?oonf[oo`H0
on_o0?l0Y_ooZ03oo`1gooooP@3o>ol00_oo:0000onco`3oo`00ool0K00>ool000coolT03Ooo0002
oolX00?oo`001?oo:0000ooonf[oobP0o`3oCP03oolX0006oiCo0?l0e?ooU?l0oiCo0?oonf[ooh40
0ooonfX01?oob@3ooo]ZoookJ_ooE`02oookJP03on/0oooonf[ookh000Cooo]Z00CoogT0onKo0?lH
0?ooJ03o0ooonfX02_l0oi;o0?n@on80ooooN@3oH@3oodd0ooooN@3oo`1/ool0Qol0omh2oookJP08
ok?o0?oo0=goN@3oool30?oonf[oolT0oomi0?lko`02oomi0009o`1goooonf[oo`3iojP0oooob@3o
oo]Zon_o0?oonf[oo`H000;ooo]Z00Coo`3loookJ_ooTP3ooaH01?oonfX00ooo0>[ooo]ZoookJP0:
oookJP03o`1coooonf[ooo]Z00Kooo]Z00Go^Ol0oomB0?nDo`3ooo]Zo`0Zo`02oookJP04ocoo0?oo
nf[o0?oOogSo00Kooo]Z00?oiOl0oookJ_oobP000ooonfX00ooo09?oiOl0ool04`04oookJP03om[o
0?oQo`3ooo]Z00;ooo]Z00?o9P3oob3o0?oonfX03OoonfX00olao`3ooo]Zo`3oF`03oookJP08o`3o
/?n2o`3oU?l0oiCo0?l0j?oo0?m=oookJ_l60?l2oookJP06onGo0?nBo`3ooo]ZoookJ_l@0?oo05go
0ooonfX00olE0?ooo`1AoookJP02oookJP03o`2]oooo07Wooo]Z04oooo]Z00Koo`3ioookJ_l0Mooo
of`0o`3oV_l0ol`2oookJP03oon10?lko`3ooo]Z00;ooo]Z00?o0?_ooookJ_oonfX00_oonfX02Ooo
0`3ooo]ZoookJ_oonf[oo`3MoookJ_l0Xooo/ol0oil0o`04oookJP03o`3og_oo08Oooo]Z00;ooo]Z
00Ooo`1/oookJ_oonf[oC@3oool^0?mQ0?oo0?m500Cooo]Z00GohP3ooookJ_oonf[ooo]Zo`3oTP05
oookJP03ofP0oooonf[ooo]Z00?ooo]Z00Go603oo`1doooonf[ooo]Zoon@0008oookJP04oonn0?oo
nf[ooo]Zon/0o`Cooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP04oookJP03oon1
0?oonf[ooo]Z00Cooo]Z00Go0=Coo`04oooonf[ooo]Zo`2Yo`03oookJP03o`3oC_l0ocCooo]Z00Co
oo]Z00Co0>7oo`3o7Ol0o`So0?mC0ooonfX03_oo07Wo0:goool0DOoonf[o403ooookJ_nBo`3o1P3o
o`3oCOl0<?oo0?nao`3oFooonf[o<Ol01_oonfX00olV0?oooo]Zom[o0002oookJP04ool0Tol0nOoo
oo]Zo`3o6`?ooo]Z00GoN?l0ocoo0?l0:_oooe80okWo0003oookJP03o`1coooonf[ooo]Z00?ooo]Z
01Woo`3ZoookJ_oo5P3ooi80ool0o?oo1P3ojol0o`2VoonX0?oo07Oooon10?lko`3o0?_oool0gOnc
o`3oo`27ool0K?oonf[oH@3ooookJ_oR0?oo0?nBofP0oolH0?ooi_l000;ooo]Z00cookh0on/0oooo
E`3ooo]Zool0;Ooonf[ooh40o`000?l0e?oo00Coo`2Yool0obh2o`3oCP;ooo]Z0ol0oad4oookJPGo
o`1i0ooonfX3o`3oD`;o0?lM0_l0hOl2oookJP;o0?m>00Cooo]Zo`2Yool0R?oo0=Co0ooonfX00ooo
P@3ooo]ZoookJP02oookJP03ool0;Ooonf[ooeL000;ooo]Z00?oL03oon/0oooo_P001?oonfX01Ooo
T03oi_l0oaP0oooonf[oJ03o00;ooo]Z00[o0?nBo`3oT?oR0?oooo]Zo`3oAOmQ0?ooC@3oool0K?oo
nf[oo`270_oonfX01?nco`3o01Ooool0gOoo0`02oookJP0Do`3koolko`3ooh40oom/0?l0Mooooo]Z
ool0nOnX0?oo0:KooookJ_oo0?Kojol0ool60?lH0?oooo]Zool0o?oonf[ooi80oookJ_oo5P03oook
JP03ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX01ooonfX01?nio`3ooe80oookJ_l0:_l2
oookJP04ocoo0?oonf[o0?oOogSo00Kooo]Z00Co0?lKoookJ_oonf[oolX00ooonfX00ooo09?oo`0C
oookJP04oookJP06om[o0?oonf[ooo]ZoookJ_lV0?oo8?l03_oonfX01?lao`3ooo]ZoookJ_l0oe/2
oookJP06o`3o/?n2o`3ooo]Zo`0`ool0j?oo0?m=0_oonfX01?l60?oooo]ZoookJ_nBo`02oookJP03
oa00ool06Ooooo]Z00?ooo]Z00Ko5@3oool0DOoonf[ooo]Zo`2]oooo07TVoookJP00;OoonfX01_oo
0?Wooo]Zo`1goooonf[oA?l0o`3oVP?oiOl000?ooo]Zoc_o0?oonfX00_oonfX00onDo`3ooo]Zoook
JP02oookJP08ool30?oonf[ooo]ZogT0oooo0=go0:?ook?o0?nO0?l4oookJP03o`3og_oMo`3oo`27
00;ooo]Z00Ooo`1/oookJ_oonf[oC@3ooookJ_oUo`3oH@3o00?ooo]Z00GohP3ooookJ_l0oi3ooo]Z
o`3oTP07oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603oo`1doooonfX00_oonfX00oooT03ooo]Z
oookJP06oookJP04oonn0?oonf[o0?l5on/0o`Cooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02go
oo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Cooo]Z00Co0=Coo`04oooonf[o0:Wo0ooonfX00ol0
obko0?m>oookJP04oookJP;oiOl000Sooo]Zo`3oDooonf[ooo]Zool0NOl0[Ooooo]Zool0D@;ooo]Z
00Ko403ooookJ_nBo`3oolT0o`3oCOn2o`02onGo0003oc7o0?oonf[ooo]Z00Cooo]Z017o9P3ooh@0
oooJo`3ohOl0ool04ol0nOooo`2Cooo:0?l0S_oo0?lKoookJ_oob@3oN?l0ocoo0?l0:_oooo]ZoomB
0004oookJP03o`1coooonf[ooo]Z00;ooo]Z00coo`3ZoookJ_oo5P3ooi80ool0o?lH0?ooo`H0o`2V
oonX0?oo07Oooom/0?lko`02oolX0004ok?o0?oo003oo`00ool0K0ooo`002Ooob@02ool000;oogT0
4Ooo0006oolX0003o`3oC_oo:03oobP000;oU?l000Go0=CooiCo0?oonf[ooo]Zoon10003oookJP08
ooo90?oonf[ooo]ZoomG0?oonf[oj`3oo`3o1Ooo_P04oookJP05oon@0?oVo`3o603ooookJ_mX0?l0
0_oonfX02_l0oi;o0?n@on80ooooN@3oH@3ooomi0?m=0?ooo`1/oomi0?oo08L2oookJP04ok?o0?oo
0=goN@3oool300;ooo]Z013oogT0oc_o0?ooN@3oogT0o`1goooonf[oo`3iojP0oooob@3ooo]Zon_o
0?oonf[oo`H0oaP0oooonf[oo`3l0_oonfX00oooTP3ooo]ZoookJP03oookJP03ool0j_oonf[ooo]Z
00Wooo]Z00?o07?ooookJ_oonfX01_oonfX01Onio`3ooe80oiCo0?oonf[o02[o00;ooo]Z00Co?ol0
oookJ_lm0?ooN?l01_oonfX00ooUo`3ooo]Zooo:0004oookJP03ool0Tooo01?ooo]Z00?ooo]Z00?o
f_l0on7o0?oonfX00_oonfX00olV0?oo8?l0oookJP0=oookJP03oc7o0?oonf[o0?mK00?ooo]Z00So
0?n`oh;o0?nDo`3oU?l0o`3Xool0odgooo]Zo`H0o`;ooo]Z00KoiOl0oi;o0?oonf[ooo]Zoa00ool0
GOl3oookJP03oaD0oooo057ooo]Z00;ooo]Z00?o0:goool0NOoonfX0CooonfX02_oo0?Wooo]Zo`1g
ooooK03o0?nJo`3oc?oonf[ooh40oookJ_lko`03oookJP03o`3koooonf[ooo]Z00;ooo]Z00Woo`<0
oookJ_oonf[ooo]Zool0gOoonf[o0:?ook?o0?nO0?l01?oonfX00ol0omkoo`27oookJP02oookJP06
ool0K?oonf[ooo]Zodd0oooo;P3oH@3o1?oonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Kooo]Z00?o
J03ooookJ_oonfX00_oonfX00olH0?oo07CooookJP02oookJP03oon@0?oonf[ooo]Z00Kooo]Z00Co
okh0oookJ_l0o`Goj`3o1?oonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Cooo]Z
00?ooh40oookJ_oonfX01?oonfX01Ol0e?oo00CooookJ_l0ZOoo08So00?ooo]Z00?o0?m>oookJ_oo
nfX01?oonfX00ol0oago0?l8o`3oD`03oookJP0?ool0NOl0[Ooooo]Zool0DOoonf[o403ooookJ_nB
o`3o1P3oo`3oCOoonf[oP_l0o`3oFooonf[o<Ol000Kooo]Z00Wo9P3oom[o0?oQo`3ooo]Zool04ooo
09?ooo]Zooo:0?l0oa/00_oonfX01_mho`3o?@3oocoo0?l0:_oooe80okWo00?ooo]Z00?o07?ooook
J_oonfX00ooonfX06?oo0>[ooo]ZoonB0?oonf[oo`3lool60?o[o`3oZ03oo`1gooooK03o>ol0o`3k
oooo0`3o/ol0o`3og_oMo`3oo`1/of40oooonf[ohP3oo`3oT_mX0?oo603oonKo00;ooo]Z00_ookh0
on/0oooonf[ooeL0ool0;Ooonf[ooh40o`000?l0e?oo00Coo`28o`02o`3oCP;ooo]Z0_l0oad4oook
JP?oo`1i1?oonfX3ool0D@;oo`1i0_oonfX2o`3oD`;o0?lM00Wo0>7ooookJ_oonf[o0?ldo`3oC_oo
nf[o0:Woo`04ool0e?l00ooonfX00oooP@3ooo]ZoookJP02oookJP07ool0;Ooonf[ooeL0oookJ_m`
0?ooj`3ooonn0004oookJP05oon@0?l0M?oo603ooookJ_mX0?l00_oonfX04?l0oi;ooo]Zon80oooo
nf[o0?m5of40oom=0?ooo`1/oookJ_l0omkoo`27oookJ_nco`3o01Ooool0gOoo0`02oookJP0@o`3k
oolko`3ooo]Zoon10?oonf[o07Ooool0nOnX0?oo0:KooookJ_oo0?Kojol0ool60?lH0?oooo]Zool0
o0;ooo]Z00?ooi80oolF0?oonfX00ooonfX00ooo0>[ooo]ZoookJP09oookJP03o`1coooonf[ooo]Z
00Oooo]Z00Co^Ol0oomB0?oonf[o02[o0_oonfX01?loo`3ooo]Zocd0oomho`06oookJP04o`3o6ooo
nf[ooo]Zooo:00?ooo]Z00?oo`2Cool04ooonfX01?oonfX01_oJo`3ooo]ZoookJ_oonf[o9P3oob3o
00kooo]Z00Co<Ol0oookJ_oonf[o0?mK0_oonfX01_l0ok3oP_l0oookJ_l0<?oooo]Zo`3oC@;ooo]Z
00Co1P3ooookJ_oonf[oT_l00_oonfX00ol@0?oo01WooookJP03oookJP06oaD0oooo057ooo]Zoook
J_l0[Oooo`1i9_oonfX002gooo]Z00Koo`3ioookJ_l0Mooooo]ZodCo0?l0oiX3onGo0003oc_o0?oo
nf[ooo]Z00;ooo]Z00?oU?l0oookJ_oonfX00_oonfX01ooo0`3ooo]ZoookJ_mi0?ooo`3Mo`2Soonc
o`001OoonfX00ol0omkoo`27oookJP02oookJP07ool0K?oonf[ooo]Zodd0oooUo`3ooo]Zof40o`03
oookJP05on80oooonf[o0?n@oookJ_l0oi801ooonfX00omX0?oooo]ZoookJP02oookJP05oaP0ool0
M?oooo]ZoookJ_ooT0002OoonfX00ooo_P3ooo]Zon/0o`05oookJP03oomG0?oonf[ooo]Z00;ooo]Z
00?oo`0]oookJ_oonfX01?oonfX00oooP@3ooo]ZoookJP05oookJP04o`3Doooonf[ooo]Zo`2Yo`?o
oo]Z00?o0?m>o`3o=?oonfX00ooonfX3onGo000@oookJ_l0oe?ooo]ZoookJ_oo07Wo0:goool0DOlE
0?oooo]Zoa00ool06OooT_l0ooo90?oonf[o0?m=oh;o00;oiOl000?o<Ol0oookJ_oonfX01?oonfX0
2OlV0?oooo]Zom[o0?oQo`3oo`0Cool0Tooonf[oolX0o`3o6`02oookJP05ooo90?mho`3o?ol0o`0Z
ooooDP001?oonfX00ol0Looooo]ZoookJP03oookJP0;ool0j_oonf[ooi80ool0o?oonf[oo`H0ool0
m_l0Y_ooo`3io`1goolko`000ooo:0000onco`3oo`00ool0K00@ool000SoolT00ooo0003oomi013o
o`001ooo:0001Ol0odkoobP0oolX0?nDo`3o0=Co00;oU?l000?ooo]Zoon10?oonfX00_oonfX02Ooo
02gooo]ZoookJ_oonf[ooeL0on/0oom`0?oooo]Zoonn0003oookJP05oon@0?oVo`3o603ooookJ_mX
0?l00_oonfX02_l0oi;ooo]Zo`3oT?oR0?ooogT0of40oom=0?ooo`1/oomi0?oo08L2oookJP04ok?o
0?l0Xoooo`3Mool300;ooo]Z00So0?_ooomi0?lko`3oogT0oookJ_l0Moooo`3iojP0o`;oolT000Co
jol0ooo90?oo1P3o603o0_oonfX00ooo0?cooo]ZoonB0005oookJP03ool0j_oonf[ooo]Z00Wooo]Z
00?o07?ooookJ_oonfX01_oonfX01Onio`3ooo]ZoomB0?oonf[o02[o00;ooo]Z00Co?ol0oookJ_lm
0?ooN?l01_oonfX00ooUo`3ooo]Zooo:0004oookJP03ool0Tooo01?ooo]Z00?ooo]Z00?of_l0on7o
0?oonfX00_oonfX00olV0?oo8?l0oookJP0=oookJP03oc7o0?oonf[o0?mK00?ooo]Z00So0?n`oh;o
0?nDo`3oU?l0o`3Xool0odgooo]Zo`H0o`;ooo]Z00KoiOl0oi;o0?oonf[ooo]Zoa00ool0GOl3oook
JP03oaD0oooo057ooo]Z00;ooo]Z00?o0:goool0NOoonfX0CooonfX02_oo0?Wooo]Zo`1gooooK03o
0?nJo`3oc?oonf[ooh40oookJ_lko`03oookJP03o`3koooonf[ooo]Z00;ooo]Z00Soo`<0oookJ_oo
nf[ooo]Zool0gOl0Xooo/ol0oil0o`Gooo]Z00?o0?oNool0QooonfX00_oonfX01_oo06cooo]Zoook
J_m=0?ooobh0of40o`Cooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP03ofP0oooonf[ooo]Z
00;ooo]Z00Go603oo`1doooonf[ooo]Zoon@0009oookJP03oonn0?oonf[oj`3o00Gooo]Z00?ooeL0
oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Gooo]Z00Go0=Co
o`04oooonf[o0:Woo`28o`03oookJP03o`3oC_oonf[ooo]Z00Cooo]Z00?o0?lMo`3o2?l0oe<00ooo
nfX03_oo07Wo0:goool0DOlE0?oo403oo`0IoonBo`3ooo]Zo`H0ool0odgo0?naoh;o0?l0oe_o<Ol0
1_oonfX02_lPo`3o9P3oom[o0?oQo`3ooo]Zool04ooo09?ooo]Zooo:0?l0oa/2oookJP05ogSo0?l0
g?oooo]ZoomB0?nio`000ooonfX00ol0Looooo]ZoookJP03oookJP0Hool0j_oonf[ooi80oookJ_oo
0?coo`H0on_o0?l0Y_ooo`3io`1goolko`3o0?_oool30?oo0=go/ol0o`3og_oo06coH@3ooookJ_oR
0?oo0?nBofP0oooonf[o603o0_oonfX03?l0o`Gookh0oookJ_ooE`3oo`0]oookJ_ooP@3ooo]Zo`3D
ool01?oo08Soo`3oCP;ooo]Z0_l0oad3oookJP?oo`1i00?ooo]Zoa00ool@0?l00ol@0?l4oookJP?o
o`1A00Koo`1ioookJ_oonf[o0?mCo`3o2?l0oad3oookJP05o`3o;_l0odkooo]Zo`2Yool0e?l01?oo
nfX01OooP@3ooo]ZoookJ_oonf[oo`0]00;ooo]Z00GooeL0oookJ_o[0?oo0?l5oonn0003oookJP03
oon@0?oonf[o603o00;ooo]Z02;oJ03ooookJ_l0oi;ooo]Zo`3oT?oR0?oooo]Zof40oom=0?ooo`1/
oookJ_l0omkoo`27oookJ_nco`3o0:?oogT0oooo0=goo`<0oookJ_l0nooooo]Zoc_o0?ooP@3oof`0
o`1goooo0?WoZ03oo`2Voooonf[oo`3fon_o0?oo1P3o603o0_oonfX01?oo0?cooo]ZoonB0?oo5P04
oookJP03ool0j_oonf[ooo]Z00Wooo]Z00?o07?ooookJ_oonfX01ooonfX01?nio`3ooe80oookJ_l0
:_l2oookJP04ocoo0?oonf[o?@3oogSo00Kooo]Z00Co0?lKoa80oooonf[oolX00ooonfX00ooo09?o
o`0CoookJP04oookJP06om[o0?oonf[ooo]ZoookJ_lV0?oo8?l03_oonfX01?lao`3ooo]ZoookJ_l0
oe/2oookJP06o`3o/?n2o`3ooo]Zo`0`oooonf[o0?m=0_oonfX01?l60?oooo]ZoookJ_nBo`02oook
JP03oa00ool06Ooooo]Z00?ooo]Z00Koo`1AoookJ_oonf[ooo]Zo`2]oooo07TVoookJP00;OoonfX0
0ooo0?Wooo]Zo`1go`02odCo0005o`3oV_oUo`3oiOl0onGo0?lko`001?oonfX01OnDo`3ooo]Zoook
J_oonf[oo`<000?ooo]Z00Coo`3MoookJ_nco`3oW`3o1OoonfX00ol0omkoo`27oookJP02oookJP07
ool0K?oonf[ooo]Zodd0oooUo`3ooo]Zof40o`03oookJP05on80oooonf[o0?n@oookJ_l0oi801ooo
nfX00omX0?oooo]ZoookJP02oookJP05oaP0ool0M?oooo]ZoookJ_ooT0002?oonfX01?oo_P3ooo]Z
o`3o1Oo[0?l5oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3o
oo]ZoookJP05oookJP04o`3Doooonf[ooo]Zo`2Yo`?ooo]Z00?o0?m>o`3o=?oonfX00ooonfX3onGo
000?oookJ_l0oe?ooo]ZoookJ_oo07Wo0:goool0DOlE0?oooo]Zoa00oooonf[oT_l0ooo90?l0odgo
033o00?oiOl000?o<Ol0oookJ_oonfX00ooonfX04OlV0?ooiOl0oookJ_oJo`3ooo]Zool04ooo09?o
olX0o`2>ool0oa_ooo]Zooo90?mho`3o0=coo`0Zoooonf[ooe8000Cooo]Z00?o07?ooookJ_oonfX0
0_oonfX03?oo0>[ooo]ZoolF0?ooTP3oo`3loaP0oooo1P3o0:KoojP0ool0MoooobP0oc_o00;oobP0
00?o/ol0ool00?oo06`01Ooo00000omX0?ooo`00ool00009ool00003oomi0?oob@3oolT000CoolT0
2_ooN@07oi;o00Ooo`001ooo:0001_l0odkoobP0o`28oonDo`3o0=CooiCo00;ooo]Z00Gooh40oook
J_oonf[ooo]Zool0;@02oookJP05oomG0?oonf[oj`3oo`3o1Ooo_P001?oonfX01?ooT03oi_l0oaP0
oomX0?l3oookJP0?o`3oT_l0oi3ohP3ooomi0?mQ0?ooC@3ooomi0?oo06coo`27o`3og_oonf[oW`3o
ok?o0?oo0=goo`<000;ooo]Z00So0?_ooomi0?lko`3oogT0ooo90?l0MoooolT0ool0n@;oolT000Co
jol0ooo90?oob@3oo`H00_oonfX00ooo0?cooo]ZoonB0005oookJP03ool0j_oonf[ooo]Z00Wooo]Z
00?o07?ooookJ_oonfX01_oonfX01Onio`3ooo]ZoomB0?oonf[o02[o00;ooo]Z00Co?ol0oookJ_l0
oegoN?l01_oonfX00ooUo`3ooo]Zooo:0004oookJP03ool0Tooo01?ooo]Z00?ooo]Z00?of_l0on7o
0?oonfX00_oonfX00olV0?oo8?l0oookJP0=oookJP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00So0?n`
oh;o0?nDo`3oU?l0o`3Xool0odgooo]Zo`H0o`;ooo]Z00KoiOl0oi;o0?oonf[ooo]Zoa00ool0GOl3
oookJP03oaD0oooo057ooo]Z00;ooo]Z00?o0:goool0NOoonfX0C_oonfX02ooo0?Wooo]Zo`1goooo
nf[oof`0o`3oV_l0olcooo]Zoon10?oonf[o>ol000?ooo]Z00Go0?_ooookJ_oonf[ooo]Zool30003
oookJP05ogT0oooo0=go0:?ook?o0?nO0?l01OoonfX01Ooo08Oooo]ZoookJ_oonf[oo`1/00?ooo]Z
00?oC@3oool^0?mQ0?l01?oonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Kooo]Z00?oJ03ooookJ_oo
nfX00_oonfX01OlH0?oo07CooookJ_oonf[ooi0000Sooo]Z00Cookh0oookJ_oonf[oj`3o1OoonfX0
0oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Cooo]Z00?ooh40oookJ_oonfX01OoonfX0
1Ol0e?oooo]ZoookJ_l0ZOoo08So00?ooo]Z00?o0?m>oookJ_oonfX00ooonfX01?l0hOoo0?lMo`3o
2?l0oe<3oookJP0>ool0NOl0[Oooo`1AoaD0ool@0?oooo]Zoi;o0?l60?oo0?m=o`0`ool0ok7oP_l0
o`3oFolao`06oookJP03obH0oooonf[of_l000;ooo]Z00Coo`2Co`3ioooobP3o0?lK0_oonfX01_l0
omooN?l0ocoo0?l0:_oooe80okWo00?ooo]Z00?o07?ooookJ_oonfX00ooonfX08ooo0>[ooaH0oonB
0?oo0?co603oool60?o[o`3oZ03oo`1gooooP@3o>ol0o`3koooo0`3o/ol0o`3og_oo06coobh0of40
oooR0?oo0?n@oookJ_mX0?oo603ooon@0?oonf[o0?l5oonn0?oonf[ooeL0ool0;Ooonf[ooh40oook
J_l0e?oo00Co00;o0?m>00?o0000o`3o7Ol0oad00_oonfX3ool0N@03oookJ_l@0?oo403o00WoT_l0
0_l@0?l2oookJP;oo`1A00Goo`1ioookJ_l0oe?o0?mCo`3o7@03oookJP05o`3o;_l0odkooo]Zo`2Y
ool0e?l00ooonfX00oooP@3ooo]ZoookJP02oookJP07ool0;Ooonf[ooeL0oookJ_m`0?ooj`3ooonn
0004oookJP05oon@0?oVo`3o603ooookJ_mX0?l00_oonfX02_l0oi;ooo]Zon80oooonf[o0?m5of40
oom=0?ooo`1/oookJ_oo08L2oookJP0Iok?o0?mi0?ooo`3Mool30?oonf[o0?_ooookJ_lko`3ooh40
oom/0?l0Mooooo]Zool0nOnX0?oooo]Zool0m_o[o`3ooo]Zool60?lH0?oooo]Zool0o?oonf[ooi80
oolF0004oookJP03ool0j_oonf[ooo]Z00Wooo]Z00?o07?ooookJ_oonfX01ooonfX01?nio`3ooe80
oookJ_l0:_l2oookJP04ocoo0?oonf[o0=coogSo00Kooo]Z00Co0?lKoa80oooonf[oolX00ooonfX0
0ooo09?oo`0CoookJP04oookJP06om[o0?oonf[ooo]ZoookJ_lV0?oo8?l03_oonfX01?lao`3ooo]Z
oookJ_l0oe/2oookJP06o`3o/?n2o`3ooo]Zo`0`oooonf[o0?m=0_oonfX01?l60?oooo]Zool0mOnB
o`02oookJP03oa00ool06Ooooo]Z00?ooo]Z00Koo`1AoookJ_oonf[ooo]Zo`2]oooo07TVoookJP00
;OoonfX00ooo0?Wo07OooookJP02odCo0005o`3oV_oUo`3oiOl0onGo0?lko`001?oonfX01OnDo`3o
oo]ZoookJ_oonf[oo`<000?ooo]Z00Coo`3MoookJ_nco`3oW`3o1?oonfX00ol0omkooo]Zool0Q`03
oookJP07ool0K?oonf[ooo]Zodd0oooUo`3ooo]Zof40o`03oookJP05on80oooonf[o0?n@oookJ_l0
oi801_oonfX00omX0?oooo]ZoookJP03oookJP05oaP0oooonf[ooo]ZoookJ_ooT0002?oonfX01?oo
_P3ooo]Zo`3o1Oo[0?l5oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01?oonfX0
0oooP@3ooo]ZoookJP04oookJP05o`3Dool01?oooo]ZoookJ_l0ZOl00ooonfX00ol0odko0?ldoook
JP03oookJP?oiOl000Oo0?mCoookJ_oonf[ooo]Zool0NOoonf[oo`1A00;ooo]Z00Ko403ooookJ_nB
o`3oolT0o`3oCOn2o`02onGo0003oc7o0?oUo`3ooo]Z00Cooo]Z013o9P3ooh@0oooJo`3ohOl0ool0
4ol0nOooo`2Cooo:0?lB0?oo0?lKoookJ_l0omooN?l0ocoo0?l0:_oooe801OoonfX00ol0Looooo]Z
oookJP02oookJP0;ool0j_oonf[oogT0oookJ_oo0?coo`H0ool0m_l0Y_ooo`3io`1goolko`000_oo
:0001?oo003o/ol0ool00?oo06`5ool00003oaP0oooo:03oo`0000Soo`0000?o0=Cooomi0?oob@00
0ooob@0<oomi00GoobP00_oo0003oi;o00Coo`000ooo:0000ol0oagoobP0oolX0002oolX0008o`3o
C_oonf[o08SooiCo0?l0e?ooU?l0oookJ_ooP@03oookJP08ool0;Ooonf[ooo]ZoookJ_ooE`3oj`3o
og00oooo_P04oookJP05oon@0?oVo`3o603ooookJ_mX0?l00_oonfX02_l0oi;o0?n@on80ooooN@3o
0?m5of40ooooN@3oo`1/ool0Qol0omh2oookJP03ok?o0?oo0=goN@3o00;ooo]Z00Ko0?_ooookJ_lk
o`3oogT0ooo90?l0Mol2ooo90003ojP0oooob@3ojol000;oolT000Koo`H0oookJ_oonf[oo`3loook
J_ooTP05oookJP03ool0j_oonf[ooo]Z00Wooo]Z00?o07?ooookJ_oonfX01_oonfX01Onio`3ooo]Z
oomB0?oonf[o02[o00;ooo]Z00Co?ol0oookJ_l0oegoN?l01_oonfX00ooUo`3ooo]Zooo:0004oook
JP03ool0Tooo01?ooo]Z00?ooo]Z00?of_l0on7o0?oonfX00_oonfX00olV0?oo8?l0oookJP0=oook
JP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00So0?n`oh;o0?nDo`3oU?l0o`3Xool0odgooo]Zo`H0o`;o
oo]Z00KoiOl0oi;o0?oonf[ooo]Zo`0Iool@0?l3oookJP03oaD0oooo057ooo]Z00;ooo]Z00?o0:go
ool0NOoonfX0C_oonfX02_oo0?Wooo]Zo`1goooonf[oof`0o`3oV_l0olcooo]Zoon10?lko`04oook
JP05o`3koooonf[ooo]ZoookJ_oo0`000ooonfX01Omi0?ooo`3Mo`2Soonco`3oW`3o00Cooo]Z00?o
0?oNool0QooonfX00_oonfX01ooo06cooo]ZoookJ_oonf[oC@3ooookJ_mQ0?l01?oonfX01OoR0?oo
0?n@oookJ_oonf[o0?nB00Kooo]Z00?oJ03ooookJ_oonfX00_oonfX01OlH0?oo07CooookJ_oonf[o
oi0000Sooo]Z00Cookh0oookJ_oonf[oj`3o1OoonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooo
nf[ooo]Z00Cooo]Z00?ooh40oookJ_oonfX01?oonfX01_l0e?oo00CooookJ_oonf[o0:Woo`28o`;o
oo]Z00?o0?m>o`3o=?oonfX01?oonfX00ol0hOoo0?lMo`3oD`04oookJP0>ool0NOoonf[oo`1Aoook
J_l@0?oooo]Zoi;o0?l60?oo0?m=o`0`oon2o`3o0?mKoookJ_lao`05oookJP0:ob3o0?lV0?oof_l0
on7o0?oonf[oo`0Cool0Tooonf[oolX0o`3o6`;ooo]Z00GoN?l0ocd0ooloo`3ooe80okWo0004oook
JP03o`1coooonf[ooo]Z00;ooo]Z01Soo`3ZoookJ_ooTP3ooo]Zool0o?lH0?ooo`H0o`2Voooo0?Wo
07Oooc_o0?l0noooo`<0ool0gOnco`3o0?oNool0K?mQ0?oohP3oo`3oT?l0oi;oJ03ooaP0ooooT002
oookJP04oonn0?oonf[ooeL0ool0;@?ooo]Z00Oo0=Coo`04ool0odko0?l^o`000?l0oago0?l800?o
o`1i0_oonfX01?l@0?ooT_l0oi;o0?nBo`09o`0`o`?oT_l00_l@0?l00ooonf[oo`1Aool0N@02oook
JP03o`3oDol0oagooo]Z00;ooo]Z00Go0?ldo`3oC_l0R?oo0:Woo`3Do`03oookJP05oon10?oonf[o
oo]ZoookJ_oo02d00_oonfX01?ooE`3ooo]Zon/0oooo_P04oookJP05oon@0?l0M?oo603ooookJ_mX
0?l00_oonfX02_l0oi;ooo]Zon80oooonf[o0?m5of40oom=0?ooo`1/oookJ_oo08L2oookJP0Iok?o
0?l05oooo`3Mool30?oonf[o0?_ooookJ_lko`3o0?o<oon10?l0Mooooo]Zool0nOnX0?oo0:Koool0
m_o[o`3ooo]Zool60?lH0?oooo]Zool0o?oonf[ooi80oolF0004oookJP03ool0j_oonf[ooo]Z00Wo
oo]Z00?o07?ooookJ_oonfX01ooonfX01?nio`3ooe80oookJ_l0:_l2oookJP04ocoo0?oonf[o0=co
ogSo00Kooo]Z00Co0?lKoa80oooonf[oolX00ooonfX00ooo09?oo`0CoookJP04oookJP06om[o0?oo
nf[ooo]ZoookJ_lV0?oo8?l03_oonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP06o`3o/?n2o`3ooo]Z
o`0`oooonf[o0?m=0_oonfX01?l60?oooo]Zool0mOnBo`02oookJP03ool0J_l@0?oooo]Z00?ooo]Z
00Koo`1AoookJ_oonf[ooo]Zo`2]oooo07TVoookJP00;OoonfX00ooo0?Wo07OooookJP02odCo0005
o`3oV_oUo`3oiOl0onGo0?lko`001?oonfX01OnDo`3ooo]ZoookJ_oonf[oo`<000;ooo]Z00GoN@3o
ool0gOoonf[o/ol0oil0o`04oookJP03o`3og_oMo`3oo`2700?ooo]Z00Ooo`1/oookJ_m=0?oooo]Z
onGo0?oonf[oH@3o00;ooo]Z00KohP3ooookJ_oonf[o0?n@oookJ_l0oi86oookJP03ofP0oooonf[o
oo]Z00?ooo]Z00Go603ooookJ_oonf[ooo]Zoon@0008oookJP03oonn0?oonf[oj`3o00Gooo]Z00?o
oeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Cooo]Z00Co
0=Coo`04oooonf[o0:Wo0ooonfX00ol0obko0?m>oookJP03oookJPCoiOl000Oo0?mCoookJ_oonf[o
o`1io`2]oooo057o5@3o00;ooo]Z00Go403ooi;o0?oob@3ooo]Zo`3oC@03onGo0003oc7o0?oUo`3o
oo]Z00Cooo]Z00Wo9P3ooookJ_oJo`3ooo]Zool04ooo09?ooo]Zooo:0?l0oa/00_oonfX01Ol0omoo
N?l0ocoo0?l0:_oooe8000Cooo]Z00?o07?ooookJ_oonfX00_oonfX03?oo0>[ooo]Zoomi0?ooN@3o
o`3loaP0oooo1P3o0:KoojP0ool0MoooobP0oc_o00;oobP000?o/ol0oolX0?oo06`01Ooo00001?oV
o`3o603ooolX0?oo_P07ool00003o`3Doooo003o0?m>00?oolT02oooN@06o`3oF`?ooo]Z0ooo0002
oi;o00;oo`001?oo:0000ol0oagoobP0oolX0002oolX0005o`3oC_l0R?oo0:Woo`3DoonDo`000_oo
nfX01OooP@3ooo]ZoookJ_oonf[oo`0]00;ooo]Z00GooeL0oookJ_o[0?oo0?l5oonn0003oookJP05
oon@0?l0M?oo603ooookJ_mX0?l00_oonfX02_l0oi;ooo]Zon80ooooN@3o0?m5of40ooooN@3oo`1/
oookJ_oo08L2oookJP0@ok?o0?oo0=goN@3oool30?oonf[o0?_ooookJ_lko`3oogT0oom/0?oob@3o
07Ooooo90?nX0?ooolT0on_o00;oolT000Ooo`H0oookJ_oonf[oo`3loookJ_ooTP3ooaH000Cooo]Z
00?oo`3ZoookJ_oonfX02OoonfX00ol0Looooo]ZoookJP07oookJP0:okWo0?ooDP3ooo]ZoookJ_l0
:_oooo]Zocoo0?oonf[o0?mMogSo00Kooo]Z00?oiOl0oookJ_oobP001?oonfX00ooo09?oo`0Coook
JP03oookJP03om[o0?oQo`3ooo]Z00;ooo]Z00?o9P3oob3o0?oonfX03OoonfX01?lao`3ooo]Zoook
J_l0oe/2oookJP08o`3o/?n2o`3oU?l0oiCo0?l0j?oo0?m=oookJ_l60?l2oookJP06onGo0?nBo`3o
oo]ZoookJ_l06Ooo403o0ooonfX00olE0?ooo`1AoookJP02oookJP03o`2]oooo07Wooo]Z04kooo]Z
00[oo`3ioookJ_l0Mooooo]Zoom/0?l0oi[o0?o<oookJ_ooP@3o>ol01?oonfX01Ol0nooooo]Zoook
J_oonf[oo`<000?ooo]Z00Goo`3MoookJ_l0Xooo/ol0oil0o`04oookJP03o`3og_oo08Oooo]Z00;o
oo]Z00Ooo`1/oookJ_oonf[oC@3oool^0?oonf[oH@3o00?ooo]Z00?ohP3ooookJ_l0oi000_oonfX0
0ol0oi;ooo]ZoookJP04oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603oo`1doooonf[ooo]Zoon@
0008oookJP04oonn0?oonf[oj`3oog00o`Gooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]Z
oookJP04oookJP03oon10?oonf[ooo]Z00Cooo]Z00Go0=Coo`04oooonf[o0:Woo`28o`03oookJP03
o`3oC_l0ocCooo]Z00Cooo]Z00?o0>7oo`3o7Ol0oe<00ooonfX03_oo07Wo0:goool0DOlE0?oooo]Z
oa00oonBo`3ooo]Zo`H0ool0odgo0?naoh;o0?l0oe_o<Ol01_oonfX00olPo`3o9P3oom[o0002oook
JP05ool0Tol0nOoooo]Zooo:0?l0oa/00_oonfX01Omho`3o0=coo`0ZooooDP3o^Ol000?ooo]Z00?o
07?ooookJ_oonfX00ooonfX05ooo0>[ooaH0oonB0?oo0?co603oool60?o[o`3oZ03oo`1gooooP@3o
>ol0o`3koooo0`3o/ol0o`3og_oo06coobh0of40ool0oi3o0?nBofP0oooVo`3o603o00;ooo]Z00Go
okh0oookJ_ooE`3ooo]Zool0;@02oookJP08o`3Dool01?oo0?ldo`3oC_l0003o0?lMo`000?oo07T2
oookJP04oa00oonBo`3oT_l0oi;o00;o033o00?ooo]Zo`3oFol0oe/01?l0oe/3oookJP;o033o00Oo
oo]Zoi;o0?nBo`3o403ooookJ_oo057oo`1i00;ooo]Z00?o0?mCo`3o7OoonfX00_oonfX01?l0ocCo
0?m>o`2Yool0e?l4oookJP04oon10?oonf[ooo]Zool0;@;ooo]Z00GooeL0oookJ_m`0?ooj`3ooonn
0003oookJP05oon@0?l0M?oo603ooookJ_mX0?l00_oonfX02_l0oi;ooo]Zon80oooonf[o0?m5of40
oom=0?ooo`1/oookJ_oo08L2oookJP0Jok?o0?l05oooo`3Mool30?oonf[o0?_ooookJ_lko`3o0?o<
oon10?oonf[o07Ooool0nOnX0?oo0:Koool0m_o[o`3ooo]Zool60?lH0?oooo]Zool0o?oonf[ooi80
oookJ_oo5P03oookJP03ool0j_oonf[ooo]Z00Wooo]Z00?o07?ooookJ_oonfX02?oonfX02OooDP3o
oo]ZoookJ_l0:_oooo]Zocoo0?oonf[o0=coogSo0006oookJP04o`3o6olB0?oooo]Zooo:00?ooo]Z
00?oo`2Cool04ooonfX01?oonfX01_oJo`3ooo]ZoookJ_oonf[o9P3oob3o00kooo]Z00Co<Ol0oook
J_oonf[o0?mK0_oonfX01_l0ok3oP_l0oookJ_l0ok7o033oo`3oC@;ooo]Z00Co1P3ooookJ_oo0?Go
T_l00_oonfX00ooo06[o403ooookJP03oookJP06ool0DOoonf[ooo]ZoookJ_l0[Oooo`1i9_oonfX0
02cooo]Z00?oo`3ioookJ_l0Mol01?m4o`03onGo0003oc_o0?oonf[ooo]Z00;ooo]Z00GoU?l0oook
J_oonf[ooo]Zool30002oookJP05ogT0oooo0=gooo]Zok?o0?nO0?l01?oonfX00ol0omkogOl0ool0
Q`02oookJP08ool0K?oonf[ooo]Zodd0oooonf[oiOl0of40ool0odD2oookJP03on80oooonf[o0?n@
00;ooo]Z00?o0?nBoookJ_oonfX01?oonfX00omX0?oooo]ZoookJP02oookJP03oaP0oooVo`3ooo]Z
00;ooo]Z00?ooi00oookJ_oonfX01OoonfX01?oo_P3ooo]ZoookJ_o[0?l5oookJP03oomG0?oonf[o
oo]Z00;ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP04oookJP04o`3Dool01?oo
oo]Zo`2Yo`?ooo]Z00?o0?m>o`3o=?oonfX00ooonfX4onGo000>o`3oDooonf[ooo]Zool0NOl0[Ooo
o`1AoaD0oooonf[o01Wooa00oonBo`3oolT0o`3oCOl0<?l3onGo0003oc7o0?oUo`3ooo]Z00?ooo]Z
013o9P3oonGo0?oonf[of_l0oookJ_oo01?oo`2Cooo:0?l0S_oo0?lKoookJ_l0omooN?l0o`3Lool0
:_oooe801OoonfX00ol0Looooo]ZoookJP02oookJP0;ool0j_oonf[oogT0oomi0?oo0?coo`H0on_o
0?oonf[oobP0o`1goolko`000ooo:0000onco`3oobP0ool0K005ool00005oaP0oooo:03oobP0oonn
0?m`0?l01Ooo00001_l0e?ooo`00o`3oC_oo003oogT0ooo900SoogT01?l0oe/5oomi0005oookJ_l0
oe_o0?mKo`3oFooonfX01?oo00000onBo`3oo`00ool00004oolX0005o`3o7Ooo:03oobP0oolX0?l0
odh00oooN@001Ol0e?oooo]ZoookJ_oonf[ooh4000;ooo]Z00Soo`0]oookJ_oonf[ooeL0oookJ_o[
0?ooL03ooonn00Cooo]Z00Cooi00onKo0?lH0?ooJ03o0ooonfX02Ol0oi;o0?n@on80ooooN@3oH@3o
odd0ooooN@3oo`1/ool0Q`02oookJP06ok?o0?oo0=goN@3oool30?oonf[o0?_o0_oob@001_lko`3o
of`0ooo90?l0MoooolT0ojP0o`;oolT000?ojol0ooo90?oo1P000_oonfX01?oo0?cooo]ZoonB0?oo
5P04oookJP03ool0j_oonf[ooo]Z00Wooo]Z00?o07?ooookJ_oonfX01ooonfX02_nio`3ooe80oook
J_oonf[o02[ooookJ_loo`3ooo]Zo`3oGOmho`06oookJP03onGo0?oonf[oolX000Cooo]Z00?oo`2C
ool04ooonfX00ooonfX00ooJo`3ohOl0oookJP02oookJP03obH0oolPo`3ooo]Z00gooo]Z00Co<Ol0
oookJ_oonf[o0?mK0_oonfX01On2o`3ooo]ZoookJ_nDo`3o0?m=00;ooo]Z00Co1P3ooookJ_oonf[o
T_l00ooonfX00ol06Ooo403ooookJP02oookJP03oaD0oooo057ooo]Z00;ooo]Z00?o0:goool0NOoo
nfX0C_oonfX02_oo0?Wooo]Zo`1goooonf[oof`0oookJ_l0olcooh40oookJ_lko`04oookJP05o`3k
oooonf[ooo]ZoookJ_oo0`000ooonfX01Ooo0=gooo]Zo`2Soonco`3oW`3o00Cooo]Z00?o0?oNool0
QooonfX00_oonfX01ooo06cooo]ZoookJ_m=0?ooobh0of40ool0odD00ooonfX00ooR0?oo0?n@oook
JP02oookJP03o`3oT_oonf[ooo]Z00?ooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?ooi_l0oook
JP02oookJP03oon@0?oonf[ooo]Z00Kooo]Z00?ookh0oookJ_o[0?l01OoonfX00oooE`3ooo]Zoook
JP02oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0e?oo00Cooook
J_l0ZOoo08So00?ooo]Z00?o0?m>oookJ_oonfX01?oonfX00ol0oago0?l8o`3oD`03oookJP0>ool0
NOl0[Oooo`1AoaD0ool06Ooo403ooi;o0?l60?oo0?m=o`0`ool0ok7oP_l0o`3oFolao`06oookJP03
obH0oooonf[of_l000;ooo]Z00Coo`2Co`3ioooobP3o0?lK0_oonfX01Ol0omooN?l0ocoo0?ooDP3o
0?lc00Cooo]Z00?o07?ooookJ_oonfX00ooonfX07Ooo0>[ooi80oookJ_oo0?co603oool60?l0Y_oo
o`3io`1goolko`3o0?_oool30?oo0=go/ol0o`3og_oo06coH@3ooookJ_l0oi3ooo]ZofP0oolH0?oo
oi00oookJ_l0o`Gookh0oomG0?oonf[oo`0]00;ooo]Z00Ko0=Coo`04ool0ocCo0?m>o`000?l0oad2
ool0N@;o403o0_nBo`000ol0<?oooo]Zo`3oF`03o`3oF`Kooo]Z1?l0oe/03Ooonf[o033ooookJ_oo
nf[oT_l0oa00oooonf[oo`1Aool0NOoonf[o0?mCo`3o2?l0oad00_oonfX01Ol0ocCo0?m>o`28ool0
ZOoo0=Co00Cooo]Z00Kooh40oookJ_oonf[oo`0]oookJ_ooE`02oookJP03on/0oooo_P3ooo]Z00?o
oo]Z00Gooi00onKo0?lH0?oooo]ZofP0o`02oookJP09o`3oT_oonf[ohP3ooookJ_l0odGoH@3ooook
J_oo06coo`2700;ooo]Z01[o/ol0o`2Soooo0=gooo]Zool30?oonf[o0?_ooookJ_lko`3ooh40oook
J_l0Moooo`3iojP0ool0Y_ooo`3foookJ_o[o`3oo`H0oaP0oooonf[oo`3loookJ_ooTP3ooo]ZoolF
00?ooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ol0Looooo]ZoookJP08oookJP09oomB0?oonf[ooo]Z
o`0Zoooonf[o?ol0oookJ_l0g?ooN?l000Kooo]Z00Co0?lKoa80oooonf[oolX00ooonfX00ooo09?o
o`0CoookJP04oookJP07om[o0?oonf[ooo]ZoookJ_lV0?ooQ03oob3o000=oookJP04oc7o0?oonf[o
oo]Zo`3oF`;ooo]Z00Ko0?n`oh;o0?oonf[o0?nao`0`ool0odd2oookJP04o`H0oooonf[oo`3eoi;o
00;ooo]Z00?oo`1Zoa00oooonfX00ooonfX01_oo057ooo]ZoookJ_oonf[o0:goool0NBKooo]Z000/
oookJP03ool0nOoonf[o07Oo00CoA?l00_oUo`000olko`3oiOl0oookJP02oookJP03oiCo0?oonf[o
oo]Z00;ooo]Z00Ooo`<0oookJ_oonf[oN@3oool0gOoonf[o/ol000Gooo]Z00?o0?oNomgo0?oo08L0
0_oonfX02?oo06cooo]ZoookJ_m=0?ooiOl0oookJ_mQ0?oo0?m50_oonfX00ooR0?oooo]Zo`3oT002
oookJP03o`3oT_oonf[ooo]Z00Cooo]Z00?oJ03ooookJ_oonfX00_oonfX01OlH0?oo07CooookJ_oo
nf[ooi0000Sooo]Z00Cookh0oookJ_l0o`Goj`3o1OoonfX00oooE`3ooo]ZoookJP02oookJP03ool0
;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX01?oonfX01?l0e?oooo]ZoookJ_l0ZOl3oookJP03
o`3oC_l0ocCooo]Z00;ooo]Z1?oUo`001ol0oe?oiOl0oookJ_oonf[oo`1io`2]oooo05400_oonfX0
1Ol@0?oooo]Zoi;o0?oob@3o0?m=00?oiOl000?o<Ol0onGo0?oUo`001?oonfX04?lV0?ooQ03ooook
J_oJo`3oo`0Co`3ioooo09?oolX0oa80ool0oa_ooo]Zo`3ogomho`3o?ol0o`0ZooooDP04oookJP03
o`1coooonf[ooo]Z00;ooo]Z00coo`3ZoookJ_ooN@3oogT0ool0o?lH0?ooo`H0o`2Voooo:03o07Oo
oolX0?lko`02oolX0006ok?o0?oo:03oo`1/of40ool0odGo0?n@0ooo0002oolX0003oonn0?m`0?oo
oo]Z00Coo`0000?o0=Coo`04ool0odh00_oo0007oomi00?o0?mK2_ooN@03oookJP?o0?mK0ooo0000
0onBo`3oo`00oolX0003oolX0003o`3o7OooN@3oogT000;oogT000Go0?m>oomi0?ooN@3o0=CooiCo
0002oookJP05oon10?oonf[ooo]ZoookJ_oo02d00_oonfX01OooE`3ooo]Zon/0oonDo`3ookh000;o
U?l000Kooo]Zoon@0?l0M?oo603ooookJ_mX0?l2oookJP09o`3oT_l0oi3ohP3ooomi0?l0odGoH@3o
oomi0?oo06coo`2700;ooo]Z00ko/ol0ool0gOmi0?ooo`<0oookJ_oob@3o0?_oooo90?lko`3oof`0
ooo90?l0MoooolT0ojP0o`;oolT000?ojol0oookJ_oo1P000ooonfX00ooo0?cooo]ZoonB0004oook
JP03ool0j_oonf[ooo]Z00Wooo]Z00?o07?ooookJ_oonfX01ooonfX02_nio`3ooe80oookJ_oonf[o
02[ooookJ_loo`3ooo]Zo`3oGOmho`06oookJP03onGo0?oonf[oolX000Cooo]Z00?oo`2Cool04ooo
nfX00ooonfX00ooJo`3ooo]Zon7o0002oookJP03obH0oooUo`3o8?l000gooo]Z00Co<Ol0oookJ_oo
nf[o0?mK0_oonfX01On2o`3ooo]ZoookJ_nDo`3o0?m=00;ooo]Z00Co1P3ooookJ_oonf[oT_l00ooo
nfX00ol06Ooo403ooookJP02oookJP03oaD0oooo057ooo]Z00;ooo]Z00?o0:goool0NOoonfX0C_oo
nfX02_oo0?Wooo]Zo`1goooonf[oof`0oookJ_l0olcooh40oookJ_lko`03oookJP03o`3koooonf[o
oo]Z00;ooo]Z00Soo`<0oookJ_oonf[ooo]Zool0gOoonf[o0:?ook?o00Gooo]Z00?o0?oNool0Qooo
nfX00_oonfX01ooo06cooo]ZoookJ_m=0?ooobh0of40ool0odD00ooonfX00ooR0?oo0?n@oookJP02
oookJP03o`3oT_oonf[ooo]Z00?ooo]Z00?oJ03ooookJ_oonfX00_oonfX01OlH0?ooi_l0oookJ_oo
nf[ooi0000Sooo]Z00Cookh0oookJ_oonf[oj`3o1OoonfX00oooE`3ooo]ZoookJP02oookJP03ool0
;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0e?oooo]ZoookJ_l0ZOoo08So00?o
oo]Z00?o0?m>oookJ_oonfX00ooonfX00ol0hOoo0?lMo`3oD`04oookJP0>ool0NOl0[Oooo`1Aoook
J_l@0?oooo]Zoi;o0?l60?oo0?m=o`0`oon2o`3o0?n`o`3oFolao`05oookJP0:ob3o0?lV0?oooo]Z
om[o0?oonf[oo`0Cool0Tooonf[oolX0o`3o6`;ooo]Z00GoN?l0o`3Looloo`3ooe80okWo0003oook
JP03o`1coooonf[ooo]Z00?ooo]Z01Ooo`3ZoolF0?ooTP3oo`3loookJ_oo1P3ojol0ojP0ool0Mooo
oh40oc_o0?oonf[oo`<0ok?o0?l0omkoo`1/of40ool0odGo0?n@o`3oT_mX0?oo603ooon@0002oook
JP04oonn0?ooE`3ooo]Zool0;@;ooo]Z00co0=CooookJ_l01?oo0?m>oookJ_l0oagoo`1io`000?l@
0?oooo]Zoi;o0?l0<?l3o`3oF`kooo]Z0ol0oe/02ol0<?oooo]Zoi;o0?l@0?oooo]Zool0DOoo07Wo
oo]Zo`3oDol0oago0>7o00;ooo]Z00Go0?ldo`3oC_l0ZOoo0=Coo`04o`03oookJP04oon10?oonf[o
oo]Zool0;@;ooo]Z00GooeL0oookJ_m`0?ooj`3ooonn0003oookJP05oon@0?l0M?oo603ooookJ_mX
0?l00_oonfX07ol0oi;ooo]Zon80oooonf[o0?m5of40oom=0?ooo`1/o`3og_oo08Oooo]Zok?o0?l0
Xoooo`3MoookJ_oo0`3ooo]Zo`3koooonf[o>ol0oon10?oonf[o07Ooool0nOnX0?oo0:Koool0m_oo
nf[ojol0ool60?lH0?l00_oonfX01?oo0?cooo]ZoonB0?oo5P03oookJP03ool0j_oonf[ooo]Z00Wo
oo]Z00?o07?ooookJ_oonfX02?oonfX02OooDP3ooo]ZoookJ_l0:_oooo]Zocoo0?oonf[o0=coogSo
0006oookJP04o`3o6olB0?oooo]Zooo:00?ooo]Z00?oo`2Cool04ooonfX01?oonfX01ooJo`3ohOl0
oookJ_oonf[o9P3ooh@0oolPo`003OoonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP06o`3o/?n2o`3o
oo]Zo`3o/Ol0<?oo0?m=0_oonfX01?l60?oooo]Zool0mOnBo`02oookJP03ool0J_l@0?oooo]Z00?o
oo]Z00Ooo`1AoookJ_oonf[ooo]Zo`2]oooonf[oo`1i02Gooo]Z000/oookJP03ool0nOoonf[o07Oo
00CoA?l00_oUo`000olko`3oiOl0oookJP02oookJP05oiCo0?oonf[ooo]ZoookJ_oo0`000ooonfX0
1?mi0?ooo`3Mo`2Soonco`05oookJP03o`3og_oMo`3oo`2700;ooo]Z00Ooo`1/oookJ_oonf[oC@3o
onGo0?oonf[oH@3o00?ooo]Z00?ohP3ooookJ_l0oi000_oonfX00ol0oi;ooo]ZoookJP04oookJP03
ofP0oooonf[ooo]Z00;ooo]Z00Go603ooookJ_oonf[ooo]Zoon@0008oookJP04oonn0?oonf[o0?l5
on/0o`Gooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[o
oo]Z00Gooo]Z00Co0=CooookJ_oonf[o0:Wo0ooonfX00ol0odko0?ldoookJP02oookJPCoiOl000Oo
0?mConGo0?oonf[ooo]Zool0NOoo057o5@3o00;ooo]Z00Go403oool0mOnBo`3ooo]Zo`3oC@03onGo
0003oc7o0?oUo`3oiOl000Cooo]Z00Wo9P3ooookJ_oJo`3ooo]Zool04ooo09?ooo]Zooo:0?l0oa/0
0_oonfX01Omho`3o0=coo`0Zoooonf[ooe8000Cooo]Z00?o07?ooookJ_oonfX00_oonfX02ooo0>[o
ogT0oomi0?ooN@3oo`3lool60?o[o`3ooo]Zool0nOl0Mooo>ol000?oobP000oo/ol0oomi0?oo:03o
H@3oo`3oT?l0oi;oobP0ool00?lH0?ooobP0oonn0?m`0?oooeL0oookJ_oo02d00_oo00001?l0e?oo
00Coo`3oC_oo0002oolX00CoogT00ol0oe/?oomi0005ooo90?oo003ooo]ZoookJ_l0oe/00ooo0000
0onBo`3oo`00oolX0002oolX0003o`3oDoooN@3oogT000;oogT000Go0?m>oomi0?ooN@3o0:Woo`3D
o`03oookJP05oon10?oonf[ooo]Zool0;OoonfX00onDo`000oo[0?ooU?l0oonn0002oiCo0006oook
J_ooT03o07CooaP0oooonf[oJ03o0_oonfX02Ol0oi;o0?n@on80oooonf[o0?m5of40ooooN@3oo`1/
ool0Q`02oookJP04ok?o0?l0Xoooo`3MogT0o`;ooo]Z00So0?_oooo90?lko`3oof`0ooo90?l0Mooo
olT0ojP0o`;oolT000?ojol0oookJ_oo1P000ooonfX00ooo0?cooo]ZoonB0004oookJP03ool0j_oo
nf[ooo]Z00Wooo]Z00?o07?ooookJ_oonfX01ooonfX02_nio`3ooe80oookJ_oonf[o02[ooookJ_lo
o`3ooo]Zo`3oGOmho`06oookJP03onGo0?lB0?ooolX000Cooo]Z00?oo`2Cool04ooonfX01?oonfX0
0ooJo`3ohOl0oookJP02oookJP03obH0oolPo`3ooo]Z00gooo]Z00?o<Ol0oookJ_l0oe/00_oonfX0
1On2o`3ooo]ZoookJ_nDo`3o0?m=00;ooo]Z00Co1P3ooookJ_oUo`3oT_l00ooonfX00ol06Ooo403o
oookJP02oookJP05oaD0oooo057ooo]ZoookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP1;oookJP0;
ool0nOoonf[o07OooookJ_ooK03o0?nJoookJ_l0olcooh40oookJ_lko`000ooonfX01Ol0nooooo]Z
oookJ_oonf[oo`<000?ooo]Z00GoN@3oool0gOoonf[o0:?ook?o0005oookJP03o`3og_oo08Oooo]Z
00;ooo]Z00Koo`1/oookJ_oonf[oC@3oool^0?mQ0?l4oookJP05on80ool0oi3ooo]ZoookJ_l0oi80
1_oonfX00omX0?oooo]ZoookJP02oookJP05oaP0ool0M?oooo]ZoookJ_ooT0002?oonfX01?oo_P3o
oo]ZoookJ_o[0?l5oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01?oonfX00ooo
P@3ooo]ZoookJP05oookJP05o`3Doooonf[ooo]Zo`2Yool0R?l00_oonfX00ol0odko0?ldoookJP04
oookJP03o`3Qool0oago0?mC00Cooo]Z00koo`1iool0DOlE0?oooo]Zoa00oooo0?GoT_l0o`H0ool0
odgo033ooh;o0?oonf[o0?mKoc7o00Gooo]Z00?o8?l0obH0oooJo`000_oonfX01Ooo09?o0?Wooook
J_oobP3o0?lK00;ooo]Z00GoN?l0o`3Lool0:_oooe80okWo0003oookJP03o`1coooonf[ooo]Z00?o
oo]Z01Koo`3ZoolF0?ooTP3oo`3loaP0oooo1P3ojol0ool0nOl0Mooo>ol0o`3koooo0`3oo`3Mok?o
0?oo06coobh0of40oooonf[o0?n@oookJ_mX0?oo603o0_oonfX01?oo_P3ooo]ZoomG0?oo02d2oook
JP09o`3Doooonf[o00Coo`3oC_oonf[o0?lMool0NOl0003o403o00;oT_l00_l0oe/5oookJPWo9P3o
1_oonfX02ol0oe_o033ooookJ_nBo`3o403oool0DOoonf[oo`1ioookJ_l0oe?o0?lM00;ooo]Z00Go
0?ldo`3oC_l0R?oo0:Woo`3Do`03oookJP0;oon10?oonf[ooo]ZoookJ_oo02gooo]ZoomG0?oonf[o
L03oon/0oooo_P000ooonfX01OooT03o07CooaP0oooonf[oJ03o00;ooo]Z01oo0?nBoookJ_oR0?oo
oo]Zo`3oAOmQ0?ooC@3oool0K?l0omkoo`27oookJ_nco`3o0:?oo`0Goooo0=goo`<0oookJ_l0nooo
oo]Zoc_o0?ooP@3oof`0o`1goooo0?Wooo]ZojP0oooonf[oo`3fon_o0?oo1P3o603o00;ooo]Z00Co
o`3loookJ_ooTP3ooaH00ooonfX00ooo0>[ooo]ZoookJP09oookJP03o`1coooonf[ooo]Z00Sooo]Z
00Wooe80oookJ_oonf[o02[ooookJ_loo`3ooo]Zo`3Loomho`001_oonfX01?l0oa_o4P3ooookJ_oo
bP03oookJP03o`3ioooo09?ooo]Z00Cooo]Z00?of_l0on7o0?oonfX00_oonfX00olV0?oo8?l0oook
JP0=oookJP03oc7o0?oonf[o0?mK00;ooo]Z00Ko0?n`oh;o0?oonf[o0?nao`0`ool0odd2oookJP03
o`H0oooonf[oT_l000?ooo]Z00?oo`1Zoa00oooonfX00ooonfX01ooo057ooo]ZoookJ_oonf[o0:go
oookJ_oo07T09OoonfX002cooo]Z00?oo`3io`1goom4o`001?m4o`02onGo0003oc_o0?oUo`3ooo]Z
00;ooo]Z00GoU?l0oookJ_oonf[ooo]Zool30003oookJP04ool0gOoonf[o0:?ook?o00Gooo]Z00?o
0?oNoookJ_oo08L00_oonfX01ooo06cooo]ZoookJ_m=0?ooiOl0oookJ_mQ0?l00ooonfX01OoR0?oo
oo]Zo`3oT?oonf[o0?nB00Oooo]Z00?oJ03ooookJ_oonfX00_oonfX01OlH0?oooo]ZoookJ_oonf[o
oi0000Sooo]Z00Cookh0oookJ_l0o`coj`3o1OoonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00Oooo]Z
00?ooh40oookJ_oonfX01?oonfX01Ol0e?oo00CooookJ_l0ZOoo08So00;ooo]Z00?o0?l^o`3oC_l0
oc@00_oonfX5onGo000=o`3oDooUo`3ooo]Zool0NOl0[Oooo`1AoaD0oooonf[oo`1Zoa00oonBo`3o
olT0o`3oC@04onGo0003oc7o0?oUo`3oiOl000Cooo]Z00Wo9P3ooookJ_oJo`3ooo]Zool04ooo09?o
oo]Zooo:0?l0oa/00_oonfX01?mho`3o0=coo`0ZooooDP05oookJP06o`1coooonf[ooo]ZoookJ_oo
0>[ooo]Z0_ooN@006Ooo0?cooo]Zool60?o[o`3oo`00ool0nOl0Mooo>ol0ool00?oo:03o/ol0oolX
0?ooN@3oobP0oookJ_l0oi3o0?nBofP0oolH0?ooobP0oonn0?m`0?oooeL0oookJ_oo02d00_oonfX0
1?l0e?oo00Coo`3oC_oo0003oolX00?oogT000Go0?mKoomi0?oo003oo`00ob3o0003obH0o`03oolX
0?ooN@3oogT000WoogT000Goo`00oookJ_oonf[oo`00o`3oF`03ool00003oi;o0?l@0?ooobP000;o
obP000?o0?mCoomi0?ooN@000_ooN@001Ol0odkoogT0o`2Yool01?oo0=Co00;ooo]Z00Gooh40oook
J_oonf[ooo]Zool0;@03oiCo0003on/0oonDo`3ookh000;oU?l000Kooo]Zoon@0?oonf[o603ooook
J_mX0?l2oookJP0?o`3oT_l0oi3ohP3ooookJ_l0odGoH@3ooomi0?oo06coo`27o`3og_oonf[o/ol0
o`2Soooo0=goN@3o00;ooo]Z00Ko0?_oooo90?lko`3oof`0ooo90?l0Mol2ooo90006ojP0oooob@3o
jol0oookJ_oo1P3o603o0_oonfX00ooo0?cooo]ZoonB0004oookJP03ool0j_oonf[ooo]Z00Wooo]Z
00?o07?ooookJ_oonfX01ooonfX02_nio`3ooe80oookJ_oonf[o02[ooookJ_loo`3ooo]Zo`3oGOmh
o`06oookJP03onGo0?lB0?ooolX000Cooo]Z00?oiOl0ool0TooonfX01?oonfX00ooJo`3ohOl0oook
JP02oookJP03obH0oolPo`3ooo]Z00gooo]Z00?o<Ol0oookJ_l0oe/00_oonfX01On2o`3ooo]Zoook
J_l0ok7o0?m=00;ooo]Z00Co1P3ooookJ_oUo`3oT_l00ooonfX00ol06Ooo403ooookJP02oookJP05
oaD0oooo057ooo]ZoookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP1;oookJP0:ool0nOoonf[o07Oo
oookJ_ooK03o0?nJoookJ_l0olcooh40oc_o00Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30003oook
JP05ogT0oooo0=gooo]Zo`2Soonco`001?oonfX00ooMo`3o0?oNool0Q`02oookJP07ool0K?oonf[o
oo]ZoookJ_m=0?oooo]Zof40o`04oookJP05on80ool0oi3ooo]ZoookJ_l0oi801_oonfX00omX0?oo
oo]ZoookJP02oookJP05oaP0ool0M?oooo]ZoookJ_ooT0002?oonfX01?oo_P3ooo]Zog00ooo[0?l5
oookJP05oomG0?oonf[ooo]ZoookJ_oo02d01ooonfX00oooP@3ooo]ZoookJP04oookJP06o`3Dool0
1?oooo]Zo`2Yoooonf[o08So0_oonfX00ol0odko0?ldoookJP04oookJP03o`3Qool0oago0?mC00?o
oo]Z00koo`1io`2]oooo057o5@3oool0J_l@0?ooT_l0o`H0ool0odgo0>Soo`0`oon2o`3o0?mKoc7o
00Kooo]Z00?o9P3ooookJ_oJo`000_oonfX01?oo09?o0?Woooo:0?l0oa/2oookJP05o`3ogomho`3o
?ol0oomB0?l0oc<01?oonfX00ol0Looooo]ZoookJP02oookJP0Zool0j_oonf[ooi80ool0o?oonf[o
o`H0on_o0?nX0?ooo`3io`1goolko`3ooo]Zool30?nco`3o0?oNool0K?mQ0?oooo]Zo`3oT?l0oi;o
J03ooaP0ooooT03ooo]Zoonn0?l0o`GooeL0oookJ_oo02gooo]Zo`3Doooonf[o00Coo`3oC_oonf[o
0?lMool0NOl0003o403ooi;o0?l0003o0?mK0ooonfX4obH0o`Wooo]Z0_lV0?l5oookJP0;o`3oFol0
<?oo1P3ooi;o0?l@0?ooo`1AoookJ_oo07Wo0?mCo`3o7Ol0hOl00_oonfX01Ol0ocCo0?m>o`2Yool0
1?oo0=Co00?ooo]Z00Kooh40oookJ_oonf[oo`0]oookJ_ooE`02oookJP03on/0oooo_P3ooo]Z00;o
oo]Z00?ooi00oookJ_lH0?l00_oonfX08OmX0?oooo]Zo`3oT_oonf[ohP3ooookJ_l0odGoH@3oodd0
oooo06cooo]Zool0Qooonf[o/ol0o`2SoonO0?ooo`3Mool30?oonf[o0?_ooookJ_lko`3ooh40oom/
0?l0Moooo`3ioookJ_nX0?oo0:Koool0m_o[o`3oo`H0oaP0o`02oookJP04ool0o?oonf[ooi80oolF
00?ooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ol0Looooo]ZoookJP08oookJP09oomB0?oonf[ooo]Z
o`0Zoooonf[o?ol0oookJ_l0g?ooN?l000Kooo]Z00Co0?lKoookJ_lB0?ooolX00ooonfX00ol0nOoo
o`2CoookJP04oookJP03om[o0?oQo`3ooo]Z00;ooo]Z00?o9P3oob3o0?oonfX03OoonfX00olao`3o
oo]Zo`3oF`02oookJP06o`3o/?n2o`3ooo]Zo`3o/Ol0<?oo0?m=0_oonfX00ol60?oooo]Zoi;o0003
oookJP03ool0J_l@0?oooo]Z00?ooo]Z00Ooo`1AoookJ_oonf[ooo]Zo`2]oooonf[oo`1i02Gooo]Z
000/oookJP03ool0nOl0MoooA?l000CoA?l000Cooo]ZonGo0?lko`3oiOl00ooonfX01OnDo`3ooo]Z
oookJ_oonf[oo`<000;ooo]Z00GoN@3oool0gOoonf[o0:?ook?o0005oookJP03o`3og_oo08Oooo]Z
00;ooo]Z00Ooo`1/oookJ_m=0?oooo]ZonGo0?oonf[oH@3o00?ooo]Z00GohP3ooookJ_l0oi3ooo]Z
o`3oTP06oookJP03ofP0oooonf[ooo]Z00?ooo]Z00Go603ooookJ_oonf[ooo]Zoon@0007oookJP05
oonn0?oonf[ooo]Zo`3o3?o[0?l01OoonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00Oooo]Z00?ooh40
oookJ_oonfX01?oonfX01Ol0e?oo00CooookJ_l0ZOoo08So00;ooo]Z00?o0?m>o`3o=?oonfX00_oo
nfX5onGo000=o`3oDooUo`3ooo]Zool0NOl0[Oooo`1AoaD0oooonf[o01Wooa00oonBo`3oolT0o`3o
C@03onGo0004oc7o0?oUo`3oiOl0onGo00?ooo]Z013o9P3ooh@0oooonf[of_l0oookJ_oo01?oo`2C
ooo:0?oUo`3o0?lKoookJ_l0omooN?l0o`3Lool0:_oooe801?oonfX00ol0Looooo]ZoookJP02oook
JP0?ool0j_ooN@3oogT0oomi0?oo0?coo`H0on_o0?l0Y_ooo`00o`1goooo003o>ol0ool0gOl0Xooo
/ol000;oogT000GoH@3oo`3oT?l0oi;oJ03ooaP0o`02oolX0004oonn0?m`0?oooeL0ool0;@;ooo]Z
00?o0=Coo`04ool0odh01?oo:002oiCo0004oomi0?l0oe_oogT0ool000?o9P3o00?oo`00oolX0?oo
:0001Ooo:004ooo900CoogT000Go8?l0oookJ_oonf[oo`00o`3oF`02ool00003oi;o0?oo003oo`00
00;oobP000?oogT0o`3oDoooN@000_ooN@001Ol0odkoogT0o`2Yoooonf[o0=Co00;ooo]Z00Kooh40
oookJ_oonf[ooo]Zool0;OoonfX3oiCo0004on/0oooo_P3oU?l0oiCo00;ooo]Z013ooi00onKo0?lH
0?oooo]ZofP0oooonf[o0?nBoookJ_oR0?oooo]Zo`3oAOmQ0?ooC@3oool0K?oo08Oo0?oN0_oonfX0
2onco`3oo`3MogT0oooo0`3ooo]Zo`3koooob@3o>ol0oom/0?oob@3o07Oo00;oolT000KoZ03oooo9
0?o[o`3ooo]Zool60?lH0?l2oookJP03ool0o?oonf[ooi8000Cooo]Z00?oo`3ZoookJ_oonfX02Ooo
nfX00ol0Looooo]ZoookJP07oookJP0:okWo0?ooDP3ooo]ZoookJ_l0:_oooo]Zocoo0?oonf[o0?mM
ogSo00Kooo]Z00?oiOl0oa80oooobP001?oonfX00ooUo`3oo`2CoookJP04oookJP03om[o0?oQo`3o
oo]Z00;ooo]Z00?o9P3oob3o0?oonfX03OoonfX00olao`3ooo]Zo`3oF`02oookJP05oh;o0?oonf[o
oo]Zo`3o/Ol0odd00_oonfX01?l60?oooo]ZonGo0?nBo`03oookJP03o`0Iool@0?oooo]Z00?ooo]Z
00Coo`1AoookJ_oonf[o0:go0_oonfX00ooo07Wooo]ZoookJP1;oookJP0:ool0nOoonf[o07Oooook
J_ooK03o0?nJoookJ_l0olcooh40oc_o00Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30003oookJP05
ogT0oooo0=gooo]Zok?o0?nO0?l01?oonfX00ooMo`3o0?oNool0Q`02oookJP07ool0K?oonf[ooo]Z
odd0oooo;P3ooo]Zof40o`04oookJP05on80ool0oi3ooo]ZoookJ_l0oi801_oonfX00omX0?oooo]Z
oookJP02oookJP05oaP0ool0M?oooo]ZoookJ_ooT0001ooonfX01Ooo_P3ooo]ZoookJ_m`0?ooj`3o
00Gooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@07oookJP03oon10?oonf[ooo]Z00Cooo]Z00Go0=Co
o`04oooonf[o0:Woo`28o`03oookJP03o`3oC_l0ocCooo]Z00?ooo]Z00Co0>7oo`3o7Ol0o`So0?mC
0ooonfX03_oo07Wo0:goool0DOlE0?oo01Wooa00oonBo`3o1P3oo`3oCOl0<?ooP_l0o`3o/?l0oe_o
<Ol01OoonfX01?lPo`3o9P3ooookJ_oJo`02oookJP04ool0Tooonf[oolX0o`3o6`;ooo]Z00GoN?l0
o`3Loooonf[ooe80okWo0003oookJP03o`1coooonf[ooo]Z00?ooo]Z01Koo`3ZoolF0?ooTP3oo`3l
oookJ_oo1P3ojol0ojP0ool0Mooooh40oc_o0?oo0`3oo`3Mok?o0?oo06coobh0of40ool0oi3o0?nB
ofP0oolH0?ooi_l00_oonfX04_oo_P3ooeL0oookJ_oo02gooo]Zo`3Doooonf[o00Coo`3oC_oonf[o
0?lMool0NOoonf[o403ooi;o0?l0003o0?mKoookJP?o9P3o3ooonfX00olV0?oo8?l0oookJP03oook
JP0:o`3oFol0<?ooT_l0oa00oooonf[oo`1Aool0NOoonf[o0?mCo`3o7@;ooo]Z00Go0?ldo`3oC_l0
ZOoooo]Zo`3Do`03oookJP04oon10?oonf[ooo]Zool0;@;ooo]Z00GooeL0oookJ_m`0?ooj`3ooonn
0003oookJP05oon@0?oVo`3o603ooookJ_mX0?l00_oonfX02Ol0oi;ohP3ooookJ_l0odGoH@3ooook
J_oo06cooo]Zool0Q`02oookJP0Cok?o0?nO0?ooo`3MoookJ_oo0`3o0?_ooookJ_lko`3ooh40oom/
0?l0Moooo`3ioookJ_nX0?oo0:Koool0m_o[o`3oo`H0oaP0o`02oookJP04ool0o?oonf[ooi80oolF
00?ooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ol0Looooo]ZoookJP08oookJP09o`3o<oooDP3ooo]Z
o`0Zoooonf[o?ol0oookJ_l0g?ooN?l000Kooo]Z00Co0?lKoookJ_lB0?ooolX00ooonfX00ol0nOoo
o`2CoookJP04oookJP03om[o0?oQo`3ooo]Z00;ooo]Z00?o9P3oob3o0?oonfX03OoonfX00olao`3o
oo]Zo`3oF`02oookJP06o`3o/?n2o`3ooo]Zo`3o/Ol0<?oo0?m=0_oonfX00ol60?oooo]Zoi;o0003
oookJP03ool0J_l@0?oooo]Z00?ooo]Z00Coo`1AoookJ_oonf[o0:go0_oonfX00ooo07Wooo]Zoook
JP0SoookJP00;?oonfX00ooo0?Wo07OoodCo0004odCo0003oookJ_oUo`3o>ol000Cooo]Z00GoU?l0
oookJ_oonf[ooo]Zool30002oookJP05ogT0oooo0=gooo]Zo`2Soonco`001OoonfX00ol0omkoo`27
oookJP02oookJP07ool0K?oonf[oC@3ooookJ_oUo`3ooo]Zof40o`03oookJP05on80oooonf[o0?n@
oookJ_l0oi801_oonfX00omX0?oooo]ZoookJP02oookJP03oaP0oooVo`3ooo]Z00;ooo]Z00?ooi00
oookJ_oonfX01OoonfX01?oo_P3ooo]Zo`3o1Oo[0?l5oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?o
o`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP04oookJP05o`3Dool01?oooo]Zo`2Yool0R?l0
0_oonfX00ol0odko0?ldoookJP02oookJPGoiOl000Ko0?mConGo0?oonf[oo`1io`2]oooo0542oook
JP05o`0Iool@0?ooT_l0oookJ_l0odd00ooUo`001?lao`3oiOl0onGo0?oUo`03oookJP09obH0oooo
nf[ohOl0om[o0?oo01?oo`2CoookJ_oobP3o0?lK00;ooo]Z00GoN?l0o`3Lool0:_oooo]ZoomB0004
oookJP03o`1coooonf[ooo]Z00;ooo]Z00koo`3Zoomi0?ooN@3oo`3loomi0?oo1P3ojol0ool00?oo
0?Wo07Oooc_o0?oo003oo`3MonGo00?oogT000[oo`00o`3oT?oo:03oJ03ooaP0oooo:03ookh0og00
ooooE`3oogT00ooonfX00ol0e?ooobP0o`3oCP04oolX0006oiCo0?nBo`3o0?mKool00?oo:03o9P3o
1_oo0004oolX00WoolT000?o9P3oob3o0?ooN@000_ooN@000ol0oe_oo`00ool00006oomi0008o`3o
DoooN@3oogT0oomi0?l0odkooo]Zo`2Yool0e?l3oookJP05oon10?oonf[ooo]ZoookJ_oo02d00onD
o`001?o[0?oookh0oiCo0?nDo`02oookJP05oon@0?oVo`3o603ooookJ_mX0?l00_oonfX02Ol0oi;o
0?n@on80ool0odGoH@3oodd0oooo06cooo]Zool0Q`02oookJP0;ok?o0?oo0=goN@3oool30?oonf[o
0?_oooo90?lko`3oof`0ooo90?l0Mol00_oob@001_nX0?ooolT0on_o0?oonf[oo`H0oaP0o`;ooo]Z
00Coo`3loookJ_ooTP3ooaH00ooonfX00ooo0>[ooo]ZoookJP09oookJP03o`1coooonf[ooo]Z00Oo
oo]Z00[o^Ol0oomB0?oonf[ooo]Zo`0Zoooonf[o?ol0oookJ_l0oegoN?l01_oonfX00ooUo`3o4P3o
ooo:0004oookJP03onGo0?oo09?ooo]Z00Cooo]Z00?of_l0on7o0?oonfX00_oonfX00om4o`3o8?l0
oookJP0=oookJP03oc7o0?oonf[o0?mK00;ooo]Z00_oP_l0oookJ_l0ok7ooo]Zo`3oCOl0j?oooo]Z
o`H0oooonf[oiOl0oi;o0003oookJP03o`0Iool@0?oooo]Z00?ooo]Z00Coo`1AoookJ_oonf[o0:go
0_oonfX00ooo07Wooo]ZoookJP1;oookJP0:ool0nOoonf[o07OooookJ_ooK03o0?nJo`3oc?oonf[o
oh40oc_o00Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30003oookJP04ogT0oooo0=go0:?ook?o00Go
oo]Z00?o0?oNoookJ_oo08L00_oonfX01ooo06cooo]ZoookJ_m=0?ooobh0oookJ_mQ0?l01?oonfX0
1OoR0?oo0?n@oookJ_oonf[o0?nB00Kooo]Z00KoJ03ooookJ_oonf[ooo]ZoaP0oooVo`03oookJP03
oon@0?oonf[ooo]Z00Gooo]Z00Cookh0oookJ_oonf[oj`3o1_oonfX01OooE`3ooo]ZoookJ_oonf[o
o`0]00Oooo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0e?oo00CooookJ_l0ZOoo08So00?ooo]Z00?o
0?m>o`3o=?oonfX00ooonfX01?l0hOoo0?lMo`3o2?l0oe<3oookJP0>ool0NOl0[Oooo`1AoookJ_l0
6Ooo403ooi;o0?l60?oo0?m=o`0`oon2o`3ooo]Zo`3oFolao`05oookJP0:ob3o0?lV0?oohOl0om[o
0?oonf[oo`2Co`3ioooonf[oolX0o`3o6`;ooo]Z00GoN?l0o`3Lool0:_oooe80okWo0003oookJP03
o`1coooonf[ooo]Z00;ooo]Z01Koo`3ZoookJ_oo5P3ooi80ool0o?lH0?ooo`H0ojP0oooo0?Wo07Oo
oc_o0?l0noooo`<0ok?o0?l0omkoo`1/of40oooonf[o0?n@oookJ_mX0?oo603o0_oonfX01?oo_P3o
oo]ZoomG0?oo02d2oookJP0=o`3Dool01?oo0?ldo`3oC_l0oagoo`1ioookJ_l@0?ooT_l0o`000?l0
oe_o0000obH0o`05oookJPWo4P3o1OoonfX00olV0?oo8?l0oookJP03oookJP0:o`3oFol0<?ooT_l0
oa00oooonf[oo`1Aool0NOoonf[o0?mCo`3o7@;ooo]Z00Co0?ldo`3oC_l0ZOoo0=Co0ooonfX02ooo
P@3ooo]ZoookJ_oonf[oo`0]oookJ_ooE`3ooo]Zog00ooo[0?oookh000?ooo]Z00Gooi00onKo0?lH
0?oooo]ZofP0o`02oookJP09o`3oT_oonf[ohP3oo`3oAOmQ0?ooobh0ool0K?oonf[oo`2700;ooo]Z
01?o/ol0oil0oooo0=gooo]Zool30?l0nooooo]Zoc_o0?ooP@3oof`0o`1goooo0?Wooo]ZojP0ool0
Y_ooo`3fon_o0?oo1P3o603o00;ooo]Z00Goo`3loookJ_ooTP3ooo]ZoolF0002oookJP03ool0j_oo
nf[ooo]Z00Wooo]Z00?o07?ooookJ_oonfX02?oonfX02Ol0oc?ooe80oookJ_l0:_oooo]Zocoo0?oo
nf[o0=coogSo0006oookJP04o`3o6ooonf[o4P3oooo:00?ooo]Z00?o0?Woool0TooonfX01?oonfX0
0ooJo`3ohOl0oookJP02oookJP03obH0oolPo`3ooo]Z00gooo]Z00?o<Ol0oookJ_l0oe/00ooonfX0
1On2o`3o0?naoookJ_l0<?oo0?m=00;ooo]Z00?o1P3ooookJ_nBo`000ooonfX00ooo06[o403ooook
JP03oookJP04ool0DOoonf[ooo]Zo`2]o`;ooo]Z00?oo`1ioookJ_oonfX08ooonfX002_ooo]Z00?o
o`3ioookJ_l0Mol01Om4o`000ooUo`3o>ol0oookJP04oookJP04oiCo0?oonf[ooo]Zool300?ooo]Z
00CoN@3oool0gOoonf[o/ol01_oonfX01Ol0omkoo`27oookJ_oonf[oo`1/00;ooo]Z00GoC@3oonGo
0?oonf[oH@3oo`3oA@03oookJP05on80oooonf[o0?n@oookJ_l0oi801_oonfX00omX0?oooo]Zoook
JP02oookJP05oaP0oooVo`3ooo]ZoookJ_ooT0002?oonfX01?oo_P3ooo]Zo`3o1Oo[0?l5oookJP03
oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP04oookJP04
o`3Dool01?oooo]Zo`2Yo`?ooo]Z00Co0?m>o`3o=?oonf[ooo]Z1OoUo`004_l0oe?oiOl0onGo0?oo
nf[oo`1io`2]oooo057ooo]Zool0J_l@0?ooo`3eoi;o0?oonf[o0?m=oh;o0?oonf[oiOl0oc7o00?o
iOl00ooonfX02OlV0?oooo]Zom[o0?oonf[oo`0Cool0Tooonf[oolX0o`3o6`02oookJP04ogSo0?l0
g?oo02[ooomB00Gooo]Z00Go07?ooookJ_oonf[ooo]Zool0jP03oomi0003ool0o?ooN@3oo`3f00;o
o`0000Ko07Ooool00?lko`3oo`00ool0gOoUo`03oomi0004o`3oT?l0oi;oobP0oaP0o`;oobP000Co
okh0og00ooooE`3oogT00_oonfX00ol0e?ooobP0o`3oCP04oolX0003oi;o0?oo:03oobP000;oobP0
00?o9P3ooolX0?oo00001ooo0002oolX00WoolT000?oogT0obH0oolPo`002oooN@002Ol0oe?oogT0
oomi0?ooN@3o0?m>oookJ_l0ZOoo00Coo`3Do`02oookJP05oon10?oonf[ooo]ZoookJ_oo02d00onD
o`001?o[0?ooU?l0oonn0?nDo`02oookJP05oon@0?l0M?oo603ooookJ_mX0?l00_oonfX02Ol0oi;o
0?n@on80oooonf[oH@3oodd0oooo06cooo]Zool0Q`02oookJP0;ok?o0?oo0=goN@3oool30?oonf[o
0?_oooo90?lko`3ooh40oom/0?l0Mol00_oob@001_nX0?ooolT0on_o0?oonf[oo`H0oaP0o`;ooo]Z
00Coo`3loookJ_ooTP3ooaH00ooonfX00ooo0>[ooo]ZoookJP09oookJP03o`1coooonf[ooo]Z00Oo
oo]Z00_o^Ol0oomB0?oonf[ooo]Zo`0Zoooonf[o?ol0oookJ_l0oegoN?l0ocd0o`05oookJP03onGo
0?lB0?ooolX000Cooo]Z00?oiOl0ool0TooonfX01?oonfX00ooJo`3ohOl0oookJP02oookJP03odCo
0?lPo`3ooo]Z00gooo]Z00?o<Ol0oookJ_l0oe/00_oonfX02on2o`3ooo]Zo`3o/Ooonf[o0?m=o`3X
oooonf[o1P3ooookJ_oUo`3oT_l000?ooo]Z00?o01Wooa00oooonfX00ooonfX01?oo057ooo]Zoook
J_l0[Ol2oookJP03ool0NOoonf[ooo]Z04_ooo]Z00[oo`3ioookJ_l0Mooooo]Zoom/0?l0oi[o0?o<
oon10?oonf[o>ol01?oonfX01?l0nooooo]ZoookJ_oo0`04oookJP04ool0gOoonf[o0:?ook?o00Go
oo]Z00?o0?oNool0QooonfX00_oonfX01ooo06cooo]ZoookJ_m=0?ooobh0of40ool0odD00ooonfX0
0ooR0?oooo]Zo`3oT002oookJP03o`3oT_oonf[ooo]Z00Cooo]Z00KoJ03ooookJ_oonf[ooo]ZoaP0
oooVo`02oookJP03oon@0?oonf[ooo]Z00Kooo]Z00Cookh0oookJ_oonf[oj`3o1_oonfX01OooE`3o
oo]ZoookJ_oonf[oo`0]00Oooo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0e?oo00CooookJ_l0ZOoo
08So00;ooo]Z00?o0?m>o`3o=?oonfX01?oonfX00ol0hOoo0?lMo`3oD`04oookJP0>ool0NOl0[Ooo
o`1Aool0J_l@0?ooo`3eoi;o0?oonf[o0?m=o`0`oon2o`3ooo]Zo`3oFolao`05oookJP03ob3o0?lV
0?oof_l000;ooo]Z00_oo`2Co`3ioooobP3o4P3oo`3o6ooonf[o0?oOogSo0?loo`3ooe80o`3o<`04
oookJP03o`1coooonf[ooo]Z00;ooo]Z01Koo`3ZoookJ_ooTP3oo`3loookJ_oo1P3ojol0ojP0ool0
Mooooh40oc_o0?oo0`3oN@3ook?o0?l0omkoo`1/of40ool0oi3o0?nBofP0oolH0?ooi_l00_oonfX0
4_oo_P3ooeL0oookJ_oo02gooo]Zo`3Dool01?oo0?ldo`3oC_l0oagoo`1ioookJ_l@0?ooT_l0o`00
0?l0oe_o0000obH0o`?ooo]Z0olB0?l8o`3Lo`03oookJ_lB0?oo4P3o00Cooo]Z00?o9P3oob3o0?oo
nfX00ooonfX00ol0oe_ooo]Zoi;o0002oookJP0;ool0DOoonf[o0?mCo`3o7Ol0hOoooo]Zo`3o=?l0
odko0:Woo`04ool0e?l00ooonfX01_ooP@3ooo]ZoookJ_oo02gooo]ZoomG00;ooo]Z00?oj`3ooonn
0?oonfX00_oonfX01OooT03o07CooaP0oooonf[oJ03o00;ooo]Z00Wo0?nBoookJ_oR0?oooo]Zof40
oooo;P3oo`1/oookJ_oo08L00_oonfX04onco`3oW`3oool0gOoonf[oo`<0o`3koooonf[o>ol0oon1
0?ooK03o07Ooool0nOoonf[oZ03oo`2Voooo0?Kojol0ool60?lH0?l00_oonfX01Ooo0?cooo]ZoonB
0?oonf[ooaH000;ooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ol0Looooo]ZoookJP08oookJP0:o`3o
<oooDP3ooo]Zo`0Zoooonf[o?ol0oookJ_l0g?ooN?l0ocd0o`Gooo]Z00Co0?lKoookJ_lB0?ooolX0
0ooonfX00ol0nOooo`2CoookJP04oookJP03om[o0?oQo`3ooo]Z00;ooo]Z00?o9P3oob3o0?oonfX0
3OoonfX00olao`3ooo]Zo`3oF`03oookJP05oh;o0?l0ok7ooo]Zo`0`ool0odd00_oonfX00ol60?oo
oo]Zoi;o0003oookJP03ool0J_l@0?oooo]Z00?ooo]Z00Coo`1AoookJ_oonf[o0:go0_oonfX00ooo
07Wooo]ZoookJP0SoookJP00:ooonfX00ooo0?Wooo]Zo`1go`05odCo0003onGo0?lko`3ooo]Z00Co
oo]Z00CoU?l0oookJ_oonf[oo`<00ooonfX01?mi0?ooo`3MoookJ_nco`05oookJP03o`3og_oMo`3o
o`2700;ooo]Z00Soo`1/oookJ_oonf[oC@3oonGo0?oonf[oH@3oo`3oA@;ooo]Z00KohP3ooookJ_oo
nf[o0?n@oookJ_l0oi86oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603oonKo0?oonf[ooo]Zoon@
0008oookJP04oonn0?oonf[o0?l5on/0o`Gooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]Z
oookJP05oookJP03oon10?oonf[ooo]Z00Cooo]Z00Co0=Coo`04ool0ZOoo08So0_oonfX00ol0obko
0?m>o`3o=004oookJP04o`3QoooUo`3oiOl0o`3oD`;oiOl000kooo]Zool0NOoo057o5@3ooookJ_oo
06[o403oool0mOnBo`3ooo]Zo`3oCOn2o`3ooo]Zoc7o00;ooo]Z0_oUo`03oookJP0?obH0oooonf[o
f_l0oookJ_oo01?oo`2CoookJ_oobP3o0?lKoookJ_lm0?ooN?l0o`3Lool0:_oooe8000Cooo]Z00?o
07?ooookJ_oonfX00_oonfX01_oo0>[oogT0oomi0?ooN@3oo`3loomi00;oo`0000Goo`3io`1goolk
o`3oo`00ool0g@02onGo00;oogT000Woo`00o`3oT?oo:03oobP0oaP0oooo:03ookh0og00ooooE`00
0_ooN@001?oonf[oobP0o`3Dool0odh4oolX0003oi;o0?oo:03oobP000;oobP000?o9P3ooolX0?oo
00001_oo0004oomB0003oolX0?oob@3oolT000KoolT00_ooN@000olV0?ooo`00oomi000:oomi0008
o`3oDoooN@3oogT0oomi0?l0odko08Soo`2Yool0e?l2oookJP06oon10?oonf[ooo]ZoookJ_oo02go
oo]Z0_nDo`001?o[0?ooU?l0oonn0?nDo`03oookJP04oon@0?oVo`3o603oofP0o`;ooo]Z00Wo0?nB
o`3oT?oR0?oooo]Zof40oom=0?oooo]Zool0K?oo08L00_oonfX02?nco`3oo`3MogT0oooo0`3ooo]Z
o`3koooonf[o>ol00_oob@000ol0MoooolT0ooo90003ooo90003oookJ_oo1P3o603o00;ooo]Z00Co
o`3loookJ_ooTP3ooaH00ooonfX00ooo0>[ooo]ZoookJP09oookJP03o`1coooonf[ooo]Z00Oooo]Z
00_o^Ol0oomB0?oonf[ooo]Zo`0Zoooonf[o?ol0oookJ_l0oegoN?l0ocd0o`05oookJP03onGo0?lB
0?ooolX000Cooo]Z00?oiOl0ool0TooonfX01?oonfX00ooJo`3ohOl0oookJP02oookJP03odCo0?lP
o`3ooo]Z00gooo]Z00?o<Ol0oookJ_l0oe/00_oonfX02on2o`3ooo]Zo`3o/Ooonf[o0?m=o`3Xoooo
nf[o1P3ooookJ_oUo`3oT_l000?ooo]Z00?o403ooookJ_oonfX00ooonfX01?oo057ooo]ZoookJ_l0
[Ol2oookJP03ool0NOoonf[ooo]Z04[ooo]Z00?oo`3ioookJ_l0Mol00_oonfX01OooK03o0?nJo`3o
c?ooP@3o>ol000Gooo]Z00Co0?_ooookJ_oonf[oo`<00ooonfX01Omi0?ooo`3MoookJ_l0Xooo/ol0
00Gooo]Z00?o0?oNool0QooonfX00_oonfX01ooo06cooo]ZoookJ_m=0?oooo]Zof40ool0odD00ooo
nfX00ooR0?oooo]Zo`3oT002oookJP03o`3oT_oonf[ooo]Z00?ooo]Z00?oJ03ooookJ_oonfX00_oo
nfX01OlH0?ooi_l0oookJ_oonf[ooi0000Sooo]Z00Cookh0oookJ_oonf[oj`3o1OoonfX00oooE`3o
oo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0e?oo
00Coo`2Yoooonf[o08So00;ooo]Z00?o0?m>o`3o=?oonfX01?oonfX00ol0hOoo0?lMo`3oD`04oook
JP0=ool0NOoo057o5@3oool0J_l@0?ooo`3eoi;o0?oonf[o0?m=o`0`oon2o`3o0?mKoc7o0006oook
JP03ob3o0?lV0?oof_l000;ooo]Z00Coo`2CoookJ_oobP3o0?lK0_oonfX01Omho`3o0=cooookJ_oo
DP3o0?lc00?ooo]Z00?o07?ooookJ_oonfX00ooonfX05Ooo0>[ooaH0oonB0?oo0?cooo]Zool60?oo
0?Koo`3io`1goolko`3o0?_oool30?nco`3o0:?oool0K?mQ0?oooo]Zo`3oT?oonf[oJ03ooaP0o`02
oookJP04oonn0?oonf[ooeL0ool0;@;ooo]Z00ko0=Coo`04ool0odko0?lMool0NOoonf[o403ooi;o
0?oonf[o0?mKo`000?lV0?oo0000oookJP;o4P3o00Co0=coo`3o<ol0oc?o0?lc1OooDP02o`0Zo`;o
0=co00?ooo]Zoa80oooonfX00ooonfX00olV0?oo8?l0oookJP02oookJP0:o`3oFol0<?ooT_l0o`H0
oooonf[oo`1Aool0NOoonf[o0?mCo`3o7@;ooo]Z00Co0?ldo`3oC_l0ZOoo0=Co0ooonfX01?ooP@3o
oo]ZoookJ_oo02d2oookJP04oomG0?oonf[oj`3ooonn00Cooo]Z00Cooi00onKo0?lH0?ooJ03o0_oo
nfX02Ol0oi;ooo]Zon80oooonf[o0?m5of40oom=0?ooo`1/ool0Q`02oookJP0Cok?o0?l0Xoooo`3M
oookJ_oo0`3ooo]Zo`3koolko`3ooh40o`3oV_l0Moooo`3ioookJ_nX0?oo0:Koool0m_o[o`3oo`H0
oaP0o`02oookJP05ool0o?oonf[ooi80oookJ_oo5P000_oonfX00ooo0>[ooo]ZoookJP09oookJP03
o`1coooonf[ooo]Z00Sooo]Z00[o0?lcoomB0?oonf[o02[ooookJ_loo`3ooo]Zo`3Loomho`3o?@3o
1OoonfX01?l0S_oo0?lKoa80oooobP03oookJP03o`3ioooo09?ooo]Z00Cooo]Z00?of_l0on7o0?oo
nfX00_oonfX00olV0?oo8?l0oookJP0=oookJP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00GoP_l0o`3o
/Ooonf[o033oo`3oC@02oookJP03o`H0oooonf[oT_l000?ooo]Z00?oo`1Zoa00oooonfX00ooonfX0
1?oo057ooo]ZoookJ_l0[Ol2oookJP03ool0NOoonf[ooo]Z02?ooo]Z000[oookJP03ool0nOl0Mooo
A?l000GoA?l000?oiOl0oc_o0?oonfX00ooonfX01OnDo`3ooo]ZoookJ_oonf[oo`<000;ooo]Z00Go
N@3ooookJ_oo0=gooo]Zok?o0005oookJP03o`3og_oMo`3oo`2700;ooo]Z00Soo`1/oookJ_oonf[o
C@3oonGo0?oonf[oH@3oo`3oA@;ooo]Z00?ohP3ooookJ_l0oi000_oonfX00ol0oi;ooo]ZoookJP04
oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603ooookJ_oonf[ooo]Zoon@0008oookJP04oonn0?oo
nf[o0?l5on/0o`Gooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP04oookJP03oon1
0?oonf[ooo]Z00Cooo]Z00Go0=Coo`04oooonf[o0:Woo`28o`02oookJP03o`3o;_l0odkooo]Z00Co
oo]Z00Co0>7oonGo0?oonf[o0?mC0_oUo`003_oo07Wo0:goool0DOlE0?oooo]Zo`0Iool@0?ooT_l0
o`H0ool0odgo033ooh;o0?oonf[o<Ol01_oonfX04?n40?oo9P3ooookJ_oJo`3ooo]Zool04ooo09?o
olX0o`3o6ooUo`3ooo]ZogSo0?l0g?oo?ol0o`0ZooooDP04oookJP06o`1coooonf[ooo]ZoookJ_oo
N@3oo`3Z0_ooN@000ooo0?coogT0oomi0002ool00004o`1goooo003o>ol0ool000?oiOl00_ooN@00
1?l0oi3o0?nBoolX0?lH0?l2oolX0004oonn0?oo:03ooeL0oomi00;oobP000?o0=CooolX0?l0odh0
2?oo:0000olV0?ooobP0ool00003ool000Cooe8000CoogT0oolX0?oo:03oobP00_ooDP05ooo900Go
o`0000?o9P3oool00?ooN@002OooN@002?l0oe?oogT0oomi0?ooN@3o0?m>oookJ_l0ZOoo0=Co0ooo
nfX01OooP@3ooo]ZoookJ_oo02gooo]Z00?oU?l000?oj`3ooonn0?nDo`000ooonfX01?ooT03oi_l0
oaP0oomX0?l2oookJP09o`3oT_l0oi3ohP3ooookJ_mQ0?ooC@3ooookJ_oo06coo`2700;ooo]Z00So
/ol0ool0gOmi0?ooo`<0oookJ_l0nooooo]Zoc_o00;oolT000?o07Ooooo90?oob@000ooob@000ooo
nf[oo`H0oaP0o`02oookJP04ool0o?oonf[ooo]ZoonB00?ooo]Z00?oo`3ZoookJ_oonfX02_oonfX0
0ol0Looooo]ZoookJP06oookJP0;okWo0?ooDP3ooo]ZoookJ_l0:_oooo]Zocoo0?oonf[o0?mMogSo
0?lm0?l01OoonfX00ooUo`3o4P3oooo:0004oookJP03onGo0?oo09?ooo]Z00Cooo]Z00?of_l0on7o
0?oonfX00_oonfX00om4o`3o8?l0oookJP0=oookJP03oc7o0?oonf[o0?mK00;ooo]Z00_oP_l0oook
J_l0ok7ooo]Zo`3oCOl0j?oooo]Zo`H0oooonf[oiOl0oi;o0003oookJP03oa00ool06Ooooo]Z00?o
oo]Z00Coo`1AoookJ_oonf[o0:go0_oonfX00ooo07Wooo]ZoookJP1:oookJP03ool0nOoonf[o07Oo
00;ooo]Z00Goof`0oookJ_l0olcooh40oc_o0004oookJP05o`3koooonf[ooo]ZoookJ_oo0`000ooo
nfX01Omi0?ooo`3MoookJ_l0Xooo/ol000Gooo]Z00?o0?oNool0QooonfX00_oonfX01ooo06cooo]Z
oookJ_m=0?oooo]Zof40ool0odD00ooonfX00ooR0?oo0?n@oookJP02oookJP03o`3oT_oonf[ooo]Z
00?ooo]Z00?oJ03ooookJ_oonfX00_oonfX01OlH0?ooi_l0oookJ_oonf[ooi0000Sooo]Z00Cookh0
oookJ_l0o`Goj`3o1OoonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Cooo]Z00?o
oh40oookJ_oonfX01?oonfX01_l0e?oo00CooookJ_l0ZOoooo]Zo`28o`;ooo]Z00?o0?m>o`3o=?oo
nfX00ooonfX01?l0hOoo0?lMo`3o2?l0oe<3oookJP0>ool0NOl0[Oooo`1AoaD0ool06Ooo403ooi;o
0?l60?oo0?m=oookJ_l0ok3oP_l0o`3oFolao`05oookJP04oh@0oolV0?oooo]Zom[o00;ooo]Z00Co
o`2CoookJ_oobP3o0?lK0_oonfX01Omho`3o0=coo`0ZooooDP3o^Ol000?ooo]Z00?o07?ooookJ_oo
nfX00_oonfX06ooo0>[ooo]ZoolF0?ooTP3oo`3loaP0oooo1P3oZ03oo`1gooooP@3o>ol0ool30?mi
0?oo/ol0o`3og_oo06coH@3oo`3oT?l0oi;oJ03ooookJ_lH0?oooo]Zoonn0?m`0?oooeL0ool0;@02
oookJP0=o`3Dool01?oo0?m>oookJ_l0oagoo`1ioa00oonBo`3ooo]Zo`3oFol0003o9P3oo`000002
oa80o`;o0=co1?ooDP05oookJP?ooe8000Co02[oo`3Loooonf[o4P3o1?oonfX00olV0?oooo]Zoook
JP02oookJP0?o`3oFooonf[oT_l0oa00oooonf[oo`1AoookJ_l0oe?o0?lMo`3Qoooonf[o0?ldo`3o
C_l0ZOoo0=Co00?ooo]Z00Cooh40oookJ_oonf[oo`0]0_oonfX01?ooE`3ooo]Zog00ooo[0?l4oook
JP04oon@0?oVo`3o603oofP0o`;ooo]Z01ko0?nBoookJ_oR0?oooo]Zo`3oAOmQ0?ooC@3oool0K?oo
08OogOl0oookJ_nco`3o0:?oool0gOoonf[oo`<0oookJ_l0nooo>ol0oon10?l0oi[o07Ooool0nOoo
nf[oZ03oo`2Voooo0?Kojol0ool60?lH0?l2oookJP05ool0o?oonf[ooo]ZoonB0?oo5P000_oonfX0
0ooo0>[ooo]ZoookJP0:oookJP03o`1coooonf[ooo]Z00Oooo]Z00[o0?lcoomB0?oonf[o02[ooook
J_loo`3ooo]Zo`3Loomho`3o?@3o1OoonfX01?l0S_oo0?lKoa80oooobP03oookJP03o`3ioooo09?o
oo]Z00Cooo]Z00?of_l0on7o0?oonfX00_oonfX00olV0?oo8?l0oookJP0=oookJP04oc7o0?oonf[o
oo]Zo`3oF`;ooo]Z00[oP_l0o`3o/Ooonf[o033oo`3oCOl0j?oooo]Zo`H0oooonf[oT_l00ooonfX0
0ol@0?oooo]Zo`0Io`03oookJP04ool0DOoonf[ooo]Zo`2]o`;ooo]Z00?oo`1ioookJ_oonfX08ooo
nfX002Sooo]Z0ol007l00ooo0?Wo07OoodCo0005odCo0004onGo0?lko`3o001oo`00O`;ooo]Z00Go
U?l0oookJ_oonf[ooo]Zool30002oookJP05ogT0oooonf[oo`3Mo`2Soonco`001OoonfX00ol0omko
gOl0ool0Q`02oookJP08ool0K?oonf[oC@3ooookJ_oUo`3ooo]Zof40ool0odD2oookJP03on80oooo
nf[o0?n@00;ooo]Z00?o0?nBoookJ_oonfX01?oonfX00omX0?oooo]ZoookJP02oookJP05oaP0oooo
nf[ooo]ZoookJ_ooT0000ooonfX3o`00O`;ooo]Z00Cookh0o`3o1Ol007ooj`3o0ol007l2oookJP03
oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3ooo]ZoookJP04oookJP05
o`3Dool01?oooo]Zo`2Yool0R?l00_oonfX00ol0odko0?ldoookJP04oookJP04o`3QoooUo`3ooo]Z
o`3oD`;ooo]Z00?oo`1io`2]oooo05400_oonfX02Ol06Ooo403ooi;o0?l60?oo0?m=oh;o0?oonf[o
iOl0oc7o0006o`00O`0@obH0oooonf[of_l0on7o0?oo01?oo`2Co`00OooobP3o0?lKonGo0?oonf[o
N?l0o`3Loooonf[o02[ooomB00Cooo]Z00?o07?ooookJ_oonfX00_ooN@001?oo0>[oogT0oomi0?oo
0?`2oomi0005ool00?oo0?Wo07Oooc_o0?oo00001?oUo`02oomi0009o`3oT?oo:03oobP0oaP0oooo
:03o0?l5oonn0?oo:03oogT000;oobP000?o0=CooolX0?l0odh01ooo:002obH0o`;oobP000Coo`00
oomB0?ooDP3ooe801OooN@05oookJP03onGo0?oob@3oolT000;oolT01Ooo00000olV0?ooo`00oomi
0007oomi00?oobP00oooN@001Ol0odkooo]Zo`2Yool01?oo0=Co00;ooo]Z00Kooh40oookJ_oonf[o
oo]Zool0;OoonfX2oiCo0004on/0oooo_P3oU?l0oookJP;o001o00Cooi00onKo0?lH0?ooJ03o0_l0
07l04ol0oi;ooo]Zon80oooonf[oH@3oodd0ool007ooo`1/ool0Qol0omkooo]Zok?o0?oo0=goN@3o
ool30?oonf[o0?_ooookJ_lko`000_oob@000ol0MoooolT0ooo90003ooo90003oookJ_oo1P3o603o
00;ooo]Z00Coo`3loookJ_oonf[ooi800ooonfX00ooo0>[ooo]ZoookJP0:oookJP03o`1coooonf[o
oo]Z00Kooo]Z00_o^Ol0oomB0?nDo`3ooo]Zo`0Zoooonf[o?ol0o`00Ool0oegoN?l0ocd0o`03oook
JP;o001o00?oiOl0oa80oooobP001?oonfX00ooUo`3oo`2CoookJP04oookJP03om[o0?oQo`3ooo]Z
00;ooo]Z00?oA?l0ob3o0?oonfX03OoonfX04?lao`3ooo]ZoookJ_l0oe_ooo]Zoh;o0?oonf[o0?na
o`0`ool0odgo0>SooookJ_l60?oooo]ZonGo0?nBo`03oookJP04oa00ool06Ooooo]ZoookJP;o001o
00Coo`1Ao`00Ool007oo0:go0_oonfX00ooo07Wooo]Zo`00O`04o`00OdCooo]Z0_l007l00ooo0?Wo
001oo`1go`02oookJP05oom/0?oonf[o0?o<oon10?lko`000ol007l00ooonf[o0?_ooookJP02oook
JP09ool30?oonf[ooo]ZoookJ_mi0?ooo`3MoookJ_l0Xooo/ol000Gooo]Z00Go0?oNool0Qooonf[o
oo]Zool0K002oookJP05odd0oooo;P3ooo]Zof40ool0odD00ooonfX01OoR0?oo0?n@oookJ_oonf[o
0?nB00Kooo]Z00?oJ03ooookJ_oonfX00_oonfX01OlH0?ooi_l0oookJ_oonf[ooi0000?ooo]Z0ol0
07l2oookJP04oonn0?oonf[o0?l5on/0o`?o001o0_oonfX00oooE`3ooo]ZoookJP02oookJP03ool0
;Ooonf[ooo]Z00Cooo]Z00?ooh40oookJ_oonfX01?oonfX02_l0e?oo00CooookJ_l0ZOoooo]Zo`28
oooonf[o0?m>o`3o;_l0oc@4oookJP04o`3Qool0oagooo]Zo`3oD`?ooo]Z00koo`1io`2]oooo057o
oo]Zo`0Iool@0?ooT_l0o`H0ool0odgo033ooh;o0?l007oo0?mKoc7o00Go001o00[o8?l0obH0oooJ
o`3ohOl0o`00Oooo09?o0?Woo`00OooobP3o0?lK0_oonfX01?mho`3o?ol0o`0ZooooDP04oookJP03
o`1coooonf[ooo]Z00;ooo]Z02coo`3ZoookJ_ooTP3oo`3loookJ_oo1P3ojol0ool0nOl0Mooo>ol0
o`3koooo0`3oo`3Mok?o0?l0omkoo`1/odd0ool0oi3ooo]ZofP0oolH0?oooi00oookJ_oo_P3oL03o
oookJ_oo02gooo]Zo`3Dool0R?oo0?m>oookJ_l0oagoo`1ioa00oonBo`3ooo]Zo`3oFolPo`3o9P3o
o`000?lB0?oo0000o`3Lo`;ooe803?oonfX01OooDP3o02[oo`3Loooonf[o4P3o00?ooo]Z00?o9P3o
ob3o0?oonfX00_oonfX04?l0oe_o033oo`H0oonBo`3ooo]Zool0DOoo07Wo0?mCo`3o7Ol0hOoooo]Z
o`3o=?l0odko0:Woo`04ool0e?l2oookJP0;oon10?oonf[ooo]ZoookJ_oo02gooo]ZoomG0?oonf[o
L03oon/0oooo_P000_oonfX01_l007oooi00onKo0?lH0?oo001oofP0o`;o001o01go0?nBon80oooo
nf[o0?m5of40oom=0?ooo`1/ool0Qol0omkooo]Zok?o0?l0Xoooo`3MoookJ_oo0`3ooo]Zo`3koolk
o`3ooh40o`3oV_l0Moooo`3ioookJ_nX0?oooo]Zo`2Vooo[o`3oo`H0oaP0o`02oookJP05ool0o?oo
nf[ooo]ZoonB0?oo5P000_oonfX00ooo0>[ooo]ZoookJP0:oookJP03o`1coooonf[ooo]Z00Oooo]Z
00[o^Ol0oomB0?oonf[o02[ooookJ_loo`3o001oo`3Loomho`3o?@3o0ooonfX2o`00O`04o`2>ool0
oa_o4P3oooo:00?ooo]Z00?o0?Woool0TooonfX01?oonfX00ooJo`3ohOl0oookJP02oookJP03obH0
oolPo`3ooo]Z00gooo]Z00Co<Ol0oookJ_oonf[o0?mK0_oonfX01on2o`3o0?naoookJ_l0<?oo0?m=
o`3Xool60?l00_oonfX01onBo`3ooo]ZoookJ_oonf[o403ooookJ_l06Ol00_oonfX01Ol007ooo`1A
oaD0ool007oo0:go00;ooo]Z00?oo`1ioookJ_oonfX01Ol007lNoookJP009ooonfX4o`00O`03ool0
nOl0MoooA?l000GoA?l000?oiOl0oc_o0?l007l00_l007l00ooonf[oU?l0oookJP02oookJP08ool3
0?oonf[ooo]ZogT0oooo0=gooo]Zo`2Soonco`05oookJP03o`3og_oMo`3oo`2700;ooo]Z00Soo`1/
oookJ_m=0?oooo]ZonGo0?oonf[oH@3oo`3oA@;ooo]Z00?ohP3ooookJ_l0oi000_oonfX00ol0oi;o
oo]ZoookJP04oookJP06ofP0oooonf[ooo]ZoookJ_lH0?ooi_l00ooonfX01?ooT03ooo]ZoookJ_oo
nfX3o`00O`;ooo]Z00Cookh0o`3o1Om`0?ooj`3o1?l007l00oooE`3ooo]ZoookJP02oookJP03ool0
;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0e?oo00CooookJ_l0ZOoo08So00;o
oo]Z00?o0?m>o`3o=?oonfX01?oonfX01?l0hOooiOl0oookJ_l0oe<2oookJP03ool0NOl0[Oooo`1A
00;ooo]Z00So403ooookJ_nBo`3ooo]Zo`3oCOn2o`3ooo]Zoc7o00Oo001o013o9P3ooookJ_oJo`3o
001oool04ooo09?oiOl0ooo:0?l0oa_oiOl0oookJ_mho`3o0=coo`0ZooooDP3o^Ol00ooonfX00ol0
Looooo]ZoookJP02oomi0005ool0j_ooN@3oogT0oomi0?oo0?`00_ooN@001Ooo003oo`3io`1goolk
o`3oo`0000?oiOl00oooN@002?l0oi3oobP0oaP0ooooT03oobP0oonn0?oo:03ooeL00ooo:0000ol0
e?oo0?m>oolX000;oolX0003oomB0?ooN@3oogT000KoogT000?ooo]ZonGo0?oUo`001?oUo`09ool0
0003obH0oooo003oogT000KoogT00ooo:0002?l0oe?oogT0oomi0?l0odko0?ldo`2Yoooonf[o0=Co
0_oonfX01_ooP@3ooo]ZoookJ_oonf[oo`0]oookJP;oU?l000Coj`3ooonn0?oonf[ooo]Z0_l007l0
1?ooT03oi_l0oaP0oomX0?l2o`00O`0Co`3oT_oonf[ohP3oo`00OomQ0?ooC@3oo`00Oooo06coo`27
o`3og_oonf[o/ol0ool0gOmi0?ooo`<0oookJ_l0nooooo]Zoc_o0002ooo90003o`1goooob@3oolT0
00;oolT000Cojol0oookJ_oo1P3o603o0_oonfX01?oo0?cooo]ZoookJ_ooTP03oookJP03ool0j_oo
nf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX01_oonfX02onio`3ooe80oiCo0?oonf[o02[ooookJ_lo
o`3o001oo`3oGOmho`3o?@3o00;ooo]Z0ol007l01?oUo`3o4P3oooo:0?l007l3oookJP03onGo0?oo
09?oo`0C00Cooo]Z00?of_l0on7o0?oonfX00_oonfX00om4o`3ooo]ZoookJP0=oookJP0@oc7o0?oo
nf[ooo]Zo`3oFooonf[oP_l0oookJ_l0ok7o033oo`3oCOl0j?oooo]Zo`H0oooonf[oiOl0oi;o00?o
oo]Z00?o403oo`0IoooonfX00_l007l01Ooo057o5@3oo`00Ool007oo0:go00;ooo]Z00?oo`1io`00
Ool007l01Ol007m2oookJP?o001o00[oo`3io`00Ool0Mooo001ooookJ_ooK03ooo]Zo`3oc?ooP@3o
>ol01?l007l01Ol0nooooo]ZoookJ_oonf[oo`<000?ooo]Z00GoN@3oool0gOl05ooo0:?ook?o0005
oookJP05o`3og_oo08Oooo]ZoookJ_oo06`00_oonfX01Om=0?ooobh0oookJ_mQ0?oo0?m500?ooo]Z
00GohP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP07ofP0oooonf[ooo]ZoookJ_lH0?oooo]ZonKo0002
oookJP04oon@0?oonf[ooo]ZoookJP?o001o0_oonfX01?oo_P3o001oog00ooo[0?l4o`00O`03oook
J_ooE`3ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP04oookJP05o`3D
ool01?oooo]Zo`2Yool0R?l00_oonfX00ol0odko0?l^o`3o=004oookJP04o`3Qool0oagooo]Zo`3o
D`?ooo]Z00goo`1io`2]oooo057ooo]Zoa00oooonf[oT_l0o`H0ool0odgo033ooh;o0?l007oo<Ol0
00Ko001o00?o8?l0obH0oooJo`000_l007l02ooo09?o001oooo:0?l0oa_o001ooookJ_mho`3o?@3o
oookJ_ooDP3o0?lc00?ooo]Z00?o07?ooookJ_oonfX00ooonfX06_oo0>[ooaH0oonB0?oo0?cooo]Z
ool60?oo0?Koo`3io`1goolko`3ooo]ZogT0oonco`3o0?oNool0K?mQ0?oooo]Zo`3oT?mX0?oooo]Z
oaP0oooonf[ookh0og00ooooE`3oo`0]0_oonfX03Ol0e?oo0?m>o`3o=?l0oagooo]Zool0NOnBo`3o
oo]Zo`3oFolPo`3o9P3oo`000?lB0?l00_l0g?l00oooDP3ooo]ZoookJP0=oookJP05oomB0?l0:_oo
0=cooookJ_lB0?l00ooonfX00olV0?oooo]ZoookJP02oookJP09o`3oFooonf[oT_l0oa00oooo057o
o`1ioookJ_l0oe?o0?lM00;ooo]Z00Co0?m>o`2Yoooonf[o0=Co0ooonfX02_ooP@3ooo]ZoookJ_oo
02gooo]ZoomG0?oonf[oL03oon/0oooo_P02oookJP06o`00OoooT03oi_l0oaP0ool007ooJ03o0_l0
07l08?l0oi;ohP3ooookJ_l0odGoH@3oodd0oooo06co001oool0Qol007oo/ol0o`2Soooo0=gooo]Z
ool30?oonf[o0?_ooc_o0?ooP@3o0?nJo`1goooo0?Wooo]ZojP0oooonf[o0:Koon_o0?oo1P3ooo]Z
oaP0oooonf[oo`3l0_oonfX01OooTP3ooaH0oookJ_oonf[oo`3Z00cooo]Z00?o07?ooookJ_oonfX0
1ooonfX02_nio`3ooe80oookJ_l0:_oooo]Zocoo0?l007oo0=coogSo0?lm0?l2oookJP?o001o00Co
08koo`3o6olB0?ooolX00ooonfX00ol0nOooo`2Cool04`04oookJP03om[o0?oQo`3ooo]Z00;ooo]Z
00?o9P3ooookJ_oonfX03OoonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP07oh;o0?l0ok7o033ooook
J_l0odgo0>Soo`H0o`02oookJP08oi;o0?oonf[ooo]ZoookJ_l@0?oooo]Zo`0IoooonfX2o`00O`08
ool0DOlE0?oo001oo`2]ool007oooo]Zool0NOoonfX7o`00Oagooo]Z000WoookJP?o001o00?ooo]Z
ool0nOl0Mol00_l007l01_oonf[oA?l0onGo0?oUo`3o>ol0oookJP?o001o00Gooo]ZoiCo0?oonf[o
oo]Zool30003oookJP05ogT0oooo0=gooo]Zo`2Soonco`001OoonfX01Ol0omkogOl0ool0Qooonf[o
o`1/00;ooo]Z00KoC@3oonGo0?oonf[ooo]Zof40ool0odD2oookJP03on80oooonf[o0?n@00;ooo]Z
00?o0?nBoookJ_oonfX00ooonfX00omX0?oooo]ZoookJP02oookJP05oaP0oooVo`3ooo]ZoookJ_oo
T0001?oonfX3o`00O`07oookJ_oo_P3ooo]Zo`3o1Om`0?ooj`3ooookJP03o`00O`03oomG0?oonf[o
oo]Z00;ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP04oookJP05o`3Dool01?oo
0:WooookJ_l0R?l00_oonfX00ol0odko0?ldoookJP03oookJP05o`3QoooUo`3ooo]ZoookJ_l0oe<0
0_oonfX03Ooo07Wo0:goool0DOoonf[o01Wooa00oooo0?GoT_l0o`3Xool0odgoP_l0oookJ_lao`00
0ol007l4oookJP08obH0oooonf[of_l0o`00Oooo01?oo`2ConGo0?l0oa/2onGo0005oomi0?l0omoo
?ol0o`0ZooooDP001?oonfX01_l0Looooo]ZoookJ_oonf[oogT0ool0jP;oogT000Soo`3loomi0?oo
N@3oogT0ojP0ool0Mooo>ol0ool000CoiOl00oooN@002?l0oi;oobP0oaP0ooooT03ooo]Zoonn0?oo
:03oogT00_oo:0000ol0e?ooobP0o`3oCP0=oolX00SoogT000?ooo]ZonGo0?oUo`003_oo00000olV
0?ooogT0oomi0005oomi00?oobP000So0?mCoomi0?ooN@3ooo]Zo`3oC_oonf[o0:Woo`3Do`?ooo]Z
00Gooh40oookJ_oonf[oo`0]oookJP02oiCo0004on/0oooo_P3ooo]ZoookJP;o001o00Cooi00onKo
0?lH0?ooJ03o0_oonfX04ol0oi;ooo]Zo`3oT?oR0?ooH@3oodd0oooonf[oo`1/ool0Qol0omkooo]Z
oil0oonco`3oN@3oool30?oonf[o0?_ooookJ_lko`000_oob@000ol0MoooolT0ooo90002ooo90004
on_o0?oonf[oo`H0oaP0o`;ooo]Z00Coo`3loookJ_oonf[ooi800ooonfX00ooo0>[ooo]ZoookJP0:
oookJP03o`1coooonf[ooo]Z00Cooo]Z0onDo`002_ooDP3oU?l0oiCo0?nDo`3o02[oocoo0?l007oo
0?mMogSo0?lm0?l2oookJP?o001o00CoiOl0oa80ool007ooolX00_oonfX01?oUo`3ooo]Zool0Tooo
01<4oookJP06om[o0?oonf[ooo]ZoookJ_m4o`3o8?l03ooonfX04?lao`3ooo]ZoookJ_l0oe_ooo]Z
oh;o0?oonf[o0?nao`0`ool0odgo0>SooookJ_l60?oooo]ZonGo0?nBo`03oookJP03oa00ool06Ooo
oo]Z00;o001o00Soo`1AoaD0oooonf[o001oo`2]ool007oooo]Zool0N@?o001o00Cooo]Zo`00Ool0
07oo001o@_oonfX3o`00O`03ool0nOoonf[o07Oo00;o001o00Koof`0oookJ_ooP@3o001ooc_o0?oo
nfX3o`00O`04o`3koooonf[ooo]Zool300Cooo]Z00GoN@3oool0gOl05ooo0:?ook?o0005oookJP05
o`3og_oo08Oooo]ZoookJ_oo06`00_oonfX01Om=0?ooobh0oookJ_mQ0?oo0?m500?ooo]Z00GohP3o
o`3oT?oonf[ooo]Zo`3oTP06oookJP06ofP0oooonf[ooo]ZoookJ_lH0?ooi_l00_oonfX00oooT03o
oo]ZoookJP02oookJP?o001o0_oonfX01Ooo_P3o001oog00ooo[0?oooo]Z00?o001o00?ooo]ZoomG
0?oonfX00_oonfX00ooo02gooo]ZoookJP05oookJP03oon10?oonf[ooo]Z00Cooo]Z00Go0=Coo`04
ool0ZOoooo]Zo`28o`02oookJP03o`3oC_l0ocCooo]Z00Cooo]Z00Co0>7oo`3o7Ooonf[o0?mC0ooo
nfX03Ooo07Wo0:goool0DOl06Ooo403ooookJ_nBo`3o0>Soo`3oCOl0<?ooP_l0o`3oFolao`000_l0
07l4oookJP03ob3o0?lV0?oof_l000;o001o00_oo`2CoookJ_oobP3o0?lKo`00Oooonf[oN?l0o`3L
oooonf[ooe80o`3o<`03oookJP03o`1coooonf[ooo]Z00;ooo]Z02coo`3ZoookJ_oo5P3ooi80ool0
o?lH0?ooo`H0ojP0ool0Moooof`0oc_o0?oo0`3oo`3Mok?o0?l0omkoo`1/of40ool0oi3o0?nBofP0
oolH0?oooi00oookJ_oo_P3oL03ooookJ_oo02gooo]Zo`3Dool01?oo0?m>oookJ_l0oagoo`1ioa00
oonBo`3o0?mKob3o0?lV0?oooo]Zoa80ool0g?oo0000oomB017ooo]Z00Cooe80o`0Zool0g?oo4P3o
1?oonfX04olV0?oooo]ZoookJ_oonf[o0?mKo`0`oonBo`3o403ooookJ_oo057ooo]Zo`3oDol0oago
0>7ooookJ_l0ocCo0?m>o`2Yool0e?l00ooonfX01_ooP@3ooo]ZoookJ_oo02gooo]ZoomG00;ooo]Z
00[oj`3ooonn0?oonf[ooo]Zo`00OoooT03oi_l0oaP0oooonf[oJ03o0_oonfX08?l0oi;o0?n@on80
ool0odGoH@3oodd0oooo06co001oool0Qol007oooo]Zok?o0?oo0=gooo]Zool30?oonf[o0?_ooc_o
0?ooP@3o0?nJo`1goooonf[oo`3iojP0oooonf[o0:Koon_o0?oo1P3ooo]ZoaP0oooonf[oo`3l0_oo
nfX01OooTP3ooaH0oookJ_oonf[oo`3Z00cooo]Z00?o07?ooookJ_oonfX02?oonfX02OooDP3ooo]Z
oookJ_l0:_oo?ol0o`00Ool0g?ooN?l0ocd0o`02oookJP?o001o00Gooo]Zo`3o6olB0?oo001oooo:
0002oookJP03o`3ioooo09?oo`0C00Cooo]Z00?of_l0oookJ_oonfX00_oonfX00olV0?oooo]Zoook
JP0=oookJP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00OoP_l0o`3o/Ol0<?oooo]Zo`3oCOl0j?oo1P3o
00;ooo]Z00SoT_l0oookJ_oonf[ooo]Zoa00oooonf[o01WooookJP;o001o00Coo`1AoaD0oooonf[o
0:go0_l007l00ooo07Wooo]Zo`00O`02o`00O`04oookJ_l007oo001oo`00Oagooo]Z000JoookJP[o
001o0_oonfX3o`00O`04oookJ_oo0?Wooo]Zo`1go`;o001o00Gooo]ZodCo0?oUo`3oiOl0oc_o0002
oookJP?o001o00CoU?l0oookJ_oonf[oo`<00ooonfX01Omi0?ooo`3MoookJ_l0Xooo/ol000Gooo]Z
00Go0?oNool0Qooonf[ooo]Zool0K002oookJP06odd0oooUo`3ooo]Zof40oooonf[o0?m50_oonfX0
1OoR0?oooo]Zo`3oT?oonf[o0?nB00?ooo]Z0ol007l00omX0?oo001oo`00O`02o`00O`05oaP0oooV
o`3ooo]ZoookJ_ooT0002?l007l01Ooo_P3o001oo`3o1Om`0?ooj`3o00;ooo]Z0_l007l00oooE`3o
oo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX01?oonfX01?l0e?oo
00Coo`2Yool0R?l2oookJP03o`3o;_l0odko0?ld00Cooo]Z00Co0>7oonGo0?oonf[o0?mC0_oonfX0
3_oo07Wo0:gooaD0oooo057o001oo`0Iool@0?ooo`3eoi;o0?l0j?oo0?m=oh;o0?oUo`3o<Ol01?l0
07l2oookJP09oh@0oolV0?oooo]Zom[o0?oo01?o0?Woool0TooobP3o0?lK00;oiOl000GoogT0o`3L
oooonf[o02[ooomB0004oookJP03o`1coooonf[ooo]Z00;oogT000Coo`3Zoomi0?ooN@3oo`3l0ooo
N@000ooo0?Wo07Oooc_o0005onGo00?oogT000Ooo`00oaP0oooo:03ooo]Zoonn0?ooN@3ooeL000;o
iOl000?oobP0o`3Dool0odh03ooo:00?oomi00?oo`0000?oolT0ool00?oo00000ooo00000olV0?oo
o`00oomi0005oomi00?oobP000Wo0?mCoomi0?ooN@3ooo]Zo`3oC_oonf[o0:Woo`04ool0e?l00_oo
nfX02OooP@3ooo]ZoookJ_oo02gooo]ZoomG0?nDo`3oj`3ooonn0003oookJP05o`00OoooT03oi_l0
oaP0oomX0?l00_oonfX03ol0oi;ooo]Zo`3oT?oR0?oo001oof40oooonf[oo`1/o`00Oooo08Oo001o
oil0oonco`3oN@3oool30002oookJP05o`3koolko`3ooh40ooo90?l0Mol01?oob@001oo[o`3ooo]Z
oookJ_oo1P3o603ooookJ_oo0?`00_oonfX00oooTP3ooo]ZoookJP02oookJP03ool0j_oonf[ooo]Z
00Wooo]Z00?o07?ooookJ_oonfX01?oonfX3oiCo000;oomB0?nDo`3oU?l0oiCo0?l0:_oo?ol0o`00
Ool0oegoN?l0ocd0oooonfX02OoUo`001Ooonf[oiOl0oookJ_oo09?oo`0C00Cooo]Z00Kof_l0oook
J_oonf[ooo]ZodCo0?lPo`0?oookJP0@oc7o0?oonf[ooo]Zo`3oFooonf[oP_l0oookJ_l0ok7o033o
o`3oCOl0j?oooo]Zo`H0oooonf[oiOl0oi;o00?ooo]Z00?o403oo`0Iool007l00_l007l02?oo057o
5@3ooookJ_l007oo0:goo`00Oooonf[oo`1i0_l007l3oookJP?o001o=?oonfX:o`00O`;ooo]Z0ol0
07l00ooo0?Wooo]Zo`1go`03o`00O`04oom/0?l007oooh40oc_o00?ooo]Z0_l007l01?l0nooooo]Z
oookJ_oo0`03oookJP05ogT0oooonf[oo`3Mo`0Goonco`001OoonfX00ooMo`3o0?oNool0Q`02oook
JP08ool0K?oonf[ooo]Zodd0oooonf[oH@3ooookJ_l0odD3oookJP05on80ool0oi3ooo]ZoookJ_l0
oi800_oonfX4o`00O`06ofP0ool007oo001oo`00OolH0?ooi_l00_oonfX00oooT03o001oo`00O`06
o`00O`05oookJ_oo_P3o001oog00ooo[0?l00_oonfX3o`00O`05oomG0?oonf[ooo]ZoookJ_oo02d0
1ooonfX00oooP@3ooo]ZoookJP04oookJP05o`3Dool01?oo0:WooookJ_l0R?l00_oonfX00ol0odko
0?ldoookJP03oookJP04o`3Qoooonf[o0?lMo`3oD`?ooo]Z00koo`1io`2]oooo057o001oo`0Iool@
0?oo001ooi;o0?l0j?oo0?m=o`0`oon2o`3o0?mKoc7o00?o001o0ooonfX02OlV0?oooo]Zom[o0?l0
07ooo`0Cool0Tooonf[oolX0o`3o6`02o`00O`05ogSo0?loo`3o02[ooomB0?nio`000ooonfX00ol0
Looooo]ZoookJP02oookJP0Jool0j_oonf[ooi80oookJ_oo0?coo`H0on_o0?oo0?Wo07Oooc_o0?l0
noooo`<0ool0gOnco`3o0?oNool0K?l0odGo0?n@oookJ_mX0?oo603ooookJ_oo_P3oL03ooomG0?oo
02d2oookJP0=o`3Dool0odkooo]Zo`3o7Ooonf[o403ooi;o0?l0oe_o8?l0obH0oooonf[o4P3oo`3L
o`02oomB0003o`000?oonf[ooo]Z013ooo]Z00Cooe80o`0Zool0omoo4P3o0ooonfX05?lV0?oooo]Z
oookJ_oonf[o0?mKo`3o/?l60?ooT_l0oookJ_oo057oo`1io`3oDol0oago0>7ooookJ_l0ocCo0?m>
o`2Yool01?oo0=Co0_oonfX01_ooP@3ooo]ZoookJ_oo02gooo]ZoomG00;ooo]Z00?oj`3ooonn0?oo
nfX00_oonfX01OooT03oi_l0oaP0ool007ooJ03o00;ooo]Z00Wo0?nBo`3oT?oR0?oo001oof40oom=
0?ooo`1/oookJ_oo08L00_l007l05Onco`3oo`3MoookJ_oo0`3ooo]Zo`3koolko`3ooo]Zoon10?l0
Mooooo]Zool0nOnX0?oooo]Zo`2Vooo[o`3ooo]Zool60?lH0?oooo]Zool0o002oookJP03oonB0?oo
5P3ooo]Z00;ooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ol0Looooo]ZoookJP08oookJP0:oomB0?l0
07oo001oo`0Zooloo`3o001oo`3Loomho`3o?@3ooookJP?o001o0_oonfX01?l0oa_o001oo`00Oooo
bP02oookJP03o`3ioooo09?oo`0C00Cooo]Z00Kof_l0oookJ_oonf[ooo]ZobH0oolPo`0?oookJP04
oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00OoP_l0o`3o/Ol0<?oooo]Zo`3oCOl0j?oo1P3o00;ooo]Z00Oo
T_l0oookJ_oonf[ooo]Zoa00oooonf[o01Wo00?o001o00Coo`1AoaD0oooonf[o0:go0_l007l01?oo
07Wo001oo`00Ool007l3oookJP?o001o7?oonfX001[ooo]Z2_l007l2oookJP?o001o00?ooo]Zool0
nOl0Mol00ol007l01Ooonf[oA?l0onGo0?oUo`3o>ol000;ooo]Z0ol007l01?nDo`3ooo]ZoookJ_oo
0`02oookJP06ogT0oooonf[oo`3MoookJ_l0Xooo/ol01OoonfX01Ol0omkoo`27oookJ_oonf[oo`1/
00;ooo]Z00GoC@3oonGo0?oonf[oH@3oo`3oA@03oookJP05on80oooonf[o0?n@oookJ_l0oi800ooo
nfX3o`00O`03ofP0ool007oo001o00;o001o00Go603oonKo0?oonf[ooo]Zoon@0008o`00O`04oonn
0?l0o`Go001oon/0o`?ooo]Z0_l007l00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Go
oo]Z00?ooh40oookJ_oonfX00ooonfX01Ol0e?oooo]Zo`04ool0ZOoo08So00;ooo]Z00?o0?m>o`3o
=?oonfX01?oonfX01?l0hOooiOl0oookJ_l0oe<2oookJP0?ool0NOl0[Ooo5@3oool0DOl007oo01Wo
oa00oonBo`3o1P3oo`3Xool0odgoP_l0onGo0?lao`3ooo]Z00Go001o00Wo8?l0obH0oooJo`3ohOl0
ool04ooo09?oiOl0ooo:0?l0oa/00_oUo`001OooN@3o0=cooookJ_l0:_oooe8000Cooo]Z00Wo07?o
oookJ_oonf[ooo]Zool0j_oonf[ooi80oomi0?oo0?`00oooN@000ooo0?Wo07OoonGo0005onGo00?o
ogT000KoobP0oaP0oooo:03oogT0oonn0?ooE`03onGo0003o`3Doooo:03o0?m>013oobP03_ooN@03
ool00003ooo90?oo003oo`0000Coo`0000?o9P3ooomi0?ooN@000oooN@003OnBo`3oobP0oolX0?oo
:03oogT0o`3oDoooN@3ooo]Zo`3oC_l0ocCo0:Woo`04ool0e?l00_oonfX02_ooP@3ooo]ZoookJ_oo
02gooo]ZoomG0?nDo`3oj`3ooiCo0?oo_P03oookJP0Eoon@0?oVo`3o603oo`00OomX0?oooo]Zo`3o
T_oonf[o0?n@oomi0?l007ooH@3ooookJ_oo06co001oool0Qol007ooW`3ook?o0?oo0=goo`<000;o
oo]Z00?o0?_ooc_o0?ooP@000_oob@002ol0MoooolT0ooo90?oob@3oo`3fon_o0?oonf[oo`H0oaP0
oooonf[oo`3l00;ooo]Z00?ooi80oookJ_oonfX00_oonfX00ooo0>[ooo]ZoookJP09oookJP03o`1c
oooonf[ooo]Z00Cooo]Z1?nDo`002_ooDP3oU?l0oiCo0?l0:_oo?ol0o`00Ool0oegoN?l0ocd0oooo
nfX9onGo0005oookJ_oUo`3oo`2CoookJ_oo01<01?oonfX01_oJo`3ooo]ZoookJ_oonf[oA?l0ob3o
00oooo]Z013o<Ol0oookJ_oonf[o0?mKoookJ_n2o`3ooo]Zo`3o/Ol0<?oo0?m=o`3Xoooonf[o1P3o
oookJ_oUo`3oT_l00ooonfX00ol@0?oo01Woo`00O`02o`00O`07ool0DOlE0?oooo]Zo`00Ool0[Ooo
001oool0N@03o`00O`?ooo]Z0ol007ldoookJP[o001o0_oonfX3o`00O`03ool0nOoonf[o07Oo00?o
001o00Coof`0o`00OoooP@3o>ol00ooonfX2o`00O`04o`3koooonf[ooo]Zool300?ooo]Z00GoN@3o
oookJ_oo0=go0:?ook?o0005oookJP03omgo0?l0omkoo`2700;ooo]Z00Ooo`1/oookJ_oonf[oC@3o
oookJ_mQ0?oo0?m500Cooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP02oookJPCo001o00KoJ03oo`00
Ool007oo001ooaP0oooVo`02oookJP03oon@0?l007oo001o00Ko001o00Cookh0o`00Ool0o`Goj`3o
0ooonfX3o`00O`05oomG0?oonf[ooo]ZoookJ_oo02d01ooonfX00oooP@3ooo]ZoookJP03oookJP0:
o`3Doooonf[o00Coo`2Yoooonf[o08SooookJ_l0odko0?l^o`3o=0Cooo]Z00Co0>7oo`3o7Ol0o`So
0?mC0ooonfX03_oo07Wo0:goool0DOl007oo01Wooa00oonBo`3o1P3oo`3Xool0odgo0?n`oh;o0?l0
oe_o<Ol01Ol007l04?lPo`3o9P3oom[o0?oQo`3o001oool0Tol0nOooolX0o`3o6ol0S_oo001oo`3o
gomho`3ooo]Zo`0ZooooDP04oookJP03o`1coooonf[ooo]Z00;ooo]Z01Woo`3ZoolF0?ooTP3oo`3l
oookJ_oo1P3oo`3fool0nOl0Mooo>ol0oookJ_mi0?oo/ol0o`3og_oo06coH@3oo`3oT?l0oi;oJ03o
onKo0?lH0?oooo]Zoonn0?m`0?oooeL000;ooo]Z00ko0=Coo`04ool0odko0?lMo`3o2?oo07WoT_l0
o`3oFooonf[o8?l0obH0oolB0?oo0=cooomB00?o00000_oonfX9ool0mPSooo]Z00Cooe80o`3ogol0
g?oo4P3o0ooonfX03OlV0?oooo]ZoookJ_oonf[o0?mKo`H0oonBo`3o403oool0DOoo07Wooo]Zo`3o
Dol0hOl00_oonfX01?l0odko0:Woo`04ool0e?l2oookJP06oon10?oonf[ooo]Zool0;Ooonf[ooeL0
0_oonfX00oo[0?oookh0oookJP02oookJP0@oon@0?oVo`3o603oo`00OomX0?oo001ooookJ_l0oi;o
0?n@on80ool007ooH@3oodd0oooo06cooo]Zool0Q`;o001o01Go/ol0ogT0oooo0=goo`<0oookJ_l0
nooo>ol0oookJ_ooP@3oof`0o`1goooo0?WoZ03ooookJ_l0Y_oooo]Zon_o0?oo1P3o603ooookJ_oo
0?`00_oonfX00oooTP3ooaH0oookJP02oookJP03ool0j_oonf[ooo]Z00Wooo]Z00?o07?ooookJ_oo
nfX02?oonfX02_ooDP3o001oo`00Ool0:_oo?ol0o`00Ool0g?ooN?l0ocd0oooonfX3o`00O`;ooo]Z
00Co0?lKo`00Ool007ooolX00_oonfX00ooo09?ooo]Zool04`04oookJP06on7o0?oJo`3ooo]Zoook
J_lV0?oo8?l03ooonfX03Olao`3ooo]ZoookJ_l0oe_ooo]Zoh;o0?l0ok3o0?nao`0`oooonf[o0?m=
o`3Xool60?l00_oonfX01onBo`3ooo]ZoookJ_oonf[o403ooookJ_l06Ol00ol007l01ooo057o5@3o
oookJ_l0[Ooo001oool0NOoonfX00ol007l3oookJP?o001o7?oonfX002Kooo]Z1?l007l00ooo0?Wo
07Ooo`00O`02o`00O`05oookJ_m4o`3oiOl0onGo0?lko`000_oonfX3o`00O`04oiCo0?oonf[ooo]Z
ool300;ooo]Z00KoN@3ooookJ_oo0=gooo]Zo`2Soonco`05oookJP0<o`3og_oo08Oooo]ZoookJ_oo
06cooo]Zodd0oooonf[oiOl0oookJ_mQ0?oo0?m50ooonfX01OoR0?oooo]Zo`3oT?oonf[o0?nB00Ko
oo]Z00?oJ03ooookJ_oonfX00_oonfX01_lH0?ooi_l0oookJ_oonf[ooi00o`00O`?ooo]Z0ol007l0
1Ooonf[ookh0o`3o1Ol007ooj`3o00?ooo]Z0_l007l00oooE`3ooo]ZoookJP02oookJP03ool0;Ooo
nf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX00ooonfX01Ol0e?oooo]Zo`04ool0ZOoo08So00;ooo]Z
00?o0?m>o`3o=?oonfX01?oonfX01?l0hOooiOl0oookJ_l0oe<2oookJP03ool0NOl0[Oooo`1A00;o
oo]Z00Wo01Wooa00oonBo`3o1P3oo`3oCOl0ok3oP_l0onGo0?lao`000ooonfX3o`00O`08ob3o0?lV
0?oof_l0o`00Oooo01?oo`2ConGo0?l0oa/3onGo0005oomi0?l0g?oo02[ooomB0?nio`000ooonfX0
0ol0Looooo]ZoookJP02oookJP04ool0j_oonf[ooi80ool0o0CoogT000?o07Oooc_o0?oUo`001OoU
o`03oomi0005oaP0oooo:03oolT0oonn0?ooN@001?oUo`000ooo:03o0?m>oolX000@oolX00koogT0
0ooo0002ooo900Goo`0000?o9P3ooomi0?ooN@000oooN@003OnBo`3oobP0oolX0?oo07Wooo]Zo`3o
DoooN@3ooo]Zo`3oC_l0ocCo0:Woo`04ool0e?l00_oonfX02_ooP@3ooo]ZoookJ_oo02gooo]ZoomG
0?oonf[oj`3ooiCo0?oo_P03oookJP0Eoon@0?l0M?oo603oo`00OomX0?oo001ooookJ_l0oi;o0?n@
oomi0?l007ooH@3ooookJ_oo06co001ooomi0?l007ooW`3ook?o0?oo0=goo`<000;ooo]Z00?o0?_o
oookJ_lko`000_oob@002ol0MoooolT0ooo90?oob@3oo`3fon_o0?oonf[oo`H0oaP0oooonf[oo`3l
00;ooo]Z00?ooi80oookJ_oonfX00_oonfX00ooo0>[ooo]ZoookJP09oookJP03o`1coooonf[ooo]Z
00Gooo]Z0onDo`002_ooDP3oU?l0oiCo0?l0:_oo?ol0o`00Ool0oegoN?l0o`3ogooonfX9onGo0005
oookJ_oUo`3oo`2CoookJ_oo01<01?oonfX01_oJo`3ooo]ZoookJ_oonf[oA?l0ob3o00oooo]Z00oo
<Ol0oookJ_oonf[o0?mKoookJ_n2o`3ooo]Zo`3o/Ol0<?oo0?m=o`3Xoooonf[o1P3ooookJ_nBo`00
1?oonfX00ol@0?oo01Woo`00O`02o`00O`07ool0DOlE0?oooo]Zo`00Ool0[Ooo001oool0N@03o`00
O`?ooo]Z0ol007m0oookJP?o001o00?oo`3ioookJ_l0Mol00ol007l01?ooK03o001ooon10?lko`03
oookJP;o001o00Co0?_ooookJ_oonf[oo`<00ooonfX01Omi0?ooo`3MoookJ_l0Xooo/ol000Gooo]Z
00?ogOl0o`3og_oo08L00_oonfX01ooo06cooo]Zodd0oooo;P3ooo]Zof40ool0odD01?oonfX01OoR
0?oo0?n@oookJ_oonf[o0?nB00Gooo]Z00?oJ03ooookJ_oonfX00_oonfX01_lH0?ooi_l0oookJ_oo
nf[ooi00o`00O`?ooo]Z0ol007l01Ooonf[ookh0o`00Ool0o`Goj`3o00?ooo]Z0_l007l00oooE`3o
oo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX00ooonfX02_l0e?oo
oo]Zo`04ool0ZOoooo]Zo`28oooonf[o0?m>o`3o;_l0oc@4oookJP04o`3Qool0oago0?l8o`3oD`?o
oo]Z00koo`1io`2]oooo057ooo]Zo`0Iool@0?ooT_l0o`H0ool0odgo033oo`3o/?n2o`3o0?mKoc7o
00;ooo]Z0ol007l00olPo`3o9P3oom[o0002o`00O`04ool0Tol0nOooolX0o`3o6`;o001o00Go0?oO
ogSo0?oonf[ooe80o`3o<`03oookJP03o`1coooonf[ooo]Z00;ooo]Z01[oo`3ZoookJ_oo5P3ooi80
ool0o?lH0?ooo`H0ojP0ool0Moooof`0oc_o0?oonf[oo`3Mok?o0?l0omkoo`1/odd0ool0oi3ooo]Z
ofP0oolH0?oooi00oonn0?m`0?oooeL0ool0;@;ooo]Z00go0=Coo`3oC_oonf[o0?lMoookJ_l@0?oo
0?mKoookJ_lPo`3o9P3ooa80oooonf[ooe8000Co00000_oo0?H9oookJP03ool0m_oonf[ooo]Z00Go
oo]Z00Gooe80o`0Zool0omoooo]Zoa80o`02oookJP0=obH0oooonf[ooo]ZoookJ_l0oe_o0?n`oi;o
0?l@0?oooo]Zool0DOoonf[o0?mCo`3Qo`02oookJP04o`3oC_l0ZOoo00Coo`3Do`;ooo]Z00Kooh40
oookJ_oonf[oo`0]oookJ_ooE`02oookJP03on/0ool0o`Gookh000;ooo]Z00Gooi00o`1doolH0?oo
001oofP0o`02o`00O`09o`3oT_oonf[ohP3oo`00OomQ0?ooC@3oool0K?oonf[oo`2700;o001o00Co
/ol0o`2Soooo0=goo`<00_oonfX03ol0nooo>ol0oon10?ooK03o07Ooool0nOnX0?oooo]Zo`2Voooo
nf[ojol0ool60?lH0?oooo]Zool0o002oookJP03oonB0?oo5P3ooo]Z00;ooo]Z00?oo`3ZoookJ_oo
nfX02OoonfX00ol0Looooo]ZoookJP08oookJP0:oomB0?l007oooo]Zo`0Zooloo`3o001oo`3Loomh
o`3o0?oOoookJP?o001o0_oonfX01?l0oa_o001oo`00OooobP02oookJP03ool0Tooonf[oo`0C00Co
oo]Z00KohOl0om[o0?oonf[ooo]ZobH0oolPo`0?oookJP0=oc7o0?oonf[ooo]Zo`3oFooonf[oP_l0
o`3o/?l0ok7o033oo`3oCOoonf[o0>Soo`H0o`02oookJP07oi;o0?oonf[ooo]ZoookJ_l@0?oooo]Z
o`0Io`03o`00O`07ool0DOlE0?oooo]Zo`2]ool007ooo`1ioookJP03o`00O`?ooo]Z0ol007lLoook
JP009_oonfX5o`00O`06o`1gool007oo001ooookJ_m4o`3o0?nJ0_oUo`000olko`3ooo]ZoookJP02
o`00O`05oiCo0?oonf[ooo]ZoookJ_oo0`000_oonfX01_mi0?oooo]Zool0gOnO0?oo0:?ook?o00Go
oo]Z00co0?oNool0Qooonf[ooo]Zool0K?oonf[oC@3ooookJ_oUo`3ooo]Zof40ool0odD3oookJP05
on80ool0oi3ooo]ZoookJ_l0oi801_oonfX01omX0?oooo]ZoookJ_oonf[o603oo`1doooVo`000_oo
nfX00oooT03o001oo`00O`02oookJP?o001o00Gooo]Zoonn0?l0o`Go001oon/0o`03oookJP;o001o
00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Cooo]Z
00Go0=Coo`04oooonf[o0:Woo`28o`02oookJP03o`3oC_l0ocCooo]Z00Cooo]Z00Co0>7oonGo0?oo
nf[o0?mC0_oonfX00ooo07Wo0:goool0D@02oookJP09oa00oooonf[oT_l0o`3Xool0odgoP_l0oook
J_oUo`3o<Ol000Cooo]Z0_l007l02?lV0?oooo]Zom[o0?l007ooo`0Cool0TooUo`3o0?lK0ooUo`00
1?ooN@3o0=coo`0ZooooDP04oookJP03o`1coooonf[ooo]Z00;ooo]Z00Coo`3ZoookJ_ooN@3oo`3l
1?ooN@000ol0MoooiOl0onGo0005onGo00;oogT000Goo`00oaP0oooo:03oolT0oonn0004onGo0003
o`3DoooUo`3o0?m>00OoobP00_ooN@08oolX00Ko/ol01oooN@04ool000;oolT01Ooo00000olV0?oo
ogT0oomi0003oomi000=oi;o0?oo:03oobP0ool0NOoonf[o0?mCoomi0?oonf[o0?m>o`3o=?l0ZOoo
00Coo`3Do`02oookJP0:oon10?oonf[ooo]Zool0;Ooonf[ooeL0oookJ_nDo`3oj`3ooonn00?ooo]Z
01Gooi00o`1doolH0?oo001oofP0ool007oooo]Zo`3oT_l007ooogT0o`00OomQ0?oooo]Zool0K?l0
07ooogT0o`00OonO0?oo/ol0ool0gOoo0`000_oonfX01_l0nooooo]Zoc_o0?ooK03oolT0o`1go`;o
olT000So0:KooookJ_o[o`3ooo]Zool60?lH0?oooo]Zool0o0;ooo]Z00?ooi80oookJ_oonfX00_oo
nfX00ooo0>[ooo]ZoookJP09oookJP03o`1coooonf[ooo]Z00Gooo]Z0onDo`002oooDP3oU?l0oiCo
0?l0:_oo?ol0o`3oGOl007ooN?l0o`3ogooonf[o001o00OoiOl000Ko001ooookJ_oUo`3oo`2Coook
J_oo01<4oookJP06om[o0?oonf[ooo]ZoookJ_m4o`3o8?l03ooonfX03olao`3ooo]ZoookJ_l0oe_o
oo]Zoh;o0?oonf[o0?nao`0`ool0odgo0>SooookJ_l60?oooo]Zoi;o0004oookJP03oa00ool06Ooo
001o00;o001o00Ooo`1AoaD0ool007oo0:goo`00Oooonf[oo`1i00?o001o0ooonfX3o`00Od3ooo]Z
1Ol007l02?l0Mooo001oo`00OoooK03o0?nJo`3oc?ooP@3o>ol00ooonfX00ol007oo0?_oo`00O`02
oookJP09ool30?oonf[ooo]ZoookJ_mi0?ooo`3Mo`0Gool0Xooo/ol000Gooo]Z00GogOl0ool0Qooo
nf[ooo]Zool0K002oookJP05odd0oooo;P3ooo]Zof40ool0odD01?oonfX01OoR0?oooo]ZoookJ_oo
nf[o0?nB00Gooo]Z00OoJ03ooookJ_oonf[ooo]ZoaP0oooonf[oi_l000;ooo]Z00?ooi00o`00Ool0
07l00_oonfX3o`00O`05oookJ_oo_P3o001oo`3o1Oo[0?l00ooonfX2o`00O`03oomG0?oonf[ooo]Z
00;ooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3ooo]ZoookJP04oookJP05o`3Dool01?oooo]Z
o`2Yool0R?l00_oonfX00ol0odko0?l^o`3o=004oookJP04o`3Qool0oago0?l8o`3oD`?ooo]Z00ko
o`1io`2]oooo057ooo]Zoa00oooonf[oT_l0o`3Xool0odgo033ooh;o0?oonf[o0?mKoc7o00?ooo]Z
0_l007l00olPo`3o9P3oom[o0002o`00O`04ool0Tooonf[oolX0o`3o6`;o001o00GoN?l0o`3Loooo
nf[ooe80okWo0003oookJP03o`1coooonf[ooo]Z00;ooo]Z02Woo`3ZoookJ_ooTP3ooo]Zool0o?lH
0?ooo`H0ojP0ool0Mooo0?nJoc_o0?oo0`3oo`3Mok?o0?l0omkoo`1/o`3oAOl0oi3oJ03ooookJ_lH
0?oooo]Zoonn0?m`0?oooeL0ool0;Ooonf[o0=Coo`04ool0odko0?lMo`3o2?oo07WoT_l0o`3oFooo
nf[o9P3ooookJ_lB0?oo0=cooomB0003o`000004ool0m_oonf[ooo]ZoookJPGo/ol00ooonfX00ooo
0?Kooo]ZoookJP06oookJP04oomB0?l0omoooo]Zoa80o`;ooo]Z00go9P3oob3o0?oonf[ooo]Zo`3o
Fol0ok3o1P3ooi;o0?oonf[oo`1AoookJ_l0oe?o0?lM00;ooo]Z00Co0?m>o`2Yoooonf[o0=Co0_oo
nfX01_ooP@3ooo]ZoookJ_oo02gooo]ZoomG00;ooo]Z00?oL03oon/0oooo_P000_oonfX01OooT03o
07CooaP0oooonf[oJ03o00;o001o00Wooo]Zo`3oT_oR0?oo001oof40oom=0?ooo`1/oookJ_oo08L0
0_l007l01?nco`3o0:?oool0gOoo0`02oookJP0?o`3koolko`3ooh40oom/0?l0Moooo`3iojP0oooo
nf[o0:Koool0m_o[o`3oo`H0oaP0oooonf[oo`3l00;ooo]Z00?ooi80oookJ_oonfX00_oonfX00ooo
0>[ooo]ZoookJP09oookJP03o`1coooonf[ooo]Z00Sooo]Z00[ooe80o`00Ool007oo02[oocoo0?l0
g?oo001oogSo0?l0omoooo]Z0ol007l2oookJP04o`3o6ol007oo001oooo:00;ooo]Z00?oo`2Coook
J_oo01<01?oonfX01_oQo`3of_l0oookJ_oonf[o9P3oob3o00oooo]Z00go<Ol0oookJ_oonf[o0?mK
oookJ_n2o`3o0?n`o`3o/Ol0<?oo0?m=oookJ_l0j?oo1P3o00;ooo]Z00OoT_l0oookJ_oonf[ooo]Z
oa00oooonf[o01Wo00?o001o00Ooo`1AoaD0ool007oo0:goo`00Oooo07Wooo]Z00?o001o0ooonfX3
o`00Oacooo]Z000VoookJP?o001o00Cooo]Zo`00Ool0Mooo001o0_oonfX01?m4o`3o001oonGo0?lk
o`03oookJP;o001o00GoU?l0oookJ_oonf[ooo]Zool30002oookJP05ogT0oooonf[oo`3Moil0oonc
o`001_oonfX02?l0omkoo`27oookJ_oonf[oo`1/oookJ_m=0?ooiOl00_oonfX00omQ0?oo0?m5oook
JP02oookJP05on80ool0oi3ooo]ZoookJ_l0oi801_oonfX01_mX0?oooo]ZoookJ_oonf[o603oonKo
00;ooo]Z00?ooi00oookJ_l007l00_l007l02Ooonf[o001oo`00Ool007oooo]Zoonn0?l0o`Go001o
on/0o`03oookJP03o`00OoooE`3o001o00Cooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3ooo]Z
oookJP04oookJP09o`3Dool01?oooo]Zo`2Yool0R?oooo]Zo`3o;_l0odko0?ld00Cooo]Z00[o0>7o
onGo0?oonf[ooo]Zo`3oDooonf[oo`1ioookJ_l0[Oooo`1A0_oonfX02?l@0?ooo`3eoi;o0?l0j?oo
0?m=oh;o0?oUo`3o<Ol01_oonfX02Ol007oo9P3oo`00OooJo`3oo`0ConGo0?oo09?oolX0o`3o6`03
onGo00;oogT000?o02[ooomB0?oonfX00ooonfX00ol0Looooo]ZoookJP02oookJP04ool0j_ooTP3o
ogT0ool0o0CoogT02?oUo`02oomi0005oolX0?lH0?ooobP0ooo90?oo_P001?oUo`000ol0e?oo0?m>
ool00006oolX00Coo`001Ooo:002ok?o00;oobP01?ooN@000onco`3oogT0oomi0004oomi00Coo`00
00?ooo]Zooo90?oob@001?oo00000olV0?ooogT0oomi0003oomi0007oolX0?nBo`3oobP0ool0NOoo
nf[o0?mCoomi0002oookJP04o`3oC_l0R?oo00Coo`3Do`;ooo]Z00[ooh40oookJ_oonf[ooo]Zool0
;Ooonf[ooeL0oiCo0?o[0?oookh00ooonfX01OooT03o07CooaP0oooonf[oJ03o00;o001o00ko0?nB
o`00OoooN@3o001oof40oom=0?ooo`1/o`00OoooN@3o001ooookJ_nco`3oo`3Mool300;ooo]Z00Ko
0?_ooookJ_lko`3oof`0ooo90?l0Mol2ooo90008o`2Voooonf[ojol0oookJ_oo1P3o603ooookJ_oo
0?`2oookJP03oonB0?oonf[ooo]Z00;ooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ol0Looooo]Zoook
JP05oookJP?oU?l000_ooe80oiCo0?nDo`3o02[oocoo0?l0oegoN?l0ocd0ool0omoooo]Zo`00O`07
onGo0006o`00Oooonf[oiOl0ool0Tooonf[oo`0C1?oonfX01_oJo`3ooo]ZoookJ_oonf[oA?l0ob3o
00oooo]Z00oo<Ol0oookJ_oonf[o0?mKoookJ_n2o`3ooo]Zo`3o/Ol0<?oo0?m=o`3Xoooonf[o1P3o
oookJ_nBo`001?oonfX00ol@0?oo01Woo`00O`02o`00O`04ool0DOlE0?oo001oo`2]o`;ooo]Z00Co
o`1io`00Ool007oo001o0ooonfX3o`00Od3ooo]Z0ol007l02_oonf[o001oo`1gool007oooo]Zoom/
0?oonf[o0?o<oon10?lko`03oookJP03o`00Ool0nooo001o00;ooo]Z00Woo`<0oookJ_oonf[ooo]Z
ogT0oooo0=go01Ooo`2Soonco`001OoonfX01Ol0omkoo`27oookJ_oonf[oo`1/00;ooo]Z00GoC@3o
ool^0?oonf[oH@3oo`3oA@03oookJP05on80ool0oi3ooo]ZoookJ_l0oi801_oonfX02_mX0?oooo]Z
oookJ_oonf[o603oo`1doooVo`3ooo]Zoon@0?oonfX3o`00O`09oookJ_l007oo001oo`00Oooonf[o
okh0o`00Ool0o`Goj`3o00?ooo]Z0_l007l00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z
00Cooo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0e?oo00CooookJ_l0ZOoo08So00;ooo]Z00?o0?m>
oookJ_l0oc@00ooonfX01Ol0hOoooo]Zo`3o7Ooonf[o0?mC00;ooo]Z00koo`1ioookJ_l0[Oooo`1A
oookJ_l@0?oooo]Zoi;o0?l0j?oo0?m=o`0`oon2o`3o0?mKoc7o00Gooo]Z017o001oobH0ool007oo
f_l0o`00Oooo01?oo`2Cooo:0?oonf[o0?lKo`00Ool0omooN?l0ocoo0?l0:_oooe80okWo0003oook
JP03o`1coooonf[ooo]Z00;ooo]Z01Woo`3ZoookJ_ooTP3oo`3loookJ_oo1P3ojol0ool0nOl0Mooo
>ol0o`3koomi0?oo/ol0omgo0?oo06coH@3oo`3oT?l0oi;oJ03ooaP0ooooT03ooo]Zoonn0?m`0?oo
oeL000;ooo]Z00Oo0=Coo`3oC_oonf[o0?lMool0NOl@0?oo0?mK00;ooo]Z00Ko9P3ooa80ool0g?oo
oe80oookJ_l00002ool0mP04o`000?nco`3o/ol0ok?o00GoH@3o00Go/ol0oookJ_oonf[ooo]Zool0
mP07oookJP05oomB0?l0:_oooo]Zoa80oooobP000_oonfX04_lV0?oooo]ZoookJ_l0oe_o0?n`o`H0
oonBo`3ooo]Zool0DOl0[Ooo0?mCo`3o7Ol0hOoooo]Zo`3o=?l0odko0:Woo`3Do`;ooo]Z00Oooh40
oookJ_oonf[ooo]Zool0;Ooonf[ooeL000;ooo]Z00Woj`3ooonn0?oonf[ooo]Zoon@0?l0M?oo603o
oookJ_mX0?l00ol007l02?l0oi;ohP3oo`00OomQ0?oooo]Zool0K?oonf[oo`270_l007l01?nco`3o
0:?oool0gOoo0`02oookJP0?o`3koolko`3ooh40oom/0?l0Moooo`3iojP0oooonf[o0:Koool0m_o[
o`3oo`H0oaP0oooonf[oo`3l00;ooo]Z00?ooi80oookJ_oonfX00_oonfX00ooo0>[ooo]ZoookJP09
oookJP03o`1coooonf[ooo]Z00Sooo]Z00[ooe80o`00Ool007oo02[oocoo0?l0g?ooN?l0ocd0ool0
omoooo]Z0ol007l2oookJP04o`3o6ol007oo001oooo:00;ooo]Z00?oo`2CoookJ_oo01<01?oonfX0
1_oQo`3of_l0oookJ_oonf[o9P3oob3o00oooo]Z013o<Ol0oookJ_oonf[o0?mKoookJ_n2o`3o0?n`
o`3o/Ol0<?oo0?m=oookJ_l0j?oo1P3ooookJ_oo0?GoT_l00ooonfX00ol@0?oooo]Zo`0Io`03o`00
O`07ool0DOlE0?oo001oo`2]oooonf[oo`1ioookJP03o`00O`?ooo]Z0ol007lLoookJP009_oonfX3
o`00O`;ooo]Z00So07OooookJ_oonf[ooo]ZodCo0?l007ooiOl0oc_o00?ooo]Z0_l007l01OnDo`3o
oo]ZoookJ_oonf[oo`<000;ooo]Z00GoN@3oool0gOoonf[o0:?ook?o0006oookJP04o`3og_oo08Oo
oo]Zool0K0;ooo]Z00KoC@3oonGo0?oonf[ooo]Zof40ool0odD3oookJP05on80ool0oi3ooo]Zoook
J_l0oi801OoonfX00omX0?oooo]ZoookJP02oookJP05oaP0oooVo`3ooo]ZoookJ_ooT0000_oonfX2
o`00O`09oookJ_l007oo001oo`00Oooonf[ookh0o`3o1Ol007ooj`3o00?ooo]Z00?o001ooomG0?l0
07l01?oonfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Cooo]Z00Wo0=Coo`04oooo
nf[o0:Woo`28oooonf[o0?l^o`3oC_l0oc@01?oonfX01?oob@3oiOl0oookJ_l0oe<2oookJP0>ool0
NOl0[Ooooo]Zool0DOoonf[o01Wooa00oooo0?GoT_l0o`3Xool0odgoP_l0onGo0?lao`03o`00O`?o
oo]Z00Wo8?l0obH0ool007oof_l0ool04ooUo`3oo`2Cooo:0?l0oa/00ooUo`02oomi0003oomB0?ni
o`3ooo]Z00;ooo]Z00?o07?ooookJ_oonfX00_oonfX01?oo0>[ooo]Zoomi0?oo0?`4oomi00SoiOl0
0oooN@001?lH0?ooobP0oolX0?oo_P05onGo0004o`3Dool0odkoo`00ool000GoobP01_oo0007oolX
0003ool00?ooN@3oogT000SoogT01?oo00000ooonf[o0?lcooo90004ool00003oomi0?lV0?ooogT0
00?oogT000OoobP0oi;o0?oo:03oo`00ool0NOl0oe?o0?lM00;ooo]Z00Co0?m>o`28ool01?oo0=Co
0_oonfX02oooP@3ooo]ZoookJ_oonf[oo`0]oookJ_ooE`3ooo]Zon/0oooo_P3ooo]Z00;o001o00Go
oi00oookJ_lH0?oooo]ZofP0o`02o`00O`09onGo0?l007ooogT0o`00OomQ0?ooC@3oooo90?oo06co
ogT000;oolT000_o/ol0ool0gOoonf[oo`<0oookJ_l0nooooo]Zoc_o0?ooK03oolT0o`1go`02ooo9
0008o`2Voooonf[ojol0oookJ_oo1P3o603ooookJ_oo0?`2oookJP03oonB0?oonf[ooo]Z00;ooo]Z
00?oo`3ZoookJ_oonfX02OoonfX00ol0Looooo]ZoookJP05oookJP?oU?l000_ooe80oiCo0?nDo`3o
02[oocoo0?l0oegoN?l0ocd0ool0omoooo]Zo`00O`0:onGo0004ool0TooUo`3oo`0ConGo00?ooo]Z
00Kof_l0oookJ_oonf[ooo]ZodCo0?lPo`0?oookJP0?oc7o0?oonf[ooo]Zo`3oFooonf[oP_l0oook
J_l0ok7o033oo`3oCOl0j?oooo]Zo`H0oooonf[oT_l000?ooo]Z00?o403oool0J_l06Ol00ol007l0
1?oo057o5@3ooookJ_l0[Ol2oookJP04ool0NOl007oo001oo`00O`?ooo]Z0ol007m0oookJP?o001o
00?ooo]Zo`1goooonfX00_oonfX01OooK03ooo]Zoon10?lko`3o001o00?ooo]Z00?o001oo`3kool0
07l00_oonfX02Ooo0`3ooo]ZoookJ_mi0?oooo]Zool0gOl05ooo0:?ook?o0005oookJP05o`3og_oo
08Oooo]ZoookJ_oo06`00_oonfX01Om=0?oooo]ZoookJ_mQ0?oo0?m500?ooo]Z00GohP3oo`3oT?oo
nf[ooo]Zo`3oTP06oookJP09ofP0oooonf[ooo]ZoookJ_lH0?oo07CoonKo0?oonf[ooi0000;ooo]Z
0_l007l02Ooonf[o001oo`00Ool007oooo]Zoonn0?l007oo0?l5on/0o`03oookJP;o001o00?ooeL0
oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Cooo]Z00Go0=Co
o`04oooonf[o0:Woo`28o`02oookJP03o`3oC_l0ocCooo]Z00?ooo]Z00Co0>7oo`3o7Ol0o`So0?mC
0ooonfX03_oo07Wo0:goool0DOlE0?oo01Wooa00oooonf[oT_l0o`3Xool0odgo033ooh;o0?l0oe_o
<Ol00_l007l3oookJP0@ob3o0?lV0?oo001oom[o0?l007ooo`0Cool0TooobP3o4P3oo`3o6ol007oo
0?oOogSo0?loo`3ooe80o`3o<`?ooo]Z00?o07?ooookJ_oonfX00_oonfX06_oo0>[ooo]ZoookJ_oo
TP3oo`3loookJ_oo1P3oZ03oo`1gooooK03o>ol0oookJ_oo0=go/ol0o`3og_oo06coC@3oo`3oT?oo
nf[oJ03ooaP0ooooT03ookh0og00ooooE`3oo`0]0_oonfX03?l0e?oo0?m>oookJ_l0oago403ooi;o
0?l0oe_ooo]ZobH0oooonf[o4P3ooomB00;ooo]Z00Coo`3fo`000?l0003o/ol00_oonfX00omQ0?oo
oo]ZoookJP03oookJP03of40oonco`3ooo]Z00;ooo]Z00?oo`3foookJ_oonfX01?oonfX01Ol0oc?o
oe80o`3ogolB0?ooolX000;ooo]Z01;o9P3ooookJ_oonf[ooo]Zo`3oFol60?ooT_l0oa00oooo057o
o`1io`3oDol0oago0>7ooookJ_l0ocCo0?m>o`2Yool0e?l2oookJP07oon10?oonf[ooo]ZoookJ_oo
02gooo]ZoomG0002oookJP03on/0oooo_P3ooo]Z00;o001o00Cooi00oaP0oooonf[oJ03o0ol007l0
2?l0oi;ohP3oo`00Ool0odGoH@3oodd0oooo06coo`270_l007l01?nco`3o0:?oool0gOoo0`02oook
JP0?o`3koolko`3ooh40oom/0?l0Moooo`3iojP0oooonf[o0:Koool0m_o[o`3oo`H0oaP0oooonf[o
o`3l00;ooo]Z00?ooi80oookJ_oonfX00_oonfX00ooo0>[ooo]ZoookJP09oookJP03o`1coooonf[o
oo]Z00Sooo]Z00[ooe80oookJ_l007oo02[oocoo0?l0g?ooN?l0ocd0ool0omoooo]Z0ol007l2oook
JP04o`3o6ol007oo001oooo:00;ooo]Z00?oo`2CoookJ_oo01<01?oonfX01_oQo`3of_l0oookJ_oo
nf[o9P3oob3o00oooo]Z013o<Ol0oookJ_oonf[o0?mKoookJ_n2o`3o0?n`o`3o/Ol0<?oo0?m=oook
J_l0j?oo1P3ooookJ_oo0?GoT_l00ooonfX00ol@0?oooo]Zo`0Io`03o`00O`07ool0DOlE0?oooo]Z
o`2]oooonf[oo`1ioookJP03o`00O`?ooo]Z0ol007lLoookJP009_oonfX3o`00O`03oookJ_l0Mooo
oo]Z00?ooo]Z00CoA?l0o`00OooUo`3o>ol00ooonfX2o`00O`0<oiCo0?oonf[ooo]ZoookJ_oo0`3o
oo]ZogT0oooonf[oo`3MoookJ_l0Xooo/ol01_oonfX01?l0omkoo`27oookJ_oo06`2oookJP06odd0
oooUo`3ooo]Zof40oooonf[o0?m50ooonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Gooo]Z00?oJ03o
oookJ_oonfX00_oonfX01OlH0?ooi_l0oookJ_oonf[ooi0000?ooo]Z1Ol007l01Ooonf[ookh0o`3o
1Ol007ooj`3o00?ooo]Z00?o001ooomG0?l007l01?oonfX00ooo02gooo]ZoookJP04oookJP03oon1
0?oonf[ooo]Z00?ooo]Z00Wo0=CooookJ_l01?oo0:WooookJ_l0R?oooo]Zo`3o;_l0odh01OoonfX0
1?oob@3oiOl0oookJ_l0oe<2oookJP0>ool0NOl0[Ooooo]Zool0DOoonf[o01Wooa00oooo0?GoT_l0
o`3Xool0odgoP_l0o`3oFolao`03o`00O`?ooo]Z00Wo8?l0obH0oooJo`3ooo]Zool04ooo09?oiOl0
ooo:0?l0oa/00ooUo`02oomi0003oiCo0?nio`3ooo]Z00;ooo]Z00?o07?ooookJ_oonfX00_oonfX3
oomi0003ool0o?ooN@3oogT000;oogT000?o07Oooc_o0?oUo`001OoUo`02oolX0006oomi0?lH0?oo
obP0oolX0?oo_P3oogT00ooUo`000ol0e?ooo`00o`3oCP03ool000?oobP01_oo0008oolX0003oaP0
ooooN@3oogT000SoogT01?oo0002oookJP03oomB0?oo:03oo`0000;oo`0000?oogT0obH0ooooN@00
0oooN@000ooo:03oT_l0oolX0002oolX0008o`3oDol0oagooo]ZoookJ_l0odko08Soo`2Yool0e?l3
oookJP0:oon10?oonf[ooo]Zool0;Ooonf[ooeL0oookJ_o[0?oookh0oookJP;o001o00Gooi00oook
J_lH0?oooo]ZofP0o`05oomi0006o`00OomQ0?ooC@3oooo90?oo06coogT00_oob@002onco`3oo`3M
oookJ_oo0`3ooo]Zo`3koooonf[o>ol0oon10?l0oi[o07Oo00;oolT000_o0:KooookJ_o[o`3ooo]Z
ool60?lH0?oooo]Zool0o?oonf[ooi80oolF0004oookJP03ool0j_oonf[ooo]Z00Wooo]Z00?o07?o
oookJ_oonfX01_oonfX2oiCo000;oomB0?nDo`3oU?l0o`0Zooloo`3o0?mMogSo0?lm0?oo0?oOoook
J_l007l02_oUo`001?oo09?oiOl0ool04ooUo`03oookJP06om[o0?oonf[ooo]ZoookJ_m4o`3o8?l0
3ooonfX00olao`3ooo]Zo`3oF`02oookJP05oh;o0?oonf[o033ooookJ_l0odd00_oonfX00ol60?oo
oo]Zoi;o0003oookJP03oa00oooo06[o01Wo00?o001o00Coo`1AoaD0oooonf[o0:go0_oonfX01?oo
07Wo001oo`00Ool007l3oookJP?o001o@?oonfX3o`00O`03oookJ_l0Mooooo]Z00;ooo]Z00Goof`0
oookJ_ooP@3o>ol0o`00O`03oookJP03o`00Ool0nooo001o00;ooo]Z00Woo`<0oookJ_oonf[oN@3o
oookJ_oo0=go01Ooo`2Soonco`001OoonfX01Ol0omkoo`27oookJ_oonf[oo`1/00;ooo]Z00GoC@3o
oookJ_mQ0?oooo]Zo`3oA@03oookJP05on80ool0oi3ooo]ZoookJ_l0oi801_oonfX02OmX0?oooo]Z
oookJ_oonf[o603oo`1doooVo`3ooo]Zoon@0003oookJPGo001o00Gooo]Zoonn0?l007oo0?l5on/0
o`03oookJP;o001o00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP04oookJP03oon10?oo
nf[ooo]Z00?ooo]Z00Ko0=CooookJ_l01?oooo]Zo`2Yool0R?l2oookJP03o`3oC_l0ocCooo]Z00?o
oo]Z00Co0>7oo`3o7Ol0o`So0?mC0ooonfX03_oo07Wo0:goool0DOoonf[o01Wooa00oooonf[oT_l0
o`3Xool0odgo033ooh;o0?l0oe_o<Ol00_l007l3oookJP0@ob3o0?lV0?oohOl0om[o0?l007ooo`2C
o`3ioooobP3o0?lKoookJ_l007oo0?oOogSo0?oonf[ooe80o`3o<`?ooo]Z00?o07?ooookJ_oonfX0
0_oonfX09ooo0>[ooo]ZoolF0?ooTP3oo`3loaP0oooo1P3oZ03oo`1gooooK03o>ol0oookJ_oo0=go
/ol0o`3og_oo06co0?m5o`3oT?mX0?ooi_l0oaP0oooonf[ookh0og00ooooE`3oo`0]oookJ_l0e?oo
00Coo`3oC_l0oagoo`1ioi;o0?oonf[o0?mKoookJ_lV0?oo4P3ooomB0002oookJP06ool0m_l0003o
0000ok?o0?l0003ooo]Z1_lH0?l2oookJP05of40oonco`3ooo]ZoookJ_oo0?H01ooonfX01?ooDP3o
0?oOoookJ_oobP02oookJP0BobH0oolPo`3ooo]ZoookJ_l0oe_o1P3ooi;o0?l@0?ooo`1Aool0NOl0
oe?o0?lMo`3Qoooonf[o0?ldo`3oC_l0ZOoo0=Co0ooonfX01_ooP@3ooo]ZoookJ_oo02gooo]ZoomG
00;ooo]Z00?oj`3ooonn0?oonfX00_l007l01OooT03oi_l0oaP0oooonf[oJ03o00;o001o00So0?nB
on80ool007oo0?m5of40oom=0?ooo`1/ool0Q`;o001o00Co/ol0o`2Soooo0=goo`<00_oonfX04_l0
nooo>ol0oon10?ooK03o07Ooool0nOnX0?oooo]Zo`2Voooo0?Kojol0ool60?lH0?oooo]Zool0o?oo
nf[ooi80oolF00Cooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ol0Looooo]ZoookJP08oookJP0:oomB
0?oonf[ooo]Zo`0Zooloo`3o0=coogSo0?lm0?oo0?oOoookJP?o001o0_oonfX01?l0oa_o001oo`00
OooobP02oookJP03ool0Tooonf[oo`0C00Cooo]Z00KohOl0om[o0?oonf[ooo]ZobH0oolPo`0?oook
JP0@oc7o0?oonf[ooo]Zo`3oFooonf[oP_l0o`3o/?l0ok7o033oo`3oCOl0j?oooo]Zo`H0oooonf[o
o`3eoi;o00;ooo]Z00Co05gooa00oooonf[o01Wo0ol007l01ooo057o5@3ooookJ_l0[Ooooo]Zool0
NOoonfX00ol007l3oookJP?o001o7?oonfX002Oooo]Z0ol007l00ol0Mooooo]Zo`00O`02o`00O`06
odCo0?oonf[oiOl0oc_o0?l007oooo]Z0ol007l03?nDo`3ooo]ZoookJ_oonf[oo`<0oookJ_mi0?oo
oo]Zool0gOoonf[o0:?ook?o00Kooo]Z00coo`27oookJ_oonf[oo`1/oookJ_m=0?oooo]Zool^0?oo
nf[oH@3ooookJ_l0odD3oookJP05on80ool0oi3ooo]ZoookJ_l0oi801OoonfX00omX0?oooo]Zoook
JP02oookJP05oaP0oooVo`3ooo]ZoookJ_ooT0000ooonfX5o`00O`07oookJ_oo_P3o0?l5o`00Ooo[
0?oo001ooookJP02o`00O`03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01OoonfX00ooo
P@3ooo]ZoookJP03oookJP05o`3Doooonf[o00Coo`2Yool0R?l00_oonfX00ol0obko0?m>oookJP03
oookJP;oolT000?oiOl0oookJ_l0oe<00_oonfX03_oo07Wo0:gooookJ_oo057ooo]Zo`0Iool@0?oo
T_l0o`H0ool0j?oo0?m=oh;o0?l0oe_o<Ol01?l007l2oookJP09ob3o0?lV0?oof_l0oookJ_oo01?o
o`2Co`00OooobP3o0?lK00?oiOl000CoogT0o`0ZoonDo`3o^Ol00ooonfX00ol0Looooo]ZoookJP02
oookJP?oogT000?oo`3loomi0?ooN@000_ooN@001Ol0Mooo>ol0ool00?oo003o/ol000?oiOl00ooo
:0002_lH0?ooobP0ooo90?oo_P3oogT0ool0;OooN@3oiOl0o`3Dool0odh5ool00003oolX0?oo003o
o`0000?oo`001Ooo:0000ooo003oobP0oolX0002oolX00;oL03o0oooN@000omQ0?ooogT0oomi0003
oomi00Coo`000_oonfX00oooDP3oobP0ool00002ool00003oomi0?lV0?ooogT000?oogT000?oobP0
oi;o0?oo:0000_oo:0002?oonf[o0?mCoookJ_oonf[o0?m>oookJ_l0ZOoo0=Co0ooonfX02_ooP@3o
oo]ZoookJ_oo02gooo]ZoomG0?oonf[oj`3ooonn0?oonfX2o`00O`05oon@0?l007oo603ooookJ_mX
0?l02?ooN@000ooob@3oo`1/oomi0002ooo9000;ok?o0?oo0=gooo]Zool30?oonf[o0?_ooookJ_lk
o`3ooh40o`3oV_l0Mol00_oob@002ol0Y_oooo]Zooo90?oonf[oo`H0oaP0oooonf[oo`3loookJ_oo
TP3ooaH000Cooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ol0Looooo]ZoookJP06oookJP;oU?l000Co
oe80oiCo0?l0oego02[o0_l0oed01_mho`3o?@3oo`3ogol0oegooo]Zo`00O`GoiOl000SoolX0onGo
0?oUo`3oiOl0ool0TooUo`3oo`0ConGo00?ooo]Z00Kof_l0oookJ_oonf[ooo]ZodCo0?lPo`0?oook
JP03oc7o0?oonf[o0?mK00;ooo]Z00GoP_l0o`3o/Ol0<?oooo]Zo`3oC@02oookJP03o`H0oooonf[o
T_l000?ooo]Z00Co403oool0J_l06Ooooo]Z0_l007l01?oo057o5@3ooookJ_l0[Ol2o`00O`03ool0
NOoonf[o001o00;o001o00Cooo]Zo`00Ool007oo001o@_oonfX3o`00O`08o`1goooonf[o001oo`00
OoooK03ooo]Zoon10?lko`02o`00O`04oookJ_l007oo001oo`3ko`?ooo]Z00Woo`<0oookJ_oonf[o
N@3ooookJ_oo0=go01Ooo`2Soonco`001OoonfX03?l0omkoo`27oookJ_oonf[oo`1/oookJ_m=0?oo
obh0oookJ_mQ0?oooo]Zo`3oA@?ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP09ofP0oooo
nf[ooo]ZoookJ_lH0?oo07CoonKo0?oonf[ooi0000?ooo]Z1Ol007l01ooonf[ookh0oookJ_l0o`Go
j`3oo`00OooonfX00ol007l01OooE`3ooo]ZoookJ_oonf[oo`0]00Oooo]Z00?ooh40oookJ_oonfX0
0ooonfX01_l0e?oooo]Zo`04oooonf[o0:Woo`28o`;ooo]Z00?o0?m>o`3o=?oonfX00ooonfX01?l0
hOoo0?lMo`3o2?l0oe<3oookJP0>ool0NOl0[Oooo`1AoookJ_l06Ooo403ooi;o0?l60?oo0>Soo`3o
COl0ok3oP_l0o`3oFolao`03o`00O`;ooo]Z00Wo8?l0obH0oooQo`3of_l0oookJ_oo09?o0?Woooo:
0?l0oa/00_l007l01Ol0omooN?l0o`0ZooooDP3o0?lc00?ooo]Z00?o07?ooookJ_oonfX00_oonfX0
6Ooo0>[ooo]ZoolF0?ooTP3oo`3lool60?o[o`3oZ03oo`1gooooK03o>ol0ool30?oo0=go/ol0ool0
K?mQ0?oo0?n@o`3oT_mX0?oo603ooon@0?oonf[ookh0og00ooooE`000_oonfX03?l0e?oo0?m>oook
J_l0oago403ooi;o0?l0oe_ooo]ZobH0oooonf[o4P3ooomB00;ooo]Z00Coo`3fo`000?nco`3o0000
0_lH0?l6og00o`05oaP0oooonf[ooo]Zof40oonco`000_oonfX00ooo0?Kooo]ZoookJP04oookJP04
oomB0?l0omoooo]Zooo:00;ooo]Z01;ohOl0obH0oooonf[ooo]Zo`3oFol60?ooT_l0oa00oooo057o
o`1ioookJ_l0oe?o0>7ooookJ_l0ocCo0?m>o`2Yool0e?l3oookJP06oon10?oonf[ooo]Zool0;Ooo
nf[ooeL00_oonfX00oo[0?oookh0oookJP02o`00O`05oon@0?oVo`3o603ooookJ_mX0?l00_l007l0
3_l0oi;ohP3oo`00Ool0odGoH@3oodd0oooo06coo`27o`00Oooonf[o/ol0o`2Soooo0=goo`<00_oo
nfX04_l0nooo>ol0oon10?ooK03o07Ooool0nOnX0?oo0:KooookJ_oo0?Kojol0ool60?lH0?oooo]Z
ool0o?oonf[ooi80oolF00Cooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ol0Looooo]ZoookJP08oook
JP09oomB0?oonf[ooo]Zo`0Zooloo`3o0=coogSo0?lm0?oo0?oO00;ooo]Z0ol007l01Ooonf[o0?lK
o`00Ool007ooolX000;ooo]Z00?oo`2CoookJ_oo01<01?oonfX01_oQo`3of_l0oookJ_oonf[o9P3o
ob3o00oooo]Z00?o<Ol0oookJ_l0oe/00_oonfX02on2o`3o0?n`oookJ_l0<?oo0?m=o`3Xoooonf[o
1P3ooookJ_oo0?GoT_l000;ooo]Z00Go05gooa00oooonf[o01WooookJP02o`00O`03ool0DOlE0?oo
0:go00;o001o00?oo`1ioookJ_oonfX00ol007l01?oonf[o001oo`00Ool007lMoookJP009ooonfX3
o`00O`06o`1gool007oo001oo`00Oooonf[oA?l00_oUo`000olko`3o001oo`00O`03o`00O`0<oiCo
0?oonf[ooo]ZoookJ_oo0`3ooo]ZogT0oooonf[oo`3Mo`0Gool0Xooo/ol01OoonfX03Ol0omkoo`27
oookJ_oonf[oo`1/oookJ_m=0?oooo]Zool^0?oonf[oH@3ooookJ_l0odD00_oonfX01OoR0?oooo]Z
o`3oT?oonf[o0?nB00Kooo]Z00OoJ03ooookJ_oonf[ooo]ZoaP0ool0M?ooi_l000;ooo]Z00?ooi00
oookJ_oonfX00_oonfX4o`00O`05oookJ_oo_P3o0?l5og00ooo[0?l01?l007l00oooE`3ooo]Zoook
JP02oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX00ooonfX01Ol0e?oooo]Zo`04
ool0ZOoo08So00;ooo]Z00?o0?m>o`3o=?oonfX00ooonfX2ooo90003onGo0?oonf[o0?mC00;ooo]Z
00ooo`1io`2]oolE0?ooo`1AoookJ_l@0?oooo]Zoi;o0?l60?oo0>Soo`3oCOn2o`3o0?mKoc7o0?oo
nfX01Ol007l02OlV0?oo001oom[o0?oonf[oo`0Cool0Tol007oo0?lKonGo0004oomi00;oU?l01?oo
nfX01?l0Looooo]ZoookJ_oonfX4oomi0006ool0o?ooN@3oogT0oomi0?l0Mooo>ol00_oo00001Onc
o`3oo`00oomi0?oo06coiOl000?oobP000Go603ooolX0?oo_P3o0?l5oomi0002oookJP03o`3Doooo
003o0?m>00Woo`001_oo:004ool000?oobP000?oogT0ool00?oo00001_ooN@05ool000;ooo]Z00?o
oe80o`0Zoooo00000_oo00003OooN@3o9P3ooomi0?ooN@3oo`00oomi0?oo:03oT_l0oolX0?oo057o
o`00oookJ_l0oe<00_oonfX01Ol0odkooo]Zo`2Yool01?oo0=Co00;ooo]Z00Wooh40oookJ_oonf[o
o`0]oookJ_ooE`3ooo]Zon/0oooo_P000_oonfX01_l007oooi00o`00OolH0?oo001oofP0o`SoogT0
00?oolT0ool0K?ooN@000_oob@006?nco`3oo`3MoookJ_oo0`3ooo]Zo`3koooonf[o>ol0oon10?l0
oi[o07Ooooo90?nX0?oo0:KooookJ_oob@3ooo]Zool60?lH0?oooo]Zool0o?oonf[ooi80oolF00Co
oo]Z00?oo`3ZoookJ_oonfX02OoonfX00ol0Looooo]ZoookJP06oookJP;oU?l000Cooe80oiCo0?l0
oego02[o0_l0oed01_mho`3o?@3oo`3ogol0oegooo]Zo`00O`GoiOl000OoolX0onGo0?oUo`3oiOl0
ool0TooUo`3oo`0C00Cooo]Z00Kof_l0oookJ_oonf[ooo]ZodCo0?lPo`0?oookJP03oc7o0?oonf[o
0?mK00;ooo]Z00GoP_l0o`3o/Ol0<?oooo]Zo`3oC@02oookJP03o`H0oooonf[oT_l000?ooo]Z00Co
403oool0J_l06Ooooo]Z0_l007l02?oo057o5@3oo`00Ool0[Ooo001ooookJ_oo07Wooo]Z1ol007m2
oookJP?o001o00So07Ooo`00Ool007oo001ooom/0?oonf[ooh40oc_o00Go001o00Go0?_ooookJ_oo
nf[ooo]Zool30002oookJP05ogT0oooonf[oo`3MoookJ_nco`001_oonfX03?l0omkoo`27oookJ_oo
nf[oo`1/oookJ_m=0?ooobh0oookJ_mQ0?oooo]Zo`3oA@?ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3o
TP06oookJP06ofP0oooonf[ooo]ZoaP0oooonf[oi_l00_oonfX00oooT03ooo]ZoookJP02oookJPCo
001o00Gooo]Zoonn0?oonf[oL03oon/0o`05o`00O`05oomG0?oonf[ooo]ZoookJ_oo02d01ooonfX0
0oooP@3ooo]ZoookJP03oookJP06o`3Doooonf[o00CooookJ_l0ZOoo08So0_oonfX00ol0odko0?ld
oookJP03oookJP04o`3Qool0oago0?l8o`3oD`?ooo]Z00koo`1io`2]oooo057ooo]Zoa00oooo06[o
T_l0o`H0ool0j?oo0?m=o`3o/?n2o`3o0?mKoc7o00Go001o00?o8?l0obH0oooJo`000_oonfX01?oo
09?o0?Woooo:0?l0oa/2o`00O`05o`3ogomho`3o02[ooomB0?l0oc<00ooonfX00ol0Looooo]Zoook
JP02oookJP0Pool0j_oonf[ooi80oookJ_oo0?coo`H0on_o0?l0Moooo`3ioc_o0?l0noooo`3Mok?o
0?oMo`3oo`1/of40ool0oi3ooo]ZofP0oolH0?oooi00oonn0?m`0?oooeL0ool0;Ooonf[o0=Coo`04
ool0odkooo]Zool0NOnBo`03oookJP03obH0oolB0?oooe8000;ooo]Z00Koo`3foookJ_nco`3o0000
oaP0oom`0?l2oookJP03o`3Doooonf[ooo]Z00;ooo]Z00KoL03ooaP0oooonf[oH@3ooookJ_nco`02
oookJP03ool0m_oonf[ooo]Z00?ooo]Z00Sooe80o`0Zoooonf[o4P3oooo:0?oonf[ohOl0obH0o`;o
oo]Z00oo0?mKo`3o/?nBo`3o403oool0DOoo07Wooo]Zo`3oDol0hOoooo]Zo`3o=?l0odko0:Woo`04
ool0e?l00_oonfX01_ooP@3ooo]ZoookJ_oo02gooo]ZoomG00;ooo]Z01[oj`3ooonn0?oonf[ooo]Z
o`00OoooT03oi_l0oaP0ool007ooJ03oo`00Oooonf[o0?nBon80ool007oo0?m5of40oom=0?ooo`1/
ool0Qol007oooo]Zok?o0?l0Xoooo`3Mool300;ooo]Z01;o0?_ooc_o0?ooP@3oof`0o`1goooo0?Wo
Z03oo`2Voooonf[oo`3fon_o0?oo1P3o603ooookJ_oo0?cooo]ZoonB0?oo5P04oookJP03ool0j_oo
nf[ooo]Z00Wooo]Z00?o07?ooookJ_oonfX02?oonfX02OooDP3ooo]ZoookJ_l0:_oo?ol0o`3Loomh
o`3o?@3oo`3og`02oookJPCo001o00Co0?lKo`00Ool007ooolX00_oonfX00ooo09?ooo]Zool04`04
oookJP06on7o0?oJo`3ooo]ZoookJ_lV0?oo8?l03ooonfX00olao`3ooo]Zo`3oF`02oookJP0;oh;o
0?l0ok3ooo]Zo`0`ool0odgo0>SooookJ_l60?oooo]Zool0mOnBo`000_oonfX01Ol@0?ooo`1Zoook
J_l06Ooooo]Z00;o001o00?oo`1AoaD0ool0[Ol00_l007l00ooo07Wooo]ZoookJP07o`00Oagooo]Z
000YoookJP04o`00Ool0Mooo001oo`00O`;ooo]Z00CoA?l0onGo0?oUo`3o>ol01?l007l00ooonf[o
U?l0oookJP02oookJP08ool30?oonf[oN@3ooookJ_oo0=go01Ooo`2Soonco`05oookJP0=o`3og_oo
08Oooo]ZoookJ_oo06cooo]Zodd0oooonf[oobh0oookJ_mQ0?oooo]Zo`3oA@02oookJP05on80oooo
nf[o0?n@oookJ_l0oi801_oonfX02OmX0?oooo]ZoookJ_oonf[o603oo`1doooVo`3ooo]Zoon@0006
oookJP?o001o00Cooo]Zoonn0?l0o`Goj`3o1Ol007l00oooE`3ooo]ZoookJP02oookJP03ool0;Ooo
nf[ooo]Z00Cooo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0e?oooo]Zo`04ool0ZOoo08So00;ooo]Z
00?o0?m>o`3o=?oonfX00ooonfX01Ooob@3oiOl0ooo90?oonf[o0?mC00;ooo]Z00?oo`1io`2]oooo
05400_oonfX02Ol@0?ooo`3eoi;o0?l60?oo0?m=oh;o0?l0ok3o0?mKoc7o0002oookJPCo001o00Wo
9P3ooookJ_oJo`3ooo]Zool04ooo09?o001oo`3o6ooUo`001?ooN@02oiCo00Cooo]Z00Co07?ooook
J_oonf[ooo]Z0_ooN@000ooonf[oo`3loomi0003oomi0008o`1goooo:03oo`00ool00?nco`3oo`00
oomi0?oo06`3oolX0004ooo90?lH0?ooobP0oonn00;oogT00_oonfX00ol0e?ooo`00o`3oCP07ool0
00OoobP01ooo00000ooo:03oogT0ool00003ool000CoogT00ooo:0001_oo003ooo]ZoookJ_oonf[o
0?lcoomB00?oo`0000googT0obH0ooooN@3oogT0ool00?l0oe_oobP0oi;o0?oo003oo`1Aool00?oo
nf[o0?mC00;ooo]Z00Go0?m>oookJ_l0ZOoo00Coo`3Do`02oookJP09oon10?oonf[ooo]Zool0;Ooo
nf[ooeL0oookJ_o[0?oookh000?ooo]Z00Gooi00o`00OolH0?oo001oofP0o`08oomi0003ooo90?oo
06coogT000;oolT001;o/ol0ool0gOoonf[oo`<0oookJ_l0nooooo]Zoc_o0?ooP@3o0?nJo`1goooo
b@3oZ03oo`2Voooonf[oolT0oookJ_oo1P02oookJP04ool0o?oonf[ooi80oolF00Cooo]Z00?oo`3Z
oookJ_oonfX02OoonfX00ol0Looooo]ZoookJP06oookJP05okWo0?nDo`3ooe80oiCo0?l0:_l00ol0
oed01?mho`3o?@3oo`3ogol0oed2oookJPGoiOl000OoolX0onGo0?oUo`3oiOl0ool0TooUo`3oo`0C
00Cooo]Z00Kof_l0onGo0?oUo`3oA?l0onGo0?lPo`03onGo00cooo]Z00?o<Ol0oookJ_l0oe/00_oo
nfX01On2o`3o0?nao`0`oooonf[o0?m=00;ooo]Z00?o1P3ooookJ_nBo`000ooonfX00ol@0?ooo`1Z
o`0Io`03oookJP04ool0DOlE0?oo001oo`2]o`;ooo]Z00?oo`1ioookJ_oonfX01Ol007m5oookJP09
o`00Ool0Mooo001oo`00Oooonf[oof`0oookJ_ooP@3o>ol000Go001o00Go0?_ooookJ_oonf[ooo]Z
ool30002oookJP05ogT0oooo0=go01Ooo`2Soonco`001_oonfX03?l0omkoo`27oookJ_oonf[oo`1/
oookJ_m=0?ooobh0oookJ_mQ0?oooo]Zo`3oA@?ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP05oook
JP09ofP0oooonf[ooo]ZoookJ_lH0?oo07CoonKo0?oonf[ooi0000Kooo]Z0ol007l01?oonf[ookh0
oookJ_o[0?l5o`00O`03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3o
oo]ZoookJP04oookJP05o`3Doooonf[o00Coo`2Yool0R?l00ooonfX00ol0odko0?ldoookJP03oook
JP04o`3Qool0oago0?l8o`3oD`?ooo]Z00ooo`1io`2]oooo057ooo]Zoa00oooonf[oT_l0o`H0ool0
odgo033ooh;o0?oonf[o0?mKoc7o0?oonfX01?l007l00olV0?oooo]Zom[o0002oookJP04ool0Tol0
nOooolX0o`3o6`;o001o00CoN?l0o`3Lool0:_oooe801?oonfX00ol0Looooo]ZoookJP02oookJP0P
ool0j_oonf[ooi80ool0o?oonf[oo`H0on_o0?l0Moooof`0oc_o0?l0noooo`3Mok?o0?l0omkoo`1/
of40ool0oi3ooo]ZofP0oolH0?oooi00oonn0?m`0?oooeL0ool0;Ooonf[o0=Coo`04ool0odko0?l8
ool0NOnBo`02oookJP03obH0oooonf[ooe8000?ooo]Z00Goo`3fok?o0?l0003o603oo`000004o`04
o`?o0=Co00Oooo]Zog00oooVo`3o603ooookJ_mQ0?oo/ol000;ooo]Z00?oo`3fool0o?oonfX00ooo
nfX02?l0oc?ooe80o`3ogolB0?ooolX0oookJ_oQo`3o9P3o0_oonfX03ol0oe_o0?n`oi;o0?l@0?oo
o`1Aool0NOoonf[o0?mCo`3Qoooonf[o0?ldo`3oC_l0ZOoooo]Zo`3Do`02oookJP06oon10?oonf[o
oo]Zool0;Ooonf[ooeL00_oonfX00oo[0?oookh0oookJP02oookJP05oon@0?oVo`3o603oo`00OomX
0?l00_oonfX02?l0oi;ohP3ooookJ_l0odGoH@3oodd0oooo06coo`270_oonfX01?nco`3o0:?oool0
gOoo0`02oookJP0Bo`3koolko`3ooh40oom/0?l0Moooo`3iojP0ool0Y_oooo]Zool0m_o[o`3oo`H0
oaP0oooonf[oo`3loookJ_ooTP3ooaH01?oonfX00ooo0>[ooo]ZoookJP09oookJP03o`1coooonf[o
oo]Z00Oooo]Z00[o^Ol0oomB0?oonf[o02[ooookJ_loo`3o0=coogSo0?lm0?oo0?oO0ooonfX3o`00
O`04o`3o6ol007oooo]Zooo:00;ooo]Z00?oo`2CoookJ_oo01<01?oonfX01_oQo`3of_l0oookJ_oo
nf[o9P3oob3o00oooo]Z00?o<Ol0oookJ_l0oe/00_oonfX02_n2o`3o0?n`o`0`oooonf[o0?m=o`3X
oooonf[o1P3ooookJ_nBo`03oookJP04oa00oooo06[ooo]Zo`0Io`?ooo]Z00Koo`1AoaD0ool0[Ooo
001ooookJ_oo07T3oookJPGo001o7_oonfX002[ooo]Z00?o07OooookJ_oonfX00_oonfX01?m4o`3o
iOl0oookJ_lko`04oookJP03oiCo0?oonf[ooo]Z00;ooo]Z00Soo`<0oookJ_mi0?oooo]Zool0gOl0
5ooo0:?ook?o00Gooo]Z00go0?oNool0Qooonf[ooo]Zool0K?oonf[oC@3ooookJ_oo;P3ooo]Zof40
oooonf[o0?m500;ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP09ofP0oooonf[ooo]Zoook
J_lH0?oooo]ZonKo0?oonf[ooi0000Wooo]Z00Cookh0oookJ_l0o`Goj`3o1?oonfX00oooE`3ooo]Z
oookJP03oookJP03ool0;Ooonf[ooo]Z00Cooo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0e?oo00Co
oookJ_l0ZOoo08So00;ooo]Z00?o0?m>o`3o=?oonfX00_oonfX2ooo90004onGo0?oob@3ooo]Zo`3o
D`;ooo]Z00?oo`1ioookJ_oo05400_oonfX02Ol@0?ooo`3eoi;o0?l60?oo0?m=oh;o0?oonf[o0?mK
oc7o0005oookJP09ob3o0?lV0?oooo]Zom[o0?oonf[oo`2Co`3ioooonf[o0?lK00GoogT00_nDo`04
oookJP04o`1coooonf[ooo]ZoookJP;oogT000SoA?l0ool0o?m4o`3oo`H0odCo0?oo0?Wo07OooolX
00;oo`0000?o/ol0ool00?oo06`01?oo:0001?lH0?ooolT0ooo90?oo_P02oomi0004oookJ_oo003o
0=Coo`3oCPKoo`002Ooo:0000ooo003oobP0ool00003oomi00?oobP01Ooo0003oomi00SoobP000Oo
oe80ool00?oo003oo`00oomi0?lV0?ooogT000;oo`0000So0?mKoolX0?nBo`3oo`00ool0DOoo07Wo
oo]Zo`3oD`;ooo]Z00Go0?m>oookJ_l0ZOoo00Coo`3Do`02oookJP09oon10?oonf[ooo]Zool0;Ooo
nf[ooeL0oookJ_o[0?oookh000?ooo]Z00Kooi00oookJ_lH0?oooo]ZofP0oooonfX8oomi000Fool0
K?ooN@3oogT0oomi0?nco`3oo`3MoookJ_oo0`3ooo]Zo`3koooonf[o>ol0oon10?oonf[o07Ooooo9
0?nX0?oo0:KooookJ_oob@3ooo]Zool600;ooo]Z00Coo`3loookJ_ooTP3ooaH01?oonfX00ooo0>[o
oo]ZoookJP09oookJP03o`1coooonf[ooo]Z00Kooo]Z00Go^Ol0oiCo0?ooDP3oU?l0o`0Zo`03o`3o
G@03ogSo0?lm0?oo0?oO00Cooo]Z0ooUo`000ooonf[oolX0onGo0002onGo0003ool0TooUo`3oo`0C
00Cooo]Z00Gof_l0onGo0?oUo`3oA?l0ob3o0004onGo00cooo]Z00?o<Ol0oookJ_l0oe/00_oonfX0
1On2o`3o0?nao`0`oooonf[o0?m=00;ooo]Z00?o1P3ooookJ_nBo`000ooonfX00ol@0?ooo`1Zo`0I
o`03oookJP06ool0DOoonf[ooo]Zo`2]oooonf[oo`1iC_oonfX02?l0Mooooo]ZoookJ_oonf[oof`0
oon10?l0olco>ol01?oonfX00ol0nooooo]ZoookJP02oookJP08ool30?oonf[ooo]ZogT0oooo0=go
01Ooo`2Soonco`06oookJP04o`3og_oo08Oooo]Zool0K0;ooo]Z00KoC@3oool^0?oonf[oH@3ooook
J_l0odD3oookJP05on80oooonf[ooo]ZoookJ_l0oi801OoonfX02OmX0?oooo]ZoookJ_oonf[o603o
o`1doooVo`3ooo]Zoon@000:oookJP03oonn0?oonf[oj`3o00Gooo]Z00?ooeL0oookJ_oonfX00_oo
nfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Cooo]Z00Go0=Coo`04oooonf[o0:Wo
o`28o`02oookJP03o`3oC_l0ocCooo]Z00Cooo]Z00Co0?lMoookJ_l0o`So0?mC0ooonfX03_oo07Wo
oo]Zool0DOoonf[o403ooookJ_nBo`3o1P3oo`3oCOl0<?ooP_l0oookJ_l0oe_o<Ol01?oonfX04?lP
o`3o9P3ooookJ_oJo`3ooo]Zool0Tooo01?ooo]Zooo:0?l0oa_ooo]Zocd0oomho`3o?ol0o`0Zoooo
DP04oookJP03o`1coooonf[ooo]Z00;ooo]Z023oo`3ZoookJ_ooTP3oo`3loookJ_oo1P3oZ03oo`1g
ooooK03o>ol0o`3koooo0=go/ol0o`3og_oo06co0?m5o`3oT?oonf[o603oonKo0?oonf[ookh0og00
ooooE`3oo`0]oookJ_l0e?oo0?m>oookJ_l0o`So403ooi;o00;ooo]Z00?o9P3ooa80ooooDP000_oo
nfX01ooo0?Kooo]Zok?o0?lH0?oo0000o`04ool000000ol@0?l2oookJP0<o`04ool0e?oooo]Zog00
oolH0?oooo]Zof40oooonf[o/ol0oom/0?oo0?Koo`3l1OoonfX01oooDP3o0?oOoa80oooobP3oo`0C
on7o0?lV0?l00_oonfX03ol0oe_o0?n`o`H0oonBo`3oo`1Aool0NOoonf[o0?mCo`3o7Ooonf[o0?ld
o`3oC_l0ZOoooo]Zo`3Do`02oookJP06oon10?oonf[ooo]Zool0;Ooonf[ooeL00_oonfX00oo[0?oo
okh0oookJP02oookJP05oon@0?oVo`3o603ooookJ_mX0?l00_oonfX02?l0oi;ohP3ooookJ_l0odGo
H@3oodd0oooo06coo`270_oonfX06?nco`3o0:?oool0gOoo0`3ooo]Zo`3koooonf[o>ol0oon10?oo
nf[o07Ooool0nOnX0?oo0:KooookJ_oo0?Kojol0ool60?lH0?oooo]Zool0o?oonf[ooi80oolF00Co
oo]Z00?oo`3ZoookJ_oonfX02OoonfX00ol0Looooo]ZoookJP07oookJP0:okWo0?ooDP3ooo]Zo`0Z
oooonf[o?ol0o`3Loomho`3o?@3oo`3og`Kooo]Z00Co0?lKoookJ_oonf[oolX00_oonfX00ooo09?o
oo]Zool04`04oookJP05on7o0?oJo`3ooo]ZoookJ_lV0?l04?oonfX00olao`3ooo]Zo`3oF`02oook
JP0:oh;o0?l0ok3o033ooookJ_l0odgo0>SooookJ_l60?oooo]Zoi;o00?ooo]Z00Co403oool0J_oo
nf[o01Wo0ooonfX01Ooo057ooo]Zo`2]oooonf[oo`1i02Oooo]Z000ZoookJP03o`1goooonf[ooo]Z
00;ooo]Z00CoA?l0onGo0?oonf[o>ol01?oonfX00onDo`3ooo]ZoookJP02oookJP08ool30?oonf[o
N@3oool0gOoonf[o01Ooo`2Soonco`05oookJP04o`3og_oo08Oooo]Zool0K0;ooo]Z00KoC@3ooook
J_oo;P3ooo]Zof40ool0odD3oookJP05on80ool0oi3ooo]ZoookJ_l0oi801OoonfX00omX0?oooo]Z
oookJP02oookJP05oaP0oooonf[oi_l0oookJ_oUo`002OoonfX01?oo_P3ooo]Zo`3o1Oo[0?l4oook
JP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3ooo]ZoookJP03oook
JP06o`3Doooonf[o00CooookJ_l0ZOoo08So0_oonfX00ol0odkooo]ZoookJP02oookJP;oolT000?o
iOl0ooo90?l0oe<00ooonfX03_oo07Wooo]Zool0DOoonf[o05gooa00oooo0?GoT_l0o`3Xool0odgo
P_l0oookJ_l0oe_o<Ol01OoonfX02OlPo`3o9P3oon7o0?oJo`3ooo]Zool0Tol0nOooolX0o`3o6`04
oomi00CoU?l00_oonfX01?l0Looooo]ZoookJ_oonfX4oomi0005ool0o?lH0?ooo`H0odCo0?oo0?T0
0_oo:002ool00003ok?o0?oo003oo`1/00CoobP000CoiOl0ooo90?oo_P3oL03o0_ooN@001?oo003o
0=Coool00?l0odh4ool000[oobP000Coo`00oolX0?oo003o403o0_oo00001?oo:03oogT0oolX0?l0
e?l5ool000?oogT02ooo:0001?oobP3oogT0obH0ooooN@02ool00008o`3oFooo003oT_l0ool00?oo
057oo`1ioookJ_l0oe<2oookJP05o`3oC_oonf[o0:Woo`04ool0e?l00_oonfX02OooP@3ooo]Zoook
J_oo02gooo]ZoomG0?oonf[oj`3ooonn0003oookJP03oon@0?oonf[o603o00?oiOl02?ooN@005_oo
06coogT0oomi0?ooN@3o/ol0ool0gOoonf[oo`<0oookJ_l0nooooo]Zoc_o0?ooP@3ooo]Zo`1goooo
0?WoZ03oo`2Voooonf[oolT0oookJ_oo1P02oookJP03ool0o?oonf[ooi8000Gooo]Z00?oo`3Zoook
J_oonfX02OoonfX00ol0Looooo]ZoookJP06oookJP05okWo0?nDo`3ooe80oiCo0?l0:_l00ol0oed0
0omho`3o?@3oo`3og`04oookJP?oiOl000?ooo]Zooo:0?oUo`000_oUo`000ooo09?oiOl0ool04`03
oookJP06on7o0?oJo`3oiOl0onGo0?m4o`3o8?l01?oUo`0<oookJP03oc7o0?oonf[o0?mK00;ooo]Z
00GoP_l0o`3o/Ol0<?oooo]Zo`3oC@02oookJP03o`H0oooonf[oT_l000?ooo]Z00?o403oool0J_l0
6Ol00ooonfX01_oo057ooo]ZoookJ_l0[Ooooo]Zool0NDkooo]Z00So07OooookJ_oonf[ooo]Zoom/
0?ooP@3o0?o<oc_o00Cooo]Z00?o0?_ooookJ_oonfX00_oonfX02?oo0`3ooo]ZoookJ_mi0?ooo`3M
o`0Gool0Xooo/ol01_oonfX01?l0omkoo`27oookJ_oo06`2oookJP05odd0oooo;P3ooo]Zof40ool0
odD01?oonfX01?oR0?oooo]ZoookJ_l0oi86oookJP09ofP0oooonf[ooo]ZoookJ_lH0?oo07CoonKo
0?oonf[ooi0000[ooo]Z00?ookh0oookJ_o[0?l01OoonfX00oooE`3ooo]ZoookJP02oookJP03ool0
;Ooonf[ooo]Z00Cooo]Z00?ooh40oookJ_oonfX00ooonfX01_l0e?oooo]Zo`04oooonf[o0:Woo`28
o`;ooo]Z00?o0?m>o`3o=?oonfX01?oonfX00ol0oagooo]Zo`3oD`04oookJP0>ool0NOoo057o5@3o
o`1Mool@0?oooo]Zoi;o0?l60?oo0?m=o`0`oon2o`3ooo]Zo`3oFolao`04oookJP0@ob3o0?lV0?oo
hOl0om[o0?oonf[oo`2Co`3ioooobP3o4P3oo`3o6ooonf[o?@3oogSo0?loo`3o02[ooomB00?ooo]Z
00?o07?ooookJ_oonfX00ooonfX07ooo0>[ooo]ZoonB0?oo0?co603oool60?nX0?oo07Oooom/0?lk
o`3ooo]Zool0gOnco`3oo`1/of40ool0odGo0?n@ofP0oolH0?oooi00oookJ_oo_P3ooo]ZoomG0?oo
nf[o0=Coo`04ool0odkooo]Zool0NOnBo`000_oonfX02olV0?oooo]Zo`3LooooDP3ooo]Zool0m_oo
nf[o/ol0oaP0ool0003o00Co00;o403o0ooonfX03_l@0?oooo]Zo`04ool0e?oooo]Zog00oolH0?oo
oo]Zof40oooonf[o/ol0oom/0?oo0?Koo`3l1OoonfX01oooDP3o0?oOoa80oooobP3oo`0Con7o0?lV
0?l00_oonfX03ol0oe_o0?n`o`H0oonBo`3oo`1Aool0NOoonf[o0?mCo`3o7Ooonf[o0?ldo`3oC_l0
ZOoooo]Zo`3Do`02oookJP06oon10?oonf[ooo]Zool0;Ooonf[ooeL00_oonfX00oo[0?oookh0oook
JP02oookJP0?oon@0?oVo`3o603ooookJ_mX0?oooo]Zo`3oT_l0oi3ohP3ooookJ_l0odGoH@3oodd0
oooo06coo`2700;ooo]Z01;o/ol0o`0Goooo0=goo`<0oookJ_l0nooooo]Zoc_o0?ooP@3ooo]Zo`1g
oooo0?WoZ03oo`2Voooonf[oo`3fon_o0?oo1P02oookJP04ool0o?oonf[ooi80oolF00Cooo]Z00?o
o`3ZoookJ_oonfX02OoonfX00ol0Looooo]ZoookJP07oookJP0:okWo0?ooDP3ooo]Zo`0Zoooonf[o
?ol0o`3Loomho`3o?@3oo`3og`Gooo]Z00Go4P3oo`3o6ooonf[ooo]Zooo:0002oookJP03ool0Tooo
nf[oo`0C00?ooo]Z00?ohOl0oookJ_oJo`000_oonfX00olV0?oooo]ZoookJP0>oookJP03oc7o0?oo
nf[o0?mK00;ooo]Z00[oP_l0o`3o/?l0<?oooo]Zo`3oCOl0j?oooo]Zo`H0oooonf[oT_l00ooonfX0
1?l@0?ooo`1ZoookJ_l06Ol3oookJP05ool0DOoonf[o0:gooookJ_oo07T09ooonfX002[ooo]Z00Wo
07OooookJ_oonf[ooo]Zo`3oV_m4o`3oiOl0oookJ_lko`001?oonfX00onDo`3ooo]ZoookJP02oook
JP08ool30?oonf[oN@3oool0gOoonf[o0:?ooil0oonco`05oookJP04o`3og_oo08Oooo]Zool0K0;o
oo]Z00KoC@3ooookJ_oo;P3oH@3ooookJ_l0odD3oookJP05on80ool0oi3ooo]ZoookJ_l0oi801Ooo
nfX00omX0?oooo]ZoookJP02oookJP05oaP0oooVo`3ooo]ZoookJ_oUo`002OoonfX01?oo_P3ooo]Z
o`3o1Oo[0?l4oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3o
oo]ZoookJP03oookJP06o`3Doooonf[o00CooookJ_l0ZOoo08So0_oonfX00ol0odkooo]ZoookJP02
oookJP;oolT000?o0?lMooo90?l0oe<00ooonfX03Ooo07Wooo]Zool0DOoonf[oo`1Zoa00oonBo`3o
1P3oo`3Xool0odgoP_l0oookJ_lao`001_oonfX02OlPo`3o9P3oon7o0?oJo`3ooo]Zool0Tol0nOoo
olX0o`3o6`04oomi00CoU?l00_oonfX01?l0Looooo]ZoookJ_oonfX4oomi0005ool0o?lH0?ooo`H0
o`2Voooo0?T00_oo:002ool00003ok?o0?oo003oo`1/00CoobP000GoiOl0ool00?oo_P3oL03ooomi
0002ool00003o`3Doooo003o0?m>00?oo`003?oo:0001?oo003o0000o`000?oo0003oolX0003oa00
oooo:03oo`0000Coo`000oooN@0=oolX000<obH0ooooN@3oo`00ool00?l0oe_oo`00oi;o0?oo003o
o`1Aool0NOoo:03o0?mC0_oo:0001Ol0odkooo]Zo`2Yool01?oo0=Co00;ooo]Z00Wooh40oookJ_oo
nf[oo`0]oookJ_ooE`3ooo]Zon/0oooo_P000ooonfX00oooT03ooo]ZoaP0o`03onGo00SoogT000Wo
o`1/oomi0?ooN@3oogT0ok?o0?mi0?oooo]Zool30?l0nol00_oonfX02olko`3ooh40oookJ_oob@3o
o`3iojP0ool0Y_oooo]Zooo90?oonf[oo`H000;ooo]Z00?oo`3loookJ_ooTP001OoonfX00ooo0>[o
oo]ZoookJP09oookJP03onGo0?oonf[ooo]Z00Kooo]Z00Go^Ol0oiCo0?ooDP3ooo]Zo`0Zo`03o`3o
G@03ogSo0?lm0?oo0?oO00Cooo]Z0ooUo`001ooonf[oolX0onGo0?oUo`3oo`2ConGo0?oo01<01?oo
nfX01_oQo`3of_l0oookJ_oUo`3oA?l0ob3o00?oiOl03OoonfX00olao`3ooo]Zo`3oF`02oookJP05
oh;o0?l0ok7o033ooookJ_l0odd00_oonfX00ol60?oooo]Zoi;o0003oookJP03oa00oooo06[o01Wo
00?ooo]Z00Koo`1AoookJ_oonf[o0:gooookJ_oo07U>oookJP08o`1goooonf[ooo]Zo`3oV_ooK03o
oh40o`3oc?lko`04oookJP03o`3koooonf[ooo]Z00;ooo]Z00Soo`<0oookJ_oonf[oN@3oool0gOl0
5ooo0:?ook?o00Kooo]Z00Coo`27oookJ_oonf[oo`1/0_oonfX01Om=0?ooobh0of40oooonf[o0?m5
00Cooo]Z00CohP3ooookJ_oonf[o0?nB1_oonfX02OmX0?oooo]ZoookJ_oonf[o603oo`1doooVo`3o
oo]Zoon@000:oookJP03oonn0?oonf[oj`3o00Gooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02go
oo]ZoookJP04oookJP03oon10?oonf[ooo]Z00?ooo]Z00Ko0=CooookJ_l01?oooo]Zo`2Yool0R?l2
oookJP03o`3oC_l0ocCooo]Z00Cooo]Z00?o0?lMoookJ_l0oe<01?oonfX03Ooo07Woo`1AoaD0ool0
GOoo403ooi;o0?oo0?Go1P3oo`3oCOl0<?ooP_l0o`3oFolao`001OoonfX04?lPo`3o9P3oon7o0?oJ
o`3ooo]Zool0Tol0nOooolX0o`3o6ol0S_oooo]Zocd0oomho`3o?ol0o`0ZooooDP03oookJP03o`1c
oooonf[ooo]Z00?ooo]Z01?oo`3ZoookJ_ooTP3oo`3lool60?o[o`3oZ03oo`1gooooK03o>ol0ool0
gOl0Xooo/ol0ool0K?mQ0?oo0?n@o`3oT_mX0?oo603o00;ooo]Z00[ookh0oomG0?oo02gooo]Zo`3D
ool01?oo0?m>o`3o2?oo07WoT_l00_oonfX00olV0?oooo]ZoomB0002oookJP06ool0m_oonf[ooo]Z
oaP0ool0003o403o0_l00002oookJP05o`3Loooonf[o403ooookJ_l0e?l00_oonfX02?lH0?ooi_l0
of40oooonf[o/ol0oom/0?oo0?Koo`3l1OoonfX01oooDP3o0?oOoookJ_oobP3oo`0Con7o0?lV0?l0
0_oonfX03ol0oe_o0?n`o`H0oonBo`3oo`1Aool0NOoonf[o0?mCo`3o7Ooonf[o0?ldo`3oC_l0ZOoo
oo]Zo`3Do`02oookJP06oon10?oonf[ooo]Zool0;Ooonf[ooeL00_oonfX00oo[0?oookh0oookJP02
oookJP08oon@0?oVo`3o603ooookJ_mX0?oooo]Zo`3oT_oR0?l2oookJP05o`3oAOmQ0?ooC@3oool0
K?oo08L00_oonfX04_nco`3oo`3MogT0oooo0`3ooo]Zo`3koooonf[o>ol0oon10?oonf[o07Ooool0
nOnX0?oo0:KooookJ_oo0?Kojol0ool600;ooo]Z00Coo`3loookJ_ooTP3ooaH01?oonfX00ooo0>[o
oo]ZoookJP09oookJP03o`1coooonf[ooo]Z00Oooo]Z00[o^Ol0oomB0?oonf[o02[ooookJ_loo`3o
0=coogSo0?lm0?oo0?oO1OoonfX01?lB0?oo0?lKoookJ_oobP02oookJP04ool0Tol0nOoooo]Zool0
4`?ooo]Z00KohOl0oookJ_oJo`3ooo]ZobH0oolPo`0@oookJP03oc7o0?oonf[o0?mK00;ooo]Z00[o
P_l0o`3o/?l0<?oooo]Zo`3oCOl0j?oooo]Zo`H0oooonf[oT_l00ooonfX01?l@0?ooo`1ZoookJ_l0
6Ol3oookJP05ool0DOoonf[o0:gooookJ_oo07T09ooonfX002[ooo]Z00Wo07OooookJ_oonf[ooo]Z
o`3oV_m4o`3ooh40oookJ_lko`001?oonfX00onDo`3ooo]ZoookJP02oookJP07ool30?oonf[oN@3o
ool0gOoonf[o0:?ook?o0006oookJP04o`3og_oo08Oooo]Zool0K0;ooo]Z00KoC@3ooookJ_oo;P3o
H@3ooookJ_l0odD3oookJP05on80ool0oi3ooo]ZoookJ_l0oi801OoonfX00omX0?oooo]ZoookJP02
oookJP05oaP0oooVo`3ooo]ZoookJ_oUo`002OoonfX01?oo_P3o0?l5oookJ_o[0?l4oookJP03oomG
0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3ooo]ZoookJP03oookJP09o`3D
oooonf[o00CooookJ_l0ZOoo08SooookJ_l0obko0?m>00?ooo]Z0ooob@000ol0oagoolT0o`3oD`03
oookJP0=ool0NOoonf[oo`1AoookJ_l06Ooo403ooi;o0?l60?oo0>Soo`3oCOn2o`3ooo]Zoc7o0006
oookJP03ob3o0?lV0?oof_l000;ooo]Z00Coo`2Co`3ioooobP3o0?lK1?ooN@04oiCo00;ooo]Z00?o
07?ooookJ_oonfX01OooN@001Ooo0?co603oool60?l0Y_ooo`3i00;oobP000Goo`00ok?o0?oo003o
o`00ool0K004oolX0004onGo0?oo003ookh0oolX00?oo`0000?o0=Coool00?l0odh00ooo0009oolX
00Coo`000_l000001Ooonf[oobP0oolX0?oo:03o403o00Koo`000_ooN@000ooo003oobP0oolX0006
oolX00Goo`0000Wo9P3ooolX0?oo:03oo`00o`3oFooo003oT_l0ool00?oo05400_m4o`002?l0oe?o
obP0oolX0?l0odkooo]Zo`2Yool01?oo0=Co0_oonfX02OooP@3ooo]ZoookJ_oo02gooo]ZoomG0?oo
nf[oj`3ooonn0003oookJP03oon@0?oonf[o603o00?oiOl02?ooN@002Ooo06coogT0oomi0?ooN@3o
/ol0ogT0oooonf[oo`<0o`3ko`02oookJP0;oc_o0?ooP@3ooo]Zooo90?oo0?WoZ03oo`2Voooob@3o
o`3foookJ_oo1P000_oonfX00ooo0?cooo]ZoonB0005oookJP03ool0j_oonf[ooo]Z00Wooo]Z00?o
iOl0oookJ_oonfX01_oonfX01Onio`3ooe80oiCo0?oonf[o02[o00?o0?mM00?oN?l0ocd0ool0oml0
1?oonfX3onGo0007ooo:0?oonf[ooo]ZonGo0?oo09?oiOl0ool04`04oookJP06on7o0?oJo`3ooo]Z
onGo0?m4o`3o8?l00ooUo`0=oookJP03oc7o0?l0oe_ooo]Z00;ooo]Z00GoP_l0o`3o/Ol0<?oooo]Z
o`3oC@02oookJP03o`H0oooonf[oT_l000?ooo]Z00?o403oo`0IoooonfX00ooonfX01_oo057ooo]Z
oookJ_l0[Ooooo]Zool0NDkooo]Z00So07OooookJ_oonf[o0?nJoom/0?ooP@3o0?o<oc_o00Cooo]Z
00?o0?_ooookJ_oonfX00_oonfX02?oo0`3ooo]ZoookJ_mi0?ooo`3Mo`0Gool0Xooo/ol01OoonfX0
1OoMo`3oo`27oookJ_oonf[oo`1/00;ooo]Z00GoC@3oool^0?mQ0?oooo]Zo`3oA@04oookJP04on80
oooonf[ooo]Zo`3oTPKooo]Z00WoJ03ooookJ_oonf[ooo]ZoaP0ool0M?ooi_l0oookJ_ooT0002_oo
nfX00ooo_P3o0?l5on/0o`05oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01?oo
nfX00oooP@3ooo]ZoookJP03oookJP06o`3Doooonf[o00CooookJ_l0ZOoo08So0_oonfX00ol0odko
0?ldoookJP04oookJP03o`3o7Ol0o`So0?mC00?ooo]Z00koo`1io`2]oooo057o5@3oo`0Iool@0?oo
T_l0ool0mOl60?oo0?m=o`3o/?n2o`3o0?mKoc7o00Gooo]Z013o8?l0obH0oooQo`3of_l0oookJ_oo
09?o0?Woooo:0?l0oa_o08kooookJ_lm0?ooN?l0ocoo0?l0:_oooe800ooonfX00ol0Looooo]Zoook
JP03oookJP0Qool0j_ooTP3ooo]Zool0o?oo1P3ojol0ojP0ool0Moooof`0oc_o0?oo0=go/ol0omgo
0?oo06coH@3oo`3oT?oonf[oJ03ooaP0oooonf[ookh0og00ooooE`3oo`0]oookJ_l0e?oo08Soo`3o
C_l0o`Soo`1ioi;o0?oonf[o9P3o00;ooo]Z00Wooe80oookJ_oonf[oo`3foookJ_lH0?oooo]Zo`00
0?l@0?l00_l00002oookJP05o`3Loooonf[ooo]Zoa00ool0e?l00_oonfX02?m`0?oo603oof40oooo
nf[o/ol0oom/0?oo0?Koo`3l1OoonfX01oooDP3o0?oOoookJ_oobP3oo`0Con7o0?lV0?l00_oonfX0
3ol0oe_oP_l0o`H0oonBo`3oo`1Aool0NOoonf[o0?mCo`3o7Ooonf[o0?m>o`3o;_l0ZOoooo]Zo`3D
o`02oookJP06oon10?oonf[ooo]Zool0;Ooonf[ooeL00_oonfX00oo[0?oooo]ZoookJP02oookJP04
oon@0?oVo`3o603oofP0o`;ooo]Z00Wo0?nBon80oooonf[o0?m5oookJ_mQ0?ooC@3oool0K?oo08L0
0_oonfX04_nco`3oo`3MogT0oooo0`3ooo]Zo`3koooonf[o>ol0oon10?oonf[o07Ooool0nOnX0?oo
0:KooookJ_o[o`3ooo]Zool600;ooo]Z00Coo`3loookJ_ooTP3ooaH01?oonfX00ooo0>[ooo]Zoook
JP09oookJP03o`1coooonf[ooo]Z00Oooo]Z00[ooe80o`3o<ooonf[o02[ooookJ_loo`3o0=coogSo
0?lm0?oo0?oO1OoonfX01?lB0?oo0?lKoookJ_oobP02oookJP03ool0Tol0nOooo`0C00Cooo]Z00Ko
hOl0oookJ_oJo`3ooo]ZobH0oolPo`0@oookJP03oc7o0?oonf[o0?mK00;ooo]Z00GoP_l0o`3o/?l0
<?oooo]Zo`3oC@02oookJP03o`H0oooonf[oT_l000?ooo]Z00?o403oool0J_l06Ol00ooonfX01_oo
057o5@3ooookJ_l0[Ooooo]Zool0NBOooo]Z000ZoookJP09o`1goooonf[ooo]ZoookJ_l0oi[oA?l0
oon10?oonf[o>ol000Cooo]Z00?oU?l0oookJ_oonfX00_oonfX01ooo0`3ooo]ZogT0oooo0=gooo]Z
o`2Soonco`001_oonfX01?l0omkoo`27oookJ_oo06`2oookJP06odd0oooonf[oobh0of40oooonf[o
0?m50ooonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Gooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH
0?ooi_l0oookJP03onGo00Sooo]Z00Cookh0o`3o1Ooonf[oj`3o1?oonfX00oooE`3ooo]ZoookJP03
oookJP03ool0;Ooonf[ooo]Z00Cooo]Z00?ooh40oookJ_oonfX00ooonfX01Ol0e?oooo]Zo`04oooo
nf[o0:Wo00;ooo]Z00?o0?l^o`3oC_oonfX00_oonfX3ooo90003o`3o7Ooob@3o0?mC00?ooo]Z00go
o`1ioookJ_oo057ooo]Zo`0Iool@0?ooT_l0o`H0ool0j?oo0?m=oh;o0?oonf[o<Ol000Kooo]Z00?o
8?l0obH0oooJo`000_oonfX01?oo09?o0?Woooo:0?l0oa/3oomi00GoU?l00_oonfX00ol0Looooo]Z
oookJP05oomi0004ool0o?lH0?ooo`H0o`2Vo`CoobP000Co/ol0ool00?oo003oo`1/1?oo:0001?oU
o`3oobP0oonn0?oo:002oomi00;oo`0000?o0?m>ool00?oo00000ooo0007oolX0004ool00?oo:03o
o`00ool000?o000000Gooo]ZoolX0?oo:03oobP0oa00o`02ool00003oolX0?oo003oo`0000;oo`00
00?oogT0ool00?oo:0001ooo:008ool00006o`3oFooo003oo`00oi;o0?oo003oo`1A0_m4o`002?l0
oe?oobP0oookJ_l0odkooo]Zo`2Yool01?oo0=Co0_oonfX00oooP@3ooo]Zool0;@02oookJP04oomG
0?m`0?ooj`3ooonn00?ooo]Z00Cooi00oookJ_lH0?oooo]Z0_oUo`05oomi0003oiCo0?ooN@3oo`1/
00?oogT000Ko/ol0ool0gOmi0?oooo]Zool30?l0nol2oookJP08oc_o0?ooP@3ooo]Zooo90?oonf[o
Z03ooookJ_oob@02oookJP06ool60?oonf[ooo]Zool0o?oonf[ooi801OoonfX00ooo0>[ooo]Zoook
JP09oookJP03onGo0?oonf[ooo]Z00Kooo]Z00Go^Ol0oomB0?nDo`3ooo]Zo`0Zo`03o`3oG@03ogSo
0?lm0?oo0?oO00Gooo]Z00?oiOl0oookJ_oobP000_oonfX01?oUo`3oo`2ConGo0?oo01<4oookJP06
on7o0?oJo`3ooo]ZonGo0?m4o`3o8?l00ooUo`0=oookJP03oc7o0?l0oe_ooo]Z00;ooo]Z00GoP_l0
o`3o/Ol0<?oo0>Soo`3oC@02oookJP03o`H0oooonf[oT_l000?ooo]Z00?o403oo`0IoooonfX00ooo
nfX01_oo057ooo]ZoookJ_l0[Ooooo]Zool0NDkooo]Z00So07OooookJ_oonf[o0?nJoom/0?ooP@3o
oo]Zoc_o00Cooo]Z00?o0?_ooookJ_oonfX00_oonfX02?oo0`3ooo]ZoookJ_mi0?ooo`3Mo`0Gool0
Xooo/ol01OoonfX01OoMo`3oo`27oookJ_oonf[oo`1/00;ooo]Z00GoC@3oool^0?mQ0?oooo]Zo`3o
A@03oookJP05on80ool0oi3ooo]ZoookJ_l0oi801_oonfX02OmX0?oooo]ZoookJ_oonf[o603oo`1d
oooVo`3ooo]Zoon@000:oookJP03oonn0?l0o`Goj`3o00Gooo]Z00?ooeL0oookJ_oonfX00_oonfX0
0ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00?ooo]Z00Go0=CooookJ_l01?oooo]Zo`2Y
o`03oookJP03o`3oC_l0ocCooo]Z00Cooo]Z00?o0?lMo`3o2?l0oe<00ooonfX03_oo07Wo0:goool0
DOlE0?oo01Wooa00oonBo`3ooo]Zo`H0ool0odgo0?n`oh;o0?l0oe_o<Ol01OoonfX04?lPo`3o9P3o
on7o0?oJo`3ooo]Zool0Tol0nOooolX0o`3o6ol0S_oooo]Zocd0oomho`3o?ol0o`0ZooooDP03oook
JP03o`1coooonf[ooo]Z00;ooo]Z01Soo`3ZoookJ_ooTP3ooo]Zool0o?oo1P3ojol0ojP0ool0Mooo
oo]Zoc_o0?oo0`3o/ol0o`3og_oo06coH@3oo`3oT?oonf[oJ03ooaP0oooonf[ookh0og00ooooE`02
oookJP0;o`3Dool0odko0?ldo`3o2?oo07WoT_l0oookJ_lV0?oooo]Zo`3LooooDP000_oonfX01Ooo
0?Kooo]ZoaP0oooonf[o403o00?o00000ooonfX03_l0g?oooo]Zoa00oooonf[o0=CooookJ_m`0?oo
603oof40oooonf[o/ol0oom/0?oo0?Koo`3l1OoonfX01oooDP3o0?oOoookJ_oobP3oo`0Con7o0?lV
0?l00_oonfX03ol0oe_oP_l0o`H0oonBo`3oo`1Aool0NOoonf[o0?mCo`3o7Ooonf[o0?m>o`3o;_l0
ZOoooo]Zo`3Do`02oookJP03oon10?oonf[oo`0]00;ooo]Z00CooeL0oookJ_m`0?ooj`3o1?oonfX0
1?ooT03oi_l0oaP0oomX0?l2oookJP0Mo`3oT_oR0?oooo]Zo`3oAOmQ0?ooobh0ool0K?oo08Oo0?oN
oookJ_nco`3o0:?oool0gOmi0?ooo`<0oookJ_l0nooooo]Zoc_o0?ooP@3ooo]Zo`1goooonf[oZ03o
o`2Voooo0?Kojol0oookJ_oo1P000_oonfX01?oo0?cooo]ZoonB0?oo5P04oookJP03ool0j_oonf[o
oo]Z00Wooo]Z00?o07?ooookJ_oonfX01ooonfX02_ooDP3o0?lcoookJ_l0:_oooo]Zocoo0?l0g?oo
N?l0ocd0ool0oml5oookJP04oa80ool0oa_ooo]Zooo:00;ooo]Z00?oo`2Co`3ioooo01<01?oonfX0
1_oQo`3ooo]Zom[o0?oonf[o9P3oob3o013ooo]Z00?o<Ol0oookJ_l0oe/00_oonfX01On2o`3o0?n`
o`0`oooonf[o0?m=00;ooo]Z00?o1P3ooookJ_nBo`000ooonfX00ol@0?ooo`1Zo`0Io`03oookJP06
ool0DOlE0?oooo]Zo`2]oooonf[oo`1i9ooonfX002Sooo]Z0_l000002Ol0Mooo0000o`000?l0003o
A?l0o`000?ooP@3o0000oc_o0004o`000005oiCo0?l0003o0000o`000?oo0`000_l000001Omi0?oo
o`3Mo`000?l0Xooo/ol000Ko000000Coo`27o`000?l0003oo`1/0_l000001_m=0?oo0000ool^0?mQ
0?oo0000o`3oA@?o000000GohP3oo`3oT?l0003o0000o`3oTP05o`000003ofP0ool0003o000000;o
000000?o603oonKo0?l000000ooUo`08o`000004oonn0?l0o`Go0000on/0o`Co000000?ooeL0o`00
0?l000000ol000000ooo02go0000o`000003o`000003oon10?l0003o000000Co000000Go0=Coo`00
0?l01?oo0000o`2Yo`02o`000003o`3o;_l0odko000000;o00000ooob@000ol0oagoolT0o`3oD`03
o`00000=ool0NOl0003oo`1Ao`000?l06Ooo403ooi;o0?l60?oo0?m=oh;o0?l0ok3o0000oc7o0006
o`000009ob3o0?lV0?oof_l0o`000?oo01?oo`2Co`000?oobP3o0?lK00?oogT01OnDo`02o`000003
o`1cool0003o000000GoogT000Coo`3lool60?o[o`3o0:Ko1?oo:0001?nco`3oo`00ool00?oo06`4
oolX0004onGo0?oo_P3oL03ooolX00;oogT000?o0000o`3Dool0odh01_oo0005oolX00;oo`0000?o
obP0ool00?oo:0001?l00003oolX0003oa00oooo003oo`0000;oobP00_oo00000omQ0?ooogT0ool0
0007oolX0003oomB0?oo003oo`0000Koo`00013o0?mKool00?oo003oT_l0odCo0?oo057oA?l0o`3o
Dol0oagoobP0o`000?l0odko0000o`2Yool01?oo0=Co0_l000000oooP@3o0000ool0;@02o`000004
oomG0?o[0?oo0?l5oonn00?o000000Cooi00onKo0?lH0?ooJ03o0ooUo`04oomi0003oiCo0?ooN@3o
o`1/00?oogT000Ko/ol0ool0gOmi0?oo0000ool30?l0nol2o`000008oc_o0?ooK03o0000ooo90?l0
003oZ03oo`000?oob@02o`000006ool60?l0003o0000ool0o?l0003ooi801Ol000000ooo0>[o0000
o`000009o`000003onGo0?l0003o000000Ko000000Go^Ol0oomB0?l0oc?o0000o`0Zo`03o`3oG@03
ogSo0?l0omoo000000Go000000?oiOl0o`000?oobP000_l000001?oUo`3oo`2ConGo0?oo01<4o`00
0006om[o0?l0003o0000onGo0?m4o`3o8?l00ooUo`0=o`000009oc7o0?l0oe_o0000o`000?n2o`3o
0?n`o`3o/Ol0<?oo0?m=00?o000000?o1P3oo`000?nBo`000_l000000ol@0?oo05goo`0Io`04o`00
0003ool0DOl0003o0:go00;o000000Coo`1io`000?l0003o0000B?oonfX3o`000008o`1gool0003o
0000oom/0?l0003ooh40o`000?lko`04o`000005o`3kool0003o0000o`000?oo0`000ol000001Omi
0?ooo`3Mo`0Gool0Xooo/ol000Go000000Go0?oNool0Qol0003o0000ool0K002o`000005odd0oooo
;P3oH@3oo`000?l0odD00ol000001OoR0?oo0?n@o`000?l0003o0?nB00Ko000000WoJ03oo`000?l0
003o0000oaP0ool0M?ooi_l0o`000?ooT0002Ol000001?oo_P3o0000o`3o1Oo[0?l5o`000003oomG
0?l0003o000000;o000000?oo`0]o`000?l000000ol000000oooP@3o0000o`000004o`000005o`3D
ool0003o00Coo`000?l0ZOl00ol000000ol0odko0?ldo`000004o`000003o`3o7Ol0o`So0?mC00?o
000000koo`1io`2]oooo057o0000o`0Iool@0?ooT_l0o`000?l0odgo0>Sooh;o0?l0003o0?mKoc7o
00Go0000013o8?l0obH0oooQo`3of_l0o`000?oo09?o0?Woooo:0?l0oa_o08koo`000?l0omooN?l0
o`000?ooDP3o0?lc0ol000000ol0Looo0000o`000002o`00000Hool0j_l0003ooi80o`000?oo0?co
o`H0on_o0?l0Moooo`3ioc_o0?l0noooN@3ook?o0?l0omkoo`1/of40ool0oi3o0000ofP0oolH0?oo
0000oonn0?l0003ooeL00_l000002_l0e?oo0?m>o`3o=?oo07Wo403ooi;o0?l0003o9P3oo`000?oo
DP03o`000005ool0m_l0003o0000o`000?l@0?l01_l000003_l0g?oo0000oa00ool0003o0=Coo`00
0?m`0?oo603oof40ool0003o/ol0oom/0?oo0?Koo`3l1Ol000001oooDP3o0?oOo`000?oobP3oo`0C
on7o0?lV0?l00_l000003ol0oe_oP_l0o`H0oonBo`3oo`1Aool0NOl0003o0?mCo`3o7Ol0003o0?m>
o`3o;_l0ZOoo00Coo`3Do`02o`000003oon10?l0003oo`0]00;o000000CooeL0o`000?o[0?oookh0
1?l000001?oVo`3o07CooaP0oomX0?l2o`00000Mo`3oT_oR0?oo0000o`3oAOmQ0?ooobh0ool0K?oo
08Oo0?oNo`000?nco`3o0:?oool0gOmi0?ooo`<0o`000?l0nooo0000oc_o0?ooK03o0000o`1gool0
003oZ03oo`2Voooo0?Kojol0o`000?oo1P000_l000001?oo0?co0000oonB0?oo5P04o`000003ool0
j_l0003o000000Wo000000?o07?oo`000?l000001ol000002OooDP3o0?lco`000?l0:_oo0000ocoo
0?l0g?ooN?l0o`3og`06o`000004oa80ool0oa_o0000ooo:00;o000000?oo`2Co`3ioooo01<01?l0
00001_oQo`3of_l0o`000?l0003o9P3oob3o013o000000?o<Ol0o`3oFol000000_l000001On2o`3o
0?n`o`0`ool0003o0?m=00;o000000?o1P3oo`000?nBo`000ol000000ol@0?ooo`1Zo`0Io`03o`00
0006ool0DOlE0?oo0000o`2]ool0003oo`1i1?l0000SoookJP00:?oonfX2o`000009o`1gool0003o
0000o`000?m4o`3o0000oon10?l0003o>ol000Co000000GoU?l0o`000?l0003o0000ool30002o`00
0005ogT0oooo0=go0000o`2Soonco`001_l000000ooo08Oo0000ool0K003o`000006odd0ool0003o
obh0of40ool0003o0?m50ol000001?oR0?oo0?n@o`000?l0oi86o`000003ofP0ool0003o000000;o
000000?o603oonKo0?l000000ooUo`08o`000004oonn0?l0o`Go0000on/0o`?o000000?ooeL0o`00
0?l000001?l000000ooo02go0000o`000003o`000003oon10?l0003o000000Co000000Go0=Coo`00
0?l01?oo0000o`2Yo`02o`000004o`3o;_l0odko0000o`0000CoolT000?o0?lMooo90?l0oe<00ol0
00003Ooo07Woo`1AoaD0ool0003o01Wooa00oonBo`3o1P3oo`3oCOn2o`3o0?n`o`000?lao`001Ol0
00002_n40?oo8?l0obH0oooJo`3o0000ool04ooo09?o0000ooo:0?l0oa/3oomi00GoU?l00_l00000
0ol0Looo0000oomi0004oomi0005ool0o?l0003oo`H0on_o0?oo00001?oo:0001?nco`3oo`00ool0
0?oo06`4oolX00;oiOl000OoL03ooolX0?ooN@3oogT0o`3Dool01?oo0?m>00Goo`0000?oobP0ool0
0?oo:0000_oo:005ool00003oolX0?l0003o000000;o00000ooo:0000ooob@3oo`00oolX0003oolX
0004ool00?mQ0?oo/ol0ool000OoobP000?ooe80ool00?oo00001_oo00003ol0oe_oo`00ool00?nB
o`3oA?l0ool0DOm4o`3o0?mCo`3o7Ooo:03o0000o`3oC_l0R?oo0:Woo`3Do`03o`000009oon10?l0
003oo`0]o`000?ooE`3o0000on/0ool0o`Gookh000?o000000Cooi00onKo0?lH0?ooJ03o0ooUo`04
oomi0003oiCo0?ooN@3oo`1/00?oogT000Ko/ol0ool0gOmi0?oo0000ool30?l0nol2o`000008oc_o
0?ooK03oolT0ool0nOl0003oZ03oo`000?oob@02o`000006ool60?l0003o0000ool0o?l0003ooi80
1Ol000000ooo0>[o0000o`000008o`000003onGo0?l0003o000000Oo000000Go^Ol0oomB0?l0oc?o
0000o`0Zo`03o`3oG@03ogSo0?l0omoo000000Co000000Co4P3oo`3o6ol0003oolX00_l000001?oU
o`3oo`2ConGo0?oo01<4o`000006om[o0?l0003o0000onGo0?m4o`3o8?l00_oUo`0>o`00000:oc7o
0?l0oe_o0000o`000?n2o`3o0?n`o`0`ool0003o0?m=o`0000;oiOl000?o1P3oonGo0?nBo`000_l0
00000ol@0?oo05goo`0Io`04o`000003ool0DOl0003o0:go00;o000000Coo`1io`000?l0003o0000
B?oonfX3o`000008o`1gool0003o0000oom/0?l0003ooh40o`000?lko`04o`000005o`3kool0003o
0000o`000?oo0`000ol000001Omi0?ooo`3Mo`0Gool0Xooo/ol000Go000000Co0?oNool0Qol0003o
o`1/0ol000001Om=0?ooobh0of40ool0003o0?m500?o000000GohP3oo`3oT?l0003o0000o`3oTP05
o`000003ofP0ool0003o000000;o000000Go603oo`1doooVo`3o0000oon@0009o`000004oonn0?l0
003o0?l5on/0o`Co000000?ooeL0o`000?l000000ol000000ooo02go0000o`000003o`000003oon1
0?l0003o000000Co000000Go0=Coo`000?l01?oo0000o`2Yo`03o`000003o`3oC_l0ocCo000000Co
000000?o0?lMo`3o2?l0oe<00ol000003_oo07Woo`1AoaD0ool0003o01Wooa00oonBo`3o1P3oo`3o
COl0j?ooP_l0o`000?l0oe_o<Ol01Ol000002OlPo`3o9P3oon7o0?oJo`3o0000ool0Tol0nOooolX0
o`3o6`02o`000005ogSo0?loo`3o0000oomB0?l0oc<00ol000000ol0Looo0000o`000002o`00000H
ool0j_l0003ooi80ool0o?l0003oo`H0on_o0?l0Moooof`0oc_o0?l0noooN@3ook?o0?l0omkoo`1/
of40ool0oi3o0000oaP0oooVo`3o0000oonn0?l0003ooeL00_l000001Ol0e?oo0?m>o`3o2?oo07Wo
T_l000;o000000?o9P3oo`000?ooDP000_l000000ooo0?Ko0000o`000002o`000003oa00ool0003o
000000;o0000013oo`3fo`000?l0g?oo0000oa00ool0003o0=Coo`000?m`0?oo603oof40ool0003o
/ol0oom/0?oo0?Koo`3l1Ol000001oooDP3o0?oOo`000?oobP3oo`0Con7o0?lV0?l00_l000003ol0
oe_oP_l0o`H0oonBo`3oo`1Aool0NOl0003o0?mCo`3o7Ol0003o0?m>o`3o;_l0ZOoo00Coo`3Do`02
o`000005oon10?l0003oo`0]o`000?ooE`000_l000000oo[0?oookh0o`000003o`000004onKo0?l0
M?oo603oofP0o`;o000001go0?nBon80ool0003o0?m5of40oooo;P3oo`1/ool0Qol0omko0000ok?o
0?l0Xoooo`3MogT0oooo0`3o0000o`3kool0003o>ol0oom/0?l0Moooo`3io`000?nX0?oo0:Koool0
m_o[o`3o0000ool60002o`000004ool0o?l0003ooi80oolF00Co000000?oo`3Zo`000?l000002Ol0
00000ol0Looo0000o`000007o`000009oomB0?l0oc?o0000o`0Zool0003o?ol0o`3Loomho`3o0?oO
00Ko000000Co4P3oo`3o6ol0003oolX00_l000000ooo09?o0?Woool04`04o`000006on7o0?oJo`3o
0000o`000?lV0?oo8?l04?l000000olao`3o0?mKo`000002o`000005oh;o0?l0ok3o033oo`000?l0
odd00_l000000ol60?oo0000oi;o0003o`000003oa00oooo06[o01Wo00?o000000Koo`1AoaD0ool0
003o0:goo`000?oo07T4o`0002?ooo]Z000XoookJP;o000000Wo07Ooo`000?l0003o0000odCo0?oU
o`3ooh40o`000?lko`000ol000000onDo`3o0000o`000002o`000008ool30?l0003o0000ogT0oooo
0=go0000o`2Soonco`06o`000003ool0Qol0003oo`1/00?o000000KoC@3oo`000?oo;P3oH@3oo`00
0?l0odD3o`000004on80ool0oi3o0000o`3oTPGo000000?oJ03oo`000?l000000ol000000olH0?oo
i_l0o`000003onGo00So000000Cookh0o`3o1Ol0003oj`3o0ol000000oooE`3o0000o`000003o`00
0003ool0;Ol0003o000000Co000000?ooh40o`000?l000001?l000001Ol0e?oo00Coo`000?l0ZOoo
08So00;o000000Co0?l^o`3oC_l0003o00001?oob@000ol0oago0?mCooo90003o`00000=ool0NOoo
057o5@3oo`000?l06Ooo403ooi;o0?l0003o0?m=oh;o0?l0ok3o0?mKoc7o0005o`00000<oh@0oolP
o`3o9P3oom[o0?l0003oo`0Cool0Tol0003o0?lKoa80ool0003oogT01_nDo`001?ooN@3o0000o`1c
ool00005oomi0004ool0o?l0003oo`H0on_o00GoobP000Co/ol0ool00?oo06coo`001?oo:002onGo
000;og00oooo:03oogT0oomi0?l0e?ooobP0o`3oC_oo003oobP0oi;o0?oo:0001?oo00001_oo:03o
o`00ool00?oo003oobP0ool000;oobP00ol00003oolX0003o`000?oob@3oo`0000GoobP000?oH@3o
ok?o0?oo00001ooo:0000oooDP3oo`00ool00006ool00007o`3oFooo003oo`00oi;o0?m4o`3oo`1A
odCo0005onGo0003o`28ool0ZOoo0=Co00;o000000[ooh40o`000?l0003oo`0]o`000?ooE`3o0000
on/0ool0o`Gookh00ol000001?ooT03oi_l0oaP0oomX0?l3onGo00?oogT00_nDo`000oooN@3oo`1/
oomi0002oomi000Cok?o0?oo0=go0000o`000?oo0`3o0?_oo`000?lko`3ooh40oom/0?oob@3oo`3i
o`000?nX0?oo0000ooo90?l0003oo`H0oaP0o`02o`000003ool0o?l0003ooi8000Go000000?oo`3Z
o`000?l000002?l000000ooUo`3o0000o`000006o`000005okWo0?l0003ooe80o`3o<ol0:_l00_l0
0002o`3oG@03ogSo0?l0omoo000000Co000000Co4P3oo`3o6ol0003oolX00_l000001?oUo`3oo`2C
onGo0?oo01<4o`000006om[o0?l0003o0000o`000?m4o`3o8?l00_oUo`0>o`00000:oc7o0?l0oe_o
0000o`000?n2o`3o0?n`o`0`ool0003o0?m=o`0000;oiOl000?o1P3ooi;o0?oUo`000_oUo`000ol@
0?oo05goo`0Io`03o`000004oaD0oooo057o0000o`2]o`;o000000Coo`1io`000?l0003o0000B?oo
nfX3o`000008o`1gool0003o0000oom/0?l0003ooh40o`000?lko`03o`000003o`3kool0003o0000
00;o000000Woo`<0o`000?l0003o0000ool0gOl0003o01Oook?o0?nO0?l01Ol000001?l0omkoo`27
o`000?oo06`3o`000005odd0oooo;P3oH@3oo`000?l0odD00ol000001OoR0?oo0?n@o`000?l0003o
0?nB00Go000000?oJ03oo`000?l000000_l000001OlH0?ooi_l0o`000?l0003ooi0000Wo000000Co
okh0o`000?l0o`Goj`3o1?l000000oooE`3o0000o`000002o`000003ool0;Ol0003o000000Co0000
00?ooh40o`000?l000001?l000001Ol0e?oo00Coo`000?l0003o0:Wo00?o000000?o0?m>o`3o=?l0
00001?l000000ol0oago0?mCo`000003o`00000>ool0NOoo057o5@3oo`000?l06Ooo403ooi;o0?l6
0?oo0?m=o`3o/On2o`3o0000o`3oFolao`05o`000009ob3o0?lV0?oohOl0om[o0?l0003oo`2Co`00
0?oobP3o0?lK00;o000000GoN?l0ocoo0?l0:_oooe80o`3o<`03o`000003o`1cool0003o000000;o
000001Soo`3Zo`000?ooTP3oo`3lo`000?oo1P3ojol0o`1gooooK03o>ol0o`3koomi0?oo/ol0ool0
K?mQ0?oo0?m5o`3oT?mX0?oo603oonKo0?l0003ookh0oomG0?oo02d2o`000005o`3Dool0odko0?l8
ool0NOnBo`000_l000000olV0?oo0000oomB0002o`000003ool0m_l0003o000000Oo0000013oo`3f
o`000?l0g?oo0000oa00ool0003o0=Coog00ool0003o603oof40ool0003o/ol0oom/0?oo0?Koo`3l
1Ol000001oooDP3o0?oOo`000?oobP3oo`0Con7o0?lV0?l00_l000004Ol0oe_oP_l0o`H0oonBo`3o
o`1Aool0NOl0003o0?mCo`3o7Ol0003o0?m>o`3o;_l0ZOoo00Coo`3Dool0003ooh4000;o000000?o
o`0]o`000?ooE`000_l000000oo[0?oookh0o`000002o`000005oon@0?oVo`3o603oo`000?mX0?l0
0_l000007Ol0oi;ohP3oo`000?l0odGoH@3oodd0oooo06coo`27o`3og_l0003o/ol0o`2Soooo0=go
0000ool30?l0003o0?_ooc_o0?ooP@3oof`0o`1goooo0?Wo0000ojP0ool0Y_ooo`3fon_o0?oo1P3o
603o00;o000000Coo`3lo`000?ooTP3ooaH01?l000000ooo0>[o0000o`000008o`000003o`1cool0
003o000000Oo000000Co^Ol0oomB0?l0oc?o02[o0_l000001?loo`3o0=coogSo0?l0oml6o`000004
oa80ool0oa_o0000ooo:00;o000000?oo`2Co`3ioooo01<01?l000001_oQo`3of_l0o`000?l0003o
9P3oob3o013o000000?o<Ol0o`3oFol000000_l000001On2o`3o0?n`o`0`ool0003o0?m=00;o0000
00?o1P3oo`000?nBo`000ol000000ol@0?ooo`1Zo`0Io`03o`000006ool0DOl0003o0000o`2]ool0
003oo`1i1?l0000SoookJP00:?oonfX2o`000009o`1gool0003o0000o`000?m4o`3oiOl0oon10?l0
003o>ol000?o000000?oU?l0o`000?l000000_l000001?oo0`3o0000o`000?oo0=d2o`000003o`2S
oonco`3o000000Go000000?oo`27o`000?oo06`00ol000000om=0?oo0000of40o`02o`000005o`3o
AOl0003o0000o`000?oR0?l00_l000000ol0oi;o0000o`000003o`000003ofP0ool0003o000000?o
000000?o603oonKo0?oUo`000ooUo`08o`000003oonn0?l0o`Goj`3o00Co000000?ooeL0o`000?l0
00000ol000000ooo02go0000o`000004o`000003oon10?l0003o000000Co000000Go0=Coo`04ool0
003o0:Woo`28o`02o`000004o`3oC_l0ocCo0000o`0000CoolT000Co0?lMo`3oDooob@3oolT00_l0
00003Ooo07WoolT0oaD0ool0003o01Wooa00oonBo`3o0000o`3oCOn2o`3oogT0o`3oFolao`001Ol0
00002_n40?oo8?l0obH0oooJo`3o0000ool04ooo09?o0000o`3o6olB0?l2oomi00OoU?l000?o07?o
o`000?ooN@001OooN@001?oo0?co0000ool60?o[o`05oolX0003ok?o0?oo:03oo`1/00GoobP00_oU
o`002?m`0?ooobP0oolX0?ooN@3oolT0oolX0?l0odkoo`000ooo:00:ool000;oobP00ol00002oolX
0003o`3Loooob@3oolT000OoobP000?o/ol0oolX0?oo:0001Ooo:0000ooo003ooe80ool00007ool0
0005o`3oFooo003o1P3ooi;o0?oo05400_m4o`09onGo000;o`000?ooP@3o0000o`000?oo02go0000
oomG0?l0003oj`3oo`3o1Ooo_P000ol000001?ooT03o603oo`000?mX0?l3onGo00?oogT00onDo`00
1_oo06coogT0oomi0?ooN@3o/ol0ool0g@;o000000koo`<0o`3kool0003o>ol0oon10?ooK03oolT0
ool0nOl0003oolT0o`000?oob@3o0000ool600?o000000?oo`3lo`000?ooTP001?l000000ooo0>[o
0000o`000009o`000003onGo0?l0003o000000Ko000000Go^Ol0o`000?ooDP3o0000o`0Zo`02o`00
00;o0?mM00?oN?l0o`3ogol000001?l000001?lB0?oo0?lKo`000?oobP03o`000003ool0TooUo`3o
o`0C00Co000000Kof_l0o`000?l0003oA?l0onGo0?lPo`02onGo00go000000?o<Ol0o`000?l0oe/0
0_l000001_n2o`3o0?n`o`0`ool0003o0?m=o`0000;oiOl000?o1P3ooi;o0?oUo`000_oUo`000ol@
0?oo05goo`0Io`03o`000004oaD0oooo057o0000o`2]o`;o000000Coo`1io`000?l0003o0000B?oo
nfX3o`000008o`1gool0003o0000oom/0?l0003ooh40o`000?lko`03o`000003o`3kool0003o0000
00;o000000Soo`<0o`000?l0003o0000ool0gOl0003o0:?ook?o00Ko000000Co0?oNool0Qol0003o
o`1/0ol000001Om=0?ooH@3oo`000?l0003o0?m500?o000000CohP3oo`000?l0003o0?nB1_l00000
0omX0?oo0000o`000002o`000005oaP0oooVo`3o0000o`000?ooT0002Ol000000ooo_P3o0000on/0
o`05o`000003oomG0?l0003o000000;o000000?oo`0]o`000?l000001?l000000oooP@3o0000o`00
0004o`000005o`3Dool01?oo0000o`000?l0ZOl00ol000000ol0odko0?ldo`000004o`000003o`3o
7Ol0oe?o000000?o000000koo`1iool0DOlE0?oo0000o`0Iool@0?ooT_l0o`H0ool0odgo0?naoh;o
0?l0003o0?mKoc7o00Go000000Wo8?l0obH0oooQo`3of_l0o`000?oo09?o0000ooo:0?l0oa/00_l0
00001?mho`3o?ol0o`0ZooooDP03o`000003o`1cool0003o000000?o000001Soo`3Zo`000?ooTP3o
o`3lool60?o[o`3oZ03oo`1gooooK03o>ol0o`3koomi0?oo/ol0ool0K?mQ0?oo0?m5o`3oT?mX0?oo
603oonKo0?l0003ookh0oomG0?oo02d2o`000005o`3Dool0odko0?l8o`000?nBo`000_l000000olV
0?oo0000oomB0002o`000003ool0m_l0003o000000Oo0000013oo`3fo`000?l0g?oo0000oa00ool0
1?oo0=Coog00oooVo`3o603oof40oonco`3o0000oom/0?oo0?Koo`3l1Ol000001oooDP3o0?oOoa80
oooobP3oo`0Cob3o0?lV0?l00_l000003_l0oe_o1P3ooi;o0?oo057o0000ool0NOl0oe?o0?l8o`3o
7Ol0ocCo0?m>o`3o;_l0ZOoo0=Co0_l000001_ooP@3o0000o`000?oo02go0000oomG00;o000000?o
j`3ooonn0?l000000_l000001OooT03oi_l0oaP0ool0003oJ03o00;o000001go0?nBon80ool0003o
0?m5of40oom=0?ooo`1/ool0Qol0omko0000ok?o0?l0Xoooo`3Mo`000?oo0`3o0?_oo`000?lko`3o
oh40oom/0?l0Moooo`3io`000?nX0?oo0:Koool0m_o[o`3oo`H0oaP0o`02o`000003ool0o?l0003o
oi8000Co000000?oo`3Zo`000?l000002Ol000000ol0Looo0000o`000007o`000004okWo0?ooDP3o
0000o`0Zo`;o000000Co?ol0o`3Loomho`3o0?oO1_l000001?lB0?oo0?lKo`000?oobP02o`000003
ool0Tol0nOooo`0C00Co000000KohOl0om[o0?l0003o0000obH0oolPo`0?o`000003oc7o0?l0003o
0?mK00?o000000GoP_l0o`3o/?l0<?oo0000o`3oC@02o`000003o`H0ool0003oT_l000?o000000?o
403oool0J_l06Ol00ol000001_oo057o0000o`000?l0[Ooo0000ool0N@Co00008ooonfX002[ooo]Z
00Wo07OooookJ_oonf[ooo]ZodCo0?oUo`3ooh40oookJ_lko`000ooonfX00onDo`3ooo]ZoookJP02
oookJP08ool30?oonf[ooo]Zool0gOoonf[o0:?oo`0Goonco`06oookJP03ool0Qooonf[oo`1/00?o
oo]Z00?oC@3oool^0?mQ0?l00_oonfX01Ol0odGooo]ZoookJ_oonf[ohP3o00;ooo]Z00?o0?nBoook
J_oonfX00ooonfX00omX0?oooo]ZoookJP03oookJP03oaP0oooonf[oiOl000CoiOl01ooonfX00ooo
_P3o0?l5on/0o`04oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01?oonfX00ooo
P@3ooo]ZoookJP04oookJP05o`3Dool0o`cooo]Zo`2Yool0R?l00_oonfX00ol0odko0?ldoookJP05
ooo9000Co`3o7Ol0oe?oolT0ooo90?oonf[oo`1io`2]oooob@3o5@3oool0J_l06Ooo403ooi;o0?oo
N@3o0?m=oh;o0?ooN@3o0?mKoc7o0005oookJP0<oh@0oolPo`3o9P3oom[o0?oonf[oo`0Cool0Tooo
nf[o0?lKoa80ooooN@3o0?oO1onDo`000ol0Looooo]Zoomi0005oomi0004ool0o?ooN@3oo`H0on_o
00GoobP000?o/ol0oolX0?oo06`01Ooo:002onGo00?oobP000CoogT0ooo90?oo:03o0?m>0ooo:00;
ool000;oobP00ol000000ooo:03ooo]Zoomi0002ooo900OoobP000?o/ol0oolX0?oo:0001?oo:002
ool00003oomB0?oo003oo`0000Koo`0000Go0?mKool00?l60?ooT_l0ool0D@02odCo00WoiOl000_o
oo]Zoon10?oonf[ooo]Zool0;Ooonf[ooeL0oookJ_o[0?oo0?l5oonn0002oookJP06oon@0?oonf[o
603ooookJ_mX0?oooo]Z0_oUo`03oomi00?oU?l000Koo`1/oomi0?ooN@3oogT0ok?o0?oo0=d2oook
JP0>ool30?l0nooooo]Zoc_o0?ooP@3oof`0ooo90?oo0?Wooo]Zooo90?oonf[oolT0oookJ_oo1P03
oookJP03ool0o?oonf[ooi8000Cooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ooUo`3ooo]ZoookJP06
oookJP05okWo0?oonf[ooe80oookJ_l0:_l00_oonfX2o`3oG@03ogSo0?l0omoooo]Z00Cooo]Z00Co
0?lKoookJ_oonf[oolX00ooonfX00ooo09?oo`0CoookJP04oookJP07om[o0?oonf[ooo]ZodCo0?oU
o`3o8?l0onGo000>oookJP03oc7o0?oonf[o0?mK00;ooo]Z00GoP_l0o`3o/?l0<?oooo]Zo`3oC@02
oookJP03onGo0?l60?ooT_l000?oiOl000?o403oo`0Ioooo06X00ooonfX01_lE0?ooo`1AoookJ_l0
[Ooooo]Zool0NDoooo]Z00So07OooookJ_oonf[oof`0oookJ_ooP@3ooo]Zoc_o00?ooo]Z00?o0?_o
oookJ_oonfX00_oonfX02?oo0`3ooo]ZoookJ_oonf[oo`3MoookJ_l0Xooo/ol01_oonfX01?l0omko
o`27oookJ_oo06`3oookJP05odd0oomQ0?oooo]ZoookJ_l0odD00ooonfX01?oR0?oooo]ZoookJ_l0
oi86oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603oonKo0?oonf[ooo]Zoon@0009oookJP03oonn
0?oonf[oj`3o00Gooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP04oookJP03oon1
0?oonf[ooo]Z00Cooo]Z00Go0=Coo`04oooonf[ooo]Zo`2Yo`03oookJP03o`3oC_l0ocCooo]Z00Co
oo]Z00?o0?lMo`3oDooonfX00ooonfX03_oo07Woo`1AoaD0oooonf[o01Wooa00oonBo`3o1P3oo`3o
COl0ok3oP_l0oookJ_l0oe_o<Ol01OoonfX00olPo`3o9P3oom[o0002oookJP04ool0Tooonf[o0?lK
oa80o`;ooo]Z00CoN?l0ocoo0?l0:_oooe800ooonfX00ol0Looooo]ZoookJP03oookJP0Cool0j_oo
nf[ooi80ool0o?oo1P3ojol0ojP0ool0Moooof`0oc_o0?oo0`3o0:?ook?o0?oo06coH@3oo`3oAOl0
oi3oJ03ooaP0o`02oookJP03oonn0?ooE`3oo`0]00;ooo]Z00Go0=Coo`3oC_l0o`Sooo]Zoi;o0002
oookJP03obH0oooonf[ooe8000;ooo]Z00?oo`3foookJ_oonfX00_oonfX4o`00000AoookJ_oo0?Ko
0=cooookJ_l@0?oooo]Zo`3Doooonf[oL03oonKo0?lH0?ooH@3ook?o0?oonf[oof`0oaP0oooo0?`0
1OoonfX01_ooDP3o0?oOo`3o6ooobP3oo`0CobH0o`?ooo]Z00ko0?mKo`H0oonBo`3oo`1Ao`2]oooo
07Wo0?mCo`3o7Ol0hOoo0?ldo`3oC_l0obko0:Woo`3Do`;ooo]Z00Kooh40oookJ_oonf[oo`0]oook
J_ooE`02oookJP03on/0oooo_P3ooo]Z00;ooo]Z00Gooi00onKo0?lH0?oooo]ZofP0o`02oookJP0M
o`3oT_oR0?oooo]Zo`3oAOmQ0?ooC@3oool0K?oo08Oo0?oNoookJ_nco`3o0:?oool0gOoonf[oo`<0
o`3koooonf[o>ol0oon10?ooK03o07Ooool0nOoonf[oZ03oo`2Voooo0?Kojol0ool60?lH0?l00_oo
nfX00ooo0?cooo]ZoonB0004oookJP03ool0j_oonf[ooo]Z00Wooo]Z00?o07?ooookJ_oonfX01ooo
nfX01?nio`3ooe80oookJ_l0:_l2oookJP04ocoo0?l0g?ooN?l0o`3og`Kooo]Z00?o0?lKoookJ_oo
bP000ooonfX00ooo09?o0?Woool04`04oookJP06on7o0?oJo`3ooo]ZoookJ_lV0?oo8?l03ooonfX0
0olao`3ooo]Zo`3oF`03oookJP05oh;o0?l0ok3o033ooookJ_l0odd00_oonfX00ol60?oooo]Zoi;o
0003oookJP03oa00ool06Ooooo]Z00?ooo]Z00Goo`1AoookJ_oonf[o0:goool0N@0XoookJP00:_oo
nfX02Ol0Mooooo]ZoookJ_l0oi[oA?l0onGo0?ooP@3ooo]Zoc_o0003oookJP03oiCo0?oonf[ooo]Z
00;ooo]Z00Soo`<0oookJ_oonf[oo`3MoookJ_l0Xooo01Oook?o00Kooo]Z00?oo`27oookJ_oo06`0
0ooonfX00om=0?ooobh0of40o`02oookJP05o`3oAOoonf[ooo]Zon80ool0oi000_oonfX00ol0oi;o
oo]ZoookJP03oookJP03ofP0oooonf[ooo]Z00?ooo]Z00?o603ooookJ_oUo`001?oUo`06oookJP04
oonn0?oonf[o0?l5on/0o`Cooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP04oook
JP03oon10?oonf[ooo]Z00Cooo]Z00Go0=Coo`3o3?oonf[o0:Woo`28o`02oookJP03o`3oC_l0ocCo
oo]Z00GoolT001;o0?lMo`3oDooob@3oolT0oookJ_oo07Wo0:goooo90?lE0?ooo`1Zo`0Iool@0?oo
T_l0oomi0?l0odgoP_l0oomi0?lao`06oookJP0;oh@0oolPo`3o9P3oon7o0?oonf[oo`0Cool0Tooo
bP3o0?lKoa80ooooN@002?nDo`000ol0Looooo]Zoomi0005oomi0003ool0o?ooN@3oo`H000KoobP0
00Ko/ol0oolX0?oo06coH@3oo`3oT?oUo`02oolX00;oiOl01?oo:002ooo90003o`3oC_oo:03oobP0
00?oobP02Ooo0002oolX00;o000000Goo`3foookJ_ooN@3oogT0ool00008oolX0003ok?o0?oo:03o
obP000CoobP00_oo00000oooDP3oo`00ool00003ool0000:obH0oooo003oo`00o`3oFooo003oT_l0
odCo0?oo057oA?l0oolX00SoiOl00_oonfX02_ooP@3ooo]ZoookJ_oo02gooo]ZoomG0?oonf[oj`3o
o`3o1Ooo_P02oookJP06oon@0?oonf[o603ooookJ_mX0?oooo]Z0ooUo`02oomi00?oU?l0013oo`1/
oomi0?ooN@3ooo]Zok?o0?oo0=gooo]Zool30?oonf[o0?_ooookJ_lko`3ooh40oom/0?oob@3oo`3i
1?oob@000ooonf[oo`H0oookJP02oookJP03ool0o?oonf[ooi8000Cooo]Z00?oo`3ZoookJ_oonfX0
2OoonfX00ooUo`3ooo]ZoookJP06oookJP05okWo0?ooDP3o0?lcoookJ_l0:_l00_oonfX2o`3oG@03
ogSo0?l0omoooo]Z00Cooo]Z00?o0?lKoookJ_oobP001?oonfX00ooo09?oo`0CoookJP04oookJP07
om[o0?oonf[ooo]ZodCo0?oUo`3o8?l0onGo000>oookJP03oc7o0?l0oe_ooo]Z00;ooo]Z00GoP_l0
o`3o/?l0<?oooo]Zo`3oC@02oookJP03onGo0?l60?ooT_l000?oiOl000?o403oo`0IoooUo`000ooo
nfX01_lE0?ooo`1AoookJ_l0[Ooooo]Zool0NDoooo]Z00So07OooookJ_l0oi[oof`0oookJ_ooP@3o
oo]Zoc_o00?ooo]Z00?o0?_ooookJ_oonfX00_oonfX02?oo0`3ooo]ZoookJ_oonf[oo`3MoookJ_l0
Xooo/ol01_oonfX01?l0omkoo`27oookJ_oo06`3oookJP05odd0oomQ0?oooo]ZoookJ_l0odD00ooo
nfX01?oR0?oooo]ZoookJ_l0oi86oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603oonKo0?oonf[o
oo]Zoon@0009oookJP03oonn0?oonf[oj`3o00Gooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02go
oo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Cooo]Z00Go0=Coo`04oooonf[ooo]Zo`2Yo`03oook
JP03o`3oC_l0ocCooo]Z00?ooo]Z00?o0>7oo`3o7Ol0oe<01?oonfX03Ooo07Woo`1AoaD0oooonf[o
01Wooa00oonBo`3o1P3oo`3oCOl0ok3oP_l0oookJ_lao`001_oonfX02OlPo`3o9P3oom[o0?oonf[o
o`0Cool0TooobP3o0?lKoa80o`02oookJP04ogSo0?loo`3o02[ooomB00?ooo]Z00?o07?ooookJ_oo
nfX00ooonfX04ooo0>[ooo]ZoonB0?oo0?coo`H0on_o0?nX0?oo07Oooom/0?lko`3ooo]Zo`2Soonc
o`3oo`1/of40ool0odGo0?n@ofP0oolH0?l00_oonfX00ooo_P3ooeL0ool0;@02oookJP05o`3Dool0
odko0?l8oookJ_nBo`000_oonfX00olV0?oooo]ZoomB0003oookJP04ool0m_oonf[ooo]ZoookJPCo
0000017oo`3fo`3Loooonf[ooo]Zoa00ool0odko0=CooookJ_m`0?oo603oo`3oT_mQ0?oo/ol0oook
J_ooK03o603oool0o005oookJP06oomB0?l0omoo0?lKooo:0?oo01?o9P3o0ooonfX03_l0oe_o1P3o
oi;o0?oo057o0:goool0NOl0oe?o0?lMoookJ_l0ocCo0?m>o`28ool0ZOoo0=Co0_oonfX01_ooP@3o
oo]ZoookJ_oo02gooo]ZoomG00;ooo]Z00?oj`3ooonn0?oonfX00_oonfX01?ooT03oi_l0oaP0oomX
0?l3oookJP0Mo`3oT_oR0?oooo]Zo`3oAOmQ0?ooC@3oool0K?oo08Oo0?oNoookJ_nco`3o0:?oool0
gOoo0`3ooo]Zo`3koooonf[o>ol0oon10?ooK03o07Ooool0nOoonf[oZ03oo`2Voooo0?Kojol0ool6
0?lH0?l00_oonfX00ooo0?cooo]ZoonB0004oookJP03ool0j_oonf[ooo]Z00Wooo]Z00?o07?ooook
J_oonfX01ooonfX01?ooDP3o0?lcoookJ_l0:_l2oookJP04ocoo0?l0g?ooN?l0o`3og`Gooo]Z00Co
08koo`3o6ooonf[oolX00ooonfX00ooo09?o0?Woool04`04oookJP06on7o0?oJo`3ooo]ZoookJ_lV
0?oo8?l03ooonfX00olao`3ooo]Zo`3oF`03oookJP05oh;o0?l0ok3ooo]Zo`3Xool0odd00_oonfX0
0ol60?oooo]Zoi;o0002oookJP03oa00ool0GOoo01Wo00Cooo]Z00Goo`1AoookJ_oonf[o0:goool0
N@0XoookJP00:_oonfX02Ol0Mooooo]ZoookJ_l0oi[oA?l0onGo0?ooP@3ooo]Zoc_o0003oookJP03
oiCo0?oonf[ooo]Z00;ooo]Z00Soo`<0oookJ_oonf[oo`3MoookJ_l0Xooo01Oook?o00Kooo]Z00?o
o`27oookJ_oo06`00ooonfX01Om=0?ooobh0of40oooonf[o0?m500?ooo]Z00GohP3oo`3oT?oonf[o
oo]Zo`3oTP05oookJP03ofP0oooonf[ooo]Z00?ooo]Z00?o603oonGo0?oUo`001?oUo`06oookJP04
oonn0?oonf[o0?l5on/0o`Cooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP04oook
JP03oon10?oonf[ooo]Z00Cooo]Z00Go0=Coo`3o3?oonf[o0:Woo`28o`02oookJP03o`3oC_l0ocCo
oo]Z00Cooo]Z00?oolT0o`3o7Ol0oe<00ooonfX03Ooo07WoolT0ooo90?oob@3oo`1Zo`0Iool@0?oo
T_l0oomi0?l0odgoP_l0oomi0?lao`001_oonfX02on40?oo9P3oom[o0?oQo`3ooo]Zool0Tol0nOoo
olX0o`3o6olB0?ooogT000SoU?l000?o07?ooomi0?ooN@001OooN@000ooo0?coogT0ool60006oolX
0005ok?o0?oo:03oo`1/of40ool0oi001OoUo`04oolX00;oolT000?oogT0oolX0?oo:0001?oo:007
ool000?oobP00ooo0?H01?ooN@3oo`00ool00?oo0006oolX00;oogT000?o/ol0oolX0?oo:0000ooo
:003ool00003oomB0?oo003oo`0000Goo`0000So0?mKooo90?oob@3oT_l0odCo0?oo057oA?l0o`3o
D`SoiOl00_oonfX02_ooP@3ooo]ZoookJ_oo02gooo]ZoomG0?oonf[oj`3ooookJ_oo_P02oookJP06
oon@0?oonf[o603ooookJ_mX0?oooo]Z0ooUo`001OooN@3oU?l0oiCo0?nDo`3oo`1/00?oogT000_o
oo]Zok?o0?oo0=gooo]Zool30?oonf[o0?_ooookJ_lko`3ooh40oom/0007ooo90007ool60?oob@3o
olT0oookJ_oo0?cooi80oolF0004oookJP03ool0j_oonf[ooo]Z00Wooo]Z00?oiOl0oookJ_oonfX0
1_oonfX01Onio`3ooe80o`3o<ooonf[o02[o00;ooo]Z00?o?ol0o`3oGOmho`001_oonfX00ol0oa_o
oo]Zooo:0004oookJP03ool0Tooo01?ooo]Z00?ooo]Z00Sof_l0on7o0?oonf[ooo]ZodCo0?oUo`3o
8?l0onGo00kooo]Z00?o<Ol0o`3oFooonfX00_oonfX01On2o`3o0?n`o`0`oooonf[o0?m=00;ooo]Z
00?oiOl0o`H0oonBo`000ooUo`000ol@0?oo01WoonGo0003oookJP06oaD0oooo057ooo]Zo`2]oooo
nf[oo`1iCooonfX02?l0Mooooo]Zo`3oV_ooK03ooo]Zoon10?oonf[o>ol00ooonfX00ol0nooooo]Z
oookJP02oookJP08ool30?oonf[ooo]ZoookJ_oo0=gooo]Zo`2Soonco`06oookJP04ool0Qooonf[o
oo]Zool0K0?ooo]Z00CoC@3oof40oooonf[o0?m51?oonfX01?oR0?oooo]ZoookJ_l0oi86oookJP03
ofP0oooonf[ooo]Z00;ooo]Z00Go603oonKo0?oonf[ooo]Zoon@0009oookJP03oonn0?oonf[oj`3o
00Gooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z
00Cooo]Z00Go0=Coo`04oooonf[ooo]Zo`2Yo`03oookJP03o`3oC_l0ocCooo]Z00?ooo]Z00?o0>7o
o`3o7Ol0oe<01?oonfX03Ooo07Woo`1AoaD0oooonf[o01Wooa00oonBo`3o1P3oo`3oCOl0ok3oP_l0
oookJ_lao`001_oonfX02OlV0?oooo]Zom[o0?oonf[oo`0Cool0TooobP3o0?lKoa80o`02oookJP04
ogSo0?loo`3o02[ooomB00?ooo]Z00?o07?ooookJ_oonfX00ooonfX04ooo0>[ooo]ZoonB0?oo0?co
o`H0on_o0?nX0?oo07Oooom/0?lko`3ooo]Zo`2Soonco`3oo`1/of40ool0odGo0?n@ofP0oolH0?l0
0_oonfX00ooo_P3ooeL0ool0;@02oookJP06o`3Dool0odko0?ldoookJ_l@0?ooT_l00ooonfX01Ol0
g?oooe80oookJ_oonf[oo`3f00?ooo]Z0_l00002ool0mP0@oookJ_l0g?oooo]Zoa00oooonf[o0?m>
oookJ_m`0?oooo]ZoaP0ool0oi;oH@3ook?o0?ooK03oo`3fool0o0Gooo]Z00Oooe80o`0Zoooonf[o
0?lKool04ooQo`3o9P3o00;ooo]Z00oo0?mKoh;o0?l60?ooT_l0ool0DOoo07Wooo]Zo`3oDol0oago
oo]Zo`3o=?l0odko08Soo`2Yool0e?l00_oonfX01_ooP@3ooo]ZoookJ_oo02gooo]ZoomG00;ooo]Z
00?oj`3ooonn0?oonfX00_oonfX01?ooT03oi_l0oaP0oomX0?l3oookJP0Eo`3oT_oR0?oooo]Zof40
oooo;P3oo`1/oookJ_oo08Oo0?oNoookJ_nco`3o0:?oool0gOoo0`3ooo]Zo`3koooonf[o>ol0oon1
0?ooK03o07Oo00;ooo]Z00KoZ03oool0m_oonf[ojol0ool60?lH0?l2oookJP03ool0o?ooTP3ooaH0
00Cooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ol0Looooo]ZoookJP07oookJP04oomB0?l0oc?ooo]Z
o`0Zo`;ooo]Z00?o?ol0o`3Loomho`001_oonfX01?l0S_oo0?lKoookJ_oobP03oookJP03ool0Tooo
01?ooo]Z00Cooo]Z00Kof_l0oookJ_oonf[ooo]ZobH0oolPo`0?oookJP03oc7o0?oonf[o0?mK00?o
oo]Z00GoP_l0o`3o/?oonf[o0>Soo`3oC@02oookJP03o`H0oooonf[oT_l000;ooo]Z00?o403ooook
J_l06Ol01?oonfX01Ooo057ooo]ZoookJ_l0[Oooo`1i02Sooo]Z000ZoookJP09o`1goooonf[ooo]Z
o`3oV_m4o`3oiOl0oon10?oonf[o>ol000?ooo]Z00?oU?l0oookJ_oonfX00_oonfX02?oo0`3ooo]Z
oookJ_oo0=gooo]Zo`2Sool05ooo/ol01OoonfX01?l0omkoo`27oookJ_oo06`3oookJP05odd0oooo
;P3oH@3ooookJ_l0odD00ooonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Gooo]Z00?oJ03ooookJ_oo
nfX00ooonfX00olH0?ooiOl0onGo0004onGo00Kooo]Z00Cookh0oookJ_l0o`Goj`3o1?oonfX00ooo
E`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Cooo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0
e?oo0?l<o`3o3?l0ZOoo08So00;ooo]Z00?o0?m>o`3o=?oonfX01?oonfX00ooob@3o0?lMo`3oD`03
oookJP0>ool0NOoob@3oolT0ooo90?l06Ooo403oool0mOnBo`3oogT0o`3oCOn2o`3oogT0oc7o0?oo
N@05oookJP03ob3o0?lV0?oof_l000;ooo]Z00Coo`2Co`3ioooobP3o0?lK0_ooN@001?l0omooN?l0
o`0ZoonDo`04oomi0003o`1coooonf[ooo]Z00;ooo]Z00Koo`3Zoomi0?ooN@3oo`3loomi0?oo1P06
oolX0005ok?o0?oo:03oo`1/onGo0?oo00001OoUo`04oolX0003ooo90?oo:03oogT000KoobP01ooo
0002oolX0003ool00?l0003oogT000Coo`001_oo:002oomi0003ok?o0?ooN@3oogT000?oobP00ooo
00000ol0oc?ooe80ool00003ool00004obH0oooo003oo`00o`3oF`GoolT000?oo`00o`3oDooUo`00
1_oUo`03oookJP0:oon10?oonf[ooo]Zool0;Ooonf[ooeL0oookJ_o[0?oooo]Zoonn00;ooo]Z00Ko
oi00oookJ_lH0?oooo]ZofP0oooonfX2onGo0003o`3oT?ooN@3oU?l000;oU?l000ooo`1/oomi0?oo
N@3oogT0oookJ_nco`3oo`3MoookJ_oo0`3ooo]Zo`3koooonf[o>ol0o`3oc?ooK0001ooob@001ooo
1P3oolT0ooo90?oo0?cooo]ZoonB0?oo5P001?oonfX00ooo0>[ooo]ZoookJP08oookJP03onGo0?oo
nf[ooo]Z00Oooo]Z00Go^Ol0oomB0?l0oc?ooo]Zo`0Zo`02oookJP03ocoo0?l0oegoN?l000Kooo]Z
00?o0?lKoookJ_oobP001?oonfX00ooo09?oo`0CoookJP03oookJP08om[o0?oonf[ooo]ZoookJ_m4
o`3ooo]Zob3o0?oUo`0>oookJP03oc7o0?l0oe_ooo]Z00;ooo]Z00GoP_l0o`3o/Ol0<?oooo]Zo`3o
C@02oookJP03onGo0?l60?ooT_l000?oiOl000?o403oo`0IoooUo`000ooonfX01_lE0?ooo`1Aoook
J_l0[Ooooo]Zool0NDoooo]Z00So07OooookJ_l0oi[oof`0oookJ_ooP@3ooo]Zoc_o00?ooo]Z00?o
0?_ooookJ_oonfX00_oonfX02?oo0`3ooo]ZoookJ_oonf[oo`3MoookJ_l0Xooo/ol01_oonfX01?oo
08Oooo]ZoookJ_oo06`3oookJP04odd0oomQ0?oooo]Zo`3oA@Cooo]Z00CohP3ooookJ_oonf[o0?nB
1_oonfX00omX0?oooo]ZoookJP02oookJP05oaP0oooVo`3ooo]ZoookJ_ooT0002OoonfX00ooo_P3o
oo]Zon/0o`05oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3o
oo]ZoookJP04oookJP05o`3Dool01?oooo]ZoookJ_l0ZOl00ooonfX00ol0odko0?ldoookJP03oook
JP03o`3Qool0oago0?mC00Cooo]Z00goo`1iool0DOlE0?oo01Wooa00oooonf[oT_l0o`H0ool0odgo
0?n`oh;o0?oonf[o<Ol000Kooo]Z00Wo9P3ooookJ_oJo`3ooo]Zool04ooo09?oolX0o`3o6olB0?l0
0_oonfX01?mho`3o?ol0o`0ZooooDP03oookJP03o`1coooonf[ooo]Z00?ooo]Z01?oo`3ZoookJ_oo
TP3oo`3lool60?o[o`3oZ03oo`1gooooK03o>ol0oookJ_l0Xooo/ol0ool0K?mQ0?oo0?m5o`3oT?oo
nf[o603o00;ooo]Z00?ookh0oomG0?oo02d00_oonfX01_l0e?oo0?m>o`3o=?oonf[o403ooi;o00Co
oo]Z00Cooe80oookJ_oonf[ooo]Z1Ooo0?H2o`00000@o`3Loooonf[ooo]Zoa00ool0odko0=Cooook
J_m`0?ooi_l0oaP0ool0oi;oH@3ook?o0?ooK03oo`3fool0o0Gooo]Z00Oooe80o`3ogol0oa_oolX0
ool04ooQo`3o9P3o00;ooo]Z00oo0?mKoh;o0?l60?ooT_l0ool0DOoo07Wooo]Zo`3oDol0oagooo]Z
o`3oC_l0obko0:Woo`04ool0e?l00_oonfX01_ooP@3ooo]ZoookJ_oo02gooo]ZoomG00;ooo]Z00?o
j`3ooonn0?oonfX00_oonfX01?ooT03o603ooookJ_mX0?l2oookJP0So`3oT_l0oi3ohP3ooookJ_mQ
0?ooobh0ool0K?oonf[oo`27o`3og_oonf[o/ol0o`2Soooo0=goo`<0oookJ_l0nooooo]Zoc_o0?l0
olcoof`0o`1goooonf[oZ03oo`2Voooo0?Kojol0oookJ_oo1P3o603ooookJ_oo0?cooo]ZoonB0?oo
5P001?oonfX00ooo0>[ooo]ZoookJP09oookJP03o`1coooonf[ooo]Z00Oooo]Z00Cooe80o`3o<ooo
nf[o02[o0_oonfX00oloo`3o0=coogSo0006oookJP04oa80ool0oa_ooo]Zooo:00?ooo]Z00?oo`2C
ool04ooonfX00ooonfX00ooQo`3of_l0oookJP02oookJP03obH0oolPo`3ooo]Z00kooo]Z00?o<Ol0
oookJ_l0oe/00ooonfX01On2o`3o033ooookJ_l0j?oo0?m=00;ooo]Z00?o1P3ooookJ_nBo`000_oo
nfX00ol@0?oooo]Zo`0Io`04oookJP05ool0DOoonf[ooo]Zo`2]oooo07T0:?oonfX002[ooo]Z00Wo
07OooookJ_oonf[o0?nJodCo0?oUo`3ooh40oookJ_lko`000ooonfX00onDo`3ooo]ZoookJP02oook
JP08ool30?oonf[ooo]Zool0gOoonf[o0:?ook?o0?nO0?l5oookJP04ool0QooMo`3ooo]Zool0K0?o
oo]Z00GoC@3oool^0?mQ0?oooo]Zo`3oA@03oookJP05on80ool0oi3ooo]ZoookJ_l0oi801OoonfX0
0omX0?oooo]ZoookJP03oookJP03oaP0oooUo`3oiOl000CoiOl01_oonfX01?oo_P3ooo]Zo`3o1Oo[
0?l4oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3ooo]Zoook
JP04oookJP05o`3Dool0o`co0?l<o`2Yool0R?l00_oonfX00ol0odko0?ldoookJP04oookJP03ooo9
0?l0oago0?mC00?ooo]Z00_oo`1iooo90?oob@3oolT0o`0Iool@0?ooo`3eoi;o0?l0j?oo0?m=oh;o
0003oomi00Gooo]Z00?o8?l0obH0ooooN@000_oonfX01?oo09?o0?Woooo:0?l0oa/2oomi0004o`3o
gomho`3o02[ooiCo00CoogT000?o07?ooookJ_oonfX00_oonfX01Ooo0>[ooo]ZoolF0?oo0?cooo]Z
00OoobP000Go/ol0oolX0?oo06coiOl0ool00006onGo00;oobP00ooob@02oomi00GoobP01ooo0002
oolX00Ooo`001?oo:004oomi0003ok?o0?ooN@3oogT000;oobP01?oo00000oooDP3o02[oool00003
ool00004obH0oooo003oo`00o`3oF`OoolT01ooUo`03oookJP09oon10?oonf[ooo]Zool0;Ooonf[o
oeL0oookJ_ooN@3ookh000?ooo]Z00Kooi00oookJ_lH0?oooo]ZofP0oooonfX2onGo0003o`3oT?oR
0?ooU?l000;oU?l0013oo`1/omgo0?ooN@3oogT0oookJ_nco`3oo`3MoookJ_oo0`3ooo]Zo`3koooo
nf[o>ol0o`3oV_oob@3oo`3i1Ooob@002?oo1P3oolT0ooo90?oonf[oo`3loookJ_ooTP3ooaH00ooo
nfX00ooo0>[ooo]ZoookJP09oookJP03onGo0?oonf[ooo]Z00Oooo]Z00[o^Ol0oomB0?l0oc?ooo]Z
o`0Zoooonf[o?ol0oookJ_l0g?ooN?l01_oonfX00ol0oa_ooo]Zooo:0004oookJP03ool0Tooo01?o
oo]Z00?ooo]Z00Oof_l0oookJ_oonf[ooo]ZodCo0?lPo`3oiOl000oooo]Z00?o<Ol0o`3oFooonfX0
0_oonfX01On2o`3o0?nao`0`ool0j?oo0?m=00;ooo]Z00?oiOl0o`H0oonBo`000_oUo`001?oonf[o
403oo`0IoooUo`03oookJP06oaD0oooo057ooo]Zo`2]oooonf[oo`1iCooonfX02?l0Mooooo]Zo`3o
V_ooK03ooo]Zoon10?oonf[o>ol00ooonfX00ol0nooooo]ZoookJP02oookJP08ool30?oonf[ooo]Z
oookJ_oo0=gooo]Zo`2Soonco`06oookJP04ool0Qooonf[ooo]Zool0K0?ooo]Z00CoC@3oof40oooo
nf[o0?m51?oonfX01?oR0?oooo]ZoookJ_l0oi86oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603o
onKo0?oonf[ooo]Zoon@0009oookJP03oonn0?oonf[oj`3o00Gooo]Z00?ooeL0oookJ_oonfX00_oo
nfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Cooo]Z00Go0=Coo`04oooonf[ooo]Z
o`2Yo`03oookJP03o`3oC_l0ocCooo]Z00?ooo]Z00?o0>7oo`3o7Ol0oe<01?oonfX03Ooo07Woo`1A
oaD0ool06Ooo403ooookJ_nBo`3o1P3oo`3oCOl0ok3oP_l0o`3oFolao`001_oonfX02OlV0?oooo]Z
om[o0?oonf[oo`0Cool0TooobP3o0?lKoa80o`02oookJP04ogSo0?loo`3o02[ooomB00?ooo]Z00?o
07?ooookJ_oonfX00ooonfX06?oo0>[ooo]ZoonB0?oo0?coo`H0on_o0?nX0?oo07Oooom/0?lko`3o
oo]Zo`2Soonco`3oo`1/of40ool0odGo0?n@oookJ_oVo`3o603ooookJ_oo_P3ooeL0ool0;@;ooo]Z
00Ko0=Coo`3oC_l0ocCo0?l8oookJ_nBo`04oookJP03o`3LooooDP3ooo]Z00Cooo]Z0_l00002o`3L
o`;ooo]Z00ko403ooookJ_l0odko0=CooookJ_m`0?oo603oo`3oT_mQ0?oo/ol0oookJ_ooK03o603o
ool0o0Gooo]Z00Oooe80o`3ogol0oa_oolX0ool04olPo`3o9P3o00;ooo]Z00oo0?mKoh;o0?nBo`3o
403oool0DOoo07Wooo]Zo`3oDol0oagooo]Zo`3oC_l0obko0:Woo`04ool0e?l00_oonfX01_ooP@3o
oo]ZoookJ_oo02gooo]ZoomG00;ooo]Z00Woj`3ooookJ_oonf[ooo]Zoon@0?oonf[o603ooookJ_mX
0?l00_oonfX08ol0oi;o0?n@on80oooonf[oH@3oodd0oooo06cooo]Zool0Qol0omkooo]Zok?o0?mi
0?ooo`3Mool30?oonf[o0?_ooookJ_lko`3o0?nJo`1goooo0?Wooo]ZojP0ool0Y_ooo`3fon_o0?oo
1P3ooo]ZoaP0oooonf[oo`3loookJ_ooTP3ooaH000Cooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ol0
Looooo]ZoookJP07oookJP09oomB0?l0oc?ooo]Zo`0Zoooonf[o?ol0oookJ_l0g?ooN?l000Kooo]Z
00Co4P3oo`3o6ooonf[oolX00ooonfX00ooo09?oo`0CoookJP03oookJP03on7o0?oJo`3ooo]Z00;o
oo]Z00?o9P3ooh@0oooonfX03_oonfX00olao`3o0?mKoookJP03oookJP05oh;o0?l0<?oooo]Zo`3X
ool0odd00_oonfX00ol60?ooo`3eoi;o0002oookJP03oa00oooonf[o01Wo00Cooo]Z00Goo`1Aoook
J_l0[Ooooo]Zool0N@0XoookJP00:_oonfX02Ol0Mooooo]ZoookJ_l0oi[oA?l0onGo0?ooP@3ooo]Z
oc_o0002oookJP03oiCo0?oonf[ooo]Z00?ooo]Z00Soo`<0oookJ_oonf[oo`3MoookJ_l0Xooo/ol0
oil0o`Gooo]Z00Coo`27omgo0?oonf[oo`1/0ooonfX01Om=0?ooobh0of40oooonf[o0?m500?ooo]Z
00GohP3oo`3oT?oonf[ooo]Zo`3oTP05oookJP03ofP0oooonf[ooo]Z00?ooo]Z00?o603oonGo0?oU
o`001OoUo`05oookJP04oonn0?oonf[o0?l5on/0o`Cooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo
02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Cooo]Z00Go0=Coo`3o3?l0o`co0:Woo`28o`02
oookJP03o`3oC_l0ocCooo]Z00Cooo]Z00?oolT0o`3o7Ol0oe<00ooonfX02ooo07WoolT0ooo90?oo
b@3o01Wooa00oooo0?GoT_l0o`3Xool0odgoP_l000?oogT01OoonfX00olPo`3o9P3ooomi0002oook
JP04ool0Tol0nOooolX0o`3o6`;oogT000Co0?oOogSo0?l0:_oooe801?ooN@000ol0Looooo]Zoook
JP02oookJP0:ool0j_oonf[ooaH0ool0o?oonf[oo`H0on_o0?oo:03o07Oooc_o00;oobP000Co/ol0
oolX0?oo06coiOl00_oo0005onGo00;oobP00ooob@02oomi00GoobP01?oo0004oolX00Ooo`001?oo
:004oomi0004ok?o0?ooN@3oogT0oomi00;oobP01?oo00000oooDP3oo`00ool00003ool00004obH0
oooo003oo`00o`3oF`OoolT01_oUo`001?l0e?oooo]ZoookJ_ooP@02oookJP07ool0;Ooonf[ooeL0
oookJ_m`0?ooogT0oonn0003oookJP05oon@0?l0M?oo603ooookJ_mX0?l00_oonfX00ooUo`3o0?n@
on80o`03oiCo0006ool0K?oMo`3oogT0oookJ_nO0?oo/ol00_oonfX02?oo0`3ooo]Zo`3koolko`3o
oh40o`3oV_oob@3oo`3i1Ooob@002?oo1P3oolT0ooo90?oonf[oo`3loookJ_ooTP3ooaH00ooonfX0
0ooo0>[ooo]ZoookJP09oookJP03onGo0?oonf[ooo]Z00Kooo]Z00?o^Ol0oookJ_ooDP000_oonfX0
1_l0:_oooo]Zocoo0?oonf[o0=coogSo00Kooo]Z00?o0?lKoookJ_oobP000ooonfX00ooo09?ooo]Z
ool04`04oookJP07om[o0?oonf[ooo]ZoookJ_m4o`3o8?l0onGo000>oookJP03oc7o0?oonf[o0?mK
00?ooo]Z00GoP_l0o`3o/Ol0<?oo0>Soo`3oC@03oookJP07o`H0oonBo`3oiOl0onGo0?oonf[o403o
o`0Io`03oookJP07oaD0oooonf[oo`1AoookJ_l0[Ooooo]Zool0N@1?oookJP08o`1goooonf[o0?nJ
oom/0?l0olcooh40oookJ_lko`02oookJP03o`3koooonf[ooo]Z00?ooo]Z00Soo`<0oookJ_oonf[o
o`3MogT0oooonf[o0:?ook?o00Kooo]Z00Coo`27oookJ_oonf[oo`1/0ooonfX01?m=0?ooH@3ooook
J_l0odD3oookJP05on80ool0oi3ooo]ZoookJ_l0oi801_oonfX00omX0?oooo]ZoookJP02oookJP05
oaP0oooVo`3ooo]ZoookJ_ooT0002OoonfX00ooo_P3ooo]Zon/0o`05oookJP03oomG0?oonf[ooo]Z
00;ooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3ooo]ZoookJP04oookJP05o`3Dool01?oooo]Z
oookJ_l0ZOl00ooonfX00ol0odko0?ldoookJP03oookJP03o`3Qool0oago0?mC00Cooo]Z00goo`1i
ool0DOoonf[o01Wooa00oooonf[oT_l0o`H0ool0odgo0?n`oh;o0?l0oe_o<Ol000Kooo]Z00Wo9P3o
oookJ_oJo`3ooo]Zool04ooo09?oolX0o`3o6olB0?l00_oonfX01?mho`3o?ol0o`0ZooooDP03oook
JP03o`1coooonf[ooo]Z00?ooo]Z01Soo`3ZoookJ_ooTP3oo`3lool60?o[o`3o0:Koo`1gooooK03o
>ol0oookJ_l0Xooo/ol0ool0K?m=0?ooH@3oo`3oT?oonf[oi_l0oaP0oooonf[ookh0og00ooooE`02
oookJP07o`3Dool01?oo0?m>o`3o2?oonf[o403ooi;o0004oookJP03o`3LooooDP3ooe8000;ooo]Z
0_ooDP004_l0g?oo0000o`000?oonf[o403ooookJ_l0odko0=CooookJ_m`0?oooo]ZoaP0ool0oi;o
H@3ook?o0?ooK03oo`3fool0o0Kooo]Z00Kooe80o`3ogol0oa_oolX0ool04olV0?l3oookJP0Ao`3o
Fon2o`3oT_l0oa00oooo057oo`1ioookJ_l0oe?o0?lMoookJ_l0odko0?l^o`2Yool01?oo0=Cooook
J_ooP@000_oonfX00ooo02gooo]ZoomG0002oookJP03og00ooo[0?oooo]Z00;ooo]Z00Gooi00o`1d
oolH0?oooo]ZofP0o`02oookJP0So`3oT_l0oi3ohP3ooookJ_mQ0?ooC@3oool0K?oonf[oo`27o`3o
g_nO0?oo/ol0ool0gOoonf[oo`<0oookJ_l0nooo>ol0oon10?l0oi[o07Ooool0nOoonf[oZ03oo`2V
oooo0?Kojol0ool60?oonf[o603ooookJ_oo0?cooo]ZoonB0?oo5P001?oonfX00ooo0>[ooo]Zoook
JP08oookJP03o`1coooonf[ooo]Z00Oooo]Z00[o^Ol0oomB0?oonf[ooo]Zo`0Zoooonf[o?ol0oook
J_l0g?ooN?l01_oonfX01?lB0?oo0?lKoookJ_oobP02oookJP03ool0Tol0nOooo`0C00Cooo]Z00?o
hOl0om[o0?oonfX00_oonfX00olV0?ooQ03ooookJP0=oookJP03oc7o0?oonf[o0?mK00Cooo]Z00Go
P_l0o`0`oooonf[o0>Soo`3oC@02oookJP03o`H0oooo0?GoT_l000;ooo]Z00?o403oool0J_l06Ol0
0ooonfX01_lE0?ooo`1AoookJ_l0[Ooooo]Zool0NBSooo]Z000ZoookJP09o`1goooonf[ooo]Zo`3o
V_m4o`3oiOl0oon10?oonf[o>ol000;ooo]Z00?oU?l0oookJ_oonfX00ooonfX02?oo0`3ooo]Zool0
gOmi0?oooo]Zo`2Soonco`3oW`3o1OoonfX01?oo08OogOl0oookJ_oo06`3oookJP05odd0oooo;P3o
H@3ooookJ_l0odD00ooonfX01?oR0?oooo]ZoookJ_l0oi86oookJP03ofP0oooonf[ooo]Z00?ooo]Z
00?o603oonGo0?oUo`001OoUo`05oookJP04oonn0?oonf[o0?l5on/0o`Cooo]Z00?ooeL0oookJ_oo
nfX00ooonfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Cooo]Z00Go0=Coo`3o3?l0
o`co0:Woo`28o`02oookJP03o`3oC_l0ocCooo]Z00Cooo]Z00?o0?lMoookJ_l0oe<00ooonfX00ooo
07WoolT0ooo90002ooo90006oa00oooo0?GoT_l0o`3Xool0odgoP_l00oooN@05oookJP09ob3o0?lV
0?ooogT0oomi0?oonf[oo`2Co`3ioooobP3o0?lK00;oogT000Go0?oOogSo0?oob@3ooe80oomi0003
oookJP03o`1coooonf[ooo]Z00;ooo]Z00[oo`3ZoookJ_oo5P3ooi80ool0o?oo1P3ojol0ojP0ool0
Mooo>ol00_oo:0001?nco`3oobP0ool0K?oUo`02ool000GoiOl00_oo:003ooo900?oogT00ooo:006
ool000SoobP00_oo0003oolX00CoogT000?oo`00ok?o0?ooN@000_ooN@000ooo:03ooo]Zool00003
ool00003oomB0?oo003oo`0000?oo`0000Co9P3oool00?oo003o0?mK1_oob@000ol0oe?o0>7oonGo
0004onGo0004o`3Doooonf[ooo]Zoon100;ooo]Z00Ooo`0]oookJ_ooE`3ooo]Zog00ooooN@3ookh0
00?ooo]Z00Cooi00oaP0oooVo`3oJ03o0ooonfX00ooUo`3ohP3ooiCo0003oiCo000<ool0K?l0omko
ogT0oookJ_nO0?oo/ol0oookJ_oo0`3ooo]Zo`3koooob@3o>ol00ooob@000ooo0?Wooo]Zooo90003
ooo90008ool60?oob@3oolT0oookJ_oo0?cooo]ZoonB0?oo5P03oookJP03ool0j_oonf[ooo]Z00Wo
oo]Z00?oiOl0oookJ_oonfX01_oonfX01Onio`3ooo]ZoomB0?oonf[o02[o00;ooo]Z00Co?ol0o`3L
oolm0?ooN?l01OoonfX01?l0S_oo0?lKoookJ_oobP03oookJP03ool0Tooonf[oo`0C00Cooo]Z00Oo
f_l0oookJ_oonf[ooo]ZodCo0?lPo`3oQ03o00kooo]Z00?o<Ol0oookJ_l0oe/00ooonfX01On2o`3o
033ooookJ_l0j?oo0?m=00?ooo]Z00Oo1P3ooi;o0?oUo`3oiOl0oa00ool0GOoo01Wo00?ooo]Z00Oo
5@3ooookJ_oo057ooo]Zo`2]oooonf[oo`1i04oooo]Z00So07OooookJ_l0oi[oof`0o`3oc?ooP@3o
oo]Zoc_o00;ooo]Z00?o0?_ooookJ_oonfX00ooonfX02?oo0`3ooo]ZoookJ_oo0=goN@3ooookJ_nc
o`3oW`3o1_oonfX01?oo08Oooo]ZoookJ_oo06`3oookJP04odd0oomQ0?oooo]Zo`3oA@?ooo]Z00Co
hP3ooookJ_oonf[o0?nB1ooonfX00omX0?oooo]ZoookJP02oookJP05oaP0oooVo`3ooo]ZoookJ_oo
T0002OoonfX00ooo_P3ooo]Zon/0o`05oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oo
nfX01?oonfX00oooP@3ooo]ZoookJP04oookJP05o`3Dool01?oooo]Zo`2Yool0R?l00_oonfX00ol0
odko0?l^o`3o=004oookJP03o`3Qool0oago0?mC00Cooo]Z00goo`1iool0DOoonf[o01Wooa00oooo
nf[oT_l0o`H0ool0odgo0?n`oh;o0?l0oe_o<Ol000Kooo]Z00Wo9P3ooookJ_oJo`3ooo]Zool04ooo
09?oolX0o`3o6olB0?l00_oonfX01?mho`3o?ol0o`0ZooooDP04oookJP03o`1coooonf[ooo]Z00;o
oo]Z017oo`3ZoookJ_ooTP3oo`3lool60?o[o`3o0:Koo`1gooooK03o>ol0oookJ_l0Xooo/ol0ool0
K?oonf[oH@3oo`3oT002oookJP06oaP0oooonf[ookh0og00ooooE`3oo`0]0_oonfX01_l0e?oo0?m>
o`3o2?oonf[o403ooi;o00Kooo]Z00Co0=cooomB0?ooDP3o0=co1?l000003ol@0?oooo]Zo`3oC_l0
e?oooo]Zog00oooonf[o603ooookJ_mQ0?oooo]Zok?o0?ooK03oo`3fool0o003oookJP09o`1coooo
nf[ooe80o`0Zoooonf[o0?lKooo:0?oo01?o9P3o00?ooo]Z00ko0?mKo`H0oonBo`3ooo]Zool0DOoo
07Wooo]Zo`3oDooonf[o0?ldo`3oC_oonf[o0:Woo`3Do`;ooo]Z00Kooh40oookJ_oonf[oo`0]oook
J_ooE`02oookJP03og00ooo[0?oooo]Z00;ooo]Z00Gooi00o`1doolH0?oooo]ZofP0o`02oookJP0>
o`3oT_oR0?oooo]ZoookJ_mQ0?ooC@3oool0K?oonf[oo`27oookJ_nO0?oo/ol0ool0gOoo0`02oook
JP0Co`3koolko`3ooh40oom/0?l0Moooo`3ioookJ_nX0?oo0:Koool0m_o[o`3oo`H0oookJ_lH0?oo
oo]Zool0o?oonf[ooi80oolF0003oookJP03ool0j_oonf[ooo]Z00Wooo]Z00?o07?ooookJ_oonfX0
1ooonfX01?nio`3ooe80oookJ_l0:_l2oookJP04ocoo0?l0g?oo?@3oogSo00Kooo]Z00?o0?lKoook
J_oobP000ooonfX00ooo09?o0?Woool04`04oookJP07on7o0?oJo`3ooo]ZoookJ_lV0?oo8?l0oh@0
o`0>oookJP03oc7o0?oonf[o0?mK00Cooo]Z00GoP_l0o`0`oooonf[o0>Soo`3oC@02oookJP03o`H0
oooo0?GoT_l000;ooo]Z00?o403oool0J_l06Ol00ooonfX01_lE0?ooo`1AoookJ_l0[Ooooo]Zool0
NBSooo]Z000ZoookJP09o`1goooonf[ooo]Zo`3oV_m4o`3ooo]Zoon10?oonf[o>ol000;ooo]Z00?o
U?l0oookJ_oonfX00ooonfX02?oo0`3ooo]Zool0gOmi0?oo0:?ooookJ_nco`3oW`3o1OoonfX01?oo
08Oooo]ZoookJ_oo06`3oookJP05odd0oooo;P3oH@3ooookJ_l0odD00ooonfX01?oR0?oooo]Zoook
J_l0oi86oookJP03ofP0oooonf[ooo]Z00?ooo]Z00?o603oonGo0?oUo`001OoUo`05oookJP04oonn
0?oonf[oj`3oog00o`Cooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP05oookJP03
oon10?oonf[ooo]Z00?ooo]Z00?o0?l<o`3Dool0o``00_l0o``01Ol0R?oooo]ZoookJ_l0odko0?ld
00Gooo]Z00?o0?lMoookJ_l0oe<00ooonfX5ooo90006oa00oonBo`3o1P3oo`3Xool0odgoP_l01?oo
N@04oookJP09ob3o0?lV0?ooogT0oomi0?oonf[oo`2Co`3ioooobP3o0?lK00;oogT000Go0?oOogSo
0?oob@3ooe80o`3o<`03oookJP03o`1coooonf[ooo]Z00;ooo]Z013oo`3ZoookJ_oo5P3ooi80ool0
o?lH0?ooo`H0ojP0oooo0?Wo07Oooc_o0?l0nooo/ol0o`2Soooo003oo`1/0ooo0004onGo00;oobP0
0ooob@03oomi00CoobP01ooo0009oolX00CoogT000?o603oool00?nco`000oooN@000ooo:03oo`3l
ool00003ool00003o`3o<oooDP3oobP000Coo`0000?o9P3oool00?l0oe/01ooob@000ol0oago0>7o
onGo0003onGo0005o`3Dool01?oooo]ZoookJ_ooP@000_oonfX3oomi0004oookJ_ooN@3o0?l5oonn
00?ooo]Z00Cooi00oaP0oooVo`3oJ03o0ooonfX00ooUo`3ohP3ooiCo0003oiCo000<ool0K?l0omko
o`27oookJ_nO0?oo/ol0oookJ_oo0`3ooo]Zo`3koooob@3o>ol02Ooob@002?oo1P3oolT0oookJ_oo
nf[oo`3loookJ_ooTP3ooaH00ooonfX00ooo0>[ooo]ZoookJP09oookJP03onGo0?oonf[ooo]Z00Ko
oo]Z00Go^Ol0oookJ_ooDP3ooo]Zo`0Zo`02oookJP04ocoo0?l0g?ooN?l0o`3og`Gooo]Z00Co0?lK
oa80oooonf[oolX00ooonfX00ooo09?oo`0CoookJP04oookJP07om[o0?oonf[ooo]ZoookJ_m4o`3o
8?l0oh@0o`0>oookJP03oc7o0?oonf[o0?mK00?ooo]Z00GoP_l0o`0`oooonf[o0>Soo`3oC@03oook
JP07o`H0oonBo`3oiOl0onGo0?l@0?oo01WoonGo0003oookJP07oaD0oooonf[oo`1AoookJ_l0[Ooo
oo]Zool0N@1?oookJP08o`1goooonf[o0?nJoom/0?l0olcooh40oookJ_lko`02oookJP03o`3koooo
nf[ooo]Z00?ooo]Z00Soo`<0oookJ_oonf[oo`3MogT0ool0Xooo/ol0oil0o`Gooo]Z00Go0?oNool0
Qooonf[ooo]Zool0K003oookJP04odd0oomQ0?oooo]Zo`3oA@?ooo]Z00CohP3ooookJ_oonf[o0?nB
1ooonfX00omX0?oooo]ZoookJP02oookJP05oaP0ool0M?oooo]ZoookJ_ooT0002OoonfX00ooo_P3o
j`3oog00o`05oookJP05oomG0?oonf[ooo]ZoookJ_oo02d01ooonfX00oooP@3ooo]ZoookJP04oook
JP05o`3Dool01?oooo]Zo`2Yool0R?l00_oonfX00ol0odko0?l^o`3o=004oookJP03o`3Qool0oago
0?mC00?ooo]Z00koo`1io`2]oooo057ooo]Zo`0Iool@0?oooo]Zoi;o0?l60?oo0?m=o`3o/?n2o`3o
0?mKoc7o00Kooo]Z00Wo9P3ooookJ_oJo`3ooo]Zool04ooo09?oolX0oookJ_l0oa/00_oonfX01?mh
o`3o?ol0o`0ZooooDP04oookJP03o`1coooonf[ooo]Z00;ooo]Z017oo`3ZoookJ_ooTP3oo`3loaP0
oooo1P3o0:Koool0nOl0Mooo>ol0o`3koooonf[o/ol0o`3og_oo06coH@3oo`3oT002oookJP06oaP0
oooonf[ooo]Zoonn0?ooE`3oo`0]0_oonfX01ol0e?oo0?m>o`3o=?l0o`Sooo]Zoa00oonBo`002Ooo
nfX3o`00000@oa00oooonf[ooo]Zo`3oC_l0e?oooo]Zog00oooonf[o603oo`3oT_mQ0?oo/ol0oook
J_ooK03o603oool0o0?ooo]Z00Wo07?ooookJ_ooDP3o02[ooa80ool0oa_oo`0Con7o0?lV0?l00_oo
nfX03ol0oe_oP_l0o`H0oonBo`3oo`1Ao`2]oooo07Wo0?mCo`3o7Ooonf[o0?ldo`3oC_oonf[o0:Wo
o`3Do`02oookJP06oon10?oonf[ooo]Zool0;Ooonf[ooeL00_oonfX00oo[0?oookh0oookJP02oook
JP05oon@0?l0M?oo603ooookJ_mX0?l00_oonfX03_l0oi;ohP3ooookJ_l0odGoH@3oodd0oooo06co
oo]Zool0Qooonf[oW`3ook?o0?oo0=goo`<00_oonfX03Ol0nooo>ol0oon10?ooK03o07Ooool0nOoo
nf[oZ03oo`2Voooo0?Kojol0ool60?lH0?l00_oonfX01?oo0?cooo]ZoonB0?oo5P03oookJP03ool0
j_oonf[ooo]Z00Wooo]Z00?o07?ooookJ_oonfX01ooonfX01?nio`3ooe80oookJ_l0:_l2oookJP04
ocoo0?l0g?ooN?l0o`3og`Kooo]Z00?o0?lKoookJ_oobP000ooonfX00ooo09?o0?Woool04`04oook
JP07on7o0?oJo`3ooo]ZoookJ_lV0?oo8?l0oh@0o`0>oookJP03oc7o0?oonf[o0?mK00Cooo]Z00Go
P_l0o`0`oooonf[o0>Soo`3oC@02oookJP03o`H0oooo0?GoT_l000;ooo]Z00?o403oo`0IoooonfX0
0ooonfX01_lE0?ooo`1AoookJ_l0[Ooooo]Zool0NBSooo]Z000ZoookJP09o`1goooonf[ooo]Zo`3o
V_m4o`3ooo]Zoon10?oonf[o>ol000;ooo]Z00?o0?_ooookJ_oonfX00ooonfX02?oo0`3ooo]ZonGo
0?mi0?oo0:?ooookJ_nco`3oW`3o1OoonfX01?oo08Oooo]ZoookJ_oo06`3oookJP05odd0oooo;P3o
H@3ooookJ_l0odD00ooonfX01?oR0?oooo]ZoookJ_l0oi86oookJP03ofP0oooonf[ooo]Z00;ooo]Z
00?oi_l0oaP0oooonfX00_oonfX00ooUo`3ooo]ZoookJP06oookJP04oonn0?oonf[oj`3oog00o`Co
oo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP05oookJP03oon10?oonf[ooo]Z00?o
oo]Z00?o0?l<o`3Dool0o``00_l0o``01Ol0R?oooo]ZoookJ_l0odko0?ld00Cooo]Z00CoolT0o`3o
7Ooonf[o0?mC0ooonfX5ooo90006oa00oonBo`3o1P3oo`3Xool0odgoP_l01?ooN@04oookJP0=ob3o
0?lV0?ooogT0oomi0?oonf[oo`2Co`3ioooobP3o0?lKoomi0?oonf[o0?oOogSo0002ooo90005oomB
0?oonf[ooo]ZoookJ_l0Lol01OoonfX03ooo0>[ooaH0oonB0?oo0?co603oool60?nX0?ooo`3io`1g
oolko`3o0?_oogT0oonco`3oo`00ool0K003ool00003oaP0oooo:03oobP000?oobP00ooob@04oomi
00?oobP01ooo0006oolX0003oomi0?oo:03oogT000;oogT00_oo:002ool00006ok?o0?ooN@3oogT0
oolX0?oo0?cooo]Z1?oo00000ol0:_oooe80oolX0003ool00004obH0oolPo`3oo`00o`3oF`KoolT0
00?o0?mCo`3o7Ol0hOl01?oUo`001Ol0e?ooolT0oookJ_oonf[oogT000;ooo]Z1oooN@03oookJP04
oon@0?lH0?oooo]ZofP0o`?ooo]Z00?o0?nBon80oonDo`000_nDo`003Ooonf[oo`1/o`3og_oo08Oo
oo]Zoil0oonco`3ooo]Zool30?oonf[o0?_oooo90?lko`002Ooob@001?oo1P3oolT0oookJ_oo0?`2
oookJP03oonB0?oo5P3ooo]Z00;ooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ooUo`3ooo]ZoookJP06
oookJP05okWo0?ooDP3o0?lcoookJ_l0:_l00_oonfX00oloo`3o0=coogSo0006oookJP04o`3o6olB
0?oooo]Zooo:00?ooo]Z00?oo`2Cool04ooonfX01?oonfX5odCo0003ob3o0?oonf[ooo]Z00gooo]Z
00?o<Ol0o`3oFooonfX00ooonfX01On2o`3o033ooookJ_l0j?oo0?m=00;ooo]Z00So1P3oonGo0?nB
o`3oiOl0oookJ_l@0?oo01WoonGo00?ooo]Z00Co5@3ooookJ_oo057o0:go0_oonfX00ooo07Wooo]Z
oookJP1=oookJP08o`1goooonf[o0?nJoom/0?l0olcooh40oookJ_lko`02oookJP03o`3koooonf[o
oo]Z00?ooo]Z00Soo`<0oookJ_oonf[oo`3MogT0ool0Xooo/ol0oil0o`Gooo]Z00Go0?oNool0Qooo
nf[ooo]Zool0K003oookJP04odd0oomQ0?oooo]Zo`3oA@?ooo]Z00CohP3ooookJ_oonf[o0?nB1ooo
nfX00omX0?oooo]ZoookJP02oookJP05oaP0ool0M?oooo]ZoookJ_ooT0002OoonfX00ooo_P3oj`3o
og00o`05oookJP05oomG0?oonf[ooo]ZoookJ_oo02d01ooonfX00oooP@3ooo]ZoookJP04oookJP05
o`3Dool01?oooo]Zo`2Yool0R?l00_oonfX00ol0odko0?ldoookJP04oookJP03o`3Qool0oago0?mC
00?ooo]Z00koo`1io`2]oooo057ooo]Zo`0Iool@0?oooo]Zoi;o0?l60?oo0?m=o`0`oon2o`3o0?mK
oc7o00Kooo]Z00Wo9P3ooookJ_oJo`3ooo]Zool04ooo09?oolX0oookJ_l0oa/00_oonfX01?mho`3o
0=coo`0ZooooDP04oookJP03o`1coooonf[ooo]Z00?ooo]Z01?oo`3ZoonB0?oo0?cooo]Zool60?l0
Y_ooZ03oo`1goolko`3o0?_ooookJ_nco`3o0?oNool0K?mQ0?oooo]Zo`3oT?oonf[o603o00;ooo]Z
00?ookh0og00oooo02d00_oonfX02?l0e?oo0?m>o`3o=?oonf[o0?l8oookJ_l@0?ooT_l02?oonfX0
4_l0003o403ooa00ool0003ooo]Zo`3oC_l0e?oooo]Zog00oooonf[o603oo`3oT_mQ0?oo/ol0oook
J_ooK03oo`3fool0o0?ooo]Z00[o07?ooookJ_oonf[ooe80o`3ogol0oa_oolX0ool04on40?oo9P3o
0_oonfX03ol0oe_oP_l0oi;o0?l@0?ooo`1Aool0NOoonf[o0?mCo`3o7Ooonf[o0?ldo`3oC_l0ZOoo
08Soo`3Do`02oookJP06oon10?oonf[ooo]Zool0;Ooonf[ooeL00_oonfX00oo[0?oookh0oookJP02
oookJP04oon@0?lH0?oooo]ZofP0o`?ooo]Z01oo0?nBon80oooonf[o0?m5of40oom=0?ooo`1/oook
J_oo08Oooo]Zoil0oonco`3oo`3Mool30?oonf[o0?_ooookJ_lko`3ooh40oom/0?l0Moooo`3ioook
J_nX0?oo0:Koool0m_o[o`3oo`H0oaP0oooonf[oo`3l00;ooo]Z00?ooi80oolF0?oonfX00_oonfX0
0ooo0>[ooo]ZoookJP09oookJP03o`1coooonf[ooo]Z00Oooo]Z00Cooe80o`3o<ooonf[o02[o0_oo
nfX00oloo`3o0=coogSo0007oookJP03o`3o6ooonf[oolX000?ooo]Z00?oo`2Co`3ioooo01<01?oo
nfX01ooQo`3of_l0oookJ_oonf[o9P3oob3o0?n40?l03_oonfX00olao`3ooo]Zo`3oF`03oookJP06
o`3o/?n2o`3o033oo`3Xoooonf[o0?m=0_oonfX00ol60?ooo`3eoi;o0002oookJP03oa00ool06Ooo
oo]Z00?ooo]Z00Ko5@3oool0DOoonf[o0:gooookJ_oo07TXoookJP00:_oonfX02Ol0Mooooo]Zo`3o
V_m4o`3oiOl0oookJ_ooP@3ooo]Zoc_o0002oookJP03o`3koooonf[ooo]Z00?ooo]Z00Soo`<0oook
J_oUo`3oN@3oo`2Soooonf[o/ol0oil0o`Gooo]Z00Coo`27oookJ_oonf[oo`1/0ooonfX01Om=0?oo
obh0of40oooonf[o0?m500?ooo]Z00CohP3ooookJ_oonf[o0?nB1_oonfX00omX0?oooo]ZoookJP02
oookJP03onKo0?lH0?oooo]Z00;ooo]Z00?oiOl0oookJ_oonfX01_oonfX00ooo_P3ooo]Zon/0o`05
oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP03
oookJP03o`3o3?l0e?oo0?l<00;o0?l<00Go08SooookJ_l0odkooo]Zo`3o=004oookJP04ooo90?l0
oagooo]Zo`3oD`?ooo]Z1_oob@001OnBo`3o1P3ooomi0?l0odgoP_l000CoogT01?oonfX00olPo`3o
9P3ooomi0002oomi0008ool0Tol0nOooolX0o`3o6oooN@3ooo]Zoomi0?mho`02ooo90005oomB0?oo
nf[ooo]ZoookJ_l0Lol01OoonfX03ooo0>[ooaH0oonB0?oo0?co603oool60?nX0?ooo`3io`1goolk
o`3o0?_oogT0oonco`3o0?oNool0K004ool00003oaP0oooo:03oobP000;oobP00ooob@04oomi00?o
obP01?oo00000ooo:03oo`00ool00005oolX0004o`3oC_oo:03oogT0oomi00CoobP00_oo00001_nc
o`3oo`00oomi0?lH0?ooo`3loookJP;oogT00_oo00002_ooDP3oo`00oolX0?oo003oobP0ool00?lV
0?ooo`00oolX0?l0oe/5ooo90004o`2]ool0oe?o0?lMooo900?oiOl000?o0:WooiCo0?ooN@000_oo
b@000oooN@3ooo]ZoookJP09oomi0005oon@0?oonf[o603ooookJ_mX0?l00ooonfX00ol0oi;ohP3o
o`3oA@02oiCo0003oookJ_oo06coo`2700;ooo]Z00So/ol0ool0gOoonf[oo`<0oookJ_l0noooolT0
oc_o00WoolT000Coo`H0oookJ_oonf[oo`3l0_oonfX00oooTP3ooo]ZoookJP02oookJP03ool0j_oo
nf[ooo]Z00Wooo]Z00?oiOl0oookJ_oonfX01_oonfX02_nio`3ooe80o`3o<ooonf[o02[ooookJ_lo
o`3ooo]Zo`3Loomho`06oookJP03o`3o6olB0?ooolX000Cooo]Z00?oo`2Cool04ooonfX00ooonfX0
0ooJo`3oA?l0odCo0007odCo00cooo]Z00?o<Ol0o`3oFooonfX00_oonfX01_l0ok3oP_l0o`0`oooo
nf[o0>SoonGo00;ooo]Z00So1P3oonGo0?nBo`3oiOl0oookJ_l@0?oo01WoonGo00?ooo]Z00Ko5@3o
oookJ_oo057o0:gooookJ_oo07U@oookJP08o`1gool0oi[oof`0oookJ_l0olcooh40oookJ_lko`02
oookJP03o`3koooonf[ooo]Z00?ooo]Z00Soo`<0oookJ_oonf[oo`3MogT0ool0Xooo/ol0oil0o`Go
oo]Z00Go0?oNool0Qooonf[ooo]Zool0K003oookJP04odd0oomQ0?oooo]Zo`3oA@?ooo]Z00CohP3o
oookJ_oonf[o0?nB1ooonfX00omX0?oooo]ZoookJP02oookJP05oaP0ool0M?oooo]ZoookJ_ooT000
2OoonfX00ooo_P3oj`3oo`3o1@05oookJP05oomG0?oonf[ooo]ZoookJ_oo02d01ooonfX00oooP@3o
oo]ZoookJP04oookJP05o`3Dool01?oooo]Zo`2Yool0R?l00_oonfX00ol0odko0?ldoookJP04oook
JP03o`3Qool0oago0?mC00?ooo]Z00koo`1io`2]oooo057ooo]Zo`0Iool@0?oooo]Zoi;o0?l60?oo
0?m=o`0`oon2o`3o0?mKoc7o00Kooo]Z00Wo9P3ooookJ_oJo`3ooo]Zool04ooo09?oolX0oookJ_l0
oa/00_oonfX01?mho`3o0=coo`0ZooooDP04oookJP03o`1coooonf[ooo]Z00?ooo]Z017oo`3ZoonB
0?oo0?cooo]Zool60?l0Y_ooZ03oo`1goolko`3o0?_ooookJ_nco`3ogOl0ool0K?m=0?ooH@3oo`3o
T002oookJP05oaP0oooonf[ookh0og00ooooE`000ooonfX01Ol0e?oo0?m>oookJ_oonf[o0?l800;o
oo]Z0ol@0?l4oookJP;o403o0_l00002o`3oCP0=o`3Doooonf[ooo]Zog00oooonf[o603oof40oooo
nf[o/ol0oookJ_ooK03oo`3fool0o003oookJP09o`1coooonf[ooe80o`0Zoooonf[o0?lKooo:0?oo
01?o9P3o00?ooo]Z00oo0?mKo`0`oonBo`3o403oool0DOoo07Wooo]Zo`3oDol0oagooo]Zo`3o=?l0
odko0:Woo`04ool0e?l00_oonfX02OooP@3ooo]ZoookJ_oo02gooo]ZoomG0?oonf[oL03oon/0o`04
oookJP04oon@0?lH0?oooo]ZofP0o`?ooo]Z01oo0?nBon80oooonf[oH@3oodd0oooonf[oo`1/ool0
Qol0omkooo]Zok?o0?l0Xoooo`3Mool30?oonf[o0?_ooookJ_lko`3ooh40oom/0?l0Mooooo]ZojP0
oooonf[o0:KooookJ_o[o`3oo`H0oaP0oooonf[oo`3l00;ooo]Z00?ooi80oookJ_oonfX00_oonfX0
0ooo0>[ooo]ZoookJP09oookJP03o`1coooonf[ooo]Z00Oooo]Z00Wooe80o`3o<ooonf[o02[ooook
J_loo`3ooo]Zo`3Loomho`001_oonfX01?l0S_oo0?lKoookJ_oobP03oookJP03ool0Tooonf[oo`0C
00Cooo]Z00Kof_l0oookJ_oonf[ooo]ZobH0oolPo`0?oookJP03oc7o0?oonf[o0?mK00?ooo]Z00[o
0?n`oh;o0?l0<?oo0>SooookJ_l0odgooo]Zo`H0oooonf[oT_l00ooonfX00ol@0?oo01WooookJP03
oookJP05oaD0oooo057ooo]Zo`2]oooo07T0:OoonfX002[ooo]Z00Wo07OooookJ_l0oi[oA?l0onGo
0?oonf[ooh40oookJ_lko`000_oonfX00ol0nooooo]ZoookJP03oookJP08ool30?oonf[oiOl0onGo
0?l0Xooooo]Zok?o0?nO0?l5oookJP04ool0Qooonf[ooo]Zool0K0?ooo]Z00GoC@3oool^0?mQ0?oo
oo]Zo`3oA@03oookJP04on80oooonf[ooo]Zo`3oTPKooo]Z00?oJ03ooookJ_oonfX00_oonfX00ooV
o`3o603ooookJP02oookJP03onGo0?oonf[ooo]Z00Kooo]Z00?ookh0oookJ_o[0?l01OoonfX00ooo
E`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX00_oonfX2o`3o
3003o`3Dool0o`co0?l<00;o0?l<00Cooo]Zo`3oC_oonf[o0?ld1?oonfX01?oob@3o0?lMoookJ_l0
oe<3oookJPKoolT000GoT_l0o`H0ooooN@3o0?m=o`3o/004oomi00Cooo]Z00?o8?l0obH0ooooN@00
0_ooN@001?oo09?o0?Wooomi0?l0oa/2oomi0006ocd0oomho`3oolT0ooo90?ooDP3o^Ol00ooonfX0
0ol0Looooo]ZoookJP02oookJP0?ool0j_oo5P3ooi80ool0o?lH0?ooo`H0on_o0?l0Y_oo07Oooc_o
0?l0noooo`00ok?o0?l0omkoo`1/00Coo`0000?o603ooolX0?oo:0000_oo:003ooo900GoogT00ooo
:006ool000;oobP000?oo`00oolX0?l0odh00_ooN@05oolX0003ooo90?oo003o/ol000?oo`0000?o
o`3lool00?oonfX01?ooN@002_ooDP3oo`00ooo:0?l0oa_oobP0ool00?lV0?ooo`00oookJ_l0oe/6
ooo90003o`3oDol0oagoolT000?oiOl01?nDo`03oomi0003ool0;OooN@3oogT000OoogT000Gooi00
oookJ_lH0?oooo]ZofP0o`02oookJP04o`3oT_l0oi3ohP3oo`3oA@;oU?l000?oo`1/omgo0?oo08L0
0_oonfX02?nco`3oo`3MoookJ_oo0`3ooo]Zo`3koooob@3o>ol02?oob@001Ooo1P3oolT0oookJ_oo
nf[oo`3l00;ooo]Z00Gooi80oookJ_oonf[ooo]Zool0jP0;oookJP03onGo0?oonf[ooo]Z00Oooo]Z
00[o^Ol0oomB0?l0oc?ooo]Zo`0Zoooonf[o?ol0oookJ_l0g?ooN?l01_oonfX00ol0oa_o4P3oooo:
0003oookJP03o`3ioooo09?oo`0C00Cooo]Z00?of_l0odCo0?m4o`001om4o`0;oookJP03oc7o0?oo
nf[o0?mK00?ooo]Z00Ko0?n`oh;o0?l0<?oooo]Zo`3XoooUo`02oookJP07o`H0oooonf[oT_l0onGo
0?oonf[o403oo`0Io`04oookJP06oaD0oooonf[oo`1Ao`2]oooonf[oo`1iD?oonfX02?l0Mooo0?nJ
oom/0?oonf[o0?o<oon10?oonf[o>ol00_oonfX00ol0nooooo]ZoookJP03oookJP08ool30?oonf[o
oo]Zool0gOmi0?oo0:?ook?o0?nO0?l5oookJP05o`3og_oo08Oooo]ZoookJ_oo06`00ooonfX01?m=
0?ooH@3ooookJ_l0odD3oookJP04on80oooonf[ooo]Zo`3oTPOooo]Z00?oJ03ooookJ_oonfX00_oo
nfX01OlH0?oo07CooookJ_oonf[ooi0000Sooo]Z00Cookh0oookJ_o[0?oo0?l51OoonfX01OooE`3o
oo]ZoookJ_oonf[oo`0]00Oooo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0e?oo00CooookJ_l0ZOoo
08So00;ooo]Z00?o0?m>o`3o=?oonfX01?oonfX00ol0hOoo0?lMo`3oD`03oookJP0>ool0NOl0[Ooo
o`1AoookJ_l06Ooo403ooookJ_nBo`3o1P3oo`3oCOl0<?ooP_l0o`3oFolao`06oookJP03obH0oooo
nf[of_l000;ooo]Z00Coo`2Co`3ioooobP3o0?lK0_oonfX01Omho`3o0=coocoo0?ooDP3o0?lc00?o
oo]Z00?o07?ooookJ_oonfX00ooonfX04Ooo0>[ooi80ool0o?oonf[oo`H0on_o0?nX0?oo07Oooc_o
0?l0nooooo]Zo`2Soonco`3oo`1/odd0oomQ0?oo0?n@00;ooo]Z00Ko603ooookJ_oo_P3oL03ooomG
0?oo02d2oookJP06o`3Dool01?oo0?m>o`3oC_oonf[o0?l81?oonfX4oa00o`0>oookJ_l0003o0000
o`3oC_l0e?oo00CooookJ_ooE`3oL03ooookJ_lH0?ooH@3ooookJ_nco`02oookJP03oom/0?lH0?oo
o`3l00?ooo]Z00Wo07?ooookJ_ooDP3o0?oOoa80ool0oa_oo`0Con7o0?lV0?l00ooonfX02?l0oe_o
1P3ooi;o0?oonf[oo`1Aool0NOl0oe?o0?lM0_oonfX01Ol0odko0?l^o`2Yool01?oo0=Co00;ooo]Z
00?ooh40oookJ_oo02d00_oonfX01?ooE`3ooo]Zon/0oooo_P04oookJP04oon@0?lH0?oooo]ZofP0
o`;ooo]Z00Wo0?nBo`3oT?oR0?oooo]Zof40oom=0?ooo`1/oookJ_oo08L00_oonfX05Onco`3o0:?o
ool0gOoo0`3ooo]Zo`3koooonf[o>ol0o`3oc?ooK03o07OooookJ_nX0?oooo]Zo`2Voooonf[oo`H0
oookJ_lH0?oooo]Zool0o002oookJP03oonB0?oonf[ooo]Z00;ooo]Z00?oo`3ZoookJ_oonfX02Ooo
nfX00ol0Looooo]ZoookJP07oookJP09oomB0?l0oc?ooo]Zo`0Zoooonf[o?ol0oookJ_l0g?ooN?l0
00Kooo]Z00Co08koo`3o6ooonf[oolX00ooonfX00ooo09?oo`0CoookJP04oookJP06om[o0?oonf[o
oo]ZoookJ_lV0?oo8?l03ooonfX00olao`3ooo]Zo`3oF`03oookJP0:o`3o/?n2o`3o033oo`3Xoooo
nf[o0?m=oookJ_l60?oooo]Zoi;o00?ooo]Z00?o403oo`0IoooonfX00ooonfX01OlE0?ooo`1Aoook
J_l0[Oooo`1i02Wooo]Z000ZoookJP09o`1goooonf[o0?nJodCo0?oUo`3ooo]Zoon10?oonf[o>ol0
00;ooo]Z00?o0?_ooookJ_oonfX00ooonfX02?oo0`3oiOl0onGo0?oUo`3o0:?ooookJ_nco`3oW`3o
1OoonfX01?oo08Oooo]ZoookJ_oo06`3oookJP05odd0oooo;P3oH@3ooookJ_l0odD00ooonfX01?oR
0?oooo]ZoookJ_l0oi86oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?oi_l0oaP0oooonfX00_oonfX0
0ooUo`3ooo]ZoookJP06oookJP03oonn0?oonf[oj`3o00Gooo]Z00?ooeL0oookJ_oonfX00_oonfX0
0onDo`3ooo]ZoookJP05oookJP03oon10?oonf[ooo]Z00;ooo]Z0_l0o``00ol0e?oo0?l<o`3o3002
o`3o3004oookJ_l0odkooo]Zo`3o=0Cooo]Z00CoolT0o`3o7Ooonf[o0?mC0ooonfX6ooo90005oi;o
0?l60?ooogT0o`3oCOl0ok001?ooN@04oookJP03ob3o0?lV0?ooogT000?oogT000Oo0?Wooomi0?oo
bP3o0?lKoomi0?lm0?ooN?l000;oolT000?ooe80okWo0?oonfX00_oonfX00ol0Looooo]ZoookJP02
oookJP0?ool0j_oo5P3ooo]Zool0o?oonf[oo`H0on_o0?l0Y_ooobP0ool00?l0noooo`00ok?o0?oo
:03oo`1/00Goo`001?oo:003ooo900GoogT00ooo:008ool000;o0?m>00?oogT0oolX0?oo:0000ooo
:0001Ooo003oobP0ooo90?oo003o/ol000?oo`0000?oo`3loookJ_oonfX00oooN@001?ooDP3oo`00
ool00?l0oa/2ool00004obH0oolPo`3oobP0o`3oF`GoolT000Goo`1io`3oDol0oago0>7oooo90002
onGo00OoU?l02_ooN@001_oonf[ooi00onKo0?lH0?oooo]ZofP0o`;ooo]Z00Wo0?nBon80oooonf[o
0?m5oiCo0?m=0?ooo`1/o`3og_oo08L00_oonfX00onco`3oo`3Mool30002oookJP03o`3koooonf[o
>ol000SoolT000Goo`H0ooo90?oonf[ooo]Zool0o002oookJP05oonB0?oonf[ooo]ZoookJ_oo0>X0
2ooonfX00ooUo`3ooo]ZoookJP07oookJP0:okWo0?ooDP3ooo]ZoookJ_l0:_oooo]Zocoo0?l0g?oo
oo]ZogSo00Kooo]Z00?o0?lKoa80oooobP000ooonfX00ol0nOooo`2Cool04`04oookJP03om[o0?m4
o`3oA?l000KoA?l03?oonfX00olao`3ooo]Zo`3oF`03oookJP06oh;o0?oonf[o033ooookJ_l0j?oo
iOl00_oonfX00ol60?oooo]Zoi;o0002oookJP03oa00ool06Ooooo]Z00?ooo]Z00Ko5@3oool0DOoo
nf[o0:gooookJ_oo07U@oookJP08o`1gool0oi[oof`0oookJ_l0olcooh40oookJ_lko`02oookJP03
o`3koooonf[ooo]Z00?ooo]Z00Soo`<0oookJ_oonf[oo`3MogT0ool0Xooo/ol0oil0o`Gooo]Z00Go
o`27oookJ_oonf[ooo]Zool0K003oookJP04odd0oomQ0?oooo]Zo`3oA@?ooo]Z00CohP3ooookJ_oo
nf[o0?nB1ooonfX00omX0?oooo]ZoookJP02oookJP05oaP0ool0M?oooo]ZoookJ_ooT0002?oonfX0
1?oo_P3ooo]Zon/0ool0o`D5oookJP05oomG0?oonf[ooo]ZoookJ_oo02d01ooonfX00oooP@3ooo]Z
oookJP04oookJP05o`3Dool01?oooo]Zo`2Yool0R?l00_oonfX00ol0odko0?ldoookJP04oookJP03
o`3Qool0oago0?mC00?ooo]Z00koo`1io`2]oooo057ooo]Zo`0Iool@0?oooo]Zoi;o0?l60?oo0?m=
o`0`oon2o`3o0?mKoc7o00Kooo]Z00?o9P3ooookJ_oJo`000_oonfX01?oo09?o0?Woooo:0?l0oa/2
oookJP05ogSo0?l0g?oo?ol0oomB0?l0oc<00ooonfX00ol0Looooo]ZoookJP03oookJP0Aool0j_oo
5P3oo`3loookJ_oo1P3ojol0ojP0ool0Mooo>ol0o`3koooonf[o0:?ook?o0?oo06cooo]Zof40ool0
oi000_oonfX01_lH0?oooo]ZoookJ_oo_P3oL03ooomG00?ooo]Z00Co0=Coo`04ool0R?oo0?m>2_oo
nfX2o`3oCP0?o`3Dool01?oooo]ZoomG0?m`0?oooo]ZoaP0ool0oi;oH@3ooookJ_nco`3ooo]Zoom/
0?oo0?Koo`3l00?ooo]Z00[o07?ooookJ_oonf[ooe80o`3ogol0oa_oolX0ool04on40?oo9P3o0_oo
nfX02Ol0oe_oP_l0oi;o0?l@0?ooo`1Ao`2]oooo07Wo0?mCo`3o7@02oookJP07o`3oC_oonf[o0:Wo
o`04ool0e?oooo]Zoon10002oookJP03ool0;Ooonf[ooeL000;ooo]Z00?oj`3ooonn0?oonfX00_oo
nfX01OooT03ooo]ZoaP0oooonf[oJ03o00;ooo]Z00Wo0?nBon80oooonf[o0?m5of40oom=0?ooo`1/
oookJ_oo08L00_oonfX00onco`3o0:?oool0g@02oookJP0@o`3koooonf[o>ol0oom/0?l0Moooo`3i
oookJ_nX0?oo0:Koool0m_oonf[oo`H0oookJ_lH0?oooo]Zool0o0;ooo]Z00?ooi80oookJ_oonfX0
0_oonfX00ooo0>[ooo]ZoookJP09oookJP03o`1coooonf[ooo]Z00Oooo]Z00Wooe80oookJ_oonf[o
02[ooookJ_loo`3o0=cooookJ_mho`001_oonfX01?l0oa_o4P3ooookJ_oobP03oookJP03ool0Tooo
01?ooo]Z00Cooo]Z00Kof_l0oookJ_oonf[ooo]ZobH0oolPo`0?oookJP03oc7o0?oonf[o0?mK00?o
oo]Z00[oP_l0o`3o/Ol0<?oo0>SooookJ_l0odgooo]Zo`H0oooonf[oT_l00ooonfX00ol@0?oo01Wo
oookJP03oookJP05oaD0oooo057ooo]Zo`2]oooo07T0:OoonfX002[ooo]Z00Wo07OooookJ_l0oi[o
A?l0onGo0?oonf[ooh40oookJ_lko`000_oonfX00ol0nooooo]ZoookJP03oookJP08ool30?oUo`3o
iOl0onGo0?l0Xooooo]Zok?o0?nO0?l4oookJP05ool0Qol0omkooo]ZoookJ_oo06`00ooonfX01Om=
0?ooobh0of40oooonf[o0?m500?ooo]Z00CohP3ooookJ_oonf[o0?nB1_oonfX00omX0?oooo]Zoook
JP02oookJP03oaP0ool0M?oooo]Z00;ooo]Z00?oiOl0oookJ_oonfX01OoonfX01?oo_P3ooo]Zoook
J_o[0?l5oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oU?l0oookJ_oonfX01OoonfX00oooP@3ooo]Z
oookJP02oookJP;o0?l<00?o0=Coo`3o3?l0o``00_l0o``01?oonf[o0?m>oookJ_l0oc@4oookJP04
ooo90?l0oagooo]Zo`3oD`;ooo]Z1ooob@001OnBo`3oo`3eoomi0?l0odgo0?n`00GoogT00ooonfX0
0olPo`3o9P3ooomi0003oomi0004o`3iooooN@3oolX0o`3o6`;oogT000GoN?l0ooo90?oob@3ooe80
okWo0003oookJP03o`1coooonf[ooo]Z00;ooo]Z00Ooo`3ZoookJ_oo5P3oo`3loookJ_oo1P3ojol0
00;oobP000Ooo`00oolX0?oo003oo`00ok?o0?oo003oo`1/00Coo`0000?o603ooolX0?oo:0001?oo
b@06oomi00;o0?m>1Ooo0003o`3oCP04o`3Doooo003oo`00oomi00CoobP000Coo`00ooo90?oob@3o
/ol00ooo00000ooo0?coo`00ool00003oomi00;oobP00_oo00001?l0oa_oo`00ool00?lV0?l2ool0
0003o`3oFooob@3oolT000?oolT000Go0:goo`3oDol0oago0>7ooomi0002onGo00OoU?l02_ooN@00
1_oonf[ooi00onKo0?lH0?oooo]ZofP0o`;ooo]Z00So0?nBon80ool0odGooo]ZoiCo0?m=0?ooo`1/
ool0Q`;ooo]Z00CoW`3ook?o0?oo0=goo`<00_oonfX00ol0nooo>ol0ooo90008ooo90008ool60?lH
0?oooo]ZoookJ_oo0?cooo]ZoonB0?oo5P03oookJP03ool0j_oonf[ooo]Z00Wooo]Z00?oiOl0oook
J_oonfX01ooonfX02_nio`3ooe80oookJ_oonf[o02[ooookJ_loo`3o0=coogSo0?l0oml5oookJP04
o`2>ool0oa_ooo]Zooo:00?ooo]Z00?o0?Woool0Tooo01<01?oonfX00ooJo`3oA?l0odCo0006odCo
00cooo]Z00?o<Ol0oookJ_l0oe/00ooonfX01On2o`3ooo]Zo`0`ool0j?ooiOl000?ooo]Z00?o1P3o
oi;o0?oUo`000_oonfX00ol@0?oo01WooookJP02oookJP07oaD0oooonf[oo`1AoookJ_l0[Ooooo]Z
ool0N@1?oookJP09o`1goooonf[o0?nJoom/0?oonf[o0?o<oon10?oonf[o>ol000;ooo]Z00?o0?_o
oookJ_oonfX00ooonfX02?oo0`3ooo]ZoookJ_oo0=goN@3oo`2Soonco`3oW`3o1OoonfX01Ooo08Oo
oo]ZoookJ_oonf[oo`1/00?ooo]Z00CoC@3oof40oooonf[o0?m50ooonfX01?oR0?oooo]ZoookJ_l0
oi87oookJP07ofP0oooonf[ooo]ZoookJ_lH0?ooi_l0o`1do`02oookJP03oon@0?oonf[ooo]Z00Ko
oo]Z00Cookh0oookJ_o[0?oo0?l51OoonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00Oooo]Z00?ooh40
oookJ_oonfX01?oonfX01Ol0e?oo00CooookJ_l0ZOoo08So00;ooo]Z00?o0?m>o`3o=?oonfX01?oo
nfX00ol0hOoo0?lMo`3oD`03oookJP0>ool0NOl0[Ooo5@3oool0DOoonf[o403ooookJ_nBo`3o1P3o
o`3oCOl0<?ooP_l0o`3oFolao`06oookJP03obH0oooonf[of_l000;ooo]Z00Coo`2Co`3ioooobP3o
0?lK0_oonfX01Omho`3o0?oOocoo0?l0:_oooe8000?ooo]Z00?o07?ooookJ_oonfX00ooonfX04Ooo
0>[ooo]Zool0o?oonf[oo`H0on_o0?nX0?oo07Oooc_o0?oonf[o0?_oogT0oonco`3o0?oNool0K?m=
0?ooH@3o00?ooo]Z00Ko603ooookJ_oonf[ookh0oomG0?oo02d3oookJP?o0=Co0_l0odh5oookJP?o
0?m>00co0=Coo`04ool0003o0000oomG0?m`0?oooo]ZoaP0ool0oi;oH@3ooookJ_nco`02oookJP03
oom/0?lH0?ooo`3l00?ooo]Z00Wo07?ooookJ_ooDP3o0?oOoookJ_l0oa_ooo]Zool04olV0?l00ooo
nfX03ol0oe_o033ooi;o0?l@0?ooo`1Aool0NOoonf[o0?mCo`3o7Ooonf[o0?ldo`3oC_l0R?oo0:Wo
o`3Do`02oookJP0:oon10?oonf[ooo]Zool0;Ooonf[ooeL0oookJ_m`0?ooj`3ooonn00?ooo]Z00Go
oi00onKo0?lH0?oooo]ZofP0o`02oookJP0>o`3oT_oR0?oooo]Zo`3oAOmQ0?ooC@3oool0K?oonf[o
o`27oookJ_nO0?oo/ol0ogT0oooo0=d2oookJP0Co`3koolko`3ooh40oom/0?l0Moooo`3ioookJ_nX
0?oo0:Koool0m_oonf[oo`H0oookJ_lH0?oooo]Zool0o?oonf[ooi80oolF0003oookJP03ool0j_oo
nf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX01ooonfX02OooDP3ooo]ZoookJ_l0:_oooo]Zocoo0?l0
g?ooN?l0o`3og`06oookJP04o`3o6olB0?oooo]Zooo:00?ooo]Z00?oo`2Cool04ooonfX01?oonfX0
1_oJo`3ooo]ZoookJ_oonf[o9P3oob3o00kooo]Z00?o<Ol0oookJ_l0oe/01?oonfX01On2o`3o0?na
o`0`ool0j?oo0?m=00;ooo]Z00?o1P3ooookJ_nBo`000ooonfX00ol@0?oo01WooookJP02oookJP06
oaD0oooo057ooo]ZoookJ_l0[Oooo`1i:OoonfX002[ooo]Z00Wo07OooookJ_l0oi[oA?l0onGo0?oo
nf[ooh40oookJ_lko`000_oonfX00ol0nooooo]ZoookJP03oookJP03ool30?oUo`3oiOl000;oiOl0
00?o/ol0oil0oooonfX01?oonfX01Ooo08Oo0?oNoookJ_oonf[oo`1/00?ooo]Z00CoC@3oool^0?mQ
0?oo0?m51?oonfX01?oR0?oooo]ZoookJ_l0oi86oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603o
o`1doooonfX00_oonfX00ooUo`3ooo]ZoookJP05oookJP04oonn0?oonf[ooo]Zon/0o`Gooo]Z00?o
oeL0oookJ_oonfX00_oonfX2oiCo00Kooo]Z00?ooh40oookJ_oonfX00_oonfX2o`3o3003o`3Dool0
o`co0?l<00;o0?l<00Cooo]Zo`3oC_oonf[o0?ld1?oonfX01_oob@3o0?lMoookJ_oonf[o0?mCoook
JPOoolT000CoT_l0ool0mOooN@3o0?m=1_ooN@03oookJP03ob3o0?lV0?ooogT000GoogT000GoolX0
o`3o6oooN@3oogT0ogSo0002ooo90003oomB0?oob@3ooo]Z00;ooo]Z00?o07?ooookJ_oonfX00_oo
nfX01ooo0>[ooo]ZoolF0?ooTP3oo`3lool60?o[o`000_oo:004ool00003ok?o0?oo003oo`1/00Co
o`0000?o603oonKo0?oo00001?oob@06oomi00;oobP01Ol0odh3ool000?oolT000CoL03oooo90?oo
:03oobP00ooo00000onco`3oolT0ool00002ool00003ool0o?oo003oo`0000?oogT00ooo:0001?l0
oa_oo`00ool00?lV0?l6ool000;oolT000Coo`1ioookJ_l0oe?o0?lM0_ooN@000ooUo`3oU?l0oiCo
0005oiCo00[oogT00_oonfX01?ooT03o603ooookJ_mX0?l3oookJP08o`3oT_oR0?oo0?m5oookJ_mQ
0?ooC@3oool0K?oo08L2oookJP04ok?o0?oo0=gooo]Zool300;ooo]Z00?o0?_ooc_o0?oob@002?oo
b@001?oo1P3o603ooookJ_oo0?`2oookJP03oonB0?oonf[ooo]Z00;ooo]Z00?oo`3ZoookJ_oonfX0
2OoonfX00ooUo`3ooo]ZoookJP06oookJP03okWo0?oonf[ooe8000;ooo]Z00Ko02[ooookJ_loo`3o
0=coogSo0?l0oml5oookJP04o`3o6olB0?oooo]Zooo:00?ooo]Z00?o0?Woool0TooonfX01?oonfX0
0ooJo`3ohOl0odCo0005odCo00gooo]Z00?o<Ol0oookJ_l0oe/00ooonfX01On2o`3ooo]Zo`0`ool0
j?ooiOl000;ooo]Z00Co1P3ooookJ_nBo`3oo`3e0_oonfX00ol@0?ooiOl0oookJP02oookJP07oaD0
oooonf[oo`1AoookJ_l0[Ooooo]Zool0N@1?oookJP09o`1goooonf[o0?nJoom/0?oonf[o0?o<oon1
0?oonf[o>ol000;ooo]Z00?o0?_ooookJ_oonfX00ooonfX02?oo0`3ooo]ZoookJ_oo0=goN@3oo`2S
oonco`3oW`3o1OoonfX01Ooo08Oooo]ZoookJ_oonf[oo`1/00?ooo]Z00?oC@3oof40ool0odD01?oo
nfX01?oR0?oooo]ZoookJ_l0oi87oookJP07ofP0oooonf[ooo]ZoookJ_lH0?ooi_l0o`1do`02oook
JP03oon@0?oonf[ooo]Z00Kooo]Z00Cookh0oookJ_o[0?oo0?l51OoonfX01OooE`3ooo]ZoookJ_oo
nf[oo`0]00Oooo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0e?oo00CooookJ_l0ZOoo08So00;ooo]Z
00?o0?m>o`3o=?oonfX01?oonfX01?l0hOoo0?lMoookJ_l0oe<2oookJP0>ool0NOl0[Ooooo]Zool0
DOoonf[o403ooookJ_nBo`3o1P3oo`3oCOl0<?ooP_l0o`3oFolao`06oookJP03obH0oooonf[of_l0
00;ooo]Z00Coo`2Co`3ioooobP3o0?lK0_oonfX01Omho`3o0?oOocoo0?l0:_oooe8000Cooo]Z00?o
07?ooookJ_oonfX00_oonfX04_oo0>[ooo]ZoonB0?oo0?coo`H0on_o0?l0Y_ooo`3io`1goolko`3o
0?_ooookJ_nco`3oW`3oool0K?m=0?ooH@3oo`3oTP;ooo]Z00Oo603ooookJ_oonf[ookh0og00oooo
E`3oo`0]00Gooo]Z0_l0e?l5o`3oCP03oookJ_l0e?oo0=Co00;o00000_ooE`001om`0?oo07CooaP0
ool0oi;oH@3ooookJ_nco`000_oonfX01?ooK03oo`3foaP0oooo0?`3oookJP09o`1coooonf[ooe80
o`3ogol0oa_oolX0ool04ooQo`3o9P3o00?ooo]Z00So0?mKoookJ_nBo`3ooo]Zool0DOoo07Wo0?mC
o`3o7@;ooo]Z00Go0?ldo`3oC_l0ZOoo00Coo`3Do`02oookJP0:oon10?oonf[ooo]Zool0;Ooonf[o
oeL0oookJ_m`0?ooj`3ooonn00?ooo]Z00Cooi00oaP0oooonf[oJ03o0ooonfX03_l0oi;ohP3ooook
J_l0odGoH@3oodd0oooo06coo`27o`3og_oonf[o/ol0o`2Soooo0=goo`<00_oonfX03ol0nooo>ol0
oon10?ooK03o07Ooool0nOoonf[oZ03oo`2Voooo0?Kojol0ool60?oonf[o603oool0o002oookJP03
oonB0?oo5P3ooo]Z00;ooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ol0Looooo]ZoookJP07oookJP0:
okWo0?ooDP3ooo]ZoookJ_l0:_oooo]Zocoo0?l0g?ooN?l0o`3og`Kooo]Z00?o0?lKoa80oooobP00
1?oonfX00ooo09?oo`0CoookJP04oookJP06om[o0?oonf[ooo]ZoookJ_lV0?oo8?l03_oonfX00ola
o`3ooo]Zo`3oF`03oookJP06o`3o/?n2o`3o033ooookJ_l0j?oo0?m=0_oonfX00ol60?oooo]Zoi;o
0002oookJP03oa00ool06Ooooo]Z00?ooo]Z00Ko5@3oool0DOoonf[ooo]Zo`2]oooo07TYoookJP00
:_oonfX02Ol0Mooooo]Zo`3oV_m4o`3oiOl0oookJ_ooP@3ooo]Zoc_o0002oookJP03o`3koooonf[o
oo]Z00?ooo]Z00?oo`<0onGo0?oUo`000_oUo`000onco`3oW`3ooookJP04oookJP05ool0Qol0omko
oo]ZoookJ_oo06`00ooonfX01?m=0?ooobh0of40ool0odD3oookJP05on80ool0oi3ooo]ZoookJ_l0
oi801_oonfX00omX0?oooo]ZoookJP02oookJP05oaP0ool0M?oooo]ZoookJ_oUo`002?oonfX01?oo
_P3ooo]Zo`3o1Oo[0?l5oookJP04oomG0?oonf[ooo]ZoookJP?oU?l01_oonfX01?ooP@3ooo]Zoook
J_oonfX3o`3o3003o`3Dool0o`co0?l<00?o0?l<00?o0?m>oookJ_l0oc@01?oonfX01_oob@3o0?lM
o`3o2?oonf[o0?mCoookJPOoolT000CoT_l0oomi0?ooN@3o0?m=1_ooN@03oookJP03ob3o0?lV0?oo
ogT000GoogT000CoolX0o`3o6oooN@3oogT00ooob@000oooDP3oolT0oookJP02oookJP03o`1coooo
nf[ooo]Z00;ooo]Z00Ooo`3ZoookJ_oo5P3ooi80ool0o?lH0?ooo`H000;oobP01?oo00001?nco`3o
o`00ool00?oo06`4ool00003onKo0?oo003oolT000?oolT01oooN@000ooUo`3oo`00ool00007ool0
0003ooo90?m`0?ooolT000;oolT00ooo00000onco`3oolT0ooo90002ool00004ool0o?oo003oo`00
ool000;oogT01_oo:0000ooo003o9P3oool00007ool00004ool0NOoo003o0?mCo`3Qo`;oogT000?o
0?m>oiCo0?nDo`001?nDo`03oomi0003oookJ_ooN@3oogT000GoogT00_oonfX01?ooT03o603ooook
J_mX0?l2oookJP09o`3oT_l0oi3ohP3oo`3oAOoonf[oH@3ooookJ_oo06coo`2700;ooo]Z00So/ol0
ool0gOoonf[oo`<0oookJ_l0nooooo]Zoc_o00WoolT000Coo`H0oaP0oooonf[oo`3l0_oonfX00ooo
TP3ooo]ZoookJP02oookJP03ool0j_oonf[ooo]Z00Wooo]Z00?oiOl0oookJ_oonfX01_oonfX00oni
o`3ooo]ZoomB0002oookJP06o`0Zooloo`3ooo]Zo`3Loomho`3o?@3o1OoonfX01?l0oa_o4P3ooook
J_oobP03oookJP03o`3ioooo09?ooo]Z00Cooo]Z00?of_l0on7o0?m4o`001Om4o`0=oookJP03oc7o
0?oonf[o0?mK00?ooo]Z00GoP_l0oookJ_l0<?oo0>SoonGo0002oookJP04o`H0oooonf[oT_l0ool0
m@;ooo]Z00?o403oonGo0?oonfX00_oonfX01olE0?oooo]Zool0DOoonf[o0:gooookJ_oo07T0Cooo
nfX02Ol0Mooooo]Zo`3oV_ooK03ooo]Zo`3oc?ooP@3ooo]Zoc_o0002oookJP03o`3koooonf[ooo]Z
00?ooo]Z00Soo`<0oookJ_oonf[oo`3MogT0oonco`3o01Oooil0o`Gooo]Z00Goo`27oookJ_oonf[o
oo]Zool0K003oookJP03odd0oooonf[oH@3o00Cooo]Z00CohP3ooookJ_oonf[o0?nB1ooonfX01_mX
0?oooo]ZoookJ_oonf[o603oonKo00?ooo]Z00?ooi00oookJ_oonfX01_oonfX00ooo_P3ooo]Zon/0
o`06oookJP05oomG0?oonf[ooo]ZoookJ_oo02d01ooonfX00oooP@3ooo]ZoookJP04oookJP05o`3D
ool01?oooo]Zo`2Yool0R?l00_oonfX00ol0odko0?ldoookJP04oookJP04o`3Qool0oago0?l8o`3o
D`;ooo]Z00koo`1io`2]oooonf[oo`1AoookJ_l@0?ooo`1Zoi;o0?l60?oo0?m=o`0`oon2o`3o0?mK
oc7o00Kooo]Z013o9P3ooookJ_oQo`3of_l0oookJ_oo01?oo`2Cooo:0?l0oa_o08kooookJ_mho`3o
0?oOocoo0?l0:_oooe801?oonfX00ol0Looooo]ZoookJP02oookJP0Eool0j_oonf[ooi80ool0o?oo
nf[oo`H0o`2VoonX0?oo07Oooc_o0?l0nooooo]Zok?o0?nO0?oo0?oNool0K?mQ0?oooo]Zo`3oT_oo
nf[o603o00?ooo]Z00Cookh0og00ooooE`3oo`0]1ooonfX5o`3Do`;ooo]Z0_ooE`003_l0003oL03o
o`1doolH0?oooo]Zo`3oT_mQ0?oo0?oNok?o0?oonf[oof`0ool0m_lH0?ooo`3l0ooonfX02_l0Looo
oo]Zo`0ZooooDP3o0?oOo`3o6ooobP3oo`0Coh@0oolV0?l2oookJP09o`3oFon2o`3oT_l0oa00oooo
nf[oo`1Aool0NOl0oe?o0?lM00;ooo]Z00Oo0?ldo`3oC_l0ZOoo00Coo`3Doooonf[ooh4000;ooo]Z
00Ooo`0]oookJ_oonf[ooeL0oookJ_o[0?oookh000Cooo]Z00Cooi00oaP0oooonf[oJ03o0_oonfX0
2Ol0oi;o0?n@on80oooonf[o0?m5of40oom=0?ooo`1/ool0Q`02oookJP0Eok?o0?l0Xoooo`3Mool3
0?oonf[o0?_ooookJ_lko`3ooh40oom/0?l0Moooo`3iojP0oooonf[o0:Koool0m_o[o`3oo`H0oook
J_lH0?ooo`3l00;ooo]Z00?ooi80oookJ_oonfX00_oonfX00ooo0>[ooo]ZoookJP09oookJP03o`1c
oooonf[ooo]Z00Oooo]Z00[o^Ol0oomB0?oonf[ooo]Zo`0Zooloo`3ooo]Zo`3Loomho`3o?@3o1_oo
nfX00ol0oa_ooo]Zooo:0003oookJP03o`3ioooo09?oo`0C00Gooo]Z00Kof_l0oookJ_oonf[ooo]Z
obH0oolPo`0>oookJP03oc7o0?oonf[o0?mK00?ooo]Z00So0?n`oh;o0?l0<?oooo]Zo`3Xool0odgo
oo]Zo`H0o`;ooo]Z00GoT_l0oookJ_oonf[o403oo`0Io`04oookJP06oaD0oooo057ooo]ZoookJ_l0
[Oooo`1i:OoonfX002[ooo]Z00Wo07OooookJ_l0oi[oA?l0onGo0?oonf[ooh40oookJ_lko`000_oo
nfX00ol0nooooo]ZoookJP03oookJP03ool30?oUo`3oiOl000;oiOl000?o/ol0oil0oooonfX01?oo
nfX01Ooo08Oo0?oNoookJ_oonf[oo`1/00?ooo]Z00CoC@3oool^0?mQ0?oo0?m50ooonfX01OoR0?oo
0?n@oookJ_oonf[o0?nB00Kooo]Z00?oJ03ooookJ_oonfX00_oonfX01OlH0?oo07CooookJ_oonf[o
iOl000Sooo]Z00Cookh0oookJ_l0o`Goj`3o1OoonfX01?ooE`3ooo]ZoookJ_oonfX3oiCo00Kooo]Z
00Cooh40oookJ_oonf[ooo]Z0ol0o``00ol0e?oo0?l<o`3o3003o`3o3003o`3oC_oonf[o0?ld00Co
oo]Z00Go0>7oo`3o7Ol0o`Sooo]Zo`3oD`02oookJP07onGo0?ooN@3oogT0ooo90?ooN@3o403ooi;o
0002oomi0003o`3oCOooN@3oogT000GoogT00ooonfX00oooN@3o9P3ooomi0004oomi0004ooo:0?l0
oa_oogT0oomi00CoolT000Gooe80ooo90?oonf[ooo]Zo`1co`04oookJP07ool0j_oonf[ooo]ZoonB
0?oo0?co603oool60002oolX00Goo`0000?o/ol0ool00?oo06`01?oo00000olH0?ooo`00ooo90003
ooo900OoogT00_oUo`09ool000?oolT00ooo00000onco`3oo`00ool00002ooo90003ool0o?oo003o
o`0000;oo`000_ooN@07oolX0003obH0oooo003oo`0000Soo`0000Co0?mCo`3QooooN@3o0?m>1onD
o`03oomi0003oookJ_ooE`3oogT000CoogT00_oonfX01OooT03oi_l0oaP0oooonf[oJ03o00;ooo]Z
00Wo0?nBon80oooonf[o0?m5of40oom=0?oooo]Zool0K?oo08L00_oonfX02?nco`3oo`3MoookJ_oo
0`3ooo]Zo`3koooonf[o>ol02Ooob@001?oo1P3o603ooookJ_oo0?`2oookJP05oonB0?oonf[ooo]Z
oookJ_oo0>X03?oonfX00ooUo`3ooo]ZoookJP06oookJP0;okWo0?ooDP3o0?lcoookJ_l0:_oooo]Z
ocoo0?oonf[o0=coogSo0?lm0?l01OoonfX01?l0oa_o4P3ooookJ_oobP03oookJP03o`3ioooo09?o
oo]Z00?ooo]Z00?of_l0on7o0?oonfX01_m4o`0=oookJP03oc7o0?l0oe_ooo]Z00;ooo]Z00Ko0?n`
oh;o0?l0ok7o033oo`3XoooUo`02oookJP03o`H0oooonf[oT_l000?ooo]Z00?o403oo`1MoooonfX0
0_oonfX01olE0?oooo]Zool0DOoonf[o0:gooookJ_oo07T0CooonfX02Ol0Mooooo]Zo`3oV_ooK03o
oo]Zo`3oc?ooP@3ooo]Zoc_o0002oookJP03o`3koooonf[ooo]Z00?ooo]Z00Soo`<0oookJ_oonf[o
o`3MogT0oonco`3o01Oooil0o`Gooo]Z00Goo`27oookJ_oonf[ooo]Zool0K002oookJP04odd0oooo
;P3ooo]Zof40o`?ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP07oookJP06ofP0oooonf[ooo]Zoook
J_lH0?ooi_l00ooonfX00oooT03ooo]ZoookJP06oookJP03oonn0?oonf[oj`3o00Kooo]Z00GooeL0
oookJ_oonf[ooo]Zool0;@08oookJP03oon10?oonf[ooo]Z00?ooo]Z00Go0=Coo`04oooonf[o0:Wo
o`28o`02oookJP03o`3oC_l0ocCooo]Z00Cooo]Z00Co0>7oo`3o7Ol0o`So0?mC0_oonfX03ooo07Wo
0:gooookJ_oo057ooo]Zoa00oooo06[oT_l0o`H0ool0odgo0>Sooh;o0?oonf[o0?mKoc7o0005oook
JP0@ob3o0?lV0?oohOl0om[o0?oonf[oo`0Cool0TooobP3o0?lKo`2>oooonf[oN?l0o`3ogoloo`3o
02[ooomB00Cooo]Z00?o07?ooookJ_oonfX00_oonfX04ooo0>[ooo]ZoonB0?oo0?cooo]Zool60?oo
0?KoZ03oo`1gooooK03o>ol0o`3koomi0?oo/ol0o`3og_oo06coC@3oof40ool0oi800_oonfX00olH
0?ooi_l0oookJP02oookJP03og00ooooE`3ooeL000;oo`0]2OoonfX2oomG00;o000000goL03oonKo
0?lH0?oooo]Zo`3oT_mQ0?oo0?oNok?o0?oonf[oof`0ool0m_oonf[oo`3l00Cooo]Z00Wo07?ooook
J_ooDP3o0?oOoookJ_l0oa_oo`2Con7o0?lV0?l00ooonfX03ol0oe_o0?m=oi;o0?l@0?ooo`1Aool0
NOoonf[o0?mCo`3o7Ooonf[o0?ldo`3oC_l0R?oo0:Woo`3Do`02oookJP06oon10?oonf[ooo]Zool0
;Ooonf[ooeL00_oonfX00oo[0?oookh0oookJP02oookJP05oon@0?oonf[o603ooookJ_mX0?l00_oo
nfX02Ol0oi;ohP3ooookJ_l0odGoH@3oodd0oooonf[oo`1/ool0Q`02oookJP0Eok?o0?l0Xoooo`3M
ool30?oonf[o0?_ooookJ_lko`3ooh40oom/0?l0Moooo`3iojP0ool0Y_oooo]Zool0m_o[o`3oo`H0
oookJ_lH0?ooo`3l00;ooo]Z00?ooi80oookJ_oonfX00_oonfX00ooo0>[ooo]ZoookJP09oookJP03
o`1coooonf[ooo]Z00Oooo]Z00[ooe80o`3o<ooonf[o02[ooookJ_loo`3ooo]Zo`3Loomho`3o?@3o
1_oonfX00ol0oa_ooo]Zooo:0003oookJP03o`3ioooo09?oo`0C00Cooo]Z00?of_l0oookJ_oonfX0
0_oonfX00olV0?oo8?l0oookJP0=oookJP03oc7o0?oonf[o0?mK00?ooo]Z00_o0?n`oh;o0?l0<?oo
oo]Zo`3Xool0odgooo]Zo`H0oooonf[oo`3eoi;o0002oookJP03oa00ool06Ooooo]Z00?ooo]Z00Ko
5@3oool0DOoonf[ooo]Zo`2]oooo07TYoookJP00:_oonfX01?l0Mooooo]Zo`3oV_m4o`02oookJP03
oon10?oonf[o>ol000;ooo]Z00?o0?_ooookJ_oonfX00ooonfX5onGo0003ok?o0?nO0?oooo]Z00Co
oo]Z00Goo`27omgo0?oonf[ooo]Zool0K003oookJP04odd0oooo;P3oH@3oo`3oA@?ooo]Z00GohP3o
o`3oT?oonf[ooo]Zo`3oTP06oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603oo`1doooonf[ooo]Z
onGo0008oookJP04oonn0?oonf[o0?l5on/0o`Gooo]Z00CooeL0oookJ_oonf[ooo]Z1?nDo`05oook
JP03oon10?oonf[ooo]Z00Cooo]Z00Wo0=CooookJ_l0o`cooo]Zo`28oooonf[o0?m>oookJ_l0oc@0
1?oonfX01Ol0hOoo0?lMo`3o2?oonf[o0?mC00;ooo]Z00OoiOl0oomi0?ooN@3oolT0oomi0?l@0?oo
T_l000;oogT000?o0?m=oomi0?ooN@001OooN@02oookJP;oogT000?o9P3ooomi0?ooN@000oooN@00
1?oobP3o0?lKoomi0?ooN@04ooo90005oomB0?oob@3ooo]ZoookJ_ooN@001OoonfX01_oo0>[ooo]Z
oolF0?ooTP3oo`3lool600;oobP01Ooo00000onco`3oo`00ool0K005ool00003oaP0oooo003oo`00
00;oo`002?ooN@000ooUo`3oo`00ool00005ool00004og00oooob@3oolT0ooo900Coo`0000Ko/ol0
ool00?oo003oo`00oaP0oooo0?`3ool000?oogT02?oo:009ool00005o`3oDol0oagoogT0oomi0?l0
odh01_nDo`03oomi0003ool0;Ooonf[ooeL000CoogT00ooonfX01?ooT03oi_l0oaP0oomX0?l3oook
JP08o`3oT_oR0?oooo]Zo`3oAOmQ0?ooC@3oool0K?oo08L2oookJP04ok?o0?l0Xoooo`3Mool300;o
oo]Z00?o0?_ooookJ_lko`002?oob@002?oo1P3o603ooookJ_oonf[oo`3loookJ_ooTP3ooaH00ooo
nfX00ooo0>[ooo]ZoookJP06oookJPGoiOl02?oonfX02onio`3ooe80oookJ_oonf[o02[ooookJ_lo
o`3o0=cooookJ_mho`3o?@3o00Gooo]Z00Co0?lKoa80oooonf[oolX00_oonfX00ol0nOooo`2Cool0
4`04oookJP03om[o0?oQo`3ooo]Z00GoA?l03OoonfX00olao`3ooo]Zo`3oF`03oookJP06oh;o0?oo
nf[o033ooookJ_l0j?ooiOl00_oonfX00ol60?oooo]Zoi;o0002oookJP03oa00ool06Ooo05go00?o
oo]Z00Oo5@3oool0DOoonf[ooo]Zo`2]oooonf[oo`1i04oooo]Z00Wo07OooookJ_l0oi[oof`0o`3o
c?oonf[ooh40oookJ_lko`000_oonfX00ol0nooooo]ZoookJP03oookJP08ool30?oonf[ooo]Zool0
gOoonf[o/ol0o`0GoonO0?l5oookJP05ool0Qooonf[ooo]ZoookJ_oo06`00_oonfX01?m=0?ooobh0
oookJ_mQ0?l3oookJP05on80ool0oi3ooo]ZoookJ_l0oi801ooonfX01_mX0?oooo]ZoookJ_oonf[o
603oonKo00?ooo]Z00?ooi00oookJ_oonfX01_oonfX00ooo_P3ooo]Zon/0o`06oookJP05oomG0?oo
nf[ooo]ZoookJ_oo02d02?oonfX00oooP@3ooo]ZoookJP03oookJP05o`3Doooonf[o00Coo`2Yool0
R?l00_oonfX00ol0odko0?ldoookJP04oookJP04o`3Qool0oago0?l8o`3oD`;ooo]Z00ooo`1io`2]
oooonf[oo`1AoookJ_l@0?ooo`1Zoi;o0?l60?oo0?m=o`3Xoon2o`3ooo]Zo`3oFolao`001OoonfX0
4?n40?oo9P3ooookJ_oJo`3ooo]Zool04ooo09?oolX0oookJ_l0oa_ooo]ZogSo0?l0omoo?ol0o`0Z
ooooDP04oookJP03o`1coooonf[ooo]Z00?ooo]Z01?oo`3ZoolF0?ooTP3oo`3lool60?o[o`3oZ03o
ool0nOl0Mooo>ol0o`3koooonf[o/ol0oil0oooo06cooo]Zof40oooonf[o0?nB00;ooo]Z00?o603o
onKo0?oonfX00_oonfX2og00o`03oomG0?oonf[oo`0]00Ooo`0]00?ooeL0oookJ_m`0?l00_m`0?l0
3OoVo`3o603ooookJ_l0oi;oH@3oo`3og_l0Xooo/ol0oom/0?oonf[oo`3foaP0oooo0?`00ooonfX0
2_l0Looooo]Zo`0ZooooDP3o0?oOo`3o6ooobP3oo`2Con7o0?lV0?l2oookJP09o`3oFon2o`3o0?m=
oi;o0?oo06[oo`1Aool0NOl0oe?o0?lM00;ooo]Z00Go0?ldo`3oC_l0ZOoo00Coo`3Do`02oookJP0:
oon10?oonf[ooo]Zool0;Ooonf[ooeL0oookJ_m`0?ooj`3ooonn00?ooo]Z00Cooi00onKo0?lH0?oo
J03o0ooonfX02Ol0oi;ohP3ooookJ_l0odGoH@3oodd0oooo06cooo]Zool0Q`02oookJP03ok?o0?oo
0=goN@3o00;ooo]Z01?o0?_ooookJ_lko`3ooh40oookJ_l0Mooooo]ZojP0ool0Y_ooo`3foookJ_oo
1P3ooo]ZoaP0oooonf[oo`3loookJ_ooTP3ooaH000Cooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ol0
Looooo]ZoookJP07oookJP0:oomB0?oonf[ooo]Zo`0Zoooonf[o?ol0o`3Loooonf[oN?l0ocd0o`Go
oo]Z00Co08koo`3o6ooonf[oolX00ooonfX00ooo09?ooo]Zool04`04oookJP03om[o0?oonf[ooo]Z
00;ooo]Z00?o9P3ooookJ_oonfX03OoonfX00olao`3ooo]Zo`3oF`03oookJP0;oh;o0?l0ok7o033o
o`3Xoooonf[o0?m=oookJ_l60?oooo]Zool0mOnBo`000_oonfX00ol@0?oo01WooookJP03oookJP06
oaD0oooo057ooo]ZoookJ_l0[Oooo`1i:OoonfX002[ooo]Z00Co07OooookJ_l0oi[oA?l00_oonfX0
0oooP@3o>ol0oookJP02oookJP03o`3koooonf[ooo]Z00?ooo]Z1OoUo`000onco`3oW`3ooookJP04
oookJP05ool0QooMo`3ooo]ZoookJ_oo06`00ooonfX01?m=0?ooobh0of40ool0odD3oookJP03on80
oooonf[o0?n@00;ooo]Z00?o0?nBoookJ_oonfX00ooonfX00omX0?oooo]ZoookJP02oookJP05oaP0
oooVo`3ooo]ZoookJ_oUo`002?oonfX01Ooo_P3ooo]Zo`3o1Om`0?ooj`3o00Cooo]Z00CooeL0oook
J_oonf[ooo]Z1?nDo`05oookJP03oon10?oonf[ooo]Z00Cooo]Z00Wo0=CooookJ_l0o`co0:Woo`28
oooonf[o0?l^o`3oC_l0oc@01?oonfX01Ol0hOoo0?lMo`3o2?oonf[o0?mC00;ooo]Z00OoiOl0oomi
0?ooN@3oolT0oomi0?l@0?ooT_l000;oogT000?o0?m=oomi0?ooN@001OooN@02oookJP;oogT000?o
9P3ooomi0?ooN@000oooN@001?oobP3o0?lKoomi0?ooN@04ooo90005oomB0?oob@3oolT0oookJ_oo
N@001OoonfX02?oo0>[ooo]ZoolF0?ooTP3oo`3loolX0?oo1P3oobP01_oo00000onco`3oo`00ool0
K004ool00003oomi0?lH0?oo603o00;oo`001OooN@000ooob@3oiOl0ool00007ool000CoolT01?oo
00000onco`3oo`00ool00002ool00003ool0o?oo003oo`0000;oo`000_ooN@08oolX00[oo`0000Go
0?mCo`3o7OooN@3oogT0o`3oCP05oiCo00CoogT000?oo`0]oookJ_ooE`001?ooN@03oookJP04oon@
0?lH0?oooo]ZofP0o`?ooo]Z00So0?nBon80ool0odGooo]Zof40oom=0?ooo`1/ool0Q`;ooo]Z00Ko
/ol0ool0gOoonf[oo`<0oookJ_l0nol2oookJP03oc_o0?oob@3oolT000KoolT000Soo`H0oaP0oooo
nf[ooo]Zool0o?oonf[ooi80oolF00?ooo]Z00?oo`3ZoookJ_oonfX01_oonfX8onGo00Gooo]Z00[o
^Ol0oomB0?oonf[ooo]Zo`0Zoooonf[o?ol0o`3Loomho`3o0?oO1_oonfX00ol0oa_o4P3oooo:0003
oookJP03o`3ioooo09?oo`0C00Cooo]Z00?of_l0on7o0?oonfX01Om4o`0=oookJP03oc7o0?oonf[o
0?mK00?ooo]Z00GoP_l0oookJ_l0<?oooo]ZonGo0003oookJP03o`H0oooonf[oT_l000;ooo]Z00?o
403oo`0IoooonfX00ooonfX01olE0?ooo`1AoookJ_oonf[o0:gooookJ_oo07T0CooonfX02?l0Mooo
oo]Zo`3oV_ooK03o0?o<oookJ_ooP@3o>ol01?oonfX00ol0nooooo]ZoookJP02oookJP08ool30?oo
nf[ooo]Zool0gOoonf[o/ol0o`0GoonO0?l5oookJP05ool0Qooonf[ooo]ZoookJ_oo06`00_oonfX0
1?m=0?ooobh0oookJ_mQ0?l3oookJP03on80oooonf[o0?n@00;ooo]Z00?o0?nBoookJ_oonfX01?oo
nfX01_mX0?oooo]ZoookJ_oonf[o603oonKo00?ooo]Z00?ooi00oookJ_oonfX01_oonfX01?oo_P3o
oo]Zog00ooo[0?l5oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01OoonfX00ooo
P@3ooo]ZoookJP03oookJP05o`3Doooonf[o00Coo`2Yool0R?l00_oonfX00ol0odko0?ldoookJP04
oookJP04o`3Qool0oago0?l8o`3oD`;ooo]Z00ooo`1io`2]oooonf[oo`1AoookJ_l@0?ooo`1Zoi;o
0?l60?oo0?m=o`3Xoon2o`3ooo]Zo`3oFolao`001OoonfX04On40?oo9P3ooookJ_oJo`3ooo]Zool0
4ooo09?oolX0oookJ_l0oa_ooo]ZogSo0?l0omoo?ol0oookJ_ooDP3o^Ol000?ooo]Z00?o07?ooook
J_oonfX00ooonfX04Ooo0>[ooo]ZoonB0?oo0?cooo]Zool60?l0Y_ooZ03oo`1goolko`3ooo]Zo`3k
oomi0?oo/ol0omgo0?oo06coH@3o00;ooo]Z00?o0?nBoookJ_oonfX00_lH0?l4oookJP;oL03o1_oo
E`04og00o`04oookJ_l0M?oo603ooaP0o`;o0?nB00WoH@3oo`3og_l0Xooo/ol0oom/0?oonf[oo`3f
oaP0oooo0?`00ooonfX02ol0Looooo]ZoookJ_ooDP3o0=coo`3ogol0oa_oo`2Cool04on40?oo9P3o
00;ooo]Z00Wo0?mKo`3oCOnBo`3o403ooookJ_oo057ooo]Zo`3oDol0oad00_oonfX01ol0ocCo0?m>
o`2Yool01?oo0=CooookJ_ooP@000ooonfX01ooo02gooo]ZoomG0?oonf[oL03oon/0oooo_P000ooo
nfX01?ooT03o603ooookJ_mX0?l3oookJP09o`3oT_oR0?oooo]Zo`3oAOmQ0?ooC@3oool0K?oo08Oo
0?oN00;ooo]Z00Go/ol0ool0gOoo0`3ooo]Zo`3ko`02oookJP0Aoc_o0?ooK03ooo]Zo`1goooonf[o
Z03oo`2Voooo0?Kooo]Zool60?oonf[o603ooookJ_oo0?cooo]ZoonB0?oo5P001?oonfX00ooo0>[o
oo]ZoookJP09oookJP03o`1coooonf[ooo]Z00Oooo]Z00Wooe80oookJ_oonf[o02[ooookJ_loo`3o
0=coogSo0?l0oml01_oonfX01?l0oa_o4P3ooookJ_oobP03oookJP03ool0Tooo01?ooo]Z00Cooo]Z
00?of_l0oookJ_oonfX00_oonfX00olV0?oooo]ZoookJP0=oookJP03oc7o0?oonf[o0?mK00?ooo]Z
00GoP_l0o`3o/Ol0<?oo0>Soo`3oC@02oookJP04o`H0oooonf[oo`3eoi;o00;ooo]Z00?o403oo`0I
oooonfX00ooonfX01_oo057ooo]ZoookJ_oonf[o0:goool0NBWooo]Z000ZoookJP04o`1goooonf[o
0?nJodCo00;ooo]Z00?ooh40oc_o0?oonfX00_oonfX00ol0nooooo]ZoookJP03oookJPGoiOl000?o
/ol0oil0oooonfX01?oonfX01Ooo08OogOl0oookJ_oonf[oo`1/00?ooo]Z00CoC@3oool^0?mQ0?oo
0?m50ooonfX00ooR0?oooo]Zo`3oT002oookJP03o`3oT_oonf[ooo]Z00?ooo]Z00?oJ03ooookJ_oo
nfX00_oonfX01OlH0?ooi_l0oookJ_oonf[oiOl000Sooo]Z00Gookh0oookJ_l0o`GoL03oon/0o`05
oookJP03oomG0?oonf[ooo]Z00CoU?l01OoonfX00oooP@3ooo]ZoookJP04oookJP09o`3Doooonf[o
0?l<o`2Yool0R?oooo]Zo`3o;_l0odko0?ld00Gooo]Z00Go0?lMo`3o2?oonf[o0?mCoookJP02onGo
00;oogT000CoolT0oomi0?ooN@3oT_l00_ooN@000ol0odgoogT0oomi0006oomi0004oookJ_ooN@3o
ogT0obH0o`KoogT000?o0?lKoomi0?ooN@001?oob@001?ooDP3oolT0ooo90?oonfX2oomi00Cooo]Z
00Soo`3ZoookJ_oonf[ooi80ool0o?oo:03oo`H0oolX00Koo`0000?o/ol0ool00?oo06`01Ooo0000
1?ooN@3oo`00oaP0oooo0002oomi0003ool00?oob@3oolT000?oolT00_m`0?l4ool00003oomi0?oo
b@3oolT000;oolT00ooo00000onco`3oo`00ool00008ool00003oomi0?ooDP3oobP000KoobP02ooo
00001?l0oe?o0>7ooomi0?l0odh6oiCo00?oogT000Cooo]Zool0;OooE`3ooo]Z0oooN@03oookJP05
oon@0?oVo`3o603ooookJ_mX0?l00_oonfX02Ol0oi;o0?n@on80ool0odGoH@3oool^0?m=0?ooo`1/
ool0Q`02oookJP06ok?o0?oo0=gooo]Zool30?oonf[o0?_o0_oonfX00olko`3oolT0ooo90005ooo9
0003on_o0?oo1P3o603o00;ooo]Z00?oo`3loookJ_ooTP001?oonfX00ooo0>[ooo]ZoookJP06oook
JPSoiOl01OoonfX02_nio`3ooe80oookJ_oonf[o02[ooookJ_loo`3o0=coogSo0?l0oml6oookJP03
o`3o6olB0?ooolX000?ooo]Z00?o0?Woool0Tooo01<01?oonfX00ooJo`3ohOl0oookJP04odCo00ko
oo]Z00?o<Ol0oookJ_l0oe/00ooonfX01On2o`3ooo]Zo`0`oooonf[oiOl000;ooo]Z00Co1P3ooook
J_oonf[oT_l00_oonfX00ol@0?oo01WooookJP03oookJP06oaD0oooo057ooo]ZoookJ_l0[Oooo`1i
D?oonfX02?l0Mooooo]Zo`3oV_ooK03o0?o<oookJ_ooP@3o>ol01?oonfX00ol0nooooo]ZoookJP02
oookJP08ool30?oonf[ooo]Zool0gOoonf[o/ol0o`0GoonO0?l4oookJP03o`3og_oo08Oooo]Z00;o
oo]Z00Ooo`1/oookJ_oonf[oC@3oool^0?oonf[oH@3o00?ooo]Z00?ohP3ooookJ_l0oi000_oonfX0
0ol0oi;ooo]ZoookJP04oookJP07ofP0oooonf[ooo]ZoookJ_lH0?oo07CoonKo0002oookJP03oon@
0?oonf[ooo]Z00Kooo]Z00Cookh0oookJ_l0o`Goj`3o1OoonfX00oooE`3ooo]ZoookJP02oookJP03
ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX00ooonfX01Ol0e?oooo]Zo`04oooonf[o0:Wo
00;ooo]Z00?o0?l^o`3oC_oonfX01?oonfX01?l0hOoo0?lMo`3o2?l0oe<3oookJP0>ool0NOoonf[o
o`1AoookJ_l06Ooo403ooi;o0?l60?oo0?m=o`3Xoon2o`3ooo]Zo`3oFolao`05oookJP0:oh@0oolV
0?oooo]Zom[o0?oonf[oo`0Cool0Tooonf[oolX0o`3o6`;ooo]Z00GoN?l0o`3Loooonf[ooe80okWo
0003oookJP03o`1coooonf[ooo]Z00?ooo]Z01;oo`3ZoookJ_ooTP3oo`3loookJ_oo1P3ojol0ojP0
ool0Moooof`0oc_o0?l0nooooo]Zo`2Soonco`3o0?oNool0K?mQ0?l2oookJP06o`3oT_oonf[ooo]Z
oookJ_lH0?ooi_l01?oonfX6og00o`Cooo]Z0_lH0?l2o`3oTP0:o`000?mQ0?oo0?oNo`2Soonco`3o
of`0oookJ_oo0?Ko603oool0o0?ooo]Z00_o07?ooookJ_oonf[ooe80o`3Lool0omoo0?lKooo:0?oo
09?ohOl0obH0o`02oookJP0:o`3oFon2o`3o0?m=oi;o0?l@0?ooo`1Aool0NOoonf[o0?mCo`3o7@;o
oo]Z00Co0?m>o`28ool0ZOoo0=Co0_oonfX01_ooP@3ooo]ZoookJ_oonf[oo`0]oomG00;ooo]Z00?o
j`3ooookJ_oo_P000_oonfX01OooT03ooo]ZoaP0oooonf[oJ03o00;ooo]Z017o0?nBo`3oT?oR0?oo
oo]Zof40oooo;P3oC@3oool0K?oo08Oo0?oNoookJ_nco`3o0:?oool0gOoo0`3ooo]Zo`3ko`02oook
JP0Aoc_o0?ooK03o07Ooool0nOoonf[oZ03oo`2Voooo0?Kooo]Zool60?oonf[o603ooookJ_oo0?co
oo]ZoonB0?oo5P001?oonfX00ooo0>[ooo]ZoookJP09oookJP03o`1coooonf[ooo]Z00Oooo]Z00Wo
oe80oookJ_oonf[o02[ooookJ_loo`3o0=coogSo0?l0oml01_oonfX01?l0oa_o4P3ooookJ_oobP03
oookJP03ool0Tooo01?ooo]Z00Cooo]Z00Kof_l0oookJ_oonf[ooo]ZobH0oolPo`0>oookJP04oc7o
0?oonf[ooo]Zo`3oF`?ooo]Z00GoP_l0o`3o/Ol0<?oo0>Soo`3oC@02oookJP04o`H0oooonf[oo`3e
oi;o00;ooo]Z00?o403oo`0IoooonfX00ooonfX01Ooo057ooo]ZoookJ_oonf[oo`1i02[ooo]Z000Z
oookJP04o`1goooonf[o0?nJodCo00;ooo]Z00?ooh40oc_o0?oonfX00_oonfX00ol0nooooo]Zoook
JP03oookJPGoiOl000?o/ol0onGo0?oonfX01?oonfX01Ooo08OogOl0oookJ_oonf[oo`1/00?ooo]Z
00CoC@3oool^0?mQ0?oo0?m50ooonfX00ooR0?oooo]Zo`3oT002oookJP03o`3oT_oonf[ooo]Z00?o
oo]Z00?oJ03ooookJ_oonfX00_oonfX01OlH0?ooi_l0oookJ_oonf[oiOl000Sooo]Z00Gookh0oook
J_l0o`GoL03oon/0o`05oookJP03oomG0?oonf[oU?l000GoU?l01?oonfX00oooP@3ooo]ZoookJP04
oookJP09o`3Doooonf[o0?l<o`2Yool0R?oooo]Zo`3o;_l0odko0?ld00Gooo]Z00Go0?lMo`3o2?oo
nf[o0?mCoookJP02onGo00;oogT000CoolT0oomi0?ooN@3oT_l00_ooN@000ol0odgoogT0oomi0002
oomi00Gooo]Z0_ooN@000olV0?ooogT0oomi0004oomi0003o`3o6olB0?ooogT000CoolT000Cooe80
ooo90?oob@3ooo]Z0oooN@04oookJP06ool0j_oonf[ooi80oookJ_oo0?coo`H00_oo:005ool00004
ok?o0?oo003oo`00ool0K0?oolT00oooN@000ooo003o603oool00003ool000KoolT00ooo00001OlH
0?ooolT0ooo90?l0oi;oogT000?oo`0000?o/ol0ool00?oo00000ooo00000ooo0?coo`00ool00002
ool000;oogT000?ooe80oolX0?oo:0001?oo:009ool00004ool0NOoo003o0?mCo`3o7@;oogT000?o
0?m>oiCo0?nDo`000onDo`03oomi0005oookJ_oo02gooo]ZoomG0?oonfX00oooN@03oookJP05oon@
0?oVo`3o603ooookJ_mX0?l00_oonfX02Ol0oi;ohP3ooookJ_l0odGoH@3oodd0oooo06coo`27o`3o
gP02oookJP09ok?o0?oo0=gooo]Zool30?oonf[o0?_ooookJ_lko`3ooh4000OoolT000Gojol0ool6
0?oonf[ooo]Zool0o002oookJP03oonB0?oonf[ooo]Z00;ooo]Z00?oo`3ZoookJ_oonfX01_oonfX7
onGo00Kooo]Z00[o^Ol0oomB0?oonf[ooo]Zo`0Zoooonf[o?ol0o`3Loomho`3o0?oO1OoonfX01?l0
S_oo0?lKoa80oooobP03oookJP03o`3ioooo09?oo`0C00Cooo]Z00?of_l0on7o0?oonfX01?m4o`0>
oookJP03oc7o0?oonf[o0?mK00?ooo]Z00GoP_l0oookJ_l0<?oooo]ZonGo0002oookJP04o`H0oooo
nf[ooo]Zoi;o00;ooo]Z00?o403oonGo0?oonfX00_oonfX00olE0?oooo]Zool0D@02oookJP03o`2]
oooo07Wooo]Z04oooo]Z00So07OooookJ_l0oi[oof`0o`3oc?oonf[ooh40oc_o00Cooo]Z00?o0?_o
oookJ_oonfX00_oonfX02?oo0`3ooo]ZoookJ_oo0=gooo]Zok?o0?l0XoooW`3o1?oonfX00ol0omko
o`27oookJP02oookJP07ool0K?oonf[ooo]Zodd0oooo;P3ooo]Zof40o`03oookJP03on80oooonf[o
0?n@00;ooo]Z00?o0?nBoookJ_oonfX01?oonfX01omX0?oooo]ZoookJ_oonf[o603oo`1doooVo`00
0_oonfX00oooT03ooo]ZoookJP06oookJP04oonn0?oonf[o0?l5on/0o`Gooo]Z00?ooeL0oookJ_oo
nfX00_oonfX00ooo02gooo]ZoookJP05oookJP03oon10?oonf[ooo]Z00?ooo]Z00Go0=CooookJ_l0
1?oooo]Zo`2Yo`02oookJP03o`3o;_l0odkooo]Z00Gooo]Z00?o0?lMo`3o2?l0oe<00ooonfX03_oo
07Wooo]Zool0DOoonf[o01Wooa00oonBo`3o1P3oo`3oCOl0j?ooP_l0o`3o/?l0oe_o<Ol01OoonfX0
1?n40?oo9P3ooookJ_oJo`02oookJP04ool04ooo09?oolX0o`3o6`;ooo]Z00GoN?l0o`3Looloo`3o
oe80o`3o<`04oookJP03o`1coooonf[ooo]Z00?ooo]Z00_oo`3ZoonB0?oonf[oo`3lool60?o[o`3o
Z03oool0nOl0Mooo0?nJo`3ko`02oookJP05ok?o0?oMo`3o0?oNool0K?mQ0?l00_oonfX01Ol0oi;o
oo]ZoookJ_oonf[o603o00;oi_l02OoonfX01_l0M?oo603ooaP0oooonf[o0?nBo`0000;oo`1/00Co
oo]Zo`2Soonco`3oof`00_oonfX01?lH0?oooo]Zool0o?oo0>X2oookJP0;o`1coooonf[o0?lcoomB
0?l0omoo4P3oo`3o6ooo09?of_l0obH0oolPo`000_oonfX02Ol0oe_o0?m=o`H0oonBo`3oo`1Zool0
DOoo07Wo0?mCo`3o7@02oookJP05o`3o=?l0odko0:WooookJ_l0e?l00_oonfX01_ooP@3ooo]Zoook
J_oo02gooo]ZoomG00;ooo]Z00?oj`3ooonn0?oonfX00_oonfX01OooT03o07CooaP0oooonf[oJ03o
00;ooo]Z00Wo0?nBon80oooonf[o0?m5of40oooo;P3oo`1/oookJ_oo08L00_oonfX05Onco`3oo`3M
ogT0oooo0`3ooo]Zo`3koooonf[o>ol0oon10?ooK03o07Ooool0nOoonf[oZ03oo`2Voooo0?Kooo]Z
ool60?lH0?oooo]Zool0o002oookJP03oonB0?oonf[ooo]Z00;ooo]Z00?oo`3ZoookJ_oonfX02_oo
nfX00ol0Looooo]ZoookJP07oookJP09oomB0?oonf[ooo]Zo`0Zoooonf[o?ol0o`3Loomho`3o0?oO
00Kooo]Z00Co0?lKoa80oooonf[oolX00_oonfX00ol0nOooo`2Cool04`05oookJP06om[o0?oonf[o
oo]ZoookJ_lV0?oo8?l03_oonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP08o`3o/?n2o`3o0?nao`0`
ool0j?oo0?m=oookJ_l60?l2oookJP05ool0mOnBo`3ooo]ZoookJ_l@0?l01?oonfX01_lE0?ooo`1A
oookJ_oonf[o0:goool0NB[ooo]Z000ZoookJP04o`1goooonf[o0?nJodCo00;ooo]Z00?ooh40oc_o
0?oonfX00_oonfX00ol0nooooo]ZoookJP03oookJPGoiOl000?o/ol0onGo0?oonfX01?oonfX01Ooo
08Oooo]ZoookJ_oonf[oo`1/00?ooo]Z00CoC@3oool^0?mQ0?oo0?m50ooonfX00ooR0?oooo]Zo`3o
T002oookJP03o`3oT_oonf[ooo]Z00?ooo]Z00?oJ03ooookJ_oonfX00_oonfX01OlH0?ooi_l0oook
J_oonf[oiOl000Sooo]Z00Gookh0oookJ_l0o`Gooo]Zon/0o`05oookJP03oomG0?oonf[oU?l000Go
U?l01?oonfX00oooP@3ooo]ZoookJP04oookJP05o`3Doooonf[o0?l<o`2Yool0R?l00_oonfX00ol0
odko0?ldoookJP04oookJP06o`3o7Ol0o`Sooo]Zo`3oDooonf[oiOl00oooN@001?oob@3oogT0oomi
0?nBo`06oomi0003o`3oFoooN@3ooo]Z00Cooo]Z00?oQ03oob3o0?lV0?l01OooN@000ol0oa_o4P3o
oomi0005ooo90003oomB0?oob@3oolT000?oogT01?oonfX02?oo0>[ooo]ZoolF0?ooTP3oo`3loolX
0?oo1P3oobP01_oo0002ok?o0003ooo90?oo06coolT000;oolT00_ooN@02ool000Co603o00?oo`00
ooo90?oob@000ooob@001?lH0?ooo`00oaP0ooooN@02o`3oTP03oolX0?oob@3oolT000;o/ol01Ooo
00000ooo0?coo`00ool00003ool00003oomi0?ooDP3oobP000GoobP02Ooo00002?oo07WoogT0ool0
0?l0oe?o0?lMoomi0?l0odkoogT01OnDo`03oomi0005oookJ_oo02gooo]ZoomG0?oonfX00_ooN@00
2?oonf[oU?l0oiCo0?nDo`3ooi00oaP0oooonf[oJ03o0ooonfX05?l0oi;ohP3ooookJ_l0odGoH@3o
odd0oooo06coo`27o`3og_oonf[o/ol0o`2Soooo0=gooo]Zool30?oonf[o0?_ooookJ_lko`3ooh40
1_oob@000oo[o`3ooo]Zool60002oookJP04ool0o?oonf[ooi80oolF00Cooo]Z00?oo`3ZoookJ_oo
nfX01_oonfX7onGo00Kooo]Z00[o^Ol0oomB0?oonf[ooo]Zo`0Zooloo`3ooo]Zo`3Loomho`3o0?oO
1OoonfX01?l0oa_ooo]Zoa80oooobP03oookJP03o`3ioooo09?ooo]Z00Cooo]Z00Cof_l0on7o0?oo
nf[ooo]Z0_m4o`000olPo`3ooo]ZoookJP0<oookJP03oc7o0?oonf[o0?mK00?ooo]Z00GoP_l0oook
J_l0<?oo0>SoonGo0002oookJP04o`H0oooonf[oo`3eoi;o00;ooo]Z00?o403oonGo0?oonfX00_oo
nfX00olE0?oooo]Zool0D@02oookJP03o`2]oooo07Wooo]Z04oooo]Z00So07OooookJ_l0oi[oof`0
o`3oc?oonf[ooh40oc_o00Cooo]Z00?o0?_ooookJ_oonfX00_oonfX02?oo0`3ooo]ZoookJ_oo0=go
oo]Zok?o0?l0XoooW`3o1?oonfX00ol0omkoo`27oookJP02oookJP07ool0K?oonf[ooo]Zodd0oooo
;P3ooo]Zof40o`03oookJP03on80oooonf[o0?n@00;ooo]Z00?o0?nBoookJ_oonfX01?oonfX01omX
0?oooo]ZoookJ_oonf[o603oo`1doooVo`000_oonfX00oooT03ooo]ZoookJP06oookJP04oonn0?oo
nf[o0?l5on/0o`Gooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP05oookJP03oon1
0?oonf[ooo]Z00?ooo]Z00Go0=CooookJ_l01?oooo]Zo`2Yo`03oookJP03o`3oC_oonf[ooo]Z00Co
oo]Z00?o0?lMo`3o2?l0oe<00ooonfX03_oo07Wooo]Zool0DOlE0?oo01Wooa00oonBo`3o1P3oo`3o
COl0j?ooP_l0o`3o/?l0oe_o<Ol01OoonfX01?n40?oo8?l0obH0oooJo`02oookJP04ool04ooo09?o
olX0o`3o6`;ooo]Z00GoN?l0ocd0ooloo`3o02[ooomB0004oookJP03o`1coooonf[ooo]Z00?ooo]Z
01?oo`3ZoolF0?ooTP3oo`3loookJ_oo1P3ojol0ojP0ool0Moooof`0oookJ_l0nooooo]Zo`2Soonc
o`3ogOl0o`3og_oo06coH@3o00;ooo]Z0_l0oi82oookJP?o603o0_oVo`02oookJP;o07Co0olH0?l0
1ooonf[o0?nBo`3oT_mQ0?ooo`1/o`3og_l0Xol00_nco`002_ooK03ooo]ZoookJ_lH0?oooo]Zool0
o?oonf[oo`3ZoookJ_l0Lol2oookJP08oomB0?l0g?oo0?oOo`3o6ooobP3oo`0Com[o0?lV0?l3oook
JP09o`3oFol0odgoT_l0oa00oooo057oo`1ioookJ_l0oe?o0?lM00;ooo]Z00Oo0?m>oookJ_l0ZOoo
00Coo`3Doooonf[ooh4000?ooo]Z00Ooo`0]oookJ_ooE`3ooo]Zog00ooo[0?oookh000?ooo]Z00Co
oi00oaP0oooVo`3oJ03o0ooonfX02Ol0oi;ohP3ooookJ_l0odGoH@3oodd0oooo06cooo]Zool0Q`02
oookJP0Hok?o0?oo0=goN@3oool30?oonf[o0?_ooookJ_lko`3ooh40oom/0?l0Moooo`3iojP0ool0
Y_oooo]Zool0m_o[o`3oo`H0oaP0oooonf[oo`3loookJ_ooTP3ooaH01?oonfX00ooo0>[ooo]Zoook
JP0:oookJP03o`1coooonf[ooo]Z00Oooo]Z00Wooe80oookJ_oonf[o02[oocoo0?oonf[o0=coogSo
0?l0oml01_oonfX00ol0oa_o4P3oooo:0003oookJP03o`3ioooo09?oo`0C00Gooo]Z00Kof_l0oook
J_oonf[ooo]ZobH0oolPo`0>oookJP03oc7o0?oonf[o0?mK00?ooo]Z00co0?n`oh;o0?l0ok7o033o
o`3Xool0odgooo]Zo`H0oooonf[oo`3eoookJ_nBo`02oookJP03oa00oooonf[ooo]Z00;ooo]Z00Ko
5@3oool0DOoonf[ooo]Zo`2]oooo07TZoookJP00:_oonfX01?l0Mooooo]Zo`3oV_m4o`02oookJP03
oon10?lko`3ooo]Z00?ooo]Z00Co0?_ooookJ_oonf[ooo]Z1_oUo`000onco`3oiOl0oookJP04oook
JP05o`3og_oo08Oooo]ZoookJ_oo06`00ooonfX01?m=0?ooobh0of40ool0odD3oookJP03on80oooo
nf[o0?n@00;ooo]Z00?o0?nBoookJ_oonfX00ooonfX00omX0?oooo]ZoookJP02oookJP05oaP0oooV
o`3ooo]ZoookJ_oUo`002OoonfX01?oo_P3o0?l5oookJ_o[0?l5oookJP03oomG0?oonf[oU?l000Go
U?l01?oonfX00oooP@3ooo]ZoookJP04oookJP05o`3Doooonf[o0?l<o`2Yool0R?l00_oonfX00ol0
odko0?ldoookJP04oookJP06o`3o7Ol0o`Sooo]Zo`3oDooonf[oiOl00oooN@001Ooob@3oogT0oomi
0?l@0?ooT_l000GoogT000?o0?mKoomi0?oonfX01OoonfX00olPo`3o9P3ooomi0004oomi0003ooo:
0?l0oa_ooo]Z00CoolT000Cooo]ZoomB0?oonf[ooo]Z1?ooN@03oookJP08ool0j_oonf[ooo]ZoonB
0?oo0?coobP0ool60?oo:006ool00004ooo90?l0Xooo/ol0ooo900;oo`1/0_oob@000oooN@3oo`00
ool00004ool000Ko603o00GoolT0o`3oT_l0oi;o0?nBoolX0004ooo900;oo`000ooo:0000ooo003o
o`3lool00003ool000;oobP000?oogT0oomB0?oo:0001?oo:00:ool00008ool0NOoo003o0?mCo`3o
7Ol0hOooogT0o`3oC_ooN@04oiCo00?oogT00_oonfX01?oo02gooo]ZoomG0?oonfX2oomi0008oook
J_nDo`3oU?l0oon@0?nDo`3o603ooiCo0?mX0?l2oookJP09o`3oT_oonf[ohP3ooookJ_l0odGoH@3o
odd0oooo06coo`2700;ooo]Z00Ko/ol0ool0gOmi0?ooo`<0oookJ_l0nol2oookJP05oc_o0?ooP@3o
oo]Zooo90?oo0?T00ooob@000oo[o`3ooo]Zool60002oookJP04ool0o?oonf[ooi80oolF00?ooo]Z
00?oo`3ZoookJ_oonfX01ooonfX6onGo00Kooo]Z00?o^Ol0oookJ_ooDP000_oonfX01_l0:_oo?ol0
o`3Loooonf[oN?l0ocd0o`Gooo]Z00Co0?lKoa80oooonf[oolX00_oonfX00ol0nOoooo]ZonGo0004
oookJP03om[o0?oonf[ohOl000;ooo]Z0_m4o`000olPo`3ooo]ZoookJP0<oookJP03oc7o0?oonf[o
0?mK00;ooo]Z00KoP_l0oookJ_oonf[o033oo`3XoooUo`02oookJP03o`H0oooonf[oT_l000?ooo]Z
00?o403oo`1MoooonfX00_oonfX01olE0?ooo`1AoookJ_oonf[o0:gooookJ_oo07T0D?oonfX02?l0
Mooooo]Zo`3oV_ooK03o0?o<oookJ_ooP@3o>ol01?oonfX00ol0nooooo]ZoookJP02oookJP08ool3
0?oonf[ooo]Zool0gOoonf[o/ol0o`2SoonO0?l4oookJP03o`3og_oo08Oooo]Z00;ooo]Z00Ooo`1/
oookJ_oonf[oC@3oool^0?oonf[oH@3o00?ooo]Z00?ohP3ooookJ_l0oi000_oonfX00ol0oi;ooo]Z
oookJP04oookJP07ofP0oooonf[ooo]ZoookJ_lH0?oo07CoonKo0002oookJP03oon@0?oonf[ooo]Z
00Oooo]Z00?ookh0o`3o1Oo[0?l01OoonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z
00Gooo]Z00?ooh40oookJ_oonfX00ooonfX01Ol0e?oooo]Zo`04oooonf[o0:Wo00?ooo]Z00?o0?m>
oookJ_oonfX01?oonfX00ol0oago0?l8o`3oD`03oookJP0>ool0NOl0[Oooo`1AoaD0ool06Ooo403o
ool0mOnBo`3o0?m=o`3Xoon2o`3o0?n`o`3oFolao`06oookJP09oh@0oolV0?oof_l0on7o0?oonf[o
o`0Cool0TooobP3o0?lK00?ooo]Z00CoN?l0o`3Lool0:_oooe801?oonfX00ol0Looooo]ZoookJP03
oookJP0<ool0j_oonf[ooi80ool0o?oonf[oo`H0on_o0?nX0?ooo`3io`1gooooK03o0?_o0_oonfX0
1?l0Xooo/ol0oookJ_l0omh2ool0K003of40oooonf[ooo]Z00;o0?nB0ooonfX6oaP0o`;ooo]Z0_l0
oi801?oonf[oH@3oool0K?l0omh2ok?o000;oookJ_ooK03ooo]Zool0m_lH0?oooo]Zool0o?oonf[o
o`3ZoookJ_l0Lol00_oonfX02Ol0oc?ooe80o`3ogol0oa_oolX0ool0TooJo`3o9P3oob3o0002oook
JP0:o`3oFol0odgo1P3ooi;o0?l@0?ooo`1Aool0NOl0oe?o0?l8o`3o7@;ooo]Z00Co0?m>o`28ool0
ZOoo0=Co0_oonfX02oooP@3ooo]ZoookJ_oonf[oo`0]oookJ_ooE`3ooo]Zon/0oooonf[ookh000;o
oo]Z00Gooi00oookJ_lH0?oooo]ZofP0o`02oookJP0:o`3oT_oonf[ohP3ooookJ_l0odGoH@3oodd0
oooo06cooo]Zool0Q`;ooo]Z00Go/ol0ool0gOmi0?oooo]Zo`3ko`02oookJP0Aoc_o0?ooP@3ooo]Z
o`1goooo0?WoZ03oo`2Voooonf[oo`3fon_o0?oo1P3o603ooookJ_oo0?cooo]ZoonB0?oo5P001?oo
nfX00ooo0>[ooo]ZoookJP09oookJP03o`1coooonf[ooo]Z00Oooo]Z00[o^Ol0oomB0?oonf[ooo]Z
o`0Zooloo`3o0=cooookJ_mho`3o?@3o1_oonfX00ol0oa_ooo]Zooo:0003oookJP03o`3ioooo09?o
o`0C00Cooo]Z00?of_l0on7o0?oonfX00_oonfX00olV0?oo8?l0oookJP0=oookJP03oc7o0?oonf[o
0?mK00?ooo]Z00_oP_l0oookJ_l0ok7o033oo`3Xool0odgooo]Zo`H0oooonf[oo`3eoi;o0002oook
JP03ool0J_l@0?oooo]Z00?ooo]Z00Ko5@3oool0DOoonf[ooo]Zo`2]oooo07TZoookJP00:_oonfX0
1?l0Mooooo]ZodCo0?l0oiX2oookJP03oon10?lko`3ooo]Z00?ooo]Z00Co0?_ooookJ_oonf[ooo]Z
1_oUo`000onco`3oiOl0onGo0004oookJP05o`3og_oo08Oooo]ZoookJ_oo06`00ooonfX01?m=0?oo
obh0of40ool0odD3oookJP03on80oooonf[o0?n@00;ooo]Z00?o0?nBoookJ_oonfX01?oonfX01_mX
0?oooo]ZoookJ_oonf[o603oonKo00;ooo]Z00?oiOl0oookJ_oonfX01ooonfX01?oo_P3o0?l5oook
J_o[0?l5oookJP03oomG0?oonf[oU?l000KoU?l00ooonfX00oooP@3ooo]ZoookJP04oookJP05o`3D
oooonf[o0?l<o`2Yool0R?l00_oonfX00ol0odko0?ldoookJP04oookJP06o`3Qool0oagooo]Zo`3o
Dooonf[oiOl00oooN@001Ooob@3oogT0oomi0?ooN@3oT_l000GoogT000?o0?mKoomi0?oonfX01Ooo
nfX00olPo`3o9P3ooomi0004oomi0003ooo:0?l0oa_ooo]Z00;ooo]Z00KoN?l0o`3Lool0:_oooe80
okWo0?oonfX5oomi00?ooo]Z00Ooo`3ZoookJ_oo5P3ooi80ool0o?oo1P3oobP000Ooo`0000?oolT0
o`2Soonco`000_oob@02ool0K003ooo90?mQ0?ooo`0000Coo`0000Co0?nBooo90?oob@3oolT00ol0
oi82oolX00KoolT01Ooo:0001?oo0?coo`00ool00?oo0004oolX0003oomB0?ooN@3oobP000?oobP0
3Ooo00001_l0oe?o0?lMoookJ_ooN@3o0?m>oomi00?oU?l01?ooN@001?oonf[oo`0]oookJ_ooE`02
oookJP03oomi0?oonf[ooo]Z00;oU?l0013ooi00onKo0?lH0?ooU?l0ofP0oonDo`3ooo]Zo`3oT_l0
oi3ohP3oo`3oAOmQ0?ooC@3oool0K?oonf[oo`270_oonfX01_nco`3oo`3MoookJ_oo0`3ooo]Zo`3k
o`;ooo]Z00Co>ol0oom/0?oonf[o07Oo0ooob@001?oo0?Kojol0ool60?lH0?l2oookJP03ool0o?oo
nf[ooi8000Cooo]Z00?oo`3ZoookJ_oonfX01ooonfX6onGo00Kooo]Z00?o^Ol0oomB0?oonfX00_oo
nfX01_l0:_oo?ol0o`3Loomho`3o0?oOocd0o`Gooo]Z00Co0?lKoa80oooonf[oolX00_oonfX00ol0
nOoooo]ZonGo0004oookJP03om[o0?oonf[ohOl000;ooo]Z0_m4o`000olPo`3ooo]ZoookJP0;oook
JP03oc7o0?oonf[o0?mK00?ooo]Z00GoP_l0oookJ_oonf[o033oonGo0002oookJP04o`H0oooonf[o
oo]Zoi;o00?ooo]Z00?o403oo`1MoooonfX00_oonfX01olE0?ooo`1AoookJ_oonf[o0:gooookJ_oo
07T0D?oonfX02?l0Mooooo]Zoom/0?l0oi[o0?o<oookJ_ooP@3o>ol01?oonfX00ol0nooooo]Zoook
JP02oookJP08ool30?oonf[ooo]ZogT0oooo0=go/ol0o`2SoonO0?l4oookJP03o`3og_oonf[oo`27
00;ooo]Z00Ooo`1/oookJ_oonf[oC@3oool^0?oonf[oH@3o00?ooo]Z00?ohP3ooookJ_l0oi000_oo
nfX00ol0oi;ooo]ZoookJP05oookJP06ofP0oooonf[ooo]ZoaP0ool0M?ooi_l00_oonfX00oooT03o
oo]ZoookJP07oookJP03oonn0?l0o`Goj`3o00Gooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02go
oo]ZoookJP05oookJP03oon10?oonf[ooo]Z00?ooo]Z00Go0=CooookJ_l01?oooo]Zo`2Yo`03oook
JP03o`3oC_oonf[ooo]Z00Cooo]Z00?o0?lMo`3o2?l0oe<00ooonfX03_oo07Wo0:goool0DOlE0?oo
01Wooa00oooo0?GoT_l0o`3oCOl0j?ooP_l0o`3o/?l0oe_o<Ol01_oonfX02_n40?oo9P3oom[o0?oQ
o`3ooo]Zool04ooo09?oolX0oa80ool0oa/2oookJP05ogSo0?l0g?oooo]ZoomB0?l0oc<01?oonfX0
0ol0Looooo]ZoookJP03oookJP0<ool0j_oo5P3ooi80ool0o?oo1P3ooo]Zon_o0?nX0?ooo`3io`1g
ool0oi[o0?_o0_oonfX01Ol0Xooo/ol0oookJ_l0omkooo]Z00;oo`1/00?oH@3ooookJ_oonfX01?l0
oi84oookJP?o0?nB00Kooo]Zof40oomQ0?ooo`1/o`3og_nco`02o`000008oom/0?oonf[oo`3fool6
0?oonf[oo`3loookJ_oo0>X2oookJP0<o`1coooonf[ooo]ZoomB0?l0omoo08koo`3o6ooo09?of_l0
on7o0?lV0?ooQ03o0_oonfX02Ol0oe_o0?m=oi;o0?l@0?ooo`1Ao`2]oooo07Wo0?mCo`3o7@02oook
JP05o`3o=?l0odko0:WooookJ_l0e?l00_oonfX01_ooP@3ooo]ZoookJ_oo02gooo]ZoomG00;ooo]Z
00?oj`3ooonn0?oonfX00_oonfX01OooT03o07CooaP0oooonf[oJ03o00;ooo]Z017o0?nBo`3oT?oR
0?oooo]Zof40oooo;P3oC@3oool0K?oo08Oo0?oNoookJ_nco`3o0:?oool0gOoo0`3ooo]Zo`3ko`02
oookJP0Aoc_o0?ooK03ooo]Zo`1goooonf[oZ03oo`2Voooo0?Kooo]Zool60?oonf[o603ooookJ_oo
0?cooo]ZoonB0?oo5P001?oonfX00ooo0>[ooo]ZoookJP09oookJP03o`1coooonf[ooo]Z00Oooo]Z
00[ooe80oookJ_oonf[ooo]Zo`0Zooloo`3o0=coogSo0?l0omoo?@3o1_oonfX00ol0oa_ooo]Zooo:
0003oookJP03o`3ioooo09?oo`0C00Cooo]Z00?of_l0on7o0?oonfX00_oonfX00olV0?oo8?l0oook
JP0=oookJP03oc7o0?oonf[o0?mK00?ooo]Z00GoP_l0oookJ_l0ok7o033oo`3oC@02oookJP04o`H0
oooonf[oo`3eoi;o00;ooo]Z00?oo`1Zoa00oooonfX00ooonfX01_oo057ooo]ZoookJ_oonf[o0:go
ool0NB[ooo]Z000ZoookJP04o`1goooonf[oA?l0o`3oVP;ooo]Z00?ooh40oc_o0?oonfX00ooonfX0
1?l0nooooo]ZoookJ_oonfX6onGo0003ok?o0?oUo`3oiOl000Cooo]Z00Go0?oNool0Qooonf[ooo]Z
ool0K003oookJP05odd0oooo;P3oH@3ooookJ_l0odD00_oonfX00ooR0?oooo]Zo`3oT002oookJP03
o`3oT_oonf[ooo]Z00Cooo]Z00KoJ03ooookJ_oonf[ooo]ZoaP0oooVo`02oookJP03onGo0?oonf[o
oo]Z00Oooo]Z00Cookh0o`3o1Ooonf[oj`3o1OoonfX00oooE`3ooo]ZoiCo0006oiCo00?ooo]Z00?o
oh40oookJ_oonfX01?oonfX01Ol0e?oooo]Zo`3o3?l0ZOoo08So00;ooo]Z00?o0?m>o`3o=?oonfX0
1?oonfX01_l0hOoo0?lMoookJ_l0oe?ooo]ZonGo00?oogT000GoolT0oomi0?ooN@3oogT0oi;o0005
oomi0003o`3oFoooN@3ooo]Z00Gooo]Z00?o8?l0obH0oooJo`001OooN@002_l0oa_oogT0oookJ_oo
nf[oN?l0o`3Lool0:_oo0?lcoomB0?oonfX6oomi00;ooo]Z00Goo`3ZoookJ_oonf[ooi80ool0o002
oolX00Ooo`000_oob@001ol0Xooo/ol0ooo90?oob@3oogT0ool0K?ooN@001?mQ0?l00ooonf[oolT0
o`3oTP02o`3oTP?oobP02Ooob@03oolX0004ool0o?oo003oo`00ool000CoobP000?ooe80o`0Zoooo
:0000ooo:002ooo900_oo`0000Go0?mCooo90?l0oagooo]Zo`3oCP02oomi00?oU?l000?ooo]Zoomi
0?ooN@000_oonfX01_oo02gooo]ZoomG0?oonf[oL03oon/0o`;ooo]Z0_nDo`004?ooT03o603ooiCo
0?nDo`3oJ03ooiCo0?oonf[o0?nBo`3oT?oR0?oo0?m5of40oom=0?ooo`1/ool0Qol0omh2oookJP0<
ok?o0?oo0=gooo]Zool30?oonf[o0?_ooookJ_lko`3ooh40o`3oV_l0Moooo`3i0ooob@000oo[o`3o
oo]Zool60003oookJP03ool0o?oonf[ooi8000Cooo]Z00?oo`3ZoookJ_oonfX01ooonfX6onGo00Ko
oo]Z00_o^Ol0oomB0?oonf[ooo]Zo`0Zoooonf[o?ol0o`3Loomho`3o0?oOocd0o`05oookJP04o`3o
6olB0?oooo]Zooo:00;ooo]Z00?o0?WooookJ_oUo`001?oonfX00ooJo`3ohOl0oookJP02oookJP03
odCo0?oonf[o8?l000gooo]Z00?o<Ol0oookJ_l0oe/00ooonfX01On2o`3ooo]ZoookJ_l0<?ooiOl0
00;ooo]Z00Co1P3ooookJ_oonf[oT_l00ooonfX00ol@0?ooiOl0oookJP02oookJP07oaD0oooo057o
oo]ZoookJ_l0[Ooooo]Zool0N@1@oookJP08o`1goooonf[oof`0o`3oV_l0olcooo]Zoon10?lko`04
oookJP03o`3koooonf[ooo]Z00;ooo]Z00Soo`<0oookJ_oonf[oN@3oool0gOoonf[o/ol0oil0o`Co
oo]Z00?o0?oNoookJ_oo08L00_oonfX02?oo06cooo]ZoookJ_m=0?ooobh0oookJ_mQ0?oo0?m50_oo
nfX00ooR0?oooo]Zo`3oT002oookJP03o`3oT_oonf[ooo]Z00Gooo]Z00KoJ03ooookJ_oonf[o603o
o`1doooVo`02oookJP03oon@0?oonf[ooo]Z00Oooo]Z00?ookh0o`3o1Oo[0?l01OoonfX00oooE`3o
oo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX00ooonfX01Ol0e?oo
oo]Zo`04oooonf[o0:Wo00?ooo]Z00?o0?m>oookJ_oonfX01?oonfX00ol0hOoo0?lMo`3oD`03oook
JP0>ool0NOl0[Oooo`1AoaD0oooonf[o01Wooa00oonBo`3ooo]Zo`3oCOl0<?ooP_l0o`3oFolao`06
oookJP0:oh@0oolV0?oof_l0on7o0?oonf[oo`0Cool0Tooonf[oolX0o`3o6`;ooo]Z00GoN?l0o`3L
ooloo`3o02[ooomB0004oookJP03o`1coooonf[ooo]Z00?ooo]Z00[oo`3ZoookJ_ooTP3ooo]Zool0
o?oo1P3ojol0ool0m_nX0?oo07Oo0_ooK0001_l0nooooo]ZoookJ_l0Xooo/ol0oookJP;o0?oN00?o
oo]Zool0K?mQ0?l00omQ0?l2oookJPCo0?nB00?ooo]Zof40oomQ0?l00ooo06`2ok?o00;o000000So
of`0oookJ_oo0?Koo`H0oookJ_oo0?cooo]Zool0jP;ooo]Z00co07?ooookJ_oonf[ooe80o`0Zool0
omoo0?lKooo:0?oo09?of_l0obH0oolPo`02oookJP0:oc7o0?l0odgo1P3ooi;o0?l@0?ooo`1Aool0
NOoonf[o0?mCo`3o7@;ooo]Z00Oo0?m>oookJ_l0ZOoo00Coo`3Doooonf[ooh4000?ooo]Z00Ooo`0]
oookJ_ooE`3ooo]Zog00ooo[0?oookh000?ooo]Z00Gooi00oaP0oooVo`3ooo]ZofP0o`02oookJP0N
o`3oT_l0oi3ohP3oo`3oAOmQ0?ooC@3oool0K?oonf[oo`27omgo0?oonf[o/ol0ool0gOmi0?ooo`<0
oookJ_l0nooooo]Zoc_o0?ooP@3oof`0o`1goooo0?Wooo]ZojP0ool0Y_ooo`3fon_o0?oo1P3o603o
0_oonfX01?oo0?cooo]ZoonB0?oo5P04oookJP03ool0j_oonf[ooo]Z00Wooo]Z00?o07?ooookJ_oo
nfX01ooonfX02_ooDP3ooo]ZoookJ_l0:_oooo]Zocoo0?l0g?ooN?l0o`3ogolm0?l5oookJP04o`3o
6olB0?oooo]Zooo:00?ooo]Z00?o0?Woool0Tooo01<01?oonfX00ooJo`3ooo]ZoookJP02oookJP03
obH0oolPo`3ooo]Z00gooo]Z00?o<Ol0oookJ_l0oe/00ooonfX01On2o`3ooo]Zo`3o/Ol0j?oo0?m=
00;ooo]Z00Co1P3ooookJ_oo0?GoT_l00_oonfX00ooo06[o403ooookJP03oookJP06ool0DOoonf[o
oo]ZoookJ_l0[Oooo`1i:_oonfX002[ooo]Z00Co07OooookJ_m4o`3o0?nJ0_oonfX00oooP@3o>ol0
oookJP03oookJP05o`3koooonf[ooo]ZoookJ_oo0`000ooonfX01?oUo`3ooo]Zo`2Soonco`05oook
JP03o`3og_oo08Oooo]Z00;ooo]Z00Soo`1/oookJ_oonf[oC@3oool^0?mQ0?oooo]Zo`3oA@?ooo]Z
00GohP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP06ofP0oooonf[ooo]ZoookJ_lH0?ooi_l00_oonfX0
0ooUo`3ooo]ZoookJP07oookJP04oonn0?l0o`Gooo]Zon/0o`Gooo]Z00?ooeL0oiCo0?nDo`001_nD
o`03oookJP03oon10?oonf[ooo]Z00Cooo]Z00Go0=CooookJ_l0o`cooo]Zo`2Yo`02oookJP03o`3o
;_l0odko0?ld00Gooo]Z00Co0?lMoookJ_l0oe?ooo]Z1?oUo`001Ooo057oiOl0oomi0?ooN@3oT_l0
00OoogT01_oonfX01?n40?oo9P3ooomi0?oJo`04oomi0009ooo:0?l0oa_ooo]ZoookJ_lm0?ooN?l0
o`0Zoooonf[ooe8000;ooo]Z1OooN@02oookJP07ool0j_oonf[ooo]ZoolF0?oo:03oo`3loolX0008
ool000;oolT000Go0:?ook?o0?nco`3oogT0o`3ogP04ool0K003ool00?mQ0?ooH@3o00CoobP02ooo
b@000ooo:03oo`3lool0o002oolX0003ool00?oo:03oogT000;oobP000?oo`00oomB0?oo00000ooo
:002ooo900[oo`0000Ooo`1iool00?l0oe?o0?lMo`3Qoooob@3o0?m>00;oogT00_nDo`02oookJP04
oomi0?oonf[ooo]Zool0;@;ooo]Z00CooeL0oookJ_o[0?ooolT00_oonfX01onDo`3ooi00oiCo0?lH
0?ooU?l0ofP0oonDo`000_oonfX05ol0oi;ohP3ooookJ_l0odGoH@3oodd0oooo06coo`27o`3og_oo
nf[o/ol0ool0gOmi0?oooo]Zool30?oonf[o0?_ooookJ_lko`3ooh40oookJ_l0Moooo`3i00;oolT0
00Cooo]Zon_o0?oonf[oo`H00_oonfX01?oo0?cooo]ZoonB0?oo5P04oookJP03ool0j_oonf[ooo]Z
00Sooo]Z1?oUo`07oookJP0:okWo0?ooDP3ooo]ZoookJ_l0:_oooo]Zocoo0?l0g?ooN?l0o`3og`Ko
oo]Z00?o0?lKoa80oooobP000ooonfX00ol0nOooiOl0ool04`04oookJP03om[o0?oQo`3ooo]Z00;o
oo]Z00?o9P3oob3o0?oonfX03OoonfX00olao`3ooo]Zo`3oF`03oookJP05oh;o0?oonf[o0?nao`0`
oooUo`000_oonfX01?l60?oooo]Zool0mOnBo`03oookJP03oa00oooUo`3ooo]Z00;ooo]Z00Oo5@3o
ool0DOoonf[ooo]Zo`2]oooonf[oo`1i053ooo]Z00So07OooookJ_ooK03o0?nJo`3oc?oonf[ooh40
oc_o00Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30003oookJP05ogT0oooo0=gooo]Zok?o0?nO0?l0
1?oonfX00ol0omkooo]Zool0Q`03oookJP07ool0K?oonf[oC@3oool^0?oonf[oH@3oo`3oA@03oook
JP05on80ool0oi3ooo]ZoookJ_l0oi801ooonfX01_mX0?oooo]ZoookJ_lH0?oo07CoonKo00;ooo]Z
00?ooi00oookJ_oonfX01ooonfX00ooo_P3o0?l5on/0o`05oookJP03oomG0?oonf[ooo]Z00;ooo]Z
00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP03oookJP05o`3Doooonf[o00CooookJ_l0
ZOl00ooonfX00ol0odko0?ldoookJP04oookJP03o`3Qool0oago0?mC00?ooo]Z00koo`1io`2]oooo
057o5@3ooookJ_l06Ooo403ooi;o0?oonf[o0?m=oookJ_n2o`3ooo]Zoc7o00Oooo]Z00?o9P3ooook
J_oJo`000_oonfX01?oo01?oo`2Cooo:0?l0oa/2oookJP06ocd0oomho`3o0=coo`0ZooooDP3o^Ol0
0ooonfX00ol0Looooo]ZoookJP03oookJP0>ool0j_oonf[ooaH0oonB0?oonf[oo`3lool60?o[o`3o
Z03oool0nOl0Mooooo]Zoom/0?l0nol2oookJP04o`2Soonco`3o/ol0omgo00;o0?oN1?oo06`4of40
o`Goo`1/00Cooo]Zok?o0?nco`3o0:?o0_l000001?ooK03o0000ool0m_oo1P02ool0o005oookJ_oo
0>[ooo]ZoookJ_l0Lol00_oonfX02_l0oc?ooe80o`3ogol0oa_oolX0ool0TooJo`3o9P3oob3o0?n4
0?l2oookJP0:oc7o0?l0odgoT_l0oa00oooonf[oo`1Aool0NOl0oe?o0?lMo`3Qo`;ooo]Z00Co0?m>
o`2Yoooonf[o0=Co0_oonfX02oooP@3ooo]ZoookJ_oonf[oo`0]oookJ_ooE`3ooo]Zon/0oooonf[o
okh000;ooo]Z00Gooi00oookJ_lH0?ooi_l0ofP0o`03oookJP09o`3oT_oR0?oooo]Zo`3oAOmQ0?oo
C@3oool0K?oonf[oo`2700;ooo]Z01So/ol0ool0gOmi0?ooo`<0oookJ_l0nooooo]Zoc_o0?ooP@3o
of`0o`1goooo0?Wooo]ZojP0oooonf[oo`3fon_o0?oo1P3o603ooookJ_oo0?cooo]ZoonB0?oo5P05
oookJP03ool0j_oonf[ooo]Z00Wooo]Z00?o07?ooookJ_oonfX01ooonfX02OooDP3ooo]ZoookJ_l0
:_oooo]Zocoo0?l0g?ooN?l0o`3og`06oookJP04o`3o6olB0?oooo]Zooo:00;ooo]Z00Co0?Woool0
Tooonf[oo`0C1?oonfX01_oJo`3ooo]ZoookJ_oonf[oQ03oobH0o`kooo]Z00Co<Ol0oookJ_oonf[o
0?mK0_oonfX03?l0ok3oP_l0o`3o/Ol0<?oo0>Soo`3oCOoonf[o1P3ooookJ_oo0?Gooo]Zoi;o00;o
oo]Z00?oo`1Zoa00oooonfX00ooonfX01_oo057ooo]ZoookJ_oonf[o0:goool0NB[ooo]Z000Zoook
JP04o`1goooonf[oA?l0o`3oVP;ooo]Z00?ooh40oc_o0?oonfX00ooonfX01Ol0nooooo]ZoookJ_oo
nf[oo`<000?ooo]Z00CoiOl0oookJ_l0Xooo/ol01OoonfX00ol0omkoo`27oookJP02oookJP04ool0
K?oonf[ooo]Zodd0o`;ooo]Z00?oH@3oo`3oAOoonfX00_oonfX01OoR0?oo0?n@oookJ_oonf[o0?nB
00Kooo]Z00KoJ03ooookJ_oonf[ooo]ZoaP0oooVo`02oookJP03onGo0?oonf[ooo]Z00Oooo]Z00Co
okh0o`3o1Ooonf[oj`3o1OoonfX00oooE`3oU?l0oiCo0007oiCo00;ooo]Z00?ooh40oookJ_oonfX0
1?oonfX01Ol0e?oooo]Zo`3o3?oonf[o0:Wo00;ooo]Z00?o0?l^o`3oC_l0oc@01OoonfX00ol0oago
oo]Zooo90005onGo0003ool0DOooN@3oogT000;oogT000OoT_l0oomi0?ooN@3oogT0oh;o0?oonf[o
<Ol000Oooo]Z00?o9P3ooomi0?oJo`001?ooN@000ooobP3o0?lKoomi0002oookJP06ogSo0?loo`3o
02[ooomB0?nio`3ooo]Z1_ooN@02oookJP03ool0j_oonf[ooo]Z00;oobP000?oo`3lool00?oo0000
1Ooo00000ooob@3oobP0oolX0002oomi0005o`2Soonco`3o/ol0ok?o0?oo00000_l0omh00ooo06co
obP0oolX0002oolX00goolT000?oo`3lool00?oo0>X00ooo00001Ooo:03oogT0oolX0?oo003ooe80
00;oo`000_oo:003ooo900Ooo`0000koT_l0ool00?oo003oo`00o`3oDooob@3o0?lMooo90?l0odko
olT0oomi0?l01?ooU?l0oomi00;ooo]Z00Gooh40oookJ_oonf[oo`0]oookJP02ooo90003oookJ_o[
0?oooo]Z00;ooo]Z00KoU?l0oon@0?oVo`3o603ooiCo0?mX0?l2oookJP0Ao`3oT_oonf[ohP3ooook
J_mQ0?ooC@3oool0K?oonf[oo`27o`3og_oonf[o/ol0ool0gOoonf[oo`<0oookJ_l0nol00_oonfX0
1?lko`3oof`0oookJ_l0Mol3ooo90004ool0m_o[o`3ooo]Zool600;ooo]Z00Coo`3loookJ_ooTP3o
oaH01?oonfX00ooo0>[ooo]ZoookJP08oookJPCoiOl01ooonfX02_nio`3ooe80oookJ_oonf[o02[o
ocoo0?oonf[o0=coogSo0?l0oml5oookJP04o`2>ool0oa_ooo]Zooo:00?ooo]Z00?o0?WoonGo0?oo
01<01?oonfX00ooJo`3ohOl0oookJP02oookJP03obH0oolPo`3ooo]Z00gooo]Z00?o<Ol0oookJ_l0
oe/00ooonfX01On2o`3ooo]Zo`0`oooonf[oiOl000;ooo]Z00?o1P3ooookJ_nBo`001?oonfX00ol@
0?ooiOl0oookJP02oookJP07ool0DOoonf[ooo]ZoookJ_l0[Ooooo]Zool0N@1@oookJP08o`1goooo
nf[oof`0o`3oV_l0olcooo]Zoon10?lko`04oookJP05o`3koooonf[ooo]ZoookJ_oo0`000ooonfX0
1Omi0?ooo`3MoookJ_nco`3oW`3o00Cooo]Z00?o0?oNoookJ_oo08L00ooonfX01ooo06cooo]Zodd0
oooo;P3ooo]Zof40ool0odD00ooonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Oooo]Z00KoJ03ooook
J_oonf[o603oo`1doooVo`02oookJP03oon@0?oonf[ooo]Z00Oooo]Z00?ookh0o`3o1Oo[0?l01Ooo
nfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX00ooo
nfX01Ol0e?oooo]Zo`04oooonf[o0:Wo00?ooo]Z00?o0?m>o`3o=?oonfX01?oonfX00ol0hOoo0?lM
o`3oD`04oookJP0=ool0NOoo057o5@3ooookJ_l06Ooo403ooi;o0?l60?oo0?m=oookJ_n2o`3ooo]Z
oc7o0007oookJP03obH0oooonf[of_l000;ooo]Z00Goo`0Cool0TooobP3o4P3oo`3o6`02oookJP05
ogSo0?l0g?oooo]ZoomB0?l0oc<01?oonfX00ol0Looooo]ZoookJP03oookJP0:ool0j_oonf[ooi80
oookJ_oo0?co603oool60?o[o`3oZ03oool0n@;o07Oo00?oof`0o`3kool0nol00_oonfX01Ol0Xooo
/ol0ok?o0?nco`3ooo]Z00?o0?oN1?oo06`3o`3ogP04oookJ_nco`3o/ol0o`2So`;ooo]Z00Oo0000
oom/0?oo0?Ko603oool60?oo0?cooo]Z00;oo`3Z0_oonfX03Ol0Looooo]ZoookJ_nio`3ooe80o`3o
gol0S_oo0?lKooo:0?oo09?of_l0obH0oolPo`000_oonfX02_lao`3o0?m=o`H0oonBo`3o403oool0
DOoo07Wooo]Zo`3oDol0oad2oookJP05o`3oC_l0obko0:Woo`04ool0e?l00_oonfX01?ooP@3ooo]Z
oookJ_oo02d2oookJP04oomG0?oonf[oj`3ooonn00?ooo]Z00Gooi00o`1doolH0?oooo]ZofP0o`02
oookJP0Ao`3oT_oonf[ohP3ooookJ_mQ0?ooobh0odd0oooo06cooo]Zool0Qooonf[oW`3ook?o0?oo
0=goo`<0oookJ_l0nol00_oonfX01?lko`3o0?nJoom/0?l0Mol2oookJP0;ojP0oooo0?Kooo]Zon_o
0?oo1P3o603ooookJ_oo0?cooo]ZoonB0?oo5P001OoonfX00ooo0>[ooo]ZoookJP09oookJP03o`1c
oooonf[ooo]Z00Oooo]Z00Wooe80oookJ_oonf[o02[oocoo0?oonf[o0=coogSo0?l0oml01_oonfX0
1?l0oa_ooo]ZoookJ_oobP02oookJP03o`3ioooo09?oo`0C00Gooo]Z00Kof_l0oookJ_oonf[ooo]Z
oh@0oolV0?l>oookJP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00_oP_l0oookJ_l0ok7o033oo`3Xool0
odgooo]Zo`H0oooonf[oo`3eoi;o0003oookJP03oa00ool06Ooooo]Z00?ooo]Z00Koo`1AoookJ_oo
nf[ooo]Zo`2]oooo07TZoookJP00:_oonfX02?l0Mooooo]ZodCo0?l0oi[o0?o<oookJ_ooP@3o>ol0
1?oonfX01Ol0nooooo]ZoookJ_oonf[oo`<000?ooo]Z00CoiOl0oookJ_l0Xooo/ol01OoonfX00ol0
omkoo`27oookJP02oookJP04ool0K?oonf[ooo]Zodd0o`;ooo]Z00?oH@3oo`3oAOoonfX00_oonfX0
1OoR0?oo0?n@oookJ_oonf[o0?nB00Kooo]Z00KoJ03ooookJ_oonf[ooo]ZoaP0oooVo`02oookJP03
onGo0?oonf[ooo]Z00Oooo]Z00Cookh0o`3o1Ooonf[oj`3o1OoonfX00oooE`3oU?l0oiCo0003oiCo
00Kooo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0e?oooo]Zo`3o3?oonf[o0:Wo00?ooo]Z00?o0?m>
o`3o=?oonfX01?oonfX00ol0oagooo]Zooo90006onGo0005ool0DOooN@3oogT0oa00oonBo`001?oo
N@000ooonf[o<Ol0oookJP06oookJP03ob3o0?lV0?oof_l000?oogT00_oonfX02_oobP3o0?lKoook
J_oonf[oN?l0ocoo0?l0:_oo0?lcoomB0?oonfX7oomi00;ooo]Z00Goo`3ZoookJ_oo5P3oobP0ool0
o002ool000?oobP01Ooo00000oooN@3oobP0oolX0002oolX0003o`2Soonco`3o/ol000;o/ol000?o
o`00o`3og_oob@003ooob@02oolX00;oo`0000GoobP0oomi0?ooN@3oogT0oomB0002ool000;oobP0
1?oob@06ool00003oi;o0?oo003oo`1A00;oo`0000Wo0?mCo`3o7Ol0hOooolT0o`3oC_oob@3oogT0
o`04ool0e?l00_oonfX01_ooP@3ooo]ZoookJ_oonf[oo`0]oookJP;oolT000?oj`3oooo90?oonfX0
0_oonfX00onDo`3ooi00oaP0o`02oiCo000<ofP0oooonf[ooo]Zo`3oT_l0oi3ohP3ooookJ_mQ0?oo
C@3oool0K?oonf[oo`270_oonfX03?nco`3oo`3MoookJ_oo0`3ooo]Zo`3koooonf[o>ol0oon10?oo
K03o07Ooool0n@;oolT000Gooo]Zool0m_o[o`3oo`H0oaP0o`02oookJP03ool0o?oonf[ooi8000Co
oo]Z00?oo`3ZoookJ_oonfX02OoonfX3onGo00Sooo]Z00[o^Ol0oomB0?oonf[ooo]ZoiCo0?loo`3o
0=cooookJ_mho`3o0?oO1OoonfX01?l0S_oo0?lKoookJ_oobP02oookJP04o`3ioooonf[oiOl0ool0
4`Cooo]Z00Oof_l0on7o0?oonf[ooo]ZobH0oon40?oo8?l000kooo]Z00?o<Ol0oookJ_l0oe/00_oo
nfX01_n2o`3o0?n`oookJ_l0<?ooiOl0o`3Xo`;ooo]Z00?o1P3ooookJ_nBo`000ooonfX00ol@0?oo
iOl0oookJP02oookJP03oaD0oooo057ooo]Z00;ooo]Z00?o0:gooookJ_oo07T0D?oonfX02?l0Mooo
oo]Zoom/0?l0oi[ooo]Zo`3oc?ooP@3o>ol01?oonfX01Ol0nooooo]ZoookJ_oonf[oo`<000?ooo]Z
00CoN@3oool0gOoonf[o/ol01OoonfX00ol0omkooo]Zool0Q`03oookJP07ool0K?oonf[oC@3oool^
0?oonf[oH@3oo`3oA@03oookJP05on80ool0oi3ooo]ZoookJ_l0oi801ooonfX01_mX0?oooo]Zoook
J_lH0?oo07CoonKo00;ooo]Z00?ooi00oookJ_oonfX01ooonfX00ooo_P3o0?l5on/0o`05oookJP03
oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP03oookJP05
o`3Doooonf[o00CooookJ_l0ZOl00ooonfX00ol0odko0?ldoookJP04oookJP03o`3Qool0oago0?mC
00Cooo]Z00koo`1io`2]oooo057ooo]Zo`0Iool@0?ooo`3eoi;o0?l0odgo0>Soo`0`oon2o`3o0?mK
oc7o00Kooo]Z00[o8?l0obH0oooJo`3ohOl0oookJ_oo01?oo`2CoookJ_oobP3o0?lK0_oonfX01_mh
o`3o0=cooookJ_l0:_oooe80okWo00?ooo]Z00?o07?ooookJ_oonfX01?oonfX02Ooo0>[ooaH0oonB
0?oonf[oo`3loaP0oooo1P3ojol0oookJP02ool0n@03o`1gooooK03o0?nJ00;o0?_o0ooonfX00ol0
Xooo/ol0ok?o0002ok?o0005oookJ_l0omko0?oNo`3og_l0Xol00onco`04oookJP;oof`000Koo`3f
oaP0oooo1P3oo`3loonB0?oo0>X4oookJP0<o`1coooonf[ooo]ZoomB0?lm0?oo0?oOo`3o6ooobP3o
o`2Com[o0?lV0?oo8?l00_oonfX02olao`3o0?mKo`3oCOnBo`3o403oo`0Ioooo057oo`1io`3oDol0
oago0>7o00;ooo]Z00Oo0?m>o`28ool0ZOoo00Coo`3Doooonf[ooh4000?ooo]Z00Ooo`0]oookJ_oo
E`3ooo]Zog00ooo[0?oookh000?ooo]Z00Gooi00oaP0oooVo`3ooo]ZofP0o`02oookJP0To`3oT_l0
oi3ohP3ooookJ_mQ0?ooC@3oool0K?oonf[oo`27o`3og_oonf[o/ol0ool0gOmi0?ooo`<0oookJ_l0
nooooo]Zoc_o0?ooP@3oof`0o`1goooo0?Wooo]ZojP0ool0Y_ooo`3fon_o0?oo1P3ooo]ZoaP0oooo
nf[oo`3loookJ_ooTP3ooaH01?oonfX00ooo0>[ooo]ZoookJP0:oookJP03o`1coooonf[ooo]Z00Oo
oo]Z00Wooe80oookJ_oonf[o02[oocoo0?l0g?oooo]ZogSo0?l0oml01_oonfX00ol0oa_ooo]Zooo:
0003oookJP03o`3ioooo09?oo`0C00Gooo]Z00Kof_l0oookJ_oonf[ooo]ZobH0oolPo`0>oookJP04
oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00GoP_l0oookJ_l0ok7o033oo`3oC@02oookJP04o`H0oooonf[o
o`3eoi;o00;ooo]Z00?oo`1Zoa00oooonfX00ooonfX00olE0?ooo`1AoookJP02oookJP03o`2]oooo
07Wooo]Z02Wooo]Z000ZoookJP08o`1goooonf[oA?l0o`3oV_l0olcooo]Zoon10?lko`04oookJP05
o`3koooonf[ooo]ZoookJ_oo0`000ooonfX01?oUo`3ooo]Zo`2Soonco`05oookJP03o`3og_oo08Oo
oo]Z00;ooo]Z00Coo`1/oookJ_oonf[oC@3o0_oonfX00omQ0?oo0?m5oookJP02oookJP05on80ool0
oi3ooo]ZoookJ_l0oi801_oonfX02OmX0?oooo]ZoookJ_oonf[o603oo`1doooVo`3ooo]ZonGo0009
oookJP04oonn0?oonf[o0?l5on/0o`Gooo]Z00?ooeL0oookJ_oonfX00_oonfX00onDo`3ooo]Zoook
JP04oookJP03oon10?oonf[ooo]Z00Cooo]Z00Go0=CooookJ_l0o`cooo]Zo`2Yo`03oookJP03o`3o
C_l0ocCooo]Z00Cooo]Z00Co0>7oo`3o7Ooob@3oolT01OoUo`001Ooo057oiOl0oomi0?l@0?ooT_l0
00CoogT000?ooo]Zo`3oFolao`001_oonfX01_lPo`3o9P3ooookJ_oJo`3ooo]Zool0T`;ooo]Z00?o
olX0o`3o6ooonfX00_oonfX01Omho`3o?ol0o`0ZooooDP3ooo]Z00OoogT00ooonfX01?oo0>[ooo]Z
oolX0?oo:002ool0o0;oo`H00_oo:006ool000KoobP000?oo`00o`2Soonco`004Ooob@03oolX0006
ool00?ooN@3oogT0oomi0?ooDP3oogT00_oo00000ooo:03oolX0ooo90002ooo900Ooo`0000OoT_l0
ool0DOoo003oo`00o`3oDol0oago0>7o00;oolT000Go0?m>oomi0?ooN@3o0=Coooo90002oookJP04
oon10?oonf[ooo]Zool0;@;ooo]Z0_oob@002_o[0?ooolT0ooo90?oob@3ooo]Zoon@0?nDo`3o603o
oiCo0?mX0?l3oookJP0Go`3oT_oR0?oooo]Zo`3oAOmQ0?ooC@3oool0K?oo08Oo0?oNoookJ_nco`3o
0:?oool0gOoonf[oo`<0oookJ_l0nooooo]Zoc_o0?ooP@3ooo]Zo`1goooo0?T00_oob@001?oonf[o
jol0oookJ_oo1P03oookJP03ool0o?oonf[ooi8000Cooo]Z00?oo`3ZoookJ_oonfX02OoonfX3onGo
00Oooo]Z00?o^Ol0oookJ_ooDP000_oonfX01OnDo`3o?ol0o`3Loomho`3o0?oO00Kooo]Z00Co0?lK
oa80oooonf[oolX00_oonfX00ol0nOoooo]ZonGo0004oookJP03om[o0?oQo`3ooo]Z00;ooo]Z00?o
9P3oob3o0?oonfX03OoonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP08oh;o0?oonf[ooo]Zo`0`oooU
o`3o0>SooookJ_l60?l2oookJP06oi;o0?oonf[ooo]ZoookJ_l@0?ooiOl00ooonfX00olE0?ooo`1A
oookJP02oookJP03o`2]oooo07Wooo]Z053ooo]Z00So07OooookJ_ooK03o0?nJoookJ_l0olcooh40
oc_o00Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30003oookJP04ogT0oooo0=gooo]Zok?o00Gooo]Z
00?ogOl0o`3og_oo08L00ooonfX01ooo06cooo]Zodd0oooo;P3ooo]Zof40ool0odD00ooonfX01OoR
0?oo0?n@oookJ_oonf[o0?nB00Oooo]Z00KoJ03ooookJ_oonf[o603oo`1doooVo`02oookJP03oon@
0?oonf[ooo]Z00Oooo]Z00Cookh0oookJ_o[0?ooL03o1?oonfX00oooE`3ooo]ZoookJP02oookJP03
ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX00ooonfX01_l0e?oooo]Zo`04oooonf[o08So
o`2Yo`?ooo]Z00?o0?m>oookJ_oonfX01?oonfX00ol0oago0?mCoookJP03oookJP0>ool0NOl0[Ooo
o`1AoaD0ool06Ooo403ooookJ_nBo`3ooo]Zo`3oCOl0<?ooP_l0o`3oFolao`07oookJP03obH0oooo
nf[of_l000;ooo]Z00Coo`2CoookJ_oobP3o0?lK0ooonfX01Omho`3o0=coo`0ZooooDP3o^Ol000?o
oo]Z00?o07?ooookJ_oonfX01OoonfX01_oo0>[ooaH0oonB0?oonf[oo`3loaP0o`;oo`H000?oo`3f
ojP0oooo0?T00_l0Mol01?ooK03o0?nJo`3kool0nol5oookJP03o`2Soonco`3o/ol000?o/ol01?oo
nfX3oom/00;oo`3f0_oo1P000ooo0?cooaH0ool0jP04oookJP0=o`1coooonf[ooo]ZoomB0?l0:_oo
N?l0o`3o6ooonf[oolX0om[o0?oQo`3o9P3oob3o0002oookJP0:oc7o0?l0odgo1P3ooi;o0?l06Ooo
o`1Aool0NOoonf[o0?mCo`3o7@;ooo]Z00Go0?ldo`3oC_l0ZOoo00Coo`3Do`02oookJP04oon10?oo
nf[ooo]Zool0;@;ooo]Z00CooeL0oookJ_o[0?oookh00ooonfX01OooT03ooo]ZoaP0oooVo`3oJ03o
00?ooo]Z00Wo0?nBon80oooonf[o0?m5of40oom=0?ooo`1/oookJ_oo08L00_oonfX04onco`3oo`3M
ogT0oooo0`3ooo]Zo`3koooonf[o>ol0oon10?ooK03o07Ooool0nOoonf[oZ03oo`2Voooo0?Kojol0
ool60?lH0?l00_oonfX01?oo0?cooo]ZoonB0?oo5P04oookJP03ool0j_oonf[ooo]Z00[ooo]Z00?o
07?ooookJ_oonfX01_oonfX02_nio`3ooe80oookJ_oonf[o02[oocoo0?l0g?ooN?l0o`3ogolm0?l6
oookJP03o`3o6ooonf[oolX000?ooo]Z00?o0?Woool0Tooo01<01?oonfX00ooJo`3ooo]ZoookJP02
oookJP03obH0oolPo`3ooo]Z00gooo]Z00Co<Ol0oookJ_oonf[o0?mK0_oonfX01On2o`3ooo]Zo`3o
/Ol0<?oo0?m=00;ooo]Z00Co1P3ooookJ_oo0?GoT_l00_oonfX00ooo06[o403ooookJP03oookJP03
ool0DOoonf[ooo]Z00;ooo]Z00?oo`1ioookJ_oonfX0:OoonfX002[ooo]Z00So07OooookJ_ooK03o
0?nJo`3oc?oonf[ooh40oc_o00Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30003oookJP04onGo0?oo
nf[o0:?ook?o00Gooo]Z00?ogOl0ool0QooonfX00_oonfX01?oo06cooo]ZoookJ_m=0?l2oookJP03
of40ool0odGooo]Z00;ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP09ofP0oooonf[ooo]Z
oookJ_lH0?oo07CoonKo0?oonf[oiOl000Wooo]Z00Cookh0oookJ_l0o`Goj`3o1OoonfX00oooE`3o
oo]ZoookJP03oookJP03oiCo0?oonf[ooo]Z00?ooo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0e?oo
oo]Zo`3o3?oonf[o0:Wo00?ooo]Z00?o0?m>o`3o=?oonfX01?oonfX01?l0hOoo0?lMooo90?oob@04
onGo0006o`2]oooo057oogT0oomi0?l@0?ooT_l01OooN@000ol0oe_o<Ol0oookJP05oookJP07oh@0
oooUo`3ooo]Zom[o0?oonf[oo`0Cool0T`02oookJP09o`3o6ol0S_oooo]ZoookJ_mho`3o?ol0o`0Z
ooooDP3o^Ol000SoogT00_oonfX00ooo0>[ooo]ZoolX0002oolX0004oookJ_oo0?co603oool600;o
obP01ooo0008oolX00Koo`001_oo:0000ooo0?coobP0oolX0005oolX00;oogT000Oooe80oomi0?oo
:03oogT0ool00?l0oa_oo`2C00?oolT01Ooo00001?l0odgoT_l0oa00oooo0542ool00009o`3oDol0
oago0>7oooo90?l0odkoolT0oomi0?l01?oo0=Co00;ooo]Z00Kooh40oookJ_oonf[ooo]Zool0;Ooo
nfX3ooo90003on/0oooob@3oolT000;oolT000Gooi00onKo0?lH0?ooU?l0ofP0o`03oookJP0@o`3o
T_oR0?oooo]Zof40oom=0?ooo`1/oookJ_oo08Oo0?oNoookJ_nco`3oo`3MoookJ_oo0`3ooo]Zo`3k
o`;ooo]Z00_o>ol0oom/0?oonf[o07OooookJ_oob@3o0:Koool0m_o[o`3ooo]Zool60003oookJP03
ool0o?oonf[ooi8000Cooo]Z00?oo`3ZoookJ_oonfX02OoonfX2onGo00Sooo]Z00?o^Ol0o`3o<ooo
DP000_oonfX01OnDo`3o?ol0o`3Loomho`3o0?oO00Kooo]Z00Co0?lKoookJ_oonf[oolX00_oonfX0
0ol0nOooiOl0ool04`04oookJP03om[o0?oQo`3ooo]Z00;ooo]Z00?o9P3oob3o0?oonfX03OoonfX0
1?lao`3ooo]ZoookJ_l0oe/2oookJP08oh;o0?oonf[o0?nao`0`oooUo`3o0>SooookJ_l60?l2oook
JP06oi;o0?oonf[ooo]ZoookJ_l@0?ooiOl00ooonfX00olE0?ooo`1AoookJP02oookJP03o`2]oooo
07Wooo]Z053ooo]Z00So07OooookJ_ooK03o0?nJoookJ_l0olcooh40oc_o00Cooo]Z00Go0?_ooook
J_oonf[ooo]Zool30003oookJP04ogT0oooo0=gooo]Zok?o00Gooo]Z00?ogOl0o`3og_oo08L00ooo
nfX01ooo06cooo]Zodd0oooo;P3ooo]Zof40ool0odD00ooonfX01OoR0?oo0?n@oookJ_oonf[o0?nB
00Oooo]Z00KoJ03ooookJ_oonf[o603oo`1doooVo`02oookJP03oon@0?oonf[ooo]Z00Oooo]Z00Co
okh0oookJ_o[0?ooL03o1?oonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Cooo]Z
00?ooh40oookJ_oonfX01?oonfX01Ol0e?oo00CooookJ_l0R?oo0:Wo00?ooo]Z00?o0?m>oookJ_oo
nfX01?oonfX00ol0oago0?l8o`3oD`03oookJP0>ool0NOl0[Oooo`1AoaD0ool06Oooo`1Zoa00oonB
o`3o1P3oo`3oCOl0<?ooP_l0o`3oFolao`07oookJP03obH0oooonf[of_l000;ooo]Z00Goo`0Cool0
Tooonf[oolX0o`3o6`02oookJP05ogSo0?l0g?oooo]ZoomB0?l0oc<01?oonfX00ol0Looooo]Zoook
JP04oookJP0>ool0j_oonf[ooo]ZoonB0?oonf[oo`3loaP0oooonf[oo`H0on_o0?l0Y_ooZ03oool0
nOl0Mol2oom/0003oookJ_l0nooo0?_o00;o0?_o1OoonfX4o`3ko`;oof`00_oonfX01ooo0?Koo`H0
ool60?l0003oo`3loolF0?oo0>X00ooonfX2o`1co`;ooo]Z00[ooe80o`0Zool0omooN?l0o`3o6ooo
bP3oo`0Com[o0?lV0?oo8?l00_oonfX02olao`3oP_l0o`3oCOnBo`3o403oo`0Ioooo057oo`1io`3o
Dol0oago0>7o00;ooo]Z00Oo0?m>o`3o;_l0ZOoo00Coo`3Doooonf[ooh4000?ooo]Z00Ooo`0]oook
J_oonf[ooeL0og00ooo[0?oookh000?ooo]Z00Gooi00o`1doolH0?oooo]ZofP0o`03oookJP0@o`3o
T_oR0?oooo]Zof40oooo;P3oC@3oool0K?oonf[oo`27oookJ_nO0?oo/ol0ool0gOoo0`3ooo]Zo`3k
o`;ooo]Z00co>ol0o`3oV_ooK03o07Ooool0nOoonf[oZ03ooookJ_oo0?Kojol0ool60?lH0?l2oook
JP04ool0o?oonf[ooi80oolF00Cooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ol0Looooo]ZoookJP07
oookJP09o`3o<oooDP3ooo]ZoookJ_l0:_oo?ol0o`3Loomho`3o0?oO00Oooo]Z00?o0?lKoookJ_oo
bP000ooonfX00ooo09?ooo]Zool04`04oookJP03om[o0?oonf[ooo]Z00;ooo]Z00?o9P3ooookJ_oo
nfX03OoonfX00olao`3ooo]Zo`3oF`03oookJP05oh;o0?l0ok7ooo]Zo`0`ool0odd00_oonfX01?l6
0?oooo]Zool0mOnBo`02oookJP03ool0J_l@0?oooo]Z00?ooo]Z00?oo`1AoookJ_oonfX00_oonfX0
0ooo07Wooo]ZoookJP0YoookJP00:_oonfX02?l0Mooooo]Zoom/0?l0oi[o0?o<oookJ_ooP@3o>ol0
1?oonfX01Ol0nooooo]ZoookJ_oonf[oo`<000?ooo]Z00CoiOl0oookJ_l0Xooo/ol01OoonfX00ooM
o`3oo`27oookJP02oookJP04ool0K?oonf[ooo]Zodd0o`;ooo]Z00?oH@3oo`3oAOoonfX00_oonfX0
1OoR0?oo0?n@oookJ_oonf[o0?nB00Kooo]Z00WoJ03ooookJ_oonf[ooo]ZoaP0ool0M?ooi_l0oook
J_oUo`002OoonfX01Ooo_P3ooo]Zo`3o1Om`0?ooj`3o00Cooo]Z00?ooeL0oookJ_oonfX00ooonfX0
0onDo`3ooo]ZoookJP03oookJP03oon10?oonf[ooo]Z00Gooo]Z00Go0=Coo`3o3?oonf[o0:Woo`28
o`02oookJP03o`3oC_oonf[o0?ld00Cooo]Z00?o0>7oo`3o7Ooob@000_oob@02oookJP06onGo0?l0
[Oooo`1Aoomi0?l06Ooo403o1_ooN@000ol0oe_o<Ol0oookJP06oookJP06onGo0?oonf[of_l0oook
J_oo01?oo`2C0_oonfX02OoobP3o0?lKoookJ_oonf[oN?l0ocd0oooonf[o02[ooomB0009oomi00;o
oo]Z00Soo`3ZoolX0?oonf[ooi80oolF0?oonf[oo`3loomi00;oo`H000?oobP0ool00?oo00004?oo
0006oolX00;oo`3l1ooo:002oomi0003oomB0?ooN@3oogT000;oobP000?o0?lKool0Tooob@000ooo
b@04ool00009o`3oCOoo003oT_l0ool0DOoo:03oo`00o`3oDol0oago0>7o00;oolT000Co0?m>ooo9
0?ooN@3o0=Co0ooonfX01?ooP@3ooo]ZoookJ_oo02d2oookJP;oolT000?oj`3oooo90?oob@000ooo
b@001OooT03o603ooiCo0?nDo`3oJ03o00;ooo]Z01ko0?nBoookJ_oR0?oooo]Zof40oom=0?ooo`1/
oookJ_oo08Oo0?oNoookJ_nco`3oo`3MoookJ_oo0`3ooo]Zo`3koooonf[o>ol0oon10?ooK03o07Oo
ool0nOoonf[oZ03oo`2Voooo0?Kojol0ool60?lH0?l2oookJP04ool0o?oonf[ooi80oolF00Cooo]Z
00?oo`3ZoookJ_oonfX02OoonfX2onGo00Sooo]Z00[o^Ol0oomB0?oonf[ooo]ZoiCo0?oonf[o?ol0
o`3Loomho`3o0?oO1_oonfX01?l0oa_ooo]ZoookJ_oobP02oookJP03o`3ioooUo`3oo`0C00Cooo]Z
00?of_l0on7o0?oonfX00_oonfX00olV0?oo8?l0oookJP0=oookJP03oc7o0?oonf[o0?mK00?ooo]Z
00GoP_l0oookJ_l0ok7o033oonGo0002oookJP03o`H0oooonf[oT_l000Cooo]Z00?o403oonGo0?oo
nfX00_oonfX01olE0?ooo`1AoookJ_oonf[o0:gooookJ_oo07T0DOoonfX02?l0Mooooo]Zoom/0?l0
oi[ooo]Zo`3oc?ooP@3o>ol01?oonfX01Ol0nooooo]ZoookJ_oonf[oo`<000?ooo]Z00CoN@3oool0
gOoonf[o/ol01OoonfX00ooMo`3o0?oNool0Q`03oookJP07ool0K?oonf[oC@3oool^0?oonf[oH@3o
o`3oA@03oookJP05on80ool0oi3ooo]ZoookJ_l0oi801ooonfX01_mX0?oooo]ZoookJ_lH0?oo07Co
onKo00;ooo]Z00?ooi00oookJ_oonfX01ooonfX01?oo_P3ooo]Zo`3o1Oo[0?l4oookJP03oomG0?oo
nf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3ooo]ZoookJP04oookJP05o`3Dool0
1?oooo]ZoookJ_l0ZOl00ooonfX00ol0odko0?ldoookJP04oookJP03o`3Qool0oago0?mC00?ooo]Z
00ooo`1io`2]oooo057o5@3oo`0Ioooo06[o403ooi;o0?l60?oo0?m=o`0`oon2o`3o0?mKoookJ_la
o`001_oonfX00olV0?oooo]Zom[o0002oookJP05ool04ooo09?ooo]Zooo:0?l0oa/00_oonfX01_mh
o`3o?@3ooookJ_l0:_oooe80okWo00Cooo]Z00?o07?ooookJ_oonfX01?oonfX01_oo0>[ooo]Zoook
J_ooTP3ooo]Zool0o0;o603o0_oo1P001?o[o`3oZ03oo`2Vool0Mol2ool0n@04oom/0?l0oi[o0?nJ
oookJPGo0?_o0oooK003oookJP04ool0m_oo1P3oo`H0oaP0o`;oo`3l00?o0000ool0j_oonfX00_oo
nfX03_l0Looooo]ZoookJ_nio`3ooe80o`0Zool0omooN?l0o`3o6ooobP3oo`0Com[o0?lV0?oo8?l0
0_oonfX02olao`3o0?mKo`3oCOl60?ooT_l0o`0Ioooo057oo`1ioookJ_l0oe?o0?lM00;ooo]Z00Go
0?ldo`3oC_l0R?oo00Coo`3Do`02oookJP0;oon10?oonf[ooo]ZoookJ_oo02gooo]ZoomG0?oonf[o
j`3oo`3o1Ooo_P000ooonfX01OooT03o603oonKo0?oonf[oJ03o00;ooo]Z01Oo0?nBoookJ_oR0?oo
oo]Zof40oom=0?oooo]Zool0K?oonf[oo`27oookJ_nO0?oo/ol0ool0gOoo0`3ooo]Zo`3koooonf[o
>ol0oon10?l0oi[o07Ooool0n@02oookJP0;ojP0oooo0?Kojol0ool60?oonf[o603ooookJ_oo0?co
oo]ZoonB0?oo5P001OoonfX00ooo0>[ooo]ZoookJP09oookJP03o`1coooonf[ooo]Z00Oooo]Z00Wo
oe80oookJ_oonf[o02[ooookJ_loo`3o0=coogSo0?l0oml01_oonfX01?l0oa_o08kooookJ_oobP02
oookJP04o`3ioooo09?ooo]Zool04`Cooo]Z00Kof_l0oookJ_oonf[ooo]ZobH0oolPo`0?oookJP03
oc7o0?oonf[o0?mK00;ooo]Z00_o0?n`oh;o0?l0ok7ooo]Zo`0`ool0odgooo]Zo`H0oooonf[oo`3e
oi;o0003oookJP03ool0J_l@0?oooo]Z00?ooo]Z00Koo`1AoookJ_oonf[ooo]Zo`2]oooo07T[oook
JP00:_oonfX02?l0Mooooo]Zoom/0?l0oi[o0?o<oookJ_ooP@3o>ol01?oonfX01Ol0nooooo]Zoook
J_oonf[oo`<000?ooo]Z00CoiOl0oookJ_l0Xooo/ol01OoonfX00ooMo`3o0?oNool0Q`02oookJP04
ool0K?oonf[ooo]Zodd0o`;ooo]Z00?oH@3oo`3oAOoonfX00_oonfX01OoR0?oo0?n@oookJ_oonf[o
0?nB00Kooo]Z00WoJ03ooookJ_oonf[ooo]ZoaP0ool0M?ooi_l0oookJ_oUo`002_oonfX01?oo_P3o
0?l5og00ooo[0?l4oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oU?l0oookJ_oonfX00ooonfX00ooo
P@3ooo]ZoookJP05oookJP05o`3Dool0o`cooo]Zo`2Yool0R?l00_oonfX00ol0obko0?m>o`3o=005
oookJP04o`3o7Ooob@3oolT0ooo900;ooo]Z00KoiOl0o`2]ooooN@3oo`1Aoomi0?l@0?l7oomi0003
o`3oFolao`3ooo]Z00Gooo]Z0_oUo`002?oonf[of_l0oookJ_oo01?oo`2CoookJ_oobP3o0?lK0ooo
nfX01Omho`3oA?l0o`0ZooooDP3oolT000GoogT000?o07?ooookJ_oonfX00ooonfX2ool0jP05oook
J_ooTP3ooaH0oookJ_oo0?`00_oo:0000ooo1P3oobP0ool0000?ool000GoobP00_oo0?`9oolX0004
oomi0?ooDP3oogT0oomi00;oobP000?o0?lKoolX0?oo09<00ooob@04ool00005o`3oCOoo003oT_l0
oa00oooo05400_oo:0001Ol0oe?o0?lMooo90?oob@3o0?m>00;oolT000Go00Coo`3Doooonf[ooo]Z
oon10003oookJP03ool0;Ooonf[ooo]Z00;oolT000?oj`3oooo90?oob@000_oob@001_ooT03oU?l0
oaP0oonDo`3ooo]ZofP0o`;ooo]Z01go0?nBon80oooonf[o0?m5of40oooonf[oo`1/ool0Qol0omko
oo]Zooo90?nco`3oo`3MoookJ_oo0`3ooo]Zo`3koooonf[o>ol0oon10?ooK03o07Ooool0nOnX0?oo
0:KooookJ_o[o`3ooo]Zool60003oookJP03ool0o?oonf[ooi8000Gooo]Z00?oo`3ZoookJ_oonfX0
2OoonfX2onGo00Oooo]Z00?o^Ol0oookJ_ooDP000_oonfX01_nDo`3ooo]Zocoo0?l0g?ooN?l0o`3o
g`Kooo]Z00Co0?lKoookJ_oonf[oolX00_oonfX00ol0nOooiOl0ool04`04oookJP07om[o0?oQo`3o
oo]ZoookJ_lV0?ooQ03oob3o000>oookJP03oc7o0?oonf[o0?mK00?ooo]Z00GoP_l0oookJ_l0ok7o
033oonGo0002oookJP03o`H0oooonf[oT_l000Cooo]Z00?o403ooookJ_oonfX00_oonfX01ooo057o
oo]ZoookJ_oonf[o0:gooookJ_oo07T0DOoonfX02?l0Mooooo]Zoom/0?l0oi[ooo]Zo`3oc?ooP@3o
>ol01?oonfX01Ol0nooooo]ZoookJ_oonf[oo`<000?ooo]Z00CoN@3oool0gOoonf[o/ol01OoonfX0
0ooMo`3o0?oNool0Q`03oookJP07ool0K?oonf[oC@3oool^0?oonf[oH@3oo`3oA@03oookJP05on80
ool0oi3ooo]ZoookJ_l0oi801ooonfX01_mX0?oooo]ZoookJ_lH0?oo07CoonKo00;ooo]Z00?ooi00
oookJ_oonfX02?oonfX00ooo_P3o0?l5on/0o`04oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]
oookJ_oonfX01?oonfX00oooP@3ooo]ZoookJP04oookJP05o`3Dool01?oooo]ZoookJ_l0ZOl00ooo
nfX00ol0odko0?ldoookJP04oookJP03o`3Qool0oago0?mC00?ooo]Z00ooo`1io`2]oooonf[oo`1A
oookJ_l06Ooo403ooi;o0?l60?oo0>Soo`3oCOl0ok7oP_l0o`3oFolao`001_oonfX01?lPo`3o9P3o
oookJ_oJo`02oookJP04ool0Tooonf[oolX0o`3o6`?ooo]Z00GoN?l0o`3Lool0:_oooe80okWo0005
oookJP03o`1coooonf[ooo]Z00Cooo]Z0_oo0>X01Ooonf[ooi80oookJ_oo0?cooo]Z00;o603o00?o
o`H0on_o0?oonfX00_l0Y_l01?oonf[oo`3iool0nOoo0?T6oom/00?ooo]Z0_oo0?H2ool600?oo`3l
00Cooi80ool0j_oo0>[o00000_oonfX00ol0Looooo]ZoookJP02oomB0009o`0Zoolm0?ooN?l0o`3o
6ooobP3oo`2Con7o0?oJo`3o9P3o00?ooo]Z00Oo<Ol0oh;o0?l0odgoT_l0oa00oolE0?ooo`1A00;o
oo]Z00_o0?mCoookJ_oonf[ooo]Zo`3oC_l0R?oo0:Woo`04ool0e?oooo]Zoon10003oookJP07ool0
;Ooonf[ooo]ZoomG0?m`0?ooj`3ooonn0003oookJP03oon@0?oonf[o603o00;ooo]Z00coJ03ooook
J_oonf[o0?nBon80oooonf[o0?m5of40oom=0?ooo`1/oookJ_oo08L2oookJP0Coil0oonco`3oN@3o
ool30?oonf[o0?_ooookJ_lko`3ooh40o`3oV_l0Moooo`3ioookJ_nX0?oo0:Koool0m_o[o`3oo`H0
oaP0o`02oookJP04ool0o?oonf[ooi80oolF00Cooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ol0Looo
oo]ZoookJP06oookJP0:okWo0?ooDP3ooo]ZoookJ_l0:_oooo]Zocoo0?l0g?ooN?l0o`3og`Kooo]Z
00Co0?lKo`2>oooonf[oolX00_oonfX01?l0nOooo`2CoookJ_oo01<4oookJP06om[o0?oonf[ooo]Z
oookJ_lV0?oo8?l03ooonfX00olao`3ooo]Zo`3oF`02oookJP0;oh;o0?oonf[o0?naoookJ_l0j?oo
0?m=oookJ_l60?oooo]Zool0mOnBo`000ooonfX00ooo06[o403ooookJP03oookJP06ool0DOoonf[o
oo]ZoookJ_l0[Oooo`1i:ooonfX002[ooo]Z00So07OooookJ_ooK03o0?nJo`3oc?oonf[ooh40oc_o
00Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30003oookJP04onGo0?oonf[o0:?ook?o00Kooo]Z00Go
0?oNool0Qooonf[ooo]Zool0K002oookJP05odd0oooonf[ooo]Zof40ool0odD00ooonfX01OoR0?oo
0?n@oookJ_oonf[o0?nB00Kooo]Z00WoJ03ooookJ_oonf[ooo]ZoaP0ool0M?ooi_l0oookJ_oUo`00
2_oonfX01?oo_P3o0?l5oookJ_o[0?l4oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oU?l0oookJ_oo
nfX00ooonfX00oooP@3ooo]ZoookJP05oookJP05o`3Dool01?oooo]ZoookJ_l0ZOl00_oonfX00ol0
obko0?m>o`3o=005oookJP03o`3Qoooob@3oolT000;oolT000Oooo]ZonGo0?l0[Ooo5@3oool0DOoo
N@3o403o00OoogT000?o0?mKoc7o0?oonfX01OoonfX3onGo0004om[o0?oonf[oo`0Cool0T`;ooo]Z
00So0?lKo`2>oooonf[ooo]Zo`3ogomho`3o02[ooomB00;oolT01?oonfX00ol0Looooo]ZoookJP05
oookJP06ool0j_oonf[ooi80oolF0?oonf[oo`3l0_oo:002ool600goo`001Ooo:002ool0o0OoobP0
00GoiOl0oolX0?oo:03oogT0oomB0002oomi00;oobP000?o0?lKoolX0?oo:0001?oob@04ool00009
o`3oCOoo:03oT_l0ool0DOoo:03oo`00o`3oDol0oago0>7o00;oolT000Co0?m>ooo90?oob@3o0=Co
0ooonfX01?ooP@3ooo]ZoookJ_oo02d2oookJP03oomG0?oob@3oj`3o00CoolT000Kooo]Zoon@0?oV
o`3o603ooiCo0?mX0?l3oookJP0>o`3oT_oR0?oooo]Zo`3oAOmQ0?ooo`1/oookJ_oo08Oo0?oNoook
J_nco`3o0:?oool0gOoo0`02oookJP0=o`3koooonf[o>ol0oom/0?oonf[o07OooookJ_nX0?oo0:Ko
ool0m_o[o`3ooo]Zool60003oookJP03ool0o?oonf[ooi8000Cooo]Z00?oo`3ZoookJ_oonfX02_oo
nfX00ooUo`3ooo]ZoookJP06oookJP03okWo0?oonf[ooe8000;ooo]Z00KoU?l0ocoo0?l0g?oooo]Z
ogSo0?l0oml6oookJP04o`3o6ooonf[ooo]Zooo:00;ooo]Z00?o0?WoonGo0?oo01<01?oonfX01_oJ
o`3ooo]ZoookJ_oonf[o9P3oob3o00oooo]Z00?o<Ol0oookJ_l0oe/00_oonfX01_n2o`3o0?n`oook
J_l0ok7oiOl0o`3Xo`;ooo]Z00?o1P3ooookJ_nBo`000ooonfX00ooUo`3o403ooookJP03oookJP07
ool0DOoonf[ooo]ZoookJ_l0[Ooooo]Zool0N@1AoookJP08o`1goooonf[oof`0o`3oV_oonf[o0?o<
oon10?lko`04oookJP05o`3koooonf[ooo]ZoookJ_oo0`000ooonfX01?mi0?ooo`3MoookJ_nco`06
oookJP03o`3og_oo08Oooo]Z00;ooo]Z00Ooo`1/oookJ_m=0?ooobh0oookJ_mQ0?oo0?m500?ooo]Z
00GohP3oo`3oT?oonf[ooo]Zo`3oTP07oookJP09ofP0oooonf[ooo]ZoaP0ool0M?oooo]ZonKo0?oo
nf[ooi0000[ooo]Z00?ookh0o`3o1Oo[0?l01?oonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooo
nf[ooo]Z00Cooo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0e?oo00CooookJ_oonf[o0:Wo00?ooo]Z
00?o0?m>o`3o=?oonfX01?oonfX01?l0hOoo0?lMoookJ_l0oe<2oookJP0?ool0NOl0[Ooooo]Zool0
DOoonf[o01Wooa00oooonf[oT_l0o`3Xool0odgo033ooh;o0?l0oe_o<Ol000Oooo]Z00?o9P3ooook
J_oJo`000_oonfX01Ooo01?oo`2CoookJ_oobP3o0?lK00;ooo]Z00Ko0?oOogSo0?loo`3ooe80o`3o
<onio`04oookJP03o`1coooonf[ooo]Z00Kooo]Z00Goo`3ZoookJ_ooTP3ooo]Zool0o003oookJP?o
o`H000?oo`3fo`2Vool0Y_l00_l0Y_l00ooo0?Wooo]ZoookJP04oookJP04ool0m_oo1P3oo`H0ool6
00;oo`3l00Cooo]ZoonB0?oo0>[oo`3Z0ol000004?oonf[o07?ooookJ_oonf[ooe80o`0Zoolm0?oo
0=coogSo0?l0oa_oolX0ool0Tooonf[of_l0obH0oon40?l2oookJP0;oc7o0?l0oe_o0?m=o`H0oonB
o`3o01Woool0DOoo07Wooo]Zo`3oDol0oad00_oonfX01Ol0odko0?l^o`28ool01?oo0=Co00;ooo]Z
00_ooh40oookJ_oonf[ooo]Zool0;Ooonf[ooeL0oookJ_m`0?ooj`3ooonn0003oookJP05oon@0?l0
M?oo603ooookJ_mX0?l00ooonfX03_l0oi;ohP3ooookJ_l0odGoH@3oodd0oooo06cooo]Zool0Qooo
nf[oW`3ook?o0?oo0=goo`<00_oonfX03_l0nooooo]Zoc_o0?l0oi[oof`0o`1goooo0?Wooo]ZojP0
ool0Y_ooo`3fon_o0?oo1P3o603o0_oonfX01?oo0?cooo]ZoonB0?oo5P04oookJP03ool0j_oonf[o
oo]Z00[ooo]Z00?o07?ooookJ_oonfX01_oonfX02_nio`3ooe80oookJ_oonf[o02[oocoo0?l0g?oo
oo]ZogSo0?l0oml6oookJP04o`3o6ooonf[ooo]Zooo:00;ooo]Z00Co0?Woool0Tooonf[oo`0C0ooo
nfX00ooQo`3of_l0oookJP02oookJP03obH0oolPo`3ooo]Z00gooo]Z00Co<Ol0oookJ_oonf[o0?mK
0_oonfX01On2o`3ooo]Zo`3o/Ooonf[o0?m=00;ooo]Z00Co1P3ooookJ_oo0?GoT_l00_oonfX00ooo
06[o05gooa00o`04oookJP06ool0DOoonf[ooo]ZoookJ_l0[Oooo`1i:ooonfX002[ooo]Z00So07Oo
oookJ_oonf[oof`0o`3oc?oonf[ooh40oc_o00Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30003oook
JP04onGo0?oonf[o0:?ook?o00Kooo]Z00Go0?oNool0Qooonf[ooo]Zool0K002oookJP05odd0oooo
nf[ooo]Zof40ool0odD00ooonfX00ooR0?oooo]Zo`3oT002oookJP03o`3oT_oonf[ooo]Z00?ooo]Z
00WoJ03ooookJ_oonf[ooo]ZoaP0ool0M?ooi_l0oookJ_oUo`002_oonfX01?oo_P3ooo]Zo`3o1Oo[
0?l4oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oU?l0oookJ_oonfX00ooonfX00oooP@3ooo]Zoook
JP05oookJP05o`3Dool01?oooo]ZoookJ_l0ZOl00_oonfX00ol0obko0?m>o`3o=005oookJP03o`3Q
oooob@3oolT000;oolT00_oonfX01_oUo`3o0:goool0DOooN@3o01Wooa00o`OoogT000?o<Ol0oook
J_oonfX01?oonfX02_n40?ooiOl0onGo0?oUo`3ohOl0ool04oooN@3oo`2CoookJ_oobP02oomi0006
oookJ_l0omooN?l0odCo0?l0:_oooe800_oob@04oookJP03o`1coooonf[ooo]Z00Gooo]Z0_oo0>X2
oonB0003oolF0?ooN@3oogT000OoogT01ooo0003oolX00?oo`3l2?oo:002onGo0003oolX0?ooN@3o
oe8000?oogT000?oobP0o`3o6ooobP000_oo:003ooo9000=oookJ_oo003oo`00ool00?l0odgo1P3o
oi;o0?oo057oobP0ool00?oonf[o0?mCo`3o7@02ooo90005o`3oC_oob@3oolT0o`04ool0e?l00_oo
nfX01OooP@3ooo]ZoookJ_oonf[oo`0]00;ooo]Z00?ooeL0ooo90?o[0?l00ooob@02oookJP05oon@
0?lH0?ooU?l0oookJ_mX0?l00_oonfX07_l0oi;ohP3oo`3oT?oonf[oH@3oodd0oooo06coolT0ool0
Qol0omkooo]Zok?o0?oo0=gooo]Zool30?oonf[o0?_ooookJ_lko`3ooh40oom/0?l0Moooo`3ioook
J_nX0?oo0:Koool0m_o[o`3oo`H0oaP0o`?ooo]Z00?oo`3loookJ_ooTP001?oonfX00ooo0>[ooo]Z
oookJP0:oookJP03o`1coooonf[ooo]Z00Kooo]Z00_o^Ol0oookJ_ooDP3ooo]ZoiCo0?oonf[o?ol0
o`3Loomho`3o?@3oo`3og`05oookJP04oa80ool0oa_ooo]Zooo:00;ooo]Z00Co0?WoonGo0?oonf[o
o`0C1?oonfX01_oJo`3ooo]ZoookJ_oonf[o9P3oob3o00oooo]Z00?o<Ol0oookJ_l0oe/00_oonfX0
2?n2o`3ooo]Zo`3o/Ol0<?ooiOl0o`3Xoooonf[o1P3o0_oonfX01_nBo`3ooo]ZoookJ_oonf[o01Wo
oa00o`Cooo]Z00Ooo`1AoookJ_oonf[ooo]Zo`2]oooonf[oo`1i057ooo]Z00So07OooookJ_oonf[o
of`0oookJ_l0olcooh40oc_o00Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30003oookJP04ogT0oooo
0=gooo]Zok?o00Kooo]Z00?o0?oNool0QooonfX00_oonfX01ooo06cooo]Zodd0oooo;P3ooo]Zof40
ool0odD00ooonfX00ooR0?oooo]Zo`3oT002oookJP03o`3oT_oonf[ooo]Z00Cooo]Z00WoJ03ooook
J_oonf[o603oo`1doooonf[oi_l0oookJ_ooT0002_oonfX00ooo_P3o0?l5on/0o`04oookJP03oomG
0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3ooo]ZoookJP05oookJP04o`3D
oooonf[ooo]Zo`2Yo`?ooo]Z00?o0?m>o`3o=?oonfX01?oonfX01?l0hOoo0?lMoookJ_l0oe<3oook
JP0?ool0NOl0[Oooo`1AoookJ_l06Ooo403ooookJ_nBo`3o1P3oo`3oCOl0<?ooP_l0oookJ_l0oe_o
<Ol000Kooo]Z00[o8?l0obH0oooJo`3ohOl0oookJ_oo01?oo`2CoookJ_oobP3o0?lK0_oonfX01_l0
omooN?l0o`3Lool0:_oooe80o`3o<`Gooo]Z00?o07?ooookJ_oonfX01_oonfX01?oo0>[ooo]ZoonB
0?ooTP03ool0o0;ooo]Z00Co603oool60?oo1P3oo`H00_oo0?H3o`2Vo`03ool0m_lH0?oo603o00;o
o`H00ooo0?`3oonB0003ool0j_oonf[o000000?o000000oo07?ooookJ_oonf[ooe80o`0Zoolm0?oo
0=coogSo0?l0oa_o08koooo:0?oonf[of_l0obH0oolPo`000ooonfX01olao`3o0?m=o`3XoonBo`3o
403oool0DOoo07T00_oonfX02ol0oe?ooo]ZoookJ_l0ocCo0?m>oookJ_l0ZOoo00Coo`3Doooonf[o
oh4000Cooo]Z00Koo`0]oookJ_ooE`3ooo]Zon/0oooo_P04oookJP05oon@0?lH0?oooo]ZoookJ_mX
0?l00_oonfX05ol0oi;ooo]Zon80oooonf[oH@3oodd0oooonf[oo`1/oookJ_oo08Oooo]Zoil0oonc
o`3oo`3Mool30?oonf[o0?_ooookJ_lko`3ooh40o`3oV_l0Moooo`3i00;ooo]Z00KoZ03oo`2Vooo[
o`3oo`H0oookJ_lH0?l2oookJP04ool0o?oonf[ooi80oolF00Cooo]Z00?oo`3ZoookJ_oonfX02_oo
nfX00ol0Looooo]ZoookJP06oookJP0:okWo0?ooDP3ooo]Zo`0Zoooonf[o?ol0o`3Loomho`3o?@3o
o`3og`Kooo]Z00Co0?lKoookJ_oonf[oolX00_oonfX01?oo09?ooo]ZoookJ_oo01<3oookJP03on7o
0?oJo`3ooo]Z00;ooo]Z00?o9P3ooookJ_oonfX03OoonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP05
oh;o0?l0ok7ooo]Zo`0`ool0odd00_oonfX01?l60?oooo]Zool0mOnBo`02oookJP03ool0J_l06Ooo
403o00?ooo]Z00?oo`1AoaD0oooonfX00_oonfX00ol0[Oooo`1ioookJP0ZoookJP00:_oonfX02?l0
Mooooo]ZoookJ_ooK03o0?o<oookJ_ooP@3o>ol01?oonfX01Ol0nooooo]ZoookJ_oonf[oo`<000?o
oo]Z00CoiOl0oookJ_l0Xooo/ol01_oonfX01Ol0omkoo`27oookJ_oonf[oo`1/00;ooo]Z00GoC@3o
oookJ_oonf[oH@3oo`3oA@04oookJP05on80ool0oi3ooo]ZoookJ_l0oi801OoonfX02OmX0?oooo]Z
oookJ_oonf[o603oo`1doooVo`3ooo]ZonGo000:oookJP04oonn0?oonf[o0?l5on/0o`Cooo]Z00?o
oeL0oookJ_oonfX00ooonfX00onDo`3ooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Cooo]Z00Ko
0=CooookJ_l01?oooo]Zo`2Yool0R?l2oookJP03o`3oC_l0ocCooo]Z00Cooo]Z00?o0>7oooo90?oo
b@000ooob@001?oonf[oiOl0o`2]oooo0542oomi0003oa00ooooN@3oogT000GoogT000?o0?mKoc7o
0?oonfX01OoonfX3onGo0006om[o0?oonf[oo`0Cool0ToooN@3oolX00oooN@001_oonf[o0?oOogSo
0?l0:_ooolT0oomB00;oolT01?oonfX00ol0Looooo]ZoookJP06oookJP03ool0j_oonf[ooi8000;o
obP03_ooN@03ool0o0WoobP000?o0000onGo0?oUo`000_oUo`001oooDP3oogT0oomi0?ooN@3oobP0
o`3o6ooobP000_oo:003ooo9000>oolX0?oo003oo`00o`3oFol0odgo1P3ooi;o0?l@0?ooo`1Aool0
0?oonf[o0?mCo`3o7Ol0hOl2ooo90004o`3oC_oob@3o0:Woo`3Do`?ooo]Z00Cooh40oookJ_oonf[o
o`0]0_oonfX00oooE`3oolT0on/0o`04ooo90007oookJ_ooT03oi_l0oaP0oonDo`3ooo]ZofP0o`02
oookJP09o`3oT_oR0?oooo]Zo`3oAOmQ0?oooo]Zool0K?oo08Oo0?oN00;oolT001?o/ol0ool0gOoo
nf[oo`<0oookJ_l0nooooo]Zoc_o0?ooP@3oof`0o`1goooo0?WoZ03oo`2Voooonf[ojol0oookJ_oo
1P3o603o00;ooo]Z00Coo`3loookJ_ooTP3ooaH01?oonfX00ooo0>[ooo]ZoookJP0:oookJP03o`1c
oooonf[ooo]Z00Kooo]Z00[o^Ol0oookJ_ooDP3ooo]ZoiCo0?oonf[o?ol0o`3Loomho`3o0?oO1_oo
nfX01?l0oa_ooo]ZoookJ_oobP02oookJP04o`3ioooUo`3ooo]Zool04`Cooo]Z00Kof_l0oookJ_oo
nf[ooo]ZobH0oolPo`0>oookJP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00SoP_l0oookJ_l0ok7o033o
onGo0?l0j?oooo]Zo`H0o`;ooo]Z00KoT_l0oookJ_oonf[ooo]Zoa00oooUo`03oookJP05oaD0oooo
057ooo]ZoookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP1?oookJP08o`1goooonf[ooo]Zoom/0?oo
nf[o0?o<oon10?lko`04oookJP05o`3koooonf[ooo]ZoookJ_oo0`000ooonfX01Omi0?ooo`3Moook
J_l0Xooo/ol000Gooo]Z00?o0?oNool0QooonfX00_oonfX01ooo06cooo]Zodd0oooo;P3ooo]Zof40
ool0odD01?oonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Kooo]Z00WoJ03ooookJ_oonf[o603oo`1d
oooonf[oi_l0oookJ_ooT0002_oonfX00ooo_P3o0?l5on/0o`04oookJP03oomG0?oonf[ooo]Z00?o
oo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP04oookJP05o`3Dool01?oooo]Zo`2Y
ool0R?l00_oonfX00ol0odko0?ldoookJP04oookJP04o`3Qool0oagooo]Zo`3oD`?ooo]Z00ooo`1i
o`2]oooo057o5@3ooookJ_l06Ooo403ooi;o0?l60?oo0?m=o`0`oon2o`3o0?n`o`3oFolao`001ooo
nfX00olV0?oooo]Zom[o0002oookJP05ool04ooo09?oolX0o`3o6olB0?l00_oonfX01_l0omooN?l0
o`0Zoooonf[ooe80o`3o<`Gooo]Z00?o07?ooookJ_oonfX01_oonfX00ooo0>[ooo]ZoookJP02oonB
0004oolF0?oo0?coo`3lool0o0?ooo]Z1ooo1P03ool0o004oookJ_ooTP3ooi80oookJP;oo`3Z0_oo
nfX3o`00000?o`1coooonf[ooo]ZoomB0?l0:_oo?@3oo`3ogomho`3o0?lKo`2>oooobP3oo`0Com[o
0?lV0?oo8?l000?ooo]Z00_o<Ol0o`3oFol0odgoT_l0oa00ool06Oooo`1Aool0NOoonf[o0?mCo`3o
7@02oookJP05o`3oC_l0obko0:Woo`04ool0e?l00_oonfX02oooP@3ooo]ZoookJ_oonf[oo`0]oook
J_ooE`3ooo]Zog00ooo[0?oookh000?ooo]Z00?ooi00oookJ_lH0?l00_oonfX03?mX0?oooo]Zoook
J_l0oi;ohP3ooookJ_l0odGoH@3oodd0oooonf[oo`1/ool0Q`;ooo]Z01[oW`3ook?o0?mi0?ooo`<0
oookJ_l0nooooo]Zoc_o0?ooP@3o0?nJo`1goooo0?Wooo]ZojP0ool0Y_ooo`3fon_o0?oo1P3ooo]Z
oaP0oooonf[oo`3loookJ_ooTP3ooo]ZoolF00?ooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ol0Looo
oo]ZoookJP06oookJP0:okWo0?oonf[ooe80oookJ_l0:_oooo]Zocoo0?l0g?ooN?l0o`3og`Kooo]Z
00Co4P3oo`3o6ooonf[oolX00ooonfX00ooo09?ooo]Zool04`04oookJP06on7o0?oJo`3ooo]Zoook
J_lV0?oo8?l03ooonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP05oh;o0?l0ok7ooo]Zo`0`ool0odd0
0_oonfX01?l60?oooo]Zool0mOnBo`02oookJP03ool0J_l@0?oooo]Z00?ooo]Z00Ooo`1AoookJ_oo
nf[ooo]Zo`2]oooonf[oo`1i02_ooo]Z000ZoookJP08o`1goooonf[ooo]Zoom/0?l0olcooo]Zoon1
0?lko`04oookJP05o`3koooonf[ooo]ZoookJ_oo0`000ooonfX01?oUo`3ooo]Zo`2Soonco`06oook
JP05o`3og_oo08Oooo]ZoookJ_oo06`00_oonfX01_m=0?oooo]ZoookJ_mQ0?oooo]Zo`3oA@?ooo]Z
00GohP3oo`3oT?oonf[ooo]Zo`3oTP05oookJP09ofP0oooonf[ooo]ZoookJ_lH0?oo07CoonKo0?oo
nf[oiOl000[ooo]Z00Cookh0oookJ_l0o`Goj`3o1?oonfX00oooE`3ooo]ZoookJP03oookJP03oiCo
0?oonf[ooo]Z00Cooo]Z00?ooh40oookJ_oonfX01OoonfX01Ol0e?oo00CooookJ_l0ZOoo08So00;o
oo]Z00?o0?m>oookJ_l0oc@01?oonfX00ol0hOooolT0ooo90003ooo90007oookJ_oUo`3o0:gooaD0
oooo057oogT0oa00o`08oomi0003oc7o0?oonf[ooo]Z00Cooo]Z1?oUo`000ooQo`3oo`0Cool0T`02
oomi000:ooo:0?ooN@3oogT0oomi0?m4o`3oN?l0odCo0?l0:_ooolT0oomB00?oolT00ooonfX2o`1c
o`Oooo]Z00?oo`3ZoookJ_oonfX00_oo:00=oomi00Koo`001Ooo:0000ol0LoooiOl0onGo0003onGo
00?oogT000?oobP0o`3o6ooobP000_oo:0000ooJo`3oolT0ooo90002oookJP0?ool00?l0oe_oP_l0
o`3oCOnBo`3oobP0ool0DOoo003o0:goo`3oDol0oago0>7ooookJ_oob@3o0?m>00;oolT000?o0:Wo
o`3DoooonfX00_oonfX01?ooP@3ooo]ZoookJ_oo02d2oookJP03oomG0?oob@3oj`3o00?oolT00_oo
nfX01OooT03oi_l0oaP0oooonf[oJ03o00;ooo]Z00oo0?nBoookJ_oR0?oooo]Zo`3oAOmQ0?ooo`1/
oookJ_oo08Oo0?oNooo90?nco`3oN@3oool0gOoo0`000_oonfX03Ol0nooooo]Zoc_o0?ooK03o0?nJ
o`1goooonf[oZ03oo`2Voooo0?Kojol0oookJ_oo1P000ooonfX01?oo0?cooo]ZoonB0?oo5P03oook
JP03ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX01_oonfX00onio`3ooo]ZoomB0002oook
JP06oiCo0?oonf[o?ol0o`3Loomho`3o0?oO1_oonfX01?l0oa_ooo]ZoookJ_oobP02oookJP03o`3i
oooUo`3oo`0C00Cooo]Z00Oof_l0on7o0?oonf[ooo]ZobH0oon40?oo8?l000kooo]Z00Co<Ol0oook
J_oonf[o0?mK0_oonfX02_n2o`3ooo]Zo`3o/Ol0<?ooiOl0o`3Xoooonf[o1P3ooookJ_nBo`04oook
JP03oa00oooonf[ooo]Z00;ooo]Z00Go5@3oool0DOoonf[ooo]Zo`2]o`02oookJP03ool0NOoonf[o
oo]Z04oooo]Z00So07OooookJ_oonf[oof`0oookJ_l0olcooh40oc_o00Cooo]Z00Go0?_ooookJ_oo
nf[ooo]Zool30003oookJP05ogT0oooo0=gooo]Zo`2Soonco`001OoonfX00ol0omkooo]Zool0Q`02
oookJP08ool0K?oonf[oC@3oool^0?oonf[oH@3ooookJ_l0odD3oookJP05on80ool0oi3ooo]Zoook
J_l0oi801_oonfX02OmX0?oooo]ZoookJ_lH0?oo07CooookJ_oVo`3ooo]Zoon@000:oookJP03oonn
0?oonf[oj`3o00Cooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP05oookJP03oon1
0?oonf[ooo]Z00Cooo]Z00Go0=Coo`04oooonf[o0:Woo`28o`02oookJP03o`3oC_l0obko0?ld00Co
oo]Z00Co0>7ooookJ_l0oago0?mC0ooonfX04?oo07Wo0:gooookJ_oo057ooo]Zo`0Iool@0?ooT_l0
ool0mOl60?oo0?m=o`3o/On2o`3o0?mKoookJ_lao`06oookJP0:obH0oooonf[of_l0on7o0?oonf[o
o`0Cool0Tooonf[oolX0o`3o6`?ooo]Z00KoN?l0o`3Lool0:_oooo]ZoomB0?nio`05oookJP;o07?o
1ooonfX01?oo0>[ooo]ZoookJ_oonfX2oonB0003oolF0?oonf[oo`3l00Woo`3l1?ooTP000ooonf[o
o`3Zool0jP04oookJP0Bo`000?l0Looo07?oo`000?oonf[ooe80o`0Zoolm0?oo0?oOogSo0?l0oa_o
08koooo:0?oo01?of_l0oookJ_lV0?ooQ03o0_oonfX02olao`3o0?mKo`3oCOnBo`3oo`3eoa00oooo
057oo`1ioookJ_l0oe?o0?lM00;ooo]Z00Ko0?ldo`3oC_oonf[o0:Woo`04ool0e?l2oookJP0;oon1
0?oonf[ooo]ZoookJ_oo02gooo]ZoomG0?oonf[oj`3oo`3o1Ooo_P000ooonfX01OooT03o07CooaP0
oooonf[oJ03o00;ooo]Z00oo0?nBoookJ_oR0?oooo]Zo`3oAOmQ0?ooC@3oool0K?oonf[oo`27oook
J_nO0?oo/ol0ool0gOoo0`000_oonfX03_l0nooooo]Zoc_o0?l0olcoof`0o`1goooo0?Wooo]ZojP0
ool0Y_ooo`3fon_o0?oo1P3o603o0_oonfX01?oo0?cooo]ZoonB0?oo5P04oookJP03ool0j_oonf[o
oo]Z00[ooo]Z00?o07?ooookJ_oonfX01_oonfX02_nio`3ooe80oookJ_oonf[o02[ooookJ_loo`3o
0=coogSo0?l0oml6oookJP04o`3o6ol0S_oooo]Zooo:00;ooo]Z00Co0?Woool0Tooonf[oo`0C1?oo
nfX01_oJo`3ooo]ZoookJ_oonf[o9P3oob3o00oooo]Z013o<Ol0oookJ_oonf[o0?mKoookJ_n2o`3o
0?n`o`3o/Ooonf[o033oo`3oCOoonf[o1P3ooookJ_oo0?GoT_l00ooonfX00ooo06[o403ooookJP03
oookJP07ool0DOoonf[ooo]ZoookJ_l0[Ooooo]Zool0N@0[oookJP00:_oonfX02?l0Mooooo]Zoook
J_ooK03o0?o<oookJ_ooP@3o>ol01?oonfX01Ol0nooooo]ZoookJ_oonf[oo`<000?ooo]Z00CoN@3o
onGo0?l0Xooo/ol01_oonfX01Ol0omkoo`27oookJ_oonf[oo`1/00;ooo]Z00KoC@3ooookJ_oonf[o
H@3ooookJ_l0odD3oookJP05on80ool0oi3ooo]ZoookJ_l0oi801OoonfX02OmX0?oooo]ZoookJ_oo
nf[o603oo`1doooVo`3ooo]Zoon@000:oookJP04oonn0?oonf[o0?l5on/0o`Cooo]Z00?ooeL0oook
J_oonfX00ooonfX00onDo`3ooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Gooo]Z00Go0=Coo`04
oooonf[o0:Woo`28o`02oookJP03o`3oC_oonf[o0?ld00Cooo]Z00?o0>7oooo90?oob@001?oob@00
1_oUo`3o0:gooookJ_oo057oogT0oa00o`GoogT000CoP_l0o`3o/?l0oe_o<Ol01_oonfX5onGo0005
ool04oooN@3oo`2Coomi0?oobP001?ooN@001Olm0?ooN?l0ooo90?l0:_oooe8000CoolT01?oonfX0
0ol0Looooo]ZoookJP05oookJP?oo`3Z0_oo:0000ooo003oogT0oomi0009oomi00Koo`001?oo:000
0ol0LoooiOl0onGo0005onGo0004oomi0?l0oa_o0?lKooo:00;oobP000?of_l0oolX0?oob@000_oo
nfX04ooo003o<Ol0oh;o0?l0odgo1P3ooi;o0?l@0?ooo`1Aool0NOoonf[o0?mCo`3o7Ol0hOoooo]Z
ooo90?l0odkoolT0o`2Yool0e?l00ooonfX02OooP@3ooo]ZoookJ_oonf[oo`0]oookJ_ooE`3ooo]Z
on/0o`03ooo900?ooo]Z00Gooi00oaP0oooonf[ooo]ZofP0o`02oookJP09o`3oT_oR0?oooo]Zo`3o
AOmQ0?ooC@3oool0K?oMo`3oo`2700;oolT001?o/ol0o`2Soooo0=goo`<0ooo90?oonf[o0?_ooc_o
0?ooP@3oof`0o`1goooo0?Wooo]ZojP0ool0Y_ooo`3fon_o0?oo1P3o603o00?ooo]Z00?oo`3loook
J_ooTP001?oonfX00ooo0>[ooo]ZoookJP0:oookJP03o`1coooonf[ooo]Z00Kooo]Z00Go^Ol0oook
J_ooDP3ooo]ZoiCo0002oookJP04ocoo0?l0g?ooN?l0o`3og`Kooo]Z00Co0?lKoookJ_oonf[oolX0
0_oonfX00ooUo`3ooo]Zool04`04oookJP06om[o0?oonf[ooo]ZoookJ_lV0?oo8?l03ooonfX01?la
o`3ooo]ZoookJ_l0oe/2oookJP0:oh;o0?oonf[o033ooookJ_oUo`3o0>SooookJ_l60?oooo]Zoi;o
00Cooo]Z00?o403ooookJ_oonfX00_oonfX01Ooo057ooo]ZoookJ_oonf[o0:go00;ooo]Z00?oo`1i
oookJ_oonfX0CooonfX02?l0Mooooo]ZoookJ_ooK03ooo]Zo`3oc?ooP@3o>ol01OoonfX01?l0nooo
oo]ZoookJ_oo0`03oookJP05ogT0oooo0=gooo]Zo`2Soonco`001OoonfX00ooMo`3o0?oNool0Q`02
oookJP08ool0K?oonf[oC@3oool^0?oonf[oH@3ooookJ_l0odD3oookJP05on80ool0oi3ooo]Zoook
J_l0oi801_oonfX02OmX0?oooo]ZoookJ_lH0?oo07CooookJ_oVo`3ooo]Zoon@000:oookJP03oonn
0?oonf[oj`3o00Cooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP05oookJP03oon1
0?oonf[ooo]Z00Cooo]Z00Go0=Coo`04oooonf[o0:Woo`28o`02oookJP03o`3oC_l0obko0?ld00Go
oo]Z00Co0>7oo`3o7Ooonf[o0?mC0_oonfX01?oo07Wo0:gooookJ_oo0542oookJP0:oa00oonBo`3o
o`3eo`H0ool0odgo033ooh;o0?oonf[o0?mKoc7o00Kooo]Z00_oQ03oobH0oooJo`3ohOl0oookJ_oo
01?oo`2Co`3ioooobP3o08koo`3o6`02oookJP07ocd0oomho`3o?ol0o`0Zoooonf[ooe80okWo0006
oookJP03o`1coooonf[ooo]Z00Gooo]Z0ooo0>X2oookJPcooi800_oonfX3ool0jPKooo]Z00So07?o
o`000?l0003o0000oomB0?l0:_oo?@3oogSo00;o0?lK0_oobP001Ooo01?ooo]Zom[o0?lV0?ooQ03o
00?ooo]Z00_o<Ol0o`3o/?l0odgoT_l0oa00oooo057o0:goool0NOoonf[o0?mCo`3o7@02oookJP05
o`3oC_oonf[o0:Woo`04ool0e?l00_oonfX02oooP@3ooo]ZoookJ_oonf[oo`0]oookJ_ooE`3ooo]Z
og00ooo[0?oookh000Cooo]Z00Gooi00oaP0oooonf[ooo]ZofP0o`02oookJP0?o`3oT_oonf[ohP3o
o`3oAOmQ0?ooC@3ooookJ_oo06co0?oNool0Qooonf[oW`3ook?o0?oo0=goo`<000;ooo]Z00Ko0?_o
oc_o0?ooP@3o0?nJo`1goooo0?T2oookJP06ojP0ool0Y_oojol0ool60?oonf[o603o0_oonfX01?oo
0?cooo]ZoonB0?oo5P04oookJP03ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX01_oonfX0
2_nio`3ooe80oookJ_oonf[o02[ooookJ_loo`3o0=coogSo0?l0oml6oookJP04o`3o6ol0S_oooo]Z
ooo:00;ooo]Z00Coo`2CoookJ_oonf[oo`0C0ooonfX00ooQo`3of_l0oookJP02oookJP03obH0oooo
nf[ooo]Z00kooo]Z013o<Ol0oookJ_oonf[o0?mKoookJ_n2o`3ooo]Zo`3o/Ol0<?oooo]Zo`3oCOoo
nf[o1P3ooookJ_oo0?GoT_l00ooonfX00ooo06[o403ooookJP03oookJP07ool0DOoonf[ooo]Zoook
J_l0[Ooooo]Zool0N@0[oookJP00;OoonfX01OooK03o0?o<oookJ_ooP@3o>ol000Cooo]Z00Go0?_o
oookJ_oonf[ooo]Zool30003oookJP04ogT0oooUo`3o01Oook?o00Kooo]Z00Go0?oNool0Qooonf[o
oo]Zool0K002oookJP06odd0oooonf[ooo]Zof40oooonf[o0?m50ooonfX01OoR0?oo0?n@oookJ_oo
nf[o0?nB00Gooo]Z00WoJ03ooookJ_oonf[ooo]ZoaP0ool0M?oooo]ZonKo0?ooT0002_oonfX01?oo
_P3ooo]Zo`3o1Oo[0?l4oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oU?l0oookJ_oonfX01?oonfX0
0oooP@3ooo]ZoookJP05oookJP05o`3Dool01?oooo]Zo`2Yool0R?l00_oonfX00ol0odkooo]Zo`3o
=005oookJPKoolT000Koo`1io`2]oooonf[oo`1Aoomi0?l@0?l3oomi0007o`H0ooooN@3oP_l0o`3o
/?oonf[o0?mKoc7o0005oookJPKoiOl000?oo`0Cool0ToooN@001_ooN@001Olm0?ooN?l0ooo90?l0
:_oooe8000CoolT01?oonfX2o`1co`Sooo]Z0ooo:002ool000WoogT000Koo`3ZoookJ_oo003ooo]Z
oolX0?oo0002oolX00;o07?o2?oUo`000ol0oa_oolX0oolX0004oolX000Gooo90?oonf[oobP0oook
J_lao`3oo`00o`3oCOl60?ooT_l0oa00oooo057oo`1ioookJ_l0oe?o0?lMo`3Qoooonf[oolT0o`3o
C_oob@3o08Soo`2Yool0e?l00ooonfX01?ooP@3ooo]ZoookJ_oo02d2oookJP03oomG0?oonf[oj`3o
00;oolT00ooonfX01OooT03oi_l0odCo0?oonf[oJ03o00;ooo]Z00[o0?nBoookJ_oR0?oooo]Zo`3o
AOmQ0?oooo]Zool0K?oo08Oo0?oN0_oob@004onco`3oo`3Mooo90?oo0`3oolT0o`3koooonf[o>ol0
oon10?ooK03o07Ooool0nOnX0?oooo]Zo`2Voooo0?Kojol0ool60?lH0?l00_oonfX01?oo0?cooo]Z
oookJ_ooTP04oookJP03ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX01_oonfX02onio`3o
oo]ZoomB0?oonf[oU?l0oookJ_loo`3o0=cooookJ_mho`3o0?oO00Gooo]Z00Go4P3oo`3o6ooonf[o
oo]Zooo:0002oookJP03onGo0?oonf[oo`0C00Cooo]Z00Kof_l0oookJ_oonf[ooo]ZobH0oolPo`0?
oookJP03oc7o0?oonf[o0?mK00;ooo]Z00SoP_l0o`3o/?l0ok7o033oonGo0?oonf[o0>Soo`H0o`;o
oo]Z00KoT_l0oookJ_oonf[ooo]Zoa00ool06Ol4oookJP07ool0DOoonf[ooo]ZoookJ_l0[Ooooo]Z
ool0N@1EoookJP05oom/0?oonf[o0?o<oon10?lko`001OoonfX01?l0nooooo]ZoookJ_oo0`03oook
JP05ogT0oooo0=gooo]Zoil0oonco`001OoonfX00ooMo`3o0?oNool0Q`02oookJP08ool0K?oonf[o
C@3oool^0?oonf[oH@3ooookJ_l0odD3oookJP05on80ool0oi3ooo]ZoookJ_l0oi801_oonfX02OmX
0?oooo]ZoookJ_oonf[o603ooookJ_oVo`3ooo]Zoon@000:oookJP04oonn0?oonf[oj`3oog00o`?o
oo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP05oookJP03oon10?oonf[ooo]Z00Co
oo]Z00Go0=Coo`04oooonf[ooo]Zo`2Yo`03oookJP03o`3oC_l0ocCooo]Z00Cooo]Z00Co0>7oo`3o
7Ooonf[o0?mC0_oonfX04?oo07Wo0:gooookJ_oo057o5@3ooookJ_l@0?oooo]Zoi;o0?l60?oo0?m=
o`0`oon2o`3ooo]Zo`3oFolao`07oookJP03obH0oooonf[of_l000;ooo]Z00Goo`0Cool0Tooonf[o
olX0o`3o6`03oookJP06ocd0oomho`3o?ol0o`0Zoooonf[ooe801ooonfX2o`1co`Sooo]Z0ooo0>X:
oookJP?oo`3Z1ooonfX2o`1co`;o000000ko^Ol0oomB0?l0:_oo?@3oogSo0?l0oa_o4P3oooo:0?oo
09?oo`0CoookJ_oJo`3o9P3ooh@0o`?ooo]Z00_o<Ol0oh;o0?l0odgoT_l0oa00oooo057o5@3oool0
NOoonf[o0?mCo`3o7@02oookJP06o`3oC_l0obkooo]Zo`2Yool01?oo0=Co0_oonfX02oooP@3ooo]Z
oookJ_oonf[oo`0]oookJ_ooE`3ooo]Zog00ooo[0?oookh000?ooo]Z00Gooi00oookJ_lH0?oooo]Z
ofP0o`03oookJP09o`3oT_oR0?oooo]Zo`3oAOmQ0?ooC@3ooookJ_oo06coo`2700;ooo]Z01Ko/ol0
ool0gOmi0?ooo`<0oookJ_l0nooooo]Zoc_o0?ooP@3o0?nJo`1goooo0?Wooo]ZojP0oooonf[o0:Ko
on_o0?oo1P3ooo]ZoaP0oooonf[oo`3l0_oonfX00oooTP3ooaH0oookJP02oookJP03ool0j_oonf[o
oo]Z00[ooo]Z00?o07?ooookJ_oonfX01ooonfX02_nio`3ooe80oookJ_l0:_oooo]Zocoo0?l0g?oo
oo]ZogSo0?l0oml6oookJP04o`3o6ol0S_oooo]Zooo:00;ooo]Z00Coo`2CoookJ_oonf[oo`0C0ooo
nfX00ooQo`3of_l0oookJP02oookJP03obH0oooonf[ooo]Z00kooo]Z00?o<Ol0oookJ_l0oe/00_oo
nfX02on2o`3o0?naoookJ_l0<?oo0?m=o`3Xoooonf[o1P3ooookJ_oo0?GoT_l000?ooo]Z00?o403o
o`0IoooonfX00ooonfX01_oo057ooo]ZoookJ_l0[Ooooo]Zool0NBcooo]Z000]oookJP05oom/0?oo
nf[o0?o<oon10?lko`001?oonfX01Ol0nooooo]ZoookJ_oonf[oiOl000?ooo]Z00GoN@3oonGo0?l0
5ooo0:?ook?o0005oookJP05omgo0?oo08Oooo]ZoookJ_oo06`00_oonfX01_m=0?oooo]ZoookJ_mQ
0?oooo]Zo`3oA@?ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP05oookJP03ofP0oooonf[ooo]Z00;o
oo]Z00Go603ooookJ_oVo`3ooo]Zoon@0009oookJP04oonn0?oonf[o0?l5on/0o`Cooo]Z00?ooeL0
oookJ_oonfX00ooonfX00onDo`3ooo]ZoookJP05oookJP03oon10?oonf[ooo]Z00Cooo]Z00[o0=Co
oookJ_l01?oo0:WooookJ_l0R?oooo]Zo`3o;_l0odko0?ld1OoonfX7ooo90003ool0NOl0[Oooo`1A
00;oogT000[o403oool0mOnBo`3o1P3ooomi0?l0ok7oP_l0o`3o/?l0oe_o<Ol01_oonfX5onGo0003
ool04oooN@3oo`2C00OoogT000GoN?l0ooo90?oob@3o02[ooomB0004ooo900Gooo]Z00?o07?ooook
J_oonfX01_oonfX00ooo:03ooo]Zool0jP02ool000OoogT01ooonfX2o`1co`03oookJ_oUo`3oiOl0
00KoiOl000?o0?lKooo:0?oo:0001?oo:0004?lV0?oooo]ZoookJ_oo:03o<Ol0o`3oFol0j?oo0?m=
oi;o0?l@0?ooo`1AoookJ_oo07Wo0?mCoookJ_l0oad2oookJP05o`3oC_oob@3o08Soo`2Yool0e?l0
0ooonfX02OooP@3ooo]ZoookJ_oonf[oo`0]oookJ_ooE`3ooo]Zon/0o`03ooo900?ooo]Z00Gooi00
onKo0?m4o`3ooo]ZofP0o`02oookJP09o`3oT_oR0?oooo]ZoookJ_l0odGoH@3oool0K?oonf[oo`27
00;oolT001Co/ol0ogT0oooo0=goo`<0ooo90?oonf[o0?_ooookJ_lko`3ooh40o`3oV_l0Mooooo]Z
ojP0ool0Y_ooo`3fon_o0?oonf[oo`H0oaP0o`;ooo]Z00Coo`3loookJ_ooTP3ooaH00ooonfX00ooo
0>[ooo]ZoookJP0:oookJP03o`1coooonf[ooo]Z00Oooo]Z00_o^Ol0oomB0?l0oc?ooo]ZoiCo0?oo
nf[o?ol0o`3Loomho`3o?@3oo`3og`05oookJP0:oa80ool0oa_ooo]ZoookJ_oobP3ooo]Zo`3ioooU
o`3ooo]Zool04`Cooo]Z00Kof_l0oookJ_oonf[o9P3ooh@0oolPo`0?oookJP03oc7o0?oonf[o0?mK
00;ooo]Z00SoP_l0o`3o/?l0ok7o033oonGo0?l0j?oooo]Zo`H0o`;ooo]Z00KoT_l0oookJ_oonf[o
oo]Zoa00ool06Ol4oookJP04ool0DOoonf[ooo]Zo`2]o`;ooo]Z00?oo`1ioookJ_oonfX0DooonfX0
1OooK03ooo]ZoookJ_ooP@3o>ol000Gooo]Z00Co0?_ooookJ_oonf[oo`<00ooonfX01Omi0?ooo`3M
oookJ_nO0?oo/ol000Gooo]Z00?ogOl0o`3og_oo08L00_oonfX01?oo06cooo]Zodd0oooo;P02oook
JP03of40ool0odGooo]Z00;ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP07ofP0oooonf[o
oo]ZoookJ_lH0?oo07CoonKo0002oookJP03oon@0?oonf[ooo]Z00Oooo]Z00Cookh0oookJ_o[0?oo
L03o0ooonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oo
nfX01OoonfX01Ol0e?oo00CooookJ_l0ZOoo08So00;ooo]Z00?o0?m>o`3o=?oonfX01?oonfX01?l0
hOoo0?lMo`3o2?l0oe<3oookJP0@ool0NOl0[Oooo`1AoaD0oooonf[o01Wooa00oonBo`3ooo]Zo`3o
COl0j?oo033ooh;o0?oonf[o0?mKoc7o00Kooo]Z00_o8?l0obH0oooJo`3ohOl0oookJ_oo01?oo`2C
o`3ioooonf[oolX0o`3o6`03oookJP07ogSo0?loo`3ooo]Zo`0Zoooonf[ooe80o`3o<`07oookJP03
o`1coooonf[ooo]Z00Sooo]Z2_oo0>X8oookJP;o07?o0_oonfX01?l0003ooe80oomB0?l0:_l2ogSo
0009o`3o6olB0?ooolX0ool0Tol0nOoooo]Zom[o0?lV0?ooQ03o00?ooo]Z00co<Ol0oh;o0?l0odgo
T_l0oa00ool06Oooo`1Ao`2]oooo07Wo0?mCo`3Qool0oad2oookJP05o`3oC_oonf[o0:Woo`04ool0
e?l00_oonfX00oooP@3ooo]ZoookJP02oookJP06ool0;OooE`3ooo]Zog00ooo[0?oookh01?oonfX0
1OooT03oi_l0oaP0oooonf[oJ03o00;ooo]Z00oo0?nBoookJ_oR0?oooo]Zo`3oAOmQ0?ooC@3oool0
K?oonf[oo`27oookJ_nO0?oo/ol0ool0gOoo0`000_oonfX05Ol0nooooo]Zoc_o0?ooP@3oof`0o`1g
oooo0?Wooo]ZojP0ool0Y_ooo`3fon_o0?oo1P3ooo]ZoaP0oooonf[oo`3loookJ_ooTP3ooo]ZoolF
0003oookJP03ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX01_oonfX02onio`3ooe80o`3o
<ooonf[o02[ooookJ_loo`3o0=coogSo0?lm0?oo0?oO00Gooo]Z00Go4P3oo`3o6ooonf[ooo]Zooo:
0002oookJP04ool0Tooonf[ooo]Zool04`?ooo]Z00KohOl0om[o0?oonf[ooo]ZobH0oolPo`0?oook
JP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00GoP_l0o`3o/Ooonf[o033oo`3oC@02oookJP04o`H0oooo
nf[oo`3eoi;o00;ooo]Z00?oo`1Zoa00ool06Ol00ooonfX01ooo057o5@3ooookJ_oonf[o0:gooook
J_oo07T0;?oonfX002gooo]Z00Goof`0oookJ_l0olcooh40oc_o0004oookJP05o`3koooonf[ooo]Z
oookJ_oUo`000ooonfX01Omi0?ooiOl0o`0Gool0Xooo/ol000Kooo]Z00Coo`27oookJ_oonf[oo`1/
0_oonfX01_m=0?oooo]ZoookJ_mQ0?oooo]Zo`3oA@?ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP05
oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603oo`1doooVo`3ooo]Zoon@0009oookJP04oonn0?oo
nf[ooo]Zon/0o`Gooo]Z00?ooeL0oookJ_oonfX00_oonfX00onDo`3ooo]ZoookJP05oookJP03oon1
0?oonf[ooo]Z00Cooo]Z00[o0=CooookJ_l01?oooo]Zo`2Yool0R?oooo]Zo`3o;_l0odko0?ld1Ooo
nfX7ooo90009ool0NOl0[OooogT0ool0DOooN@3o403ooomi0?nBo`3o1P3o00;oogT000CoP_l0o`3o
/?oonf[o<Ol01_oonfX6onGo0003ool04ooo09?oogT000OoogT000CoN?l0ooo90?oob@3o02[o0_oo
DP03ooo900Gooo]Z00?o07?ooookJ_oonfX02OoonfX00oooN@3oo`00ool00005oomi00Kooo]Z00?o
07?ooookJ_oonfX01ooUo`02o`3o6`03ooo:0?oUo`3oiOl000?oobP000Go9P3ooolX0?oo:03oobP0
oc7o0002oolX000:o`3oCOoo:03oT_l0oa00oooo057oo`1io`3oDooonf[o0?lMo`3Qo`;ooo]Z00Go
0?m>oookJ_l0ZOoooo]Zo`3Do`03oookJP04oon10?oonf[ooo]Zool0;@;ooo]Z00?ooeL0oookJ_o[
0?l00_oob@03oookJP05oon@0?oVo`3oA?l0oookJ_mX0?l00_oonfX02_l0oi;ooo]Zon80oooonf[o
0?m5of40oom=0?ooo`1/ool0Qol0omh2ooo90004ok?o0?l0Xoooo`3Mool300;ooo]Z00go0?_ooc_o
0?ooP@3oof`0o`1goooo0?Wooo]ZojP0ool0Y_ooo`3fon_o0?oo1P3o603o00?ooo]Z00Coo`3loook
J_ooTP3ooaH00ooonfX00ooo0>[ooo]ZoookJP0:oookJP03o`1coooonf[ooo]Z00Kooo]Z00Go^Ol0
oookJ_ooDP3ooo]ZoiCo0002oookJP04ocoo0?l0g?ooN?l0o`3og`Kooo]Z00Co4P3oo`3o6ooonf[o
olX00_oonfX01?l0nOooiOl0oookJ_oo01<4oookJP05om[o0?oonf[ooo]ZobH0oolPo`004?oonfX0
0olao`3ooo]Zo`3oF`02oookJP0:oh;o0?oonf[o0?nao`0`oooUo`3o0>SooookJ_l60?oooo]Zoi;o
00Cooo]Z00?o403ooookJ_oonfX00ooonfX01?oo057ooo]ZoookJ_l0[Ol2oookJP03ool0NOoonf[o
oo]Z05?ooo]Z00Goof`0oookJ_oonf[ooh40oc_o0005oookJP04o`3koooonf[ooo]Zool300?ooo]Z
00GoN@3oool0gOoonf[oW`3ook?o0006oookJP08o`3og_oo08Oooo]ZoookJ_oo06cooo]Zodd0oooo
;P02oookJP03of40ool0odGooo]Z00;ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP07ofP0
oooonf[ooo]ZoookJ_lH0?oo07CoonKo0002oookJP03oon@0?oonf[ooo]Z00Oooo]Z00Cookh0oook
J_o[0?ooL03o1?oonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooh40
oookJ_oonfX01?oonfX01Ol0e?oo00CooookJ_l0ZOoo08So00;ooo]Z00?o0?m>o`3o=?oonfX01?oo
nfX01Ol0hOoo0?lMo`3o2?oonf[o0?mC00;ooo]Z013oo`1io`2]oooonf[oo`1AoookJ_oo06[o403o
oi;o0?oo0?Go1P3oo`3oCOl0<?ooP_l0oookJ_l0oe_o<Ol01ooonfX00olV0?oooo]Zom[o0002oook
JP06ool0Tooonf[o0?Woooo:0?lB0?oo0?lK0ooonfX2ogSo0003ocoo0?l0:_oooo]Z00;ooe801ooo
nfX00ol0Looooo]ZoookJP0HoookJP0;o`1coooonf[ooo]ZoookJ_nio`3ooe80o`0Zoolm0?ooN?l0
o`3ogol0oa/00_oobP001_oo09?o0?Woom[o0?oJo`3o9P3ooh@0o`?ooo]Z00co<Ol0oh;o0?l0j?oo
0?m=oi;o0?l@0?ooo`1AoaD0oooo07Wo0?mCoookJ_l0oad2oookJP06o`3oC_l0obko0:Woo`28ool0
1?oo0=Co0_oonfX02oooP@3ooo]ZoookJ_oonf[oo`0]oookJ_ooE`3ooo]Zog00ooo[0?oookh000?o
oo]Z00Gooi00oookJ_lH0?oooo]ZofP0o`03oookJP09o`3oT_oR0?oooo]Zo`3oAOmQ0?ooC@3ooook
J_oo06coo`2700;ooo]Z00CoW`3ook?o0?oo0=goo`<00_oonfX03_l0nooo>ol0oon10?l0oi[o07Oo
oookJ_oo0?WoZ03ooookJ_l0Y_oojol0ool60?oonf[o603o0_oonfX01Ooo0?cooo]ZoonB0?oonf[o
oaH000?ooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ol0Looooo]ZoookJP06oookJP0:okWo0?ooDP3o
oo]ZoookJ_l0:_oooo]Zocoo0?l0g?ooN?l0o`3og`Kooo]Z00Co4P3oo`3o6ooonf[oolX00ooonfX0
1?oo09?ooo]ZoookJ_oo01<3oookJP06on7o0?oJo`3ooo]ZoookJ_lV0?oo8?l03ooonfX01?lao`3o
oo]ZoookJ_l0oe/2oookJP05oh;o0?l0ok7ooo]Zo`0`ool0odd00_oonfX00ol60?ooo`3eoi;o0003
oookJP03ool0J_l@0?oooo]Z00?ooo]Z00Ooo`1AoaD0oooonf[ooo]Zo`2]oooonf[oo`1i02cooo]Z
000]oookJP05oom/0?oonf[o0?o<oon10?lko`001?oonfX01?l0nooooo]ZoookJ_oonfX2onGo00;o
oo]Z00GoN@3oonGo0?l05ooo0:?ook?o0006oookJP04ool0Qooonf[ooo]Zool0K0;ooo]Z00KoC@3o
oookJ_oonf[oH@3ooookJ_l0odD3oookJP05on80ool0oi3ooo]ZoookJ_l0oi801OoonfX00omX0?oo
oo]ZoookJP02oookJP05oaP0ool0M?ooi_l0oookJ_ooT0002_oonfX00ooo_P3ooo]Zon/0o`05oook
JP03oomG0?oonf[ooo]Z00?ooo]Z00?oU?l0oookJ_oonfX01?oonfX00oooP@3ooo]ZoookJP05oook
JP05o`3Dool01?oooo]Zo`2Yool0R?l00_oonfX00ol0odkooo]Zo`3o=004oookJPSoolT000?o0:go
oomi0?oo05400_ooN@002_l@0?ooT_l0o`H0oooonf[oogT0oh;o0?l0ok3ooo]Zo`3oFolao`05oook
JPOoiOl000?oo`0Cool0ToooN@001oooN@03ooo90003o`0Zoooob@3ooe8000?oolT01OoonfX2o`1c
o`[ooo]Z00CoogT0ool00?ooN@3ooo]Z0_ooN@04oookJP?o07?o0_oonfX7onGo0003o`3o6ooUo`3o
olX000GoobP000Go9P3ooolX0?oo:03oobP0oc7o0004oolX0008oi;o0?l@0?ooo`1Aool0NOoonf[o
0?mCo`3o7Ol0hOl2oookJP05o`3oC_l0ocCo08Soo`2Yool0e?l00ooonfX01oooP@3ooo]ZoookJ_oo
nf[oo`0]oookJ_ooE`000_oonfX00oo[0?ooolT0oookJP03oookJP05oon@0?oVo`3oA?l0oookJ_mX
0?l00_oonfX03ol0oi;ooo]Zon80oooonf[o0?m5of40oooonf[oo`1/ool0Qol0omkoolT0ok?o0?oo
b@3oo`3Mool30002oookJP0>o`3koooonf[o>ol0oon10?l0oi[o07Ooool0nOnX0?oooo]Zo`2Voooo
0?Kojol0ool60?lH0?l2oookJP04ool0o?oonf[ooo]ZoonB00Cooo]Z00?oo`3ZoookJ_oonfX02_oo
nfX00ol0Looooo]ZoookJP06oookJP05okWo0?oonf[ooe80oookJ_nDo`000_oonfX01?loo`3o0=co
ogSo0?l0oml5oookJP05oa80oooUo`3o0?lKoookJ_oobP000_oonfX00ooUo`3ooo]Zool04`04oook
JP06on7o0?oJo`3ooo]ZoookJ_lV0?oo8?l03ooonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP0:oh;o
0?oonf[o033ooookJ_oUo`3o0>SooookJ_l60?oooo]Zoi;o00Cooo]Z00?o403ooookJ_oonfX00ooo
nfX01?oo057ooo]ZoookJ_l0[Ol2oookJP03ool0NOoonf[ooo]Z00Cooo]Z00?oU?l0oookJ_oonfX0
C?oonfX01OooK03ooo]ZoookJ_ooP@3o>ol000Gooo]Z00Co0?_ooookJ_oonf[oo`<00ooonfX01Omi
0?ooo`3MoookJ_nO0?oo/ol000Kooo]Z00So0?oNool0Qooonf[ooo]Zool0K?oonf[oC@3oool^00;o
oo]Z00?oH@3oo`3oAOoonfX00_oonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Kooo]Z00OoJ03ooook
J_oonf[ooo]ZoaP0ool0M?ooi_l000;ooo]Z00?ooi00oookJ_oonfX02?oonfX00ooo_P3oj`3oog00
o`04oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]Zoook
JP04oookJP05o`3Dool01?oooo]Zo`2Yool0R?l00_oonfX00ol0odko0?l^o`3o=004oookJP05o`3Q
ool0oago0?l8oookJ_l0oe<00ooonfX03?oo07Wooo]Zool0DOlE0?oooo]Zo`0IoonBo`3oo`3eo`H0
ool0odgo0>Sooh;o00;ooo]Z00?o<Ol0oookJ_oonfX01OoonfX01?lPo`3o9P3ooookJ_oJo`02oook
JP06ool0Tol0nOoooo]Zooo:0?lB0?oo0?lK0ooonfX01ol0omooN?l0ocoo0?l0:_oooo]ZokWo0?oo
DP001ooonfX2o`1coaGooo]Z0ol0Lol2oookJP04okWo0?ooDP3ooe80o`0Zo`;oN?l000[o0?oOo`3o
6ooobP3ooo]Zool0Tooonf[of_l0on7o0?lV0?ooQ03o0ooonfX03?lao`3o0?mKo`3Xool0odgoT_l0
oa00oooo057o5@3oool0NOoonf[o0?mCo`3o7@?ooo]Z00Go0?m>oookJ_l0ZOoo00Coo`3Do`02oook
JP03oon10?oonf[ooo]Z00;ooo]Z00Ooo`0]oomG0?oonf[ooo]Zon/0ool0o`Gookh000?ooo]Z00Go
oi00onKo0?lH0?oooo]ZofP0o`02oookJP0:o`3oT_oonf[ohP3ooookJ_l0odGoH@3oodd0oooonf[o
o`1/ool0Q`;ooo]Z00?o/ol0ool0gOmi0?l00_oonfX04Ol0nooooo]Zoc_o0?ooP@3oof`0o`1goooo
0?Wooo]ZojP0oooonf[o0:Koon_o0?oo1P3ooo]ZoaP0oooonf[oo`3l00;ooo]Z00?ooi80oolF0?oo
nfX00_oonfX00ooo0>[ooo]ZoookJP0:oookJP03o`1coooonf[ooo]Z00Oooo]Z00Co^Ol0oomB0?oo
nf[o02[o0_oonfX01?loo`3o0=coogSo0?l0oml6oookJP04oa80ool0oa_ooo]Zooo:00;ooo]Z00Co
o`2CoookJ_oonf[oo`0C0ooonfX00ooQo`3ooo]Zom[o0002oookJP03obH0oon40?oooo]Z00kooo]Z
013o<Ol0oookJ_oonf[o0?mKoookJ_n2o`3o0?n`o`3o/Ol0<?oooo]Zo`3oCOoonf[o1P3ooookJ_oo
0?GoT_l00ooonfX00ooo06[o403ooookJP03oookJP07ool0DOlE0?oooo]ZoookJ_l0[Ooooo]Zool0
N@07oookJP03o`3oDooonf[ooo]Z02;ooo]Z000]oookJP05oom/0?oonf[o0?o<oon10?lko`001?oo
nfX01?l0nooooo]ZoookJ_oonfX2onGo00;ooo]Z00GoN@3oonGo0?l05ooo0:?ook?o0006oookJP04
o`3og_oo08Oooo]Zool0K0;ooo]Z00KoC@3ooookJ_oonf[oH@3ooookJ_l0odD3oookJP05on80ool0
oi3ooo]ZoookJ_l0oi801OoonfX00omX0?oooo]ZoookJP02oookJP05oaP0ool0M?ooi_l0oookJ_oo
T0002_oonfX00ooo_P3ooo]Zon/0o`05oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oU?l0oookJ_oo
nfX01?oonfX00oooP@3ooo]ZoookJP05oookJP05o`3Dool01?oooo]Zo`2Yool0R?l00_oonfX00ol0
odkooo]Zo`3o=004oookJPGoolT00ooonfX03ooo07WoogT0ool0DOlE0?oooo]Zoa00ooooN@3oT_l0
o`H0ool0odgo0>Sooh;o0?l0ok3o0?mKoc7o0005oookJPSoiOl000?oo`0Cool0ToooN@001oooN@03
ooo900;o02[o00?ooe80o`3o<ooonfX01ooonfX3o`1co`Sooo]Z00GoogT0oookJ_oonf[ooo]Zoomi
0004o`1co`Cooo]Z1ooUo`000ol0oa_o4P3oooo:0005oolX0003obH0oooo:03oobP000;oobP000?o
<Ol0oolX0?oo:0000ooo:0001olE0?ooo`1Aool0NOl0oe?ooo]Zo`3o7Ol0hOl00_oonfX01Ol0odko
08Soo`2Yool01?oo0=Co00?ooo]Z00Cooh40oookJ_oonf[oo`0]0_oob@001?ooE`3ooo]Zon/0oooo
b@04oookJP05oon@0?oVo`3oA?l0oookJ_mX0?l00_oonfX02_l0oi;ooo]Zon80oooonf[o0?m5of40
oom=0?ooo`1/ool0Qol0omh2ooo90004ok?o0?l0Xoooo`3Mool300;ooo]Z00ko0?_ooookJ_lko`3o
oh40o`3oV_l0Mooooo]ZojP0ool0Y_ooo`3fon_o0?oonf[oo`H0oaP0o`;ooo]Z00Coo`3loookJ_oo
nf[ooi800ooonfX00ooo0>[ooo]ZoookJP0:oookJP03o`1coooonf[ooo]Z00Oooo]Z00Go^Ol0oomB
0?l0oc?ooo]ZoiCo0002oookJP04ocoo0?l0g?ooN?l0o`3og`Gooo]Z00Go4P3oo`3o6ooonf[ooo]Z
ooo:0002oookJP03onGo0?oonf[oo`0C00Cooo]Z00Kof_l0oookJ_oonf[ooo]ZobH0oolPo`0?oook
JP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00[oP_l0oookJ_l0<?ooiOl0oookJ_oUo`3ooo]Zo`H0oooo
nf[oT_l00ooonfX00ol@0?oo01WooookJP03oookJP05ool0DOoonf[ooo]ZoookJ_l0[Ol00_oonfX0
0om4o`3ooo]ZoookJP04oookJP03oiCo0?oonf[ooo]Z04cooo]Z00Goof`0oookJ_oonf[ooh40oc_o
0005oookJP04o`3koooonf[ooo]Zool300?ooo]Z00GoN@3oool0gOoonf[oW`3ook?o0006oookJP08
o`3og_oo08Oooo]ZoookJ_oo06cooo]Zodd0oooo;P02oookJP03of40ool0odGooo]Z00;ooo]Z00Go
hP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP07ofP0oooonf[ooo]ZoookJ_lH0?oo07CoonKo0002oook
JP03oon@0?oonf[ooo]Z00Sooo]Z00?ookh0on/0oom`0?l01?oonfX00oooE`3ooo]ZoookJP03oook
JP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0e?oo00CooookJ_l0ZOoo
08So00;ooo]Z00?o0?m>o`3o;_l0oc@01OoonfX01?l0hOoo0?lMo`3o2?l0oe<3oookJP0@ool0NOoo
nf[oo`1AoaD0oooonf[o01Wooa00oonBo`3ooo]Zo`3oCOl0j?oo033ooh;o0?oonf[o0?mKoc7o00Oo
oo]Z00_o9P3ooookJ_oQo`3of_l0oookJ_oo01?oo`2Co`3ioooonf[oolX0o`3o6`04oookJP03o`3o
gomho`3o?ol000;o02[o00?ooo]ZoomB0?l0oc<01ooonfX3o`1co`kooo]Z1?l0Lol4oookJP;ooe80
00?o02[oocd0oomho`000_l0oml02Ol0oa_oolX0oookJ_oo09?ooo]Zom[o0?oQo`3o9P3ooh@0o`03
oookJP0=oc7o0?l0oe_oP_l0o`3oCOnBo`3o403oo`0Ioooo057oo`1ioookJ_l0oe?o0?lMo`3Qo`02
oookJP06o`3oC_oonf[o0:Woo`04oooonf[o0=Co0_oonfX02oooP@3ooo]ZoookJ_oonf[oo`0]oook
J_ooE`3ooo]Zog00ooo[0?oookh000?ooo]Z00Gooi00oookJ_lH0?oooo]ZofP0o`03oookJP0?o`3o
T_l0oi3ohP3oo`3oAOmQ0?ooobh0odd0oooo06coo`27o`3og_oonf[oW`3ook?o0?oo0=goo`<000;o
oo]Z017o0?_ooookJ_lko`3ooh40oom/0?l0Moooo`3ioookJ_nX0?oo0:Koool0m_o[o`3oo`H0oook
J_lH0?oooo]Zool0o002oookJP03oonB0?oo5P3ooo]Z00;ooo]Z00?oo`3ZoookJ_oonfX02_oonfX0
0ol0Looooo]ZoookJP06oookJP05okWo0?ooDP3o0?lcoookJ_l0:_l00_oonfX01?loo`3o0=coogSo
0?l0oml6oookJP04o`3o6ooonf[ooo]Zooo:00;ooo]Z00Coo`2CoookJ_oonf[oo`0C0ooonfX01_oQ
o`3of_l0oookJ_oonf[o9P3oob3o013ooo]Z013o<Ol0oookJ_oonf[o0?mKoookJ_n2o`3ooo]Zo`3o
/Ol0<?oo0?m=o`3Xoooonf[o1P3ooookJ_oo0?GoT_l00ooonfX00ol@0?oo01WooookJP03oookJP04
ool0DOoonf[ooo]Zo`2]o`;ooo]Z00?oo`1ioookJ_oonfX01OoonfX00ol0oe?ooo]ZoookJP0Roook
JP00;_oonfX01?ooK03o0?o<oon10?lko`04oookJP04o`3koooonf[ooo]ZoookJP?oiOl000Kooo]Z
ogT0oooUo`3o01Ooo`2Soonco`06oookJP04o`3og_oo08Oooo]Zool0K0;ooo]Z00KoC@3oool^0?oo
nf[oH@3ooookJ_l0odD4oookJP04on80oooonf[ooo]Zo`3oTPGooo]Z00?oJ03ooookJ_oonfX00_oo
nfX01OlH0?oo07CoonKo0?oonf[ooi0000[ooo]Z00Cookh0oookJ_m`0?ooj`3o1OoonfX00oooE`3o
oo]ZoookJP02oookJP03oiCo0?oonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0e?oo
oo]Zo`04ool0ZOoo08So00;ooo]Z00?o0?l^o`3oC_l0oc@01?oonfX2ooo90003o`3o7Ooonf[oolT0
00?ooo]Z00ooo`1io`2]oooo057o5@3ooookJ_l06Ooo403ooi;o0?l60?oooo]Zo`3oCOn2o`3o0?n`
oookJ_lao`001OoonfX6onGo0005om[o0?ooN@3oogT0ool04ooo09<02?ooN@04ooo90004o`0Zoooo
DP3ooe80okWo00Wooo]Z0ol0Lol4oookJPKo07?o1ooonfX5onGo00;oobP000Co0?lKoa80oooobP3o
o`2C1ooo:002oookJP03oc7o0?oo:03oobP000GoobP000Goo`1io`3oDooonf[o0?lMo`3Qo`02oook
JP05o`3oC_l0obko08Soo`2Yool0e?l00ooonfX01OooP@3ooo]ZoookJ_oo02gooo]Z00?oolT000?o
oo]Zon/0oooo_P001?oonfX01OooT03oi_l0odCo0?oonf[oJ03o00;ooo]Z00[o0?nBoookJ_oR0?oo
oo]Zo`3oAOmQ0?ooC@3oool0K?oo08Oo0?oN0_oob@001?nco`3oo`3Mooo90?oo0`02oookJP0=o`3k
oolko`3ooh40oom/0?l0Moooo`3ioookJ_nX0?oo0:Koool0m_o[o`3oo`H0oaP0o`02oookJP05ool0
o?oonf[ooo]ZoonB0?oo5P000ooonfX00ooo0>[ooo]ZoookJP0:oookJP03o`1coooonf[ooo]Z00Ko
oo]Z00Go^Ol0oookJ_ooDP3ooo]ZoiCo0002oookJP04ocoo0?l0g?oo?@3oogSo00Kooo]Z00Co4P3o
o`3o6ooonf[oolX00ooonfX00ooUo`3ooo]Zool04`04oookJP06om[o0?oonf[ooo]ZobH0oon40?oo
8?l03ooonfX03Olao`3ooo]ZoookJ_l0oe_ooo]Zoh;o0?l0ok3o0?nao`0`oooUo`3ooo]ZonGo0?l6
0?l00_oonfX01_nBo`3ooo]ZoookJ_oonf[o403oo`0Io`Cooo]Z00Coo`1AoookJ_oonf[o0:go0ooo
nfX00om4o`3ooo]ZoookJP04oookJP03oiCo0?oonf[ooo]Z04gooo]Z00Coof`0oookJ_ooP@3o>ol0
1OoonfX01Ol0nooooo]ZoookJ_oonf[oo`<000;ooo]Z00GoN@3oool0gOoonf[oW`3ook?o0006oook
JP0<o`3og_oo08Oooo]ZoookJ_oo06cooo]Zodd0oooonf[oobh0oookJ_mQ0?oo0?m51?oonfX01?oR
0?oooo]ZoookJ_l0oi86oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603oonKo0?oonf[ooo]Zoon@
000:oookJP03oonn0?oonf[oj`3o00Gooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]Zoook
JP05oookJP03oon10?oonf[ooo]Z00Gooo]Z00Co0=Coo`04ool0ZOoo08So0ooonfX00ol0odko0?ld
oookJP04oookJP04o`3Qool0oago0?l8o`3oD`?ooo]Z013oo`1io`2]oooo057o5@3ooookJ_oo06[o
403ooi;o0?oo0?Go1P3oo`3oCOl0j?ooP_l0oookJ_l0oe_o<Ol01ooonfX01?lV0?ooQ03ooookJ_oJ
o`02oookJP06ool04ooo09?ooo]ZoookJ_oobP3o0?lK1?oonfX01_lm0?ooN?l0o`3Looloo`3o02[o
oookJP;ooe802OoonfX3o`1co`Gooo]Z1_l0Lol6oookJP04okWo0?ooDP3o02[oocoo00;oN?l000Co
0?oOo`2>ool0oa_oolX00_oo09<01Ooonf[of_l0on7o0?lV0?ooQ03o00?ooo]Z00go<Ol0o`3oFon2
o`3o0?m=oi;o0?l@0?oo01Woool0DOl0[Oooo`1io`3oDooonf[o0?lM00;ooo]Z00Ko0?m>o`3o;_oo
nf[o0:Woo`04ool0e?l2oookJP07oon10?oonf[ooo]ZoookJ_oo02gooo]ZoomG0002oookJP03og00
ooo[0?oookh000?ooo]Z00Gooi00onKo0?lH0?oooo]ZofP0o`02oookJP0:o`3oT_oonf[ohP3ooook
J_l0odGoH@3oodd0oooonf[oo`1/ool0Q`;ooo]Z00Co/ol0ool0gOmi0?ooo`<00_oonfX03_l0nooo
>ol0oon10?l0oi[o07OooookJ_oo0?WoZ03ooookJ_l0Y_oojol0ool60?oonf[o603o0_oonfX01Ooo
0?cooo]ZoonB0?oonf[ooaH000?ooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ol0Looooo]ZoookJP06
oookJP0:okWo0?ooDP3ooo]ZoookJ_l0:_oooo]Zocoo0?l0g?oooo]ZogSo00Kooo]Z00Co4P3oo`3o
6ooonf[oolX00ooonfX01?oo09?ooo]ZoookJ_oo01<3oookJP06on7o0?oJo`3ooo]ZoookJ_lV0?oo
8?l04?oonfX04?lao`3ooo]ZoookJ_l0oe_ooo]Zoh;o0?l0ok7ooo]Zo`0`ool0odgo0>SooookJ_l6
0?oooo]Zool0mOnBo`03oookJP03oa00ool06Ooooo]Z00?ooo]Z00Coo`1AoookJ_oonf[o0:go0_oo
nfX00ooo07Wooo]ZoookJP05oookJP03o`3oDooonf[ooo]Z02;ooo]Z000^oookJP04oom/0?l0olco
oh40oc_o00Cooo]Z00?o0?_ooookJ_oonfX01?oUo`001_oonf[oN@3oonGo0?l05ooo0:?ook?o00Ko
oo]Z00Co0?oNool0Qooonf[oo`1/0_oonfX01_m=0?ooobh0oookJ_mQ0?oooo]Zo`3oA@Cooo]Z00Co
hP3ooookJ_oonf[o0?nB1OoonfX00omX0?oooo]ZoookJP03oookJP05oaP0oooVo`3ooo]ZoookJ_oo
T0002OoonfX01?oo_P3ooo]Zog00ooo[0?l5oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oU?l0oook
J_oonfX01OoonfX00oooP@3ooo]ZoookJP04oookJP0:o`3Doooonf[o00CooookJ_l0ZOoo08Sooook
J_l0obko0?m>o`3o=0Gooo]Z00Go0>7oo`3o7Ooonf[ooo]Zooo90003oookJP03ool0NOoonf[oo`1A
00;ooo]Z00[o403ooomi0?nBo`3oogT0o`3oCOl0ok7oP_l0oookJ_l0oe_o<Ol01OoonfX4onGo00;o
ogT000?of_l0oomi0?oo01<02_ooN@001?oob@3o0?oOo`3Looloo`02o`0Zo`03oomB0?nio`3o^Ol0
00[ooo]Z1?l0Lol:oookJP04okWo0?ooDP3oiOl0onGo00CoolT00_l0oa/2ooo:0003ool0Tooo:03o
obP000;oobP000Ko9P3ooolX0?oo:03oobP0oookJ_lao`06oolX0006ool0DOoo07WoobP0o`3oDol0
oago0>7o0_oonfX01_l0ocCo0?m>o`28ool0ZOoo00Coo`3Do`?ooo]Z00Gooh40oookJ_oonf[oo`0]
oookJP03ooo90003on/0oooo_P3ooo]Z00?ooo]Z00Gooi00oookJ_m4o`3ooo]ZofP0o`02oookJP03
o`3oT_oonf[ohP3o00;ooo]Z00_oH@3oooo90?oo06cooo]Zool0Qooonf[oolT0ok?o0?l0Xoooo`3M
ool30002oookJP0>o`3koooonf[o>ol0oon10?l0oi[o07Ooool0nOnX0?oooo]Zo`2Voooo0?Kojol0
ool60?lH0?l2oookJP04ool0o?oonf[ooo]ZoonB00Cooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ol0
Looooo]ZoookJP06oookJP05okWo0?oonf[ooe80oookJ_nDo`000_oonfX01?loo`3o0=coogSo0?l0
oml6oookJP04oa80ool0oa_ooo]Zooo:00?ooo]Z00?oiOl0ool04ooonfX01?oonfX01OoUo`3ooo]Z
oookJ_lV0?oo8?l0013ooo]Z00?o<Ol0oookJ_l0oe/00_oonfX02on2o`3o0?n`o`3o/Ol0<?ooiOl0
oookJ_oUo`3o1P3ooookJ_nBo`3oo`3e00?ooo]Z00?o403oo`0IoooonfX00ooonfX01?oo057ooo]Z
oookJ_l0[Ol3oookJP03odCo0?oonf[ooo]Z00?ooo]Z00?oU?l0oookJ_oonfX0C_oonfX01?ooK03o
oo]Zoon10?lko`05oookJP05o`3koooonf[ooo]ZoookJ_oo0`000_oonfX01Omi0?ooo`3MoookJ_l0
5ooo/ol000Kooo]Z00co0?oNool0Qooonf[ooo]Zool0K?oonf[oC@3ooookJ_oo;P3ooo]Zof40ool0
odD4oookJP04on80oooonf[ooo]Zo`3oTPKooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?ooi_l0
oookJP02oookJP03oon@0?oonf[ooo]Z00Oooo]Z00?ookh0oookJ_o[0?l01OoonfX00oooE`3ooo]Z
oookJP02oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0e?oo00Co
oookJ_l0ZOoo08So00;ooo]Z00?o0?m>o`3o=?oonfX01?oonfX01Ol0hOoo0?lMo`3o2?oonf[o0?mC
00?ooo]Z013oo`1ioookJ_oo057o5@3ooookJ_l06Ooo403ooi;o0?l60?oo0?m=o`3Xool0ok3oP_l0
oookJ_l0oe_o<Ol01ooonfX01?lV0?oooo]Zon7o0?oJo`02oookJP05ool04ooo09?ooo]Zooo:0?oo
nfX00_l0oa/3oookJP04ocd0oomho`3o0=coocoo00;o02[o00?ooo]ZoomB0?nio`002_oonfX5o`1c
o`Wooo]Z0_nio`02oomB0005o`0Zoomho`3oN?l0o`3ogooonfX00_l0oa/00ooobP3oo`2Cool04`02
om[o0003on7o0?lV0?ooQ03o00?ooo]Z00go<Ol0o`3oFon2o`3o0?m=o`H0oonBo`3o403oool0DOl0
[Oooo`1ioookJ_l0oe?o0?lM00;ooo]Z00Oo0?ldo`3oC_oonf[o0:Woo`04oooonf[o0=Co00;ooo]Z
00_ooh40oookJ_oonf[ooo]Zool0;Ooonf[ooeL0oookJ_m`0?ooj`3ooonn0003oookJP05oon@0?oo
nf[o603ooookJ_mX0?l00ooonfX02_l0oi;ooo]Zon80oooonf[oH@3oool^0?m=0?ooo`1/oookJ_oo
08L2oookJP03ok?o0?oo0=goN@3o00;ooo]Z017o0?_ooookJ_lko`3ooh40oom/0?l0Moooo`3ioook
J_nX0?oo0:Koool0m_o[o`3oo`H0oookJ_lH0?oooo]Zool0o002oookJP03oonB0?oo5P3ooo]Z00;o
oo]Z00?oo`3ZoookJ_oonfX02_oonfX00ol0Looooo]ZoookJP07oookJP0:okWo0?ooDP3ooo]Zoook
J_l0:_oooo]Zocoo0?l0g?ooN?l0o`3og`Kooo]Z00Co4P3oo`3o6ooonf[oolX00ooonfX00ooo09?o
oo]Zool04`04oookJP06on7o0?oJo`3ooo]ZoookJ_lV0?oo8?l04?oonfX00olao`3ooo]Zo`3oF`02
oookJP0:oh;o0?l0ok7ooo]Zo`0`ool0odgo0>SooookJ_l60?oooo]Zoi;o00?ooo]Z00?oo`1Zoa00
ool06Ol00ooonfX01Ooo057o5@3ooookJ_oonf[o0:go00;ooo]Z00?oo`1ioookJ_oonfX01?oonfX0
0ol0oe?ooo]ZoookJP0SoookJP00;_oonfX01?ooK03o0?o<oon10?lko`04oookJP03o`3koooonf[o
oo]Z00CoiOl000Kooo]ZogT0oooUo`3o01Ooo`2Soonco`06oookJP04o`3og_oo08Oooo]Zool0K0?o
oo]Z00GoC@3ooookJ_mQ0?oooo]Zo`3oA@04oookJP04on80oooonf[ooo]Zo`3oTPGooo]Z00?oiOl0
oookJ_oonfX00ooonfX01OlH0?ooi_l0oookJ_oonf[ooi0000Wooo]Z00Cookh0oookJ_l0o`Goj`3o
1OoonfX00oooE`3ooo]ZoookJP02oookJP03oiCo0?oonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX0
1?oonfX01_l0e?oooo]Zo`04oooonf[o0:Woo`28o`;ooo]Z00?o0?m>o`3o=?oonfX01OoonfX01?l0
oago0?l8oookJ_oob@03oookJP0@ool0NOl0[Oooo`1AoaD0oooonf[o01Wooa00oonBo`3o1P3ooomi
0?l0odgo033ooh;o0?l0oe_ooo]Zoc7o00Cooo]Z0_oUo`001OooN@3o9P3ooomi0?ooN@3of_l000;o
ogT000?oo`0Coomi0?ooN@001OooN@001?oonf[oolT0oookJ_mho`02o`3og`04ocoo0?oonf[o02[o
oomB00;o0?lc5?oonfX01_nio`3ooe80oomB0?ooDP3o02[ooolX00CoolT000?o0?lKooo:0?oobP00
0_oo09<01Ooo01?oobP0oolX0?oo:03o9P3o00CoobP000?o<Ol0oolX0?oo:0001Ooo:0001Ooo057o
obP0o`3oDol0oago0>7o00;ooo]Z00Ko0?ldo`3oC_l0obko0:WooookJ_l0e?l3oookJP05oon10?oo
nf[ooo]Zool0;OoonfX00ooob@001?m`0?ooj`3ooonn0?oob@02odCo0006oookJ_ooT03oi_l0odCo
0?oonf[oJ03o0_oonfX04?l0oi;ooo]Zon80oooonf[o0?m5of40oooob@3oo`1/ool0Qol0omkooo]Z
ooo90?nco`3oo`3MoookJ_oo0`02oookJP0>o`3koooonf[o>ol0oon10?l0oi[o07OooookJ_nX0?oo
0:Koool0m_oonf[ojol0ool60?lH0?l2oookJP04ool0o?oonf[ooo]ZoonB00?ooo]Z00?oo`3Zoook
J_oonfX02_oonfX00ol0Looooo]ZoookJP07oookJP05okWo0?ooDP3o0?lcoookJ_nDo`000_oonfX0
1?loo`3o0=coogSo0?l0oml5oookJP05oa80oooonf[o0?lKoookJ_oobP000_oonfX00ooUo`3ooo]Z
ool04`04oookJP06on7o0?oUo`3ooo]ZoookJ_lV0?oo8?l04?oonfX00olao`3ooo]Zo`3oF`02oook
JP04oh;o0?l0ok3o033ooookJP;oiOl000Cooo]Zo`H0oooonf[oT_l01?oonfX00ol@0?oo01Wooook
JP03oookJP04ool0DOoonf[ooo]Zo`2]o`;ooo]Z00?oA?l0oookJ_oonfX01?oonfX00onDo`3ooo]Z
oookJP1>oookJP04oom/0?oonf[ooh40oc_o00Gooo]Z00Go0?_ooookJ_oonf[ooo]Zool30002oook
JP06ogT0oooo0=gooo]Zo`0Gool0Xooo/ol01OoonfX01OoMo`3oo`27oookJ_oonf[oo`1/00;ooo]Z
00GoC@3oool^0?oonf[oH@3oo`3oA@04oookJP04on80oooonf[ooo]Zo`3oTPKooo]Z00?oJ03ooook
J_oonfX00_oonfX00olH0?ooi_l0oookJP02oookJP03oon@0?oonf[ooo]Z00Oooo]Z00?ookh0oook
J_o[0?l01OoonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooh40oook
J_oonfX01?oonfX01Ol0e?oo00CooookJ_l0ZOoo08So00;ooo]Z00?o0?m>o`3o=?oonfX01OoonfX0
1?l0oagooo]Zo`3o2?l0oe<3oookJP0Aool0NOl0[Oooo`1AoaD0oooonf[oo`1Zoa00oonBo`3oo`3e
o`H0ool0odgo033oo`3o/?n2o`3o0?mKoookJ_lao`001_oonfX01OlPo`3o9P3ooookJ_oQo`3of_l0
00;ooo]Z00Ooo`0Cool0Tol0nOooolX0oookJ_lB0?oo0?lK00Cooo]Z00CoN?l0o`3ogoloo`3ooo]Z
0_l0:_l00oooDP3o0?lcoookJP0CoookJP;o^Ol00oooDP001Ol0:_ooN?l0ogSo0?l0omoooo]Z00;o
0?lK00GoolX0o`000?oo09?oo`0Com[o0002on7o0003obH0oooonf[ooo]Z00;ooo]Z00ko<Ol0o`3o
Fon2o`3o0?m=o`H0oonBo`3o403ooaD0oooo057oo`1ioookJ_l0oe?o0?lMo`3o20;ooo]Z00Ko0?m>
o`3o;_l0ZOoooo]Zo`04ool0e?l2oookJP07oon10?oonf[ooo]ZoookJ_oo02gooo]ZoomG0002oook
JP03og00ooo[0?oooo]Z00?ooo]Z00Gooi00onKo0?lH0?oooo]ZofP0o`03oookJP0?o`3oT_l0oi3o
hP3oo`3oAOmQ0?ooobh0odd0oooo06coo`27omgo0?oonf[o/ol0o`2Soooo0=goo`<000;ooo]Z017o
0?_ooookJ_lko`3ooh40oom/0?l0Moooo`3ioookJ_nX0?oo0:Koool0m_o[o`3oo`H0oookJ_lH0?oo
oo]Zool0o002oookJP03oonB0?oo5P3ooo]Z00;ooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ol0Looo
oo]ZoookJP06oookJP05okWo0?ooDP3o0?lcoookJ_l0:_l00_oonfX01?loo`3o0=coogSo0?l0oml6
oookJP04oa80ool0oa_ooo]Zooo:00;ooo]Z00Coo`2Co`3ioooonf[oo`0C0ooonfX00ooQo`3ooo]Z
om[o0002oookJP03obH0oon40?oooo]Z00kooo]Z00Co<Ol0oookJ_oonf[o0?mK0_oonfX01On2o`3o
0?nao`0`oooonf[o0?m=00;ooo]Z00?o1P3oool0mOnBo`000ooonfX00ooo06[o403oo`0Io`03oook
JP07ool0DOlE0?oooo]ZoookJ_l0[Ooooo]Zool0N@07oookJP03o`3oDooonf[ooo]Z02?ooo]Z000^
oookJP04oom/0?l0olcooh40oc_o00Cooo]Z00?o0?_ooookJ_oonfX01OoUo`001Omi0?ooiOl0onGo
0?l0Xooo/ol000Kooo]Z00Co0?oNool0Qooonf[oo`1/0ooonfX01Om=0?oooo]Zof40oooonf[o0?m5
00Cooo]Z00CohP3ooookJ_oonf[o0?nB1OoonfX00ooUo`3ooo]ZoookJP03oookJP05oaP0oooVo`3o
oo]ZoookJ_ooT0002OoonfX01?oo_P3ooo]ZoookJ_o[0?l5oookJP03oomG0?oonf[ooo]Z00;ooo]Z
00?oo`0]oookJ_oonfX01_oonfX00oooP@3ooo]ZoookJP04oookJP05o`3Dool01?oooo]Zo`2Yool0
R?l00_oonfX00ol0obko0?m>o`3o=005oookJP04o`3Qool0oagooo]Zooo900?ooo]Z013oo`1io`2]
oooo057o5@3ooookJ_l06Ooo403ooomi0?nBo`3o1P3oo`3Xool0odgoP_l0o`3o/?l0oe_o<Ol01?oo
nfX01OoUo`3oogT0oomi0?ooN@3o9P3o00;oogT000Cof_l0oomi0?ooN@3oo`0C1OooN@02o`3o6`?o
oo]Z00CoN?l0oookJ_l0omoo?@3o0_loo`03oomB00;o0?lc0onio`08oookJP?o^Ol000Co0?lcoomB
0?ooDP3ooe800_l0:_l00ol0g?ooobP0ooo90002ooo900;o0?lK00?oolX0ooo90?oo09<00_oo01<3
oolX0003obH0oooo:03oobP000SoobP000So403ooomi0?oo057oo`1ioomi0?oonf[o0?lMo`3Qo`;o
oo]Z00Go0?ldo`3oC_l0R?oo0:Woo`3Do`03oookJP06oon10?oonf[ooo]ZoookJ_oo02gooo]Z0ooo
b@001?o[0?oookh0ooo90?oob@05odCo0003oookJ_mX0?oooo]Z00;ooo]Z02;o0?nBo`3oT?oR0?oo
oo]Zof40oooob@3oo`1/oookJ_oo08Oooo]Zooo90?nco`3o0:?oool0gOoonf[oo`<0oookJ_l0nooo
oo]Zoc_o0?ooP@3o0?nJo`1goooo0?Wooo]ZojP0ool0Y_ooo`3fon_o0?oo1P3ooo]ZoaP0oooonf[o
o`3l0_oonfX00oooTP3ooaH0oookJP02oookJP03ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oo
nfX01ooonfX01Onio`3ooe80oookJ_oonf[oU?l000;ooo]Z00?o?ol0o`3Loomho`001_oonfX01?lB
0?oo0?lKoookJ_oobP03oookJP03onGo0?oonf[oo`0C00Cooo]Z00KoiOl0oookJ_oonf[ooo]ZobH0
oolPo`0?oookJP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00CoP_l0oookJ_l0<?oooo]Z0_oUo`001?oo
nf[o1P3ooookJ_nBo`03oookJP03oa00oooUo`3o01Wo00?ooo]Z00Goo`1AoaD0oooonf[ooo]Zo`2]
o`02oookJP03odCo0?oonf[ooo]Z00Cooo]Z00?oU?l0oookJ_oonfX0C_oonfX01?ooK03ooo]Zoon1
0?lko`05oookJP05o`3koooonf[ooo]ZoookJ_oo0`000_oonfX01_mi0?ooo`3MoookJ_l05ooo0:?o
ok?o00Gooo]Z00GogOl0ool0Qooonf[ooo]Zool0K002oookJP05odd0oooo;P3ooo]Zof40ool0odD0
1?oonfX01?oR0?oooo]ZoookJ_l0oi86oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603oo`1doooV
o`000_oonfX00oooT03ooo]ZoookJP07oookJP03oonn0?oonf[oj`3o00Gooo]Z00?ooeL0oookJ_oo
nfX00_oonfX00ooo02gooo]ZoookJP06oookJP03oon10?oonf[ooo]Z00Cooo]Z00Go0=Coo`04oooo
nf[o0:Woo`28o`03oookJP03o`3oC_l0ocCooo]Z00Cooo]Z00Co0>7oo`3o7Ol0o`So0?mC1?oonfX0
4?oo07Woo`1AoaD0oooonf[oo`1Zo`0Iool@0?ooT_l0o`H0oooonf[o0?m=o`0`oon2o`3ooo]Zo`3o
Folao`07oookJP04ob3o0?lV0?oooo]Zom[o00;ooo]Z00Coo`0CoookJ_oo09?o0?Wo0_oobP000olB
0?oo0?lKoookJP03oookJP03ogSo0?l0omoo?@3o00;o?ol000Go02[ooomB0?ooDP3ooe80o`3o<`03
okWo00Sooo]Z1?nio`001?l0oc?ooe80oomB0?ooDP02o`0Zo`06ocd0oomho`3o0?oOo`3ogooonf[o
0?lK0_oobP02ool0T`05ool04ooJo`3ohOl0ob3o0?lV0?l00ooonfX2oc7o000=oookJ_l0j?oo0?m=
o`H0oonBo`3o403oo`0Ioooo057oo`1ioookJ_l0oe?o0?lMo`3Qo`02oookJP06o`3o=?l0odkooo]Z
o`2Yool01?oo0=Co0_oonfX00oooP@3ooo]ZoookJP02oookJP07ool0;Ooonf[ooeL0oookJ_m`0?oo
j`3ooonn0003oookJP05oon@0?oonf[o603ooookJ_mX0?l00ooonfX02_l0oi;ooo]Zon80oooonf[o
H@3ooookJ_m=0?ooo`1/oookJ_oo08L2oookJP0Bok?o0?oo0=goN@3oool30?oonf[o0?_ooookJ_lk
o`3ooh40oom/0?l0Mooooo]Zool0nOnX0?oooo]Zo`2Vooo[o`3oo`H00_oonfX01olH0?oooo]Zool0
o?oonf[ooi80oookJ_oo5P000ooonfX00ooo0>[ooo]ZoookJP0:oookJP03o`1coooonf[ooo]Z00Ko
oo]Z00Go^Ol0oomB0?oonf[ooo]Zo`0Zo`02oookJP03ocoo0?l0g?ooN?l000Oooo]Z00?o0?lKoook
J_oobP000ooonfX01?oo09?ooo]ZoookJ_oo01<3oookJP07on7o0?oJo`3ooo]ZoookJ_lV0?oo8?l0
oh@0o`0?oookJP0@oc7o0?oonf[ooo]Zo`3oFooonf[oP_l0o`3o/?l0ok7o033ooookJ_l0odgooo]Z
o`H0oooonf[oo`3eoi;o00?ooo]Z00?o403ooookJ_l06Ol00ooonfX01?oo057o5@3ooookJ_l0[Ol2
oookJP03ool0NOoonf[ooo]Z00Gooo]Z00?o0?mCoookJ_oonfX08ooonfX002kooo]Z00Coof`0o`3o
c?ooP@3o>ol01?oonfX00ol0nooooo]ZoookJP05onGo0005ogT0oooUo`3oiOl0o`2Soonco`001_oo
nfX01?l0omkoo`27oookJ_oo06`3oookJP03odd0oooonf[oH@3o00;ooo]Z00Go0?m5oookJ_oonf[o
oo]Zon80o`02oookJP03o`3oT_oonf[ooo]Z00?ooo]Z0_oUo`04oookJP05oaP0oooVo`3ooo]Zoook
J_ooT0002OoonfX01?oo_P3ooo]ZoookJ_o[0?l6oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]
oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP04oookJP05o`3Doooonf[o00CooookJ_l0ZOl00ooo
nfX00ol0odko0?ldoookJP05oookJP04o`3o7Ooonf[ooo]Zooo900?ooo]Z00?oo`1io`2]oooo0540
0_oonfX02oooN@3o403ooi;o0?l60?oo0>Soo`3oCOl0<?ooP_l0o`3oFooonf[o<Ol000Gooo]Z0ooo
N@000olV0?ooogT0om[o0006oomi00;ooo]Z00CoolX0oookJ_l0oa_o08ko0_oonfX3ogSo0003ocd0
ool0g?oo?ol000;o02[o1OooDP05okWo0003o`3o<oooDP3ooe8000Cooe800_l0:_l00oooN@3o?@3o
ocd0o`04ooo90007o`3o6ooobP3oolX0ooo90?oo09?oo`0Con7o0002oolX00;o9P3o2_oo:0000ol@
0?ooogT0ool0D@03oomi0009o`3o7Ol0hOoooo]ZoookJ_l0ocCo0?m>o`28ool0ZOoo0=Co00Cooo]Z
00Cooh40oookJ_oonf[oo`0]0_oonfX2ooo90003on/0oooob@3ookh000;oolT01Om4o`005?oonf[o
J03ooookJ_oonf[o0?nBoookJ_oR0?oooo]Zo`3oAOmQ0?ooolT0ool0K?oo08Oo0?oNoookJ_oob@3o
/ol0o`2Soooo0=goo`<00_oonfX03_l0nooooo]Zoc_o0?ooP@3o0?nJo`1goooo0?WoZ03oo`2Voooo
nf[oo`3fon_o0?oo1P3o603o0_oonfX01?oo0?cooo]ZoookJ_ooTP04oookJP03ool0j_oonf[ooo]Z
00[ooo]Z00?o07?ooookJ_oonfX01_oonfX01Onio`3ooo]ZoomB0?oonf[oU?l000;ooo]Z00Co?ol0
oookJ_lm0?ooN?l01_oonfX01?lB0?oo0?lKoookJ_oobP03oookJP03onGo0?oo01?ooo]Z00Cooo]Z
00KoiOl0oookJ_oonf[o9P3oob3o0?n40?l?oookJP03oc7o0?oonf[o0?mK00?ooo]Z00[oP_l0o`3o
/Ol0<?ooiOl0oookJ_oUo`3ooo]Zo`H0oooonf[oT_l00ooonfX00ol@0?oo01WooookJP03oookJP04
ool0DOlE0?oooo]Zo`2]o`?ooo]Z00?oA?l0oookJ_oonfX01?oonfX00onDo`3ooo]ZoookJP1>oook
JP04oom/0?oonf[ooh40oc_o00Gooo]Z00Go0?_ooookJ_oonf[ooo]Zool30002oookJP06ogT0oooo
0=gooo]Zo`0Gool0Xooo/ol01OoonfX01OoMo`3oo`27oookJ_oonf[oo`1/00;ooo]Z00KoC@3oool^
0?oonf[oH@3ooookJ_l0odD3oookJP04on80oooonf[ooo]Zo`3oTPKooo]Z00?oJ03ooookJ_oonfX0
0ooonfX01OlH0?ooi_l0oookJ_oonf[ooi0000Wooo]Z00Cookh0oookJ_o[0?ooL03o1OoonfX00ooo
E`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX01OoonfX01?l0
e?oo00CooookJ_l0ZOl3oookJP03o`3oC_l0ocCooo]Z00Gooo]Z00Co0?lMo`3o2?oonf[o0?mC0ooo
nfX04Ooo07Wo0:goool0DOlE0?oooo]Zo`0Iool@0?ooT_l0ool0mOl60?oo0?m=o`0`ool0ok3oP_l0
o`3oFooonf[o<Ol000Oooo]Z00Co8?l0obH0oooonf[of_l00_oonfX01ooo01?ooo]Zool0Tol0nOoo
oo]Zooo:0?lB0?l00_l0oa/3oookJP?oN?l000?o0=coocoo0?l0:_l00_l0:_l4oomB00Go^Ol000?o
0?lcoomB0?ooDP001OooDP02o`0Zo`06o`3Loolm0?ooN?l0ogSo0?l0omoooo]Z0_l0oa/01ooobP3o
oo]Zool0Tooo01?o0000om[o0?oQo`000_lV0?l3oookJP0;oc7o0?l0oe_ooo]Zo`3Xool0odgo1P3o
oi;o0?l@0?oo01Woool0DOoo07T00_oonfX02_l0oe?o0>7ooookJ_oonf[o0?ldo`3oC_oonf[o0:Wo
o`04ool0e?l3oookJP07oon10?oonf[ooo]ZoookJ_oo02gooo]ZoomG0002oookJP03on/0oooo_P3o
oo]Z00?ooo]Z00Gooi00o`1doolH0?oooo]ZofP0o`03oookJP0?o`3oT_l0oi3ohP3oo`3oAOmQ0?oo
obh0odd0oooo06coo`27o`3og_oonf[o/ol0o`2Soooo0=goN@3o00;ooo]Z017o0?_ooookJ_lko`3o
oh40oom/0?l0Mooooo]Zool0nOnX0?oo0:KooookJ_o[o`3oo`H0oookJ_lH0?oooo]Zool0o002oook
JP03oonB0?oo5P3ooo]Z00;ooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ol0Looooo]ZoookJP07oook
JP0:okWo0?ooDP3ooo]ZoookJ_l0:_oooo]Zocoo0?oonf[o0=coogSo00Kooo]Z00Co4P3oo`3o6ooo
nf[oolX00ooonfX00ooo09?ooo]Zool04`04oookJP06on7o0?oJo`3ooo]ZoookJ_lV0?oo8?l04?oo
nfX00olao`3ooo]Zo`3oF`02oookJP0;oh;o0?l0ok3ooo]Zo`0`ool0odgo0>SooookJ_l60?oooo]Z
ool0mOnBo`000ooonfX00ol@0?oo01WooookJP03oookJP04ool0DOlE0?oooo]Zo`2]o`;ooo]Z00?o
o`1ioookJ_oonfX01OoonfX00ol0oe?ooo]ZoookJP0SoookJP00;_oonfX01?ooK03o0?o<oon10?lk
o`04oookJP03o`3koooonf[ooo]Z00GoiOl000GoN@3oonGo0?oUo`3o0:?ook?o0007oookJP03ool0
Qooonf[oo`1/00?ooo]Z00?oC@3oool^0?mQ0?l00_oonfX01Ol0odGooo]ZoookJ_oonf[ohP3o00;o
oo]Z00?o0?nBoookJ_oonfX00ooonfX2onGo00Cooo]Z00?o603oo`1doooVo`000_oonfX00oooT03o
oo]ZoookJP06oookJP04oonn0?oonf[ooo]Zon/0o`Kooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo
02gooo]ZoookJP05oookJP03oon10?oonf[ooo]Z00Cooo]Z00Ko0=CooookJ_l01?oooo]Zo`2Yool0
R?l2oookJP03o`3oC_l0ocCooo]Z00Gooo]Z00Co0>7oo`3o7Ooonf[oolT00ooonfX04Ooo07Wo0:go
oookJ_oo057ooo]Zo`0Iool@0?ooogT0oi;o0?l60?oo0>Soo`3oCOn2o`3o0?n`o`3oFooonf[o<Ol0
00Cooo]Z1?ooN@001_lV0?ooogT0om[o0?oQo`3oogT0oookJP;oogT000?oo`2Co`3ioooonfX00_oo
bP02o`3o6`Cooo]Z0omho`02o`3Lo`03ocoo0?l0:_oo02[o00;o02[o1_ooDP000ooonf[o02[oo`0Z
o`03o`0Zo`;oogT00_mho`03ooo900;o0?lK00WoolX0ooo90?oo09?oo`2Cooo90?oJo`3oobP0ob3o
0?lV0?l00_oonfX:oolX0003o`0Ioooo057oogT000?oogT000Wo0>7ooookJ_oonf[o0?ldo`3oC_oo
nf[o08Soo`2Yool0e?l00ooonfX01?ooP@3ooo]ZoookJ_oo02d3oookJP;oolT000Coj`3ooonn0?oo
b@3oolT02?m4o`02oookJP0@o`3oT_l0oi3ohP3ooookJ_mQ0?ooolT0ool^0?oo06coo`27o`3og_oo
nf[o/ol0o`2Soooo0=gooo]Zool300;ooo]Z013o0?_ooookJ_lko`3ooh40oookJ_l0Mooooo]ZojP0
ool0Y_ooo`3foookJ_o[o`3oo`H0oaP0oooonf[oo`3l0ooonfX01OooTP3ooo]ZoookJ_oonf[oo`3Z
00cooo]Z00?o07?ooookJ_oonfX01ooonfX01Onio`3ooe80o`3o<ooonf[oU?l000;ooo]Z00Co?ol0
o`3Loolm0?ooN?l01OoonfX01OoUo`3o4P3oo`3o6ooonf[oolX000?ooo]Z00?oiOl0ool04ooonfX0
1?oonfX01OoUo`3ooo]ZoookJ_lV0?oo8?l0013ooo]Z00?o<Ol0oookJ_l0oe/00_oonfX01?n2o`3o
0?n`o`0`oooonfX2onGo0005oookJ_l60?oooo]Zoi;o0?oo0?D00ooonfX00ol@0?oo01WooookJP03
oookJP04ool0DOlE0?oooo]Zo`2]o`;ooo]Z00?oA?l0oookJ_oonfX01OoonfX00onDo`3ooo]Zoook
JP1>oookJP04oom/0?oonf[ooh40oc_o00Gooo]Z00Go0?_ooookJ_oonf[ooo]Zool30002oookJP06
ogT0oooo0=gooo]Zo`0Gool0Xooo/ol01_oonfX01?l0omkoo`27oookJ_oo06`2oookJP06odd0oooo
nf[oobh0of40oooonf[o0?m50ooonfX01?oR0?oooo]ZoookJ_l0oi87oookJP03ofP0oooonf[ooo]Z
00;ooo]Z00Go603oonKo0?oonf[ooo]Zoon@0009oookJP04oonn0?oonf[oj`3oog00o`Gooo]Z00?o
oeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP05oookJP03oon10?oonf[ooo]Z00Gooo]Z00Go
0=Coo`04oooonf[o0:Woo`28o`02oookJP03o`3oC_l0ocCooo]Z00Gooo]Z00Co0>7oo`3o7Ol0o`So
0?mC1?oonfX00ooo07Wooo]Zool0D@02oookJP0;o`0Iool@0?ooT_l0oookJ_l60?oo0?m=o`0`oon2
o`3ooo]Zo`3oFolao`002?oonfX01?lPo`3o9P3ooookJ_oJo`02oookJP;oo`0C00?oo`2Co`3ioooo
nfX00_oobP000olB0?oo0?lKoookJP03oookJP06o`3ogomho`3oN?l0ogSo0?l0g?oo?ol01?l0:_l6
oomB0003oookJ_l0:_oo02[o00Co02[o00Co?@3oogSo0?mho`3oN?l00_oonfX2o`3o6`;oolX000?o
0?Woool0TooonfX00_oJo`000ol0003o9P3ooookJP03oookJP0?oc7o0?l0oe_o0?n`o`3Xool0odgo
1P3ooi;o0?l@0?oo01Woool0DOl0[Oooo`1ioookJ_l0oe?o0?lM00?ooo]Z00Ko0?m>oookJ_l0R?oo
0:Woo`04ool0e?l2oookJP05oon10?oonf[ooo]ZoookJ_oo02d00_oonfX01OooE`3ooo]Zog00ooo[
0?oookh000?ooo]Z00?ooi00oookJ_lH0?l00_oonfX03OmX0?oooo]ZoookJ_l0oi;ooo]Zo`3oT?oR
0?ooH@3ooookJ_m=0?ooo`1/oookJ_oo08L00_oonfX01?nco`3oo`3MogT0oooo0`02oookJP0Ao`3k
oooonf[o>ol0oon10?ooK03o07Ooool0nOnX0?oooo]Zo`2Voooo0?Kojol0ool60?oonf[o603ooook
J_oo0?`00_oonfX00oooTP3ooaH0oookJP02oookJP03ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooook
J_oonfX01_oonfX01Onio`3ooe80o`3o<ooonf[o02[o00;ooo]Z00Co?ol0o`3Loooonf[oN?l01_oo
nfX01?lB0?oo0?lKoookJ_oobP03oookJP03ool0Tooonf[oo`0C00Cooo]Z00KohOl0om[o0?oonf[o
oo]ZobH0oolPo`0@oookJP03oc7o0?oonf[o0?mK00;ooo]Z00GoP_l0o`3o/Ol0<?oooo]Zo`3oC@02
oookJP03o`H0oooonf[oT_l000Cooo]Z00?o403oo`0IoooonfX00ooonfX01_oo057o5@3ooookJ_l0
[Ooooo]Zool0N@Sooo]Z00?o0?mCoookJ_oonfX08ooonfX002kooo]Z00Coof`0o`3oc?ooP@3o>ol0
1?oonfX00ol0nooooo]ZoookJP08onGo0003o`2Soonco`3ooo]Z00Kooo]Z00?oo`27oookJ_oo06`0
0ooonfX00om=0?ooobh0of40o`02oookJP06o`3oAOoonf[ooo]ZoookJ_oR0?oo0?n@0_oonfX00ol0
oi;ooo]ZoookJP02oookJP?oiOl01?oonfX01OlH0?ooi_l0oookJ_oonf[ooi0000Sooo]Z00Cookh0
oookJ_oonf[oj`3o1_oonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?o
oh40oookJ_oonfX01?oonfX01_l0e?oooo]Zo`04oooonf[o0:Woo`28o`;ooo]Z00?o0?l^o`3oC_oo
nfX01_oonfX00ol0oagooo]Zo`3oD`03oookJP0Bool0NOoonf[o0:goool0DOoonf[o01Wooomi0?l@
0?ooogT0oi;o0?l0j?oo0?m=oomi0?n2o`3ooo]Zo`3oFooonf[o<Ol00ooonfX5oomi0005obH0oooo
N@3of_l0om[o0?oonfX00oooN@02ool0T`;ooo]Z00CoolX0oa80ool0oa_o08ko1OoonfX3ogSo0003
o`3Loooonf[o?ol000;o?ol01_l0:_l2oomi00GoN?l000KoogT0ooo90?oob@3oolT0o`3o6ooobP02
ooo90005ool0Tooo01?of_l0om[o0?n40?l00_lV0?l00ol0003ooo]ZoolX000;oolX00KoogT000Oo
oo]Zo`3o=?l0odkooo]Zo`28ool0ZOoo0=Co00?ooo]Z00Gooh40oookJ_oonf[ooo]Zool0;@02oook
JP;oolT000?oj`3ooonn0?oob@000_oob@09odCo0003o`3oT_oonf[ohP3o00;ooo]Z00GoH@3oooo9
0?oo06coo`27o`3ogP02oookJP0Gok?o0?l0Xoooo`3MoookJ_oo0`3ooo]Zo`3koooonf[o>ol0oon1
0?l0oi[o07Ooool0nOoonf[oZ03oo`2Voooo0?Kojol0ool60?oonf[o603ooookJ_oo0?`00_oonfX0
0oooTP3ooo]ZoookJP02oookJP03ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX01ooonfX0
1Onio`3ooe80oookJ_oonf[oU?l000;ooo]Z00?o?ol0o`3Loomho`001_oonfX01?lB0?oo0?lKoook
J_oobP03oookJP03onGo0?l0nOooo`0C00Cooo]Z00KoiOl0oookJ_oonf[ooo]ZobH0oolPo`0@oook
JP03oc7o0?oonf[o0?mK00;ooo]Z00CoP_l0o`3o/?l0<?oooo]Z0_oUo`001?oonf[o1P3ooookJ_nB
o`03oookJP03oa00oooUo`3o01Wo00Cooo]Z00Coo`1AoookJ_oonf[o0:go0_oonfX00om4o`3ooo]Z
oookJP04oookJP03oiCo0?oonf[ooo]Z04oooo]Z00Coof`0oookJ_ooP@3o>ol01OoonfX00ol0nooo
oo]ZoookJP02oookJP04ool30?oonf[ooo]Zool0g@;ooo]Z00?o0:?ook?o0?oonfX01OoonfX01?l0
omkoo`27oookJ_oo06`2oookJP06odd0oooonf[oobh0of40oooonf[o0?m50ooonfX01OoR0?oo0?n@
oookJ_oonf[o0?nB00Kooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?ooi_l0oookJP02oookJP03
oon@0?oonf[ooo]Z00Kooo]Z00Cookh0oookJ_o[0?ooL03o1OoonfX00oooE`3ooo]ZoookJP02oook
JP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooh40oookJ_oonfX01?oonfX01Ol0e?oo00CooookJ_l0ZOoo
08So00?ooo]Z00?o0?m>oookJ_oonfX01OoonfX00ol0oago0?l8o`3oD`04oookJP03ool0NOl0[Ooo
o`1A00;ooo]Z00co01Wooa00oooonf[oT_l0o`H0ool0odgo033oo`3o/?n2o`3ooo]Zo`3oFolao`08
oookJP03ob3o0?lV0?oooo]Z00;of_l00_oonfX00ooo01?oo`2Cool0T`02oookJP04ooo:0?lB0?oo
0?lKo`2>o`Gooo]Z00Go0?oOogSo0?mho`3oN?l0oookJP03ocoo00Ko02[o0_loo`05ogSo00?ooo]Z
00Oo08koo`3o6olB0?ooolX0oookJ_oo01?oo`2C00;of_l000CohOl0obH0oolV0?oo00000ooonfX0
3olao`3o0?mKo`3o/?l0j?oo0?m=o`H0oonBo`3o403oo`0Ioooo057o0:goool0NOoonf[o0?mCo`3o
7@03oookJP06o`3oC_oonf[o08Soo`2Yool01?oo0=Co0_oonfX00oooP@3ooo]ZoookJP02oookJP07
ool0;Ooonf[ooeL0oookJ_m`0?ooj`3ooonn0004oookJP05oon@0?l0M?oo603ooookJ_mX0?l00ooo
nfX02_l0oi;ooo]Zon80oooonf[oH@3oool^0?m=0?ooo`1/ool0Qol0omh2oookJP0Bok?o0?oo0=go
N@3oool30?oonf[o0?_ooookJ_lko`3ooh40oom/0?l0Mooooo]Zool0nOnX0?oo0:KooookJ_o[o`3o
o`H00_oonfX01_lH0?oooo]Zool0o?oonf[ooi80oolF00?ooo]Z00?oo`3ZoookJ_oonfX02ooonfX0
0ol0Looooo]ZoookJP06oookJP05okWo0?ooDP3ooo]ZoookJ_l0:_l00_oonfX00oloo`3o0=coogSo
0007oookJP03o`3o6ooonf[oolX000?ooo]Z00Coo`2Co`3ioooonf[oo`0C0ooonfX01ooQo`3of_l0
oookJ_oonf[o9P3oob3o0?n40?l04?oonfX00olao`3ooo]Zo`3oF`02oookJP05oh;o0?l0ok7o033o
oookJ_l0odd00_oonfX00ol60?ooo`3eoi;o0003oookJP03oa00oooonf[o01Wo00?ooo]Z00Ooo`1A
oaD0oooonf[ooo]Zo`2]oooonf[oo`1i00Oooo]Z00?o0?mCoookJ_oonfX09?oonfX002kooo]Z00Co
of`0oookJ_ooP@3o>ol01OoonfX00ol0nooooo]ZonGo0007onGo0003o`2Soonco`3oW`3o00Kooo]Z
00?oo`27oookJ_nDo`001?oonfX01Om=0?ooH@3ooookJ_oonf[o0?m500?ooo]Z00GohP3oo`3oT?oo
nf[ooo]Zo`3oTP04oookJPCoiOl00ooonfX01OlH0?ooi_l0oookJ_oonf[ooi0000Wooo]Z00?ookh0
oookJ_o[0?l01_oonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40
oookJ_oonfX00ooonfX00ol0e?oooo]Zo`04o`02oookJP06o`2Yoooonf[ooo]ZoookJ_l0odko0?ld
1_oonfX01?l0hOoo0?lMoookJ_l0oe<3oookJP0Aool0NOl0[Ooo5@3oool0DOoonf[oogT0oa00oooo
N@3oT_l0o`H0ool0j?oo0?m=oh;o0?l0ok3ooo]Zo`3oFolao`001?oonfX2oomi00?ooo]Z00?o9P3o
oookJ_oonfX00_oJo`04oomi00;oo`2C00?oogT0ooo:0?oobP000ol0oa/6oookJPgoN?l01OooN@00
1_oob@3o0?lKo`3o6ol0oa_oolX0ooo900;oo`2C00GoolT0om[o0?oob@3o8?l0obH0o`03o`0000Oo
obP000GoT_l0oolX0?oo:03oobP0ool0D@08oomi0005o`3oC_l0obko08Soo`2Yool0e?l00ooonfX0
1OooP@3ooo]ZoookJ_oonf[oo`0]00;ooo]Z00GoiOl0ooo90?m`0?ooj`3ooonn0002ooo90003oook
J_m4o`3oA?l000OoA?l000[o0?nBo`3oT?oR0?oooo]Zof40oooob@3oobh0ool0K?oo08Oo0?oN0_oo
nfX01?nco`3oo`3Mooo90?oo0`02oookJP0>o`3koooonf[o>ol0oon10?oonf[o07Ooool0nOnX0?oo
0:KooookJ_oo0?Kojol0ool60?lH0?l2oookJP04ool0o?oonf[ooo]ZoonB00Cooo]Z00?oo`3Zoook
J_oonfX02_oonfX00ol0Looooo]ZoookJP06oookJP05okWo0?oonf[ooe80oookJ_nDo`000_oonfX0
1?loo`3ooo]Zo`3Loomho`06oookJP04oa80ool0oa_ooo]Zooo:00?ooo]Z00?oiOl0ool04ooonfX0
1?oonfX01_oUo`3ooo]ZoookJ_oonf[o9P3oob3o013ooo]Z00?o<Ol0o`3oFooonfX00_oonfX01?n2
o`3o0?n`o`0`oooonfX2onGo0004oookJ_l60?oooo]Zoi;o00?ooo]Z00?o403oonGo0?l06Ol01?oo
nfX01?oo057ooo]ZoookJ_l0[Ol2oookJP03odCo0?oonf[ooo]Z00Cooo]Z00?oU?l0oookJ_oonfX0
CooonfX01?ooK03ooo]Zoon10?lko`05oookJP03o`3koooonf[ooo]Z00;ooo]Z00Soo`<0oookJ_oo
nf[oN@3oool0gOoonf[o0:?ook?o00Kooo]Z00Co0?oNool0Qooonf[oo`1/0ooonfX01Om=0?ooobh0
of40oooonf[o0?m500?ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP03ofP0oooonf[ooo]Z
00;ooo]Z00?o603oonKo0?oonfX00_oonfX00oooT03ooo]ZoookJP07oookJP03oonn0?oonf[oj`3o
00Gooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP05oookJP03oon10?oonf[ooo]Z
00Cooo]Z00Go0=Coo`04oooonf[ooo]Zo`2Yo`03oookJP03o`3oC_l0ocCooo]Z00Gooo]Z00Co0>7o
o`3o7Ooonf[o0?mC1?oonfX00ooo07Wooo]Zool0D@02oookJP08oa00oooonf[oT_l0ool0mOl60?oo
0?m=o`0`oon2o`02oookJP03o`3oFolao`3ooo]Z00Oooo]Z00Go8?l0obH0oooonf[ohOl0om[o0002
oookJP;oo`0C0_oo09<00ooonf[oolX0ooo:0003o`3o6`Kooo]Z00?o0?oOogSo0?mho`002_mho`02
o`3og`?ooo]Z00Co08koo`3o6ol0oa_o0?lK0_oobP001?oo01?oo`2Cool0TooJo`02on7o0004obH0
ool0003o0000o`0000;ooo]Z00oo<Ol0o`3oFon2o`3o0>Soo`3oCOl60?ooT_l0oa00ool06Oooo`1A
o`2]oooo07Wooo]Zo`3oDol0oad00ooonfX01_l0odko0?l^oookJ_l0ZOoo00Coo`3Do`?ooo]Z00Oo
oh40oookJ_oonf[ooo]Zool0;Ooonf[ooeL000;ooo]Z00?oL03oon/0oooonfX00ooonfX00oooT03o
oo]ZoaP0o`02oookJP0CofP0oooonf[ooo]Zo`3oT_oonf[o0?n@on80oomQ0?oooo]Zodd0oooo06co
oo]Zool0QooMo`3ooo]Zok?o0?oo0=gooo]ZogT0o`02oookJP0Ao`3koooonf[o>ol0oon10?ooK03o
07OooookJ_oo0?WoZ03oo`2Voooonf[ojol0ool60?oonf[o603ooookJ_oo0?`00_oonfX00oooTP3o
oaH0oookJP02oookJP03ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX01ooonfX02_nio`3o
oe80oookJ_oonf[o02[ooookJ_loo`3ooo]Zo`3Loomho`07oookJP03o`3o6ooonf[oolX000?ooo]Z
00?oo`2Co`3ioooo01<01?oonfX01ooQo`3of_l0oookJ_oonf[o9P3oob3o0?n40?l04?oonfX02_la
o`3o0?mKoookJ_oonf[oP_l0o`3o/?l0ok7o033ooookJ_l0odd2oookJP03o`H0oooo0?GoT_l000?o
oo]Z00?o403ooookJ_l06Ol00ooonfX01?oo057o5@3ooookJ_l0[Ol2oookJP03ool0NOoonf[ooo]Z
00Gooo]Z00?o0?mCoookJ_oonfX09?oonfX002kooo]Z00Goof`0oookJ_ooP@3ooo]Zoc_o0004oook
JP03o`3koooonf[oiOl000OoiOl000?o0:?oonGo0?nco`001_oonfX00ooo08Oooo]ZoiCo0004oook
JP05odd0oomQ0?oooo]ZoookJ_l0odD00ooonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Cooo]Z1?oU
o`03oookJP05oaP0oooVo`3ooo]ZoookJ_ooT0002OoonfX01?oo_P3ooo]Zog00ooo[0?l6oookJP03
oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP04oookJP05
o`3Doooonf[o00CooookJ_l0ZOl00ooonfX00ol0obko0?m>oookJP05oookJP04o`3Qool0oagooo]Z
o`3oD`?ooo]Z00Coo`1ioookJ_l0[Oooo`1A0_oonfX03?ooN@3o403ooomi0?nBo`3o1P3oo`3oCOoo
N@3oP_l0o`3o/?oonf[o0?mKoc7o00?ooo]Z00?oogT0oookJ_oonfX00ooonfX01OlV0?oooo]Zoook
J_oQo`3of_l000GoogT00_oo09<01?ooN@3oolX0oookJ_lB0?l3o`3o6`Kooo]Z3OooN@03o`3o6`03
ooo:0?oob@3oo`2C00;oo`2C00Kooo]Zom[o0?oJo`3oQ03oob3o0?lV0?l3o`0000OoobP000GoT_l0
oolX0?oo:03oobP0ool0D@07oomi0007oookJ_l0ocCo0?m>oookJ_l0ZOoo0=Coo`04o`03oookJP05
oon10?oUo`3oiOl0oookJ_oo02d00_oonfX01?oUo`3oolT0on/0oooo_P02ooo900;ooo]Z2?m4o`00
2_l0oi;ooo]Zo`3oT?oR0?oooo]Zof40oooob@3oo`1/oookJ_oo08L2oookJP07ok?o0?l0Xoooo`3M
oookJ_oo0`3ooo]Zo`3ko`02oookJP0>oc_o0?ooP@3ooo]Zo`1goooonf[oZ03oo`2Voooo0?Kooo]Z
on_o0?oo1P3o603ooookJ_oo0?`2oookJP03oonB0?oo5P3ooo]Z00;ooo]Z00?oo`3ZoookJ_oonfX0
2_oonfX00ol0Looooo]ZoookJP07oookJP05okWo0?ooDP3o0?lcoookJ_nDo`000_oonfX01?loo`3o
0=coocd0oomho`06oookJP04oa80ool0oa_ooo]Zooo:00?ooo]Z00?oiOl0ool04ooonfX01?oonfX0
1_oUo`3ooo]ZoookJ_lV0?oo8?l0oh@0oa3ooo]Z00?o<Ol0o`3oFooonfX00_oonfX01On2o`3o0?n`
o`0`oooonf[oiOl000;ooo]Z00?o1P3ooookJ_nBo`000ooUo`000ol@0?ooiOl0o`0Io`03oookJP04
ool0DOlE0?oooo]Zo`2]o`;ooo]Z00?oA?l0oookJ_oonfX01OoonfX00onDo`3ooo]ZoookJP1?oook
JP05oom/0?oonf[ooh40o`3oc?lko`001?oonfX00ol0nooooo]ZoookJP02oookJP08ool30?oonf[o
oo]ZogT0oooo0=gooo]Zo`2Soonco`06oookJP04o`3og_oo08Oooo]Zool0K0?ooo]Z00GoC@3oool^
0?mQ0?oooo]Zo`3oA@03oookJP05on80ool0oi3ooo]ZoookJ_l0oi801_oonfX00omX0?oooo]Zoook
JP02oookJP03oaP0oooVo`3ooo]Z00;ooo]Z00?ooi00oookJ_oonfX01ooonfX00ooo_P3ooo]Zon/0
o`06oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]Zoook
JP04oookJP05o`3Doooonf[o00CooookJ_l0ZOl01?oonfX00ol0odkooo]ZoookJP04oookJP05o`3Q
ool0oago0?l8oookJ_l0oe<00ooonfX00ooo07Wo0:goool0D@03oookJP08oa00oooonf[oT_l0o`H0
ool0odgo0>SooookJ_n2o`02oookJP03oc7o0?oonf[ooo]Z00Oooo]Z00Co8?l0obH0oooonf[ohOl0
0_oJo`02oookJP08ool04ol0nOooo`2Cool0Tooonf[oolX0oookJ_l0S_l3o`3o6`Kooo]Z1Ol0oml0
0olm0?oooo]ZoookJP04oookJP04o`2>ool0oa_o0?lKo`3o6`;oolX000Cooo]Zool0Tooo09?oo`2C
0_oJo`000ooQo`3o8?l0obH0o`04o`000004oookJ_lao`3o0?mKoh;o00;o0?m=00Go1P3ooi;o0?l@
0?oo01Woool0D@02ool0N@04oookJ_l0oe?o0?lMo`3Qo`;ooo]Z00Ko0?ldo`3oC_oonf[o0:Wooook
J_l0e?l3oookJP03oon10?oonf[ooo]Z00;ooo]Z00Ooo`0]oookJ_ooE`3ooo]Zog00ooo[0?oookh0
00Cooo]Z00Gooi00o`1doolH0?oooo]ZofP0o`03oookJP0:o`3oT_oonf[o0?n@on80oomQ0?ooobh0
odd0oooo06cooo]Zool0Q`;ooo]Z00Ko/ol0ool0gOmi0?ooo`<0oookJ_l0nol2oookJP0Coc_o0?oo
P@3ooo]Zo`1goooo0?WoZ03oo`2Voooonf[oo`3fon_o0?oo1P3ooo]ZoaP0oooonf[oo`3loookJ_oo
TP3ooo]ZoolF0003oookJP03ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX01ooonfX01?oo
DP3o0?lcoookJ_l0:_l2oookJP04ocoo0?l0g?oooo]ZogSo00Kooo]Z00Co4P3oo`3o6ooonf[oolX0
0ooonfX00ooo09?ooo]Zool04`04oookJP07on7o0?oJo`3ooo]ZoookJ_lV0?oo8?l0oh@0o`0@oook
JP0?oc7o0?l0oe_ooo]ZoookJ_n2o`3o0?n`oookJ_l0<?oo0>Soo`3oCOoonf[o1P3ooookJ_oo0?Go
T_l000?ooo]Z00?o403ooookJ_l06Ol00ooonfX01?oo057o5@3ooookJ_l0[Ol2oookJP03ool0NOoo
nf[ooo]Z00Gooo]Z00?o0?mCoookJ_oonfX09?oonfX002[ooo]Z00Wo07OooookJ_oonf[ooo]Zo`3o
V_ooK03ooh40oookJ_lko`001?oonfX00ol0noooiOl0onGo0007onGo0003o`2SoooUo`3o/ol000Ko
oo]Z00Co0?oNool0QonDo`3oU?l00ooonfX01Om=0?ooH@3ooookJ_oonf[o0?m500Cooo]Z00CohP3o
oookJ_oonf[o0?nB1?oonfX5onGo00;ooo]Z00?o603oodCo0?oonfX00_oonfX00oooT03ooo]Zoook
JP06oookJP04oonn0?oonf[ooo]Zon/0o`Kooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]Z
oookJP05oookJP03oon10?oonf[ooo]Z00Cooo]Z00Ko0=CooookJ_l01?oooo]Zo`2Yool0R?l3oook
JP03o`3oC_l0ocCooo]Z00Gooo]Z00Co0>7oo`3o7Ooonf[o0?mC0ooonfX04_oo07Wo0:gooaD0oooo
057ooo]Zoomi0?l@0?ooogT0oi;o0?l60?ooogT0o`3oCOooN@3oP_l0ooo90?oonf[o0?mKoc7o00Wo
oo]Z00Co9P3ooh@0oooonf[oogT00_oJo`05oomi00;oo`2C1OooN@03o`3o6`googT00ol0oa/00ooo
bP3oolT0ooo90002ool0T`;oo`0C0_oJo`02oh@0o`;o9P3o00Cooo]Zo`000?l0003o00001?oo:000
0ol0odgoobP0oi;o0003oolX0003ool0DOooN@3oogT000GoogT000Oooo]Zo`3o=?l0odkooo]Zo`2Y
oooonf[o0=Co00?ooo]Z00?ooh40oookJ_oUo`000_oUo`02oookJP06onGo0?oob@3oj`3oooo90?oo
_P3oolT00ooonfX7odCo000;oookJ_l0oi;ooo]Zon80oooonf[o0?m5of40oooonf[oo`1/ool0Qol0
omh00_oonfX05?nco`3oo`3Mooo90?oonf[oo`<0oookJ_l0nooooo]Zooo90?ooP@3o0?nJo`1goooo
0?Wooo]ZojP0oooonf[oo`3fon_o0?oo1P3o603o0_oonfX01?oo0?cooo]ZoookJ_ooTP04oookJP03
ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX01ooonfX01Onio`3ooe80oookJ_oonf[oU?l0
00;ooo]Z00?o?ol0o`3Loomho`001_oonfX01?lB0?oo0?lKoookJ_oobP04oookJP03onGo0?oo01?o
oo]Z00?ooo]Z00OoiOl0on7o0?oonf[ooo]ZobH0oolPo`3oQ03o00oooo]Z00?o<Ol0oookJ_l0oe/0
0ooonfX00on2o`3o033ooookJP02onGo00;ooo]Z00?o1P3ooi;o0?oo0?D00ooUo`000ol@0?ooiOl0
o`0Io`03oookJP04ool0DOoUo`3ooo]Zo`2]o`;ooo]Z00?oA?l0oookJ_oonfX01OoonfX00onDo`3o
oo]ZoookJP1;oookJP09o`1goooonf[ooo]ZoookJ_l0oi[oof`0oon10?l0olco>ol000Cooo]Z00?o
0?_ooookJ_oonfX00_oonfX02?oo0`3ooo]ZoookJ_mi0?ooo`3MoookJ_l0Xooo/ol01_oonfX01?oM
o`3oo`27oookJ_oo06`3oookJP05odd0oooo;P3oH@3ooookJ_l0odD01?oonfX01?oR0?oooo]Zoook
J_l0oi87oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603ooookJ_oonf[ooo]Zoon@0009oookJP04
oonn0?oonf[oj`3oog00o`Gooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP05oook
JP03oon10?oonf[ooo]Z00Gooo]Z00Go0=Coo`04oooonf[o0:Woo`28o`03oookJP03o`3oC_l0ocCo
oo]Z00Gooo]Z00Co0>7oo`3o7Ooonf[o0?mC0ooonfX01?oo07Wo0:gooaD0oooo0542oookJP09oa00
oooonf[oT_l0ool0mOl60?oo0?m=o`3Xool0ok3oP_l000;ooo]Z00?o<Ol0oookJ_oonfX01ooonfX0
0olPo`3o9P3ooookJP02on7o0003om[o0?oonf[ooo]Z00;oo`0C00?o0?Woool0Tooo09<01?oobP00
1?lB0?oo0?lKo`3o6ol0oa/2o`2>o`Kooo]Z1Ol0S_l3o`3o6`;oolX000Gooo]Zool0Tooo09?oo`2C
ool04`02om[o0005on7o0?n40?oo9P3oobH0oooonfX01?l000002olao`3o0?mKoh;o0?l0odgo1P3o
oookJ_nBo`3o403ooaD0oooo057oo`1i00;ooo]Z00?o0?mCo`3o7Ol0hOl00ooonfX01_l0odkooo]Z
o`2Yoooonf[o00Coo`3Do`;ooo]Z00?ooh40oookJ_oonfX00_oonfX00ooo02gooo]ZoomG0002oook
JP03on/0oooo_P3ooo]Z00?ooo]Z00?ooi00oookJ_lH0?l00_oonfX09_mX0?oooo]ZoookJ_oonf[o
0?nBo`3oT?oR0?oo0?m5of40oom=0?ooo`1/oookJ_oo08Oo0?oNoookJ_nco`3o0:?oool0gOmi0?oo
o`<0oookJ_l0nooooo]Zoc_o0?ooP@3oof`0o`1goooonf[oo`3iojP0ool0Y_oooo]Zon_o0?oo1P3o
oo]ZoaP0oooonf[oo`3l0_oonfX00oooTP3ooaH0oookJP02oookJP03ool0j_oonf[ooo]Z00_ooo]Z
00?o07?ooookJ_oonfX01_oonfX01Onio`3ooe80oookJ_oonf[o02[o00;ooo]Z00Co?ol0o`3Loomh
o`3o?@3o1_oonfX00ol0oa_ooo]Zooo:0004oookJP03ool0Tooonf[oo`0C00Cooo]Z00Kof_l0oook
J_oonf[ooo]ZobH0oolPo`0@oookJP03oc7o0?oonf[o0?mK00;ooo]Z00GoP_l0o`3o/?l0<?oooo]Z
o`3oC@02oookJP03o`H0oooonf[oT_l000Cooo]Z00?o403ooookJ_l06Ol00ooonfX01_oo057o5@3o
oookJ_l0[Ooooo]Zool0N@Sooo]Z00?o0?mCoookJ_oonfX09?oonfX002[ooo]Z00Wo07OooookJ_oo
nf[ooo]Zo`3oV_ooK03ooh40oookJ_lko`001?oonfX00ol0noooiOl0onGo0007onGo0003o`2SoooU
o`3o/ol000Kooo]Z00Co0?oNool0QonDo`3oU?l00ooonfX01Om=0?ooobh0of40oooonf[o0?m500Co
oo]Z00CohP3ooookJ_oonf[o0?nB1?oonfX5onGo00;ooo]Z00?o603oodCo0?oonfX00_oonfX00ooo
T03ooo]ZoookJP06oookJP04oonn0?oonf[ooo]Zon/0o`Kooo]Z00?ooeL0oookJ_oonfX00ooonfX0
0ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Cooo]Z00?o0=CooookJ_l01?l00_oonfX0
1_l0ZOoooo]ZoookJ_oonf[o0?m>o`3o=0Kooo]Z00Go0>7oo`3o7Ooonf[ooo]Zo`3oD`02oookJP05
ool0NOoonf[o0:gooaD0oooo05400_ooN@002ol@0?ooogT0oi;o0?l60?ooogT0o`3oCOn2o`3o0?n`
ooo90?l0oe_o<Ol000[ooo]Z0_lV0?l2oookJP03oomi0?oJo`3of_l000GoogT00_oo09<6oomi00go
0?lK00?oolX0oomi0?ooN@000ooo09<2ool04`06oookJ_oJo`3ohOl0oh@0oooonf[o9P3o0ooonfX2
o`0000CoobP000Co0?m=oolX0?nBo`3o403o0_oo:0000ooo057oobP0oomi0004oomi00;ooo]Z00Oo
0?ldo`3oC_oonf[ooo]Zo`2Yool0e?oo00Co00;ooo]Z00?ooh40oookJ_oUo`001OoUo`001Ooonf[o
olT0on/0oooo_P3oolT000?ooo]Z1om4o`005?oonf[o0?nBoookJ_l0oi3ohP3ooookJ_mQ0?ooolT0
ool0K?oonf[oo`27omgo0?oonf[o/ol0o`2Soooo0=gooo]Zool30?oonf[o0?_o0_oonfX03?oob@3o
oh40oookJ_l0Moooo`3iojP0ool0Y_oooo]Zool0m_o[o`3oo`H0oaP0o`;ooo]Z00Coo`3loookJ_oo
TP3ooaH01?oonfX00ooo0>[ooo]ZoookJP0:oookJP03o`1coooonf[ooo]Z00Oooo]Z00Co^Ol0oomB
0?oonf[oU?l00_oonfX01?loo`3ooo]Zo`3Loomho`06oookJP04oa80ool0oa_ooo]Zooo:00?ooo]Z
00?oiOl0o`3ioooo01<01?oonfX01_oUo`3ohOl0oookJ_oonf[o9P3oob3o013ooo]Z00?o<Ol0oook
J_l0oe/00_oonfX01?n2o`3o0?n`o`0`oooonfX2onGo0005oookJ_l60?oooo]Zoi;o0?oo0?D00_oU
o`000ol@0?ooiOl0o`0Io`03onGo0005oookJ_oo057oiOl0oookJ_l0[Ol00_oonfX00om4o`3ooo]Z
oookJP05oookJP03oiCo0?oonf[ooo]Z04_ooo]Z00Wo07OooookJ_oonf[ooo]Zo`3oV_ooK03ooh40
o`3oc?lko`001?oonfX00ol0nooooo]ZoookJP02oookJP08ool30?oonf[ooo]ZogT0oooo0=gooo]Z
o`2Soonco`06oookJP05omgo0?oo08Oooo]ZoookJ_oo06`00_oonfX01Om=0?oooo]Zool^0?mQ0?oo
0?m500Cooo]Z00CohP3ooookJ_oonf[o0?nB1ooonfX00omX0?oooo]ZoookJP02oookJP05oaP0ool0
M?oooo]ZoookJ_ooT0002OoonfX01?oo_P3ooo]Zo`3o1Oo[0?l5oookJP03oomG0?oonf[ooo]Z00?o
oo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP04oookJP05o`3Dool01?oooo]Zoook
J_l0ZOl00ooonfX00ol0odko0?l^o`3o=005oookJP05o`3Qool0o`So0?lMoookJ_l0oe<00ooonfX0
1?oo07Wo0:gooaD0oooo0542oookJP08oa00oooonf[oT_l0o`H0oooonf[o0?m=o`0`oon2o`02oook
JP03oc7o0?oonf[ooo]Z00Sooo]Z00Go8?l0obH0oolV0?oooo]Zon7o0002om[o00;ooo]Z00?oo`0C
oookJ_l0nOl00_oo09<2oookJPCoolX03Ol0oa/2ooo:0004oookJ_oo09?oo`2Cool0T`;oo`0C00?o
oo]Zom[o0?oQo`000_n40?l01?lV0?oooo]ZoookJ_oonfX3o`00000;oc7o0?l0oe_oP_l0o`3oCOl6
0?ooo`3eoi;o0?l@0?oo5@3oool0DOoo07T00_oonfX00ol0oe?o0?lMo`3Qo`03oookJP06o`3oC_oo
nf[ooo]Zo`2Yoooonf[o0=Co0ooonfX01OooP@3ooo]ZoookJ_oonf[oo`0]00;ooo]Z00GooeL0oook
J_m`0?ooj`3ooonn0004oookJP05oon@0?l0M?oo603ooookJ_mX0?l00ooonfX04_l0oi;ooo]Zo`3o
T?oR0?ooH@3oool^0?m=0?ooo`1/oookJ_oo08OogOl0oookJ_nco`3oo`3MogT0oooo0`3ooo]Zo`3k
o`;ooo]Z00oo>ol0oon10?ooK03o07OooookJ_oo0?WoZ03oo`2Voooonf[ojol0ool60?oonf[o603o
oookJ_oo0?`00_oonfX00oooTP3ooaH0oookJP02oookJP03ool0j_oonf[ooo]Z00[ooo]Z00?o07?o
oookJ_oonfX01ooonfX02_nio`3ooe80oookJ_oonf[o02[ooookJ_loo`3ooo]Zo`3Loomho`07oook
JP03o`3o6ooonf[oolX000?ooo]Z00?oo`2Co`3ioooo01<01OoonfX01_oJo`3ooo]ZoookJ_lV0?oo
8?l0oh@0oa3ooo]Z00?o<Ol0o`3oFooonfX00_oonfX01On2o`3o0?nao`0`oooonf[o0?m=00;ooo]Z
00?o1P3ooookJ_nBo`000ooonfX00ol@0?ooo`1Zo`0Io`04oookJP06ool0DOlE0?oooo]Zo`2]oooo
nf[oo`1i2?oonfX00ol0oe?ooo]ZoookJP0ToookJP00:_oonfX02Ol0Mooooo]ZoookJ_oonf[o0?nJ
oom/0?ooP@3ooo]Zoc_o0004oookJP03o`3koooUo`3oiOl000CoiOl00_oonfX01OoUo`3o0:?oonGo
0?nco`3oiOl000Gooo]Z00?o0?oNool0QonDo`000_nDo`02oookJP05odd0oooo;P3oH@3ooookJ_l0
odD01?oonfX01?oR0?oooo]ZoookJ_l0oi84oookJPKoiOl00_oonfX01OlH0?ooA?l0oookJ_oonf[o
oi0000Sooo]Z00Gookh0oookJ_oonf[oL03oon/0o`06oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?o
o`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP03oookJP03o`3Doooonf[o00Co00;ooo]Z00?o
0:WooookJ_oonfX00_oonfX00ol0odko0?ldoookJP05oookJP04o`3o7Ooonf[ooo]Zo`3oD`;ooo]Z
00Goo`1ioookJ_l0[Ooooo]Zool0D@02oomi0007oa00ooooN@3oT_l0oomi0?l60?oo0?m=o`3Xo`02
oomi0003ooo90?l0oe_o<Ol000[ooo]Z00Co8?l0obH0oolV0?oooo]Z0_ooN@000ooJo`3oogT0oomi
0004oomi00;oo`2C3?ooN@001?lB0?oooo]ZoookJ_oonfX4ool0T`04ooo90?oo01?oogT0on7o00;o
f_l00_n40?l2obH0o`Cooo]Z00Co0000oolX0?oo:03o0?mK0_l0odd2oi;o0005oa00oooo:03oobP0
ool0DOoo:0001OooN@02oookJP07o`3o=?l0odko0?l^oookJ_l0ZOoo0=Coo`04o`03oookJP03oon1
0?oonf[oiOl000KoiOl000?oj`3oooo90?oo_P001?oonfX6odCo00;ooo]Z00?o0?nBoookJ_oR0?l0
0_oonfX01OmQ0?oooo]Zool0K?oo08Oo0?oN00;ooo]Z01Co/ol0ool0gOoob@3ooo]Zool30?oonf[o
0?_ooookJ_oob@3ooh40o`3oV_oonf[o07OooookJ_nX0?oo0:Koool0m_o[o`3ooo]Zool600;ooo]Z
00Coo`3loookJ_oonf[ooi801?oonfX00ooo0>[ooo]ZoookJP0:oookJP03o`1coooonf[ooo]Z00Oo
oo]Z00Go^Ol0oomB0?l0oc?ooo]ZoiCo0002oookJP04ocoo0?l0g?oo?@3oogSo00Kooo]Z00Co4P3o
o`3o6ooonf[oolX00ooonfX00ooUo`3oo`0CoookJP04oookJP06onGo0?oonf[ooo]ZoookJ_lV0?oo
8?l04?oonfX00ooUo`3o0?mKoookJP02oookJP04oh;o0?l0ok3o033ooookJP;oiOl000Gooo]Zo`H0
oooonf[oT_l0oookJP02onGo0003oa00oooUo`3o01Wo00?oiOl000Gooo]Zool0DOoUo`3ooo]Zo`2]
o`02oookJP03odCo0?oonf[ooo]Z00Cooo]Z00?oU?l0oookJ_oonfX0C?oonfX02Ol0Mooooo]Zoook
J_oonf[o0?nJoom/0?ooP@3o0?o<oc_o0004oookJP03o`3koooonf[ooo]Z00;ooo]Z00Woo`<0oook
J_oonf[ooo]Zool0gOoonf[o0:?ook?o0?nO0?l01OoonfX01OoMo`3oo`27oookJ_oonf[oo`1/00;o
oo]Z00GoC@3ooookJ_oo;P3oH@3oo`3oA@04oookJP04on80oooonf[ooo]Zo`3oTPOooo]Z00?oJ03o
oookJ_oonfX00_oonfX00olH0?oo07CooookJP02oookJP03oon@0?oonf[ooo]Z00Kooo]Z00Cookh0
oookJ_l0o`Goj`3o1_oonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?o
oh40oookJ_oonfX01?oonfX01Ol0e?oo00CooookJ_oonf[o0:Wo00Cooo]Z00?o0?m>o`3o=?oonfX0
1OoonfX01?l0hOoo0?lMoookJ_l0oe<3oookJP04ool0NOl0[Ooooo]Zool0D@;ooo]Z00So403oo`0I
oonBo`3oo`3eo`H0ool0odgo0>Soo`3o/0;oP_l000?ooo]Zoc7o0?oonfX02OoonfX2ob3o00;o9P3o
00Gooo]Zon7o0?oJo`3ohOl0oookJP04ool04`Coo`2C0ooonfX7ooo:0004oa80oooonf[ooo]Zoook
JPCoo`2C0_oo01<2oookJP;of_l000CohOl0oh@0oolV0?oo9P3o1?oonfX2o`000005oc7o0?l0oe_o
P_l0o`3oCOl60?l00_nBo`001?l@0?oo5@3oool0DOoo07T3oookJP03o`3oDol0hOoooo]Z00;ooo]Z
00Ko0?m>o`3o;_oonf[o0:WooookJ_l0e?l3oookJP03oon10?oonf[ooo]Z00;ooo]Z00?oo`0]oook
J_ooE`000_oonfX00oo[0?oookh0oookJP03oookJP03oon@0?oonf[o603o00;ooo]Z02CoJ03ooook
J_oonf[ooo]Zo`3oT_l0oi3ohP3ooookJ_mQ0?ooC@3oool0K?oonf[oo`27o`3og_oonf[o/ol0o`2S
oooo0=goN@3oool30?oonf[o0?_ooookJ_lko`3ooh40oom/0?oonf[o07Ooool0nOnX0?oo0:Kooook
J_o[o`3ooo]Zool60?lH0?l2oookJP04ool0o?oonf[ooi80oolF00Cooo]Z00?oo`3ZoookJ_oonfX0
2_oonfX00ol0Looooo]ZoookJP07oookJP0:oomB0?l0oc?ooo]ZoookJ_l0:_oooo]Zocoo0?l0g?oo
oo]ZogSo00Kooo]Z00Co08koo`3o6ooonf[oolX00ooonfX00ooo09?ooo]Zool04`04oookJP07on7o
0?oJo`3ooo]ZoookJ_lV0?oo8?l0oh@0o`0@oookJP03oc7o0?l0oe_ooo]Z00;ooo]Z00GoP_l0o`3o
/Ol0<?oooo]Zo`3oC@02oookJP03o`H0oooo0?GoT_l000?ooo]Z00?o403oool0J_l06Ol00ooonfX0
1?oo057o5@3ooookJ_l0[Ol2oookJP03ool0NOoonf[ooo]Z00Gooo]Z00?o0?mCoookJ_oonfX09Ooo
nfX002_ooo]Z00So07OooookJ_oonf[o0?nJoom/0?ooP@3ooo]Zoc_o00Cooo]Z00?o0?_oonGo0?oU
o`000ooonfX00ooUo`3ooo]ZoookJP02onGo0003o`2Soonco`3oiOl000Gooo]Z00?o0?oNool0QonD
o`000onDo`02oookJP04odd0oomQ0?oooo]Zo`3oA@Cooo]Z00CohP3ooookJ_oonf[o0?nB1?oonfX6
onGo00;ooo]Z00Go603oodCo0?m4o`3ooo]Zoon@0009oookJP04oonn0?oonf[o0?l5on/0o`Kooo]Z
00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP05oookJP03oon10?oonf[ooo]Z00Cooo]Z
00?o0=CooookJ_l01?l00_oonfX01_l0ZOoooo]ZoookJ_oonf[o0?m>o`3o=0Kooo]Z00Go0>7oo`3o
7Ooonf[ooo]Zo`3oD`02oookJP05ool0NOoonf[o0:gooookJ_oo05400_ooN@001Ol@0?oooo]Zoi;o
0?l60?oooo]Z00;o0?m=0oooN@000ol0oe_o<Ol0oc7o000:oookJP05ob3o0?lV0?oo9P3oobH0oooo
N@000ooJo`04oomi00?oo`0C2OooN@05ool0T`GoolT00ooJo`001?n40?oo9P3oobH0oolV0?l5oook
JP07oc7o0?oo:03o0?mKoh;o0?l0odgoobP0oi;o0005oomi00;oobP00oooN@002_l0o`Sooo]Zoook
J_oonf[o0?ldo`3oC_oonf[o0:WooookJ_l0e?l3oookJP03oon10?oonf[ooo]Z00KoiOl000?oL03o
on/0oooo_P001OoonfX5odCo00;ooo]Z01?o0?nBoookJ_l0oi3ohP3ooookJ_mQ0?ooolT0ool0K?oo
nf[oo`27o`3og_oonf[oW`3ook?o0?oo0=gooo]Zool30?oonf[o0?_o00;ooo]Z00coolT0oon10?oo
nf[o07Ooool0nOoonf[oZ03ooookJ_oo0?Kojol0ool60?lH0?l2oookJP04ool0o?oonf[ooo]ZoonB
00Cooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ol0Looooo]ZoookJP07oookJP0:okWo0?ooDP3ooo]Z
oookJ_nDo`3ooo]Zocoo0?oonf[o0=coogSo00Kooo]Z00CoiOl0o`3o6ooonf[oolX01?oonfX00ooU
o`3oo`0CoookJP03oookJP07onGo0?oQo`3ooo]ZoookJ_lV0?oo8?l0oh@0o`0@oookJP03onGo0?l0
oe_ooo]Z00;ooo]Z00GoP_l0o`3o/?l0<?oooo]ZonGo0002oookJP04o`H0oooonf[oT_l0oookJP;o
iOl000?o403oonGo0?oUo`000_oUo`02oookJP03ool0DOoonf[o0:go00;ooo]Z00?oA?l0oookJ_oo
nfX01OoonfX00onDo`3ooo]ZoookJP1=oookJP08o`1goooonf[ooo]Zo`3oV_ooK03ooh40o`3oc?lk
o`05oookJP03o`3koooonf[ooo]Z00;ooo]Z00Coo`<0oookJ_oonf[oo`3M0_oonfX00ol0Xooo/ol0
oookJP04oookJP05omgo0?oo08Oooo]ZoookJ_oo06`00ooonfX01?m=0?ooobh0of40ool0odD4oook
JP04on80oooonf[ooo]Zo`3oTPOooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?ooi_l0oookJP02
oookJP03oon@0?oonf[ooo]Z00Oooo]Z00Cookh0o`3o1Oo[0?ooL03o1OoonfX00oooE`3ooo]Zoook
JP02oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX01OoonfX01Ol0e?oo00Cooook
J_oonf[o0:Wo00?ooo]Z00?o0?m>o`3o;_l0oc@01OoonfX01Ol0hOoo0?l8o`3o7Ooonf[o0?mC00?o
oo]Z00Coo`1io`2]oooonf[oo`1A0_oonfX01Ol@0?oooo]Zoi;o0?nBo`3o1P3o00;o0?m=00Co0?n`
oookJ_n2o`3ooo]Z0_lao`0:oookJP;o8?l00_lV0?l01?oonf[of_l0om[o0?oJo`03oookJPCoo`0C
1Ooo09<4o`3io`Goo`2C00Gooo]Zool04ooo01?oo`0CoookJP03om[o0004oookJ_lV0?oo9P3oobH0
o`Kooo]Z0_lao`001on2o`3o0?m=o`3oCOoonf[oT_l0ool0J_l@0?l00_oo05401_oo07Wooo]Zoook
J_oonf[o0?mCo`3Qo`?ooo]Z00Oo0?ldo`3oC_oonf[o0:WooookJ_l01?oo0=Co00?ooo]Z00Oooh40
oookJ_oonf[ooo]Zool0;Ooonf[ooeL000;ooo]Z00?oL03oon/0oooonfX01?oonfX01OooT03oi_l0
oaP0oooonf[oJ03o00?ooo]Z01;o0?nBoookJ_oR0?oooo]Zof40oooo;P3oC@3oool0K?oonf[oo`27
o`3og_oonf[o/ol0ool0gOmi0?ooo`<0oookJ_l0nol2oookJP0?oc_o0?ooP@3oof`0o`1goooonf[o
o`3iojP0ool0Y_oooo]Zon_o0?oo1P3ooo]ZoaP0oooonf[oo`3l00;ooo]Z00?ooi80oolF0?oonfX0
0_oonfX00ooo0>[ooo]ZoookJP0;oookJP03o`1coooonf[ooo]Z00Kooo]Z00_o^Ol0oomB0?oonf[o
oo]Zo`0Zoooonf[o?ol0oookJ_l0g?ooN?l0ocd0o`06oookJP03o`3o6ooonf[oolX000Cooo]Z00?o
o`2CoookJ_oo01<01?oonfX01ooJo`3ooo]ZoookJ_oonf[o9P3oob3o0?n40?l04?oonfX02_lao`3o
0?mKoookJ_oonf[oP_l0o`3o/?oonf[o033oo`3Xool0odd2oookJP03o`H0oooo0?GoT_l000?ooo]Z
00?o403ooookJ_l06Ol00ooonfX01_oo057o5@3ooookJ_l0[Ooooo]Zool0N@Sooo]Z00?o0?mCoook
J_oonfX09OoonfX002_ooo]Z00Wo07OooookJ_oonf[o0?nJoom/0?l0olcooh40oookJ_lko`000ooo
nfX00ol0nooooo]ZoookJP03oookJP03onGo0?oonf[ooo]Z00;oiOl000Co0:?ook?o0?nO0?ooiOl0
1?oonfX00ol0omkoo`27oiCo0003oiCo00;ooo]Z00CoC@3oof40oooonf[o0?m51?oonfX01?oR0?oo
oo]ZoookJ_l0oi84oookJPOoiOl000Kooo]ZoaP0oom4o`3oA?l0oookJ_ooT009oookJP04oonn0?oo
nf[o0?l5on/0o`Kooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP04oookJP03oon1
0?oonf[ooo]Z00Cooo]Z00?o0=CooookJ_l01?l00_oonfX00ol0ZOoooo]ZoookJP02oookJP03o`3o
C_l0ocCooo]Z00Gooo]Z00Co0?lMoookJ_oonf[o0?mC0_oonfX03ooo07Wooo]Zo`2]oooonf[oo`1A
oomi0?oonf[o01Wooa00oooonf[oT_l0o`H0oooonf[o0>Soo`3oC@03oomi0003o`3oFooob@3o<Ol0
00[ooo]Z00?oQ03oob3o0?lPo`000_lV0?l2oomi00?of_l01?ooN@000ooonf[oo`0Coomi0006oomi
00?oo`0C1?oob@03om[o0004oookJ_lV0?oo9P3oobH0o`Kooo]Z0_lao`001_l0oe_oP_l0oh;o0?l0
odgoobP0oi;o00GoogT00_oo:003oomi000;o`3o2?oonf[ooo]ZoookJ_l0ocCo0?m>oookJ_l0ZOoo
oo]Zo`3Dool01?l00_oonfX00oooP@3ooo]ZoookJP07onGo0003on/0oooob@3ookh000Cooo]Z00?o
oi00odCo0?m4o`000_m4o`001_mX0?oooo]ZoookJ_l0oi;ooo]Zon80o`;oolT000GoH@3oooo90?oo
06coo`27onGo0002oookJP0Gok?o0?oo0=goolT0oookJ_oo0`3ooo]Zo`3koooonf[oolT0oon10?l0
oi[ooo]Zo`1goooonf[oZ03oo`2Voooo0?Kojol0oookJ_oo1P3o603ooookJ_oo0?`00_oonfX00ooo
TP3ooaH0oookJP03oookJP03ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX01ooonfX01?ni
o`3ooe80oookJ_nDo`02oookJP04ocoo0?oonf[o0=coogSo00Kooo]Z00Co4P3oo`3o6ooonf[oolX0
1?oonfX00ooUo`3oo`0CoookJP03oookJP07onGo0?oQo`3ooo]ZoookJ_lV0?oo8?l0oh@0o`0?oook
JP03onGo0?oonf[o0?mK00?ooo]Z00GoP_l0o`3o/?oonf[ooo]ZonGo0002oookJP04o`H0oooonf[o
T_l0oookJP;oiOl000?o403oonGo0?oUo`000_oUo`001Ooonf[oo`1AonGo0?oonf[o0:go00;ooo]Z
00?oA?l0oookJ_oonfX01OoonfX00onDo`3ooo]ZoookJP1=oookJP09o`1goooonf[ooo]Zo`3oV_oo
K03ooo]Zoon10?oonf[o>ol000Cooo]Z00?o0?_ooookJ_oonfX00_oonfX01?oo0`3ooo]ZoookJ_oo
0=d2oookJP03o`2Soonco`3ooo]Z00Gooo]Z00Coo`27oookJ_oonf[oo`1/0ooonfX01?m=0?ooobh0
of40ool0odD4oookJP04on80oooonf[ooo]Zo`3oTPSooo]Z00?oJ03ooookJ_oonfX00_oonfX01OlH
0?oooo]ZoookJ_oonf[ooi0000Wooo]Z00Cookh0o`3o1Ooonf[oj`3o1OoonfX00oooE`3ooo]Zoook
JP03oookJP03ool0;Ooonf[ooo]Z00Cooo]Z00?ooh40oookJ_oonfX01OoonfX01_l0e?oo00Cooook
J_oonf[o0:Woo`28o`?ooo]Z00?o0?m>o`3o=?oonfX01OoonfX01Ol0hOoo0?lMoookJ_oonf[o0?mC
00;ooo]Z00Coo`1io`2]oooonf[oo`1A0_oonfX01Ol0GOoo403ooookJ_oo0?GoT_l000;ooo]Z00Oo
0?m=o`3o/?l0ok3oP_l0oookJ_l0oe_o<Ol000[ooo]Z00?oQ03oob3o0?lPo`000_lV0?l2oookJPCo
f_l01?oonfX4ool04`Coo`2C1_oo01<01Ooonf[of_l0om[o0?oJo`3ohOl000?o9P3o1ooonfX2oc7o
000;o`000?n2o`3o0?m=o`3Xoooo0?GoT_l0o`0Iool@0?ooo`1AoookJ_oo07T00ooonfX00ol0oe?o
0>7ooookJP02oookJP04o`3o=?l0odkooo]Zo`2Yo`;ooo]Z00Go0=CooookJ_oonf[ooo]Zoon10004
oookJP03ool0;Ooonf[ooeL000;ooo]Z00?oj`3ooonn0?oonfX00ooonfX00oooT03ooo]ZoaP0o`02
oookJP0WofP0oooonf[ooo]ZoookJ_l0oi;ooo]Zon80oooonf[oH@3oodd0oooo06cooo]Zool0Qol0
omkooo]Zok?o0?l0Xoooo`3MogT0oooo0`3ooo]Zo`3koooonf[o>ol0oon10?ooK03ooo]Zo`1goooo
0?WoZ03oo`2Voooonf[ojol0oookJ_oo1P3ooo]ZoaP0oooonf[oo`3l00;ooo]Z00?ooi80oolF0?oo
nfX00_oonfX00ooo0>[ooo]ZoookJP0:oookJP03o`1coooonf[ooo]Z00Oooo]Z00_o^Ol0oomB0?oo
nf[ooo]Zo`0Zoooonf[o?ol0oookJ_l0g?ooN?l0ocd0o`06oookJP03o`3o6ooonf[oolX000Cooo]Z
00?oo`2Cool04ooonfX01?oonfX01ooJo`3ooo]ZoookJ_oonf[o9P3oob3o0?n40?l03ooonfX00ola
o`3o0?mKoookJP02oookJP0;oh;o0?l0ok3o033ooookJ_l0j?oo0?m=oookJ_l60?oooo]Zool0mOnB
o`000ooonfX00ol@0?oooo]Zo`0Io`03oookJP06ool0DOlE0?oooo]Zo`2]oooonf[oo`1i2?oonfX0
0ol0oe?ooo]ZoookJP0UoookJP00:ooonfX02Ol0Mooooo]ZoookJ_l0oi[oof`0o`3oc?ooP@3ooo]Z
oc_o0003oookJP03o`3koooonf[ooo]Z00?ooo]Z00?oiOl0oookJ_oonfX00_oUo`001?l0Xooo/ol0
oil0oooUo`04oookJP03o`3og_oo08OoU?l000CoU?l000Gooo]Zodd0oooonf[oH@3oo`3oA@04oook
JP04on80oooonf[ooo]Zo`3oTPCooo]Z2?oUo`001_lH0?ooA?l0odCo0?m4o`3ooo]Zoon@00Sooo]Z
00Gookh0oookJ_oonf[o0?l5on/0o`05oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oo
nfX01?oonfX00oooP@3ooo]ZoookJP05oookJP06o`3Dool01?oooo]ZoookJ_l0ZOoo08So0ooonfX0
0ol0odko0?ldoookJP05oookJP05o`3Qool0oagooo]ZoookJ_l0oe<00_oonfX01Ooo07Wooo]Zo`2]
oooonf[oo`1A00;ooo]Z00Co01Wooa00oooonf[oT_l00_l60?l00ol0j?oo0?m=oomi0002oomi00;o
0?mK0_lao`0:oookJP03oh@0oolPo`3o8?l000;o9P3o0oooN@03om[o0004oomi0?oonf[ooo]Zoook
JPKoogT000Cooo]Zooo90?oob@3oolT00ooJo`001_oob@3o9P3oobH0oolV0?ooQ03ooookJP;oolT0
1?oonfX01?lao`3o0?mKo`3oFon2o`02o`3oC@;oT_l01_ooN@001Ooo:03oogT0oomi0?ooN@3o0?l8
00?ooo]Z00Oo0?ldo`3oC_oonf[o0:WooookJ_l0e?oo00Co00;ooo]Z00Cooh40oookJ_oonf[ooo]Z
1_oUo`000oo[0?ooolT0oonn0005oookJP05oon@0?m4o`3oA?l0odCo0?mX0?l00_oonfX00ol0oi;o
oo]Zon80o`02ooo9000>of40oooob@3oo`1/ooo90?oo08OoiOl0oookJ_nO0?oo/ol0ool0gOoonf[o
o`<0oookJ_l0nol2oookJP0<ooo90?ooP@3ooo]Zo`1goooo0?Wooo]ZojP0oooonf[oo`3fon_o0?oo
nf[oo`H00_oonfX01?oo0?cooo]ZoookJ_ooTP04oookJP03ool0j_oonf[ooo]Z00_ooo]Z00?o07?o
oookJ_oonfX01_oonfX2oiCo0003oomB0?oonf[oU?l000;ooo]Z00Co?ol0o`3Loooonf[oN?l01_oo
nfX01?l0oa_ooo]ZoookJ_oobP03oookJP03onGo0?oo01?ooo]Z00Cooo]Z00OoiOl0on7o0?oonf[o
oo]ZobH0oolPo`3oQ03o00oooo]Z00?oiOl0o`3oFooonfX00ooonfX5onGo0008oookJ_l60?oooo]Z
oi;o0?oo0?Gooo]ZonGo0?l@0?l4onGo00;ooo]Z00Coo`1AonGo0?oonf[o0:go0_oonfX00om4o`3o
oo]ZoookJP05oookJP03oiCo0?oonf[ooo]Z04gooo]Z00Wo07OooookJ_oonf[o0?nJoom/0?oonf[o
oh40oookJ_lko`001?oonfX00ol0nooooo]ZoookJP02oookJP04ool30?oonf[ooo]Zool0g@;ooo]Z
00?o0:?ook?o0?oonfX01OoonfX01Ooo08Oooo]ZoookJ_oonf[oo`1/00;ooo]Z00CoC@3oool^0?oo
nf[oH@3o1?oonfX01?oR0?oooo]ZoookJ_l0oi88oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603o
o`1doooonf[ooo]Zoon@0009oookJP04oonn0?oonf[o0?l5on/0o`Gooo]Z00?ooeL0oookJ_oonfX0
0ooonfX00ooo02gooo]ZoookJP04oookJP03oon10?oonf[ooo]Z00Kooo]Z00Go0=CooookJ_oonf[o
0:Woo`28o`03oookJP03o`3oC_oonf[o0?ld00Gooo]Z00Go0>7ooookJ_l0oagooo]Zo`3oD`03oook
JP04ool0NOl0[Ooooo]Zool0D@;ooo]Z00go01Wooa00oooonf[ooo]Zoi;o0?l60?oo0>Soo`3oCOl0
<?oo0?n`oh;o0?oonf[o0?mK00;o<Ol02_oonfX00on40?oo8?l0ob3o0002obH0o`;ooo]Z0_oQo`03
om[o00gooo]Z0ooJo`001OoQo`3o9P3oobH0oolV0?ooQ03o00Sooo]Z00Ko<Ol0o`3oFol0ok3oP_l0
o`3oCOl60?l2oi;o00;o403o00?oo`1AoookJ_oo07T00ooonfX00ol0oe?o0>7ooookJP02oookJP04
o`3o=?l0odkooo]Zo`2Yo`;ooo]Z00Go0=CooookJ_oonf[ooo]Zoon10004oookJP03ool0;Ooonf[o
oeL000;ooo]Z00?oj`3ooonn0?oonfX01?oonfX01OooT03oi_l0oaP0oooonf[oJ03o00?ooo]Z01;o
0?nBoookJ_oR0?oooo]Zof40oooo;P3oC@3oool0K?oonf[oo`27o`3og_oonf[o/ol0ool0gOmi0?oo
o`<0oookJ_l0nol2oookJP0=oc_o0?ooP@3oof`0o`1goooonf[oo`3iojP0ool0Y_oooo]Zon_o0?oo
nf[oo`H0oaP0o`02oookJP04ool0o?oonf[ooi80oolF00Cooo]Z00?oo`3ZoookJ_oonfX02_oonfX0
0ol0Looooo]ZoookJP07oookJP0:okWo0?ooDP3ooo]ZoookJ_l0:_oooo]Zocoo0?l0g?oooo]ZogSo
00Kooo]Z00Co08koo`3o6ooonf[oolX00ooonfX00ooo09?ooo]Zool04`05oookJP06om[o0?oonf[o
oo]ZobH0oolPo`3oQ03o4?oonfX00olao`3o0?mKoookJP02oookJP05oh;o0?l0ok3o033ooookJ_l0
odd00_oonfX00ol60?oooo]Zoi;o0003oookJP03oa00oooo06[o01Wo00Cooo]Z00?oo`1AoookJ_l0
[Ol00_oonfX00ooo07Wooo]ZoookJP06oookJP03o`3oDooonf[ooo]Z02Gooo]Z000[oookJP09o`1g
oooonf[ooo]Zo`3oV_ooK03o0?o<oon10?oonf[o>ol000?ooo]Z00?o0?_ooookJ_oonfX00ooonfX0
0ooUo`3ooo]ZoookJP02onGo0003o`2Soonco`3oW`3o00;oiOl01?oonfX00ooo08OoU?l0oiCo0003
oiCo0006oookJ_m=0?ooobh0of40oooonf[o0?m50ooonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00?o
oo]Z2?oUo`001_lH0?ooA?l0odCo0?m4o`3ooo]Zoon@00Wooo]Z00Cookh0oookJ_l0o`Goj`3o1_oo
nfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX01?oo
nfX00ol0e?oooo]Zo`04o`02oookJP07o`2Yool0R?oooo]ZoookJ_l0odko0?l^o`3o=005oookJP05
o`3Qool0oago0?l8oookJ_l0oe<00ooonfX01Ooo07Wo0:gooookJ_oonf[oo`1A00;ooo]Z00So01Wo
oa00oooonf[oT_l0oookJ_l60?oo0>Soo`3oC@CoogT000?o0?mKoomi0?lao`003?oonfX2ob3o00Co
9P3o0_ooN@06om[o00?oogT01?oJo`05obH0o`?oolT000Cooo]Zooo90?oob@3oolT00_oonfX2oc7o
0007o`3oFol0ok3oP_l0o`3oCOl0j?ooT_l0oolX0009oomi0003o`3o7Ooonf[ooo]Z00;ooo]Z00Oo
0?ldo`3oC_oonf[o08Soo`2Yool0e?oo00Co00?ooo]Z00Cooh40oookJ_oonf[ooo]Z1_oUo`000oo[
0?oookh0oookJP04oookJP06oon@0?m4o`3oA?l0odCo0?oonf[oJ03o0_oonfX00ol0oi;ooo]Zon80
o`02ooo9000Dof40oooob@3oo`1/ooo90?oo08OoolT0oookJ_nco`3oo`3Mooo90?oonf[oo`<0oook
J_l0nooooo]Zooo90?ooP@3oof`0oookJ_l0Mol2oookJP06ojP0oooo0?Kojol0oookJ_oo1P3o603o
0_oonfX01?oo0?cooo]ZoonB0?oo5P04oookJP03ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oo
nfX01ooonfX00onDo`3ooe80oiCo0003oiCo0004ocoo0?oonf[o0=coogSo00Kooo]Z00CoiOl0o`3o
6ooonf[oolX00ooUo`000ooonf[oiOl0ool04`04oookJP03onGo0?oQo`3ooo]Z00;ooo]Z00?o9P3o
oh@0oooonfX03ooonfX00ooUo`3o0?mKoookJP02oookJP03oh;o0?oUo`3oiOl000CoiOl000?o1P3o
oookJ_nBo`000_oonfX00ooUo`3o403oonGo0003onGo00;ooo]Z00Koo`1AoookJ_oonf[o0:gooook
J_m4o`08oookJP03oiCo0?oonf[ooo]Z04gooo]Z00Wo07OooookJ_oonf[o0?nJoom/0?oonf[ooh40
oookJ_lko`001?oonfX00ol0nooooo]ZoookJP02oookJP04ool30?oonf[ooo]Zool0g@;ooo]Z00?o
0:?ook?o0?oonfX01OoonfX01Ooo08Oooo]ZoookJ_oonf[oo`1/00;ooo]Z00GoC@3ooookJ_oo;P3o
H@3oo`3oA@03oookJP05on80ool0oi3ooo]ZoookJ_l0oi801ooonfX00omX0?oooo]ZoookJP02oook
JP05oaP0oooVo`3ooo]ZoookJ_ooT0002_oonfX01?oo_P3o0?l5on/0oom`0?l5oookJP03oomG0?oo
nf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP05oookJP06o`3Dool0
1?oooo]ZoookJ_l0ZOoo08So0_oonfX00ol0odko0?l^o`3o=005oookJP03o`3Qoooonf[o0?lM00;o
oo]Z00Go0?mCoookJ_oonf[ooo]Zool0N@02oookJP05ool0DOoonf[ooo]Zo`0Iool@0?l00_oonfX0
1onBo`3o1P3oo`3Xool0odgo033oo`3o/?n2o`000_oonfX00ol0oe_o<Ol0oc7o000;oookJP;o8?l0
1?lV0?l2oookJP03on7o0?oJo`3of_l000_of_l01?lV0?l00on40?oooo]ZoookJP07oookJP;o<Ol0
0_l0ok002_l0j?oo0?m=o`000?nBo`3oo`1Zoa00oooonf[oo`1AoookJ_oo07T3oookJP03o`3oDol0
hOoooo]Z00;ooo]Z00Oo0?ldo`3oC_oonf[o08Soo`2Yoooonf[o0=Co00Cooo]Z00Oooh40oookJ_oo
nf[ooo]Zool0;Ooonf[ooeL000;ooo]Z00?oL03oon/0oooo_P001?oonfX00oooT03ooo]ZoaP0o`02
oookJP04ofP0oooonf[ooo]Zo`3oTP;ooo]Z00GohP3oo`3oAOmQ0?ooC@3oool0K002oookJP0Jool0
Qooonf[oW`3ook?o0?oo0=gooo]Zool30?oonf[o0?_ooookJ_lko`3ooh40o`3oV_ooK03o07Ooool0
nOoonf[oZ03ooookJ_oo0?Kojol0ool60?oonf[o603ooookJ_oo0?`2oookJP03oonB0?oo5P3ooo]Z
00;ooo]Z00?oo`3ZoookJ_oonfX02ooonfX00ol0Looooo]ZoookJP06oookJP0;okWo0?ooDP3ooo]Z
oookJ_l0:_oooo]Zocoo0?oonf[o0=coogSo0?lm0?l01_oonfX00ol0oa_o4P3oooo:0004oookJP03
ool0Tooonf[oo`0C00Cooo]Z00Oof_l0oookJ_oonf[ooo]ZobH0oolPo`3oQ03o013ooo]Z00?o<Ol0
o`3oFooonfX00_oonfX01On2o`3o0?nao`0`ool0j?oo0?m=00;ooo]Z00?o1P3oool0mOnBo`000ooo
nfX00ol@0?ooo`1Zo`0Io`04oookJP03ool0DOoonf[o0:go00;ooo]Z00?oo`1ioookJ_oonfX01_oo
nfX00ol0oe?ooo]ZoookJP0UoookJP00:ooonfX02Ol0Mooooo]ZoookJ_l0oi[oof`0o`3oc?ooP@3o
oo]Zoc_o0003oookJP03o`3koooonf[ooo]Z00?ooo]Z00SoiOl0oookJ_oonf[oiOl0ogT0ool0Xooo
/ol0oil0o`;oiOl01?oonfX00ooo08OoU?l0oiCo0004oiCo0005odd0oooo;P3oH@3ooookJ_l0odD0
0ooonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00?ooo]Z2OoUo`001OlH0?ooA?l0odCo0?m4o`3ooi00
00Wooo]Z00Cookh0oookJ_l0o`Goj`3o1_oonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[o
oo]Z00Cooo]Z00?ooh40oookJ_oonfX01OoonfX01_l0e?oo00CooookJ_oonf[o0:Woo`28o`?ooo]Z
00?o0?m>o`3o=?oonfX01OoonfX01Ol0hOoo0?lMoookJ_oonf[o0?mC00?ooo]Z00Goo`1io`2]oooo
nf[oo`1AoaD0o`02oookJP07o`0Iool@0?oooo]Zoi;o0?oob@3o1P3oo`3Xo`02o`3oC@?oogT00_l0
oe/00olao`3ooo]ZoookJP0;oookJPCo8?l01OlV0?l00ooonf[ohOl0on7o0002ooo900Go9P3o3?oo
b@02oc7o0008o`3oFol0ok3oP_l0oh;o0?l0odgo1P3ooi;o0?l0GOl:oomi00Cooo]Z0_l0odh01Ooo
nf[o08Soo`2Yoooonf[o0=Co00?ooo]Z00Cooh40oookJ_oonf[ooo]Z1_oUo`000oo[0?oo0?l5oonn
0005oookJP05oon@0?m4o`3oA?l0oookJ_mX0?l00_oonfX00ol0oi;ooo]Zon80o`02ooo90005of40
oooob@3oo`1/ooo90?oo08L00_oob@001OnO0?oo/ol0ool0gOoonf[oo`<000;ooo]Z00ko0?_ooook
J_oob@3ooh40o`3oV_l0Moooo`3ioookJ_nX0?oooo]Zool0m_o[o`3ooo]Zool600;ooo]Z00Coo`3l
oookJ_oonf[ooi801OoonfX00ooo0>[ooo]ZoookJP0:oookJP03o`1coooonf[ooo]Z00Oooo]Z00?o
U?l0oomB0?nDo`001OnDo`000ooonf[oN?l0oookJP05oookJP04onGo0?l0oa_ooo]Zooo:00KoiOl0
1?oonfX01ooUo`3ohOl0oookJ_oonf[o9P3oob3o0?n40?l03ooonfX00ooUo`3ooo]Zo`3oF`03oook
JP03oh;o0?oUo`3oiOl000KoiOl000GoT_l0oookJ_oonf[oiOl0oa00o`04onGo00;ooo]Z00?oo`1A
oookJ_l0[Ol00_oonfX00om4o`3ooo]ZoookJP05oookJP03oiCo0?oonf[ooo]Z04kooo]Z00Wo07Oo
oookJ_oonf[o0?nJoom/0?oonf[ooh40oookJ_lko`001?oonfX00ol0nooooo]ZoookJP02oookJP09
ool30?oonf[ooo]Zool0gOmi0?oooo]Zo`2Soonco`3oW`3o00Gooo]Z00Goo`27oookJ_oonf[ooo]Z
ool0K002oookJP05odd0oooonf[oobh0of40ool0odD00ooonfX01OoR0?oo0?n@oookJ_oonf[o0?nB
00Oooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?ooi_l0oookJP02oookJP03oon@0?oonf[ooo]Z
00Oooo]Z00Cookh0o`3o1Ooonf[oj`3o1OoonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[o
oo]Z00Cooo]Z00?ooh40oookJ_oonfX01_oonfX01Ol0e?oo00CooookJ_l0ZOoo08So00?ooo]Z00?o
0?m>oookJ_l0oc@01OoonfX00ol0hOoooo]Zo`3o7@02oookJP08o`3oDooonf[ooo]ZoookJ_oo07Wo
oo]Zool0DOlE0?l2oookJP07o`0Iool@0?oooo]ZoookJ_nBo`3o1P3oo`3Xo`02o`3oC@04o`3o/?n2
o`3ooo]ZoookJP;o0?mK00?o<Ol0oookJ_oonfX02_oonfX4ob3o00Go9P3o0_oonfX3on7o00Ko9P3o
00?oQ03ooookJ_oonfX02OoonfX2oc7o0007oookJ_l0ok3oP_l0o`3Xool0odgoo`3eoi;o0002oa00
o`04oookJ_oo057o0:goool0N@;ooo]Z0_l0oe<02ol0hOoooo]ZoookJ_oonf[o0?ldo`3oC_oonf[o
08Soo`2Yoooonf[o0=Co00Cooo]Z00?ooh40oookJ_oonfX00_oonfX00ooo02gooo]ZoomG0002oook
JP03on/0oooo_P3ooo]Z00Cooo]Z00Gooi00onKo0?lH0?oooo]ZofP0o`03oookJP0:o`3oT_oonf[o
hP3ooookJ_mQ0?ooobh0odd0oooo06cooo]Zool0Q`;ooo]Z00Co/ol0o`2Soooo0=goo`<00_oonfX0
3ol0nooooo]Zoc_o0?ooP@3oof`0o`1goooonf[oo`3iojP0ool0Y_oooo]Zon_o0?oonf[oo`H0oaP0
o`02oookJP04ool0o?oonf[ooi80oolF00Cooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ol0Looooo]Z
oookJP07oookJP0;okWo0?ooDP3ooo]ZoookJ_l0:_oooo]Zocoo0?oonf[o0=coogSo0?lm0?l01_oo
nfX00ol0oa_ooo]Zooo:0004oookJP03ool0Tooo01?ooo]Z00Cooo]Z00Oof_l0oookJ_oonf[ooo]Z
obH0oolPo`3oQ03o00oooo]Z00?o<Ol0oookJ_l0oe/00_oonfX01_n2o`3o0?n`o`0`oooonf[o0>So
o`3oC@;ooo]Z00?o1P3oool0mOnBo`000ooonfX00ol@0?ooo`1Zo`0Io`03oookJP06ool0DOlE0?oo
oo]Zo`2]oooonf[oo`1i2?oonfX00ol0oe?ooo]ZoookJP0VoookJP00;?oonfX02?l0Mooooo]Zo`3o
V_ooK03o0?o<oon10?oonf[o>ol00ooonfX00ol0nooooo]ZoookJP03oookJP08onGo0?oonf[ooo]Z
onGo0?mi0?oo0:?ook?o0?nO0?l3onGo00?ooo]Z00?oo`27oiCo0?nDo`001?nDo`001Ooonf[oC@3o
of40oooonf[o0?m500?ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP03oookJPKoiOl00_oonfX00om4
o`3o603oodCo0003odCo00[ooo]Z00Cookh0o`3o1Ooonf[oj`3o1OoonfX00oooE`3ooo]ZoookJP03
oookJP03ool0;Ooonf[ooo]Z00Cooo]Z00?ooh40oookJ_oonfX01_oonfX01_l0e?oo00CooookJ_l0
ZOoooo]Zo`28o`;ooo]Z00?o0?m>oookJ_l0oc@01OoonfX01Ol0hOoo0?lMo`3o2?oonf[o0?mC00Co
oo]Z00?oo`1io`2]oooonfX00_oo05402?oonf[o01Wooa00oooo06[ooo]Zoi;o0?oob@3o1P3o0_l0
j?l00ol0odgoogT0oomi0002oomi0003o`3oFolao`3o<Ol000cooo]Z0oooN@03oh@0o`;o8?l01OlV
0?l@ooo90003oc7o0?oob@3o0?mK00;oP_l00_l0odd2oi;o00;o403o2?ooN@000ol0oagooo]Zoook
JP02oookJP07o`3oC_l0obkooo]Zo`28ool0ZOoooo]Zo`3Do`03oookJP03oon10?oonf[ooo]Z00;o
oo]Z1OoUo`000om`0?ooj`3ooonn0005oookJP05oon@0?oVo`3oA?l0oookJ_mX0?l00_oonfX01?l0
oi;ooo]Zooo90?oR0?l2ooo9000Dof40oooob@3oo`1/ooo90?oo08OoolT0oookJ_nO0?oo/ol0ooo9
0?oonf[oo`<0oookJ_l0nooooo]Zooo90?ooP@3oof`0oookJ_l0Mol2oookJP03ojP0oooo0?Kojol0
00;ooo]Z00Coo`H0oookJ_oonf[oo`3l0_oonfX00oooTP3ooo]ZoookJP02oookJP03ool0j_oonf[o
oo]Z00_ooo]Z00?o07?ooookJ_oonfX01ooonfX00onDo`3ooe80oiCo0005oiCo0003ogSo0?l0omoo
oo]Z00Gooo]Z00Co0?lKoookJ_oonf[oolX02?oUo`02oookJP07onGo0?oQo`3ooo]ZoookJ_lV0?oo
8?l0oh@0o`0?oookJP03onGo0?oonf[o0?mK00?ooo]Z00?oP_l0onGo0?oUo`001_oUo`001?nBo`3o
oo]ZoookJ_l@0?l4onGo00;ooo]Z00Coo`1AonGo0?oonf[o0:go0_oonfX00om4o`3ooo]ZoookJP05
oookJP03oiCo0?oonf[ooo]Z04oooo]Z00So07OooookJ_l0oi[oof`0oookJ_ooP@3ooo]Zoc_o00Co
oo]Z00?o0?_ooookJ_oonfX00_oonfX02Ooo0`3ooo]ZoookJ_oo0=goN@3ooookJ_l0Xooo/ol0oil0
o`05oookJP05omgo0?oo08Oooo]ZoookJ_oo06`00ooonfX01?m=0?ooobh0of40ool0odD3oookJP05
on80ool0oi3ooo]ZoookJ_l0oi802?oonfX01_mX0?oooo]ZoookJ_oonf[o603oonKo00?ooo]Z00?o
oi00oookJ_oonfX01ooonfX01?oo_P3o0?l5oookJ_o[0?l5oookJP03oomG0?oonf[ooo]Z00?ooo]Z
00?oo`0]oookJ_oonfX01?oonfX00oooP@3ooo]ZoookJP06oookJP06o`3Dool01?oooo]Zo`2Yoooo
nf[o08So0_oonfX00ol0odko0?l^o`3o=005oookJP06o`3Qoooonf[o0?lMo`3o2?oonf[o0?mC1?oo
nfX02?oo07Wooo]Zool0DOoo057ooo]Zo`0Iool@0?ooo`1Z0_oonfX01onBo`3o1P3oo`3Xool0j?oo
0?m=oookJ_n2o`000ooonfX00ol0oe_o<Ol0oc7o000>oookJP?oQ03o0_lPo`05obH0o`03ob3o0?n4
0?ooQ03o00kooo]Z00Go<Ol0o`3oFol0ok3oP_l0o`3Xo`02o`3oC@;oT_l000Ko403oo`0Ioooo057o
o`1Ao`2]oooo07T2oookJP03o`3oDol0oago0>7o00?ooo]Z00Oo0?ldo`3oC_oonf[o08Soo`2Yoooo
nf[o0=Co00Cooo]Z00?ooh40oookJ_oonfX00_oonfX00ooo02gooo]ZoomG0002oookJP03og00ooo[
0?oooo]Z00Cooo]Z00Gooi00onKo0?lH0?oooo]ZofP0o`03oookJP08o`3oT_oonf[ohP3ooookJ_l0
odGoH@3oodd0oooo06`2oookJP0Hool0Qooonf[oW`3ook?o0?oo0=gooo]Zool30?oonf[o0?_ooook
J_lko`3ooh40o`3oV_ooK03o07Ooool0nOoonf[oZ03ooookJ_oo0?Kojol0oookJ_oo1P3o603o0_oo
nfX01?oo0?cooo]ZoonB0?oo5P04oookJP03ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX0
1ooonfX02_nio`3ooe80oookJ_oonf[o02[ooookJ_loo`3o0=cooookJ_mho`06oookJP04o`2>ool0
oa_ooo]Zooo:00?ooo]Z00?o0?Woool0Tooo01<01OoonfX01ooJo`3ooo]ZoookJ_lV0?oooo]Zob3o
0?n40?l03ooonfX00olao`3o0?mKoookJP02oookJP06oh;o0?l0ok3o033ooookJ_l0j?oo0?m=0_oo
nfX00ol60?ooo`3eoi;o0002oookJP03oa00oooo06[o01Wo00Cooo]Z00Koo`1AoookJ_oonf[o0:go
oookJ_oo07T8oookJP03o`3oDooonf[ooo]Z02Kooo]Z000/oookJP09o`1goooonf[o0?nJoookJ_oo
K03o0?o<oon10?oonf[o>ol000;ooo]Z00?o0?_ooookJ_oonfX01?oonfX01ooUo`3ooo]ZonGo0?mi
0?oo0:?ook?o0?nO0?l01_oonfX00ol0omkoU?l0oiCo0005oiCo0004odd0oooonf[oH@3oo`3oA@Co
oo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP02oookJP;oiOl00_oonfX00ooUo`3ooo]ZoookJP02oook
JP03oaP0oom4o`3oA?l000;oA?l000?ooi00oookJ_oonfX01ooonfX01?oo_P3ooo]Zo`3o1Oo[0?l5
oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP05
oookJP06o`3Doooonf[o00CooookJ_l0ZOoo08So0_oonfX00ol0odko0?l^o`3o=006oookJP05o`3Q
ool0oago0?l8oookJ_l0oe<01?oonfX03?oo07Wo0:gooookJ_lE0?ooo`1AoookJ_l06Ooo403oool0
J_oonf[oT_l0ooo900;o1P3o00?o0>Soo`3oCOooN@001?ooN@000ol0oe_o<Ol0oookJP0;oookJP?o
ogT02ooonfX<ooo900;o<Ol00ooob@02o`3oC@05o`H0oonBo`3ooo]Zoa00ool06Ol01_ooN@000ol0
oe?ooo]Zo`3o7@04oookJP07o`3oC_l0obkooo]Zo`28ool0ZOoooo]Zo`3Do`04oookJP05oon10?oo
nf[ooo]ZoookJ_oo02d01OoUo`000oo[0?oooo]Zoonn0004oookJP06oon@0?oonf[oi_l0oaP0oooo
nf[oJ03o0_oonfX01_l0oi;ooo]Zon80oooonf[oolT0of40o`;oolT000Woo`1/ool0Qooob@3ooo]Z
oil0oonco`3oo`3MoookJ_oo0`000_oonfX01ol0nooooo]Zooo90?ooP@3o0?nJo`1goooo0?T00_oo
nfX01OnX0?ooo`3fon_o0?oonf[oo`H000;ooo]Z00Goo`3loookJ_oonf[ooi80oolF0004oookJP03
ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX01ooonfX00onio`3ooe80oiCo0005oiCo0003
o`3Loomho`3ooo]Z00Gooo]Z00GoiOl0o`3o6ooonf[oolX0oookJP08onGo0004oookJ_oUo`3ooo]Z
on7o00;ooo]Z00?o9P3oob3o0?oonfX03ooonfX00ooUo`3o0?mKoookJP03oookJP03oh;o0?oUo`3o
iOl000GoiOl000GoT_l0ool0mOoonf[ooo]Zoa00o`04onGo00;ooo]Z00Koo`1AoookJ_oonf[o0:go
oookJ_m4o`08oookJP05oiCo0?oonf[ooo]ZoookJ_l0oad0COoonfX02Ol0Mooooo]Zo`3oV_oonf[o
of`0oookJ_ooP@3ooo]Zoc_o0003oookJP03o`3koooonf[ooo]Z00?ooo]Z00Soo`<0oookJ_oo0=go
N@3ooookJ_l0Xooo/ol0oil0o`Gooo]Z00?ogOl0ool0QooonfX00_oonfX01ooo06cooo]ZoookJ_m=
0?ooobh0oookJ_mQ0?l01?oonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Oooo]Z00?oJ03ooookJ_oo
nfX00_oonfX01OlH0?ooi_l0oookJ_oonf[ooi0000[ooo]Z00Cookh0o`3o1Oo[0?ooL03o1?oonfX0
0oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oookJ_oonfX01_oonfX0
2ol0e?oo00CooookJ_l0ZOoooo]Zo`28oooonf[o0?m>o`3o;_oonf[o0?ld00Gooo]Z00?o0>7ooook
J_l0oad00_oonfX00ol0oe?ooo]ZoookJP02oookJP08ool0NOoonf[o5@3oool0DOoonf[o01Wooa00
oooo06X2oookJP08oi;o0?l60?oo1P3oo`3Xool0odgo033ooh;o0?l0ok03oookJP03o`3oFolao`3o
oo]Z02Gooo]Z0_lao`000ol0ok3oP_l0oh;o0002o`3oC@09oookJ_nBo`3o403ooa00ool06Oooo`1A
oaD0ool0[Oooo`1i00;ooo]Z00?o0?mCo`3o7Ol0hOl00ooonfX01ol0ocCo0?m>oookJ_l0R?oo0:Wo
oookJ_l0e?l01?oonfX00oooP@3ooo]ZoookJP02oookJP03ool0;Ooonf[ooeL000;ooo]Z00?o0?l5
on/0oooo_P001?oonfX01_ooT03ooo]ZonKo0?lH0?oooo]ZofP0o`?ooo]Z00[o0?nBoookJ_oR0?oo
oo]Zof40oooo;P3oC@3oool0K?oonf[oo`270_oonfX01?nco`3o0:?oool0gOoo0`02oookJP0?o`3k
oooonf[o>ol0oon10?ooK03o07OooookJ_oo0?Wooo]ZojP0oooonf[ojol0oookJ_oo1P3o603o00;o
oo]Z00Goo`3loookJ_oonf[ooi80oolF0003oookJP03ool0j_oonf[ooo]Z00_ooo]Z00?o07?ooook
J_oonfX01ooonfX02_ooDP3ooo]ZoookJ_oonf[o02[oocoo0?oonf[o0=coogSo0?lm0?l6oookJP03
o`3o6olB0?ooolX000Cooo]Z00?oo`2CoookJ_oo01<01?oonfX01ooJo`3ohOl0oookJ_oonf[o9P3o
ob3o0?n40?l04?oonfX00olao`3o0?mKoookJP02oookJP05oh;o0?l0ok3o033ooookJ_l0odd00_oo
nfX00ol60?oooo]Zoi;o0003oookJP03oa00oooo06[o01Wo00Cooo]Z00?oo`1AoookJ_l0[Ol00_oo
nfX00ooo07Wooo]ZoookJP06oookJP05o`3oDooonf[ooo]ZoookJ_l0oad09?oonfX002cooo]Z00Wo
07OooookJ_oonf[o0?nJoom/0?l0olcooh40oookJ_lko`000_oonfX00ol0nooooo]ZoookJP04oook
JP08onGo0?oonf[oiOl0ogT0ool0Xooo/ol0oookJ_nO0?l5oookJP03o`3og_nDo`3oU?l000KoU?l0
00?ooo]Zof40ool0odD01?oonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Oooo]Z00GoiOl0oookJ_oo
nf[ooo]ZoaP0o`05odCo00Wooo]Z00Gookh0oookJ_l0o`Goj`3oog00o`05oookJP03oomG0?oonf[o
oo]Z00?ooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooP@3ooo]ZoookJP06oookJP06o`3Dool01?oo
oo]Zo`2Yoooonf[o08So0_oonfX00ol0odkooo]Zo`3o=006oookJP05o`3o7Ooonf[o0?l8oookJ_l0
oe<01?oonfX02ooo07Wo0:gooookJ_lE0?ooo`1AoookJ_l06Ooo403oool0J_oonf[oT_l000;oolT0
00?o1P3oo`3Xool0odd01OooN@001?l0oe_o<Ol0oc7o0?lao`0:oookJP03oomi0?oonf[ooo]Z017o
oo]Z0ooob@02oc7o00?oolT00_l0odd01_l0j?ooo`3eoi;o0?l0GOoo403oo`0Io`GoogT00_l0oe<0
0ol0o`So0?lMoookJP03oookJP03o`3oC_l0obkooo]Z00;o0:Wo00?ooo]Zo`3DoooonfX00ooonfX0
1OooP@3ooo]ZoookJ_oonf[oo`0]00CoiOl000Cooo]Zon/0ool0o`Gookh01?oonfX01_ooT03ooo]Z
onKo0?lH0?oooo]ZofP0o`;ooo]Z00Co0?nBoookJ_oR0?oooo]Z0_oob@001OmQ0?ooolT0ool0K?oo
b@3oo`2700;oolT000goW`3ook?o0?oo0=gooo]Zool30?oonf[o0?_ooookJ_oob@3ooh40oom/0?oo
nf[o07Oo00;ooo]Z00?oZ03oool0m_o[o`000_oonfX01?oo1P3ooo]ZoookJ_oo0?`2oookJP03oonB
0?oonf[ooo]Z00?ooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ol0Looooo]ZoookJP07oookJP03okWo
0?ooDP3oU?l000GoU?l000?ooo]ZogSo0?oonfX01OoonfX01OoUo`3o0?lKoookJ_oobP3ooo]Z00Oo
iOl00_oonfX00ooUo`3ohOl0oookJP02oookJP03obH0oon40?oooo]Z00kooo]Z00?oiOl0oookJ_l0
oe/01?oonfX00on2o`3oiOl0onGo0005onGo0005oi;o0?oo0?Gooo]ZoookJ_l@0?l00ooUo`03oook
JP06ool0DOoonf[ooo]Zo`2]oooonf[oA?l02?oonfX01OnDo`3ooo]ZoookJ_oonf[o0?lM04gooo]Z
00Wo07OooookJ_oonf[o0?nJoom/0?oonf[ooh40oookJ_lko`000ooonfX00ol0nooooo]ZoookJP03
oookJP08ool30?oonf[oo`3MogT0oooonf[o0:?ook?o0?nO0?l5oookJP03omgo0?oo08Oooo]Z00;o
oo]Z00Ooo`1/oookJ_oonf[oC@3oool^0?oonf[oH@3o00Cooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3o
TP07oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603oonKo0?oonf[ooo]Zoon@000:oookJP04oonn
0?l0o`Gooo]Zon/0o`Gooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP05oookJP03
oon10?oonf[ooo]Z00Gooo]Z00Ko0=Coo`04oooonf[o0:WooookJ_l0R?l2oookJP04o`3oC_oonf[o
oo]Zo`3o=0Gooo]Z00Go0>7oo`3o7Ol0o`Sooo]Zo`3oD`04oookJP09ool0NOl0[Ooooo]ZoaD0oooo
057ooo]Zo`0Iool@0?ooo`1Z00;ooo]Z00SoT_l0oookJ_l60?oooo]Zo`3oCOl0<?ooP_l0o`3o/0?o
oo]Z00Co0?mKoc7o0?lao`3o<Ol08?oonfX3oc7o00?oP_l00_l0odd02?oonf[oo`3eoi;o0?l@0?oo
01Woo`000?oo057o5@3o0_oo07T01Ooonf[o0?mCo`3oDol0oago0>7o00?ooo]Z00?o0?ldo`3oC_oo
nfX00_l0ZOl00ooonf[o0=CooookJP03oookJP03oon10?oonf[ooo]Z00;ooo]Z00Coo`0]oookJ_oo
nf[ooeL00_oonfX00oo[0?oookh0oookJP04oookJP05oon@0?oVo`3o603ooookJ_mX0?l00ooonfX0
2?l0oi;ooo]Zon80oooonf[o0?m5of40oom=0?ooo`1/0_oonfX06?oo08Oooo]Zoil0oonco`3oo`3M
oookJ_oo0`3ooo]Zo`3koooonf[o>ol0oon10?l0oi[oof`0o`1goooo0?Wooo]ZojP0ool0Y_ooo`3f
on_o0?oonf[oo`H0oaP0o`;ooo]Z00Coo`3loookJ_ooTP3ooaH01?oonfX00ooo0>[ooo]ZoookJP0:
oookJP03o`1coooonf[ooo]Z00Oooo]Z00_o^Ol0oomB0?oonf[ooo]Zo`0Zoooonf[o?ol0o`3Loooo
nf[oN?l0ocd0o`06oookJP03o`3o6olB0?ooolX000Cooo]Z00?oo`2Cool04ooonfX01?oonfX01ooJ
o`3ooo]ZoookJ_oonf[o9P3oob3o0?n40?l03ooonfX00olao`3ooo]Zo`3oF`03oookJP05oh;o0?l0
ok7o033oo`3Xool0odd00_oonfX00ol60?oooo]Zoi;o0003oookJP03oa00oooo06[o01Wo00Cooo]Z
00Goo`1AoookJ_l0[Ooooo]Zool0N@09oookJP05o`3oDooonf[ooo]ZoookJ_l0oad09?oonfX002[o
oo]Z00?oo`3ioookJ_l0Mol00_oonfX01_l0oi[oof`0o`3oc?ooP@3ooo]Zoc_o00;ooo]Z00?o0?_o
oookJ_oonfX01?oonfX02?oUo`3ooo]Zool0gOmi0?oo0:?ook?o0?oUo`3oW`3o1OoonfX00ol0omko
U?l0oiCo0006oiCo0003oookJ_mQ0?oo0?m500Cooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP07oook
JP05onGo0?oonf[ooo]ZoookJ_lH0?l01Om4o`0:oookJP04oonn0?l0o`Gooo]Zon/0o`Gooo]Z00?o
oeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP05oookJP03oon10?oonf[ooo]Z00Gooo]Z00Ko
0=CooookJ_l01?oo0:WooookJ_l0R?l2oookJP03o`3oC_l0obko0?ld00Oooo]Z00Co0?lMo`3o2?oo
nf[o0?mC1OoonfX01Ooo07Wo0:gooookJ_lE0?ooo`1A00;ooo]Z00[o403oool0J_oob@3oT_l0ooo9
0?ooN@3o1P3ooomi0?l0odgo0>So0_ooN@03oookJP03o`3oFooonf[o<Ol000;o<Ol06OoonfX2ooo9
00?o<Ol00ooob@02o`3oC@;oolT00_nBo`02oa00o`03oookJ_ooN@3oogT000;oogT000?o0000o`3o
DooonfX00_l0oad4oookJP04o`3oC_l0obkooo]Zo`2Yo`;ooo]Z00?o0=CooookJ_oonfX00_oonfX0
1_ooP@3ooo]ZoookJ_oonf[oo`0]oookJP?oiOl00_oonfX00oo[0?oooo]Zoonn0004oookJP05oon@
0?oonf[o603ooookJ_mX0?l00ooonfX01_l0oi;ooo]Zon80oooonf[oolT0of40o`;oolT000?oo`1/
ool0QooonfX00_oob@001?nco`3oo`3MoookJ_oo0`02oookJP07o`3koooonf[oolT0oon10?ooK03o
07Ooool0n@02oookJP05ojP0oooo0?Kojol0oookJ_oo1P000ooonfX01?oo0?cooo]ZoonB0?oo5P04
oookJP03ool0j_oonf[ooo]Z00_ooo]Z00?o07?ooookJ_oonfX01ooonfX00onio`3ooe80oiCo0004
oiCo0003o`3Loomho`3o0?oO00Kooo]Z00Go0?lKoookJ_oonf[oolX0oookJP07onGo00;ooo]Z00Oo
iOl0on7o0?oonf[ooo]ZobH0oolPo`3oQ03o00oooo]Z00?oiOl0oookJ_l0oe/00ooonfX00on2o`3o
0?n`onGo0005onGo0003oookJ_nBo`3ooo]Z00;ooo]Z00Co403oonGo0?oUo`3oiOl00ooonfX00ooo
057ooo]Zo`2]o`02oookJP03odCo0?oonf[ooo]Z00Gooo]Z00?oU?l0oookJ_oonfX00_oonfX00ol0
oagooo]ZoookJP19oookJP03ool0nOoonf[o07Oo00;ooo]Z00Ko0?nJoom/0?oonf[ooh40oookJ_lk
o`03oookJP03o`3koooonf[ooo]Z00?ooo]Z00Soo`<0oookJ_oo0=goN@3ooookJ_l0Xooo/ol0oil0
o`Kooo]Z00Goo`27oookJ_oonf[ooo]Zool0K002oookJP04odd0oooo;P3ooo]Zof40o`Cooo]Z00Go
hP3oo`3oT?oonf[ooo]Zo`3oTP07oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603oonKo0?oonf[o
oo]Zoon@000:oookJP04oonn0?oonf[o0?l5on/0o`Gooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo
02gooo]ZoookJP05oookJP03oon10?oonf[ooo]Z00Kooo]Z00?o0=Coo`04ool0ZOl00_oonfX01_l0
R?oooo]Zo`3oC_l0obkooo]Zo`3o=0Kooo]Z00Go0>7oo`3o7Ol0o`Sooo]Zo`3oD`04oookJP05ool0
NOl0[Ooooo]ZoaD0oooo05400_oonfX02_l@0?ooo`1ZoookJ_oonf[oT_l0oookJ_l60?oooo]Zo`3o
COl0j?l2oh;o00Cooo]Z00?o0?mKoookJ_lao`000_lao`0JoookJP?o<Ol000Cooo]Zoh;o0?n2o`3o
0?n`0_l0odd01Ol60?ooo`3eoi;o0?nBo`3o403o00;ooo]Z00Koo`1Ao`2]oooo07Wo0000oookJ_l0
oe<2o`3o7@08o`3Qoooonf[ooo]ZoookJ_l0ocCo0?m>oookJ_l0ZOl2oookJP03o`3Doooonf[ooo]Z
00;ooo]Z00?ooh40oookJ_oonfX00_oonfX01?oo02gooo]ZoookJ_ooE`02oookJP03o`3o1Oo[0?oo
okh000Cooo]Z00Gooi00oookJ_lH0?oooo]ZofP0o`03oookJP0;o`3oT_oonf[ohP3ooookJ_l0odGo
H@3oool^0?m=0?ooo`1/oookJ_oo08L00_oonfX01?nco`3o0:?oool0gOoo0`02oookJP0?o`3koooo
nf[o>ol0oon10?l0oi[o07OooookJ_oo0?Wooo]ZojP0oooonf[ojol0oookJ_oo1P3o603o00?ooo]Z
00Coo`3loookJ_ooTP3ooaH01?oonfX00ooo0>[ooo]ZoookJP0:oookJP03o`1coooonf[ooo]Z00Oo
oo]Z00_o^Ol0oomB0?oonf[ooo]Zo`0Zoooonf[o?ol0o`3Loomho`3o0?oOocd0o`05oookJP04o`2>
ool0oa_ooo]Zooo:00?ooo]Z00?o0?Woool0Tooo01<01OoonfX01ooJo`3ooo]ZoookJ_oonf[o9P3o
ob3o0?n40?l03ooonfX00olao`3o0?mKoookJP03oookJP05oh;o0?l0<?oooo]Zo`3Xool0odd00_oo
nfX00ol60?ooo`3eoi;o0003oookJP03oa00ool06Ooooo]Z00?ooo]Z00Ko5@3oool0DOoonf[o0:go
oookJ_oo07T8oookJP03o`3oDooonf[ooo]Z00;ooo]Z00?o0?lMoookJ_oonfX08_oonfX002[ooo]Z
00?oo`3ioookJ_l0Mol00_oonfX01_l0oi[oof`0o`3oc?ooP@3ooo]Zoc_o00;ooo]Z00?o0?_ooook
J_oonfX01?oonfX02?oUo`3ooo]Zool0gOoonf[o0:?ooookJ_nco`3oW`3o1OoonfX00ol0omkoU?l0
oiCo0007oiCo0003of40ool0odGooo]Z00?ooo]Z00?ohP3ooookJ_l0oi000_oonfX00ol0oi;ooo]Z
oookJP04oookJP06onGo0?oonf[ooo]ZoookJ_m4o`3o603o1Om4o`09oookJP04oonn0?oonf[o0?l5
on/0o`Gooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP05oookJP03oon10?oonf[o
oo]Z00Kooo]Z00Ko0=Coo`04oooonf[o0:WooookJ_l0R?l2oookJP03o`3oC_oonf[o0?ld00Oooo]Z
00?o0?lMo`3o2?oonfX00_l0oe<4oookJP05ool0NOl0[Ooooo]ZoaD0oooo05400_oonfX02?l@0?oo
01Woooo90?nBo`3ooo]Zoomi0?l60?ooogT00_l0odd01Ol0<?ooP_l0oh;o0?n2o`3ooo]Z00?o0?mK
00Cooo]Zoc7o0?lao`3o<Ol03_oonfX3oomi00Cooo]Z0olao`05ooo90003o`3oCOoob@3oolT000?o
olT000?o403ooookJ_oonfX00_ooN@001ooo07WoogT0o`000?l0oe?ooo]Zo`3o7Ol0hOl01?oonfX0
1?l0odko0?l^oookJ_l0ZOl2oookJP03o`3Doooonf[ooo]Z00;ooo]Z00Gooh40oookJ_oonf[ooo]Z
ool0;@02oookJP;oiOl00_oonfX00oo[0?oooo]Zoonn0004oookJP03oon@0?oonf[o603o00;ooo]Z
00KoJ03ooookJ_oonf[o0?nBoookJ_oR0?l2oookJP07ooo90?mQ0?ooolT0ool0K?oo08OoiOl0oook
JP02ooo9000<ok?o0?oo0=goolT0ooo90?oonf[o0?_ooookJ_oob@3ooh40oom/0?l0oi[o07Oo0_oo
nfX00onX0?ooo`3fon_o0002oookJP04ool60?oonf[ooo]Zool0o0;ooo]Z00?ooi80oookJ_oonfX0
0ooonfX00ooo0>[ooo]ZoookJP0:oookJP03o`1coooonf[ooo]Z00Sooo]Z00?ooe80oiCo0?nDo`00
0onDo`001?l0g?oooo]ZogSo0?l0oml6oookJP03o`3o6ooonf[oolX000;ooo]Z1_oUo`02oookJP03
onGo0?oonf[ohOl000;ooo]Z00?o9P3oob3o0?oonfX03ooonfX00ooUo`3o0?mKoookJP03oookJP03
oh;o0?l0ok3oiOl000GoiOl000Gooo]Zoi;o0?oonf[ooo]Zoa00o`03onGo00?ooo]Z00CoiOl0ool0
DOoonf[o0:go0_oonfX00om4o`3ooo]ZoookJP02oookJPCoU?l00ooonfX00ol0oago0?l8oookJP1:
oookJP03ool0nOoonf[o07Oo00;ooo]Z00Ko0?nJoom/0?oonf[ooh40oookJ_lko`03oookJP03o`3k
oooonf[ooo]Z00?ooo]Z00Woo`<0oookJ_oo0=gooo]ZogT0ool0Xooo/ol0o`0GoonO0?l01OoonfX0
1Ooo08Oooo]ZoookJ_oonf[oo`1/00;ooo]Z00CoC@3ooookJ_oo;P3oH@3o1?oonfX00ooR0?oooo]Z
o`3oT002oookJP03o`3oT_oonf[ooo]Z00Gooo]Z00KoJ03ooookJ_oonf[ooo]ZoaP0oooVo`03oook
JP03oon@0?oonf[ooo]Z00Sooo]Z00Cookh0o`3o1Oo[0?ooL03o1?oonfX00oooE`3ooo]ZoookJP03
oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooh40oookJ_oonfX01OoonfX01_l0e?oooo]Zo`04ool0
ZOoooo]Zo`28o`;ooo]Z00Co0?m>oookJ_oonf[o0?ld1_oonfX01?l0hOoo0?lMoookJ_oonfX2o`3o
D`?ooo]Z00Goo`1io`2]oooonf[o5@3oool0D@02oookJP08oa00ool06Oooo`1ZoookJ_nBo`3ooo]Z
o`H0oooonfX2o`3oC@04o`3Xoon2o`3oP_l0oh;o00;ooo]Z0ol0oe/01?oonf[o<Ol0oc7o0?lao`0D
oookJP?o<Ol000Wo0?mKoookJ_n2o`3oP_l0o`3o/?l0ok7o0?m=o`3Xoooo0?D00_nBo`02oa00o`03
oookJ_lE0?ooo`1A00;oo`1i0_l000001?l0oe?o0?lMoookJ_l0hOl3oookJP04o`3o=?l0odkooo]Z
o`2Yo`;ooo]Z00?o0=CooookJ_oonfX00_oonfX00oooP@3ooo]ZoookJP02oookJP09ool0;Ooonf[o
oo]ZoookJ_ooE`3ooo]Zo`3o1Oo[0?oookh000Cooo]Z00Kooi00oookJ_oVo`3o603ooookJ_mX0?l3
oookJP0Ro`3oT_oonf[ohP3ooookJ_l0odGoH@3oodd0oooo06cooo]Zool0QooMo`3ooo]Zoil0oonc
o`3oo`3MoookJ_oo0`3ooo]Zo`3koooonf[o>ol0oon10?l0olcoof`0o`1goooo0?Wooo]ZojP0ool0
Y_ooo`3fon_o0?oonf[oo`H0oaP0o`;ooo]Z00Coo`3loookJ_ooTP3ooaH01?oonfX00ooo0>[ooo]Z
oookJP0;oookJP03o`1coooonf[ooo]Z00Oooo]Z00[ooe80oookJ_oonf[ooo]Zo`0Zooloo`3ooo]Z
o`3Loomho`3o0?oO1_oonfX00ol0oa_o4P3oooo:0004oookJP03ool0Tooonf[oo`0C00Cooo]Z00Oo
f_l0on7o0?oonf[ooo]ZobH0oolPo`3oQ03o013ooo]Z00?o<Ol0o`3oFooonfX00_oonfX01_n2o`3o
0?n`o`0`oooonf[o0>Soo`3oC@;ooo]Z00?o1P3oool0mOnBo`000_oonfX00ol@0?oo05goo`0Io`04
oookJP06ool0DOoonf[ooo]Zo`2]oooonf[oo`1i2?oonfX01_l0oe?ooo]ZoookJ_oonf[o0?lMo`3o
22Cooo]Z000ZoookJP0;ool0nOoonf[ooo]Zo`1goooonf[o0?nJoom/0?l0olcooh40oookJ_lko`00
0_oonfX00ol0nooooo]ZoookJP04oookJP08onGo0?oonf[ooo]Zool0gOl0Xooooo]Zok?o0?nO0?l5
oookJP03o`3og_nDo`3oU?l000CoU?l000Kooo]Zodd0oooo;P3ooo]Zof40ool0odD3oookJP03on80
oooonf[o0?n@00;ooo]Z00?o0?nBoookJ_oonfX01?oonfX01_oUo`3ooo]ZoookJ_oonf[oA?l0oaP0
o`KoA?l02OoonfX01?oo_P3o0?l5on/0oom`0?l5oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]
oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP05oookJP06o`3Doooonf[o00Coo`2Yoooonf[o08So
0ooonfX00ol0odko0?ldoookJP06oookJP03o`3Qool0oago0?l800;ooo]Z00?o0?mCoookJ_oonfX0
0_oonfX01Ooo07Wo0:gooookJ_oonf[oo`1A00;ooo]Z0_l@0?l00ooonf[oiOl0onGo0002onGo0003
oomi0?oonf[o0?m=00;o0?m=00Go033ooh;o0?n2o`3o0?n`oookJP04o`3oF`?o<Ol01ooonfX7oomi
0004o`00Oolao`3o<Ol0oc7o00KoolT00_l0odd02Ooob@3oT_l0oi;o0?oo06[o01Wooa00oooonf[o
o`1Aoomi0002ool0N@;oogT000Co0?mCo`3o7Ol0oago0>7o1?oonfX01?l0odko0?l^oookJ_l0ZOl2
oookJP03o`3Doooonf[ooo]Z00;ooo]Z00Gooh40oookJ_oonf[ooo]Zool0;@02oookJP;oiOl00_oo
nfX00om`0?ooj`3ooonn0004oookJP06oon@0?oonf[oi_l0oaP0oooonf[oJ03o0_oonfX01ol0oi;o
olT0ooo90?oR0?oooo]Zooo90?mQ0?l00_oob@000ooo06coo`27oookJP02ooo90003ok?o0?oo0=go
olT000?oolT000Oo0?_ooookJ_oob@3ooh40oom/0?l0Moooo`3i00;ooo]Z00GoZ03oool0m_o[o`3o
oo]Zool60003oookJP04ool0o?oonf[ooi80oolF00Gooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ol0
Looooo]ZoookJP07oookJP03okWo0?ooDP3oU?l000CoU?l000?o0=coogSo0?l0oml01_oonfX01?l0
oa_o4P3ooookJ_oobP02oookJPKoiOl00_oonfX00ooUo`3ooo]Zon7o0002oookJP03obH0oon40?oo
oo]Z00kooo]Z00?oiOl0oookJ_l0oe/01?oonfX00on2o`3o033oonGo0004onGo0003o`H0oonBo`3o
o`3e00;ooo]Z00Co403oonGo0?oUo`3oiOl00ooonfX01_oo057ooo]ZoookJ_l0[Ooooo]ZodCo00Go
oo]Z1_nDo`000ooonf[o0?lMo`3o201;oookJP0;ool0nOoonf[ooo]Zo`1goooonf[o0?nJoom/0?oo
nf[o0?o<oon10?lko`000ooonfX00ol0nooooo]ZoookJP03oookJP09ool30?oonf[ooo]Zool0gOmi
0?oo0:?ooookJ_nco`3oW`3o00Gooo]Z00?oo`27oookJ_oonfX00_oonfX01ooo06cooo]Zodd0oooo
nf[oobh0oookJ_mQ0?l00ooonfX00ooR0?oooo]Zo`3oT002oookJP03o`3oT_oonf[ooo]Z00Gooo]Z
00?oJ03ooookJ_oonfX00_oonfX01OlH0?ooi_l0oookJ_oonf[ooi0000[ooo]Z00Cookh0oookJ_l0
o`Goj`3o1OoonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooh40oook
J_oonfX01_oonfX00ol0e?oo00Coo`2Yo`02oookJP06o`28oooonf[ooo]Zo`3oC_oonf[o0?ld1ooo
nfX00ol0hOoo0?lMoookJP02oookJP06o`3oDooonf[ooo]ZoookJ_oo07Wo0:go0_oonfX2ool0D@05
oookJ_l@0?oo403oool0J_oonfX00_nBo`000ol60?oooo]ZoookJP03o`3oC@04o`0`oon2o`3oP_l0
o`3o/0;ooo]Z1?l0oe/3oc7o00_ooo]Z0ol007l3oc7o00;o0?mK0on2o`001Ol0<?oo0>Soo`3oCOl0
odgoo`3e00;oT_l000Co01Wooa00oooonf[o5@3o0_oo05402?oo07Wo0000o`000?l0003o0?mCo`3o
7Ooonf[o0>7o0ooonfX01?l0ocCo0?m>oookJ_l0ZOl2oookJP03o`3Doooonf[ooo]Z00;ooo]Z00?o
oh40oookJ_oonfX00_oonfX02Ooo02gooo]ZoookJ_oonf[ooeL0oookJ_l0o`GoL03oon/0o`04oook
JP06oon@0?oonf[oi_l0oaP0oooonf[oJ03o0ooonfX02ol0oi;ooo]Zon80oooonf[o0?m5of40oooo
;P3oC@3oool0K?oonf[oo`2700;ooo]Z00Co/ol0o`2Soooo0=goo`<00_oonfX03ol0nooooo]Zoc_o
0?ooP@3o0?nJo`1goooonf[oo`3ioookJ_nX0?oooo]Zon_o0?oonf[oo`H0oaP0o`03oookJP04ool0
o?oonf[ooi80oolF00Cooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ol0Looooo]ZoookJP07oookJP0;
okWo0?ooDP3ooo]ZoookJ_l0:_oooo]Zocoo0?l0g?oooo]ZogSo0?lm0?l01_oonfX00ol0oa_o4P3o
ooo:0003oookJP03o`3ioooo09?oo`0C00Gooo]Z00Oof_l0on7o0?oonf[ooo]ZobH0oolPo`3oQ03o
00oooo]Z00?o<Ol0oookJ_l0oe/00ooonfX01_n2o`3o0?nao`0`ool0j?oooo]Zo`3oC@;ooo]Z00?o
1P3ooi;o0?oonfX00_oonfX00ol@0?ooo`1Zo`0Io`04oookJP03ool0DOoonf[o0:go00;ooo]Z00?o
o`1ioookJ_oonfX01_oonfX01_l0oe?ooo]ZoookJ_oonf[o0?lMo`3o22Cooo]Z000[oookJP0;ool0
nOoonf[o07OooookJ_l0oi[oof`0o`3oc?oonf[ooh40oookJ_lko`000_oonfX00ol0nooooo]Zoook
JP03oookJP08onGo0?oonf[ooo]Zool0gOmi0?oo0:?ook?o0?nO0?l5oookJP03o`3og_nDo`3oU?l0
00;ooo]Z00SoU?l0oookJ_oonf[ooo]Zodd0oooonf[oH@3oo`3oA@Cooo]Z00GohP3oo`3oT?oonf[o
oo]Zo`3oTP07oookJP05onGo0?oonf[ooo]ZodCo0?lH0?l01?m4o`000oooT03ooo]ZoookJP08oook
JP04oonn0?oonf[oj`3oog00o`Gooo]Z00?oU?l0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP06
oookJP03oon10?oonf[ooo]Z00Gooo]Z00Ko0=CooookJ_l01?oo0:WooookJ_l0R?l3oookJP03o`3o
C_oUo`3oiOl000Kooo]Z00?o0>7oo`3o7OoonfX00_oonfX00ol0oe?ooo]ZoookJP02oookJP08ool0
NOl0[Ooooo]ZoookJ_oo057o5@3ooookJ_l0GOl2oa00o`03ool0mOoUo`3oiOl000GoiOl00_l0odd0
0ol0<?ooP_l0oh;o0002o`3o/0?ooo]Z0_l0oe/?oc7o0003o`3oFooob@3oolT000;oolT000CoogT0
o`3Xool0odgo0?m=0onBo`001?l007oo01Wooa00ool@0?l2ool0D@04o`2]oooo07Wooo]Zoomi00;o
0?mC00?o0?lMoomi0?ooN@001?oonfX01?l0odko0?l^oookJ_l0ZOl2oookJP03o`3Doooonf[ooo]Z
00;ooo]Z00Gooh40oookJ_oonf[ooo]Zool0;@03oookJP06onGo0?oonf[ooo]Zog00ooo[0?oookh0
1?oonfX01_ooT03ooo]ZoookJ_lH0?oooo]ZofP0o`;oolT000Cooo]Zo`3oT_oob@3ohP3o0_oob@00
2omQ0?ooolT0ooo90?oo06coo`27onGo0?oonf[oolT0ok?o0?oUo`3oo`3M00CoolT000Kooo]Zooo9
0?ooP@3oof`0o`3oV_l0Mol2oookJP03ojP0ool0Y_oojol000;ooo]Z00Soo`H0oookJ_oonf[ooo]Z
ool0o?oonf[ooi80oolF00Cooo]Z00?oo`3ZoookJ_oonfX02ooonfX00ol0Looooo]ZoookJP07oook
JP03okWo0?ooDP3oU?l000?oU?l000Cooo]Zo`3Loomho`3o0?oO1_oonfX01?l0oa_o4P3ooookJ_oo
bP02oookJPGoiOl00ooonfX01ooUo`3ohOl0oookJ_oonf[o9P3oob3o0?n40?l03ooonfX00ooUo`3o
oo]Zo`3oF`04oookJP03oh;o0?l0<?ooiOl000?oiOl000Cooo]Zo`H0oonBo`3oo`3e0_oonfX01?l@
0?ooiOl0onGo0?oUo`03oookJP06ool0DOoonf[ooo]Zo`2]oooonf[oA?l01OoonfX8oiCo0003o`3o
2?oonf[ooo]Z04[ooo]Z00_oo`3ioookJ_l0Mooooo]Zo`3oV_ooK03ooo]Zo`3oc?ooP@3ooo]Zoc_o
0003oookJP03o`3koooonf[ooo]Z00;ooo]Z00Woo`<0oookJ_oonf[oo`3MogT0oooonf[o0:?ook?o
0?nO0?l01OoonfX00ooo08Oooo]ZoookJP02oookJP07ool0K?oonf[ooo]Zodd0oooo;P3ooo]Zof40
o`04oookJP05on80ool0oi3ooo]ZoookJ_l0oi801ooonfX00omX0?oooo]ZoookJP02oookJP05oaP0
oooVo`3ooo]ZoookJ_ooT0002_oonfX01Ooo_P3ooo]Zo`3o1Oo[0?ooL03o00Cooo]Z00?ooeL0oook
J_oonfX00ooonfX00ooo02gooo]ZoookJP06oookJP03oon10?oonf[ooo]Z00Gooo]Z00Co0=Cooook
J_l01?oo0:Wo0_oonfX01_l0R?oooo]ZoookJ_l0odkooo]Zo`3o=0Oooo]Z00?o0>7oo`3o7OoonfX0
0_oonfX01_l0oe?ooo]ZoookJ_oonf[oo`1io`2]o`;ooo]Z00Co5@3oool0DOoonf[o05go0_l@0?l0
1?oonf[oo`3eoi;o0?nBo`02o`H0o`05oookJ_l0j?oo0?m=o`3oCOl0<?l00_n2o`02o`3o/0?ooo]Z
0ol0oe/>oc7o00;o0?mK0on2o`000ol0<?oo0>Soo`3Xo`02o`3oC@?oT_l000Co01Wooa00ool@0?oo
oo]Z0_oo05401?oo07Wooo]ZoookJ_l00002o`3oD`03o`3o2?l0hOoo0>7o00?ooo]Z00Co0?ldo`3o
C_oonf[o0:Wo0_oonfX00ol0e?oooo]ZoookJP02oookJP03oon10?oonf[ooo]Z00;ooo]Z00Goo`0]
oookJ_oonf[ooo]ZoomG0002oookJP03og00ooo[0?oooo]Z00Cooo]Z00Gooi00oookJ_lH0?oooo]Z
ofP0o`03oookJP0;o`3oT_oonf[o0?n@on80ool0odGoH@3ooookJ_m=0?ooo`1/oookJ_oo08L00_oo
nfX05_nco`3o01Ooo`2Soooo0=goo`<0oookJ_l0nooooo]Zoc_o0?ooP@3ooo]Zoom/0?l0Moooo`3i
oookJ_nX0?oo0:Koool0m_o[o`3ooo]Zool60?lH0?l3oookJP04ool0o?oonf[ooi80oolF00Cooo]Z
00?oo`3ZoookJ_oonfX02_oonfX00ol0Looooo]ZoookJP07oookJP0;okWo0?ooDP3ooo]ZoookJ_l0
:_oo?ol0oookJ_l0g?ooN?l0o`3ogolm0?l01OoonfX01?l0S_oo0?lKoa80oooobP03oookJP03o`3i
oooo09?oo`0C00Gooo]Z00Oof_l0oookJ_oonf[ooo]ZobH0oolPo`3oQ03o00oooo]Z00?o<Ol0o`3o
FooonfX00ooonfX01On2o`3o0?nao`0`ool0j?oo0?m=00;ooo]Z00?o1P3ooookJ_nBo`000ooonfX0
0ol@0?oo01WooookJP03oookJP06oaD0oooo057ooo]Zo`2]oooonf[oo`1i2OoonfX01_l0oe?ooo]Z
oookJ_oonf[o0?lMo`3o22Cooo]Z000[oookJP0;ool0nOoonf[o07OooookJ_l0oi[oof`0o`3oc?oo
nf[ooh40oookJ_lko`000_oonfX00ol0nooooo]ZoookJP04oookJP08onGo0?oonf[oo`3MogT0ool0
Xooo/ol0onGo0?nO0?l5oookJP05ool0Qooonf[ooo]ZoookJ_nDo`000ooonfX01?m=0?oooo]Zof40
ool0odD4oookJP03on80oooonf[o0?n@00;ooo]Z00?o0?nBoookJ_oonfX01?oonfX01OoUo`3ooo]Z
oookJ_m4o`3o603o00;oA?l00_oonfX00oooT03ooo]ZoookJP08oookJP04oonn0?oonf[o0?l5on/0
o`Gooo]Z00?oU?l0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP06oookJP03oon10?oonf[ooo]Z
00Gooo]Z00Oo0=CooookJ_l01?oooo]Zo`2Yoooonf[o08So00?ooo]Z00?o0?m>onGo0?oUo`001_oo
nfX00ol0hOoo0?lMoookJP02oookJP03o`3oDooonf[ooo]Z00;ooo]Z0_oo07T2oookJP05ool0DOlE
0?oooo]ZoookJ_oo06X00_l@0?l8onGo00;o0?m=00CoiOl0oh;o0?n2o`3oP_l00_l0ok02oookJP;o
ogT02?l0oe/00oooN@3oP_l0oh;o0002oh;o00CoogT00ol0odd2oi;o0003ool0mOl007oo403o00;o
403o0_oo05402?oonf[oo`1iool0NOoonf[oogT0o`3oDoooN@3o0?lM0_ooN@03oookJP05o`3o=?l0
odko0?l^oookJ_l0ZOl00_oonfX00ol0e?oooo]ZoookJP02oookJP03oon10?oonf[ooo]Z00;ooo]Z
00Woo`0]oookJ_oonf[ooo]ZoomG0?oonf[oL03oon/0oooo_P001OoonfX00oooT03ooo]ZoaP0o`02
oookJP03ofP0oooob@3oolT000?oolT000CohP3oooo90?oob@3oH@3o0_oob@001ooo06coo`27oook
J_oonf[oolT0ok?o0?oo0=d01?oob@003ol0nooooo]Zooo90?ooP@3oof`0o`1goooo0?Wooo]ZojP0
ool0Y_ooo`3fon_o0?oonf[oo`H0oaP0o`02oookJP04ool0o?oonf[ooo]ZoonB00Gooo]Z00?oiOl0
oookJ_oonfX02_oonfX00ol0Looooo]ZoookJP08oookJP03oomB0?nDo`3oU?l000?oU?l000Co0=co
oookJ_mho`3o0?oO1_oonfX00ol0oa_ooo]Zooo:0003oookJPCoiOl00ooonfX00ooUo`3ooo]Zon7o
0002oookJP03obH0oolPo`3ooo]Z00oooo]Z00?oiOl0o`3oFooonfX01?oonfX00on2o`3ooo]ZonGo
0003onGo0004o`H0oooonf[oT_l0ool0m@;ooo]Z00?o403oonGo0?oUo`000ooonfX01?oUo`3oo`1A
oookJ_l0[Ol2oookJP03odCo0?oonf[ooo]Z00?ooo]Z2?nDo`1=oookJP0;ool0nOoonf[o07Oooook
J_l0oi[oof`0oookJ_l0olcooh40oookJ_lko`000ooonfX00ol0nooooo]ZoookJP03oookJP08ool3
0?oonf[oo`3MogT0oooonf[o0:?ook?o0?nO0?l5oookJP03o`3og_oo08Oooo]Z00;ooo]Z00Ooo`1/
oookJ_oonf[oC@3oool^0?oonf[oH@3o00Cooo]Z00?ohP3ooookJ_l0oi000_oonfX00ol0oi;ooo]Z
oookJP04oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603oonKo0?oonf[ooo]Zoon@000;oookJP04
oonn0?l0o`Goj`3oog00o`Cooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP07oook
JP03oon10?oonf[ooo]Z00Gooo]Z00Ko0=CooookJ_l01?oo0:WooookJ_l0R?l3oookJP03o`3oC_l0
ocCooo]Z00Kooo]Z00?o0>7oo`3o2?l0oad00ooonfX01?l0oe?ooo]ZoookJ_oonfX2ool0N@?ooo]Z
00Coo`1AoookJ_oonf[o05go0_l@0?l01?oonf[oo`3eoi;o0?nBo`03o`H0o`04o`3Xool0odgo0?m=
o`0`o`?oP_l00_l0ok04oookJPSo0?mK00?ooo]Zoh;o0?n2o`000_n2o`02o`3o/0;o033o00Co0>So
o`3oCOl0odgo0?m=0_nBo`001Ooo0?Go403ooa00ool@0?oo001o00;oo`1A0_oo07T3oookJP04o`3o
Dol0oago0>7oo`3Qo`?ooo]Z0_l0oc@00ol0odkooo]Zo`2Yo`02oookJP03o`3Doooonf[ooo]Z00;o
oo]Z00?ooh40oookJ_oonfX00ooonfX02?oo02gooo]ZoookJ_oonf[ooeL0oookJ_m`0?ooj`3o1Ooo
nfX01_ooT03ooo]ZonKo0?lH0?oooo]ZofP0o`?ooo]Z00_o0?nBoookJ_oR0?oooo]Zo`3oAOmQ0?oo
obh0odd0oooo06cooo]Zool0Q`02oookJP04ok?o0?l0Xoooo`3Mool300;ooo]Z013o0?_ooookJ_lk
o`3ooh40o`3oV_l0Mooooo]Zool0nOoonf[oZ03ooookJ_o[o`3ooo]Zool60?oonf[o603o0_oonfX0
1?oo0?cooo]ZoonB0?oo5P04oookJP03ool0j_oonf[ooo]Z00_ooo]Z00?o07?ooookJ_oonfX01ooo
nfX02oooDP3ooo]ZoookJ_oonf[o02[oocoo0?oonf[o0=coogSo0?l0omoo?@3o00Gooo]Z00?o0?lK
oa80oooobP001?oonfX00ol0nOooo`2Cool04`04oookJP07om[o0?oQo`3ooo]ZoookJ_lV0?oooo]Z
ob3o000?oookJP03oc7o0?oonf[o0?mK00Cooo]Z00GoP_l0o`0`oooonf[o0>Soo`3oC@02oookJP03
o`H0oooonf[oT_l000?ooo]Z00?o403oo`0IoooonfX00ooonfX01_lE0?ooo`1AoookJ_l0[Ooooo]Z
ool0N@Wooo]Z00Go0?mCoookJ_oonf[ooo]Zo`3o7@0UoookJP00:ooonfX02ooo0?Wooo]Zo`1goooo
nf[o0?nJoom/0?l0olcooo]Zoon10?oonf[o>ol000;ooo]Z00?o0?_ooookJ_oonfX01?oonfX02?oU
o`3ooo]ZoookJ_oo0=go0:?ook?o0?oUo`3oW`3o1OoonfX00ol0omkoo`27oookJP02oookJP08oiCo
0?oonf[ooo]Zodd0oooonf[oH@3ooookJ_l0odD3oookJP03on80oooonf[o0?n@00;ooo]Z00?o0?nB
oookJ_oonfX01?oonfX02_oUo`3ooo]ZoookJ_m4o`3o603oo`1doooonf[oA?l0oookJ_ooT00;oook
JP04oonn0?oonf[oj`3oog00o`Cooo]Z0_nDo`05oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooh40
oookJ_oonfX01OoonfX01_l0e?oooo]Zo`04oooonf[o0:Woo`28o`?ooo]Z00?o0?m>onGo0?oUo`00
0_oUo`05oookJP03o`3Qool0oagooo]Z00;ooo]Z00?o0?mCoookJ_oonfX00ooonfX01?oo07Wooo]Z
oookJ_oo0542oaD0o`04oookJ_oo06[o01Wooa00o`WoiOl00ol0odd00ol0j?ooP_l0oh;o000=oh;o
00?oogT01Ol0odd00oooN@3oT_l0oi;o0002oomi00;o403o00Cooo]Zool0DOoo057o001o0_oo07T2
oookJP04oomi0?l0oe?o0?lMo`3o7@?oogT00_oonfX01Ol0ocCo0?m>o`3o;_l0R?oo0:Wo00;ooo]Z
00?o0=CooookJ_oonfX00_oonfX00oooP@3ooo]ZoookJP02oookJP0:ool0;Ooonf[ooo]ZoookJ_oo
E`3ooo]Zog00ooo[0?oooo]Zoonn00Cooo]Z00Kooi00oookJ_l0M?oo603ooookJ_mX0?l5ooo90004
on80oooob@3oolT0of40o`;oolT000?oo`1/ool0QooonfX00_oonfX00onco`3oolT0ool0g@06ooo9
0004oon10?ooK03o0?nJo`1go`;ooo]Z00KoZ03oo`2Voooonf[ojol0oookJ_oo1P03oookJP04ool0
o?oonf[ooi80oolF00Gooo]Z00?oiOl0oookJ_oonfX02_oonfX00ol0Looooo]ZoookJP07oookJP03
okWo0?ooDP3oU?l000?oU?l000Co?ol0o`3Loomho`3o0?oO1_oonfX01?l0oa_o4P3ooookJ_oobP03
oookJPCoiOl00ooonfX00ooUo`3ooo]Zon7o0002oookJP03obH0oolPo`3ooo]Z00kooo]Z00?oiOl0
oookJ_l0oe/01?oonfX00on2o`3o033ooookJP03onGo0004oookJ_l60?oooo]Zoi;o00;ooo]Z00Co
403oonGo0?oUo`3oo`1Z0ooonfX01_oUo`3oo`1AoookJ_l0[Ooooo]ZodCo00Kooo]Z1onDo`000ol0
o`Sooo]ZoookJP1;oookJP0;ool0nOoonf[o07OooookJ_l0oi[oof`0oookJ_l0olcooh40oookJ_lk
o`000ooonfX00ol0nooooo]ZoookJP03oookJP08ool30?oonf[ooo]Zool0gOoonf[o0:?ook?o0?nO
0?l5oookJP03omgo0?oo08Oooo]Z00;ooo]Z00Soo`1/oookJ_oonf[oC@3oool^0?oonf[oH@3oo`3o
A@?ooo]Z00?ohP3ooookJ_l0oi000_oonfX00ol0oi;ooo]ZoookJP05oookJP09ofP0oooonf[ooo]Z
oookJ_lH0?oo07CoonKo0?oonf[ooi0000_ooo]Z00Cookh0oookJ_l0o`Goj`3o1OoonfX00oooE`3o
oo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooh40oookJ_oonfX01OoonfX01ol0e?oo
oo]Zo`04oooonf[o0:WooookJ_l0R?l00_oonfX00ol0odko0?l^o`3o=007oookJP03o`3Qool0o`So
0?lM00?ooo]Z00?o0?mCoookJ_oonfX00_oonfX01_oo07Wooo]ZoookJ_oonf[oo`1AoaD0o`;ooo]Z
00Go01Wooa00ool@0?oo403ooookJP02oi;o0004oookJ_l60?oo1P3oo`H0o`?o0?m=0_l0j?l>oh;o
00?o0?n`00?o033oo`3oCOl0odd00ol0odd00ol60?ooT_l0oi;o0003oa00o`;ooo]Z0_oo0542ool0
N@Cooo]Z00?o0?mCo`3o7Ol0hOl00_l00002oookJP05o`3o=?oonf[o0?m>o`28ool0ZOl00_oonfX0
0ol0e?oooo]ZoookJP02oookJP03oon10?oonf[ooo]Z00?ooo]Z00Woo`0]oookJ_oonf[ooo]ZoomG
0?oonf[oL03oon/0oooo_P001?oonfX01_ooT03ooo]Zo`1doolH0?oooo]ZofP0o`?ooo]Z00_o0?nB
oookJ_oR0?oooo]Zo`3oAOmQ0?oooo]Zodd0oooo06cooo]Zool0Q`02oookJP04ok?o0?l0XoooN@3o
ool0g@?ooo]Z00oo0?_ooc_o0?ooP@3ooo]Zoom/0?l0Moooo`3ioookJ_nX0?oo0:Koool0m_o[o`3o
oo]Zool60?lH0?l00ooonfX01?oo0?cooo]ZoonB0?oo5P04oookJP03ool0j_oonf[ooo]Z00[ooo]Z
00?o07?ooookJ_oonfX01ooonfX00onio`3ooe80oookJP02oookJP06o`0Zooloo`3o0=cooookJ_mh
o`3o?@3o1_oonfX00ol0oa_o4P3oooo:0003oookJP03o`3ioooo09?oo`0C00Gooo]Z00Oof_l0on7o
0?oonf[ooo]ZobH0oolPo`3oQ03o00oooo]Z00?o<Ol0oookJ_l0oe/00ooonfX01_l0ok3oP_l0o`0`
ool0j?oooo]Zo`3oC@;ooo]Z00?o1P3oool0mOnBo`000_oonfX00ol@0?oo05goo`0Io`04oookJP06
oaD0oooo057ooo]Zo`2]oooonf[oo`1i2?oonfX01_l0oe?ooo]ZoookJ_oonf[o0?lMo`3o22Gooo]Z
000[oookJP0;ool0nOoonf[o07OooookJ_l0oi[oof`0o`3oc?oonf[ooh40oookJ_lko`000ooonfX0
0ol0nooooo]ZoookJP03oookJP08onGo0?oonf[ooo]Zool0gOmi0?oo0?l<onGo0?nO0?l5oookJP03
o`3og_oo08Oooo]Z00;ooo]Z00SoU?l0oookJ_oonf[oC@3oool^0?oonf[oH@3oo`3oA@Cooo]Z00Go
hP3oo`3oT?oonf[ooo]Zo`3oTP07oookJP09onGo0?oonf[ooo]ZoookJ_lH0?oooo]ZodCo0?oonf[o
oi0000_ooo]Z00Cookh0oookJ_o[0?ooL03o1OoonfX2oiCo00Cooo]Z00?oo`0]oookJ_oonfX01_oo
nfX00oooP@3ooo]ZoookJP06oookJP06o`3Dool01?oooo]ZoookJ_l0ZOoo08So0ooonfX00ol0odko
iOl0onGo0003onGo00?ooo]Z00Co0>7ooookJ_l0oago0?l80_oonfX2o`3oD`Cooo]Z0_oo07T01Ooo
nf[oo`1AoookJ_lE0?oooo]Z00;oo`1Z00?o01WoonGo0?oUo`002OoUo`08o`3oC@GoogT00_l0j?l4
o`3oC@;o0>So00CoogT0oi;o0?nBo`3oT_l01?ooN@001ol007oooo]Zool0DOlE0?oo0:goool0NOl0
07l00_oonfX2o`3oD`03o`3o7OooN@3oogT000CoogT000So0?ldo`3oC_l0obko08Soo`2Yoooonf[o
A?l0o`3Do`Cooo]Z00?ooh40oookJ_oonfX00_oonfX01Ooo02gooo]ZoookJ_oonf[ooeL000;ooo]Z
00?oj`3oo`3o1Ooo_P001?oonfX01oooT03ooo]ZoookJ_lH0?oooo]ZofP0oooonfX01?oob@001?oR
0?ooolT0ooo90?mQ0?l2ooo90003ool0K?oo08OoiOl000;ooo]Z00?oolT0ok?o0?oo0=d01ooob@00
3?ooP@3oof`0o`1goooo0?Wooo]ZojP0ool0Y_ooo`3fon_o0?oonf[oo`H0oaP0o`;ooo]Z00Coo`3l
oookJ_oonf[ooi801OoonfX00ooUo`3ooo]ZoookJP0;oookJP03o`1coooonf[ooo]Z00Oooo]Z00?o
iOl0oomB0?nDo`000onDo`001?oonf[o0=coogSo0?l0oml2oookJP?oiOl000Gooo]Zo`3o6olB0?oo
oo]Zooo:0003oookJP?oiOl01?oonfX00ooUo`3ooo]Zon7o0002oookJP03obH0oooonf[ooo]Z00ko
oo]Z00?oiOl0oookJ_l0oe/01?oonfX00on2o`3o033ooookJP03onGo0004oookJ_l60?ooT_l0ool0
m@;ooo]Z00?o403oonGo0?oUo`001?oonfX01_oUo`3oo`1AoookJ_l0[Ooooo]ZodCo00Kooo]Z1onD
o`000ol0o`Sooo]ZoookJP1;oookJP0;ool0nOoonf[o07OooookJ_l0oi[oof`0oookJ_l0olcooo]Z
oon10?lko`000ooonfX00ol0nooooo]ZoookJP03oookJP09ool30?oonf[ooo]Zool0gOmi0?oooo]Z
ok?o0?l05oooW`3o00Cooo]Z00?ogOl0ool0QooonfX00ooonfX01ooo06cooo]Zodd0oooonf[oobh0
oookJ_mQ0?l01?oonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Oooo]Z00OoJ03ooookJ_oonf[ooo]Z
oaP0ool0M?ooi_l000;ooo]Z00?ooi00oookJ_oonfX02OoonfX01?oo_P3o0?l5on/0oom`0?l4oook
JP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01ooonfX00oooP@3ooo]ZoookJP05oook
JP06o`3Doooonf[o00CooookJ_l0ZOoo08So0ooonfX00ol0odko0?l^o`3o=007oookJP03o`3Qool0
o`So0?lM00?ooo]Z00?o0?mCoookJ_oonfX00_oonfX2ool0N@;ooo]Z00Ooo`1AoaD0oooonf[ooo]Z
ool0J_l06Oooo`1Z00;o403o00?ooo]Zoi;o0?nBo`000_oonfX3o`H0o`So0?m=1Ol0<?l00ol0ok7o
0>Soo`3Xo`04o`3oC@03o`3Xool60?oo1P3o00?oT_l00_l@0?l00ol06Ooo001ooookJP02ool0D@03
o`2]oooo07Wo001o00?ooo]Z0_l0oe<2o`3Qo`Co000000So0?ldoookJ_l0odko08Soo`2Yoooonf[o
00Coo`3Do`Cooo]Z00?ooh40oookJ_oonfX00ooonfX01Ooo02gooo]ZoookJ_oonf[ooeL000;ooo]Z
00?oj`3ooonn0?oonfX01?oonfX01OooT03ooo]ZoaP0oooonf[oJ03o00Cooo]Z00_o0?nBo`3oT?oR
0?oooo]Zof40oooonf[oobh0ool0K?oonf[oo`27omgo0002oookJP04ok?o0?l0Xoooo`3Mool300;o
oo]Z00Oo0?_ooookJ_lko`3ooh40oom/0?l0Moooo`3i00;ooo]Z00OoZ03oo`2Voooo0?Kojol0ool6
0?oonf[o603o00;ooo]Z00Coo`3loookJ_ooTP3ooaH01?oonfX00ooo0>[ooo]ZoookJP0;oookJP03
o`1coooonf[ooo]Z00Oooo]Z00_o^Ol0oomB0?oonf[ooo]Zo`0Zooloo`3ooo]Zo`3Loomho`3o0?oO
ocd0o`05oookJP04o`3o6ooonf[o4P3oooo:00?ooo]Z00?o0?Woool0Tooo01<01OoonfX01_oJo`3o
hOl0oookJ_oonf[o9P3oob3o013ooo]Z00?o<Ol0o`3oFooonfX00ooonfX01_n2o`3o0?nao`0`ool0
j?oooo]Zo`3oC@;ooo]Z00?o1P3ooi;o0?oonfX00_oonfX00ol@0?oo01WooookJP03oookJP06oaD0
oooo057ooo]Zo`2]oooonf[oo`1i2OoonfX01_l0oe?ooo]ZoookJ_oonf[o0?lMo`3o22Gooo]Z000[
oookJP0;ool0nOoonf[ooo]Zo`1gool0oi[ooo]Zoom/0?oonf[ooh40oookJ_lko`000ooonfX00ol0
nooooo]ZoookJP03oookJP08onGo0?oonf[ooo]Zool0gOmi0?oo0?l<onGo0?nO0?l5oookJP03o`3o
g_oo08Oooo]Z00;ooo]Z00SoU?l0oookJ_oonf[oC@3oool^0?oonf[oH@3oo`3oA@Cooo]Z00?ohP3o
o`3oT?oonfX00_oonfX00ol0oi;ooo]ZoookJP04oookJP07onGo0?oonf[ooo]ZoookJ_lH0?oo07Co
odCo0002oookJP03oon@0?oonf[ooo]Z00Sooo]Z00Gookh0oookJ_l0o`Goj`3oog00o`04oookJP?o
U?l00ooonfX00ooo02gooo]ZoookJP07oookJP03oon10?oonf[ooo]Z00Gooo]Z00?o0=CooookJ_l0
1?l00_oonfX00ol0ZOoooo]ZoookJP02oookJP03o`3oC_oUo`3oiOl000?oiOl00ooonfX01?l0hOoo
oo]Zo`3o7Ol0o`P3oookJP03o`3oDooonf[ooo]Z00?ooo]Z0_oo07T2ool0D@;o5@3o0_oonfX00ol0
6OooiOl0onGo0007onGo0003oookJ_l60?oo1P3o00?o1P3o0ol0j?l7o`3oC@;oogT01OnBo`08oomi
0004ool0DOoob@3oolT0ool0N@;o001o0_l0oe<2o`3o7@OoogT000Oo0?m>odCo0?l0R?oo0:Wooook
J_m4o`3o0=Co00Cooo]Z00?ooh40oookJ_oonfX00_oonfX01Ooo02gooo]ZoookJ_oonf[ooeL000;o
oo]Z00?oj`3oo`3o1Ooo_P001?oonfX01?ooT03ooo]ZoookJ_lH0?l2oookJP03ofP0oooonf[oolT0
00?oolT000?ohP3oooo90?oob@000ooob@000ooo06coo`27onGo0002onGo0003ok?o0?oo0=goolT0
00WoolT000Wo07Ooool0nOoonf[oZ03oo`2Voooo0?Kojol0oookJ_oo1P000ooonfX01?oo0?cooo]Z
oonB0?oo5P05oookJP03onGo0?oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX02?oonfX00oooDP3o
oo]ZoiCo0002oiCo0005ocoo0?l0g?oooo]ZogSo0?l0oml00_oonfX4onGo0003o`3o6ooUo`3oolX0
00Cooo]Z0ooUo`03oookJP03onGo0?oonf[ohOl000;ooo]Z00?o9P3oob3o0?oonfX03ooonfX00ooU
o`3ooo]Zo`3oF`04oookJP03oh;o0?l0ok7ooo]Z00;oiOl000Gooo]Zo`H0oooonf[oT_l0ool0m@02
oookJP03oa00oooUo`3oo`1Z00?ooo]Z00OoiOl0ool0DOoonf[ooo]Zo`2]oooonf[oA?l000Kooo]Z
1_nDo`000ol0oagooo]Zo`3Qo`1=oookJP0:ool0nOoonf[o07Ooo`3oV_oonf[oof`0o`3oc?oonf[o
oh40oc_o00Cooo]Z00?o0?_ooookJ_oonfX00_oonfX02Ooo0`3ooo]ZoookJ_oo0=goN@3ooookJ_nc
o`3o01Oooil0o`04oookJP03omgo0?l0omkoo`2700?ooo]Z00Ooo`1/oookJ_m=0?oooo]Zool^0?oo
nf[oH@3o00Cooo]Z00?ohP3oo`3oT?oonfX00_oonfX00ol0oi;ooo]ZoookJP04oookJP03ofP0oooo
nf[ooo]Z00;ooo]Z00Go603oonKo0?oonf[ooo]Zoon@000;oookJP04oonn0?oonf[oj`3oog00o`Go
oo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP07oookJP03oon10?oonf[ooo]Z00Go
oo]Z00Oo0=CooookJ_oonf[o00CooookJ_l0ZOoo08So00?ooo]Z00?o0?m>o`3o;_l0oc@01ooonfX0
0ol0hOoooo]Zo`3o7@03oookJP03o`3oDooonf[ooo]Z00?ooo]Z0_oo07T01?l0[Oooo`1Aool0DOlE
0?l2oookJP?o01Wo0_l@0?l01?oonf[oT_l0oi;o0?oo0?D2oookJPKo1P3o0_l0j?l8o`3oC@;o1P3o
1OnBo`02oa00o`04o`0Ioooonf[o001oo`00O`;oo`1A00?o5@3oool0NOoo07T00_l007l01_oonf[o
0?mCo`3oDol0oago0>7ooookJP?o00000_l0oc@01ooonf[o0?m>o`28ool0ZOoooo]Zo`04ool0e?l0
1?oonfX00oooP@3ooo]ZoookJP03oookJP05ool0;Ooonf[ooo]ZoookJ_ooE`000_oonfX00oo[0?oo
okh0oookJP04oookJP06oon@0?oonf[oi_l0oaP0oooonf[oJ03o0ooonfX02ol0oi;ooo]Zon80oooo
nf[o0?m5of40oooonf[oC@3oool0K?oonf[oo`2700;ooo]Z00Co/ol0o`2Soooo0=goo`<00ooonfX0
3ol0nooo>ol0oon10?l0olcoof`0o`1goooo0?Wooo]ZojP0ool0Y_oooo]Zon_o0?oonf[oo`H0oaP0
o`03oookJP04ool0o?oonf[ooi80oolF00Cooo]Z00?oo`3ZoookJ_oonfX02ooonfX00ol0Looooo]Z
oookJP07oookJP0;oomB0?oonf[ooo]ZoookJ_l0:_oo?ol0oookJ_l0g?ooN?l0o`3ogolm0?l01Ooo
nfX00ol0oa_o4P3oooo:0004oookJP03o`3ioooo09?oo`0C00Cooo]Z00?of_l0on7o0?oonfX00_oo
nfX00olV0?oo8?l0oookJP0>oookJP03oc7o0?oonf[o0?mK00Cooo]Z00[oP_l0o`0`oooonf[o0>So
oookJ_l0odgooo]Zo`H0oooonf[oT_l00ooonfX00ol@0?oo01WooookJP03oookJP06oaD0oooo057o
oo]Zo`2]oooonf[oo`1i2OoonfX01ol0oe?ooo]ZoookJ_oonf[o0?lMoookJ_l0hOl09?oonfX002co
oo]Z00Koo`3ioookJ_l0Mooo0?nJoookJ_ooK002oookJP03oon10?oonf[o>ol000;ooo]Z00?o0?_o
oookJ_oonfX00ooonfX01OoUo`3ooo]ZoookJ_oo0=goN@3o00;o0?l<00?oW`3ooookJ_oonfX00ooo
nfX00ol0omkogOl0ool0Q`03oookJP08oiCo0?oonf[ooo]Zodd0oooonf[oH@3ooookJ_l0odD3oook
JP03on80oooonf[o0?n@00;ooo]Z00?o0?nBoookJ_oonfX01?oonfX02_oUo`3ooo]ZoookJ_oonf[o
603oo`1doooonf[oA?l0oookJ_ooT00;oookJP04oonn0?oonf[oj`3oog00o`Cooo]Z1?nDo`03oook
JP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooh40oookJ_oonfX01_oonfX00ol0e?oo00CooookJP02oook
JP03o`2Yool0R?oooo]Z00;ooo]Z00?o0?m>onGo0?oUo`001?oUo`02oookJP03o`3Qoooonf[o0?lM
00;o0?l80_oonfX00ol0oe?ooo]ZoookJP04oookJP03ool0NOl0[Oooo`1A00;oo`1A1?oonfX7onGo
00KoT_l00ol0o``4o`H0o`GoT_l03OooN@03ooo900;o001o00?o0?mCoomi0?l0oad02?ooN@001ol0
odkoA?l0odCo0?m4o`3ooo]ZodCo0?l0e?l01?oonfX00oooP@3ooo]ZoookJP02oookJP05ool0;Ooo
nf[ooo]ZoookJ_ooE`000_oonfX00om`0?ooj`3ooonn0005oookJP07oon@0?oonf[o603oonKo0?oo
nf[oJ03ooookJP04ooo90003on80oooob@3oolT000;oolT000?oC@3oool0K?oo08L00ooUo`000onc
o`3oiOl0ool0g@0;ooo90008oookJ_nX0?oooo]Zo`2Vooo[o`3ooo]Zool60?lH0?l2oookJP05ool0
o?oonf[ooo]ZoonB0?oo5P001?oonfX00ooUo`3ooo]ZoookJP0;oookJP03o`1coooonf[ooo]Z00Oo
oo]Z00?oiOl0oomB0?oonfX00_nDo`001Ooonf[o?ol0o`3Loomho`3o0?oO00?ooo]Z0ooUo`001Ol0
oa_o4P3oonGo0?oobP3oiOl000;ooo]Z00?o0?WoonGo0?oUo`001?oonfX00ooUo`3ooo]Zon7o0002
oookJP03obH0oolPo`3ooo]Z00kooo]Z00?oiOl0oookJ_l0oe/01?oonfX01?l0ok3oP_l0o`3o/Ooo
nfX2onGo0007oookJ_l60?oooo]Zoi;o0?oo0?Gooo]Zoa00o`02onGo000:ool0J_oonf[ooo]Zoook
J_oUo`3oo`1AoookJ_l0[Ooooo]ZodCo00Oooo]Z1_nDo`000ol0oagooo]Zo`3Qo`1=oookJP0;ool0
nOoonf[o07Ooo`3oV_oonf[oof`0o`3oc?oonf[ooh40oookJ_lko`000ooonfX00ol0nooooo]Zoook
JP02oookJP09ool30?oonf[ooo]ZoookJ_oo0=gooo]Zo`2Soonco`3oW`3o00Gooo]Z00?o0?oNool0
QooonfX00_oonfX02?oo06cooo]ZoookJ_m=0?ooobh0oookJ_mQ0?oo0?m50ooonfX00ooR0?oooo]Z
o`3oT002oookJP03o`3oT_oonf[ooo]Z00Cooo]Z00?oJ03ooookJ_oonfX00_oonfX01OlH0?oo07Co
onKo0?oonf[ooi0000_ooo]Z00Cookh0oookJ_l0o`Goj`3o1_oonfX00oooE`3ooo]ZoookJP02oook
JP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooh40oookJ_oonfX01OoonfX00ol0e?oooo]Zo`04o`02oook
JP03o`2Yool0R?oo08So00;ooo]Z00?o0?m>o`3o;_l0oc@01ooonfX01?l0hOoooo]Zo`3o7Ol0o`P2
oookJP03o`3oDooonf[ooo]Z00Cooo]Z00?oo`1io`2]ool0[Ol00ooo0543oookJP;o01Wo0ol@0?l8
oi;o0004ool0mOoonf[ooo]ZoookJPCo1P3o1OnBo`04oa00o`03o`0Iool0GOoo001o00;ooo]Z0_oo
05401?lE0?ooo`1iool0NOoonfX2o`00O`;o0?mC00?o0?lMo`3QoooonfX00_oonfX2o`000009o`3o
=?l0003o0?l^o`3oC_l0R?oo0:WooookJ_l01?oo0=Co00Cooo]Z00?ooh40oookJ_oonfX00ooonfX0
1Ooo02gooo]ZoookJ_oonf[ooeL000;ooo]Z00?oj`3ooonn0?oonfX01?oonfX01_ooT03ooo]Zo`1d
oolH0?oooo]ZofP0o`?ooo]Z00_o0?nBoookJ_oR0?oooo]Zo`3oAOmQ0?oooo]Zool^0?oo06cooo]Z
ool0Q`02oookJP05ok?o0?l05ooo0:?oool0gOoo0`000_oonfX04?l0nooooo]Zoc_o0?ooP@3oof`0
o`1goooo0?Wooo]ZojP0oooonf[o0:Koool0m_o[o`3oo`H0oookJ_lH0?l2oookJP05ool0o?oonf[o
oo]ZoonB0?oo5P000ooonfX00ooo0>[ooo]ZoookJP0;oookJP03o`1coooonf[ooo]Z00Oooo]Z00?o
^Ol0oomB0?oonfX00_oonfX01_l0:_oo?ol0o`3Loooonf[oN?l0ocd0o`Kooo]Z00?o0?lKoa80oooo
bP000ooonfX00ol0nOoooo]Zool0T`05oookJP07om[o0?oQo`3ooo]ZoookJ_lV0?oooo]Zob3o000?
oookJP03oc7o0?oonf[o0?mK00?ooo]Z00Ko0?n`oh;o0?l0<?oooo]Zo`3Xool0odd2oookJP03o`H0
oooonf[oT_l000;ooo]Z00?o403oo`1Mool06Ol01?oonfX01_lE0?ooo`1AoookJ_l0[Ooooo]Zool0
N@Wooo]Z00Oo0?mCoookJ_oonf[ooo]Zo`3o7Ooonf[o0>7o02Cooo]Z000/oookJP0;ool0nOoonf[o
07Ooo`3oV_oonf[oof`0o`3oc?oonf[ooh40oookJ_lko`000_oonfX00ol0nooooo]ZoookJP03oook
JP05onGo0?oonf[ooo]ZoookJ_oo0=d00ol0o``5oookJP03o`3og_oMo`3oo`2700?ooo]Z00CoU?l0
oookJ_oonf[oC@3o0_oonfX00omQ0?oo0?m5oookJP03oookJP05on80ool0oi3ooo]ZoookJ_l0oi80
1_oonfX02_oUo`3ooo]ZoookJ_oonf[o603oo`1doooonf[oA?l0oookJ_ooT00;oookJP04oonn0?oo
nf[oj`3oog00o`Cooo]Z1OnDo`02oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooh40oookJ_oonfX0
1OoonfX00ol0e?oooo]Zo`04o`03oookJP06o`2Yool0R?oooo]ZoookJ_oUo`3o0?m>1ooUo`001_oo
nf[o0>7ooookJ_l0oagooo]Zo`3o20;ooo]Z00?o0?mCoookJ_oonfX01?oonfX2ool0N@;o0:go0ooo
0542oookJPGoiOl01ol0o``7oi;o00Ko403o0_l06Ol01?l0GOoooo]ZoookJ_lE0?l3ool0D@;oo`1i
1?oob@02o`3oD`03oomi0?l0oagoogT000GoogT000?o0?ldo`3oC_l0odh01?m4o`02o`3Do`Cooo]Z
00?ooh40oookJ_oonfX00_oonfX01Ooo02gooo]ZoookJ_oonf[ooeL000;ooo]Z00?oL03oon/0oooo
_P001OoonfX01?ooT03ooo]Zo`1doolH0?l2oookJP03ofP0oooonf[oolT000?oolT000SohP3oooo9
0?oob@3oolT0odd0oooo06coiOl0ool0Q`?oiOl000?o/ol0ool0gOoob@002ooob@001ooonf[oZ03o
o`2Voooo0?Kojol0oookJ_oo1P000ooonfX01?oo0?cooo]ZoookJ_ooTP05oookJP03onGo0?oonf[o
oo]Z00_ooo]Z00?o07?ooookJ_oonfX01ooonfX00ooUo`3ooe80oookJP02oiCo0005ocoo0?l0g?oo
oo]ZogSo0?l0oml00ooonfX3onGo0005o`3o6olB0?ooiOl0ooo:0?oUo`000_oonfX00ol0nOooiOl0
onGo0004oookJP03onGo0?oonf[ohOl000;ooo]Z00?o9P3oob3o0?oonfX03_oonfX00ooUo`3ooo]Z
o`3oF`04oookJP03oh;o0?l0<?oooo]Z00;oiOl00_oonfX00ol60?oooo]Zoi;o0002oookJP03oa00
oooUo`3oiOl000Cooo]Z00KoiOl0ool0DOoonf[o0:gooookJ_m4o`07oookJPGoU?l000Co0?lMo`3o
2?oonf[o0>7oCOoonfX02ooo0?Wooo]Zo`1gool0oi[ooo]Zoom/0?oonf[o0?o<oon10?oonf[o>ol0
00?ooo]Z00?o0?_ooookJ_oonfX00_oonfX02Ooo0`3ooo]ZoookJ_oonf[oo`3MoookJ_l0Xooo/ol0
oil0o`05oookJP03o`3og_oo08Oooo]Z00;ooo]Z00Goo`1/oookJ_oonf[oC@3oool^0002oookJP03
of40oooonf[ooo]Z00;ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP07oookJP09ofP0oooonf[ooo]Z
oookJ_lH0?oo07CoonKo0?oonf[ooi0000cooo]Z00Cookh0oookJ_o[0?ooL03o1OoonfX00oooE`3o
oo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00?ooh40oookJ_oonfX01?oonfX01?l0e?oo
oo]ZoookJ_l01?l2oookJP03o`2Yoooonf[o08So00;ooo]Z00?o0?m>oookJ_l0oc@01ooonfX01?l0
hOoooo]Zo`3o7Ol0o`P2oookJP03o`3oDooonf[ooo]Z00Cooo]Z0_oo07T2o`2]o`04oaD0oooo057o
o`1Aool0D@?ooo]Z0ol06Ol7oa00o`SoT_l01Ol@0?l2o`0Io`04o`1Moooonf[ooo]Zo`00O`?oo`1A
0_oo07T01?l007oooo]ZoookJ_oonfX2o`3oD`03o`3o2?l0oago0>7o00Cooo]Z0_l0oc@01_l0003o
0?m>o`3oC_l0R?oo0:WooookJP;o0=Co1?oonfX00oooP@3ooo]ZoookJP03oookJP05ool0;Ooonf[o
oo]ZoookJ_ooE`000_oonfX00oo[0?oookh0oookJP05oookJP03oon@0?l0M?oo603o00;ooo]Z00oo
J03ooookJ_oonf[ooo]Zo`3oT_l0oi3ohP3ooookJ_l0odGoH@3ooookJ_oo06cooo]Zo`3og_oo08L0
0_oonfX01?nco`3o0:?oool0gOoo0`03oookJP0?o`3koolko`3ooh40o`3oc?ooK03o07Ooool0nOoo
nf[oZ03oo`2Voooonf[ojol0oookJ_oo1P3o603o00?ooo]Z00Coo`3loookJ_ooTP3ooaH01?oonfX0
0ooo0>[ooo]ZoookJP0;oookJP03o`1coooonf[ooo]Z00Oooo]Z00_o^Ol0oomB0?oonf[ooo]Zo`0Z
ooloo`3ooo]Zo`3Loomho`3o0?oOocd0o`05oookJP04o`3o6olB0?oooo]Zooo:00?ooo]Z00?o0?Wo
ool0Tooo01<01OoonfX01_oJo`3ohOl0oookJ_oonf[o9P3oob3o013ooo]Z00?o<Ol0o`3oFooonfX0
0ooonfX01_n2o`3o0?nao`0`ool0j?oooo]Zo`3oC@;ooo]Z00?o1P3oool0mOnBo`000_oonfX00ol@
0?oo01WooookJP03oookJP04oaD0oooonf[oo`1Ao`2]o`;ooo]Z00?oo`1ioookJ_oonfX01ooonfX0
1ol0oe?ooo]ZoookJ_l0oago0?l8oookJ_l0hOl09?oonfX002cooo]Z00_oo`3ioookJ_l0Mooooo]Z
o`3oV_ooK03o0?o<oookJ_ooP@3ooo]Zoc_o0003oookJP03o`3koooonf[ooo]Z00?ooo]Z00CoiOl0
oookJ_oonf[oo`3M0ol0o``00onO0?oooo]ZoookJP03oookJP03o`3og_oo08Oooo]Z00;ooo]Z00Co
U?l0oookJ_oonf[oC@3o0_oonfX00omQ0?oo0?m5oookJP03oookJP03on80ool0oi3ooo]Z00;ooo]Z
00?o0?nBoookJ_oonfX01?oonfX01ooUo`3ooo]ZoookJ_oonf[o603ooookJ_m4o`000_oonfX00ooo
T03ooo]ZoookJP09oookJP04oonn0?oonf[oj`3oog00o`Cooo]Z1OnDo`02oookJP03ool0;Ooonf[o
oo]Z00Kooo]Z00?ooh40oookJ_oonfX01_oonfX2o`3Do`06o`04oooonf[ooo]Zo`2Yoooonf[o08So
0_oonfX00ol0odkoiOl0onGo0006onGo0005oookJ_l0hOoo0>7oo`3o7OoonfX00_l0o`P00ooonf[o
0?mCoookJP06oookJP;oo`1i0_l0[Ol01?oonf[oo`1Aool0DOoo0544onGo00co0?l<00?o403oo`0I
ool06Ol01?l06Ol3o`00O`Coo`1A0ooo07T01?l007ooolT0ooo90?oob@02o`3oD`?oolT01?ooN@00
1Ooonf[o0?ldo`3oC_l0odko0?l^00CoA?l000?o0=CoodCo0?oonfX00ooonfX00oooP@3ooo]Zoook
JP02oookJP05ool0;Ooonf[ooo]ZoookJ_ooE`000_oonfX01?m`0?ooj`3oo`3o1Ooo_P04oookJP07
oon@0?oonf[ooo]ZoaP0oonDo`3ooo]ZofP0o`02oookJP?oolT000SohP3oooo90?oob@3oH@3oodd0
oooUo`3oo`1/ool0Q`?oiOl000?o/ol0ooo90?oo0=d00_oob@000ooonf[oolT0ooo90006ooo90008
oookJ_nX0?oooo]Zo`2Vooo[o`3ooo]Zool60?lH0?l2oookJP05ool0o?oonf[ooo]ZoonB0?oo5P00
1?oonfX00ooUo`3ooo]ZoookJP0;oookJP03o`1coooonf[ooo]Z00Oooo]Z00_oiOl0oomB0?oonf[o
oo]ZoiCo0?oonf[o?ol0o`3Loomho`3oiOl0o`3og`03oookJP?oiOl000Co0?lKonGo0?oobP3oiOl0
0ooonfX00ol0nOooiOl0oookJP03oookJP04onGo0?oonf[ooo]Zon7o00;ooo]Z00?o9P3ooookJ_oo
nfX03_oonfX00ooUo`3ooo]Zo`3oF`03oookJP0;o`3o/?n2o`3o033ooookJ_oUo`3o0?m=oookJ_l6
0?oooo]Zoi;o0?oo0?D00_oonfX00ol@0?ooiOl0ool0JP03oookJP07onGo0?oonf[oo`1AoookJ_l0
[Ooooo]ZodCo0007oookJPCoU?l000Cooo]Zo`3o7Ooonf[o0>7oC_oonfX02ooo0?Wooo]Zo`1goooo
nf[o0?nJoom/0?oonf[o0?o<oon10?oonf[o>ol000Cooo]Z00?o0?_ooookJ_oonfX00_oonfX01?oo
0`3ooo]ZoookJ_oo0=d2oookJP03ok?o0?nO0?oooo]Z00Cooo]Z00?ogOl0o`3og_oo08L00_oonfX0
1Ooo06cooo]ZoookJ_m=0?ooobh000;ooo]Z00?oH@3ooookJ_oonfX00_oonfX00ooR0?oo0?n@oook
JP02oookJP03o`3oT_oonf[ooo]Z00Cooo]Z00?oJ03ooookJ_oonfX00_oonfX01OlH0?ooi_l0oook
J_oonf[ooi0000_ooo]Z00Cookh0oookJ_o[0?ooL03o1_oonfX00oooE`3ooo]ZoookJP02oookJP03
ool0;Ooonf[ooo]Z00Oooo]Z00?ooh40oookJ_oonfX01OoonfX2o`3Do`04o`04oooonf[ooo]Zo`2Y
o`;ooo]Z00Ko08SooookJ_l0odko0?l^oookJ_l0oc@7oookJP;o0>7o00Go0?lMo`3o2?l0o`Sooo]Z
o`3oD`07oookJP;oo`1i0ol0[Ol00olE0?ooo`1Aool0D@04oookJP?o01Wo1?oo06X6oa00o`Ko01Wo
0ol007l01?oonf[oo`1Aool0DOoo0543ool0N@?o001o0_oonfX01?l0oe?o0?l8o`3o7Ol0oad5oook
JP09o`3o=?l0003o0?m>o`3oC_l0R?oooo]Zo`2Yool01?oo0=Co00Gooo]Z00?ooh40oookJ_oonfX0
0ooonfX01Ooo02gooo]ZoookJ_oonf[ooeL000;ooo]Z00?oj`3oo`3o1Ooo_P001OoonfX01_ooT03o
oo]ZoaP0oooVo`3ooo]ZofP0o`?ooo]Z00_o0?nBoookJ_oR0?oooo]Zo`3oAOmQ0?oooo]Zodd0oooo
06cooo]Zool0Q`02oookJP05ok?o0?l0Xoooo`3MoookJ_oo0`000_oonfX04?l0nooooo]Zoc_o0?oo
P@3oof`0o`1goooo0?Wooo]ZojP0oooonf[o0:Koool0m_o[o`3oo`H0oookJ_lH0?l2oookJP05ool0
o?oonf[ooo]ZoonB0?oo5P000ooonfX00ooo0>[ooo]ZoookJP0<oookJP03o`1coooonf[ooo]Z00Ko
oo]Z00?o^Ol0oomB0?oonfX00_oonfX01_l0:_oo?ol0o`3Loooonf[oN?l0o`3og`Kooo]Z00?o0?lK
oa80oooobP001?oonfX00ol0nOooo`2Cool04`04oookJP03om[o0?oonf[ohOl000;ooo]Z00?o9P3o
ob3o0?oonfX03_oonfX00olao`3ooo]Zo`3oF`03oookJP0;o`3o/?n2o`3o0?nao`0`ool0j?oooo]Z
o`3oCOoonf[o1P3ooookJ_nBo`000ooonfX00ol@0?oo01WooookJP03oookJP06oaD0oooonf[oo`1A
o`2]oooonf[oo`1i2OoonfX01ol0oe?ooo]ZoookJ_oonf[o0?lMoookJ_l0hOl09OoonfX002cooo]Z
00_oo`3ioookJ_l0Mooooo]Zo`3oV_ooK03o0?o<oookJ_ooP@3ooo]Zoc_o0003oookJP03o`3koooo
nf[ooo]Z00?ooo]Z00GoiOl0oookJ_oonf[oo`3MogT0o`03o`3o30Gooo]Z00?o0?oNoookJ_oo08L0
0_oonfX02OnDo`3ooo]ZoookJ_m=0?ooobh0oookJ_mQ0?oooo]Zo`3oA@03oookJP03on80oooonf[o
0?n@00;ooo]Z00?o0?nBoookJ_oonfX01?oonfX02_oUo`3ooo]ZoookJ_oonf[o603oo`1doooonf[o
A?l0oookJ_ooT00;oookJP04oonn0?oonf[oj`3oog00o`Cooo]Z1_nDo`02oookJP03ool0;Ooonf[o
oo]Z00Kooo]Z00?ooh40oookJ_oonfX01ooonfX02_l0e?oooo]ZoookJ_oonf[o0:WooookJ_l0R?oo
oo]ZonGo0?l0odh8onGo00;ooo]Z00Oo0>7oo`3o7Ol0oagooo]Zo`3o2?oonf[o0?mC00Sooo]Z00Co
o`1ioookJ_l0[Ooo0:go0_oonfX01?oo057oiOl0onGo0?oUo`02oomi00Wo0?l<0_l0GOl6oookJP?o
o`1A0_l0[Ol2ool0N@;o001o00?ooo]Zooo90?oob@000_l0oe<4ooo900;oogT00ooonfX01?l0ocCo
0?m>o`3o;_l00004odCo0004o`3Doom4o`3oA?l0odCo00;ooo]Z00Cooh40oookJ_oonf[ooo]Z0_oU
o`03oookJP07oomG0?oonf[ooo]Zog00ooo[0?oo0?l5oonn0004oookJP07oon@0?oonf[ooo]ZoaP0
oonDo`3ooo]ZofP0o`02oookJP?oolT000SohP3oooo90?oob@3oH@3oooo90?m=0?ooo`1/ool0Q`Co
iOl000Co/ol0ool0gOoob@3oolT00_oonfX7ooo90008ool0nOoonf[oZ03oo`2Voooo0?Kojol0oook
J_oo1P02oookJP05ool0o?oonf[ooo]ZoookJ_ooTP001OoonfX00ooUo`3ooo]ZoookJP0;oookJP03
o`1coooonf[ooo]Z00Oooo]Z00[oiOl0oomB0?oonf[ooo]Zo`0Zooloo`3ooo]Zo`3Loomho`3o0?oO
1?oonfX2onGo0005o`3o6olB0?ooiOl0ooo:0?oUo`000_oonfX00ol0nOoooo]Zool0T`04oookJP03
onGo0?oonf[ohOl000;ooo]Z00?o9P3oob3o0?oonfX03_oonfX00ooUo`3ooo]Zo`3oF`04oookJP05
o`3o/?n2o`3o0?naoookJ_l0odd00_oonfX01?l60?oooo]Zoi;o0?oo0?D2oookJP03oa00oooUo`3o
o`1Z00?ooo]Z00OoiOl0oookJ_oo057ooo]Zo`2]oooonf[oA?l000Oooo]Z1?nDo`001?oonf[o0?lM
oookJ_l0hOm?oookJP0:ool0nOl0Mooooo]Zo`3oV_ooK03ooo]Zo`3oc?oonf[ooh40oc_o00Cooo]Z
00?o0?_ooookJ_oonfX00_oonfX02Ooo0`3ooo]ZoookJ_oonf[oo`3MoookJ_l0Xooo/ol0oil0o`04
oookJP03omgo0?l0omkoo`2700?ooo]Z00Soo`1/oookJ_m=0?oooo]Zool^0?oonf[oH@3oo`3oA@Co
oo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603oo`1d
oooVo`3ooo]Zoon@000;oookJP04oonn0?oonf[ooo]Zon/0o`Kooo]Z00?ooeL0oookJ_oonfX00ooo
nfX00ooo02gooo]ZoookJP07oookJP03oon10?oonf[ooo]Z00Kooo]Z00Go0=Coo`04oooonf[ooo]Z
o`2Yo`02oookJP06o`28oooonf[o0?m>o`3o;_oonf[o0?ld2?oonfX00ol0hOoo0?lMo`3o7@02o`3o
2003o`3oDooonf[ooo]Z00Kooo]Z00?oo`1ioookJ_oonfX00_l0[Ol01Ooonf[oo`1Aool0DOoo057o
5@3o00?ooo]Z2?l06Ol2o`1Mo`Kooo]Z1?oo05400ol0[Oooo`1iool0N@02o`00O`04oookJ_l007oo
001oo`00O`;o0?mC0_l0oad2o`00O`Cooo]Z00Wo0?ldoookJ_l0odko0000o`28ool0003o0:Woo`04
ool0e?l01OoonfX00oooP@3ooo]ZoookJP02oookJP;oo`0]0ooonfX01_ooE`3ooo]ZoookJ_m`0?oo
j`3ooonn00Gooo]Z00Kooi00oookJ_l0M?oo603ooookJ_mX0?l3oookJP0<o`3oT_oonf[o0?n@on80
ool0odGoH@3ooookJ_m=0?ooo`1/oookJ_oo08OogOl00_oonfX01?nco`3o0:?oool0gOoo0`02oook
JP0@o`3koooonf[o>ol0oon10?ooK03o0?nJo`1goooo0?Wooo]ZojP0ool0Y_oooo]Zon_o0?oonf[o
o`H0oaP0o`;ooo]Z00Goo`3loookJ_oonf[ooo]ZoonB0004oookJP03ool0j_oonf[ooo]Z00_ooo]Z
00?o07?ooookJ_oonfX01ooonfX00onio`3ooe80oookJP02oookJP06o`0Zoooonf[o0=coogSo0?l0
omoo?@3o1_oonfX00ol0oa_o4P3oooo:0003oookJP03o`3ioooonf[oo`2C00Gooo]Z00?of_l0on7o
0?oonfX00_oonfX00olV0?oo8?l0oookJP0>oookJP03oc7o0?oonf[o0?mK00?ooo]Z00Ko0?n`oh;o
0?l0<?oooo]Zo`3Xool0odd2oookJP03o`H0oooonf[oT_l000?ooo]Z00?o403oo`0IoooonfX00ooo
nfX01_lE0?ooo`1AoookJ_l0[Ooooo]Zool0N@Wooo]Z00Oo0?mCoookJ_oonf[ooo]Zo`3o7Ooonf[o
0>7o02Gooo]Z000/oookJP0;ool0nOoonf[ooo]Zo`1gool0oi[oof`0o`3oc?oonf[ooh40oookJ_lk
o`000ooonfX00ol0nooooo]ZoookJP03oookJP05onGo0?oonf[ooo]ZoookJ_oo0=d01?l0o``4oook
JP03o`3og_oonf[oo`2700?ooo]Z00SoU?l0oookJ_m=0?ooobh0oookJ_mQ0?oooo]Zo`3oA@Cooo]Z
00GohP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP03onGo0?oonf[ooo]Z00;ooo]Z00?o603ooookJ_m4
o`000_oonfX00oooT03ooo]ZoookJP08oookJP05oonn0?oonf[oj`3oo`3o1Om`0?l00ooonfX7oiCo
00;ooo]Z00?oo`0]oookJ_oonfX01_oonfX00oooP@3ooo]ZoookJP07oookJP0:o`3Dool01?oooo]Z
oookJ_l0ZOoooo]Zo`28oooonf[oiOl0o`3oCPOoiOl01?oonfX01Ol0hOoo0?lMo`3o7Ol0o`Sooo]Z
00;o0?mC1ooonfX3ool0N@CoogT000?oiOl0ool0DOoo05401_oo0544o`3o30Co5@3o1?oo0542o`2]
o`?oo`1i00?ooo]Zo`00Ool007l00ooob@000ol0oe?oolT0ooo90004ooo900?ooo]Z00Go0?ldo`3o
C_l0odkooo]Zo`000003odCo00;o0=Co1Om4o`001OooP@3ooo]ZoookJ_oonf[oiOl000Cooo]Z00Oo
oeL0oookJ_oonf[ooo]Zon/0ool0o`Gookh000Gooo]Z00Cooi00oookJ_lH0?ooU?l00_oonfX00omX
0?oooo]ZoookJP03ooo90008on80oooob@3oH@3oooo90?m=0?ooo`1/onGo0?oo08L3onGo0006ok?o
0?oo0=goolT0ooo90?oo0`3ooo]Z1ooob@002Ooo0?Wooo]ZojP0ool0Y_ooo`3fon_o0?oonf[oo`H0
oaP0o`02oookJP05ool0o?oonf[ooo]ZoonB0?oo5P001?oonfX00ooUo`3ooo]ZoookJP0<oookJP03
o`1coooonf[ooo]Z00Kooo]Z00_oiOl0oookJ_ooDP3ooo]Zo`0Zoooonf[o?ol0o`3Loooonf[oN?l0
o`3og`04oookJP;oiOl000Co0?lKonGo0?oUo`3oolX00ooonfX00ol0nOooo`2Cool04`04oookJP03
onGo0?oonf[ohOl000;ooo]Z00?o9P3oob3o0?oonfX03_oonfX00ooUo`3ooo]Zo`3oF`04oookJP05
oh;o0?l0<?oo0?naonGo0?l0odd00_oonfX01_l60?oooo]Zoi;o0?oo0?GoiOl0oa00o`;oiOl01?oo
nfX01_oUo`3oo`1AoookJ_l0[Ooooo]ZodCo00Sooo]Z0onDo`02oookJP03o`3o7Ooonf[o0>7o04oo
oo]Z00[oo`3ioookJ_l0Mooo0?nJoom/0?oonf[o0?o<oookJ_ooP@3o>ol01?oonfX00ol0nooooo]Z
oookJP02oookJP09ool30?oonf[ooo]ZoookJ_oo0=gooo]Zo`2Soonco`3oW`3o00Cooo]Z00?ogOl0
o`3og_oo08L00ooonfX02?oo06cooo]Zodd0oooonf[oobh0oookJ_mQ0?oo0?m51?oonfX01OoR0?oo
0?n@oookJ_oonf[o0?nB00Kooo]Z00?oJ03ooookJ_oonfX00ooonfX01OlH0?ooi_l0oookJ_oonf[o
oi0000_ooo]Z00Cookh0oookJ_o[0?ooL03o1_oonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooo
nf[ooo]Z00Kooo]Z00?ooh40oookJ_oonfX01ooonfX01Ol0e?oo00Coo`04oooonf[o0:Wo00;ooo]Z
00Ko08SooookJ_l0odko0?l^oookJ_l0oc@9oookJP04o`3Qool0oago0?lMo`3o20;o0?mC1ooonfX4
ool0N@Co0:go2Ooo0544oookJPCo5@3o0ooo05400olE0?oo0:goool0N@02ool0N@04oookJ_l007oo
001oo`00O`;ooo]Z0_l0oe<2o`3o7@03o`3Qool007oo001o00?ooo]Z0_l0oc@2o`3oCP04o`000?l0
R?oo0:Woo`2Yo`;o0=Co1?oonfX2oon100Cooo]Z00?oo`0]oookJ_oonfX00_oonfX01_ooE`3ooo]Z
oookJ_oonf[oj`3ooonn00Gooo]Z00Cooi00oookJ_l0M?oo603o0_oonfX03?mX0?oooo]ZoookJ_oo
nf[o0?nBo`3oT?oR0?oooo]Zo`3oAOmQ0?ooobh0ool0K0;ooo]Z00Soo`27oookJ_oonf[o/ol0o`2S
oooo0=gooo]Zool300;ooo]Z013o0?_ooookJ_lko`3ooh40oom/0?l0Moooo`3ioookJ_nX0?oooo]Z
o`2Voooo0?Kojol0ool60?oonf[o603o0_oonfX01Ooo0?cooo]ZoookJ_ooTP3ooaH000?ooo]Z00?o
o`3ZoookJ_oonfX03?oonfX00ol0Looooo]ZoookJP06oookJP03okWo0?oonf[ooe8000;ooo]Z00Ko
02[oocoo0?oonf[o0=coogSo0?l0oml6oookJP04o`3o6olB0?oooo]Zooo:00?ooo]Z00?o0?Woool0
Tooo01<01OoonfX01ooJo`3ohOl0oookJ_oonf[o9P3ooh@0oolPo`003ooonfX00olao`3ooo]Zo`3o
F`03oookJP06oh;o0?oonf[o033oo`3Xoooonf[o0?m=0_oonfX00ol60?oooo]Zoi;o0002oookJP03
oa00ool06Ooooo]Z00?ooo]Z00Oo5@3ooookJ_oo057ooo]Zo`2]oooonf[oo`1i00Wooo]Z00Oo0?mC
oookJ_oonf[o0?lMo`3o2?oonf[o0>7o02Gooo]Z000]oookJP06ool0nOoonf[o07OooookJ_ooK03o
0?o<0_oonfX00oooP@3ooo]Zoc_o0003oookJP03o`3koooonf[ooo]Z00;ooo]Z00GoiOl0oookJ_oo
nf[ooo]Zool0g@05o`3o30Cooo]Z00?o0?oNool0QooonfX00_oonfX01?nDo`3ooo]ZoookJ_m=0?l2
oookJP03of40oooonf[o0?m500?ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP03onGo0?oo
nf[ooo]Z00;ooo]Z00?o603oo`1doom4o`000_oonfX00oooT03ooo]ZoookJP09oookJP04oonn0?oo
nf[oj`3oog00o`Cooo]Z1onDo`000ooonf[oo`0]oookJP07oookJP03oon10?oonf[ooo]Z00Sooo]Z
00Oo0=Coo`04oooonf[ooo]Zo`2Yoooonf[o08So00;oiOl000?o0?m>onGo0?oUo`000ooUo`06oook
JP;o0>7o0_l0oad00ol0o`Sooo]Zo`3oD`02o`3oD`Oooo]Z1Ooo07T4oomi00Co5@3o2?oo05400ol0
[Oooo`1iool0N@03ool0N@Go001o0_oob@02o`3oD`OoolT00_oonfX2o`3oCP04o`3o;_oonf[o08So
o`28o`;oA?l000?o0=CoodCo0?m4o`000om4o`000oooP@3ooo]ZoookJP02oookJP03onGo0?oonf[o
oo]Z00?ooo]Z00KooeL0oookJ_oonf[oj`3oo`3o1Ooo_P05oookJP04oon@0?oonf[ooo]ZoaP0o`;o
oo]Z00CoJ03ooookJ_oonf[ooo]Z0_oob@002?oR0?ooolT0of40oooob@3oC@3ooookJ_oo06coo`27
0ooUo`001Onco`3oiOl0ool0gOoob@3oo`<000;ooo]Z1_oob@002Ol0Moooo`3iojP0oooonf[o0:Ko
ool0m_o[o`3oo`H0oaP0o`02oookJP06ool0o?oonf[ooo]ZoookJ_ooTP3ooaH01?oonfX00ooUo`3o
oo]ZoookJP0;oookJP03o`1coooonf[ooo]Z00Oooo]Z00_oiOl0oomB0?oonf[ooo]Zo`0Zoooonf[o
?ol0o`3Loomho`3oiOl0o`3og`04oookJP05onGo0?l0oa_o4P3oonGo0?oobP000ooonfX00ol0nOoo
oo]Zool0T`04oookJP04onGo0?oonf[ooo]Zon7o00;ooo]Z00?o9P3ooookJ_oonfX03_oonfX00ooU
o`3ooo]Zo`3oF`03oookJP08o`3o/?n2o`3o033ooookJ_oUo`3o0?m=oookJ_l60?l2oookJP06oi;o
0?oo0?GoiOl0oa00oooUo`3oo`1Z1?oonfX01_oUo`3oU?l0oookJ_l0[Ooooo]ZodCo00Sooo]Z0onD
o`001?oonf[o0?l8o`3o7Ol0hOm@oookJP0;ool0nOoonf[o07OooookJ_ooK03ooo]Zo`3oc?oonf[o
oh40oookJ_lko`000ooonfX00ol0nooooo]ZoookJP02oookJP05ool30?oonf[ooo]ZoookJ_oo0=d0
0_oonfX00onco`3oW`3ooookJP04oookJP03omgo0?l0omkoo`2700;ooo]Z00Goo`1/oookJ_oonf[o
C@3oool^0002oookJP03of40ool0odGooo]Z00;ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP07oook
JP03ofP0oooonf[ooo]Z00;ooo]Z00Go603oonKo0?oonf[ooo]Zoon@000;oookJP04oonn0?oonf[o
j`3oog00o`Kooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP07oookJP03oon10?oo
nf[ooo]Z00Oooo]Z00Go0=CooookJ_l01?oooo]Zo`2Yo`02oookJP06o`28oooonf[o0?m>o`3o;_oo
nf[o0?ld2OoonfX2o`3Qo`;o0?lM00Co0?l8o`3oDol0oe?o0?mC2?oonfX5ool0N@?o0:go1OlE0?l8
ool0D@03o`2]oooo07Woo`1i00;oo`1i1_l007l00ooonf[o0?mCo`3oD`02o`3o7@03o`3Qool007oo
001o00;o001o0_oonfX01?l0ocCo0?m>o`3oC_oonfX2o`28o`03o`2Yool0003o0=Co00Gooo]Z00?o
oh40oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP02oookJP06oomG0?oonf[ooo]Zo`3o1Oo[0?oo
okh01_oonfX00oooT03ooo]ZoaP0o`02oookJP0FofP0oooonf[ooo]ZoookJ_l0oi;ooo]Zon80oooo
nf[o0?m5of40oooonf[oC@3oool0K?oonf[oo`27omgo0?oonf[o/ol0oil0ool0Xoooo`3Mool300;o
oo]Z013o0?_ooookJ_lko`3ooh40oom/0?l0oi[o07Ooool0nOoonf[oZ03oo`2Voooonf[ojol0ool6
0?oonf[o603o0_oonfX01_oo0?cooo]ZoookJ_oonf[ooi80oolF00?ooo]Z00?oo`3ZoookJ_oonfX0
2ooonfX00ol0Looooo]ZoookJP07oookJP03okWo0?ooDP3ooo]Z00;ooo]Z00Ko02[oocoo0?l0g?oo
oo]ZogSo0?l0oml6oookJP03o`3o6olB0?ooolX000?ooo]Z00Co0?WooookJ_oo09?oo`0C1?oonfX0
0ooJo`3ooo]Zon7o0002oookJP03obH0oolPo`3ooo]Z00kooo]Z00?o<Ol0oookJ_l0oe/00ooonfX0
2Ol0ok3oP_l0o`3o/Ol0<?oo0>SooookJ_l0odgooo]Zo`H0o`02oookJP05oi;o0?oonf[ooo]Zoa00
ool06Ol01?oonfX01_lE0?oooo]Zool0DOl0[Ooooo]Zool0N@[ooo]Z00Ko0?mCoookJ_oonf[o0?lM
oookJ_l0hOlVoookJP00;OoonfX01_oo0?Wooo]Zo`1goooonf[oof`0o`3oc0;ooo]Z00?ooh40oook
J_lko`000ooonfX00ol0nooooo]ZoookJP02oookJP05onGo0?oonf[ooo]ZoookJ_oo0=d01Ol0o``4
oookJP03o`3og_oonf[oo`2700;ooo]Z00CoU?l0oookJ_oonf[oC@3o0_oonfX00omQ0?oooo]Zo`3o
A@03oookJP03on80oooonf[o0?n@00;ooo]Z00?o0?nBoookJ_oonfX01?oonfX00ooUo`3ooo]Zoook
JP02oookJP03oaP0oom4o`3ooo]Z00;ooo]Z00?ooi00oookJ_oonfX02?oonfX01?oo_P3ooo]Zon/0
oom`0?l4oookJPSoU?l000?ooo]Zool0;OoonfX01ooonfX00oooP@3ooo]ZoookJP08oookJP07o`3D
ool01?oooo]ZoookJ_l0ZOoooo]Zo`28o`02onGo00;o0?m>0_oUo`09oookJP;o0>7o0ol0oad2oook
JP?o0?mC2OoonfX5ool0N@GoogT000?oo`1io`3o3?oo07T01?oo07T5oookJPCo001o0ol0oe<:ooo9
0006o`3oC_l0obkooo]ZoookJ_l0R?oo0:Wo0_m4o`001?l0e?ooA?l0odCo0?m4o`02oookJP03oon1
0?oUo`3ooo]Z00;ooo]Z00?oiOl0oookJ_oonfX00ooonfX01oooE`3ooo]ZoookJ_m`0?ooj`3ooook
J_oo_P001?oonfX01?ooT03ooo]ZoookJ_lH0?l2oookJP04ofP0oooonf[ooo]ZoookJP?oolT000So
hP3oooo90?mQ0?ooC@3ooookJ_oo06coiOl0ool0Q`;oiOl000Sooo]Zok?o0?oo0=goolT0oookJ_oo
0`3ooo]Zo`3ko`GoolT000[o07Ooool0nOoonf[oZ03oo`2Voooo0?Kojol0oookJ_oo1P3o603o0_oo
nfX01Ooo0?cooo]ZoookJ_ooTP3ooaH000Cooo]Z00?oiOl0oookJ_oonfX03?oonfX00ol0Looooo]Z
oookJP06oookJP0;onGo0?oonf[o0?l<oookJ_l0:_oooo]Zocoo0?l0g?oooo]ZogSo0?l0oml01Ooo
nfX01OoUo`3o0?lKonGo0?oUo`3oolX000?ooo]Z00?o0?Woool0Tooo01<01?oonfX00ooUo`3ooo]Z
on7o0002oookJP03oh@0oolV0?oooo]Z00kooo]Z00CoiOl0oookJ_oonf[o0?mK0ooonfX01On2o`3o
oo]Zo`0`oooonf[o0?m=00;ooo]Z00Co1P3ooookJ_oonf[oT_l00_oUo`000ol@0?ooiOl0ool0JP02
onGo0008oookJ_oUo`3ooo]ZoiCo0?oonf[o0:gooookJ_m4o`08oookJP;oU?l00_oonfX00ol0oago
oo]Zo`3Qo`1@oookJP0;ool0nOoonf[o07OooookJ_ooK03ooo]Zo`3oc?oonf[ooh40oookJ_lko`00
1?oonfX01Ol0nooooo]ZoookJ_oonf[oo`<000?ooo]Z00Goo`3MoookJ_oonf[o0:?ook?o0005oook
JP03omgo0?l0omkoo`2700;ooo]Z00Goo`1/oookJ_oonf[oC@3oool^0002oookJP03of40ool0odGo
oo]Z00?ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP03ofP0oooonf[ooo]Z00?ooo]Z00Go
603ooookJ_oonf[ooo]Zoon@000:oookJP04oonn0?oonf[ooo]Zon/0o`Oooo]Z00?ooeL0oookJ_oo
nfX00ooonfX00ooo02gooo]ZoookJP07oookJP03oon10?oonf[ooo]Z00Oooo]Z00Go0=CooookJ_l0
1?oooo]Zo`2Yo`02oookJP06o`28oooonf[o0?m>o`3oC_oonf[o0?ld2_oonfX2o`3Qo`;o0?lM0_oo
nfX3o`3oD`[ooo]Z1Ooo07T2oookJP?o0:go1ooo07T4oookJPCo001o0ol0oe<00ol0oago0>7ooook
JP05o`00O`;ooo]Z0_l0odh00ol0obkooo]Zo`28o`02o`2Yo`03o`04ool0e?oo000000Cooo]Z00?o
oh40oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP02oookJP07oomG0?oonf[ooo]Zo`3o1Oo[0?oo
oo]Zoonn0005oookJP06oon@0?oonf[oi_l0oaP0oooonf[oJ03o1?oonfX02ol0oi;o0?n@on80oooo
nf[oH@3ooookJ_m=0?ooo`1/oookJ_l0omkoo`2700;ooo]Z00Go/ol0o`2Soooo0=gooo]Zool30002
oookJP0@o`3koooonf[o>ol0oon10?ooK03o07Ooool0nOoonf[oZ03oo`2Voooonf[oo`3fon_o0?oo
1P3ooo]ZoaP0o`;ooo]Z00Goo`3loookJ_oonf[ooi80oolF0003oookJP03ool0j_oonf[ooo]Z00co
oo]Z00?o07?ooookJ_oonfX01_oonfX00onio`3ooo]ZoomB0002oookJP06o`0Zooloo`3ooo]Zo`3L
oomho`3o0?oO1ooonfX00ol0oa_ooo]Zooo:0003oookJP03o`3ioooo09?oo`0C00Gooo]Z00?of_l0
on7o0?oonfX00_oonfX00olV0?oo8?l0oookJP0>oookJP03oc7o0?oonf[o0?mK00?ooo]Z00KoP_l0
oookJ_l0ok7o033oo`3Xool0odd2oookJP04o`H0oooonf[oo`3eoi;o00;ooo]Z00?o403oo`0Ioooo
nfX00ooonfX01_lE0?oooo]Zool0DOl0[Ooooo]Zool0N@[ooo]Z00Ko0?mCoookJ_oonf[o0?lMoook
J_l0hOlVoookJP00;OoonfX02ooo0?Wooo]Zo`1goooonf[oof`0oookJ_l0olcooo]Zoon10?oonf[o
>ol000?ooo]Z00?o0?_ooookJ_oonfX00_oonfX01OoUo`3ooo]ZoookJ_oonf[oo`3M00Ko0?l<0ooo
nfX00ol0omkooo]Zool0Q`02oookJP04oiCo0?oonf[ooo]Zodd0o`;ooo]Z00?oH@3ooookJ_l0odD0
1?oonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Kooo]Z00?oiOl0oookJ_oonfX00_oonfX00olH0?oo
07CoodCo0002oookJP03oon@0?oonf[ooo]Z00Wooo]Z00Cookh0on/0ool0o`GoL03o0ooonfX6oiCo
00Cooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooP@3ooo]ZoookJP09oookJP07o`3Dool01?oooo]Z
oookJ_l0ZOoooo]Zo`28o`03onGo00;o0?m>00?oiOl0oookJ_oonfX02?oonfX2o`3Qo`03onGo0?l0
oago0?lM00?oiOl00ol0oe<8oookJP?oogT01Ooo07T00oooN@3ooo]ZoookJP09oookJPCo0?mC2_oo
b@001?oonf[o0?m>o`3oC_l0obh2oookJP;o0:Wo00?oA?l0o`3Dool0e?l00_m4o`02oookJP;ooh40
0ooUo`000ooonf[oiOl0oookJP04oookJP08oomG0?oonf[ooo]Zog00ooo[0?oooo]Zoonn0?oonfX2
oiCo0005oookJ_ooT03ooo]ZoookJ_lH0?l00ooonfX01?mX0?oooo]ZoookJ_oonfX2ooo90008on80
oooob@3oH@3oool^0?m=0?ooo`1/onGo0?oo08L2onGo0006oookJ_nco`3oW`3oool0gOmi0?ooo`<0
0_oonfX00ol0noooolT0ooo90002ooo9000=o`3oV_l0Moooo`3iojP0oooonf[o0:Koool0m_o[o`3o
o`H0oookJ_lH0?oooo]Zool0o003oookJP03oonB0?oo5P3ooo]Z00?ooo]Z00?oiOl0oookJ_oonfX0
2ooonfX00ol0Looooo]ZoookJP07oookJP0;onGo0?oonf[o0?l<oookJ_l0:_oooo]Zocoo0?l0g?oo
N?l0onGo0?l0oml01?oonfX2onGo0004o`3o6ooUo`3oiOl0ooo:00?ooo]Z00?o0?Woool0Tooo01<0
1?oonfX00ooUo`3ooo]Zon7o0002oookJP03obH0oolPo`3ooo]Z00kooo]Z00?oiOl0oookJ_l0oe/0
1?oonfX01On2o`3o033oo`3o/OoUo`3o0?m=00;ooo]Z00Co1P3ooookJ_nBo`3oo`3e0_oUo`000ol@
0?ooiOl0onGo0002onGo0003oookJ_oUo`3oU?l000;ooo]Z00?o0:goodCo0?oonfX02?oonfX2oiCo
00;ooo]Z00?o0?lMoookJ_l0hOl0D?oonfX01Ooo0?Wooo]Zo`1goooonf[oof`000;ooo]Z00Co0?o<
oookJ_ooP@3o>ol01?oonfX01Ol0nooooo]ZoookJ_oonf[oo`<000?ooo]Z00GoN@3oool0gOoonf[o
0:?ook?o0005oookJP03omgo0?l0omkoo`2700?ooo]Z00Coo`1/oookJ_m=0?ooobh00_oonfX00omQ
0?oo0?m5oookJP03oookJP05on80ool0oi3ooo]ZoookJ_l0oi801_oonfX00omX0?oooo]ZoookJP03
oookJP05oaP0oooVo`3ooo]ZoookJ_ooT0002ooonfX01?oo_P3ooo]Zon/0oom`0?l7oookJP03oomG
0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX01_oonfX00oooP@3ooo]ZoookJP08oookJP05o`3D
oooonf[o00CooookJ_l0ZOl00_oonfX00ol0R?oooo]ZoookJP02o`3oCP03o`3o=?oonf[ooo]Z00Wo
oo]Z0_l0hOl2o`3o7@03o`3o2?oonf[ooo]Z00?o0?mC3?oonfX5ool0N@_ooo]Z1?l0oe<2o`3o7@03
o`3Qoooonf[ooo]Z00Kooo]Z0_l0odh00ol0obkooo]ZoookJP02o`2Yo`03oookJ_l0e?oo0=Co00;o
00000ooonfX00oooP@3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00;ooo]Z00OooeL0oookJ_oo
nf[o0?l5on/0oooonf[ookh000Gooo]Z00Cooi00oookJ_oVo`3o603o0_oonfX03?mX0?oooo]Zoook
J_oonf[o0?nBo`3oT?oR0?oooo]Zo`3oAOmQ0?ooC@3oool0K0;ooo]Z00Soo`27oookJ_oonf[o/ol0
o`2Soooo0=goN@3oool300;ooo]Z00ko0?_ooookJ_lko`3ooh40oom/0?l0oi[o07Ooool0nOoonf[o
Z03oo`2Voooonf[ojol0ool600;ooo]Z00?o603ooookJ_oo0?`00ooonfX00oooTP3ooaH0oookJP02
oookJP03ool0j_oonf[ooo]Z00_ooo]Z00?o07?ooookJ_oonfX01ooonfX00onio`3ooo]ZoomB0002
oookJP06o`0Zooloo`3ooo]Zo`3Loomho`3o0?oO1_oonfX01?l0oa_o4P3ooookJ_oobP03oookJP03
o`3ioooo09?oo`0C00Gooo]Z00Oof_l0on7o0?oonf[ooo]ZobH0oon40?oo8?l000oooo]Z00?o<Ol0
oookJ_l0oe/00ooonfX02?n2o`3ooo]Zo`0`ool0j?oooo]Zo`3oCOoonf[o1P3o0_oonfX01OnBo`3o
oo]ZoookJ_oonf[o403o00Cooo]Z00Oo5@3ooookJ_oo057ooo]Zo`2]oooonf[oo`1i00Wooo]Z00Oo
0?mCoookJ_oonf[ooo]Zo`3o7Ooonf[o0>7o02Kooo]Z000]oookJP03ool0nOoonf[o07Oo00;ooo]Z
00Koof`0o`3oc?oonf[ooh40oookJ_lko`03oookJP03o`3koooonf[ooo]Z00?ooo]Z00CoiOl0oook
J_oonf[ooo]Z1ol0o``3oookJP03o`3og_oo08Oooo]Z00;ooo]Z00KoU?l0oookJ_m=0?ooobh0oook
J_mQ0?l2oookJP06o`3oAOoonf[ooo]ZoookJ_oR0?oo0?n@0_oonfX00ol0oi;ooo]ZoookJP04oook
JP03onGo0?oonf[ooo]Z00?ooo]Z00?o603oodCo0?oonfX00_oonfX00oooT03ooo]ZoookJP08oook
JP04oonn0?oonf[oj`3oog00o`?ooo]Z1OnDo`06oookJP03ool0;Ooonf[ooo]Z00Gooo]Z0_ooP@0:
oookJP04o`3Dool01?oo00CooookJP;oolT00ooUo`02ooo90004o`3oC_oUo`3o0?ldooo900Wooo]Z
00?o0>7ooookJ_oUo`000_l0oad4onGo00?o0?mC1OoUo`03oookJPKoogT01ooonfX4o`3oD`;o0?l8
1ooob@04oookJP;o0?m>00So0?l^oookJ_oonf[ooo]Zo`2Yoooonf[oA?l0o`3Do`;oA?l00_l00000
0ooonf[ooh40oookJP05onGo00Gooo]Z00OooeL0oookJ_oonf[oL03oon/0oooonf[ookh000;ooo]Z
0onDo`001?ooT03ooo]ZoiCo0?lH0?l2oookJP0>ofP0oooonf[ooo]ZoookJ_l0oi;oolT0on80oooo
nf[oH@3ooookJ_m=0?oooo]Zool0K?oo08L3onGo0009oookJ_nco`3oo`3MogT0oooonf[oo`<0oook
J_l0nooooo]Z00?oolT000_o0?nJo`1goooo0?Wooo]ZojP0ool0Y_ooo`3fon_o0?oonf[oo`H0oaP0
o`02oookJP05ool0o?oonf[ooo]ZoookJ_ooTP001?oonfX00ooUo`3ooo]ZoookJP0<oookJP03o`1c
oooonf[ooo]Z00Oooo]Z00CoiOl0o`3o3?oonf[o02[o0_oonfX01Oloo`3o0=coogSo0?oUo`3o0?oO
00Cooo]Z00GoiOl0o`3o6olB0?ooiOl0ooo:0003oookJP04o`3ioooonf[oo`2Cool04`?ooo]Z00?o
iOl0oookJ_oQo`000ooonfX00olV0?oooo]ZoookJP0>oookJP03onGo0?oonf[o0?mK00?ooo]Z00Go
0?n`oh;o0?l0<?oo0?nao`3oC@02oookJP09o`H0oooonf[ooo]Zoi;o0?oo0?GoiOl0oa00oooUo`3o
o`1Z00;oiOl00_oonfX01_oUo`3oU?l0oookJ_l0[Ooooo]ZodCo00Wooo]Z00OoU?l0oookJ_oonf[o
0?l8o`3o7Ooonf[o0>7o057ooo]Z00[oo`3io`1goooonf[ooo]Zoom/0?oonf[o0?o<oookJ_ooP@3o
>ol01?oonfX00ol0nooooo]ZoookJP02oookJP05ool30?oonf[ooo]ZoookJ_oo0=d00_oonfX00onc
o`3oW`3ooookJP04oookJP03omgo0?l0omkoo`2700;ooo]Z00Woo`1/oookJ_m=0?oooo]Zool^0?oo
nf[oH@3ooookJ_l0odD00ooonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Kooo]Z00?oJ03ooookJ_oo
nfX01?oonfX01OlH0?oooo]ZoookJ_oonf[ooi0000[ooo]Z00Cookh0oookJ_oonf[oj`3o1ooonfX0
0oooE`3ooo]ZoookJP04oookJP03ool0;Ooonf[ooo]Z00Kooo]Z0_ooP@09oookJP04o`3Doooonf[o
00CooookJP;o0:Wo00?ooo]Zo`28oooonfX00_oonfX00ol0odko0?ldo`3o=00;oookJP04o`3Qoooo
nf[o0?lMo`3o7@?o0?l800Cooo]Zo`3oDol0oe?o0?mC5_oonfX3o`3oD`;o0?l80_l0oad9oookJP04
o`3o=?l0odko0?l^o`3o;P;ooo]Z00Co0:WooookJ_oonf[o0=Co1?l000000ooonf[ooh40oon10005
oookJP03ool0;Ooonf[ooo]Z00;ooo]Z00OooeL0oookJ_oonf[o0?l5on/0oooonf[ookh000Gooo]Z
00Cooi00oookJ_oVo`3o603o0_oonfX04?mX0?oooo]ZoookJ_oonf[o0?nBoookJ_oR0?oooo]Zo`3o
AOmQ0?ooobh0odd0oooo06cooo]Zool0QooMo`02oookJP07ok?o0?l0Xoooo`3MoookJ_oo0`3ooo]Z
o`3ko`02oookJP0>oc_o0?ooP@3oof`0o`1goooo0?Wooo]ZojP0ool0Y_oooo]Zool0m_o[o`3oo`H0
oookJ_lH0?l2oookJP05ool0o?oonf[ooo]ZoookJ_ooTP000ooonfX00ooo0>[ooo]ZoookJP0<oook
JP03o`1coooonf[ooo]Z00Oooo]Z00_o^Ol0oomB0?oonf[ooo]Zo`0Zoooonf[o?ol0o`3Loooonf[o
N?l0o`3og`06oookJP03o`3o6ooonf[oolX000?ooo]Z00Co0?WooookJ_oo09?oo`0C1?oonfX00ooJ
o`3ohOl0oookJP02oookJP03obH0oolPo`3ooo]Z00kooo]Z00?o<Ol0oookJ_l0oe/00ooonfX01_l0
ok3oP_l0oookJ_l0<?oo0>Soo`3oC@;ooo]Z00Co1P3ooookJ_oonf[oT_l00_oonfX00ol@0?oo01Wo
oookJP03oookJP07oaD0oooonf[oo`1AoookJ_l0[Ooooo]Zool0N@09oookJP04o`3oDooonf[ooo]Z
o`3o7@;ooo]Z00?o0>7ooookJ_oonfX09?oonfX002kooo]Z00Koo`3ioookJ_l0Mooooo]Zoom/0?l0
ol`2oookJP03oon10?lko`3ooo]Z00?ooo]Z00?o0?_ooookJ_oonfX00_oonfX01?oUo`3ooo]Zoook
J_oonfX7o`3o30?ooo]Z00?o0?oNool0QooonfX00_oonfX01?nDo`3ooo]Zodd0oooo;P02oookJP03
of40oooonf[o0?m500?ooo]Z00?ohP3oo`3oT?oonfX00_oonfX00ol0oi;ooo]ZoookJP04oookJP03
onGo0?oonf[ooo]Z00;ooo]Z00?o603oodCo0?oonfX00_oonfX00oooT03ooo]ZoookJP08oookJP05
oonn0?oonf[ooo]Zon/0oom`0?l00ooonfX2oiCo00;ooo]Z00?oU?l0oookJ_oonfX00ooonfX00ooo
02gooo]ZoookJP07oookJP03oon10?oonf[ooo]Z00Sooo]Z00?o0=CooookJ_l01?l01Ooob@000ooo
nf[oolT0ooo90002o`3oCP;o0?ld0_oob@07oookJP;o0>7o00Cooo]ZonGo0?l0oago0?lM1OoUo`09
o`3oD`03oookJ_ooN@3oogT000;oogT00ooonfX4o`3oD`;o0?l80ol0oad3ooo900Kooo]Z0_l0oc@0
0ol0odko0?l^oookJP02oookJP;o0:Wo00Cooo]ZodCo0?l0e?oooo]Z1?l000000oooP@3ooo]Zoook
JP06onGo00?ooo]Z00OooeL0oookJ_m`0?ooL03oon/0oooonf[ookh000;ooo]Z1_nDo`001?lH0?oo
oo]ZoookJ_oob@04oookJP0:ooo90?oR0?oooo]ZoookJ_mQ0?ooC@3ooookJ_oo06cooo]Zool0Q`?o
iOl000So/ol0ool0gOmi0?oooo]Zool30?oonf[o0?_ooookJP?oolT000ko0?nJoookJ_l0Moooo`3i
ojP0ool0Y_oooo]Zool0m_o[o`3oo`H0oookJ_lH0?oooo]Zool0o0?ooo]Z00?ooi80oookJ_oonfX0
0ooonfX00ooUo`3ooo]ZoookJP0;oookJP03o`1coooonf[ooo]Z00Oooo]Z00_oiOl0oookJ_l0o`co
oo]Zo`0Zoooonf[o?ol0o`3Loooonf[oN?l0o`3og`05oookJP05onGo0?l0oa_oiOl0onGo0?oobP00
0ooonfX00ol0nOooo`2Cool04`04oookJP03onGo0?oonf[ohOl000;ooo]Z00?oQ03oobH0oooonfX0
3_oonfX01?oUo`3ooo]ZoookJ_l0oe/3oookJP05oh;o0?oonf[o033ooookJ_l0odd00_oonfX01?l6
0?oooo]ZoookJ_nBo`02onGo0003oa00oooUo`3oiOl000;oiOl000Sooo]ZonGo0?oonf[oU?l0oook
J_l0[Ooooo]ZodCo00Wooo]Z00Ko0?mCoookJ_oonf[o0?l8o`3o7Ol0hOmBoookJP0:ool0nOoonf[o
07OooookJ_ooK03ooo]Zo`3oc?oonf[ooh40oc_o00Cooo]Z00?o0?_ooookJ_oonfX00_oonfX01Ooo
0`3ooo]ZoookJ_oonf[oo`3M00;ooo]Z00?o0:?ook?o0?oonfX01?oonfX00ooMo`3o0?oNool0Q`02
oookJP05ool0K?oonf[oC@3ooookJ_oo;P000_oonfX00omQ0?oo0?m5oookJP03oookJP05on80oooo
nf[ooo]ZoookJ_l0oi801_oonfX00omX0?oooo]ZoookJP03oookJP05oaP0ool0M?oooo]ZoookJ_oo
T0002_oonfX01Ooo_P3ooo]ZoookJ_l0o`Goj`3o00Oooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo
02gooo]ZoookJP08oookJP03oon10?oonf[ooo]Z00Oooo]Z00?o0=CooookJ_l01?l00_oonfX00ol0
ZOoooo]Zo`28o`03oookJP;o0?m>0_l0oc@:oookJP;o0>7o00Cooo]Zo`3o7Ol0oagooo]Z0ol0o`P0
0ooonf[o0?mCo`3oD`07o`3oD`Wooo]Z1?l0oe<00ol0o`So0?lMo`3o7@02o`3o7@Sooo]Z0_l0oc@2
o`3oCP03o`3o;_oonf[ooo]Z00;o0:Wo0_oonfX00ol0e?oooo]Zo`000003o`000003oon10?oonf[o
oo]Z00Cooo]Z00?oo`0]oookJ_oonfX00_oonfX01oooE`3ooo]ZoookJ_m`0?ooj`3ooookJ_oo_P00
1OoonfX01oooT03ooo]ZoookJ_oVo`3o603ooookJ_mX0?l01?oonfX02?l0oi;ohP3ooookJ_oonf[o
H@3ooookJ_m=0?ooo`1/0_oonfX02?oo08Oooo]ZoookJ_nco`3o0:?oool0gOoonf[oo`<00_oonfX0
3_l0nooooo]Zoc_o0?ooP@3oof`0oookJ_l0Moooo`3ioookJ_nX0?oo0:KooookJ_oo0?Koo`H00_oo
nfX00olH0?oooo]Zool0o003oookJP03oonB0?oonf[ooo]Z00;ooo]Z00?oo`3ZoookJ_oonfX02ooo
nfX00ol0Looooo]ZoookJP07oookJP03okWo0?oonf[ooe8000;ooo]Z00Ko02[oocoo0?oonf[o0=co
ogSo0?l0oml7oookJP03o`3o6ooonf[oolX000?ooo]Z00?o0?Woool0Tooo01<01OoonfX00ooJo`3o
hOl0oookJP02oookJP03obH0oolPo`3ooo]Z00kooo]Z00?o<Ol0oookJ_l0oe/00ooonfX01_n2o`3o
oo]Zo`3o/Ol0<?oo0>Soo`3oC@;ooo]Z00Co1P3ooookJ_oo0?GoT_l00_oonfX00ol@0?oo01Wooook
JP03oookJP06oaD0oooonf[oo`1Ao`2]oooonf[oo`1i2_oonfX01_l0oe?ooo]ZoookJ_l0oagooo]Z
o`3QobOooo]Z000^oookJP0;ool0nOoonf[o07OooookJ_ooK03ooo]Zo`3oc?oonf[ooh40oookJ_lk
o`000ooonfX00ol0nooooo]ZoookJP02oookJP05onGo0?oonf[ooo]ZoookJ_oo0=d01ol0o``3oook
JP05o`3og_oo08Oooo]ZoookJ_nDo`000_oonfX01_m=0?oooo]ZoookJ_mQ0?oooo]Zo`3oA@Cooo]Z
00GohP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP03onGo0?oonf[ooo]Z00?ooo]Z00?o603oodCo0?oo
nfX00_oonfX00oooT03ooo]ZoookJP08oookJP05oonn0?oonf[o0?l5on/0oom`0?l00_oonfX01OnD
o`3ooo]ZoookJ_oonf[oU?l000Kooo]Z00?oo`0]oookJ_oonfX01ooonfX00oooP@3ooo]ZoookJP08
oookJP03o`3Doooonf[o00Co00WoolT00_l0odh2o`3o=0CoolT01OoonfX4o`3Qo`Go0?lM1OoUo`04
oookJPSo0?mC00?o0?l8o`3o7Ol0oad00ol0oad00ol0hOoooo]ZoookJP07oookJP;o0?ld0_l0odh0
1ol0obkooo]ZoookJ_l0R?oo0:WooookJ_l01?l00_l0e?l2oookJP;o00000_ooP@02oookJPSoiOl0
00Kooo]ZoomG0?oonf[oL03oo`3o1Oo[0?l2oonn00?ooo]Z1OnDo`001OlH0?oooo]ZoookJ_oonf[o
olT000?ooo]Z00[o0?nBon80oooonf[ooo]Zof40oooo;P3oC@3ooookJ_oo06coo`270ooUo`002Onc
o`3oiOl0ool0gOoUo`3ooo]Zool30?oonf[o0?_ooookJP02ooo9000<oon10?l0oi[o07Ooool0nOoo
nf[oZ03oo`2Voooo0?Kojol0oookJ_oo1P3o603o0_oonfX01Ooo0?cooo]ZoookJ_oonf[ooi8000Co
oo]Z00?oiOl0oookJ_oonfX03?oonfX00ol0Looooo]ZoookJP07oookJP04onGo0?l0o`co0?lco`0Z
o`;ooo]Z00Go?ol0o`3Loomho`3oiOl0o`3og`05oookJP05onGo0?l0oa_oiOl0onGo0?oobP000ooo
nfX00ol0nOooo`2Cool04`04oookJP03onGo0?oonf[ohOl000;ooo]Z00?o9P3oob3o0?oonfX03_oo
nfX00ooUo`3ooo]Zo`3oF`04oookJP07oh;o0?l0<?oo0?naoookJ_l0odgooo]Zo`H0o`03oookJP04
oi;o0?oUo`3oiOl0oa00o`?oiOl00_oonfX01_oUo`3oU?l0oookJ_oonf[o0:goodCo00Wooo]Z00Oo
0?mCoookJ_oonf[ooo]Zo`3o7Ooonf[o0>7o05;ooo]Z00Goo`3ioookJ_l0Mooooo]Zoom/0002oook
JP04o`3oc?ooP@3ooo]Zoc_o00Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30003oookJP05ogT0oooo
0=gooo]Zo`2Soonco`001_oonfX01OoMo`3oo`27oookJ_oonf[oo`1/00;ooo]Z00KoC@3oool^0?oo
nf[ooo]Zof40ool0odD4oookJP05on80ool0oi3ooo]ZoookJ_l0oi801_oonfX00omX0?oooo]Zoook
JP04oookJP05oaP0oooonf[ooo]ZoookJ_ooT0002_oonfX01Ooo_P3ooo]ZoookJ_l0o`Goj`3o00Ko
oo]Z00?ooeL0oookJ_oonfX01?oonfX00ooo02gooo]ZoookJP08oookJP03oon10?oonf[ooo]Z00Oo
oo]Z00Go0=CooookJ_l01?oo00CooookJP02o`2Yo`03o`28oooonf[ooo]Z00;ooo]Z0_l0odh2o`3o
=0[ooo]Z0ol0hOl5o`3o7@?o0?l81_oonfX9o`3oD`Go0?lM00?o0>7ooookJ_oonfX01ooonfX2o`3o
=0;o0?m>0_l0obh00ooonf[o08Soo`2Yo`02oookJP;o0=Co0_oonfX3o`000003oon10?oonf[ooo]Z
00?ooo]Z0_oo02d4oookJP05oomG0?oonf[ooo]Zog00ooo[0?l00_oo_P05oookJP05oon@0?oonf[o
oo]ZonKo0?lH0?l00_oonfX01_mX0?oooo]ZoookJ_oonf[o0?nBon80o`;ooo]Z017o0?m5of40oom=
0?oooo]Zool0K?oonf[oo`27omgo0?oonf[o/ol0oil0oooo0=goN@3ooookJ_oo0`3ooo]Zo`3ko`02
oookJP0>oc_o0?ooP@3o0?nJo`1goooo0?Wooo]ZojP0ool0Y_oooo]Zool0m_o[o`3oo`H0oookJ_lH
0?l2oookJP05ool0o?oonf[ooo]ZoookJ_ooTP000ooonfX00ooo0>[ooo]ZoookJP0<oookJP03o`1c
oooonf[ooo]Z00Oooo]Z00_o^Ol0oomB0?l0oc?ooo]Zo`0Zoooonf[o?ol0oookJ_l0g?ooN?l0o`3o
g`06oookJP04o`3o6olB0?oooo]Zooo:00?ooo]Z00?o0?Woool0Tooo01<01OoonfX01_oJo`3ohOl0
oookJ_oonf[o9P3oob3o00oooo]Z00Co<Ol0oookJ_oonf[o0?mK0ooonfX02?n2o`3ooo]Zo`0`oooo
nf[o0>Soo`3oCOoonf[o1P3o0_oonfX01_oo0?GoT_l0oookJ_oonf[o403oo`1Mo`?ooo]Z00Oo5@3o
oookJ_oo057ooo]Zo`2]oooonf[oo`1i00Wooo]Z00Oo0?mCoookJ_oonf[ooo]Zo`3o7Ooonf[o0>7o
02Oooo]Z000ZoookJP0?ojP0oooonf[ooo]ZoookJ_oo0?Wooo]Zo`1goooonf[oof`0o`3oV_l0olco
oo]Zoon10?oonf[o>ol000?ooo]Z00?o0?_ooookJ_oonfX00_oonfX01OoUo`3ooo]ZoookJ_oonf[o
N@3o00So0?l<0_oonfX01Ol0omkoo`27oookJ_oonf[oU?l000;ooo]Z00CoC@3ooookJ_oonf[oH@3o
0_oonfX01_l0odGooo]ZoookJ_oonf[ohP3oo`3oT0;ooo]Z00?o0?nBoookJ_oonfX01?oonfX00omX
0?oooo]ZoookJP03oookJP03oaP0oom4o`3ooo]Z00;ooo]Z00?ooi00oookJ_oonfX02?oonfX01_oo
_P3ooo]ZoookJ_o[0?oooo]Zog00o`Kooo]Z00?oU?l0oookJ_oonfX01?oonfX00ooo02gooo]Zoook
JP07oookJP03oon10?oonf[ooo]Z00Sooo]Z00?o0=CooookJ_l01?l02_oob@001?l0odkoolT0o`3o
=?l0oc@4ooo900Oooo]Z00?oiOl0o`3Qool0hOl00_l0hOl7o`3o7@Co0?l80_l0hOl5o`3o7@03o`3Q
oooonf[ooo]Z00[ooo]Z00Go0?ldo`3oC_l0odko0?m>o`3o;P02oookJP03o`28ool0ZOoo0:Wo00;o
00Co00?o0=CooookJ_oonfX00_oonfX01?l0003ooh40o`000?l00002oookJPSoiOl000?ooeL0oook
J_m`0?l00_o[0?l00ooo_P3ooo]ZoookJP02oookJPGoU?l000Go603ooiCo0?nDo`3ooo]Zooo90003
oookJP0;o`3oT_oR0?oo0?n@oookJ_mQ0?oooo]Zodd0oooonf[oo`1/oookJ_oo08L00ooUo`000onc
o`3oo`3MonGo0002onGo000DoookJ_l0nooooo]ZoookJ_oob@3ooh40o`3oV_oonf[o07Ooool0nOnX
0?oo0:KooookJ_oo0?Kojol0ool60?oonf[o603ooookJ_oo0?`3oookJP03oonB0?oonf[ooo]Z00?o
oo]Z00?oiOl0oookJ_oonfX02ooonfX00ol0Looooo]ZoookJP07oookJP05onGo0?oonf[o0?l<oook
J_l0:_l00_oonfX01Oloo`3o0=coogSo0?oonf[o0?oO00Gooo]Z00Co0?lKonGo0?oUo`3oolX00ooo
nfX01?l0nOooo`2CoookJ_oo01<3oookJP03onGo0?oonf[ohOl000?ooo]Z00?o9P3ooookJ_oonfX0
3_oonfX00ooUo`3ooo]Zo`3oF`03oookJP05o`3o/?n2o`3o033oo`3o/Ol0odd00_oonfX02Ol60?oo
oo]ZoookJ_nBo`3oo`3eonGo0?l@0?ooiOl0ool0JP02onGo00;ooo]Z00KoiOl0oiCo0?oonf[ooo]Z
o`2]oom4o`09oookJP07o`3oDooonf[ooo]Zo`3o2?l0oagooo]Zo`3Qo`1>oookJP0?ojP0oooonf[o
oo]ZoookJ_oo0?Wooo]Zo`1goooonf[oof`0o`3oV_oonf[o0?o<oookJ_ooP@3o>ol000Cooo]Z00Go
0?_ooookJ_oonf[ooo]Zool30003oookJP05ogT0oooo0=gooo]Zo`2Soonco`001_oonfX00ooMo`3o
0?oNool0Q`02oookJP04ool0K?oonf[oC@3oool^00;ooo]Z00?oH@3ooookJ_l0odD01?oonfX01?oR
0?oooo]ZoookJ_l0oi86oookJP03ofP0oooonf[ooo]Z00Cooo]Z00Go603oo`1doooonf[ooo]Zoon@
000:oookJP06oonn0?oonf[ooo]Zo`3o1Oo[0?ooL03o1_oonfX00oooE`3ooo]ZoookJP04oookJP03
ool0;Ooonf[ooo]Z00Sooo]Z00?ooh40oookJ_oonfX01ooonfX01?l0e?oooo]ZoookJ_l01?l2oook
JP03o`2Yool0R?oooo]Z00Cooo]Z00Co0?m>o`3o;_l0ocCo0?ld3OoonfX3o`3Qo`Oo0?lM1?l0o`P2
o`3Qo`Go0?lM00?o0>7ooookJ_oonfX02_oonfX01?l0ocCo0?m>o`3oC_l0odh2o`3o;P07oookJ_l0
R?oo0:Woo`2Yoooonf[o00Coo`3Do`04oookJP;o000000?ooh40o`000?oonfX00ooonfX00ooo02go
oo]ZoookJP03oookJP03oomG0?oonf[ooo]Z00;oj`3o00?ookh0oookJ_oonfX01?oonfX01OooT03o
oo]ZoookJ_oVo`3o603o00;ooo]Z013oJ03ooookJ_oonf[ooo]Zo`3oT_oonf[ohP3ooookJ_l0odGo
H@3oodd0oooonf[oo`1/oookJ_l0omkoo`270_oonfX01onco`3o0:?oool0gOoonf[oo`<0oookJ_l0
nol00_oonfX02?lko`3ooh40oom/0?oonf[o07Ooool0nOoonf[oZ03o0_oonfX01ooo0?Koo`H0oook
J_oonf[o603ooookJ_oo0?`00ooonfX00oooTP3ooo]ZoookJP02oookJP03ool0j_oonf[ooo]Z00_o
oo]Z00?o07?ooookJ_oonfX01ooonfX00onio`3ooo]ZoomB0002oookJP07o`0Zoooonf[o?ol0o`3L
oooonf[oN?l0o`3og`06oookJP03o`3o6ooonf[oolX000?ooo]Z00Co0?Woool0Tooonf[oo`0C1?oo
nfX00ooJo`3ohOl0oookJP02oookJP03obH0oolPo`3ooo]Z00kooo]Z00?o<Ol0oookJ_l0oe/00ooo
nfX01_l0ok3oP_l0oookJ_l0<?oo0>Soo`3oC@;ooo]Z00Co1P3ooookJ_oonf[oT_l00_oonfX00ol@
0?oo01WooookJP03oookJP07oaD0oooonf[oo`1AoookJ_l0[Ooooo]Zool0N@09oookJP07o`3oDooo
nf[ooo]Zo`3o2?l0oagooo]Zo`3Qo`0WoookJP00:_oonfX03onX0?oooo]ZoookJ_oonf[oo`3ioook
J_l0Mooooo]Zoom/0?l0oi[o0?o<oookJ_ooP@3ooo]Zoc_o0004oookJP05o`3koooonf[ooo]Zoook
J_oUo`000ooonfX00omi0?oo0?l<o`3o3003o`3o30Gooo]Z00?o0?oNool0QooonfX00_oonfX01_nD
o`3ooo]Zodd0oooo;P3ooo]Zof40o`;ooo]Z00Ko0?m5oookJ_oonf[ooo]Zon80ool0oi03oookJP03
o`3oT_oonf[ooo]Z00Cooo]Z00?oJ03ooookJ_oonfX00ooonfX00olH0?oo07CooookJP02oookJP03
oon@0?oonf[ooo]Z00Sooo]Z00Gookh0oookJ_l0o`Goj`3oog00o`06oookJP03oiCo0?oonf[ooo]Z
00Cooo]Z00?oo`0]oookJ_oonfX02?oonfX00oooP@3ooo]ZoookJP08oookJP04o`3Doooonf[o00Co
o`04o`WoolT00_l0odh00ooob@3o0?ldooo90002ooo900Wooo]Z1ooUo`03o`3Qo`Ko0?lM3ooonfX0
1Ol0ocCo0?m>o`3oC_l0odko0?l^00?ooo]Z00?o08Soo`2Yool0ZOl00_l01?l00ooonf[o0=Cooook
JP04oookJP05oon10?l0003o0000o`000?oonfX01ooUo`02oomG0005oookJ_m`0?ooj`3ooookJ_oo
_P001OoonfX4oiCo0005oaP0oonDo`3oU?l0oiCo0?oob@000ooonfX02ol0oi;ooo]Zon80oooonf[o
0?m5of40oom=0?oooo]Zool0K?oonf[oo`2700?oiOl000?o/ol0onGo0?oo0=d00_oUo`000ooo0`3o
0?_ooookJP02oookJP0=oc_o0?ooK03ooo]Zo`1goooo0?WoZ03oo`2Voooonf[oo`3fon_o0?oonf[o
o`H0oaP0o`02oookJP05ool0o?oonf[ooo]ZoonB0?oo5P001?oonfX00ooUo`3ooo]ZoookJP0;oook
JP03o`1coooonf[ooo]Z00Sooo]Z00CoiOl0o`3o3?l0oc?o02[o0_oonfX01Oloo`3o0=cooookJ_mh
o`3o0?oO00Kooo]Z00Co0?lKonGo0?oonf[oolX00ooonfX01?l0nOooo`2Cool04ooonfX4onGo0006
oookJ_oQo`3ooo]ZoookJ_lV0?oo8?l03ooonfX01?oUo`3ooo]ZoookJ_l0oe/3oookJP05oh;o0?oo
nf[o033oo`3o/Ol0odd00_oonfX01ol60?oooo]ZoookJ_nBo`3ooo]ZonGo0?l@0?l00ooUo`02oook
JP07onGo0?oonf[oU?l0oookJ_l0[Ooooo]ZodCo0009oookJP06o`3oDooonf[ooo]Zo`3o2?l0oago
0>7oCooonfX00onX0?oooo]ZoookJP02oookJP0:ool0nOl0Mooooo]Zoom/0?l0oi[ooo]Zo`3oc?oo
nf[ooh40oc_o00Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30003oookJP06ogT0oooo0=gooo]Zo`0G
ool0Xooo/ol01OoonfX00ooMo`3o0?oNool0Q`02oookJP09ool0K?oonf[oC@3ooookJ_oo;P3ooo]Z
of40oooonf[o0?m500Cooo]Z00GohP3ooookJ_oonf[ooo]Zo`3oTP06oookJP03ofP0oooonf[ooo]Z
00?ooo]Z00?oi_l0oaP0oooonfX00_oonfX00oooT03ooo]ZoookJP08oookJP05oonn0?oonf[ooo]Z
o`3o1Oo[0?l01_oonfX00oooE`3ooo]ZoookJP04oookJP03ool0;Ooonf[ooo]Z00Wooo]Z00?ooh40
oookJ_oonfX01ooonfX01?l0e?oooo]ZoookJ_l01?l2oookJP;o0:Wo1OoonfX2o`3oCP03o`3o;_l0
ocCo0?ld01;ooo]Z0ol0hOl6o`3o7@oooo]Z00Co0?ldo`3oC_l0odko0?m>0_l0obh2oookJP04o`28
ool0ZOoo0:WooookJP;o00Co00?o0=CooookJ_oonfX00ooonfX01?l0003ooh40o`000?l00003oook
JP03ool0;Ooonf[ooo]Z00;ooo]Z0_ooE`02oookJP03on/0oooonf[ookh000Kooo]Z00Gooi00oook
J_oonf[oi_l0oaP0o`02oookJP0=ofP0oooonf[ooo]ZoookJ_l0oi;ooo]Zon80oooonf[o0?m5oook
J_mQ0?ooC@3oool0K002oookJP06ool0Qooonf[ooo]Zok?o0?l0Xoooo`3M0_oonfX00ooo0`3ooo]Z
o`3ko`02oookJP0>oc_o0?ooK03ooo]Zo`1goooo0?Wooo]ZojP0ool0Y_oooo]Zool0m_o[o`3oo`H0
oookJ_lH0?l2oookJP05ool0o?oonf[ooo]ZoonB0?oo5P000ooonfX00ooo0>[ooo]ZoookJP0<oook
JP03o`1coooonf[ooo]Z00Oooo]Z00_o^Ol0oomB0?l0oc?ooo]Zo`0Zoooonf[o?ol0oookJ_l0g?oo
N?l0o`3og`07oookJP03o`3o6ooonf[oolX000?ooo]Z00?o0?Woool0Tooo01<01OoonfX01ooJo`3o
hOl0oookJ_oonf[o9P3ooh@0oolPo`003ooonfX00olao`3ooo]Zo`3oF`03oookJP06oh;o0?oonf[o
oo]Zo`0`ool0j?oo0?m=0_oonfX01?l60?oooo]Zool0mOnBo`02oookJP03oa00ool06Ooooo]Z00?o
oo]Z00Ko5@3oool0DOoonf[ooo]Zo`2]oooo07T:oookJP06o`3oDooonf[ooo]Zo`3o7Ooonf[o0>7o
:?oonfX002[ooo]Z00OoZ03ooookJ_oonf[ooo]Zool0nOoonf[o07Oo00;ooo]Z00Koof`0oookJ_l0
olcooh40oookJ_lko`04oookJP05o`3koooonf[ooo]ZoookJ_oUo`001?oonfX2o`3o3003onGo0?l0
o`cooo]Z00Kooo]Z00So0?oNool0Qooonf[ooo]ZoiCo0?oonf[oC@3oool^00;ooo]Z00?oH@3ooook
J_l0odD01?oonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Kooo]Z00?oJ03ooookJ_oonfX00ooonfX0
0olH0?ooA?l0oookJP02oookJP03oon@0?oonf[ooo]Z00Wooo]Z00Gookh0o`3o1Ooonf[oj`3oog00
o`06oookJP03oiCo0?oonf[ooo]Z00Cooo]Z00?oo`0]oookJ_oonfX02?oonfX00oooP@3ooo]Zoook
JP08oookJP04o`3Doooonf[ooo]Zo`04o`[oolT00_l0odh2o`3o=0cooo]Z1OoUo`0FoookJP?o0?m>
00Co0?l^oookJ_oonf[ooo]Z0ol0R?l01?l0ZOoo00Coo`04oooonfX2o`3Do`Gooo]Z00?ooh40o`00
0?l000000_l00007onGo0007oomG0?oonf[ooo]Zog00ooo[0?oooo]Zoonn0005oookJPCoU?l000Go
603ooiCo0?nDo`3oU?l0ooo90003oookJP07o`3oT_oonf[ohP3ooookJ_l0odGoH@3oodd0o`02oook
JP03ool0K?oo08Oo0?oN00?oiOl000Oo/ol0ool0gOoUo`3oiOl0ool30?oonf[o0?_o00;ooo]Z00go
>ol0oon10?l0oi[ooo]Zo`1goooo0?WoZ03oo`2Voooonf[oo`3fon_o0?oo1P3o603o00;ooo]Z00Go
o`3loookJ_oonf[ooo]ZoonB0005oookJP03onGo0?oonf[ooo]Z00_ooo]Z00?o07?ooookJ_oonfX0
1ooonfX01OoUo`3ooo]Zo`3o3?oonf[o02[o00;ooo]Z00Go?ol0o`3Loomho`3oiOl0o`3og`05oook
JP05o`3o6olB0?ooiOl0oookJ_oobP000_oonfX01Ol0nOooo`2CoookJ_oo01?ooo]Z00KoiOl00_oo
nfX00olV0?oooo]ZoookJP0>oookJP03onGo0?oonf[o0?mK00?ooo]Z00So0?n`oh;o0?oonf[o033o
oookJ_l0odgooo]Zo`H0o`?ooo]Z00CoT_l0oookJ_oUo`3o403o0ooUo`02oookJP07onGo0?nDo`3o
oo]ZoookJ_l0[Ooooo]ZodCo0008oookJP07o`3oDooonf[ooo]ZoookJ_l0o`So0?lMo`3Qo`1?oook
JP03ojP0oooonf[ooo]Z00;ooo]Z00Goo`3io`1goooonf[ooo]Zoom/0002oookJP03o`3oc?ooP@3o
>ol000Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30004oookJP05ogT0oooo0=gooo]Zo`2Soonco`00
1_oonfX02OoMo`3oo`27oookJ_oonf[oo`1/oookJ_m=0?oooo]Zool^0002oookJP03of40ool0odGo
oo]Z00?ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP03ofP0oooonf[ooo]Z00Cooo]Z00Go
603oo`1doooonf[ooo]Zoon@000;oookJP05oonn0?oonf[o0?l5oookJ_o[0?l01_oonfX00oooE`3o
oo]ZoookJP04oookJP03ool0;Ooonf[ooo]Z00Wooo]Z00?ooh40oookJ_oonfX01ooonfX01?l0e?oo
oo]ZoookJ_l01?l3oookJP03o`2Yool0R?oooo]Z00Cooo]Z0_l0odh00ol0obko0?ldo`3o=00Voook
JP03o`3o=?l0odko0?m>00;o0?l^0ooonfX2o`28o`04o`2Yoooonf[o00Coo`04o`;o0=Co1OoonfX2
oon100?o00000_oonfX00ooo02gooo]ZoookJP02oookJP07oomG0?oonf[ooo]ZoookJ_o[0?oooo]Z
oonn0006oookJP05oon@0?oonf[ooo]ZonKo0?lH0?l00_oonfX04?mX0?oooo]ZoookJ_oonf[o0?nB
oookJ_oR0?oooo]Zo`3oAOoonf[oH@3oodd0oooonf[oo`1/oookJ_oo08L2oookJP03oil0oonco`3o
o`3M00;ooo]Z00?oo`<0oookJ_l0nol00_oonfX02?lko`3ooh40oom/0?oonf[o07Ooool0nOoonf[o
Z03o0_oonfX01?oo0?Koo`H0oookJ_lH0?l2oookJP05ool0o?oonf[ooo]ZoookJ_ooTP001?oonfX0
0ooo0>[ooo]ZoookJP0;oookJP03o`1coooonf[ooo]Z00Oooo]Z00?o^Ol0oookJ_ooDP000_oonfX0
1ol0:_oooo]Zocoo0?oonf[o0=coogSo0?l0oml01_oonfX01?l0oa_ooo]ZoookJ_oobP02oookJP04
o`3ioooo09?ooo]Zool04`Gooo]Z00Kof_l0oookJ_oonf[ooo]ZobH0oolPo`0?oookJP04oc7o0?oo
nf[ooo]Zo`3oF`;ooo]Z00Ko0?n`oh;o0?oonf[o0?nao`0`ool0odd2oookJP05o`H0oooonf[ooo]Z
ool0mOnBo`000_oonfX00ol@0?oo05gooookJP02oookJP07oaD0oooonf[oo`1AoookJ_l0[Ooooo]Z
ool0N@09oookJP07o`3oDooonf[ooo]ZoookJ_l0oagooo]Zo`3Qo`0XoookJP00:_oonfX00onX0?oo
oo]ZoookJP02oookJP0:ool0nOoonf[o07OooookJ_ooK03ooo]Zo`3oc?oonf[ooh40oc_o00Cooo]Z
00?o0?_ooookJ_oonfX00_oonfX01OoUo`3ooo]ZoookJ_oonf[oo`3M00;ooo]Z00?o0?l<oookJ_oo
nfX01OoonfX01Ol0omkoo`27oookJ_oonf[oU?l000;ooo]Z00CoC@3oool^0?oonf[oH@3o0_oonfX0
1_l0odGooo]ZoookJ_oonf[ohP3oo`3oT0;ooo]Z00?o0?nBoookJ_oonfX01OoonfX00omX0?oooo]Z
oookJP03oookJP03oaP0ool0M?oooo]Z00;ooo]Z00?ooi00oookJ_oonfX02OoonfX01Ooo_P3oiOl0
on/0oooonf[oL03o00Gooo]Z00?oU?l0oookJ_oonfX01OoonfX00ooo02gooo]ZoookJP08oookJP03
oon10?oonf[ooo]Z00Sooo]Z00Co0=CooookJ_oonf[o00Co2ooob@001?l0odkoolT0o`3o=?l0oc@5
oookJPSoU?l000?oiOl0oookJ_oonfX04OoonfX01?l0ocCo0?m>o`3oC_l0odh2o`3o;P?ooo]Z0_l0
R?l01Ooonf[o0:Woo`04ool01?oooo]Z00;o0=Co1OoonfX2oon10003oookJ_l0003o000000;o0000
1OoUo`002?oonf[ooeL0oookJ_oonf[oL03oon/0oooonf[ookh01_oonfX3oiCo0005oaP0oonDo`3o
U?l0oiCo0?oob@000ooonfX00ol0oi;ooo]Zon80o`02oookJP08of40oooo;P3oC@3ooookJ_oo06co
oo]Zool0QooonfX2onGo0007ok?o0?oo0=goiOl0onGo0?oo0`3ooo]Zo`3ko`02oookJP0@oc_o0?oo
P@3oof`0oookJ_l0Moooo`3iojP0ool0Y_oooo]Zo`3oGOo[o`3ooo]Zool60?lH0?oooo]Zool0o0?o
oo]Z00?ooi80oookJ_oonfX00ooonfX00ooUo`3ooo]ZoookJP0;oookJP03o`1coooonf[ooo]Z00So
oo]Z00CoiOl0o`3o3?l0oc?o02[o0_oonfX01_loo`3o0=cooookJ_mho`3ooo]Zo`3og`Gooo]Z00Co
0?lKonGo0?oonf[oolX00ooonfX01Ol0nOooo`2CoookJ_oo01?ooo]Z00SoiOl000?o9P3ooookJ_oo
nfX03OoonfX01?oUo`3ooo]ZoookJ_l0oe/3oookJP05oh;o0?oonf[o033oonGo0?l0odd00_oonfX0
1?l60?oooo]ZoookJ_nBo`02oookJP04onGo0?l@0?ooo`1ZonGo00?ooo]Z00KoiOl0oiCo0?oonf[o
oo]Zo`2]oom4o`09oookJP07o`3oDooonf[ooo]Zo`3o2?l0oagooo]Zo`3Qo`1?oookJP03ojP0oooo
nf[ooo]Z00;ooo]Z00Goo`3ioookJ_l0Mooooo]Zoom/0002oookJP03o`3oc?ooP@3o>ol000Gooo]Z
00Go0?_ooookJ_oonf[ooo]Zool30003oookJP05ogT0oooo0=gooo]Zo`2Soonco`001_oonfX01OoM
o`3o0?oNool0Qooonf[oo`1/00;ooo]Z00OoC@3ooookJ_oo;P3ooo]Zof40oooonf[o0?m500Cooo]Z
00CohP3ooookJ_oonf[o0?nB1ooonfX00omX0?oooo]ZoookJP03oookJP03onKo0?lH0?oooo]Z00;o
oo]Z00?ooi00oookJ_oonfX02OoonfX01Ooo_P3ooo]Zo`3o1Oo[0?ooL03o00Gooo]Z00?ooeL0oook
J_oonfX01OoonfX00ooo02gooo]ZoookJP09oookJP03oon10?oonf[ooo]Z00Oooo]Z00Co0=Cooook
J_oonf[o00Co0ooonfX2o`2Yo`03o`28oooonf[ooo]Z00?ooo]Z00?o0?m>o`3o;_l0obh00_l0oc@P
oookJP;o0?ld0ol0odh00ol0obkooo]ZoookJP02oookJP;o08So0_l0ZOl2o`04o`;o0=Co1_oonfX0
0oooP@3ooo]Zo`000003o`000003oookJ_oo02gooo]Z00?ooo]Z00OooeL0oookJ_oonf[ooo]Zon/0
oooonf[ookh000Kooo]Z00Gooi00oookJ_oonf[oi_l0oaP0o`02oookJP07ofP0oooonf[ooo]Zoook
J_l0oi;ooo]Zon80o`02oookJP08o`3oAOmQ0?ooC@3ooookJ_oo06cooo]Zo`3og_oo08L2oookJP05
ok?o0?l0Xoooo`3MoookJ_oo0`000_oonfX04ol0nooooo]Zoc_o0?ooP@3oof`0oookJ_l0Moooo`3i
oookJ_nX0?oo0:KooookJ_oo0?Kojol0ool60?oonf[o603ooookJ_oo0?`00ooonfX00oooTP3ooo]Z
oookJP02oookJP03ool0j_oonf[ooo]Z00cooo]Z00?o07?ooookJ_oonfX01ooonfX03?nio`3ooe80
o`3o<ooonf[o02[ooookJ_loo`3ooo]Zo`3Loooonf[oN?l0o`3og`Kooo]Z00?o0?lKoookJ_oobP00
0ooonfX01?l0nOooo`2CoookJ_oo01<4oookJP03om[o0?oQo`3ooo]Z00;ooo]Z00?o9P3oob3o0?oo
nfX03_oonfX00olao`3ooo]Zo`3oF`03oookJP06oh;o0?oonf[ooo]Zo`0`ool0j?oo0?m=0_oonfX0
1?l60?oooo]Zool0mOnBo`03oookJP03oa00ool0GOoooo]Z00;ooo]Z00Oo5@3ooookJ_oo057ooo]Z
o`2]oooonf[oo`1i00Wooo]Z00Oo0?mCoookJ_oonf[o0?l8o`3o7Ooonf[o0>7o02Sooo]Z000Zoook
JP03ojP0oooonf[ooo]Z00;ooo]Z00_oo`3ioookJ_l0Mooooo]Zoom/0?l0oi[o0?o<oookJ_ooP@3o
oo]Zoc_o0004oookJP05o`3koooonf[ooo]ZoookJ_oUo`000ooonfX01Omi0?ooo`3MoookJ_l0Xooo
0?l<00Kooo]Z00?o0?oNool0QooonfX00_oonfX01_nDo`3ooo]Zodd0oooo;P3ooo]Zof40o`;ooo]Z
00Ko0?m5oookJ_oonf[ooo]Zon80ool0oi03oookJP03o`3oT_oonf[ooo]Z00Gooo]Z00?oJ03ooook
J_oonfX00_oonfX00olH0?oo07CooookJP03oookJP03oon@0?oonf[ooo]Z00Sooo]Z00Gookh0onGo
0?oUo`3oj`3oog00o`06oookJP03oiCo0?oonf[ooo]Z00Gooo]Z00?oo`0]oookJ_oonfX02?oonfX2
oon100Wooo]Z1?m4o`0;ooo9013oU?l000?oiOl0oookJ_oonfX02ooonfX4o`3o=0?o0?m>0_l0obh4
oookJP;o08So0ol0ZOl01?l01?oo0=Coo`3Dool0e?l6oookJP04oon10?oonf[ooo]ZoookJP?o0000
1?oUo`000ooonf[ooeL0oomG0002oookJP04og00ooo[0?oooo]Zoonn00Kooo]Z0onDo`001OlH0?oo
U?l0oiCo0?oonf[oolT000?ooo]Z00?o0?nBoookJ_oR0?l00_oonfX02?l0odGoH@3oodd0oooonf[o
o`1/oookJ_oo08Oooo]Z0_oUo`001onco`3oiOl0ool0gOoUo`3oo`<0oookJ_l0nol00_oonfX00olk
o`3ooh40oom/0002oookJP09o`1goooonf[oZ03oo`2Voooonf[ojol0oookJ_oo1P3o603o00;ooo]Z
00Goo`3loookJ_oonf[ooo]ZoonB0004oookJP03onGo0?oonf[ooo]Z00cooo]Z00?o07?ooookJ_oo
nfX01ooonfX01OoUo`3ooo]Zo`3o3?oonf[o02[o00;ooo]Z00Go?ol0o`3Loomho`3oiOl0o`3og`06
oookJP04o`3o6ol0S_oooo]Zooo:00?ooo]Z00?oo`2CoookJ_oo01<00_oonfX7onGo0003obH0oooo
nf[ooo]Z00kooo]Z00CoiOl0oookJ_oonf[o0?mK0ooonfX01On2o`3ooo]Zo`0`oooUo`3o0?m=00;o
oo]Z00Co1P3ooookJ_oonf[oT_l00_oonfX01?l@0?ooiOl0onGo0?oUo`02oookJP03onGo0?nDo`3o
oo]Z00;ooo]Z00?o0:goodCo0?oonfX02?oonfX01_l0oe?ooo]ZoookJ_l0o`So0?lMo`3Qoe7ooo]Z
00ooZ03ooookJ_oonf[ooo]Zool0nOoonf[o07OooookJ_ooK03o0?nJoookJ_l0olcooh40oookJ_lk
o`001?oonfX01Ol0nooooo]ZoookJ_oonf[oo`<000?ooo]Z00KoN@3oool0gOoonf[o01Ooo`2Soonc
o`06oookJP0=o`3og_oo08Oooo]ZoookJ_oo06cooo]Zodd0oooonf[oobh0oookJ_mQ0?oooo]Zo`3o
A@04oookJP05on80oooonf[ooo]ZoookJ_l0oi801ooonfX00omX0?oooo]ZoookJP02oookJP03onKo
0?lH0?oo07Co00?ooo]Z00?ooi00oookJ_oonfX02?oonfX01Ooo_P3ooo]Zo`3o1Ooonf[oj`3o00Ko
oo]Z00?ooeL0oookJ_oonfX01OoonfX00ooo02gooo]ZoookJP09oookJP03oon10?oonf[ooo]Z00Oo
oo]Z0_l0e?l00ooonf[o00CooookJP03oookJP04o`2Yool0R?oo08Soo`28o`?ooo]Z1?l0odh2o`3o
=1Sooo]Z1Ol0oc@3o`3oCP03o`3o;_oonf[ooo]Z00?ooo]Z00Ko08Soo`2Yool0ZOoo0:WooookJ_l0
1?l2o`3Do`Oooo]Z00?ooh40oookJ_oonfX01?l000001?oo02gooo]ZoookJ_oonfX2oomG00?ooo]Z
00?oj`3ooookJ_oo_P001_oonfX01OooT03ooo]ZoookJ_l0M?oo603o00;ooo]Z017oJ03ooookJ_oo
nf[ooo]Zo`3oT_oonf[o0?n@on80oooonf[o0?m5oookJ_mQ0?oooo]Zool0K?oonf[o0?oNool0Q`02
oookJP05ok?o0?l05oooo`3MoookJ_oo0`000_oonfX02?l0nooooo]Zoc_o0?ooP@3o0?nJoom/0?oo
nf[o07Oo0_oonfX01onX0?oooo]ZoookJ_o[o`3oo`H0oookJ_lH0?l00_oonfX01Ooo0?cooo]Zoook
J_oonf[ooi8000?ooo]Z00?oo`3ZoookJ_oonfX03?oonfX00ol0Looooo]ZoookJP07oookJP03okWo
0?oonf[ooe8000;ooo]Z00Oo02[ooookJ_loo`3ooo]Zo`3Loomho`3o0?oO00Kooo]Z00Co4P3oo`3o
6ooonf[oolX00ooonfX00ol0nOooo`2Cool04`05oookJP06om[o0?oonf[ooo]ZoookJ_lV0?oo8?l0
4?oonfX00olao`3ooo]Zo`3oF`03oookJP08oh;o0?oonf[ooo]Zo`0`ool0j?oo0?m=oookJ_l60?l2
oookJP06ool0mOnBo`3ooo]ZoookJ_l@0?oo01Wo1?oonfX01olE0?ooo`1AoookJ_oonf[o0:gooook
J_oo07T02?oonfX01ol0oe?ooo]ZoookJ_oonf[o0?l8o`3o7Ol0hOl0:OoonfX002[ooo]Z00?oZ03o
oookJ_oonfX00_oonfX00ooo0?Wooo]Zo`1go`02oookJP06oom/0?oonf[o0?o<oon10?oonf[o>ol0
1?oonfX01Ol0nooooo]ZoookJ_oonf[oiOl000?ooo]Z00GoN@3oool0gOoonf[o0:?oo`3o3007oook
JP05o`3og_oo08Oooo]ZoookJ_nDo`000_oonfX00om=0?ooobh0of40o`02oookJP03o`3oAOoonf[o
oo]Z00;ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP07oookJP03ofP0oooonf[ooo]Z00?ooo]Z00?o
603oo`1doooonfX00_oonfX00oooT03ooo]ZoookJP09oookJP05oonn0?oUo`3oiOl0on/0oom`0?l0
1_oonfX00onDo`3ooo]ZoookJP04oookJP03ool0;Ooonf[ooo]Z00[ooo]Z00?ooh40oookJ_oonfX0
2?oonfX7odCo00GoolT00ooUo`0>oiCo00Wooo]Z1?l0oc@5o`3oCP;o0?l^1OoonfX01_l0R?oo0:Wo
o`2Yool0ZOoooo]Zo`04o`;o0=Co2?oonfX00oooP@3ooo]ZoookJP02oookJP?o00000ooUo`000ooo
nf[ooeL0oookJP02oookJP04og00ooo[0?oooo]Zoonn00Kooo]Z00Cooi00oiCo0?oob@3o603o0_nD
o`000ooonf[oolT0oookJP03oookJP07o`3oT_oR0?oooo]ZoookJ_l0odGoH@3oodd0o`02oookJP04
ool0K?l0omkoo`27oookJP;oiOl000Co/ol0ool0gOoUo`3oo`<00_oonfX04?l0nooooo]ZoookJ_lk
o`3ooo]Zoom/0?oonf[o07Ooool0nOnX0?oo0:KooookJ_l0oegojol0oookJ_oo1P02oookJP05ool0
o?oonf[ooo]ZoookJ_ooTP001OoonfX00ooUo`3ooo]ZoookJP0;oookJP03o`1coooonf[ooo]Z00So
oo]Z00GoiOl0o`3o3?l0oc?ooo]Zo`0Zo`02oookJP05ocoo0?l0g?ooN?l0oookJ_l0oml01OoonfX0
1Ol0oa_o08kooookJ_oonf[oolX000;ooo]Z00Co0?Woool0Tooonf[oo`0C0_oonfX7onGo0003obH0
oooonf[ooo]Z00kooo]Z00CoiOl0oookJ_oonf[o0?mK0_oonfX02?l0ok3oP_l0oookJ_l0<?oo0?m=
onGo0?oonf[o1P3o0ooonfX01?nBo`3ooo]ZoookJ_l@0?l2onGo00?ooo]Z00OoiOl0oiCo0?oonf[o
oo]Zo`2]oooonf[oA?l000Sooo]Z00Oo0?mCoookJ_oonf[ooo]Zo`3o2?l0oago0>7o057ooo]Z00?o
Z03ooookJ_oonfX00_oonfX01Ooo0?Wo07OooookJ_oonf[oof`000;ooo]Z00?o0?o<oon10?lko`00
1?oonfX01Ol0nooooo]ZoookJ_oonf[oo`<000?ooo]Z00KoN@3ooookJ_oo0=go01Ooo`2Soonco`06
oookJP05omgo0?oo08Oooo]ZoookJ_oo06`00_oonfX01_m=0?oooo]Zool^0?mQ0?oooo]Zo`3oA@Co
oo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP07oookJP03ofP0oooonf[ooo]Z00?ooo]Z00?oi_l0oaP0
oooonfX00_oonfX00oooT03ooo]ZoookJP09oookJP05oonn0?oonf[o0?l5oookJ_o[0?l01_oonfX0
0oooE`3ooo]ZoookJP04oookJP03ool0;Ooonf[ooo]Z00[ooo]Z00?ooh40oookJ_oonfX02?oonfX2
o`3Do`;o00Co0ooonfX2o`2Yo`03oookJ_l0R?oo08So00Gooo]Z1_l0odh5o`3o=0[ooo]Z1Ol0oc@5
o`3oCP03o`3o;_oonf[ooo]Z00Cooo]Z0ol0ZOl2oookJP03o`04ool0e?oo0=Co00Sooo]Z00Cooh40
oookJ_oonf[ooo]Z0ol000001Ooo02go0000oookJ_oonf[ooeL000Cooo]Z00?oj`3ooookJ_oo_P00
1_oonfX01OooT03ooo]ZoookJ_l0M?oo603o00;ooo]Z00?oJ03ooookJ_oonfX00_oonfX04Ol0oi;o
0?n@on80oooonf[o0?m5oookJ_mQ0?ooC@3ooookJ_oo06co0?oNomgo0?oo08Oooo]Zoil0oonco`3o
o`3M00;ooo]Z00?oo`<0oookJ_l0nol00_oonfX02?lko`3ooh40oom/0?oonf[o07Ooool0nOoonf[o
Z03o0_oonfX01?oo0?Kojol0ool60?lH0?l2oookJP05ool0o?oonf[ooo]ZoookJ_ooTP001?oonfX0
0ooo0>[ooo]ZoookJP0<oookJP03o`1coooonf[ooo]Z00Oooo]Z00?o^Ol0oomB0?l0oc<00_oonfX0
1ol0:_oooo]Zocoo0?l0g?oooo]ZogSo0?l0oml01_oonfX01?l0oa_ooo]ZoookJ_oobP02oookJP04
o`3ioooo09?ooo]Zool04`Gooo]Z00Kof_l0oookJ_oonf[ooo]ZobH0oolPo`0?oookJP04oc7o0?oo
nf[ooo]Zo`3oF`;ooo]Z00Ko0?n`oh;o0?oonf[o0?nao`0`ool0odd2oookJP05o`H0oooonf[ooo]Z
ool0mOnBo`000_oonfX00ol@0?oo05gooookJP02oookJP03oaD0oooonf[oo`1A00;ooo]Z00?o0:go
ool0NOoonfX02?oonfX01ol0oe?ooo]ZoookJ_oonf[o0?lMoookJ_l0hOl0:OoonfX002_ooo]Z00Oo
Z03ooookJ_oonf[ooo]Zool0nOoonf[o07Oo00;ooo]Z00Koof`0oookJ_l0olcooh40oookJ_lko`04
oookJP05o`3koooonf[ooo]ZoookJ_oo0`000ooonfX01Omi0?ooo`3MoookJ_oUo`3o0?l<00Oooo]Z
00Go0?oNool0Qooonf[ooo]ZoiCo0002oookJP04odd0oooo;P3ooo]Zof40o`;ooo]Z00Ko0?m5oook
J_oonf[ooo]Zon80ool0oi02oookJP03o`3oT_oonf[ooo]Z00Kooo]Z00?oJ03ooookJ_oonfX00_oo
nfX00olH0?ooi_l0oookJP03oookJP03oon@0?oonf[ooo]Z00Wooo]Z00Gookh0onGo0?oUo`3oj`3o
og00o`05oookJP03oiCo0?oonf[ooo]Z00Gooo]Z00?oo`0]oookJ_oonfX02_oonfX00oooP@3ooo]Z
oookJP08oookJP_oA?l01_oUo`0;oiCo00Co0?ld2Ol0odh2o`3o;POooo]Z00Co08Soo`2Yool0ZOoo
0:Wo0_oonfX00ol01?oo0=Coo`3Do`08oookJP;ooh401OoonfX2o`0000;oiOl00_oonfX00oooE`3o
oo]ZoookJP02og00o`03on/0oooonf[ookh000Kooo]Z00Gooi00oiCo0?nDo`3o603oooo90002oook
JP03ooo90?oonf[ooo]Z00;ooo]Z00co0?nBon80oooonf[ooo]Zo`3oAOmQ0?ooobh0odd0oooonf[o
o`1/omgo0?oo08L2oookJP08onGo0?m4o`3oiOl0ool0gOoonf[oo`<0oookJ_l0nol2oookJP0>oc_o
0?ooP@3oof`0oookJ_l0Moooo`3ioookJ_nX0?oooo]Zo`3oGOo[o`3ooo]Zool60?lH0?l2oookJP05
ool0o?oonf[ooo]ZoonB0?oo5P001?oonfX00ooUo`3ooo]ZoookJP0<oookJP03o`1coooonf[ooo]Z
00Oooo]Z00GoiOl0oookJ_l0o`cooo]Zo`0Zo`02oookJP05ocoo0?l0g?oooo]ZogSo0?l0oml01_oo
nfX01?l0oa_o08kooookJ_oobP03oookJP05ool0Tooonf[ooo]Zool04ooonfX01ooUo`000olV0?oo
8?l0oookJP0>oookJP04onGo0?oonf[ooo]Zo`3oF`?ooo]Z00GoP_l0oookJ_oonf[o033oo`3oC@02
oookJP04o`H0oooonf[ooo]Zoi;o00?ooo]Z00?o403oonGo0?oUo`000ooonfX01_oUo`3oU?l0oook
J_oonf[o0:goodCo00Wooo]Z00Oo0?mCoookJ_oonf[o0?l8oookJ_l0oago0>7o057ooo]Z00?oZ03o
oookJ_oonfX00_oonfX01Ooo0?Wo07OooookJ_oonf[oof`000;ooo]Z00?o0?o<oon10?lko`001Ooo
nfX01?l0nooooo]ZoookJ_oo0`03oookJP06ogT0oooonf[oo`3Mo`0Gool0Xooo/ol01_oonfX01OoM
o`3o0?oNool0Qooonf[oo`1/00;ooo]Z00OoC@3ooookJ_oo;P3ooo]Zof40oooonf[o0?m500Cooo]Z
00CohP3ooookJ_oonf[o0?nB2?oonfX00omX0?oooo]ZoookJP03oookJP03oaP0ool0M?oooo]Z00;o
oo]Z00?ooi00oookJ_oonfX02OoonfX01Ooo_P3ooo]Zo`3o1Ooonf[oj`3o00Gooo]Z00?ooeL0oook
J_oonfX01OoonfX00ooo02gooo]ZoookJP0:oookJP03oon10?oonf[ooo]Z00Wooo]Z0_l0e?l3o`04
o`;ooo]Z00?o0:WooookJ_oonfX00_l0R?l9oookJPGo0?m>1_l0oc@9o`3oCP03o`3o;_oonf[ooo]Z
00Kooo]Z0ol0ZOl3oookJP?o0=Co2?oonfX2oon100Cooo]Z0_l000001Ooo02go0000oookJ_oonf[o
oeL000?ooo]Z00CoL03oon/0oooonf[ookh01_oonfX01OooT03ooo]ZoookJ_l0M?oo603o00;ooo]Z
00?oJ03ooookJ_oonfX00_oonfX03Ol0oi;o0?n@on80oooonf[o0?m5oookJ_mQ0?ooC@3ooookJ_oo
06cooo]Zo`3og_oo08L00_oonfX01Onco`3o0:?oool0gOoonf[oo`<000;ooo]Z017o0?_ooookJ_lk
o`3ooh40oom/0?oonf[o07Ooool0nOoonf[oZ03oo`2Voooonf[oo`3fon_o0?oo1P3ooo]ZoaP0o`02
oookJP05ool0o?oonf[ooo]ZoonB0?oo5P000ooonfX00ooo0>[ooo]ZoookJP0<oookJP03o`1coooo
nf[ooo]Z00Oooo]Z00?o^Ol0oookJ_ooDP000_oonfX01ol0:_oooo]Zocoo0?oonf[o0=coogSo0?l0
oml01ooonfX00ol0oa_ooo]Zooo:0003oookJP04o`3ioooo09?ooo]Zool04`Cooo]Z00Kof_l0on7o
0?oonf[ooo]ZobH0oolPo`0@oookJP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00KoP_l0oookJ_oonf[o
0?nao`3Xool0odd2oookJP04o`H0oooonf[oo`3eoi;o00;ooo]Z00?oo`1Zoa00ool0GOl00ooonfX0
1olE0?oooo]Zool0DOoonf[o0:gooookJ_oo07T02OoonfX01ol0oe?ooo]ZoookJ_l0o`So0?lMoook
J_l0hOl0:OoonfX002_ooo]Z00OoZ03ooookJ_oonf[ooo]Zool0nOoonf[o07Oo00;ooo]Z00Koof`0
o`3oV_l0olcooh40oookJ_lko`04oookJP03o`3koooonf[ooo]Z00;ooo]Z00Woo`<0oookJ_oonf[o
oo]ZogT0oooo0=goiOl0o`2Sool0o``01ooonfX01?oo08Oooo]ZoookJ_nDo`03oookJP03odd0oooo
;P3oH@3o00;ooo]Z00Ko0?m5oookJ_oonf[ooo]Zon80ool0oi03oookJP03o`3oT_oonf[ooo]Z00Go
oo]Z00?oJ03ooookJ_oonfX00ooonfX00olH0?oo07CooookJP02oookJP03oon@0?oonf[ooo]Z00[o
oo]Z00Kookh0onGo0?o[0?ooiOl0og00oooUo`04oookJP03oiCo0?ooE`3ooo]Z00Gooo]Z00?oo`0]
oookJ_oonfX02_oonfX00oooP@3ooo]ZoookJP08oookJPcoA?l00ooUo`03oookJP[oU?l00ol0odh2
o`3o;Pcooo]Z0_l0R?l3o`2Yo`?ooo]Z00?o00Coo`3Dool0e?l02?oonfX2oon100Oooo]Z00Coo`0]
onGo0?l0003o00000_ooE`02oookJP03og00oooonf[oj`3o00;ookh01_oonfX01?ooT03ooo]ZoiCo
0?lH0?l4ooo900Cooo]Z00co0?nBoookJ_oR0?oooo]Zo`3oAOoonf[oH@3oodd0oooonf[oo`1/oook
J_oo08L2oookJP;oiOl000CoA?l0ool0gOoonf[oo`<00_oonfX03Ol0nooooo]Zoc_o0?ooP@3ooo]Z
oom/0?oonf[o07OooookJ_nX0?oo0:KooookJ_o[o`000_oonfX01?oo1P3ooo]ZoookJ_oo0?`3oook
JP03oonB0?oUo`3oiOl000?ooo]Z00?oiOl0oookJ_oonfX02ooonfX00ol0Looooo]ZoookJP08oook
JP05onGo0?l0o`co0?lcoookJ_l0:_l00_oonfX01Oloo`3o0=coogSo0?oonf[o0?oO00Kooo]Z00Co
0?lKoookJ_oonf[oolX00ooonfX00ooo09?ooo]Zool04`02oookJPOoiOl000?o9P3ooookJ_oonfX0
3_oonfX01?oUo`3ooo]ZoookJ_l0oe/3oookJP05oh;o0?oonf[o033ooookJ_l0odd00_oonfX01?l6
0?oooo]ZoookJ_nBo`03oookJP03oa00oooUo`3ooo]Z00;ooo]Z00?oiOl0oiCo0?oonfX00_oonfX0
0ol0[OooA?l0oookJP07oookJP08o`3oDooonf[ooo]ZoookJ_l0o`So0?lMoookJ_l0hOmAoookJP03
ojP0oooonf[ooo]Z00;ooo]Z00?oo`3io`1goooonfX00_oonfX01OooK03ooo]Zo`3oc?ooP@3o>ol0
00Gooo]Z00Go0?_ooookJ_oonf[ooo]Zool30003oookJP06ogT0oooo0=gooo]Zo`2SoonO0?oo/ol0
1_oonfX01?oMo`3oo`27oookJ_oo06`3oookJP06odd0oooonf[oobh0of40oooonf[o0?m51?oonfX0
1OoR0?oooo]ZoookJ_oonf[o0?nB00Oooo]Z00?oJ03ooookJ_oonfX00ooonfX00ooVo`3o603ooook
JP02oookJP03oon@0?oonf[ooo]Z00[ooo]Z00Gookh0oookJ_l0o`Goj`3oog00o`05oookJP;ooeL0
1_oonfX00ooo02gooo]ZoookJP0:oookJP03oon10?oonf[ooo]Z00[ooo]Z0_l0e?l01?oonf[o00Co
o`04oooonfX3o`2Yo`04oookJ_l0R?oo08Soo`28o`_ooo]Z1_l0odh00ol0obkooo]ZoookJP0:oook
JP;o08So0ol0ZOl4oookJP;o0=Co2OoonfX2oon100Kooo]Z0_oo02d2o`000003oookJ_ooE`3ooo]Z
00;ooo]Z00CoL03oon/0oooonf[ookh01_oonfX01OooT03ooo]ZoookJ_l0M?oo603o00;ooo]Z00?o
J03ooookJ_oonfX00_oonfX01Ol0oi;ooo]Zon80oooonf[o0?m500;ooo]Z00KoH@3ooookJ_oo06co
oo]Zo`3og_oo08L2oookJP05oil0oonco`3oo`3MoookJ_oo0`000_oonfX02?l0nooooo]Zoc_o0?oo
P@3o0?o<oom/0?oonf[o07Oo0_oonfX01onX0?oooo]ZoookJ_o[o`3ooo]Zool60?lH0?l00_oonfX0
1Ooo0?cooo]ZoookJ_oonf[ooi8000Cooo]Z00?oo`3ZoookJ_oonfX03?oonfX00ol0Looooo]Zoook
JP07oookJP03okWo0?ooDP3o0?lc00;ooo]Z00Oo02[ooookJ_loo`3ooo]Zo`3Loomho`3o0?oO00Ko
oo]Z00Co4P3oo`3o6ooonf[oolX00ooonfX00ooo09?ooo]Zool04`05oookJP06om[o0?oonf[ooo]Z
oookJ_lV0?oo8?l04?oonfX00olao`3ooo]Zo`3oF`03oookJP05oh;o0?oonf[ooo]Zo`0`ool0odd0
0_oonfX01Ol60?oooo]ZoookJ_oo0?GoT_l000;ooo]Z00?o01Wooa00ool0GOl00ooonfX01olE0?oo
o`1AoookJ_oonf[o0:gooookJ_oo07T02?oonfX02?l0oe?ooo]ZoookJ_oonf[o0?l8o`3o7Ooonf[o
0>7o:OoonfX002_ooo]Z00?oZ03ooookJ_oonfX00_oonfX00ooo0?Wooo]Zo`1go`02oookJP05oom/
0?oonf[o0?o<oon10?lko`001OoonfX01Ol0nooooo]ZoookJ_oonf[oo`<000?ooo]Z00GoN@3oool0
gOoonf[o0:?oo`3o3007oookJP05o`3og_oo08Oooo]ZoookJ_nDo`000_oonfX00om=0?ooobh0of40
o`03oookJP06o`3oAOoonf[ooo]ZoookJ_oR0?oo0?n@0_oonfX00ol0oi;ooo]ZoookJP06oookJP03
ofP0oooonf[ooo]Z00;ooo]Z00?o603oonKo0?oonfX00ooonfX00oooT03ooo]ZoookJP09oookJP05
oonn0?oUo`3oiOl0on/0oom`0?l00_oUo`05oookJP03oomG0?oonf[ooo]Z00Cooo]Z0_oo02d;oook
JP03oon10?oonf[ooo]Z00Sooo]Z2om4o`03o`2Yo`03onGo0?oonf[ooo]Z00;ooo]Z1_nDo`0>oook
JPCo08So0ol0ZOl3oookJP04o`04ool0e?oo0=Coo`3Do`Sooo]Z0_ooP@07oookJP;oo`0]0ol00000
1OooE`3ooo]ZoookJ_oonf[oL03o00;oj`3o00?ookh0oookJ_oonfX01OoonfX01?ooT03ooo]ZoiCo
0?lH0?l5ooo900?ooo]Z00?o0?nBoookJ_oR0?l00_oonfX00ol0odGoH@3oodd0o`02oookJP03ool0
K?oo08Oooo]Z00;ooo]Z00GoiOl0odCo0?oo0=gooo]Zool30002oookJP0Ao`3koooonf[ooo]Zoc_o
0?oonf[oof`0oookJ_l0Moooo`3ioookJ_nX0?oooo]Zo`3oGOo[o`3ooo]Zool60?lH0?l00_oonfX0
1Ooo0?cooo]ZoookJ_ooTP3ooo]Z00GoiOl03_oonfX00ol0Looooo]ZoookJP07oookJP05onGo0?oo
nf[o0?l<oookJ_l0:_l00ooonfX01?l0g?oooo]ZogSo0?l0oml6oookJP04o`3o6ol0S_oooo]Zooo:
00?ooo]Z00Co0?Woool0Tooonf[oo`0C0_oonfX6onGo0003obH0oolPo`3ooo]Z00oooo]Z00CoiOl0
oookJ_oonf[o0?mK0_oonfX02?n2o`3oiOl0onGo0?oUo`3o0?m=onGo0?oonf[o1P3o0_oonfX01OnB
o`3ooo]ZoookJ_oonf[o403o00;oiOl00ooonfX00ooUo`3oU?l0oookJP02oookJP03o`2]oom4o`3o
oo]Z00Oooo]Z00Oo0?mCoookJ_oonf[ooo]Zo`3o2?l0oago0>7o05;ooo]Z00?oZ03ooookJ_oonfX0
0_oonfX00ooo0?Wooo]Zo`1go`02oookJP05oom/0?oonf[ooo]Zoon10?lko`001OoonfX01Ol0nooo
oo]ZoookJ_oonf[oo`<000?ooo]Z00KoN@3ooookJ_oo0=go01Ooo`2Soonco`06oookJP05omgo0?oo
08Oooo]ZoookJ_oo06`00_oonfX01?m=0?oooo]Zool^0?mQ0?l2oookJP06o`3oAOoonf[ooo]Zoook
J_oR0?oo0?n@0_oonfX00ol0oi;ooo]ZoookJP06oookJP03ofP0oooonf[ooo]Z00?ooo]Z00?o603o
o`1doooonfX00_oonfX00oooT03ooo]ZoookJP09oookJP05oonn0?oonf[ooo]Zo`3o1Oo[0?l01ooo
nfX00oooE`3ooo]ZoookJP04oookJP;oo`0]2ooonfX00oooP@3ooo]ZoookJP0;oookJP?o0=Co0ol0
1?l00ooonf[o0:Woo`2Yo`02o`2Yo`;o08So6?oonfX3o`28o`?o0:Wo1?oonfX00ol01?oo0=Coo`3D
o`09oookJP;ooh401_oonfX2ool0;@?o00000_ooE`03oookJP;oj`3o00?ooo]Zoonn0?oonfX01Ooo
nfX01OooT03ooo]ZoookJ_l0M?oo603o00;ooo]Z00?oJ03ooookJ_oonfX00_oonfX00ol0oi;ooo]Z
on80o`02oookJP03o`3oAOoonf[oH@3o00;ooo]Z00?oo`1/o`3og_oo08L00_oonfX01OnO0?oo/ol0
o`2Soooo0=goo`<000?ooo]Z013o0?_ooookJ_lko`3ooh40oom/0?oonf[o07Ooool0nOoonf[oZ03o
o`2Voooonf[oo`3fon_o0?oo1P3o603o0ooonfX01?oo0?cooo]ZoookJ_ooTP04oookJP03ool0j_oo
nf[ooo]Z00cooo]Z00?o07?ooookJ_oonfX01ooonfX00onio`3ooo]ZoomB0002oookJP07o`0Zoooo
nf[ooo]Zocoo0?l0g?oo?@3oogSo0007oookJP03o`3o6ooonf[oolX000?ooo]Z00Co0?Woool0Tooo
nf[oo`0C1OoonfX01_oJo`3ooo]ZoookJ_lV0?oooo]Zob3o00oooo]Z00Co<Ol0oookJ_oonf[o0?mK
0_oonfX01_n2o`3ooo]ZoookJ_l0ok7o033oo`3oC@;ooo]Z00Co1P3ooookJ_oo0?GoT_l00ooonfX0
0ol@0?oo05gooookJP02oookJP03oaD0oooonf[oo`1A00;ooo]Z00?o0:goool0NOoonfX02?oonfX0
1ol0oe?ooo]ZoookJ_oonf[o0?l8o`3o7Ol0hOl0:_oonfX002[ooo]Z00?o0:KoojP0oooonfX00ooo
nfX00ooo0?Wooo]Zo`1go`02oookJP06oom/0?oonf[o0?o<oon10?oonf[o>ol01?oonfX00ol0nooo
oo]ZoookJP02oookJP09ool30?oonf[ooo]ZogT0oooo0=gooo]ZonGo0?l0Xooo0?l<00Kooo]Z00Go
0?oNool0Qooonf[ooo]ZoiCo0003oookJP03odd0oooo;P3oH@3o00;ooo]Z00Ko0?m5oookJ_oonf[o
oo]Zon80oooUo`02oookJP03o`3oT_oonf[ooo]Z00Kooo]Z00?oJ03ooookJ_oonfX00ooonfX00olH
0?ooi_l0oookJP02oookJP03oon@0?oonf[ooo]Z00[ooo]Z00Gookh0onGo0?oUo`3oj`3oog00o`02
onGo00Gooo]Z00?ooeL0oookJ_oonfX01OoonfX00ooo02gooo]ZoookJP09oookJP03oon10?oonf[o
oo]Z00Sooo]Z2Om4o`04onGo00Go0:Wo0ol0R?l3oiCo00[ooo]Z0ol0R?l5o`2Yo`03oookJ_l01?oo
00Co00;o00Co0_l0e?l9oookJP;ooh402?oonfX01?oo02gooo]ZoookJ_l00002oomG0007o`000?oo
nf[ooo]Zog00ooo[0?oo0?l5oonn0007oookJP04oon@0?oonf[ooo]ZoaP0o`OoolT000Cooo]Zo`3o
T_oonf[ohP3o0_oonfX00ol0odGoH@3oodd0o`02oookJP03ool0K?oo08Oooo]Z00;ooo]Z00GoW`3o
odCo0?oUo`3oo`3Mool30002oookJP0>o`3koooonf[ooo]Zoc_o0?ooP@3oof`0oookJ_l0Moooo`3i
oookJ_nX0?oooo]Zo`3oGOo[o`02oookJP04ool60?oonf[ooo]Zool0o0?ooo]Z00?ooi80oookJ_oU
o`001?oUo`0=oookJP03o`1coooonf[ooo]Z00Sooo]Z00GoiOl0o`3o3?l0oc?ooo]Zo`0Zo`02oook
JP05onGo0?l0g?ooN?l0oookJ_l0oml01_oonfX01?l0oa_ooo]ZoookJ_oobP03oookJP04ool0Tooo
nf[ooo]Zool04`;ooo]Z1OoUo`000ooonf[o9P3ooookJP0?oookJP04onGo0?oonf[ooo]Zo`3oF`?o
oo]Z00GoP_l0onGo0?oUo`3oiOl0o`3oC@02onGo0004o`H0oooonf[ooo]Zoi;o00?ooo]Z00?o403o
onGo0?oonfX00ooonfX01_oUo`3oU?l0oookJ_oonf[o0:goodCo00Wooo]Z00Oo0?mCoookJ_oonf[o
0?l8oookJ_l0oago0>7o057ooo]Z00?o0:KooookJ_nX0?l01?oonfX01Ooo0?Wo07OooookJ_oonf[o
of`000;ooo]Z00?o0?o<oon10?lko`001?oonfX00ol0nooooo]ZoookJP02oookJP0:ool30?oonf[o
oo]ZogT0oooonf[oo`3Mo`0Gool0XoooW`3ook?o00Kooo]Z00Co0?oNool0Qooonf[oo`1/0ooonfX0
1_m=0?oooo]Zool^0?mQ0?oooo]Zo`3oA@Cooo]Z00CohP3ooookJ_oonf[o0?nB2OoonfX00omX0?oo
oo]ZoookJP03oookJP05oaP0oooonf[ooo]ZoookJ_ooT0003?oonfX01Ooo_P3ooo]ZoookJ_l0o`Go
j`3o00Oooo]Z00?ooeL0oookJ_oonfX01OoonfX00ooo02gooo]ZoookJP09oookJP03oon10?oonf[o
oo]Z00gooo]Z0_l0e?l00ooonf[o00Coo`04o`03oookJPGo0:Wo1ol0R?l9oookJP?o08So1Ol0ZOl2
oookJPCo00Co0_l0e?l9oookJP;ooh401ooonfX00ooo02gooo]ZoookJP02o`000003oomG0?l0003o
oo]Z00;ooo]Z00Coj`3oo`3o1Ooonf[ookh01_oonfX01OooT03ooo]ZoookJ_l0M?oo603o00?ooo]Z
017oJ03ooookJ_oonf[ooo]Zo`3oT_oonf[o0?n@on80oooonf[o0?m5oookJ_mQ0?ooC@3ooookJ_oo
06co0?oNool0Q`02oookJP06oil0oonco`3oN@3oool0gOoonf[oo`<00_oonfX02?l0nooooo]Zoc_o
0?ooP@3o0?nJoom/0?l0Moooo`3i0_oonfX01onX0?oooo]Zool0m_o[o`3ooo]Zool60?lH0?l00_oo
nfX01Ooo0?cooo]ZoookJ_ooTP3ooaH000Cooo]Z00?oo`3ZoookJ_oonfX03?oonfX00ol0Looooo]Z
oookJP07oookJP03okWo0?ooDP3o0?lc00;ooo]Z00Oo02[ooookJ_loo`3ooo]Zo`3Loomho`3o0?oO
00Kooo]Z00Co4P3oo`3o6ooonf[oolX00ooonfX01?oo09?ooo]ZoookJ_oo01<4oookJP06om[o0?oo
nf[ooo]ZoookJ_lV0?oo8?l04?oonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP08oh;o0?oonf[ooo]Z
o`3o/Ol0<?oo0?m=oookJ_l60?l2oookJP07ool0mOnBo`3ooo]ZoookJ_oo06[o403oo`1Mo`03oook
JP07oaD0oooo057ooo]ZoookJ_l0[Ooooo]Zool0N@09oookJP07o`3oDooonf[ooo]Zo`3o2?l0oago
oo]Zo`3Qo`0ZoookJP00:_oonfX00ol0Y_ooZ03ooookJP03oookJP03ool0nOoonf[o07Oo00?ooo]Z
00Goof`0o`3oc?ooP@3ooo]Zoc_o0004oookJP03o`3koooonf[ooo]Z00;ooo]Z00Woo`<0oookJ_oo
nf[oN@3oool0gOoonf[o01Ooo`2Sool0o``01ooonfX01?oo08Oooo]ZoookJ_oo06`3oookJP06odd0
oooo;P3ooo]Zof40oooonf[o0?m50ooonfX00ooR0?ooiOl0onGo0002oookJP03o`3oT_oonf[ooo]Z
00Kooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?oo07CoonKo0003oookJP03oon@0?oonf[ooo]Z
00Wooo]Z00KoiOl0oonn0?oUo`3oj`3oonGo0?m`0?l3onGo00Cooo]Z00?ooeL0oookJ_oonfX01Ooo
nfX00ooo02gooo]ZoookJP09oookJP03oon10?oonf[ooo]Z00Wooo]Z1om4o`03o`04o`Kooo]Z1?l0
ZOl00ooonf[oU?l0o`28o`03o`28o`Wo0:Wo0_oonfX4o`04o`04oookJ_l0e?oo0=Coo`3Do`Wooo]Z
0_ooP@08oookJP;oo`0]0ooonfX02OooE`3o0000o`000?l0003ooo]Zog00ooo[0?oo0?l5oonn0007
oookJP04oon@0?oonf[oi_l0oaP0o`SoolT000?o0?nBoookJ_oR0?l00_oonfX01ol0odGoH@3oool^
0?m=0?oooo]ZonGo0?oo08L01?oonfX01Om4o`3oiOl0ool0gOoonf[oo`<000;ooo]Z00go0?_ooook
J_lko`3ooh40oookJ_ooK03o07Ooool0nOoonf[oZ03oo`2Voooonf[ojol000;ooo]Z00GoiOl0oook
J_oonf[ooo]Zool0o002oookJP03oonB0?oonf[oiOl000OoiOl02ooonfX00ol0Looooo]ZoookJP07
oookJP05onGo0?oonf[o0?l<oookJ_l0:_l00ooonfX01?oUo`3o0=coogSo0?l0oml6oookJP04oa80
ool0oa_ooo]Zooo:00Cooo]Z00?oo`2CoookJ_oo01<00ooonfX4onGo00;ooo]Z00?o9P3ooookJ_oo
nfX03_oonfX01?oUo`3ooo]ZoookJ_l0oe/2oookJP05o`3o/?n2o`3oiOl0onGo0?l0odd01OoUo`00
0ooo0?GoT_l0oookJP02oookJP03oa00ool0GOoooo]Z00;ooo]Z00?oiOl0oiCo0?oonfX00_oonfX0
0ol0[OooA?l0oookJP07oookJP08o`3oDooonf[ooo]ZoookJ_l0o`Sooo]Zo`3o7Ol0hOmAoookJP03
o`2Voooonf[oZ03o00Cooo]Z00?oo`3io`1goooonfX00_oonfX01OooK03ooo]Zo`3oc?ooP@3o>ol0
00Gooo]Z00Go0?_ooookJ_oonf[ooo]Zool30002oookJP07ogT0oooonf[oo`3Mo`0Gool0Xooooo]Z
ok?o0006oookJP04omgo0?oo08Oooo]Zool0K0Cooo]Z00GoC@3oool^0?mQ0?oooo]Zo`3oA@04oook
JP05on80oooonf[ooo]ZoookJ_l0oi802?oonfX00omX0?oooo]ZoookJP03oookJP03oaP0oooVo`3o
oo]Z00;ooo]Z00?ooi00oookJ_oonfX02_oonfX01Ooo_P3ooo]Zo`3o1Oo[0?ooL03o00Oooo]Z00?o
oeL0oookJ_oonfX01OoonfX00ooo02gooo]ZoookJP09oookJP03oon10?oonf[ooo]Z00kooo]Z0_l0
e?l00ooonf[o00Coo`04o`06oookJPCo0:Wo0ooonfX3o`28o`Wo0:Wo0ooonfX4o`04o`04oookJ_l0
e?oo0=Coo`3Do`Sooo]Z0oooP@07oookJP;oo`0]0ooonfX01?l0003ooeL0o`000?l00002oookJP04
on/0ool0o`Gooo]Zoonn00Kooo]Z00Gooi00oookJ_oonf[oi_l0oaP0o`03oookJP0AofP0oooonf[o
oo]ZoookJ_l0oi;ooo]Zo`3oT?oR0?oooo]Zo`3oAOoonf[oH@3oodd0oooonf[oo`1/o`3og_oo08L0
0ooonfX01Onco`3ooo]Zool0gOoonf[oo`<000;ooo]Z00So0?_ooookJ_lko`3ooh40o`3oc?ooK03o
07Ooool0n@;ooo]Z00OoZ03ooookJ_oonf[ojol0oookJ_oo1P3o603o00?ooo]Z00Coo`3loookJ_oo
nf[ooi801?oonfX00ooo0>[ooo]ZoookJP0<oookJP03o`1coooonf[ooo]Z00Oooo]Z00?o^Ol0oook
J_ooDP000_oonfX01ol0:_oooo]ZoookJ_loo`3ooo]Zocd0oomho`001ooonfX00olB0?oo0?lKooo:
0004oookJP03ool0Tooonf[oo`0C00Gooo]Z00Kof_l0oookJ_oonf[ooo]ZobH0oolPo`0?oookJP04
oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00Ko0?n`oh;o0?oonf[o0?nao`0`ool0odd2oookJP04o`H0oooo
nf[ooo]Zoi;o00?ooo]Z00?o01Wooa00ool0GOl00ooonfX01olE0?ooo`1AoookJ_oonf[o0:gooook
J_oo07T02?oonfX02?l0oe?ooo]ZoookJ_oonf[o0?l8o`3o7Ooonf[o0>7o:_oonfX002[ooo]Z00?o
0:KoojP0oooonfX00ooonfX00ooo0?Wooo]Zo`1go`03oookJP05oom/0?oonf[ooh40oookJ_lko`00
1OoonfX01Ol0nooooo]ZoookJ_oonf[oo`<000?ooo]Z00GoN@3oool0gOoonf[o0:?oo`3o3007oook
JP05ool0QooMo`3ooo]ZoookJ_oo06`00ooonfX00om=0?ooobh0of40o`02oookJP05o`3oAOoonf[o
oo]ZoookJ_oR0?l00_oUo`02oookJP03o`3oT_oonf[ooo]Z00Gooo]Z00?oJ03ooookJ_oonfX00ooo
nfX00olH0?ooi_l0oookJP02oookJP03oon@0?oonf[ooo]Z00[ooo]Z00GoiOl0oonn0?oUo`3oj`3o
og00o`04onGo00Cooo]Z00?ooeL0oookJ_oonfX01OoonfX2ool0;@[ooo]Z1Ooob@07oookJPOoA?l0
00Cooo]ZonGo0?l01?oo00Co2?oonfX6o`2Yo`Kooo]Z1Ol01?l5o`3Do`[ooo]Z0_ooP@08oookJP;o
o`0]1?oonfX00oooE`3o0000o`000002o`000004og00ooo[0?oo0?l5oonn00Oooo]Z00Gooi00oook
J_oVo`3o603ooookJP07ooo90003o`3oT_oonf[ohP3o00;ooo]Z00Co0?m5of40oooonf[oC@3o0_oo
nfX00ooUo`3oo`27oookJP02oookJP05odCo0?oUo`3oN@3oool0gOoo0`000_oonfX03_l0nooooo]Z
oc_o0?ooP@3o0?o<oom/0?oonf[o07Ooool0nOoonf[oZ03ooookJ_l0oegojol00_oonfX01?oUo`3o
oo]ZoookJ_oo0?`2oookJP03oonB0?oo5P3ooo]Z00WoiOl02OoonfX00ol0Looooo]ZoookJP08oook
JP05onGo0?l0o`co0?lcoookJ_l0:_l00_oonfX01?oUo`3o0=coonGo0?mho`07oookJP04o`3o6ooo
nf[ooo]Zooo:00?ooo]Z00Coo`2CoookJ_oonf[oo`0C0ooonfX4onGo0003oookJ_lV0?oooo]Z013o
oo]Z00CoiOl0oookJ_oonf[o0?mK0_oonfX01On2o`3ooo]ZonGo0?oUo`3o0?m=00GoiOl000KoT_l0
oookJ_oonf[ooo]Zoa00oooUo`04oookJP03onGo0?nDo`3ooo]Z00;ooo]Z00?o0:goodCo0?oonfX0
1ooonfX01ol0oe?ooo]ZoookJ_oonf[o0?l8o`3o7Ol0hOl0DooonfX00ol0Y_ooZ03ooookJP03oook
JP03ool0nOl0Mooooo]Z00;ooo]Z00Goof`0oookJ_oonf[ooh40oc_o0005oookJP05o`3koooonf[o
oo]ZoookJ_oo0`000ooonfX01_mi0?ooo`3MoookJ_l05ooo0:?ook?o00Oooo]Z00Coo`27oookJ_oo
nf[oo`1/0ooonfX01_m=0?oooo]Zool^0?mQ0?oooo]Zo`3oA@Cooo]Z00GohP3ooookJ_oonf[ooo]Z
o`3oTP08oookJP03ofP0oooonf[ooo]Z00?ooo]Z00Go603ooookJ_oonf[ooo]Zoon@000=oookJP04
oonn0?oonf[o0?l5on/0o`Sooo]Z00?ooeL0oookJ_oonfX01OoonfX2ool0;@[ooo]Z0_ooP@0@oook
JP;o0=Co00Cooo]Zo`04ool01?oo00Co1ooonfX6o`2Yo`Oooo]Z1Ol01?l5o`3Do`Wooo]Z0_ooP@08
oookJP;oo`0]1?oonfX2oomG00?o000000Gooo]Zon/0ool0o`Gooo]Zoonn0006oookJP05oon@0?oo
nf[ooo]ZonKo0?lH0?l00ooonfX03OmX0?oooo]ZoookJ_oonf[o0?nBoookJ_l0oi3ohP3ooookJ_l0
odGooo]Zof40oom=0?l00_oonfX00ooo06coo`27oookJP02oookJP05ok?o0?l05ooo0:?oool0gOoo
0`000ooonfX02?l0nooo>ol0oookJ_ooP@3oof`0oookJ_l0Moooo`3i0_oonfX00onX0?oooo]Zon_o
0002oookJP05ool60?oonf[ooo]ZoookJ_oo0?`00_oonfX00oooTP3ooaH0oookJP03oookJP03ool0
j_oonf[ooo]Z00cooo]Z00?o07?ooookJ_oonfX01ooonfX00onio`3ooe80o`3o<`02oookJP07o`0Z
oooonf[o?ol0oookJ_l0g?oo?@3oogSo0006oookJP04oa80ool0oa_ooo]Zooo:00?ooo]Z00Co0?Wo
ool0Tooonf[oo`0C1?oonfX01_oQo`3of_l0oookJ_oonf[o9P3oob3o013ooo]Z00Co<Ol0oookJ_oo
nf[o0?mK0_oonfX01_n2o`3ooo]ZoookJ_l0ok7o033oo`3oC@;ooo]Z00Co1P3ooookJ_oo0?GoT_l0
0ooonfX00ol@0?oo05gooookJP02oookJP03oaD0oooonf[oo`1A00;ooo]Z00?o0:gooookJ_oo07T0
2?oonfX01ol0oe?ooo]ZoookJ_oonf[o0?l8o`3o7Ol0hOl0:ooonfX002_ooo]Z00?oZ03ooookJ_oo
nfX00ooonfX00ooo0?Wo07OooookJP02oookJP05oom/0?oonf[ooh40oookJ_lko`001OoonfX00ol0
nooooo]ZoookJP02oookJP09ool30?oonf[ooo]ZogT0oooo0=gooo]Zo`0Gool0Xooo0?l<00Oooo]Z
00Coo`27oookJ_oonf[oo`1/0ooonfX01_m=0?ooobh0oookJ_mQ0?oooo]Zo`3oA@?ooo]Z00KohP3o
onGo0?oUo`3oiOl0oookJ_l0oi88oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603ooookJ_oVo`00
0ooonfX00oooT03ooo]ZoookJP09oookJP;oiOl000Cookh0onGo0?o[0?ooL03o1?oUo`04oookJP03
oomG0?oonf[ooo]Z00Kooo]Z00?oo`0]oookJ_oonfX02OoonfX:ooo90003oookJ_m4o`3oA?l000;o
A?l00_oonfX00om4o`3o0=Coo`3Do`03o`3Doa;o00Co00?ooo]Zo`3Dool0e?l00_l0e?l=oookJP;o
oh402?oonfX2ool0;@Cooo]Z0_ooE`002?oonf[o0000o`000?l0003oL03oon/0oooonf[ookh01ooo
nfX01OooT03ooo]ZonKo0?lH0?oooo]Z00OoolT000Co0?nBoookJ_l0oi3ohP3o0_oonfX00omQ0?oo
oo]Zodd0o`02oookJP03onGo0?oo08Oooo]Z00;ooo]Z00GoA?l0o`0Gool0Xoooo`3Mool30002oook
JP0>o`3koooonf[ooo]Zoc_o0?ooP@3o0?nJoom/0?l0Moooo`3ioookJ_nX0?oo0:Koo`3oGOo[o`02
oookJP05onGo0?oonf[ooo]ZoookJ_oo0?`00_oonfX00oooTP3ooo]ZoookJP09onGo00Wooo]Z00?o
07?ooookJ_oonfX02?oonfX01?oUo`3o0?l<oookJ_l0:_l3oookJP04onGo0?l0g?ooN?l0o`3og`Ko
oo]Z00Co4P3oo`3o6ooonf[oolX01?oonfX00ooo09?ooo]Zool04`04oookJP?oiOl00_oonfX00olV
0?oooo]ZoookJP0>oookJP05onGo0?oonf[ooo]ZoookJ_l0oe/00_oonfX01On2o`3ooo]ZonGo0?oU
o`3o0?m=00CoiOl000?ooo]Zoi;o0?oonfX00_oonfX00ol@0?oo05gooookJP03oookJP03oiCo0?oo
nf[ooo]Z00;ooo]Z00?o0:goodCo0?oonfX01ooonfX01ol0oe?ooo]ZoookJ_l0o`Sooo]Zo`3o7Ol0
hOl0DooonfX00ol0Y_ooZ03ooookJP03oookJP03ool0nOl0Mooooo]Z00;ooo]Z00Go0?nJoom/0?oo
nf[ooh40oc_o0005oookJP03o`3koooonf[ooo]Z00;ooo]Z00[oo`<0oookJ_oonf[oN@3ooookJ_oo
0=go01Ooo`2Soooonf[o/ol01_oonfX01?oMo`3oo`27oookJ_oo06`4oookJP05odd0oooo;P3ooo]Z
of40ool0odD01?oonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Sooo]Z00?oJ03ooookJ_oonfX00ooo
nfX00olH0?ooi_l0oookJP02oookJP03oon@0?oonf[ooo]Z00_ooo]Z00Cookh0oookJ_l0o`Goj`3o
2?oonfX00oooE`3ooo]ZoookJP06oookJP03ool0;Ooonf[ooo]Z00Wooo]Z0_ooP@0@oookJPKo0=Co
4_l01?l00ooonf[o0=Coo`3Do`02o`3Do`cooo]Z0_ooP@08oookJP;oo`0]1OoonfX00oooE`3ooo]Z
o`000003o`000004on/0oooonf[ooo]Zoonn00Kooo]Z00Gooi00oookJ_oonf[oi_l0oaP0o`03oook
JP08ofP0oooonf[ooo]ZoookJ_l0oi;ooo]Zo`3oT?oR0?l2oookJP03o`3oAOmQ0?ooC@3o00;ooo]Z
00?oo`1/ool0QooonfX00_oonfX01OnO0?oo/ol0ogT0oooo0=goo`<000?ooo]Z00So0?_ooookJ_lk
o`3ooh40o`3oV_ooK03o07Ooool0n@;ooo]Z00OoZ03ooookJ_oo0?Kojol0oookJ_oo1P3o603o00?o
oo]Z00Coo`3loookJ_oonf[ooi801?oonfX00ooo0>[ooo]ZoookJP0<oookJP03o`1coooonf[ooo]Z
00Sooo]Z00Go^Ol0oomB0?oonf[ooo]Zo`0Zo`02oookJP04ocoo0?oonf[o0=coogSo00Oooo]Z00?o
4P3oo`3o6ooobP001?oonfX00ooo09?ooo]Zool04`05oookJP06om[o0?oonf[ooo]ZoookJ_lV0?oo
8?l04?oonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP08oh;o0?oonf[o0?naoookJ_l0odgo0>Sooook
J_l60?l2oookJP07ool0mOnBo`3ooo]ZoookJ_oo06[o403oo`1Mo`03oookJP03oaD0oooo057ooo]Z
00;ooo]Z00?o0:goool0NOoonfX01ooonfX02?l0oe?ooo]ZoookJ_oonf[o0?l8o`3o7Ooonf[o0>7o
:ooonfX002_ooo]Z00?o0:KoojP0oooonfX00ooonfX00ooo0?Wooo]Zo`1go`02oookJP05o`3oV_oo
K03o0?o<oon10?lko`001OoonfX00ol0nooooo]ZoookJP02oookJP05ool30?oonf[ooo]ZoookJ_oo
0=d00_oonfX00ol0Xooo0?l<oookJP06oookJP05ool0Qooonf[ooo]ZoookJ_oo06`00ooonfX01Om=
0?ooobh0of40oooonf[o0?m500?ooo]Z00?ohP3oonGo0?oUo`000_oUo`000ooonf[o0?nBoookJP07
oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603oo`1doooVo`000_oonfX00oooT03ooo]ZoookJP0:
oookJP07onGo0?oo_P3oiOl0onGo0?o[0?ooL03oonGo0007oookJP03oomG0?oonf[ooo]Z00Kooo]Z
00?oo`0]oookJ_oonfX02OoonfX;ooo900?oA?l02?oonfX9o`3Do`Gooo]Z1Ol0e?l?oookJP;ooh40
2OoonfX00ooo02gooo]ZoookJP03oookJP04oomG0?oonf[ooo]ZoookJP;o000000CoL03oon/0oooo
nf[ookh01ooonfX01OooT03ooo]ZonKo0?lH0?oooo]Z00KoolT00_oonfX00ol0oi;o0?n@on80o`02
oookJP07of40oooo;P3oobh0odd0oooonf[oiOl0ool0Q`03oookJP05odCo0?nO0?oo0:?oool0gOoo
0`000ooonfX02?l0nooooo]Zoc_o0?ooP@3ooo]Zoom/0?l0Moooo`3i0_oonfX00onX0?oooo]Zon_o
0002oookJP05onGo0?oonf[ooo]ZoookJ_oo0?`00_oonfX01?ooTP3ooo]ZoookJ_oonfX8onGo00Wo
oo]Z00?o07?ooookJ_oonfX02?oonfX01OoUo`3o0?l<oookJ_oonf[o02[o00;ooo]Z00CoiOl0oook
J_l0g?ooN?l01ooonfX01?l0oa_ooo]ZoookJ_oobP03oookJP04ool0Tooonf[ooo]Zool04`?ooo]Z
0ooUo`02oookJP03obH0oolPo`3ooo]Z00oooo]Z00CoiOl0oookJ_oonf[o0?mK0_oonfX01On2o`3o
oo]ZoookJ_oUo`3o0?m=00GoiOl000?oT_l0oookJ_oonfX00_oonfX00ol@0?oo05gooookJP02oook
JP03onGo0?nDo`3ooo]Z00;ooo]Z00?o0:goodCo0?oonfX01ooonfX02?l0oe?ooo]ZoookJ_oonf[o
0?l8oookJ_l0oago0>7oDooonfX00ol0Y_oooo]ZojP0o`04oookJP09ool0nOl0Mooooo]ZoookJ_l0
oi[oof`0oookJ_l0olco>ol000Gooo]Z00?o0?_ooookJ_oonfX00_oonfX02_oo0`3ooo]ZoookJ_oo
nf[oN@3oool0gOoonf[o0:?ooookJ_nco`06oookJP05omgo0?oo08Oooo]ZoookJ_oo06`00ooonfX0
1Om=0?oooo]Zool^0?mQ0?oo0?m500Cooo]Z00?ohP3oo`3oT?oonfX00_oonfX00ol0oi;ooo]Zoook
JP06oookJP03ofP0oooonf[ooo]Z00?ooo]Z00Go603oonKo0?oonf[ooo]Zoon@000=oookJP05oonn
0?oonf[ooo]Zo`3o1Oo[0?l02?oonfX00oooE`3ooo]ZoookJP06oookJP;oo`0]2ooonfX3oon101?o
oo]Z2Ol0e?l5oookJPGo0=Co3_oonfX2oon100Wooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooE`3o
oo]ZoookJP02o`000005o`3o1Oo[0?oooo]ZoookJ_oo_P001_oonfX01OooT03ooo]ZoookJ_oVo`3o
603o00?ooo]Z00?oJ03ooookJ_oonfX00_oonfX03Ol0oi;o0?n@oookJ_oR0?oooo]Zo`3oAOmQ0?oo
obh0odd0oooonf[oo`1/o`3og_oo08L00ooonfX01Onco`3ooo]Zool0gOoonf[oo`<000;ooo]Z00So
0?_ooookJ_lko`3ooh40o`3oc?ooK03o07Ooool0n@?ooo]Z00KoZ03oool0m_o[o`3ooo]Zool60?lH
0?l3oookJP04ool0o?oonf[ooo]ZoonB00Gooo]Z00?oo`3ZoookJ_oonfX02ooonfX00ol0Looooo]Z
oookJP08oookJP03okWo0?ooDP3o0?lc00;ooo]Z00?o02[ooookJ_loo`000_oonfX00olm0?ooN?l0
oookJP05oookJP04o`2>ool0oa_ooo]Zooo:00?ooo]Z00Co0?Woool0Tooonf[oo`0C1?oonfX01ooQ
o`3of_l0oookJ_oonf[o9P3oob3o0?n40?l03ooonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP06oh;o
0?oonf[ooo]Zo`3o/Ol0<?oo0?m=0_oonfX01?l60?oooo]Zool0mOnBo`03oookJP03o`0Iool@0?oo
oo]Z00?ooo]Z00Oo5@3oool0DOoonf[ooo]Zo`2]oooonf[oo`1i00Sooo]Z00So0?mCoookJ_oonf[o
oo]Zo`3o2?l0oagooo]Zo`3Qob_ooo]Z000[oookJP03o`2VoonX0?oooo]Z00?ooo]Z00?oo`3ioook
J_l0Mol00ooonfX01OooK03ooo]Zoon10?oonf[o>ol000Cooo]Z00?o0?_ooookJ_oonfX00ooonfX0
2?oo0`3ooo]ZoookJ_mi0?ooo`3MoookJ_l0Xooo0?l<1ooonfX01Ooo08OogOl0oookJ_oonf[oo`1/
00?ooo]Z00KoC@3oool^0?oonf[oH@3ooookJ_l0odD3oookJP03on80oooUo`3oiOl000;oiOl000?o
0?nBoookJ_oonfX01_oonfX00omX0?oooo]ZoookJP02oookJP03oaP0oooonf[oi_l000?ooo]Z00?o
oi00oookJ_oonfX02OoonfX2onGo0005oonn0?oUo`3oj`3oonGo0?m`0?l02?oonfX2oomG00Oooo]Z
0_oo02d:oookJP_oolT000?oA?l0oookJ_oonfX04?oonfX5o`3Doa;ooo]Z0_ooP@09oookJP;oo`0]
1OoonfX00oooE`3ooo]ZoookJP02oookJP;oL03o00?oj`3oo`000?oo_P001ooonfX01?ooT03ooo]Z
onKo0?lH0?l2oookJPCoolT00ooonfX00ol0oi;o0?n@on80o`02oookJP07of40oooo;P3ooo]Zodd0
oooonf[oiOl0ool0Q`04oookJP04odCo0?l0XoooN@3oool0g@?ooo]Z017o0?_ooookJ_lko`3ooh40
o`3oc?l0oi[oof`0o`1goooo0?Wooo]ZojP0oooonf[o0?mMon_o0?oonf[oiOl0oaP0o`03oookJP04
ool0o?oonf[ooo]ZoonB00?ooo]Z1ooUo`09oookJP03o`1coooonf[ooo]Z00Wooo]Z00CoiOl0o`3o
3?oonf[o02[o0ooonfX01?oUo`3o0=coonGo0?mho`07oookJP03o`3o6ooonf[oolX000Cooo]Z00?o
o`2CoookJ_oo01<01?oonfX3onGo00;ooo]Z00?o9P3ooookJ_oonfX03ooonfX01?oUo`3ooo]Zoook
J_l0oe/2oookJP05oh;o0?oonf[oiOl0onGo0?l0odd01?oUo`000ooonf[oT_l0oookJP03oookJP03
oa00oooonf[ooo]Z00;ooo]Z00OoiOl0oiCo0?m4o`3oA?l0oookJ_l0[OooA?l000Sooo]Z00So0?mC
oookJ_oonf[ooo]Zo`3o2?oonf[o0?lMo`3QoeCooo]Z00?o0:KoojP0oooonfX00ooonfX00ooo0?Wo
07OooookJP02oookJP05oom/0?oonf[ooo]Zoon10?lko`001OoonfX00ol0nooooo]ZoookJP02oook
JP09ool30?oonf[ooo]ZogT0oooo0=gooo]Zo`0Gool0Xooo/ol000Oooo]Z00Goo`27oookJ_oonf[o
oo]Zool0K003oookJP05odd0oooo;P3ooo]Zof40ool0odD01?oonfX01OoR0?oo0?n@oookJ_oonf[o
0?nB00Wooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?ooi_l0oookJP02oookJP03oon@0?oonf[o
oo]Z00_ooo]Z00Gookh0oookJ_oonf[oj`3oog00o`08oookJP;ooeL02?oonfX00ooo02gooo]Zoook
JP0;oookJP;ooh406_oonfX5o`3Doa7ooo]Z0_ooP@09oookJP;oo`0]1_oonfX02_ooE`3ooo]Zoook
J_oonf[o0000og00ooo[0?oo0000oookJ_oo_P06oookJP05oon@0?oonf[oi_l0onKo0?lH0?l00ooo
nfX00omX0?oooo]ZoookJP02oookJP0=o`3oT_l0oi3ooo]Zon80oooonf[o0?m5of40oooo;P3oC@3o
oookJ_oo06co0?oNool0Q`03oookJP05ok?o0?l05ooo0:?oool0gOoo0`000ooonfX02?l0nooo>ol0
oookJ_ooP@3o0?nJoom/0?l0Moooo`3i0_oonfX01_nX0?oooo]Zon_o0?oonf[oo`H0oaP0o`Cooo]Z
00Coo`3loookJ_ooTP3ooaH01?oonfX00ooo0>[ooo]ZoookJP0<oookJP03o`1coooonf[ooo]Z00So
oo]Z00Go^Ol0oomB0?oonf[ooo]Zo`0Zo`02oookJP05ocoo0?oonf[o0=coo`3ogomho`001_oonfX0
0olB0?oo0?lKooo:0004oookJP03ool0Tooonf[oo`0C00Gooo]Z00KohOl0om[o0?oonf[ooo]ZobH0
oolPo`0@oookJP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00KoP_l0oookJ_oonf[o0?nao`0`ool0odd2
oookJP04o`H0oooonf[oo`3eoi;o00?ooo]Z00?o01Wooa00oooonfX00_oonfX00olE0?ooo`1Aoook
JP02oookJP03o`2]oooonf[oo`1i00Sooo]Z00So0?mCoookJ_oonf[ooo]Zo`3o2?l0oagooo]Zo`3Q
ob_ooo]Z000/oookJP03o`2VoonX0?oooo]Z00;ooo]Z00?oo`3ioookJ_l0Mol00ooonfX01OooK03o
oo]Zoon10?oonf[o>ol000Gooo]Z00?o0?_ooookJ_oonfX00_oonfX01Ooo0`3ooo]ZoookJ_oonf[o
o`3M00;ooo]Z00?o0:?oo`3o3?oonfX01_oonfX01Ooo08Oooo]ZoookJ_oonf[oo`1/00?ooo]Z00Go
C@3oool^0?oonf[oH@3oo`3oA@03oookJP03on80oooUo`3oiOl000?oiOl000?o0?nBoookJ_oonfX0
1_oonfX00omX0?oooo]ZoookJP02oookJP03oaP0ool0M?ooi_l000;ooo]Z00?ooi00oookJ_oonfX0
2_oonfX2onGo0004oonn0?oUo`3oj`3oog00o`[ooo]Z00?ooeL0oookJ_oonfX01_oonfX00ooo02go
oo]ZoookJP09oookJPWoolT09ooonfX3oon100Wooo]Z0_oo02d5oookJP;ooeL01?oonfX01Om`0?oo
0?l5on/0ool0003ookh000Kooo]Z0_oob@000ooonf[oi_l0oaP0o`02oookJPCoolT00ooonfX00ol0
oi;ooo]Zon80o`02oookJP07o`3oAOmQ0?oooo]Zodd0oooonf[oiOl0ool0Q`04oookJP05odCo0?l0
XoooN@3oool0gOoo0`000_oonfX03_l0nooooo]Zoc_o0?ooP@3o0?o<o`3oV_ooK03o07Ooool0nOoo
nf[oZ03oo`2Vool0oegojol00_oonfX01OoUo`3ooo]ZoookJ_oonf[oo`3l00;ooo]Z00Cooi80oook
J_oonf[ooo]Z1ooUo`0:oookJP03o`1coooonf[ooo]Z00Sooo]Z00GoiOl0o`3o3?oonf[ooo]Zo`0Z
o`02oookJP04onGo0?oonf[o0=coonGo00Oooo]Z00Co0?lKoookJ_oonf[oolX00ooonfX01?oo09?o
0?WooookJ_oo01<4oookJP;oiOl00_oonfX00olV0?oo8?l0oookJP0?oookJP05onGo0?oonf[ooo]Z
oookJ_l0oe/00_oonfX01On2o`3ooo]Zo`0`oooUo`3o0?m=00?oiOl000?ooo]Zool0mOnBo`000ooo
nfX00ol@0?oo05gooookJP03oookJP03oiCo0?oonf[oA?l000CoA?l01ooonfX01Ol0oe?ooo]Zoook
J_oonf[o0?l800;ooo]Z00?o0?lMoookJ_oonfX0DooonfX00ol0Y_ooZ03ooookJP03oookJP03ool0
nOl0Mooooo]Z00;ooo]Z00Go0?nJoom/0?oonf[ooh40oc_o0005oookJP03o`3koooonf[ooo]Z00;o
oo]Z00[oo`<0oookJ_oonf[ooo]ZogT0oooo0=gooo]Zo`2Soooonf[o/ol01_oonfX01OoMo`3oo`27
oookJ_oonf[oo`1/00?ooo]Z00GoC@3ooookJ_oo;P3oH@3oo`3oA@04oookJP03on80oooonf[o0?n@
00;ooo]Z00?o0?nBoookJ_oonfX01_oonfX00omX0?oooo]ZoookJP03oookJP05oaP0oooVo`3ooo]Z
oookJ_ooT0003_oonfX01?oo_P3ooo]ZoookJ_o[0?l:oookJP03oomG0?oonf[ooo]Z00Kooo]Z00?o
o`0]oookJ_oonfX03?oonfX2oon102_ooo]Z0oooP@09oookJP;oo`0]1_oonfX2oomG00Cooo]Z00Go
L03oon/0ool0003o0000oonn0005oookJP;ooi0000Cooo]ZonKo0?l0M?oo603o0ooonfX00omX0?oo
oo]ZoookJP02oookJP0=o`3oT_oonf[o0?n@on80oooonf[o0?m5of40oooo;P3oC@3ooookJ_oo06co
0?oNool0Q`03oookJP05ok?o0?l05ooo0:?oool0gOoo0`000ooonfX02?l0nooo>ol0oookJ_ooP@3o
0?nJoom/0?l0Moooo`3i0_oonfX01onX0?oooo]Zool0m_o[o`3ooo]Zool60?lH0?l00ooonfX01?oo
0?cooo]ZoookJ_ooTP05oookJP03ool0j_oonf[ooo]Z00_ooo]Z00?o07?ooookJ_oonfX02?oonfX0
0onio`3ooe80o`3o<`02oookJP03o`0Zoooonf[o?ol000;ooo]Z00?o?@3oogSo0?oonfX01OoonfX0
1?l0S_oo0?lKoookJ_oobP04oookJP03ool0Tooonf[oo`0C00Gooo]Z00Kof_l0oookJ_oonf[o9P3o
ob3o0?n40?l@oookJP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00SoP_l0oookJ_l0ok7o033oo`3oCOl0
j?oooo]Zo`H0o`;ooo]Z00OoT_l0oookJ_oonf[ooo]Zool0J_l@0?oo05go00?ooo]Z00?o5@3oool0
DOoonfX00_oonfX00ol0[Oooo`1ioookJP07oookJP08o`3oDooonf[ooo]ZoookJ_l0o`Sooo]Zo`3o
7Ol0hOl/oookJP00;?oonfX00ol0Y_ooZ03ooookJP02oookJP03ool0nOoonf[o07Oo00?ooo]Z00Go
0?nJoom/0?ooP@3ooo]Zoc_o0005oookJP03o`3koooonf[ooo]Z00?ooo]Z00Coo`<0oookJ_oonf[o
o`3M0_oonfX00ol0Xooo0?l<oookJP06oookJP03ool0QooMo`3ooo]Z00;ooo]Z00Soo`1/oookJ_oo
nf[oC@3oool^0?oonf[oH@3oo`3oA@?ooo]Z00?ohP3oonGo0?oUo`001?oUo`000ol0oi;ooo]Zoook
JP05oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Co603ooookJ_l0M?ooi_l00_oonfX2oon@00[ooo]Z
0ooUo`001?oo_P3ooo]Zon/0ooo[0?l:oookJP03oomG0?oonf[ooo]Z00Kooo]Z00?oo`0]oookJ_oo
nfX02OoonfX8ooo902?ooo]Z1?ooP@0;oookJP03ool0;Ooonf[ooo]Z00?ooo]Z0_ooE`04oookJP;o
L03o0_o[0?l2oonn0003o`000?oonf[ooo]Z00?ooo]Z00GoolT0oookJ_oVo`3oi_l0oaP0o`03oook
JP;oolT01?oonfX00ol0oi;ooo]Zon80o`02oookJP08o`3oAOmQ0?oooo]Zodd0oooonf[oiOl0ool0
Qol0omh3oookJP05odCo0?l0Xooooo]Zool0gOoo0`000ooonfX03Ol0nooooo]Zoc_o0?ooP@3o0?o<
oom/0?l0Moooo`3ioookJ_nX0?oo0:KooookJ_o[o`000_oonfX01OoUo`3ooo]ZoookJ_oonf[oo`3l
00;ooo]Z00?ooi80oolF0?oonfX00_oonfX6onGo00[ooo]Z00?o07?ooookJ_oonfX02OoonfX01?oU
o`3o0?l<oookJ_l0:_l2oookJP03onGo0?oonf[o0=co00;oiOl01ooonfX00ol0oa_ooo]Zooo:0004
oookJP03ool0Tooonf[oo`0C00Gooo]Z00KoiOl0oookJ_oonf[ooo]ZobH0oon40?l@oookJP04onGo
0?oonf[ooo]Zo`3oF`;ooo]Z00GoP_l0oookJ_oonf[o033oo`3oC@04onGo0003oookJ_nBo`3ooo]Z
00?ooo]Z00?o403ooookJ_oonfX00_oonfX00ooUo`3oU?l0oookJP07odCo00Gooo]Z00So0?mCoook
J_oonf[ooo]Zo`3o2?oonf[o0?lMo`3QoeGooo]Z00?o0:KooookJ_nX0?l00ooonfX00ooo0?Wo07Oo
oookJP02oookJP05o`3oV_ooK03ooo]Zoon10?lko`001OoonfX00ol0nooooo]ZoookJP03oookJP09
ool30?oonf[ooo]ZogT0oooo0=gooo]Zo`2Soooonf[o/ol000Oooo]Z00Goo`27oookJ_oonf[ooo]Z
ool0K003oookJP04odd0oooo;P3ooo]Zof40o`Cooo]Z00?ohP3ooookJ_l0oi000ooonfX00ol0oi;o
oo]ZoookJP06oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603oo`1doooVo`000_oonfX2oon@00go
oo]Z00?ookh0oookJ_oonfX00_o[0?l9oookJP03oomG0?oonf[ooo]Z00Kooo]Z0_oo02d>oookJP;o
oh409OoonfX4oon100_ooo]Z00?oo`0]oookJ_oonfX01?oonfX2oomG00Cooo]Z00CoL03oon/0ooo[
0?oo00000_oo_P05oookJP06oon@0?oonf[ooo]ZonKo0?l0M?oo603o0ooonfX00omX0?oooo]Zoook
JP02oookJP0=o`3oT_oonf[o0?n@on80oooonf[o0?m5of40oooo;P3oC@3ooookJ_oo06cooo]Zool0
Q`03oookJP06ok?o0?nO0?oo0:?oool0gOoonf[oo`<00ooonfX01ol0nooo>ol0oon10?oonf[oof`0
o`1goooo0?T00_oonfX01onX0?oo0:Koool0m_o[o`3ooo]Zool60?lH0?l00ooonfX01Ooo0?cooo]Z
oookJ_ooTP3ooaH000Cooo]Z00?oo`3ZoookJ_oonfX03?oonfX00ol0Looooo]ZoookJP08oookJP05
okWo0?ooDP3ooo]ZoookJ_l0:_l00_oonfX01Oloo`3ooo]Zo`3Lool0omooN?l000Kooo]Z00?o4P3o
o`3o6ooobP001?oonfX00ooo09?ooo]Zool04`05oookJP07on7o0?oJo`3ooo]ZoookJ_lV0?oo8?l0
oh@0o`0?oookJP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00coP_l0oookJ_oonf[o0?nao`0`ool0odgo
0>SooookJ_l60?oooo]Zool0mOnBo`03oookJP03o`0Iool@0?oooo]Z00?ooo]Z00Oo5@3oool0DOoo
nf[ooo]Zo`2]oooonf[oo`1i00Sooo]Z00So0?mCoookJ_oonf[ooo]Zo`3o2?l0oagooo]Zo`3Qobco
oo]Z000/oookJP03o`2VoonX0?oooo]Z00?ooo]Z00?oo`3io`1goooonfX00ooonfX01OooK03ooh40
o`3oc?oonf[o>ol000Cooo]Z00?o0?_ooookJ_oonfX00ooonfX02Ooo0`3ooo]ZoookJ_oo0=goN@3o
oookJ_l0Xooo0?l<oil0o`06oookJP03ool0QooMo`3ooo]Z00;ooo]Z00Soo`1/oookJ_oonf[ooo]Z
odd0oooo;P3ooo]Zof40o`;oiOl00_oonfX00ooR0?ooiOl0onGo0004onGo00Sooo]Z00?oJ03ooook
J_oonfX00_oonfX2o`3o3003oookJ_oVo`3ooo]Z00;ooo]Z00?ooi00oookJ_oonfX02?oonfX00ooU
o`3ooo]Zoonn0002oookJP03onGo0?o[0?ooL03o00Wooo]Z00?ooeL0oookJ_oonfX01_oonfX00ooo
02gooo]ZoookJP09oookJPSoolT07_oonfX4oon100gooo]Z0_oo02d4oookJP;ooeL01OoonfX00om`
0?ooj`3oon/0o`02oonn00?o00001?oonfX01Ooob@3ooo]ZonKo0?oonf[o603o00?ooo]Z00?oolT0
oookJ_oonfX00ooonfX00ol0oi;ohP3oon80o`03oookJP07of40oooonf[oC@3ooookJ_oUo`3ooo]Z
ool0Q`03oookJP05odCo0?l0Xooooo]Zool0gOoo0`000ooonfX02?l0nooooo]Zoc_o0?ooP@3o0?o<
oom/0?oonf[o07Oo0_oonfX01onX0?oooo]Zo`3oGOo[o`3ooo]ZonGo0?lH0?l00ooonfX01?oo0?co
oo]ZoookJ_ooTP04oookJPGoiOl02ooonfX00ol0Looooo]ZoookJP04oookJP;oiOl00_oonfX01OoU
o`3o0?l<oookJ_oonf[o02[o00;ooo]Z00CoiOl0oookJ_l0g?ooiOl01ooonfX01?l0oa_ooo]Zoook
J_oobP03oookJP04ool0Tol0nOoooo]Zool04`Gooo]Z00Gof_l0oookJ_oonf[o9P3oob3o000Aoook
JP04onGo0?oonf[ooo]Zo`3oF`;ooo]Z00GoP_l0oookJ_oUo`3oiOl0o`3oC@03onGo00;ooo]Z00Ko
T_l0oookJ_oonf[ooo]Zool0J_l@0?l4oookJP03onGo0?nDo`3ooo]Z00SoA?l01?oonfX02?l0oe?o
oo]ZoookJ_oonf[o0?l8oookJ_l0oago0>7oE_oonfX00ol0Y_ooZ03ooookJP02oookJP03ool0nOl0
Mooooo]Z00?ooo]Z00Go0?nJoom/0?ooP@3o0?o<oc_o0004oookJP03o`3koooonf[ooo]Z00?ooo]Z
00[oo`<0oookJ_oonf[ooo]Zool0gOoonf[o0:?oo`0Goonco`3oW`3o1_oonfX01Ooo08Oooo]Zoook
J_oonf[oo`1/00?ooo]Z00GoC@3ooookJ_oo;P3oH@3oo`3oA@04oookJP03on80oooonf[o0?n@00;o
oo]Z00?o0?nBoookJ_oonfX01_oonfX00omX0?oooo]ZoookJP03oookJP03oaP0oooonf[oi_l000?o
oo]Z00?ooi00oookJ_oonfX02_oonfX01_oo_P3ooo]ZoookJ_l0o`GoL03oon/0o`Wooo]Z00?ooeL0
oookJ_oonfX01ooonfX00ooo02gooo]ZoookJP0=oookJP?ooh407_oonfX4oon100gooo]Z0_oo02d5
oookJP;ooeL01?oonfX01?m`0?ooj`3oon/0oooonfX2oonn00;o00001?oonfX01_ooT03ooo]Zoook
J_oVo`3o07CooaP0o`?ooo]Z00?oJ03ooookJ_oonfX00_oonfX01?l0oi;ooo]Zon80oooR0?l2oook
JP07of40oooo;P3oC@3ooookJ_oo06cooo]Zool0Q`04oookJP05ok?o0?l0Xoooo`3MoookJ_oo0`00
0ooonfX01ol0nooo>ol0oookJ_ooP@3oof`0oookJ_l0Mol00_oonfX01onX0?oo0:KooookJ_o[o`3o
oo]Zool60?lH0?l01?oonfX01?oo0?cooo]ZoonB0?oo5P05oookJP03ool0j_oonf[ooo]Z00_ooo]Z
00?o07?ooookJ_oonfX02?oonfX00onio`3ooe80o`3o<`02oookJP03o`0Zoooonf[o?ol000;ooo]Z
00?o?@3oogSo0?oonfX01OoonfX01?l0S_oo0?lKoookJ_oobP04oookJP03ool0Tooonf[oo`0C00Go
oo]Z00KohOl0om[o0?oonf[o9P3ooookJ_lPo`0@oookJP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00So
P_l0oookJ_l0ok7ooo]Zo`3oCOl0j?oooo]Zo`H0o`;ooo]Z00Ooo`3eoi;o0?oonf[ooo]Zool0J_l0
6Ooo403o00?ooo]Z00?o5@3oool0DOoonfX00_oonfX00ol0[Ooooo]Zool0N@07oookJP03o`3oDooo
nf[ooo]Z00;ooo]Z00Co0?l8o`3o7Ooonf[o0>7o;?oonfX002gooo]Z00?o0:KoojP0oooonfX00_oo
nfX00ooo0?Wooo]Zo`1go`03oookJP05o`3oV_ooK03ooh40oookJ_lko`001OoonfX00ol0nooooo]Z
oookJP03oookJP04ool30?oonf[ooo]Zool0g@;ooo]Z00?o0:?oo`3o3?oonfX01_oonfX00ooo08Oo
oo]ZoookJP02oookJP07ool0K?oonf[ooo]Zodd0oooo;P3ooo]Zof40o`03onGo0003oookJ_oR0?oo
iOl000KoiOl01ooonfX00omX0?oooo]ZoookJP02oookJP?o0?l<00?oi_l0oookJ_oonfX00_oonfX0
0oooT03ooo]ZoookJP0:oookJP04oonn0?oonf[ooo]ZonGo00;oj`3o2OoonfX00oooE`3ooo]Zoook
JP06oookJP;oo`0]2ooonfX4ooo900;ooo]Z0_oob@0IoookJP?ooh403ooonfX2ool0;@Cooo]Z0_oo
E`05oookJP;oL03o00Coj`3ooookJ_oo_P3ooo]Z1?l00002oookJP;oolT000Cooo]ZonKo0?l0M?oo
603o0_oonfX00omX0?ooolT0oookJP04oookJP03o`3oT_oR0?oo0?n@00?ooo]Z00GoH@3ooookJ_m=
0?oooo]ZonGo0002odCo00?ooo]Z00GoA?l0o`2Sool05oooo`3Mool30003oookJP0>o`3koooonf[o
>ol0oon10?l0olcoof`0o`3oV_l0Moooo`3ioookJ_nX0?oo0:Koo`3oGOo[o`02oookJP05onGo0?oo
nf[ooo]ZoookJ_oo0?`00_oonfX00oooTP3ooo]ZoookJP03oookJPCoiOl02ooonfX00ol0Looooo]Z
oookJP05oookJPCoiOl000Co0?l<o`3o<ooonf[o02[o0_oonfX00ooUo`3ooo]Zo`3Lo`02onGo00Oo
oo]Z00?o0?lKoookJ_oobP001?oonfX00ooo09?o0?Woool04`05oookJP06om[o0?oonf[ooo]Zoook
J_lV0?oo8?l03?oonfX3onGo0003oookJ_oUo`3ooo]Z00;ooo]Z00Oo0?mKoookJ_n2o`3o0?n`oook
J_l0<?oo0?m=00CoiOl000?ooo]Zoi;o0?oonfX00ooonfX00ol@0?oooo]ZoookJP03oookJP03oiCo
0?oonf[ooo]Z00SoA?l00ooonfX01Ol0oe?ooo]ZoookJ_oonf[o0?l800;ooo]Z00?o0?lMoookJ_oo
nfX0EOoonfX00ol0Y_oooo]ZojP0o`03oookJP03ool0nOl0Mooooo]Z00;ooo]Z00Go0?nJoom/0?oo
nf[ooh40oc_o0005oookJP03o`3koooonf[ooo]Z00?ooo]Z00Woo`<0oookJ_oonf[oN@3oool0gOoo
nf[o0:?ooookJ_nco`001_oonfX00ooMo`3oo`27oookJP02oookJP08ool0K?oonf[ooo]ZoookJ_m=
0?ooobh0oookJ_mQ0?l4oookJP03on80oooonf[o0?n@00?ooo]Z00?o0?nBoookJ_oonfX01_oonfX0
0omX0?oooo]ZoookJP02oookJP03oaP0ool0M?ooi_l000Cooo]Z00?ooi00oookJ_oonfX02_oonfX0
1Ooo_P3ooo]ZoookJ_l0o`Gooo]Z00;oj`3o2?oonfX00oooE`3ooo]ZoookJP07oookJP;oo`0]4?oo
nfX2oon101Wooo]Z0oooP@0?oookJP;oo`0]1OoonfX2oomG00Gooo]Z00GoL03oon/0oooonf[ooo]Z
oonn0004o`0000;ooo]Z0_ooT0001Ooonf[oi_l0onKo0?l0M?oo603o00;ooo]Z0_mX0?l4oookJP03
o`3oT_oonf[ohP3o00?ooo]Z00OoH@3oool^0?m=0?oooo]Zool0K?oonf[oo`2700Cooo]Z00Go/ol0
o`2Soooo0=gooo]Zool30003oookJP08o`3koolko`3ooo]Zoon10?ooK03o0?nJo`1goooo0?T2oook
JP07ojP0ool0Y_ooo`3fon_o0?oonf[oo`H0oaP0o`03oookJP04ool0o?oonf[ooo]ZoonB00Gooo]Z
00?oo`3ZoookJ_oonfX03?oonfX00ol0Looooo]ZoookJP08oookJP07okWo0?ooDP3ooo]ZoookJ_l0
:_oooo]Zocoo0002oookJP03o`3Lool0omooN?l000Kooo]Z00?o0?lKoookJ_oobP001?oonfX00ooo
09?o0?Woool04`05oookJP07on7o0?oJo`3ooo]ZoookJ_lV0?oo8?l0oh@0o`0@oookJP0>oc7o0?oo
nf[ooo]Zo`3oFooonf[oP_l0o`3o/?oonf[o0?nao`0`ool0odgo0>SooookJ_l60?l2oookJP06oi;o
0?oonf[ooo]ZoookJ_oo06[o403o1?oonfX01OlE0?ooo`1AoookJ_oonf[o0:go00;ooo]Z00?oo`1i
oookJ_oonfX01OoonfX02?l0oe?ooo]ZoookJ_oonf[o0?l8oookJ_l0oago0>7o;OoonfX002gooo]Z
00?o0:KoojP0oooonfX00_oonfX00ooo0?Wooo]Zo`1go`03oookJP03o`3oV_ooK03ooh4000;ooo]Z
00?o>ol0oookJ_oonfX00_oonfX00ol0nooooo]ZoookJP03oookJP09ool30?oonf[ooo]Zool0gOmi
0?oooo]Zo`2Sool0o`coW`3o00Kooo]Z00?oo`27omgo0?oonfX00_oonfX02?oo06cooo]ZoookJ_oo
nf[oC@3oool^0?oonf[oH@3o0ooUo`000ooonf[ohP3oonGo0006onGo00Oooo]Z00?oJ03ooookJ_oo
nfX00_oonfX4o`3o30Cooo]Z00?ooi00oookJ_oonfX02_oonfX01ooo_P3ooo]ZoookJ_oUo`3ooo]Z
on/0oom`0?l02?oonfX00oooE`3ooo]ZoookJP07oookJP03ool0;Ooonf[ooo]Z00Wooo]Z0ooob@04
oookJP03ooo90?ooP@3ooh4000Sooh402_oonfX4oon100oooo]Z0ooo02d4oookJP;ooeL01_oonfX0
0om`0?ooj`3oon/0o`02oonn00;ooo]Z00KoolT0o`000?l0003o0000oookJ_oob@02oookJP03onKo
0?lH0?oo603o00;ooo]Z00?oJ03ooookJ_oonfX00ooonfX2o`3oTP0;on80ool0oi3ooo]ZonGo0?oo
nf[oH@3ooookJ_m=0?oooo]ZonGo0?oonfX00om4o`001ooonf[oA?l0o`2Sool05oooo`3MoookJ_oo
0`000ooonfX04Ol0nooooo]Zoc_o0?ooP@3oof`0o`3oV_l0Moooo`3ioookJ_nX0?oo0:KooookJ_l0
oegojol0oookJ_oUo`3o603o00?ooo]Z00Coo`3loookJ_oonf[ooi801OoonfX3onGo00cooo]Z00?o
07?ooookJ_oonfX01OoonfX4onGo0004o`3o3?oUo`3ooo]Zo`0Zo`?oiOl000?ooo]Zo`3LoooUo`00
1ooonfX01?l0oa_o4P3ooookJ_oobP04oookJP03ool0Tooonf[oo`0C00Gooo]Z00Gof_l0oookJ_oo
nf[ooo]ZobH0o`0=oookJPKoiOl000Wooo]Zo`3oFooonf[ooo]Zoh;o0?oonf[oiOl0o`0`ool0odd0
0ooUo`02oookJP03oi;o0?oonf[ooo]Z00;ooo]Z00?o403ooookJ_oonfX00ooonfX00onDo`3ooo]Z
oookJP07odCo00Cooo]Z00Go0?mCoookJ_oonf[ooo]Zo`3o2002oookJP03o`3o7Ooonf[ooo]Z05Go
oo]Z00?o0:KooookJ_nX0?l00ooonfX00ooo0?Wo07OooookJP02oookJP06o`3oV_ooK03ooo]Zoon1
0?oonf[o>ol01?oonfX00ol0nooooo]ZoookJP03oookJP0:ool30?oonf[ooo]ZoookJ_oo0=gooo]Z
o`2Sool05ooo/ol0oil0o`Kooo]Z00?oo`27oookJ_oonfX00_oonfX02?oo06cooo]ZoookJ_m=0?oo
oo]Zool^0?oonf[oH@3o1?oonfX00ooR0?oooo]Zo`3oT003oookJP03o`3oT_oonf[ooo]Z00Kooo]Z
00?oJ03ooookJ_oonfX00_oonfX00olH0?oo07CoonKo0004oookJP03oon@0?oonf[ooo]Z00[ooo]Z
00Oookh0oookJ_oonf[o0?l5oookJ_m`0?ooj`3o00Sooo]Z00?ooeL0oookJ_oonfX02?oonfX00ooo
02gooo]ZoookJP0?oookJP_ooh402_oonfX4oon100oooo]Z0ooo02d5oookJP;ooeL01OoonfX01?m`
0?ooj`3oon/0oooonfX2oonn0003oookJ_l0003o000000;o000000Kooo]Zoon@0?oonf[ooo]ZonKo
0?l0M?l2oaP0o`;ooo]Z00?oJ03ooookJ_oonfX00_oonfX2o`3oTP03oookJ_oR0?oooo]Z00;ooo]Z
00So0?m5of40oom=0?oooo]Zool0K?oonf[oo`27omgo00?ooo]Z00Go/ol0o`2Soooo0=gooo]Zool3
0004oookJP07o`3koolko`3ooh40oom/0?l0oi[o07Ooool0n@02oookJP07ojP0ool0Y_ooo`3fon_o
0?oonf[oo`H0oaP0o`04oookJP04ool0o?oonf[ooi80oolF00Gooo]Z00?oo`3ZoookJ_oonfX02ooo
nfX00ol0Looooo]ZoookJP08oookJP03okWo0?oonf[ooe8000;ooo]Z00Oo02[ooookJ_loo`3ooo]Z
o`3Loolm0?ooN?l000Kooo]Z00Co08koo`3o6ooonf[oolX01?oonfX00ooo09?ooo]Zool04`05oook
JP06on7o0?oJo`3ooo]ZoookJ_lV0?oo8?l04?oonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP0<oh;o
0?oonf[o0?naoookJ_l0<?oo0?m=o`3Xoooonf[o1P3ooookJ_oo0?GoT_l00ooonfX00ol06Ooo403o
oookJP03oookJP07oaD0oooo057ooo]ZoookJ_l0[Ooooo]Zool0N@08oookJP08o`3oDooonf[ooo]Z
oookJ_l0o`Sooo]Zo`3o7Ol0hOl]oookJP00;OoonfX00ol0Y_oooo]ZojP0o`02oookJP03ool0nOoo
nf[o07Oo00Cooo]Z00Goof`0oon10?l0olcooo]Zoc_o0004oookJP03o`3koooonf[ooo]Z00?ooo]Z
00Woo`<0oookJ_oonf[oo`3MogT0oooonf[o0:?oo`3o3?nO0?l01_oonfX00ooo08Oo0?oNoookJP03
oookJP05ool0K?oonf[ooo]Zodd0oooo;P000_oonfX01_mQ0?ooiOl0onGo0?oUo`3ooo]Zon80o`Oo
iOl01_oonfX00omX0?oooo]ZoookJP02oookJPKo0?l<0ooonfX00oooT03ooo]ZoookJP0:oookJP;o
iOl000?ooo]ZonGo0?oonfX00_o[0?l8oookJP03oomG0?oonf[ooo]Z00Oooo]Z00?oo`0]oookJ_oo
nfX02OoonfX00ooob@3ooo]ZoookJP0>oookJP[ooh404?oonfX3ool0;@Gooo]Z0_ooE`06oookJP03
og00ooo[0?ooj`3o00;ookh01?oonfX01Ooob@3o0000o`000?l0003oolT000;ooo]Z00?oi_l0oaP0
oooonfX00_oonfX00omX0?oooo]ZoookJP03oookJP04o`3oT_oonf[ohP3oo`3oT0;ooo]Z00OoiOl0
of40oooonf[oC@3ooookJ_oUo`3ooo]Z00KoA?l000Co0:?oool0gOmi0?ooo`<00ooonfX04Ol0nooo
oo]Zoc_o0?ooP@3ooo]Zoom/0?l0Moooo`3ioookJ_nX0?oooo]Zo`2Vool0oegojol0oookJ_oUo`3o
603o00?ooo]Z00Coo`3loookJ_oonf[ooi801OoonfX3onGo00cooo]Z00?o07?ooookJ_oonfX01Ooo
nfX4onGo0005o`3o3?l0oc?oiOl0o`0ZoooonfX01OoUo`000ol0omoooo]ZoookJP05oookJP03o`3o
6ooonf[oolX000Cooo]Z00?oo`2Co`3ioooo01<01OoonfX01_oJo`3ooo]ZoookJ_oonf[o9P3oob3o
00gooo]Z2?oUo`02oookJP05oh;o0?oonf[o033ooookJ_l0odd00ooUo`000ooonf[oo`3eoi;o0003
oookJP03oa00oooUo`3ooo]Z00?ooo]Z00CoiOl0oiCo0?oonf[ooo]Z1_m4o`05oookJP08o`3oDooo
nf[ooo]ZoookJ_l0o`Sooo]Zo`3o7Ol0hOmHoookJP03o`2Voooonf[oZ03o00;ooo]Z00?oo`3io`1g
oooonfX00ooonfX01Ol0oi[oof`0oon10?l0olco>ol000Cooo]Z00?o0?_ooookJ_oonfX00ooonfX0
2_oo0`3ooo]ZoookJ_oonf[oo`3MoookJ_l0Xooo01Oook?o0?nO0?l6oookJP03ool0Qol0omkooo]Z
00;ooo]Z00Woo`1/oookJ_oonf[ooo]Zodd0oooo;P3ooo]Zof40ool0odD01?oonfX00ooR0?oooo]Z
o`3oT002oookJP03o`3oT_oonf[ooo]Z00Kooo]Z00?oJ03ooookJ_oonfX00ooonfX00olH0?oo07Co
onKo0004oookJP03oon@0?oonf[ooo]Z00[ooo]Z0_oo_P001?oonf[o0?l5oookJ_oonfX2on/0o`Oo
oo]Z00?ooeL0oookJ_oonfX02?oonfX00ooo02gooo]ZoookJP0IoookJP[ooh404?oonfX3ool0;@Go
oo]Z0oooE`05oookJP04og00ooo[0?ooj`3ooookJP;ookh00ooonfX4o`000006oon@0?oonf[ooo]Z
onKo0?l0M?oo603o0ooonfX00omX0?oooo]ZoookJP02oookJP04o`3oT_oonf[ooo]Zon80o`?ooo]Z
00So0?m5of40oom=0?oooo]Zool0K?oonf[oo`27omgo00?ooo]Z00Ko/ol0o`2Soooo0=goN@3ooook
J_oo0`03oookJP07o`3koolko`3ooo]Zoon10?ooK03o07Ooool0n@02oookJP07ojP0ool0Y_oooo]Z
on_o0?oonf[oo`H0oaP0o`04oookJP04ool0o?oonf[ooi80oolF00Gooo]Z00?oo`3ZoookJ_oonfX0
3?oonfX00ol0Looooo]ZoookJP08oookJP07okWo0?ooDP3ooo]ZoookJ_l0:_oooo]Zocoo0002oook
JP03o`3Loomho`3ooo]Z00Kooo]Z00?o0?lKoa80oooobP001OoonfX00ooo09?oo`0CoookJP04oook
JP07on7o0?oJo`3ooo]ZoookJ_lV0?oo8?l0oh@0o`0@oookJP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z
00SoP_l0oookJ_l0ok7o033oo`3oCOl0j?oooo]Zo`H0o`;ooo]Z00KoT_l0oookJ_oonf[ooo]Zool0
J_l@0?l4oookJP03oaD0oooo057ooo]Z00;ooo]Z00?o0:gooookJ_oo07T01ooonfX00ol0oe?ooo]Z
oookJP02oookJP04o`3o2?l0oagooo]Zo`3Qobgooo]Z000^oookJP05o`2VoonX0?oooo]ZoookJ_oo
0?T00_oonfX01ol0Mooooo]ZoookJ_oonf[o0?nJoom/0?ooP@000_oonfX01Olko`3ooo]ZoookJ_oo
nf[o0?_o00Kooo]Z00Woo`<0oookJ_oonf[oo`3MogT0oooonf[o0:?oo`3o3?nO0?l01_oonfX00ooo
08OogOl0oookJP02oookJP08ool0K?oonf[ooo]ZoookJ_m=0?ooobh0oookJ_mQ0?l5onGo0003on80
oooUo`3oiOl000;oiOl000?ooo]Zo`3oT_oonfX01_oonfX00omX0?oooo]ZoookJP02oookJPKo0?l<
0ooonfX00oooT03ooo]ZoookJP09oookJPGoiOl00_oonfX00oo[0?ooL03ooookJP06oookJP03oomG
0?oonf[ooo]Z00Oooo]Z0ooo02d`oookJP?oo`0]1_oonfX2oomG00Kooo]Z00?oL03oon/0ooo[0?l0
0_oo_P05oookJPGoolT000Cooo]ZonKo0?oVo`3o603o0_oonfX2ofP0o`Gooo]Z00Co0?nBoookJ_oR
0?oo0?n@0_oonfX3onGo0005odd0oooonf[oiOl0oookJ_oo08L01_m4o`000ooo0=goN@3oool30003
oookJP0Ao`3koooonf[o>ol0oon10?oonf[oof`0o`3oV_l0Moooo`3iojP0oooonf[o0:KooookJ_o[
o`3ooo]ZonGo0?lH0?l01?oonfX01?oo0?cooo]ZoonB0?oo5P05oookJP;oiOl03OoonfX00ol0Looo
oo]ZoookJP05oookJPCoiOl000Go0?l<onGo0?oUo`3o02[ooookJP07onGo00Gooo]Z00Co0?lKoa80
oooonf[oolX01?oonfX00ooo09?o0?Woool04`05oookJP06om[o0?oonf[ooo]ZoookJ_lV0?ooQ03o
3OoonfX8onGo0006oookJ_n2o`3ooo]ZonGo0?l0<?oo0?m=0ooUo`02oookJP03oi;o0?oonf[ooo]Z
00;ooo]Z00?o403ooookJ_oonfX00ooonfX01?nDo`3ooo]ZoookJ_oonfX6odCo00Cooo]Z00Go0?mC
oookJ_oonf[ooo]Zo`3o2002oookJP03o`3o7Ol0hOoooo]Z05Oooo]Z00?o0:KooookJ_nX0?l00_oo
nfX00ooo0?Wooo]Zo`1go`03oookJP06o`3oV_ooK03ooo]Zoon10?oonf[o>ol01?oonfX00ol0nooo
oo]ZoookJP03oookJP0:ool30?oonf[ooo]ZoookJ_oo0=gooo]Zo`2Sool05ooo/ol0oil0o`Kooo]Z
00?oo`27oookJ_oonfX00_oonfX02?oo06cooo]ZoookJ_m=0?oooo]Zool^0?oonf[oH@3o1OoonfX0
0ooR0?oo0?n@oookJP02oookJP03o`3oT_oonf[ooo]Z00Kooo]Z00?oJ03ooookJ_oonfX00ooonfX0
0olH0?ooi_l0oookJP04oookJP03oon@0?oonf[ooo]Z00_ooo]Z00?ookh0oookJ_l0o`D00_oonfX0
0om`0?ooj`3ooookJP06oookJP03oomG0?oonf[ooo]Z00Sooo]Z0ooo02d_oookJP?oo`0]1_oonfX2
oomG00Oooo]Z0_o[0?l00ooonf[ookh0oonn0005oookJP;o00000_ooT002oookJP03onKo0?lH0?oo
603o00;ooo]Z0_mX0?l4oookJP04o`3oT_oonf[o0?n@on80o`;ooo]Z0_l0odD01?mQ0?ooC@3ooook
J_oo06`2oookJP0:ool0Qooonf[ooo]ZoookJ_nco`3o0:?oool0gOmi0?oooo]Zool300?ooo]Z017o
0?_ooc_o0?oonf[ooh40oom/0?l0oi[o07Ooool0nOoonf[oZ03ooookJ_l0Y_ooo`3fon_o0?oo1P3o
oo]ZoaP0o`04oookJP04ool0o?oonf[ooi80oolF00Gooo]Z00?oo`3ZoookJ_oonfX02ooonfX00ol0
Looooo]ZoookJP08oookJP03okWo0?oonf[ooe8000;ooo]Z00Oo02[ooookJ_loo`3ooo]Zo`3Loolm
0?ooN?l000Kooo]Z00Co08koo`3o6ooonf[oolX01?oonfX00ooo09?o0?Woool04`05oookJP07on7o
0?oJo`3ooo]ZoookJ_lV0?oo8?l0oh@0o`0@oookJP06oc7o0?oonf[ooo]Zo`3oFooonf[oP_l00_oo
nfX02Ol0ok7o033oo`3oCOl0j?oooo]Zo`H0oooonf[oo`3eoi;o0003oookJP03ool0J_l@0?oooo]Z
00?ooo]Z00Go5@3oool0DOoonf[ooo]Zo`2]o`02oookJP03ool0NOoonf[ooo]Z00Gooo]Z00Wo0?mC
oookJ_oonf[ooo]Zo`3o2?oonf[o0?lMoookJ_l0hOl0;OoonfX002kooo]Z00?o0:KooookJ_nX0?l0
0_oonfX00ooo0?Wooo]Zo`1go`03oookJP03o`3oV_ooK03ooh4000;ooo]Z00?o>ol0oookJ_oonfX0
0_oonfX00ol0nooooo]ZoookJP03oookJP09ool30?oonf[ooo]Zool0gOmi0?oooo]ZoiCo0?l0o`co
W`3o00Kooo]Z00?oo`27omgo0?oonfX00ooonfX01Ooo06cooo]ZoookJ_m=0?ooobh000;ooo]Z00?o
H@3oonGo0?oUo`000_oUo`001?oR0?ooiOl0onGo0?oUo`03oookJP03o`3oT_oonf[ooo]Z00Gooo]Z
00?oJ03ooookJ_oonfX00_oonfX7o`3o30;ooo]Z00?ooi00oookJ_oonfX02OoonfX7onGo00;oj`3o
1ooonfX2oomG00[ooo]Z1?oo02dYoookJP?oo`0]1ooonfX2oomG00Oooo]Z00CoL03oon/0ool0o`Go
okh01_oonfX5ooo90004o`000?oVo`3o603ooaP0o`;ooo]Z00?oJ03ooookJ_oonfX01?oonfX00ol0
oi;ooo]Zon80o`03oookJP03o`3oAOoUo`3oiOl000?oiOl000?ooo]Zool0Qom4o`001om4o`005_oo
0`3ooo]ZoookJ_oonf[o0?_ooookJ_lko`3ooo]Zoon10?ooK03o0?nJo`1goooo0?Wo0?mMojP0ool0
Y_oooo]Zo`3oGOo[o`3ooo]ZonGo0?lH0?l3oookJP04ool0o?oonf[ooo]ZoonB00Kooo]Z00?oiOl0
oookJ_oonfX02ooonfX00ol0Looooo]ZoookJP06oookJP?oiOl000Co0?l<o`3o<ooUo`3o02[o0_oo
nfX4onGo0004o`3ogooUo`3oiOl0onGo00Cooo]Z00?o0?lKoookJ_oobP001?oonfX00ooo09?o0?Wo
ool04`05oookJP06om[o0?oQo`3ooo]ZoookJ_lV0?oo8?l03_oonfX7onGo00;ooo]Z00GoP_l0oook
J_l0<?oooo]Zo`3oC@02onGo0004o`H0oooonf[ooo]Zoi;o00Cooo]Z00?o403ooookJ_oonfX00ooo
nfX01?nDo`3ooo]ZoookJ_oonfX5odCo00Gooo]Z00Go0?mCoookJ_oonf[ooo]Zo`3o2002oookJP03
o`3o7Ooonf[ooo]Z05Oooo]Z00?o0:KooookJ_nX0?l00ooonfX00ooo0?Wo07OooookJP02oookJP06
o`3oV_oonf[oof`0oon10?oonf[o>ol01?oonfX00ol0nooooo]ZoookJP03oookJP0:ool30?oonf[o
oo]ZoookJ_oo0=gooo]Zo`2Sool05ooo/ol0oil0o`Kooo]Z00?oo`27oookJ_oonfX00_oonfX02Ooo
06cooo]ZoookJ_oonf[oC@3oool^0?oonf[oH@3oo`3oA@04oookJP03on80oooonf[o0?n@00?ooo]Z
00?o0?nBoookJ_oonfX01OoonfX00omX0?oooo]ZoookJP04oookJP03oaP0oooVo`3ooo]Z00Cooo]Z
00?ooi00oookJ_oonfX02ooonfX2oonn00;o0?l50_oonfX2on/0o`Kooo]Z0_ooE`0;oookJPCoo`0]
:?oonfX3ool0;@Oooo]Z0_ooE`07oookJP05og00ooo[0?oo0?l5oookJ_oo_P001ooonfX00ol0003o
oi00o`000002o`000003onKo0?lH0?oooo]Z00;ooo]Z00?oJ03ooookJ_oonfX00ooonfX01?l0oi;o
oo]Zo`3oT?oR0?l2oookJP06o`3oAOoonf[oH@3oodd0oooonf[oo`1/0_oonfX02_oo08Oooo]Zoook
J_oonf[o/ol0o`2Sool05oooo`3MoookJ_oo0`03oookJP0Ao`3koolko`3ooo]Zoon10?ooK03o0?nJ
o`1goooo0?Wooo]ZojP0oooonf[o0:Koool0m_o[o`3ooo]Zool60?lH0?l01?oonfX01?oo0?cooo]Z
oonB0?oo5P05oookJP03ool0j_oonf[ooo]Z00cooo]Z00?o07?ooookJ_oonfX02?oonfX01onio`3o
oe80oookJ_oonf[o02[ooookJ_loo`000_oonfX00ol0g?ooN?l0oookJP06oookJP03o`3o6olB0?oo
olX000Gooo]Z00?oo`2Cool04ooonfX01OoonfX01_oJo`3ooo]ZoookJ_lV0?oo8?l0oh@0oa3ooo]Z
00Co<Ol0oookJ_oonf[o0?mK0_oonfX02on2o`3ooo]Zo`3o/Ol0<?oo0?m=oookJ_l0j?oooo]Zo`H0
oooonf[oT_l000Cooo]Z00?o01Wooa00oooonfX00ooonfX01ooo057ooo]ZoookJ_oonf[o0:gooook
J_oo07T02?oonfX02?l0oe?ooo]ZoookJ_oonf[o0?l8oookJ_l0oago0>7o;_oonfX002[ooo]Z00Oo
o`3foookJ_oonf[ooo]Zo`2Voooonf[oZ03o00;ooo]Z00Coo`3ioookJ_oonf[o07Oo0ooonfX00ooo
K03ooo]Zoon10002oookJP05oc_o0?oonf[ooo]ZoookJ_l0nol01_oonfX02Ooo0`3ooo]Zool0gOoo
nf[oN@3ooiCo0?l0o`co01Oooil0o`05oookJP03ool0Qol0omkooo]Z00?ooo]Z00Soo`1/oookJ_oo
nf[ooo]Zodd0oooo;P3ooo]Zof40o`GoiOl000?ohP3ooookJ_oUo`000ooonfX00ol0oi;ooo]Zoook
JP05oookJP03ofP0oooonf[ooo]Z00;ooo]Z2Ol0o``00ooonf[ooi00oookJP0:oookJPSoiOl000?o
j`3oog00oooonfX01_oonfX3oomG00_ooo]Z1?oo02dRoookJP?oo`0]2?oonfX2oomG00Oooo]Z00?o
L03oon/0ooo[0?l00_oo_P06oookJPKoolT000?oi_l0oaP0oooonfX00_oonfX00omX0?oooo]Zoook
JP04oookJP03o`3oT_oonf[ohP3o00?ooo]Z00?o0?m5onGo0?oUo`001?oUo`000ooMo`3oo`27odCo
0008odCo00;ooo]Z01;o0?_ooookJ_oonf[o>ol0oon10?ooK03o0?nJo`1goooo0?Wo0?mMojP0ool0
oego0:Koo`3oGOo[o`3ooo]ZonGo0?lH0?l3oookJP04ool0o?oonf[ooo]ZoonB00Oooo]Z00?oo`3Z
oookJ_oonfX02ooonfX00ol0Looooo]ZoookJP06oookJP?oiOl000Co0?l<onGo0?oUo`3o02[o0_oo
nfX8onGo00?ooo]Z00Co0?lKoa80oooonf[oolX01?oonfX00ooo09?o0?Woool04`05oookJP06om[o
0?oonf[ooo]ZoookJ_lV0?ooQ03o3_oonfX6onGo0008o`3oFooonf[ooo]Zoh;o0?oUo`3o033oo`3o
COoonfX2onGo0003o`H0oooonf[oT_l000Cooo]Z00?o403oonGo0?oonfX00ooonfX01?nDo`3ooo]Z
oookJ_oonfX6odCo00Cooo]Z00?o0?mCoookJ_oonfX00_oonfX01?l0o`Sooo]Zo`3o7Ol0hOmEoook
JP03ool0m_oonf[ooo]Z00;ooo]Z00?o0:KooookJ_nX0?l00_oonfX00ooo0?Wooo]Zo`1go`03oook
JP06o`3oV_ooK03ooo]Zoon10?oonf[o>ol00ooonfX00ol0nooooo]ZoookJP04oookJP0:ool30?oo
nf[ooo]Zool0gOmi0?oo0:?ooookJ_nco`3ooo]Zoil0o`Gooo]Z00?oo`27o`3og_oonfX00ooonfX0
2Ooo06cooo]ZoookJ_m=0?oooo]Zool^0?oonf[oH@3oo`3oA@04oookJP03on80oooonf[o0?n@00;o
oo]Z00?o0?nBoookJ_oonfX01_oonfX00omX0?oooo]ZoookJP04oookJP03oaP0oooVo`3ooo]Z00Co
oo]Z00?ooi00oookJ_oonfX03?oonfX01ooo_P3ooo]Zo`3o1Ol0o`Gooo]Zog00ooo[0?l01ooonfX3
oomG00cooo]Z1?oo02dQoookJP?oo`0]2?oonfX2oomG00Sooo]Z0_o[0?l00ol0o`Gookh0oonn0008
oookJP03oon@0?l0003o000000;oi_l000Go603ooookJ_oonf[ooo]ZofP0o`05oookJP04o`3oT_oo
nf[o0?n@on80o`;ooo]Z00Co0?m5oookJ_mQ0?ooC@3o0_oonfX00ooo06cogOl0ool0Q`03oookJP06
oil0oonco`3o01Ooool0gOoonf[oo`<00ooonfX02?l0nooooo]Zoc_o0?oonf[ooh40o`3oV_l0Mooo
o`3i0_oonfX01onX0?oooo]Zo`2Vooo[o`3ooo]Zool60?lH0?l01?oonfX01?oo0?cooo]ZoookJ_oo
TP06oookJP03ool0j_oonf[ooo]Z00_ooo]Z00?o07?ooookJ_oonfX02?oonfX00onio`3ooo]ZoomB
0002oookJP07o`0Zoooonf[o?ol0oookJ_l0g?oo?@3oogSo0006oookJP04o`2>ool0oa_ooo]Zooo:
00Cooo]Z00?oo`2Co`3ioooo01<01OoonfX01ooQo`3of_l0oookJ_oonf[o9P3oob3o0?n40?l04?oo
nfX01?lao`3ooo]ZoookJ_l0oe/2oookJP08oh;o0?oonf[o0?nao`0`ool0odgo0>SooookJ_l60?l2
oookJP06oi;o0?oonf[ooo]ZoookJ_oo06[o403o1?oonfX01OlE0?ooo`1AoookJ_oonf[o0:go00;o
oo]Z00?oo`1ioookJ_oonfX01OoonfX00ol0oe?ooo]ZoookJP02oookJP04o`3o2?l0oagooo]Zo`3Q
obkooo]Z000ZoookJP03ool0m_oonf[ooo]Z00;ooo]Z00Go0:KooookJ_nX0?oooo]Zool0n@02oook
JP07o`1goooonf[ooo]ZoookJ_l0oi[oof`0oon10002oookJP05oc_o0?oonf[ooo]ZoookJ_l0nol0
1_oonfX02Ooo0`3ooo]ZoookJ_oo0=goN@3ooookJ_nDo`3o0?l<oil0o`06oookJP03ool0QooMo`3o
oo]Z00?ooo]Z00Soo`1/oookJ_oonf[oC@3oool^0?oonf[oiOl0of40o`GoiOl000?ohP3ooookJ_oU
o`000ooonfX00ol0oi;ooo]ZoookJP05oookJP03ofP0oooonf[ooo]Z00;ooo]Z2Ol0o``00ooonf[o
oi00oookJP0:oookJPSoiOl000?oj`3oonGo0?oUo`002?oonfX3oomG00cooo]Z1?oo02dKoookJP?o
o`0]2OoonfX2oomG00Sooo]Z0_o[0?l2oonn00Oooo]Z1_oob@02oaP0o`?ooo]Z00?oJ03ooookJ_oo
nfX00ooonfX2o`3oTP03oookJ_oR0?oooo]Z00;ooo]Z00?o0?m5onGo0?oUo`001_oUo`08odCo0004
ool30?oonf[ooo]Zo`3ko`;ooo]Z00oo>ol0oon10?ooK03o0?nJoookJ_l0Moooo`3iojP0ool0oego
0:Koo`3oGOo[o`3o0?mMonGo0?lH0?l00ooonfX01Ooo0?cooo]ZoookJ_oonf[ooi8000Kooo]Z00?o
o`3ZoookJ_oonfX02ooonfX00ol0Looooo]ZoookJP07oookJP;oiOl000Co0?l<o`3o<ooUo`3o02[o
0_oonfX4onGo0004o`3ogooUo`3oiOl0onGo00?ooo]Z00Co0?lKo`2>oolB0?ooolX01?oonfX00ooo
09?o0?Woool04`05oookJP07om[o0?oQo`3ooo]ZoookJ_lV0?oo8?l0oh@0o`0>oookJPKoiOl00_oo
nfX02?n2o`3ooo]Zo`0`oooonf[o0?m=oookJ_oUo`3o1P3o0_oonfX00onBo`3ooo]ZoookJP02oook
JP03oa00oooonf[oiOl000;oiOl000?ooo]ZoiCo0?oonfX00_oonfX5odCo00Gooo]Z00Go0?mCoook
J_oonf[ooo]Zo`3o2002oookJP03o`3o7Ol0hOoooo]Z05Cooo]Z00?oo`3foookJ_oonfX00_oonfX0
0ol0Y_oooo]ZojP0o`02oookJP03ool0nOoonf[o07Oo00?ooo]Z00Ko0?nJoom/0?oonf[ooh40oook
J_lko`03oookJP03o`3koooonf[ooo]Z00Cooo]Z00[oo`<0oookJ_oonf[ooo]Zool0gOoonf[o0:?o
o`0Goonco`3oW`3o1_oonfX00ooo08Oooo]ZoookJP02oookJP0:ool0K?oonf[ooo]ZoookJ_m=0?oo
obh0oookJ_mQ0?oooo]Zo`3oA@Cooo]Z00?ohP3oo`3oT?oonfX00_oonfX00ol0oi;ooo]ZoookJP06
oookJP03ofP0oooonf[ooo]Z00Cooo]Z00?o603oonKo0?oonfX01?oonfX00oooT03ooo]ZoookJP0<
oookJP;ookh000Gooo]Zo`3o1Ol0o`Gooo]Zon/0o`09oookJP?ooeL03OoonfX3ool0;A_ooo]Z0ooo
02d9oookJP;ooeL02?oonfX2on/0o`03o`3o1Ooo_P3ookh000Wooo]Z00Cooi00o`000?l0003oi_l0
0_lH0?l2oookJP;oJ03o1OoonfX01?l0oi;ooo]Zon80oooR0?l2oookJP04o`3oAOoonf[oH@3oodd0
o`;ooo]Z00?oo`1/omgo0?oo08L00ooonfX01?nO0?oo/ol0o`0Goooo0=d2oookJP0Eool30?oonf[o
oo]Zo`3koooonf[o>ol0oookJ_ooP@3o0?nJoookJ_l0Moooo`3ioookJ_nX0?oooo]Zo`2Voooo0?Ko
jol0ool60?oonf[o603o00?ooo]Z00Goo`3loookJ_oonf[ooi80oolF0005oookJP03ool0j_oonf[o
oo]Z00cooo]Z00?o07?ooookJ_oonfX02?oonfX01onio`3ooe80oookJ_oonf[o02[ooookJ_loo`00
0_oonfX00ol0g?ooN?l0oookJP06oookJP03o`3o6olB0?ooolX000Gooo]Z00?oo`2Cool04ooonfX0
1OoonfX01ooJo`3ooo]ZoookJ_lV0?oo8?l0oookJ_n40?l03ooonfX01?lao`3ooo]ZoookJ_l0oe/2
oookJP0<oh;o0?oonf[o0?nao`0`oooonf[o0?m=o`3Xoooonf[o1P3ooookJ_oo0?GoT_l00ooonfX0
0ooo06[o403ooookJP03oookJP05oaD0oooo057ooo]ZoookJ_l0[Ol00_oonfX00ooo07Wooo]Zoook
JP05oookJP09o`3oDooonf[ooo]ZoookJ_l0o`Sooo]Zo`3o7Ooonf[o0>7o02kooo]Z000ZoookJP03
ool0m_oonf[ooo]Z00;ooo]Z00?o0:KooookJ_nX0?l00_oonfX01?oo0?Wooo]ZoookJ_l0Mol2oook
JP04o`3oV_ooK03o0?o<oon100;ooo]Z00Go>ol0oookJ_oonf[ooo]Zo`3ko`06oookJP09ool30?oo
nf[ooo]Zool0gOmi0?ooU?l0o`3o3?nDo`3oW`3o00Gooo]Z00?o0?oNool0QooonfX01?oonfX02?oo
06cooo]ZoookJ_m=0?ooobh0oookJ_oUo`3oH@3o1OoUo`000ooR0?ooiOl0oookJP02oookJP03o`3o
T_oonf[ooo]Z00Gooo]Z00?oJ03ooookJ_oonfX00_oonfX:o`3o3003oookJ_ooT03ooo]Z00[ooo]Z
2?oUo`02on/0o`03onGo0?oonf[ooo]Z00Sooo]Z0oooE`0=oookJPCoo`0]2ooonfX<ool0;@Wooo]Z
0oooE`08oookJP;oj`3o0_oo_P08oookJPKoolT000Co603oooo90?oob@3oolT00_mX0?l5oookJP04
o`3oT_oonf[ooo]Zon80o`?ooo]Z00?o0?m5ool^0?oUo`001ooUo`07odCo0004ool30?oonf[ooo]Z
o`3ko`;ooo]Z00[o>ol0oon10?oonf[oof`0oookJ_l0Moooo`3iojP0ool0oego0:Ko0_l0oed01?o[
o`3o0?mMonGo0?lH0?l3oookJP04ool0o?oonf[ooo]ZoonB00Kooo]Z00?oo`3ZoookJ_oonfX03?oo
nfX00ol0Looooo]ZoookJP05oookJP;o0?l<0_oUo`001Ol0o`coiOl0onGo0?l0:_oooo]Z00SoiOl0
1?oonfX01?l0oa_o4P3ooookJ_oobP04oookJP03ool0Tol0nOooo`0C00Gooo]Z00Kof_l0oookJ_oo
nf[ooo]ZobH0oolPo`0?oookJPGoiOl000ko0?mKoookJ_oonf[oP_l0oookJ_l0<?oooo]Zo`3oCOoo
nf[o0>Soo`H0oooonf[oo`3eoi;o00?oiOl000?o403oonGo0?oonfX01?oUo`001?nDo`3oiOl0oook
J_l0[Ol4odCo00Kooo]Z00So0?mCoookJ_oonf[ooo]Zo`3o2?oonf[o0?lMo`3QoeKooo]Z00?oo`3f
oookJ_oonfX00_oonfX01?l0Y_oooo]ZoookJ_nX0?l2oookJP03ool0nOoonf[o07Oo00;ooo]Z00Oo
0?nJoookJ_ooK03o0?o<oon10?oonf[o>ol000?ooo]Z00?o0?_ooookJ_oonfX01?oonfX02_oo0`3o
oo]ZoookJ_oonf[oo`3MoookJ_l0Xooo/ol0oookJ_nO0?l5oookJP03o`3og_oo08Oooo]Z00?ooo]Z
00Woo`1/oookJ_oonf[oC@3ooookJ_oo;P3ooo]Zof40ool0odD01OoonfX01OoR0?oo0?n@oookJ_oo
nf[o0?nB00Sooo]Z00?oJ03ooookJ_oonfX01OoonfX00olH0?oo07CooookJP04oookJP03oon@0?oo
nf[ooo]Z00gooo]Z00Gookh0oookJ_oonf[o0?l5oookJP02on/0o`[ooo]Z0oooE`0=oookJPCoo`0]
3?oonfX;ool0;@Wooo]Z0oooE`08oookJP;oj`3o00?o0?l5oonn0?oo_P002OoonfX2oon@0005oook
J_l0003oi_l0oaP0ool000000_oonfX00omX0?oooo]ZoookJP03oookJP;o0?nB00?ooo]Zon80oooo
nfX00_oonfX01?l0odGooo]Zof40oom=0?l2oookJP03ool0K?l0omkoo`2700?ooo]Z00CoW`3ook?o
0?l0Xoooo`3M0_oonfX05Ooo0`3ooo]ZoookJ_l0nooooo]Zoc_o0?oonf[ooh40oom/0?oonf[o07Oo
ool0nOoonf[oZ03ooookJ_l0Y_ooo`3fon_o0?oonf[oo`H0oaP0o`04oookJP04ool0o?oonf[ooi80
oolF00Gooo]Z00?oo`3ZoookJ_oonfX03?oonfX00ol0Looooo]ZoookJP08oookJP03okWo0?oonf[o
oe8000;ooo]Z00Oo02[ooookJ_loo`3ooo]Zo`3Loolm0?ooN?l000Kooo]Z00Co08koo`3o6ooonf[o
olX01?oonfX00ooo09?o0?Woool04`05oookJP07on7o0?oJo`3ooo]ZoookJ_lV0?oo8?l0oh@0o`0@
oookJP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00SoP_l0oookJ_l0ok7o033oo`3oCOoonf[o0>Soo`H0
o`;ooo]Z00KoT_l0oookJ_oonf[ooo]Zool0J_l@0?l5oookJP04ool0DOoonf[ooo]Zo`2]o`?ooo]Z
00?oo`1ioookJ_oonfX01?oonfX00ol0oe?ooo]ZoookJP02oookJP04o`3o2?l0oagooo]Zo`3Qoboo
oo]Z000ZoookJP03ool0m_oonf[ooo]Z00;ooo]Z00?o0:KooookJ_nX0?l00_oonfX01?oo0?Wooo]Z
oookJ_l0Mol2oookJP04o`3oV_ooK03ooo]Zoon100;ooo]Z00Go>ol0oookJ_oonf[ooo]Zo`3ko`06
oookJP07ool30?oonf[ooo]Zool0gOmi0?ooU?l0o`3o3002oiCo00Kooo]Z00?oU?l0ool0QooonfX0
0ooonfX02?oo06cooo]ZoookJ_m=0?ooobh0oookJ_oUo`3oH@3o1OoUo`000ooR0?oooo]ZonGo0003
oookJP03o`3oT_oonf[ooo]Z00Gooo]Z0_mX0?l3oookJPWo0?l<0_oonfX00oooT03ooo]ZoookJP09
oookJPWoiOl000?oj`3oog00oooonfX02ooonfX2oomG00oooo]Z2ooo02dAoookJP?ooeL00_m4o`09
oookJP03on/0ool0o`Gookh000[ooo]Z1Ooob@001OlH0?ooolT0ooo90?l0003oJ03o00Kooo]Z00Co
0?nBoookJ_l0oi3ohP3o0_oonfX2o`3oA@03ool^0?oUo`3oiOl000KoiOl01_m4o`001Ooonf[oo`<0
oookJ_oonf[o0?_o00?ooo]Z00Wo>ol0oon10?ooK03ooo]Zo`1goooo0?Wooo]ZojP0ool0Y_l00_l0
oed01?o[o`3o0?mMonGo0?lH0?l3oookJP05ool0o?oonf[ooo]ZoonB0?oo5P001OoonfX00ooo0>[o
oo]ZoookJP0<oookJP03o`1coooonf[ooo]Z00Kooo]Z1?l0o``00ol0oc?oiOl0o`0Zo`02oookJPOo
iOl01?oonfX01?l0oa_o08kooa80oooobP04oookJP03ool0Tol0nOooo`0C00Gooo]Z00Oof_l0on7o
0?oonf[ooo]ZobH0oolPo`3oQ03o00kooo]Z1_oUo`02oookJP0<oh;o0?l0ok3oiOl0o`0`ool0odgo
oo]Zo`3Xoooonf[o1P3ooookJ_nBo`3ooo]Z0ooUo`000ol@0?ooiOl0onGo0003onGo0003oiCo0?oU
o`3oiOl000;oiOl01?m4o`05oookJP03o`3oDooonf[ooo]Z00;ooo]Z00Co0?l8oookJ_l0oago0>7o
EooonfX00ooo0?Kooo]ZoookJP02oookJP03o`2Voooonf[oZ03o00;ooo]Z00?oo`3ioookJ_l0Mol0
0_oonfX01ol0oi[ooo]Zoom/0?oonf[ooh40oookJ_lko`000ooonfX00ol0nooooo]ZoookJP04oook
JP0:ool30?oonf[ooo]ZoookJ_oo0=gooo]Zo`2Soonco`3ooo]Zoil0o`Kooo]Z00?o0?oNool0Qooo
nfX00ooonfX02Ooo06cooo]ZoookJ_m=0?ooobh0oookJ_mQ0?oooo]Zo`3oA@04oookJP03on80oooo
nf[o0?n@00;ooo]Z00?o0?nBoookJ_oonfX01_oonfX2ofP0o`Kooo]Z00?o603oo`1doooonfX01?oo
nfX00oooT03ooo]ZoookJP0=oookJP;ookh000Gooo]Zo`3o1Ol0o`GoL03oon/0o`0<oookJP?ooeL0
3_oonfX<ool0;A3ooo]Z1?ooE`0:oookJP04on/0ool0o`Go0?l5oonn00[ooo]Z00Cooi00oookJ_oo
nf[o07Co0_lH0?l2o`0000;oJ03o1OoonfX01?l0oi;ooo]Zo`3oT?oR0?l3oookJP04o`3oAOoonf[o
H@3oodd0o`;ooo]Z00?oo`1/o`3og_oo08L00ooonfX01?nO0?oo/ol0o`2Soooo0=d2oookJP04ool3
0?oonf[ooo]Zo`3ko`;ooo]Z00oo>ol0o`3oc?ooP@3ooo]Zo`1goooo0?Wooo]ZojP0oooonf[o0:Ko
oookJ_o[o`3ooo]Zool60?lH0?l01?oonfX01Ooo0?cooo]ZoookJ_ooTP3ooaH000Cooo]Z00?oo`3Z
oookJ_oonfX03OoonfX00ol0Looooo]ZoookJP08oookJP0;okWo0?ooDP3ooo]ZoookJ_l0:_oooo]Z
ocoo0?oonf[o0=cooookJ_mho`001ooonfX00ol0oa_o4P3oooo:0005oookJP03ool0Tooo01?ooo]Z
00Gooo]Z00Oof_l0oookJ_oonf[o9P3ooookJ_lPo`3oQ03o013ooo]Z00?o<Ol0oookJ_l0oe/00_oo
nfX03?n2o`3o0?n`oookJ_l0ok7o033oo`3oCOl0j?oooo]Zo`H0oooonf[oo`3eoi;o00?ooo]Z00?o
o`1Zoa00oooonfX00ooonfX01OlE0?ooo`1AoookJ_oonf[o0:go00;ooo]Z00?oo`1ioookJ_oonfX0
1OoonfX00ol0oe?ooo]ZoookJP02oookJP04o`3o2?l0oagooo]Zo`3Qoboooo]Z000[oookJP03ool0
m_oonf[ooo]Z00;ooo]Z00?o0:KooookJ_nX0?l00_oonfX01?oo0?Wooo]ZoookJ_l0Mol2oookJP06
o`3oV_ooK03o0?o<oon10?oonf[o>ol00ooonfX00ol0nooooo]ZoookJP05oookJP07ool30?oonf[o
oo]Zool0gOmi0?ooU?l0o`3o3002oiCo00Gooo]Z00?oU?l0ool0QonDo`001?oonfX01Ooo06cooo]Z
oookJ_m=0?ooobh000;oiOl000?oH@3oonGo0?oUo`000ooUo`000ooR0?oooo]ZonGo0003oookJP03
o`3oT_oonf[ooo]Z00Kooo]Z00?oJ03ooookJ_oonfX02?l0o``4oookJP03oon@0?oonf[ooo]Z00Wo
oo]Z2?oUo`000ol0o`Goj`3oon/0o`0=oookJP?ooeL08ooonfX5oomG00;ooo]Z0om4o`06oookJP03
odCo0?o[0?ooj`3o00;ookh02_oonfX4ooo900;o603o0ol000000omX0?oooo]ZoookJP04oookJP04
o`3oT_oonf[ohP3oon80o`;ooo]Z00Co0?m5oookJ_oo;P3oH@3o1ooUo`000ooonf[oA?l0odCo0003
odCo0005oookJ_oob@3ooo]ZoookJ_l0nol00ooonfX00olko`3ooh40oom/0002oookJP04o`1goooo
0?WoZ03oo`2Vo`;o0?mM00Cojol0o`3oGOoUo`3o603o0ooonfX01Ooo0?cooo]ZoookJ_oonf[ooi80
00Kooo]Z00?oo`3ZoookJ_oonfX02ooonfX00ol0Looooo]ZoookJP07oookJPGo0?l<00Gooo]Zo`0Z
oooonf[oiOl0oookJP02onGo0004o`3ogooUo`3oiOl0onGo00Cooo]Z00Co0?lKoa80oooonf[oolX0
1?oonfX00ooo09?ooo]Zool04`05oookJP06om[o0?oonf[ooo]ZoookJ_lV0?oo8?l03ooonfX5onGo
000;o`3oFooonf[ooo]Zoh;o0?oonf[o033ooookJ_l0odgooo]Zo`3Xool60?l00_oonfX01OnBo`3o
oo]ZonGo0?oUo`3o403o00KoiOl000?oU?l0onGo0?oUo`000_oUo`03odCo00Kooo]Z00Go0?mCoook
J_oonf[ooo]Zo`3o2002oookJP03o`3o7Ol0hOoooo]Z05Kooo]Z00?oo`3foookJ_oonfX00_oonfX0
0ol0Y_oooo]ZojP0o`03oookJP03ool0nOoonf[o07Oo00;ooo]Z00Oo0?nJoom/0?oonf[o0?o<oon1
0?oonf[o>ol000;ooo]Z00?o0?_ooookJ_oonfX01OoonfX02_oo0`3ooo]ZoookJ_oonf[oo`3Moook
J_l0Xooo/ol0oookJ_nO0?l5oookJP03o`3og_oo08Oooo]Z00?ooo]Z00[oo`1/oookJ_oonf[ooo]Z
odd0oooo;P3ooo]Zof40oooonf[o0?m51?oonfX00ooR0?oo0?n@oookJP02oookJP03o`3oT_oonf[o
oo]Z00Oooo]Z00?oJ03ooookJ_oonfX01?oonfX00olH0?ooi_l0oookJP04oookJP03oon@0?oonf[o
oo]Z00kooo]Z0_oo_P000ooonf[o0?l5o`3o1@02on/0o`gooo]Z0oooE`0RoookJPGooeL02ooonfX0
1?m`0?ooj`3oon/0oooonfX2oonn00[ooo]Z00Gooi00oookJ_oonf[oi_l0oaP0o`03o`000003ofP0
oooonf[ooo]Z00Cooo]Z00Co0?nBoookJ_l0oi3ohP3o0ooonfX01?l0odGooo]Zof40oom=0?l2oook
JP03ool0K?l0omkoo`2700?ooo]Z00CoW`3ook?o0?l0Xoooo`3M0_oonfX01?oo0`3ooo]ZoookJ_l0
nol2oookJP03oc_o0?l0olcooh4000;ooo]Z00_o07Ooool0nOnX0?oooo]Zo`2Voooonf[ojol0oook
J_oo1P3ooo]ZoaP0o`03oookJP05ool0o?oonf[ooo]ZoonB0?oo5P001OoonfX00ooo0>[ooo]Zoook
JP0<oookJP03o`1coooonf[ooo]Z00Wooo]Z00_o^Ol0oomB0?oonf[ooo]Zo`0Zoooonf[o?ol0oook
J_l0g?ooN?l0ocd0o`06oookJP04o`2>ool0oa_o4P3oooo:00Cooo]Z00?o0?Woool0Tooo01<01Ooo
nfX01ooJo`3ooo]ZoookJ_oonf[o9P3oob3o0?n40?l04?oonfX01?lao`3ooo]ZoookJ_l0oe/2oook
JP0;oh;o0?oonf[o0?nao`0`ool0odgooo]Zo`3Xoooonf[o1P3ooookJ_nBo`001?oonfX00ol@0?oo
01WooookJP03oookJP05ool0DOoonf[ooo]ZoookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP05oook
JP09o`3oDooonf[ooo]ZoookJ_l0o`Sooo]Zo`3o7Ooonf[o0>7o02oooo]Z000ZoookJP03on_o0?oo
0?Kooo]Z00?ooo]Z00?o0:KooookJ_nX0?l00_oonfX01?oo0?Wooo]ZoookJ_l0Mol2oookJP04o`3o
V_ooK03o0?o<oon100;ooo]Z00Go>ol0oookJ_oonf[ooo]Zo`3ko`06oookJP07ool30?oonf[ooo]Z
ool0gOoonf[oU?l0ok?o0003oiCo00Gooo]Z00?oU?l0ool0QonDo`000ooonfX02?oo06cooo]Zoook
J_m=0?ooobh0oookJ_oUo`3oH@3o1?oUo`02oookJP03on80oooUo`3ooo]Z00;ooo]Z00?o0?nBoook
J_oonfX01ooonfX00omX0?oooo]ZoookJP06o`3o3003onKo0?oonf[ooo]Z00?ooo]Z00?ooi00oook
J_oonfX02OoonfX6onGo00?ooo]Z00?o0?l5on/0oom`0?l03_oonfX3oomG01cooo]Z1?ooE`05oook
JPGoA?l00ooonfX01?m4o`3oj`3oon/0ooo[0?l2oonn00_ooo]Z1?oob@001?lH0?oooo]ZoookJ_l0
0002ofP0o`03o`000?oonf[ooo]Z00;ooo]Z0_l0oi800ooonf[ohP3ooookJP02oookJP04o`3oAOoo
nf[oobh0of40o`KoiOl00_oonfX4odCo0003ool0gOoonf[oolT000?ooo]Z00Ko0?_ooookJ_oonf[o
>ol0oon10?ooK002oookJP03o`1goooo0?WoZ03o00;oiOl00_l0oed01?o[o`3oiOl0oookJ_lH0?l2
oookJP05ool0o?oonf[ooo]ZoookJ_ooTP001_oonfX00ooo0>[ooo]ZoookJP0<oookJP03o`1coooo
nf[ooo]Z00Kooo]Z1ol0o``01?l0:_oooo]ZonGo0?oonfX5onGo00Cooo]Z00Co0?lKo`2>oolB0?oo
olX01?oonfX00ooo09?o0?Woool04`05oookJP03om[o0?oQo`3ooo]Z00;ooo]Z00?o9P3ooh@0oooo
nfX03_oonfX4onGo000>o`3oFooonf[ooo]ZoookJ_n2o`3oiOl0o`0`oooonf[o0?m=o`3Xoooonf[o
1P3ooookJ_nBo`02oookJP;oiOl000?o403oonGo0?oUo`001?oUo`001OnDo`3oiOl0onGo0?oUo`3o
oo]Z00?oA?l01_oonfX02?l0oe?ooo]ZoookJ_oonf[o0?l8oookJ_l0oago0>7oEooonfX00oo[o`3o
o`3foookJP03oookJP04o`2Voooonf[ooo]ZojP0o`;ooo]Z00?oo`3ioookJ_l0Mol00_oonfX01ol0
oi[ooo]Zoom/0?l0olcooh40oookJ_lko`000ooonfX00ol0nooooo]ZoookJP04oookJP0:ool30?oo
nf[ooo]ZoookJ_oo0=goN@3ooookJ_nco`3o01Oooil0o`Gooo]Z00?ogOl0o`3og_oo08L01?oonfX0
1Ooo06cooo]ZoookJ_m=0?ooobh000;ooo]Z00?oH@3oo`3oAOoonfX01?oonfX01OoR0?oo0?n@oook
J_oonf[o0?nB00[ooo]Z00?oJ03ooookJ_oonfX01?oonfX00olH0?ooi_l0oookJP04oookJP03oon@
0?oonf[ooo]Z00oooo]Z00Kookh0oookJ_oonf[o0?l5og00ooo[0?l?oookJP?ooeL06ooonfX4oomG
00gooo]Z00GoL03oon/0ooo[0?ooj`3ooookJP02oonn00[ooo]Z0_ooT002oookJP;o603o00Gooo]Z
o`000?l0003oJ03oo`000005oookJP04o`3oT_oonf[o0?n@on80o`;ooo]Z0_l0odD00ooonf[oH@3o
odd0o`02oookJP03ool0K?oo08Ooo`2700?ooo]Z00CoW`3ooookJ_nco`3oo`3M0_oonfX01?oo0`3o
oo]ZoookJ_l0nol2oookJP0@oc_o0?l0olcooh40o`3oV_oonf[o07Ooool0nOoonf[oZ03oo`2Voooo
nf[oo`3fon_o0?oo1P3ooo]ZoaP0o`?ooo]Z00Goo`3loookJ_oonf[ooi80oolF0005oookJP03ool0
j_oonf[ooo]Z00gooo]Z00?o07?ooookJ_oonfX02?oonfX00onio`3ooe80oookJP02oookJP06o`0Z
ooloo`3ooo]Zo`3Loooonf[oN?l01ooonfX00ol0oa_o4P3oooo:0005oookJP03ool0Tooo01?ooo]Z
00Gooo]Z00Oof_l0oookJ_oonf[ooo]ZobH0oolPo`3oQ03o013ooo]Z00?o<Ol0oookJ_l0oe/00ooo
nfX02?n2o`3ooo]Zo`3o/Ol0<?oo0?m=o`3Xoooonf[o1P3o0_oonfX01_nBo`3ooo]ZoookJ_oonf[o
o`1Zoa00o`Gooo]Z00Coo`1AoookJ_oonf[o0:go0ooonfX00ooo07Wooo]ZoookJP04oookJP03o`3o
Dooonf[ooo]Z00;ooo]Z00Co0?l8o`3o7Ooonf[o0>7o<?oonfX002[ooo]Z00?ojol0ool0m_oonfX0
0ooonfX01?l0Y_oooo]ZoookJ_nX0?l2oookJP0<ool0nOoonf[ooo]Zo`1goooonf[o0?nJoookJ_oo
K03o0?o<oon10?oonf[o>ol01?oonfX00ol0nooooo]ZoookJP04oookJP04ool30?oonf[ooo]Zool0
g@;oU?l000Co/ol0oiCo0?nDo`3oU?l01?oonfX2oiCo0003ool0QonDo`3ooo]Z00;ooo]Z00Goo`1/
oookJ_oonf[oC@3oool^0002onGo0003of40oooUo`3oiOl000Cooo]Z00?ohP3oonGo0?oonfX00_oo
nfX00ol0oi;ooo]ZoookJP07oookJP03ofP0oooonf[ooo]Z00Go0?l<00?ooo]ZonKo0?oonfX01?oo
nfX00oooT03ooo]ZoookJP09oookJPOoiOl00ooonfX9ooo900Wooo]Z3?ooE`0<oookJPCooeL01ooo
nfX8odCo00?oj`3o0ooo_P0<oookJP?oolT000?oi_l0oaP0oooonfX00_oonfX01?mX0?oo0000o`00
0?l00003oookJP04o`3oT_oonf[ooo]Zon80o`?ooo]Z00Go0?m5oookJ_mQ0?ooH@3oodd0o`04onGo
00Cooo]Z0om4o`000ooo0=gooo]Zooo90003oookJP06o`3koooonf[ooo]Zoc_o0?l0olcooh400_oo
nfX01?l0Moooo`3iojP0oooonfX3onGo0004on_o0?l0oegoiOl0oaP0o`?ooo]Z00Goo`3loookJ_oo
nf[ooo]ZoonB0005oookJP03ool0j_oonf[ooo]Z00cooo]Z00?o07?ooookJ_oonfX01ooonfX8o`3o
3005onGo0?oonf[o0=coonGo0?l0oml00_oUo`05oookJP04o`3o6olB0?oooo]Zooo:00Cooo]Z00?o
o`2CoookJ_oo01<01OoonfX01ooJo`3ohOl0oookJ_oonf[o9P3oob3o0?n40?l03ooonfX4onGo000>
o`3oFooonf[ooo]Zoh;o0?l0ok3o033ooookJ_l0odgooo]Zo`3Xoooonf[o1P3ooookJ_nBo`02oook
JP;oiOl000?o403oonGo0?oUo`000ooUo`001_nDo`3oiOl0onGo0?oUo`3o0:gooookJP;oA?l01_oo
nfX00ol0oe?ooo]ZoookJP02oookJP04o`3o2?oonf[o0?lMo`3QoeOooo]Z00?ojol0oookJ_oo0?H0
1?oonfX00ol0Y_oooo]ZojP0o`03oookJP0<ool0nOoonf[o07OooookJ_l0oi[ooo]Zoom/0?oonf[o
0?o<oon10?oonf[o>ol00ooonfX00ol0nooooo]ZoookJP04oookJP0:ool30?oonf[ooo]ZoookJ_oo
0=gooo]Zo`2Soonco`3ooo]Zoil0o`Gooo]Z00?ogOl0o`3og_oo08L00ooonfX02_oo06cooo]Zoook
J_oonf[oC@3oool^0?oonf[oH@3ooookJ_l0odD5oookJP05on80ool0oi3ooo]ZoookJ_l0oi802_oo
nfX00omX0?oooo]ZoookJP04oookJP03oaP0oooVo`3oi_l000Cooo]Z00?ooi00oookJ_oonfX03ooo
nfX2oonn00;ooo]Z00Co0?l5on/0ooo[0?ooj`3o3ooonfX<oomG00_ooo]Z1?ooE`0>oookJP05og00
ooo[0?ooj`3oon/0oooonfX00ooo_P0;oookJP05oon@0?oonf[ooo]ZonKo0?lH0?l00ooonfX2ofP0
o`;o00001?oonfX01?l0oi;ooo]Zo`3oT?oR0?l2oookJP05o`3oAOoonf[oH@3oof40oom=0?l00_oo
nfX00ooo06coo`27oookJP03oookJP04oil0oooonf[o/ol0ool0g@;ooo]Z00Coo`<0oookJ_oonf[o
0?_o0_oonfX04?lko`3o0?o<oon10?l0oi[ooo]Zo`1goooo0?Wooo]ZojP0oooonf[o0:Koool0m_o[
o`3ooo]Zool60?lH0?l4oookJP05ool0o?oonf[ooo]ZoonB0?oo5P001?oonfX00ooo0>[ooo]Zoook
JP0=oookJP03o`1coooonf[ooo]Z00Wooo]Z00_o^Ol0oomB0?oonf[ooo]Zo`0Zoooonf[o?ol0oook
J_l0g?ooN?l0ocd0o`06oookJP04o`2>ool0oa_o4P3oooo:00Cooo]Z00?o0?Woool0Tooo01<01Ooo
nfX02?oJo`3ohOl0oookJ_oonf[o9P3oob3o0?oonf[oQ03o4?oonfX00olao`3ooo]Zo`3oF`02oook
JP0<oh;o0?l0ok3o0?nao`0`oooonf[o0?m=o`3Xoooonf[o1P3ooookJ_oo0?GoT_l00ooonfX00ol@
0?oo01WooookJP03oookJP05oaD0oooo057ooo]ZoookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP05
oookJP03o`3oDooonf[ooo]Z00;ooo]Z00Co0?l8o`3o7Ooonf[o0>7o<?oonfX002[ooo]Z00?ojol0
o`3o[OoonfX00ooonfX01?l0Y_oooo]ZoookJ_nX0?l3oookJP03ool0nOoonf[o07Oo00;ooo]Z00Oo
0?nJoom/0?l0olcooo]Zoon10?oonf[o>ol000?ooo]Z00?o0?_ooookJ_oonfX01?oonfX01Ooo0`3o
oo]ZoookJ_oonf[oo`3M00;oU?l000Co/ol0oiCo0?nDo`3oU?l00ooonfX3oiCo0005ool0QonDo`3o
oo]ZoookJ_oo06`00_oonfX00om=0?ooobh0onGo0002onGo0003of40oooonf[oiOl000Cooo]Z00?o
hP3ooookJ_oonfX00_oonfX00ol0oi;ooo]ZoookJP07oookJP03ofP0oooonf[o0?l<00;o0?l<0_oo
nfX01?l0o`cooo]ZonKo0?oVo`04oookJP03oon@0?oonf[ooo]Z00Wooo]Z0ooUo`03oookJP03onGo
0?oonf[ooo]Z00;ooo]Z3ooob@0=oookJPcooeL02_oonfX6odCo00?oj`3o0ooo_P0>oookJP;oolT0
00?oi_l0oaP0oolH0?l00ooonfX00omX0?oo0000o`000002o`0000;ooo]Z00Co0?nBoookJ_l0oi3o
hP3o0ooonfX01Ol0odGooo]Zof40oooonf[oC@3o00CoiOl01?oonfX3odCo0003ool0gOoonf[oolT0
00?ooo]Z00co0?_ooookJ_oonf[o>ol0o`3oc?ooP@3o0?nJoookJ_l0Mooooo]Zool0nOnX0?l6onGo
0005oookJ_lH0?oooo]ZoookJ_oo0?`00ooonfX00oooTP3ooo]ZoookJP03oookJP03ool0j_oonf[o
oo]Z00gooo]Z00?o07?ooookJ_oonfX01ooonfX8o`3o3003onGo0?l0g?oooo]Z00?oiOl01OoonfX0
1?l0oa_o08kooa80oooobP05oookJP03ool0Tooo01?ooo]Z00Cooo]Z00?of_l0on7o0?oonfX00_oo
nfX00olV0?ooQ03ooookJP0?oookJP?oiOl000oo0?mKoookJ_oonf[ooo]Zoh;o0?oUo`3o033ooook
J_l0odgo0>SooookJ_l60?oooo]Zool0mOnBo`000_oonfX00ooUo`3o403oonGo0005onGo0004oiCo
0?oUo`3oiOl0onGo00;ooo]Z00?oA?l0oookJ_oonfX01OoonfX02Ol0oe?ooo]ZoookJ_oonf[o0?l8
oookJ_l0oagooo]Zo`3Qo`1HoookJP03on_o0?oo0?Kooo]Z00?ooo]Z00Co0:KooookJ_oonf[oZ03o
0_oonfX00ooo0?Wooo]Zo`1go`02oookJP07o`3oV_oonf[oof`0o`3oc?oonf[ooh40oc_o0003oook
JP03o`3koooonf[ooo]Z00Cooo]Z00?oo`<0oookJ_oonfX00_oonfX01Ooo0=gooo]Zo`2Soonco`3o
W`3o00Gooo]Z00?ogOl0oookJ_oo08L01?oonfX01Ooo06cooo]ZoookJ_m=0?ooobh000;ooo]Z00?o
H@3ooookJ_l0odD01OoonfX01OoR0?oooo]ZoookJ_oonf[o0?nB00[ooo]Z00?oJ03ooookJ_oonfX0
1?oonfX00olH0?oo07CoonKo0004oookJP03oon@0?oonf[ooo]Z013ooo]Z00Cookh0oookJ_oonf[o
oo]Z0_m`0?l3on/0oaSooo]Z2oooE`0?oookJP05og00ooo[0?ooj`3oon/0ool0o`D00ooo_P0=oook
JP03oon@0?oonf[oi_l000;o603o0ooonfX00omX0?oo0000o`000002o`0000?ooo]Z00Co0?nBo`3o
T?oR0?oohP3o0_oonfX01Ol0odGooo]Zof40oooo;P3oC@3o00;ooo]Z00?oo`1/ool0QooonfX00ooo
nfX01?nO0?oooo]Zok?o0?oo0=d2oookJP04ool30?oonf[ooo]Zo`3ko`;ooo]Z017o>ol0oookJ_oo
P@3o0?nJoookJ_l0Mooooo]Zool0nOnX0?oooo]Zo`2Voooonf[ojol0oookJ_oo1P3ooo]ZoaP0o`03
oookJP05ool0o?oonf[ooo]ZoonB0?oo5P001OoonfX00ooo0>[ooo]ZoookJP0=oookJP03o`1coooo
nf[ooo]Z00Sooo]Z00?o^Ol0oomB0?oonfX00_oonfX01_l0:_oo?ol0oookJ_l0g?oooo]ZogSo00Oo
oo]Z00?o0?lKoa80oooobP001OoonfX00ooo09?oo`0CoookJP05oookJP07om[o0?oonf[ooo]Zoook
J_lV0?oo8?l0oh@0o`0@oookJP03oc7o0?oonf[o0?mK00?ooo]Z00KoP_l0oookJ_l0ok7o033oo`3o
COl0j?l2oookJP03o`H0oooonf[oT_l000Cooo]Z00?o403oo`0IoooonfX00ooonfX01?oo057ooo]Z
oookJ_l0[Ol3oookJP03ool0NOoonf[ooo]Z00Cooo]Z00?o0?mCoookJ_oonfX00_oonfX01Ol0o`So
0?lMoookJ_oonf[o0>7o033ooo]Z000ZoookJP03on_o0?l0ojgo0?n]00Cooo]Z00Co0:KooookJ_oo
nf[oZ03o0_oonfX03?oo0?Wooo]ZoookJ_l0Mooooo]Zo`3oV_ooK03o0?o<oookJ_ooP@3ooo]Zoc_o
00Cooo]Z00?o0?_ooookJ_oonfX00ooonfX01Ooo0`3ooo]ZoookJ_oonf[oo`3M00?oU?l000Co/ol0
oiCo0?nDo`3oU?l00ooonfX2oiCo0006ool0QonDo`3oU?l0oiCo0?oonf[oo`1/0_oonfX01Om=0?oo
obh0onGo0?oonf[oH@3o00;ooo]Z00KoiOl0oookJ_oonf[ooo]Zon80oooUo`03oookJP03o`3oT_oo
nf[ooo]Z00Sooo]Z00?oJ03ooookJ_l0o``01?oonfX01?l0o`cooo]Zo`1doooVo`04oookJP03oon@
0?oonf[ooo]Z00Wooo]Z00?oiOl0oookJ_oonfX00ooonfX2onGo00?ooo]Z00?o0?l5ooo90?oob@00
2ooob@0QoookJPGoA?l00oo[0?l3oonn00oooo]Z00Gooi00ooo90?oonf[oi_l0oaP0o`04oookJP03
ofP0oooonf[o000000?o000000Gooo]Zo`3oT_oonf[o0?n@on80o`02oookJP;o0?m500Cooo]Zof40
oooonf[oC@3o0ooUo`000ooo08OoolT0ooo90002oookJP06oil0oom4o`3o0:?oool0gOoonf[oolT0
0ooonfX01ol0nooooo]ZoookJ_lko`3o0?o<oon10?ooK0000_oonfX01?l0Moooo`3iojP0ool0Y_l7
onGo00;ooo]Z00Koo`3loookJ_oonf[ooo]ZoonB0?oUo`05oookJP03ool0j_oonf[ooo]Z00cooo]Z
00?o07?ooookJ_oonfX02?oonfX7o`3o3005onGo0?oonf[o0=coonGo0?l0oml00_oUo`05oookJP03
o`3o6ooonf[oolX000Gooo]Z00?oo`2CoookJ_oo01<01OoonfX01ooJo`3ohOl0oookJ_oonf[o9P3o
ob3o0?n40?l04?oonfX3onGo000>o`3oFooonf[ooo]Zoh;o0?l0ok3o033ooookJ_l0odgooo]Zo`3X
oooonf[o1P3ooookJ_nBo`03oookJP03onGo0?l@0?ooiOl000CoiOl000GoU?l0onGo0?oUo`3oiOl0
o`2]o`02oookJP03ool0NOoonf[ooo]Z00Cooo]Z00?o0?mCoookJ_oonfX00_oonfX01Ol0o`Sooo]Z
o`3o7Ooonf[o0>7o05Sooo]Z00?ojol0ool0m_oonfX00ooonfX01?l0Y_oooo]ZoookJ_nX0?l3oook
JP0<ool0nOoonf[o07OooookJ_l0oi[ooo]Zoom/0?l0olcooo]Zoon10?oonf[o>ol00ooonfX00ol0
nooooo]ZoookJP03oookJP03ool30?oonf[ooo]Z00;ooo]Z00Koo`3MoookJ_oonf[o0:?ook?o0?nO
0?l5oookJP03omgo0?l0omkoo`2700?ooo]Z00Soo`1/oookJ_oonf[ooo]Zodd0oooo;P3ooo]Zof40
o`;ooo]Z00?o0?m5oookJ_oonfX00_oonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00_ooo]Z00?oJ03o
oookJ_oonfX01?oonfX00olH0?oo07CoonKo0004oookJP03oon@0?oonf[ooo]Z013ooo]Z0_oo_P02
oookJP;o0?l50_m`0?l4on/0ob_ooo]Z00GoL03oon/0ooo[0?ooj`3oo`3o1@03oonn00kooo]Z0_oo
T0000ooonf[oi_l0oaP0o`04oookJP03ofP0oooonf[o000000?o00000_oonfX00ol0oi;o0?n@on80
o`03oookJP05o`3oAOoonf[oH@3oool^0?m=0?l00_oonfX00ooo06coo`27oookJP03oookJP07oil0
oooonf[o/ol0ogT0oooo0=gooo]Zool30002oookJP07o`3koooonf[ooo]Zoc_o0?oonf[ooh40oom/
0002oookJP0;o`1goooo0?WoZ03ooookJ_l0Y_oooo]Zool0m_o[o`3oo`H0oookJ_lH0?l00ooonfX0
1_oo0?cooo]ZoookJ_oonf[ooi80oolF00Cooo]Z00?oo`3ZoookJ_oonfX03OoonfX00ol0Looooo]Z
oookJP09oookJP0;okWo0?ooDP3ooo]ZoookJ_l0:_oooo]Zocoo0?oonf[o0=coogSo0?lm0?l01_oo
nfX01?l0oa_ooo]Zoa80oooobP04oookJP03o`3ioooo09?oo`0C00Gooo]Z00Sof_l0on7o0?oonf[o
oo]ZobH0oolPo`3ooo]Zoh@0oa3ooo]Z00?o<Ol0oookJ_l0oe/00_oonfX03?n2o`3o0?n`o`3o/Ol0
<?oooo]Zo`3oCOl0j?oooo]Zo`H0oooonf[oo`3eoi;o00?ooo]Z00?o403oo`0IoooonfX01?oonfX0
1?oo057ooo]ZoookJ_l0[Ol3oookJP03ool0NOoonf[ooo]Z00Cooo]Z00?o0?mCoookJ_oonfX00_oo
nfX01Ol0o`So0?lMoookJ_oonf[o0>7o033ooo]Z000[oookJP03on_o0?l0ojgo0?n]00?ooo]Z00Co
0:KooookJ_oonf[oZ03o0ooonfX03?oo0?Wooo]Zo`1goooonf[o0?nJoookJ_ooK03o0?o<oookJ_oo
P@3ooo]Zoc_o00Cooo]Z00?o0?_ooookJ_oonfX00ooonfX01Ooo0`3ooo]ZoookJ_oonf[oo`3M00;o
U?l000?o/ol0oiCo0?nDo`000_nDo`02oookJP?oU?l000Goo`27oiCo0?nDo`3oU?l0ool0K002oook
JP03odd0oooo;P3ooo]Z00;ooo]Z00?oH@3ooookJ_oUo`001?oonfX00ooR0?ooiOl0oookJP02oook
JP03o`3oT_oonf[ooo]Z00Sooo]Z0_mX0?l5oookJP04o`3o3?oonf[o07CoonKo00Cooo]Z00?ooi00
oookJ_oonfX04?oonfX00ooUo`3ooo]ZoookJP02oookJPcoolT07ooonfX4odCo00?oj`3o00?oA?l0
oonn0?oo_P001?m4o`0<oookJP;ooi0000Cooo]ZonKo0?lH0?oo603o0ooonfX2ofP0o`;ooo]Z1?l0
00001?l0oi;ooo]Zo`3oT?oR0?l2oookJP0;o`3oAOoonf[oH@3oof40oooonf[oC@3ooookJ_oUo`3o
oo]Zool0QooonfX00ooob@001_nco`3oA?l0o`2Soooo0=gooo]Zooo900?ooo]Z00Oo0?_ooookJ_oo
nf[o>ol0o`3oc?ooP@3oof`000;ooo]Z00Go07Ooool0nOnX0?oo0:KooookJP08onGo0003ool0o?oo
nf[ooo]Z00;ooo]Z00?ooi80oookJ_oonfX00ooonfX00ooo0>[ooo]ZoookJP0=oookJP03o`1coooo
nf[ooo]Z00Oooo]Z1ol0o``01?oonf[oiOl0o`3LoooonfX3onGo00Gooo]Z00Co0?lKo`2>oolB0?oo
olX01OoonfX00ooo09?oo`0CoookJP04oookJP03om[o0?oQo`3ooo]Z00;ooo]Z00?o9P3oob3o0?n4
0?l04?oonfX2onGo000?o`3oFooonf[ooo]ZoookJ_n2o`3ooo]Zo`0`oooonf[o0?m=o`3Xoooonf[o
1P3ooookJ_oo0?GoT_l000?ooo]Z00?o403oonGo0?oUo`001?oUo`001?nDo`3oiOl0onGo0?oUo`02
oookJP03ool0NOoonf[ooo]Z00Gooo]Z00?o0?mCoookJ_oonfX00_oonfX01?l0o`So0?lMoookJ_l0
hOmIoookJP03on_o0?oonf[oo`3f00Cooo]Z00Co0:KooookJ_oonf[oZ03o0_oonfX03?oo0?Wooo]Z
o`1goooonf[o0?nJoookJ_ooK03ooo]Zo`3oc?oonf[ooh40oc_o00Cooo]Z00?o0?_ooookJ_oonfX0
0ooonfX00ooo0`3ooo]ZoookJP02oookJP05ool0gOoonf[o0:?ook?o0?nO0?l01_oonfX00ooMo`3o
0?oNool0Q`03oookJP05ool0K?oonf[ooo]Zodd0oooo;P000_oonfX00omQ0?oooo]Zo`3oA@05oook
JP05on80oooonf[ooo]ZoookJ_l0oi802ooonfX00omX0?oooo]ZoookJP04oookJP04oaP0ool0M?oo
i_l0onKo00?ooo]Z00?ooi00oookJ_oonfX04OoonfX01?oo_P3ooo]ZoookJ_oonfX2o`3o1@;ooo]Z
0_m`0?l3on/0obGooo]Z00GoL03oon/0ooo[0?ooj`3oo`3o1@03oonn00oooo]Z0_ooT0001?oonf[o
i_l0onKo0?lH0?l3oookJP;oJ03o0_oonfX4o`0000;o0?nB00?o0?n@on80oooonfX00_oonfX01Ol0
odGooo]Zof40oooo;P3oC@3o00;ooo]Z00?oo`1/ool0QooonfX00ooonfX01onO0?oo/ol0ok?o0?mi
0?ooo`3MoookJ_oo0`000ooonfX01_l0nooooo]Zoc_o0?oonf[ooh40oom/00;ooo]Z00_o07Ooool0
nOnX0?oooo]Zo`2Voooonf[oo`3fon_o0?oonf[oo`H0oaP0o`03oookJP06ool0o?oonf[ooo]Zoook
J_ooTP3ooaH01?oonfX00ooo0>[ooo]ZoookJP0>oookJP03o`1coooonf[ooo]Z00Sooo]Z00?o^Ol0
oomB0?oonfX00_oonfX01_l0:_oo?ol0oookJ_l0g?oooo]ZogSo00Oooo]Z00Co0?lKoa80oooonf[o
olX01?oonfX00ooo09?oo`0CoookJP05oookJP08om[o0?oonf[ooo]ZoookJ_lV0?oo8?l0oookJ_n4
0?l@oookJP03oc7o0?oonf[o0?mK00;ooo]Z00KoP_l0oookJ_l0ok7o033oo`3oCOl0j?l2oookJP03
o`H0oooonf[oT_l000Cooo]Z00?o403oo`0IoooonfX00ooonfX01?lE0?ooo`1AoookJ_l0[Ol3oook
JP03ool0NOoonf[ooo]Z00Gooo]Z00?o0?mCoookJ_oonfX00_oonfX01?l0oagooo]ZoookJ_l0hOla
oookJP00:_oonfX00onDo`3ojol0o`3o[@02o`3o[@;ooo]Z00Go0:KooookJ_oonf[ooo]ZojP0o`02
oookJP0<ool0nOoonf[ooo]Zo`1goooonf[o0?nJoom/0?l0olcooo]Zoon10?oonf[o>ol01?oonfX0
0ol0nooooo]ZoookJP03oookJP03ool30?oonf[ooo]Z00;ooo]Z00Coo`3MoiCo0?nDo`3o/ol01?nD
o`02oookJP?oU?l000Goo`27oiCo0?nDo`3oU?l0ool0K002oookJP;oiOl00_oonfX01?mQ0?oooo]Z
oookJ_oUo`04oookJP05on80oooonf[ooo]ZoookJ_l0oi803?oonfX00omX0?oooo]ZoookJP03oook
JP03o`3o3?oonf[o07Co00;oi_l00ooonfX00oooT03ooo]ZoookJP0@oookJP03onGo0?oo_P3ookh0
00?ooo]Z2_oob@0NoookJP;oA?l00oo[0?l01?m4o`3ookh0oonn0?oo_P06odCo00[ooo]Z0_ooT000
1?oonf[oi_l0onKo0?lH0?l4oookJP03ofP0oooonf[ooo]Z00;ooo]Z0_l00002o`3oTP03oookJ_l0
oi3ohP3o00;ooo]Z00So0?m5oookJ_mQ0?ooobh0oookJ_m=0?ooo`1/onGo00;oo`2700[ooo]Zooo9
0?oob@3oolT0ok?o0?oob@3o0:?oool0gOoonf[oolT00ooonfX01ol0nooooo]ZoookJ_lko`3ooo]Z
oon10?ooK0000_oonfX01Ol0Moooo`3iojP0ool0Y_oooo]Z00OoiOl00_oonfX01Ooo0?cooo]Zoook
J_oonf[oiOl000Gooo]Z00?oo`3ZoookJ_oonfX03OoonfX00ol0Looooo]ZoookJP08oookJPKo0?l<
00Oooo]ZonGo0?oonf[o0=coonGo0?l0omooiOl000Kooo]Z00?o0?lKoookJ_oobP001OoonfX00ooo
09?ooo]Zool04`05oookJP07om[o0?oQo`3ooo]ZoookJ_lV0?oo8?l0oh@0o`0AoookJP03onGo0?oo
nf[o0?mK00?ooo]Z00[oP_l0o`0`oooonf[ooo]Zo`3oCOl0j?oooo]Zo`H0oooonf[oT_l00ooonfX0
0ooUo`3o403oonGo0005onGo0004oiCo0?oUo`3oiOl0o`2]o`;ooo]Z00?oo`1ioookJ_oonfX01Ooo
nfX02Ol0oe?ooo]ZoookJ_oonf[o0?l8oookJ_l0oagooo]Zo`3Qo`1JoookJP03on_o0?oo0?Kooo]Z
00?ooo]Z00Co0:KooookJ_oonf[oZ03o0ooonfX03?oo0?Wooo]Zo`1goooonf[o0?nJoookJ_ooK03o
0?o<oookJ_ooP@3ooo]Zoc_o00?ooo]Z00?o0?_ooookJ_oonfX00ooonfX00ooo0`3ooo]ZoookJP02
oookJP05ogT0oooo0=gooo]Zo`2Soonco`001ooonfX00ooMo`3o0?oNool0Q`03oookJP07ool0K?oo
nf[ooo]Zodd0oooo;P3ooo]Zof40o`02oookJP03o`3oAOoonf[ooo]Z00?ooo]Z00CohP3ooookJ_oo
nf[o0?nB3?oonfX00omX0?oooo]ZoookJP04oookJP04oaP0ool0M?oooo]ZonKo00?ooo]Z00?ooi00
oookJ_oonfX04OoonfX3oonn00;ooo]Z1?l0o`D00ooonf[oL03oog00o`04on/0oakooo]Z00GoL03o
on/0ooo[0?ooj`3oo`3o1@03oonn013ooo]Z0_ooT0000ooonf[oi_l0onKo0002oaP0o`?ooo]Z00?o
J03ooookJ_oonfX00_oonfX3o`000004o`3oT_oonf[o0?n@on80o`?ooo]Z00Ko0?m5of40oomQ0?oo
obh0odd0oooonfX2ool0K003ool0Qooonf[ooo]Z00;ooo]Z00OoW`3ook?o0?l0XoooN@3oool0gOoo
nf[oo`<000?ooo]Z00Ko0?_ooookJ_lko`3ooo]Zoon10?ooK002oookJP05o`1goooonf[oo`3iojP0
ool0Y_l00_oonfX01Oo[o`3ooo]Zool60?oonf[o603o00?ooo]Z00Goo`3loookJ_oonf[ooi80oolF
0004oookJP03ool0j_oonf[ooo]Z00kooo]Z00?o07?ooookJ_oonfX02OoonfX02onio`3ooe80oook
J_oonf[o02[oocoo0?oonf[o0=cooookJ_mho`3o?@3o00Kooo]Z00Co0?lKoookJ_lB0?ooolX01?oo
nfX00ol0nOooo`2Cool04`05oookJP08om[o0?oQo`3ooo]ZoookJ_lV0?oooo]Zob3o0?n40?l@oook
JP03oc7o0?oonf[o0?mK00?ooo]Z00SoP_l0oookJ_l0<?oooo]Zo`3oCOl0j?oooo]Zo`H0o`;ooo]Z
00?oT_l0oookJ_oonfX00_oonfX00ol@0?oo01WooookJP03oookJP04ool0DOoonf[ooo]Zo`2]o`?o
oo]Z00?oo`1ioookJ_oonfX01?oonfX00ol0oe?ooo]ZoookJP02oookJP05o`3o2?l0oagooo]Zoook
J_l0hOl0<OoonfX002[ooo]Z0_nDo`04o`3o[@;ooo]Z00Co0:KooookJ_oonf[oZ03o0ooonfX01ooo
0?Wooo]Zo`1goooonf[o0?nJoom/0?l0ol`00_oonfX00oooP@3ooo]Zoc_o0004oookJP03o`3koooo
nf[ooo]Z00?ooo]Z00Goo`<0oookJ_oonf[ooo]Zool0g@03oiCo0003ok?o0?nDo`3ooo]Z00?ooo]Z
1?nDo`001?oo08OoU?l0oiCo0?oo06`2oookJPCoiOl000Gooo]Zof40oooonf[ooo]ZonGo0004oook
JP05on80oooonf[ooo]ZoookJ_l0oi803?oonfX00omX0?oooo]ZoookJP03oookJP05o`3o3?oonf[o
07CooookJ_oVo`000ooonfX2oon@01?ooo]Z1Ooo_P07ooo90004og00oooob@3oolT0ooo901Cooo]Z
1_m`0?l3on/0o`05odCo0?oo_P3ookh0oonn0?m4o`003ooonfX3oon@00;ooo]Z00?oi_l0o`1doolH
0?l01?oonfX00omX0?oooo]ZoookJP03oookJP06o`000?l0oi;o0000o`000?l0oi3ohP3o0_oonfX0
2ol0odGooo]Zof40oooo;P3ooo]Zodd0oooo06cooo]Zool0Qol0omkooo]Z00?oolT000Ko/ol0ooo9
0?l0Xoooo`3MoookJ_oob@03oookJP07o`3koooonf[ooo]Zoc_o0?oonf[ooh40oom/0002oookJP04
o`1goooo0?Wooo]ZojP0o`;ooo]Z1_oUo`02oookJP04ool0o?oonf[ooo]ZoookJP;oiOl01?oonfX0
0ooo0>[ooo]ZoookJP0>oookJP03o`1coooonf[ooo]Z00Sooo]Z1Ol0o``01ol0:_ooiOl0oookJ_l0
g?ooiOl0o`3ogooUo`001_oonfX01?l0oa_o08kooa80oooobP05oookJP03ool0Tooo01?ooo]Z00Co
oo]Z00?of_l0on7o0?oonfX00_oonfX00olV0?oo8?l0oh@0o`0AoookJP03oc7o0?l0oe_ooo]Z00;o
oo]Z00KoP_l0o`3o/?l0<?oooo]Zo`3oCOl0j?l2oookJP03o`H0oooonf[oT_l000?ooo]Z00?o403o
onGo0?oUo`000_oUo`000ooonf[oiOl0oiCo0002onGo0004oookJ_l0[Ooooo]Zool0N@Oooo]Z00?o
0?mCoookJ_oonfX00_oonfX01Ol0o`Sooo]Zo`3o7Ooonf[o0>7o05[ooo]Z00?ojol0oookJ_oo0?H0
0ooonfX01?l0Y_oooo]ZoookJ_nX0?l3oookJP08ool0nOoonf[o07OooookJ_l0oi[ooo]Zoom/0?l0
ol`2oookJP03oon10?lko`3ooo]Z00?ooo]Z00?o0?_ooookJ_oonfX00ooonfX00ooo0`3ooo]Zoook
JP02oookJP05ool0gOoonf[ooo]Zo`2Soonco`001ooonfX00ooMo`3oo`27oookJP02oookJP08ool0
K?oonf[ooo]Zodd0oooonf[oobh0oookJ_mQ0?l2oookJP03o`3oAOoonf[ooo]Z00?ooo]Z00CohP3o
oookJ_oonf[o0?nB3?oonfX00omX0?oooo]ZoookJP04oookJP03oaP0ool0M?oooo]Z00;oi_l00_oo
nfX2oon@01Cooo]Z1Ooo_P000ooonf[o0?l5o`3o1@03o`3o1@;oL03o0oo[0?lDoookJPGoL03o0oo[
0?l01?l0o`Gookh0oonn0?oo_P0AoookJP;ooi000_oonfX00ooVo`3o07CooaP0o`04oookJP03ofP0
oooonf[ooo]Z00?ooo]Z0_l000001?l0oi;o0000o`3oT?oR0?l2oookJP;o0?m500SoH@3ooookJ_oo
;P3oC@3ooookJ_oo06coo`27o`3ogPCooo]Z00OoW`3ook?o0?l0XoooN@3oool0gOoonf[oo`<000?o
oo]Z00Ko0?_ooookJ_lko`3ooo]Zoon10?ooK002oookJP05o`1goooonf[oo`3iojP0ool0Y_l00_oo
nfX01Ooo0?Kojol0ool60?oonf[o603o00?ooo]Z00Goo`3loookJ_oonf[ooo]ZoonB0005oookJP03
ool0j_oonf[ooo]Z00kooo]Z00?o07?ooookJ_oonfX02?oonfX00onio`3ooe80oookJP02oookJP06
o`0Zooloo`3ooo]Zo`3Loomho`3o0?oO1ooonfX01?l0oa_ooo]Zoa80oooobP04oookJP03o`3ioooo
09?ooo]Z00Gooo]Z00Sof_l0oookJ_oonf[ooo]ZobH0oolPo`3ooo]Zoh@0oa3ooo]Z00?o<Ol0oook
J_l0oe/00_oonfX01_n2o`3o0?n`o`3o/Ol0<?oooo]Zo`3oC@;ooo]Z00?o1P3ooookJ_nBo`001?oo
nfX00ol@0?oo01WooookJP04oookJP04ool0DOoonf[ooo]Zo`2]o`;ooo]Z00?oo`1ioookJ_oonfX0
1OoonfX00ol0oe?ooo]ZoookJP02oookJP05o`3o2?l0oagooo]ZoookJ_l0hOl0<OoonfX002[ooo]Z
0onDo`04o`3o[@05oookJ_l0Y_oooo]ZoookJ_nX0?l00ooonfX03?oo0?Wooo]ZoookJ_l0Mooo0?nJ
oookJ_ooK03o0?o<oookJ_ooP@3ooo]Zoc_o00Cooo]Z00?o0?_ooookJ_oonfX00ooonfX01_oo0`3o
oo]ZoookJ_oonf[oU?l0ool0g@;oU?l000?o/ol0oookJ_oonfX00ooonfX4oiCo0005ool0QonDo`3o
U?l0oiCo0?oo06`00_oonfX4onGo0004oookJ_mQ0?oooo]ZonGo00Cooo]Z00?ohP3ooookJ_oonfX0
0_oonfX2o`3oTP_ooo]Z00?oJ03ooookJ_oonfX00ooonfX01Ol0o`cooo]Zo`1doooonf[oi_l000Co
oo]Z0_ooT00FoookJP;ookh01Ooob@03o`3o1@03og00oooob@3oolT001Soj`3o00Co0?l5oonn0?oo
_P3ookh04OoonfX2oon@00?ooo]Z0_oVo`02oaP0o`?ooo]Z0_mX0?l6oookJP05o`3oT_l0003o0?n@
o`3oT?oR0?l00_oonfX01?l0odGoH@3oof40oooo;P02odd0o`04ool0K?oonf[oo`27o`3ogP;ooo]Z
0_oob@001?nco`3oolT0o`2Soooo0=d2ooo900?ooo]Z00Oo0?_ooookJ_oonf[o>ol0oookJ_ooP@3o
of`000;ooo]Z00Go07Ooool0nOoonf[oZ03oo`2Vo`02oookJPGoiOl00_oonfX01?oo0?cooo]Zoook
J_oonfX2onGo00Gooo]Z00?oo`3ZoookJ_oonfX03OoonfX00ol0Looooo]ZoookJP08oookJPGo0?l<
00So02[ooookJ_oUo`3ooo]Zo`3LoooUo`3o0?oOocd0o`Kooo]Z00?o0?lKoookJ_oobP001OoonfX0
0ooo09?oo`0CoookJP05oookJP03om[o0?oQo`3ooo]Z00;ooo]Z00?o9P3ooh@0oooonfX04?oonfX0
0olao`3ooo]Zo`3oF`03oookJP0:oh;o0?oUo`3o033ooookJ_l0odgo0>SooookJ_l60?oooo]Zoi;o
00Cooo]Z00Co403oonGo0?oUo`3oiOl00_oonfX01OoUo`3oU?l0onGo0?oUo`3o0:go00;ooo]Z00?o
o`1ioookJ_oonfX01OoonfX00ol0oe?ooo]ZoookJP02oookJP04o`3o2?l0oagooo]Zo`3Qoe_ooo]Z
00?ojol0oookJ_oo0?H01?oonfX01?l0Y_oooo]ZoookJ_nX0?l3oookJP04ool0nOoonf[o07Ooo`3o
VP;ooo]Z00Koof`0o`3oc?oonf[ooh40oookJ_lko`03oookJP03o`3koooonf[ooo]Z00?ooo]Z00?o
o`<0oookJ_oonfX00_oonfX01Omi0?ooo`3MoookJ_l0Xooo/ol000Sooo]Z00?o0?oNool0QooonfX0
0_oonfX02_oo06cooo]ZoookJ_m=0?oooo]Zool^0?oonf[oH@3ooookJ_l0odD5oookJP04on80oooo
nf[ooo]ZoookJP;o0?nB2ooonfX2ofP0o`Gooo]Z00Go603oo`1doooonf[ooo]ZonKo0003oookJP;o
oi005ooonfX4oonn00;ooo]Z1?l0o`D00om`0?ooj`3oon/0o`0Gon/0o`04o`3o1Ooo_P3ookh0oonn
01;ooo]Z0_ooT002oookJP;oi_l00_lH0?l3oookJP;oJ03o1_oonfX01Ol0003o0?nBo`3oT?l0oi3o
hP3o00;ooo]Z00Co0?m5oookJ_mQ0?ooobh00_m=0?l01?oonf[oo`1/ool0Qol0omh4oookJP07oil0
oonco`3o0:?oogT0oooo0=gooo]Zool30003oookJP0Do`3koooonf[o>ol0oookJ_ooP@3oof`0o`3o
V_oonf[o07OooookJ_oo0?WoZ03ooookJ_l0Y_oooo]Zool0m_o[o`3oo`H0oookJ_lH0?l3oookJP05
ool0o?oonf[ooo]ZoookJ_ooTP001OoonfX00ooo0>[ooo]ZoookJP0>oookJP03o`1coooonf[ooo]Z
00Sooo]Z00?o^Ol0oookJ_ooDP000_oonfX01ol0:_oo?ol0oookJ_l0g?oooo]ZogSo0?lm0?l01_oo
nfX01?l0oa_ooo]Zoa80oooobP04oookJP03o`3ioooo09?oo`0C00Gooo]Z00?of_l0on7o0?oonfX0
0_oonfX00olV0?oo8?l0oh@0o`0@oookJP03oc7o0?oonf[o0?mK00?ooo]Z00KoP_l0oookJ_l0ok7o
033oo`3oCOl0j?l2oookJP03o`H0oooonf[oT_l000Cooo]Z00?o403oo`0IoooonfX00ooonfX01?oo
057ooo]ZoookJ_l0[Ol3oookJP03ool0NOoonf[ooo]Z00Cooo]Z00?o0?mCoookJ_oonfX00ooonfX0
1?l0oagooo]ZoookJ_l0hOlboookJP00:_oonfX4oiCo00Co0?n]00Go0:KooookJ_oonf[ooo]ZojP0
o`03oookJP07ool0nOoonf[o07OooookJ_l0oi[oof`0o`3oc002oookJP03oon10?oonf[o>ol000Co
oo]Z00?o0?_ooookJ_oonfX00ooonfX01_oo0`3ooo]ZoookJ_oonf[oo`3MoiCo00;ooo]Z00?o/ol0
oookJ_oonfX00ooonfX4oiCo0006ool0QonDo`3oU?l0oiCo0?oo06cooo]Z1OoUo`001?mQ0?oooo]Z
oookJ_oUo`04oookJP03on80oooonf[ooo]Z00?ooo]Z00?o0?nBoookJ_oonfX02OoonfX00omX0?oo
oo]ZoookJP03oookJP04o`3o3?oonf[o07CooookJP;oi_l01?oonfX3oon@01Kooo]Z0ooob@02oonn
00Gooo]Z1om`0?l4oookJPOo0?l51ooo_P0BoookJP;ooi000ooonfX2onKo00;o603o0ooonfX2ofP0
o`Oooo]Z00Ko0?nBo`000?l0oi3o0000on80oooonfX2o`3oA@04of40oooo;P3ooo]Zodd0o`;oo`1/
00?ooo]Zool0Qol0omh00_oonfX2ooo90004ok?o0?l0Xooo0:?oool0g@CoolT00_oonfX03Ol0nooo
oo]Zoc_o0?oonf[ooh40o`3oV_ooK03ooo]Zo`1goooo0?Wooo]ZojP0ool0Y_l00_oonfX5onGo00;o
oo]Z00?oo`3loookJ_oonfX00_oonfX00ooUo`3ooo]ZoookJP03oookJP03ool0j_oonf[ooo]Z00go
oo]Z00?o07?ooookJ_oonfX02OoonfX4o`3o3008oookJ_l0:_ooiOl0oookJ_l0g?ooiOl0o`3ogolm
0?l6oookJP04o`3o6ol0S_oooo]Zooo:00Cooo]Z00?o0?Woool0Tooo01<01OoonfX00ooJo`3ohOl0
oookJP02oookJP03obH0oolPo`3oQ03o017ooo]Z00?o<Ol0o`3oFooonfX00_oonfX01_n2o`3o0?n`
o`0`oooonf[o0?m=o`3Xo`;ooo]Z00?o1P3ooookJ_nBo`001?oonfX01?l@0?ooiOl0onGo0?oUo`02
oookJP07onGo0?nDo`3oiOl0oookJ_l0[Ooooo]Zool0N@08oookJP09o`3oDooonf[ooo]ZoookJ_l0
o`Sooo]Zo`3o7Ooonf[oU?l000gooo]Z00?o0?ldoookJ_oonfX0BOoonfX01_oo1P3ooo]ZoookJ_o[
o`3ooo]Zool0mP?ooo]Z00Co0:KooookJ_oonf[oZ03o0ooonfX02?oo0?Wooo]Zo`1goooonf[o0?nJ
oookJ_ooK03o0?o<0_oonfX00oooP@3o>ol0oookJP03oookJP03o`3koooonf[ooo]Z00?ooo]Z00?o
o`<0oookJ_oonfX00_oonfX01Ooo0=gooo]ZoookJ_l0Xooo/ol000Sooo]Z00Go0?oNool0Qooonf[o
oo]Zool0K003oookJP04odd0oooonf[oobh0of40o`;ooo]Z00?o0?m5oookJ_oonfX00ooonfX00ooR
0?oooo]ZoookJP02oookJP03o`3oT_oonf[ooo]Z00[ooo]Z00?oJ03ooookJ_oonfX00ooonfX01OlH
0?oo07CooookJ_oonf[oi_l000Cooo]Z0oooT00HoookJPCookh01?oonfX00ol0o`GoL03oog00o`05
og00o`?ooo]Z1ol0o`D00ooonf[ookh0oonn0004oonn01;ooo]Z0oooT002oookJP;oi_l00_lH0?l3
oookJP;oJ03o2?oonfX01?l0oi;o0?n@o`000?oR0?l2oookJP06o`3oAOoonf[oH@3oool^0?m=0?oo
oo]Z0_oo06`00ooo08Oo0?oNoookJP03oookJP07oil0oonco`3o0:?oogT0oooo0=gooo]Zool30003
oookJP0>o`3koooonf[o>ol0oookJ_ooP@3ooo]Zoom/0?oonf[o07OooookJ_oo0?WoZ03ooookJ_l0
Y_l2oookJP04on_o0?oonf[oo`H0oaP0o`?ooo]Z00Goo`3loookJ_oonf[ooo]ZoonB0005oookJP03
ool0j_oonf[ooo]Z00kooo]Z00?o07?ooookJ_oonfX02OoonfX00onio`3ooe80oookJP02oookJP06
o`0Zooloo`3ooo]Zo`3Loomho`3o0?oO1ooonfX01?l0oa_ooo]Zoa80oooobP03oookJP04o`3ioooo
nf[oo`2Cool04`Gooo]Z00Sof_l0oookJ_oonf[ooo]ZobH0oolPo`3ooo]Zoh@0oa3ooo]Z00?o<Ol0
oookJ_l0oe/00_oonfX03?n2o`3o0?n`o`3o/Ol0<?oooo]Zo`3oCOl0j?oooo]Zo`H0oooonf[oo`3e
oi;o00?ooo]Z00?o403ooookJ_l06Ol01?oonfX01?oo057ooo]ZoookJ_l0[Ol2oookJP03ool0NOoo
nf[ooo]Z00Gooo]Z00?o0?mCoookJ_oonfX00_oonfX01Ol0o`So0?lMoookJ_oonf[o0>7o00gooo]Z
00?o0?ldoookJ_oonfX08_oonfX002[ooo]Z1OnDo`04o`3o[@04o`2Voooonf[ooo]ZojP0o`?ooo]Z
00Ooo`3ioookJ_oonf[o07OooookJ_l0oi[oof`000;ooo]Z00?ooh40oookJ_lko`001OoonfX00ol0
nooooo]ZoookJP02oookJP06ool30?oonf[ooo]ZoookJ_nDo`3oo`3M0_oonfX00onDo`3o/ol0oook
JP03oookJPGoU?l000Coo`27oiCo0?oonf[oo`1/0_oonfX5onGo00;oH@3o00?ooo]ZonGo0?oonfX0
0ooonfX00ooR0?oo0?n@oookJP03oookJP03o`3oT_oonf[ooo]Z00Wooo]Z00?oJ03ooookJ_oonfX0
0ooonfX00ol0o`co603oodCo0002odCo0003onKo0?oonf[ooo]Z00Cooo]Z0_ooT00FoookJP03ooo9
0?oonf[ooo]Z00Gookh01OoonfX2o`3o1@_ookh05ooonfX2oon@00?ooo]Z00Co07CoonKo0?lH0?oo
603o0ooonfX2ofP0o`Sooo]Z00?o0?nBoookJ_l0oi000_oR0?l01Ol0003o0?m5oookJ_mQ0?ooobh0
00;oC@3o00Goo`1/oookJ_oonf[oo`27omgo0003oookJP05ooo90?nco`3o0:?oooo90?oo0=d00ooo
b@03oookJP0=o`3koooonf[o>ol0oookJ_ooP@3o0?nJoom/0?oonf[o07Ooool0nOoonf[oZ03oo`2V
o`03oookJPCoiOl00_oonfX00ooo0?cooo]ZoookJP02oookJP03onGo0?oonf[ooo]Z00?ooo]Z00?o
o`3ZoookJ_oonfX03OoonfX00ol0Looooo]ZoookJP0:oookJP?o0?l<00Sooo]Zo`0Zoooonf[oiOl0
oookJ_l0g?ooiOl0o`3og`Oooo]Z00?o0?lKoookJ_oobP001OoonfX00ooo09?oo`0CoookJP05oook
JP03om[o0?oQo`3ooo]Z00;ooo]Z00?o9P3oob3o0?oonfX04?oonfX00olao`3ooo]Zo`3oF`03oook
JP06oh;o0?l0ok3o033ooookJ_l0odgo0>So0_oonfX00ol60?ooo`3eoi;o0003oookJP04oa00oooU
o`3oiOl0onGo00?ooo]Z00CoU?l0onGo0?oUo`3o0:go0_oonfX00ooo07Wooo]ZoookJP05oookJP03
o`3oDooonf[ooo]Z00;ooo]Z00Go0?l8o`3o7Ooonf[ooo]ZoiCo000=oookJP03o`3o=?oonf[ooo]Z
04Wooo]Z00Coo`H0oookJ_oonf[ojol00_oonfX01?oo0?Kooo]ZoookJ_l0Y_l3oookJP0;ojP0oooo
nf[ooo]ZoookJ_oo0?Wooo]Zo`1goooonf[o0?nJoom/0?l0ol`00_oonfX00oooP@3ooo]Zoc_o0004
oookJP03o`3koooonf[ooo]Z00;ooo]Z00?oo`<0oookJ_oonfX00_oonfX01_mi0?ooo`3MoookJ_l0
5ooo0:?ook?o00Oooo]Z00?ogOl0ool0QooonfX00_oonfX01ooo06cooo]ZoookJ_oonf[oC@3ooook
J_oo;P000_mQ0?l00ooonf[o0?m5oookJP04oookJP03on80ool0oi3ooo]Z00;ooo]Z00?o0?nBoook
J_oonfX02_oonfX00omX0?oooo]ZoookJP03oookJP;o603o00Co07CooookJ_oVo`3oi_l01OoonfX2
oon@01[ooo]Z1Ooo_P04oookJP?o0?l52ooo_P0FoookJP;ooi000ooonfX01?l0M?ooi_l0oaP0oolH
0?l3oookJP;oJ03o2OoonfX01ol0oi;o0?n@on80oooR0?oo0000oookJ_l0odD00_mQ0?l01ooo;P3o
C@3ooookJ_oo06cooo]Zool0QooMo`001?oonfX2ok?o0005o`0Goomi0?ooo`3MoookJ_oo0`000ooo
nfX03_l0nooooo]Zoc_o0?oonf[ooh40o`3oc?ooK03ooo]Zo`1goooonf[oo`3iojP0oooonf[o0:Ko
0_oonfX01?o[o`3ooo]Zool60?lH0?l3oookJP06ool0o?oonf[ooo]ZoookJ_ooTP3ooaH01OoonfX0
0ooo0>[ooo]ZoookJP0=oookJP03o`1coooonf[ooo]Z00Wooo]Z00?o^Ol0oookJ_ooDP000_oonfX0
1_l0:_oo?ol0oookJ_l0g?oooo]ZogSo00Oooo]Z00Co0?lKoookJ_lB0?ooolX01?oonfX00ol0nOoo
o`2Cool04`05oookJP03om[o0?oQo`3ooo]Z00;ooo]Z00?o9P3oob3o0?n40?l04?oonfX00olao`3o
oo]Zo`3oF`03oookJP06oh;o0?l0ok3o0?nao`0`ool0odgo0>So0_oonfX00ol60?oooo]Zoi;o0004
oookJP03oa00ool06Ooooo]Z00Cooo]Z00?oo`1AoookJ_l0[Ol00ooonfX00ooo07Wooo]ZoookJP05
oookJP03o`3oDooonf[ooo]Z00;ooo]Z00Go0?lMoookJ_oonf[ooo]Zo`3Qo`0=oookJP03o`3o=?oo
nf[ooo]Z02;ooo]Z000ZoookJP?oU?l000?ojol0o`3o[Ol0ojd00ol0ojd01Ol0Y_oooo]ZoookJ_oo
nf[oZ03o00?ooo]Z00Ooo`3ioookJ_l0Mooooo]Zo`3oV_ooK03o0?o<00;ooo]Z00?ooh40oookJ_lk
o`001?oonfX00ol0nooooo]ZoookJP03oookJP03ool30?oonf[ooo]Z00;ooo]Z00Goo`3MoookJ_oo
nf[oU?l0ok?o0004oookJPGoU?l000Coo`27oookJ_oonf[oo`1/0_oonfX6onGo0003of40oooUo`3o
oo]Z00Cooo]Z00?ohP3oo`3oT?oonfX00ooonfX2o`3oTP[ooo]Z0_mX0?l5oookJP;o603o0_m4o`00
0ooVo`3oA?l0odCo0002odCo00?ooo]Z0_ooT00LoookJPOookh08?oonfX2oon@00?ooo]Z00Co07Co
oaP0oolH0?oo603o1?oonfX00omX0?oooo]ZoookJP06oookJP;o0?nB00?ooo]Zon80oooR0?l00_l0
00002?l0odGoH@3oof40oooo;P3oC@3ooookJ_oo06cooo]Z0_oo08L01ooMo`3ooo]ZoookJ_oonf[o
olT0ok?o0?l0Xol01?oob@04oookJP0=o`3koooonf[o>ol0oookJ_ooP@3o0?nJoom/0?oonf[o07Oo
ool0nOoonf[oZ03oo`2Vo`03oookJP04on_o0?oUo`3oiOl0onGo00?ooo]Z00Goo`3loookJ_oonf[o
oo]ZonGo0005oookJP03ool0j_oonf[ooo]Z00kooo]Z00?o07?ooookJ_oonfX02OoonfX00onio`3o
0?l<o`3o3002oookJP07o`0ZoooUo`3ooo]Zo`3LoooUo`3o0?oOocd0o`06oookJP04o`3o6ol0S_oo
oo]Zooo:00Cooo]Z00?o0?Woool0Tooo01<01OoonfX00ooJo`3ooo]Zon7o0002oookJP03obH0oolP
o`3ooo]Z017ooo]Z00?o<Ol0o`3oFooonfX00ooonfX01On2o`3o033ooookJ_oonf[o0?m=00;ooo]Z
00?o1P3ooookJ_nBo`001?oonfX01?l@0?ooiOl0onGo0?oUo`03oookJP06oiCo0?oUo`3ooo]Zo`2]
oooonf[oo`1i2?oonfX00ol0oe?ooo]ZoookJP02oookJP04o`3o2?l0oagooo]ZoiCo00gooo]Z00?o
0?ldoookJ_oonfX0BooonfX01_oo1P3ooo]ZoookJ_o[o`3ooo]Zool0mP?ooo]Z00Co0:KooookJ_oo
nf[oZ03o0ooonfX02?oo0?Wooo]Zo`1goooonf[o0?nJoookJ_ooK03o0?o<0_oonfX00oooP@3o>ol0
oookJP03oookJP03o`3koooonf[ooo]Z00?ooo]Z00?oo`<0oookJ_oonfX00_oonfX01_mi0?ooo`3M
oookJ_l05ooo0:?ook?o00Oooo]Z00?ogOl0ool0QooonfX00_oonfX02_oo06cooo]ZoookJ_oonf[o
C@3ooookJ_oo;P3ooo]Zof40ool0odD6oookJP03on80ool0oi3ooo]Z00;ooo]Z0_l0oi8;oookJP03
ofP0oooonf[ooo]Z00Cooo]Z0_lH0?l00ol0M?oooo]ZonKo0006oookJP;ooi007OoonfX7oonn01oo
oo]Z0_ooT003oookJP04o`1doolH0?oo603ooaP0o`Cooo]Z00?oJ03ooookJ_oonfX01ooonfX2o`3o
TP;ohP3o0ol000000ol0odGoH@3oool^0002odd0o`;oo`1/0_oo08L00ooMo`3ooo]ZoookJP02oook
JP03ok?o0?l0Xooo01Oo00;oo`3M00?ooo]Zool30?oonfX00_oonfX03_l0nooooo]Zoc_o0?oonf[o
oh40o`3oc?ooK03ooo]Zo`1goooonf[oo`3ioookJ_nX0?oo0:Ko0_oonfX01?o[o`3ooo]Zool60?lH
0?l4oookJP05ool0o?oonf[ooo]ZoonB0?oo5P001OoonfX00ooo0>[ooo]ZoookJP0>oookJP03o`1c
oooonf[ooo]Z00Sooo]Z00?o^Ol0oookJ_ooDP000ooonfX01_l0:_oo?ol0o`3Loooonf[oN?l0o`3o
g`Oooo]Z00Co0?lKoookJ_lB0?ooolX00ooonfX01?l0nOoooo]Zool0Tooo01<5oookJP07om[o0?oQ
o`3ooo]ZoookJ_lV0?oo8?l0oh@0o`0AoookJP03oc7o0?oonf[o0?mK00?ooo]Z00SoP_l0o`3o/Ol0
<?oooo]Zo`3oCOl0j?oooo]Zo`H0o`;ooo]Z00OoT_l0oookJ_oonf[ooo]Zoa00oooo06[o01Wo00Co
oo]Z00Coo`1AoookJ_oonf[o0:go0_oonfX00ooo07Wooo]ZoookJP05oookJP03o`3oDooonf[ooo]Z
00?ooo]Z00Co0?lMoookJ_oonf[o0>7o3OoonfX00ol0ocCooo]ZoookJP0SoookJP00:ooonfX01?nD
o`3ooo]Zo`3o[Oo[o`04o`3o[@05o`2Vool0ojgooo]ZoookJ_nX0?l00ooonfX01ooo0?Wooo]Zoook
J_l0Mooooo]Zoom/0?l0ol`00_oonfX00oooP@3ooo]Zoc_o0005oookJP03o`3koooonf[ooo]Z00;o
oo]Z00?oo`<0oookJ_oonfX00_oonfX01Ooo0=gooo]ZoookJ_nO0?oo/ol000Cooo]Z1OnDo`001?oo
08Oooo]ZoookJ_oo06`2oookJPOoiOl000?oH@3oonGo0?oonfX00ooonfX00ooR0?oooo]Zo`3oT005
oookJP03o`3oT_oonf[ooo]Z00Wooo]Z00?oJ03ooookJ_oonfX01?oonfX2oaP0o`03odCo0?oVo`3o
i_l000OoA?l00_ooT00noookJP?ooi000ooonfX00ol0M?oo603ooaP0o`05oookJP;oJ03o1ooonfX2
o`3oTP;ooo]Z00OohP3ooookJ_l0003o0000o`3oAOmQ0?ooobh000;oC@3o0_oo06`01?oonf[oo`27
o`3og_oMo`03oookJP;o/ol000?o0:?oooo90?mi0?l00_oob@04oookJP0:o`3koooonf[o>ol0oook
J_ooP@3o0?nJoom/0?oonf[o07Ooool0n@;ooo]Z00GoZ03ooookJ_oonf[ooo]Zon_o0003onGo00?o
oo]Z00Goo`3loookJ_oonf[ooo]ZonGo0006oookJP03ool0j_oonf[ooo]Z00gooo]Z00?o07?ooook
J_oonfX02_oonfX2o`3o30;ooo]Z00Oo02[ooookJ_oUo`3o0=coonGo0?oonf[o0?oO00Oooo]Z00?o
0?lKoookJ_oobP001OoonfX00ooo09?oo`0CoookJP05oookJP03om[o0?oQo`3ooo]Z00;ooo]Z00?o
9P3oob3o0?oonfX04?oonfX00olao`3ooo]Zo`3oF`03oookJP06oh;o0?l0ok3o033ooookJ_l0odgo
0>So0_oonfX00ol60?oooo]Zoi;o0003oookJP04oa00oooo06[oiOl0onGo00?ooo]Z00CoU?l0onGo
0?oonf[o0:go0_oonfX00ooo07Wooo]ZoookJP06oookJP06o`3oDooonf[ooo]ZoookJ_l0o`So0?lM
0_oonfX00onDo`3ooo]ZoookJP0;oookJP03o`3o=?oonf[ooo]Z04_ooo]Z00Ooo`H0oookJ_oonf[o
oo]Zon_o0?oonf[oo`3f00;ooo]Z00Go0:KooookJ_oonf[ooo]ZojP0o`03oookJP07ool0nOoonf[o
07OooookJ_l0oi[oof`0o`3oc002oookJP03oon10?oonf[o>ol000Cooo]Z00?o0?_ooookJ_oonfX0
0_oonfX00ooo0`3ooo]ZoookJP02oookJP06ogT0oooo0=gooo]Zo`0Gool0Xooo/ol02?oonfX01Ol0
omkoo`27oookJ_oonf[oo`1/00Cooo]Z00KoC@3ooookJ_oo;P3ooo]Zof40ool0odD5oookJP03on80
oooonf[o0?n@00Cooo]Z00?o0?nBoookJ_oonfX02OoonfX00omX0?oooo]ZoookJP05oookJP;o603o
00?o07CoonKo0?oVo`001_oonfX2oon@03oooo]Z0_ooT003oookJP03o`1doolH0?oo603o00Gooo]Z
0_mX0?l8oookJP;o0?nB00?ooo]Zon80oooonfX00ol000002_l0odGoH@3oool^0?m=0?oooo]Zool0
K?oonf[oo`27o`3og_oMo`04oookJP04ok?o0?l0Xooo01Ooool0g@;ooo]Z01;oo`<0oookJ_oonf[o
oo]Zo`3koooonf[o>ol0oookJ_ooP@3o0?o<oom/0?oonf[o07OooookJ_oo0?Wooo]ZojP0ool0Y_l2
oookJP04on_o0?oonf[ooo]Zool600Cooo]Z00Goo`3loookJ_oonf[ooi80oolF0005oookJP03ool0
j_oonf[ooo]Z00kooo]Z00?o07?ooookJ_oonfX02OoonfX00onio`3ooo]ZoomB0002oookJP06o`0Z
ooloo`3ooo]Zo`3Loomho`3o0?oO1ooonfX01?l0oa_ooo]Zoa80oooobP04oookJP03o`3ioooo09?o
o`0C00Gooo]Z00?of_l0on7o0?oonfX00_oonfX00olV0?oo8?l0oh@0o`0@oookJP03oc7o0?oonf[o
0?mK00?ooo]Z00KoP_l0o`3o/?l0ok7o033ooookJ_l0odd2oookJP03o`H0oooonf[oT_l000Cooo]Z
00?o403ooookJ_l06Ol01?oonfX00ooo057ooo]Zo`2]o`03oookJP03ool0NOoonf[ooo]Z00Gooo]Z
00?o0?mCoookJ_oonfX00_oonfX01Ol0oagooo]ZoookJ_oonf[o0>7o00gooo]Z00?o0?ldoookJ_oo
nfX08ooonfX002cooo]Z00?oU?l0oookJ_o[o`001Ol0ojd01Ol0Y_oo0?n]oookJ_oonf[oZ03o00?o
oo]Z00Ooo`3ioookJ_oonf[o07OooookJ_ooK03o0?o<00;ooo]Z00?ooh40oookJ_lko`001OoonfX0
1Ol0nooooo]ZoookJ_oonf[oo`<000Gooo]Z00Goo`3MoookJ_oonf[oU?l0ok?o0003oookJP?oU?l0
0_oonfX01?nDo`3oo`27oookJ_oonfX2ool0K003oookJ_oUo`3oiOl000GoiOl000?oH@3oonGo0?oU
o`000ooonfX01?oR0?oooo]Zo`3oT?l0oi04oookJP03o`3oT_oonf[ooo]Z00Wooo]Z00?oJ03ooook
J_oonfX01OoonfX2oaP0o`03odCo0?oVo`3oA?l000OoA?l00_ooT00joookJP;ooi001?oonfX00ol0
M?oo603ooaP0o`05oookJP;oJ03o2?oonfX00ol0oi;ooo]ZoookJP02on80o`;ooo]Z00Oo0000o`3o
AOmQ0?ooobh0odd0oooonf[oo`1/00;ooo]Z00?oo`27o`3og_oMo`000ooonfX01Onco`3oW`3oo`2S
oooob@3oN@3o00;oolT01?oonfX02_l0nooooo]Zoc_o0?oonf[ooh40o`3oc?ooK03ooo]Zo`1goooo
0?T2oookJP06ojP0oooonf[ooo]ZoookJ_o[o`3ooo]Z0_oUo`03oookJP05ool0o?oonf[ooo]Zoook
J_oUo`001_oonfX00ooo0>[ooo]ZoookJP0=oookJP03o`1coooonf[ooo]Z00[ooo]Z00_o^Ol0o`3o
3?oonf[ooo]Zo`0Zoooonf[oiOl0oookJ_l0g?ooiOl0o`3og`07oookJP04o`3o6ol0S_ooA?l0ooo:
00Cooo]Z00?o0?Woool0Tooo01<01OoonfX00ooJo`3ooo]Zon7o0002oookJP03obH0oolPo`3ooo]Z
017ooo]Z00?o<Ol0o`3oFooonfX00ooonfX01On2o`3o0?n`oookJ_oonf[o0?m=00?ooo]Z00?o1P3o
oi;o0?oonfX00ooonfX00ol@0?ooo`1ZonGo0004oookJP04oiCo0?lE0?oooo]Zo`2]o`;ooo]Z00?o
o`1ioookJ_oonfX01OoonfX00ol0oe?ooo]ZoookJP02oookJP04o`3o2?l0oagooo]ZoiCo00kooo]Z
00?o0?ldoookJ_oonfX0C?oonfX01_oo1P3ooo]ZoookJ_o[o`3ooo]Zool0mP;ooo]Z00Go0:Kooook
J_oonf[ooo]ZojP0o`03oookJP08ool0nOoonf[ooo]Zo`1goooonf[o0?nJoom/0?l0ol`2oookJP03
oon10?lko`3ooo]Z00Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30005oookJP06ogT0oooo0=gooo]Z
o`0Gool0Xooo/ol02?oonfX01?l0omkoo`27oookJ_oonfX2ool0K0?ooo]Z00KoC@3ooookJ_oo;P3o
oo]Zof40ool0odD5oookJP04on80oooonf[o0?n@o`3oT0?ooo]Z00?o0?nBoookJ_oonfX02OoonfX0
0omX0?oooo]ZoookJP06oookJP;o603o00?o07CoonKo0?oonfX01_oonfX2oon@03_ooo]Z0_ooT003
oookJP03o`1doolH0?oo603o00Gooo]Z0_mX0?l8oookJP;o0?nB00?ooo]Zon80oooR0?l00_oonfX2
o`0000;oH@3o0_m=0?l01_oonf[oo`1/oookJ_oo08Oo0?oNomgo00Cooo]Z00Co/ol0o`2Sool05ooo
o`3M0_oonfX04_oo0`3ooo]ZoookJ_oonf[o0?_ooookJ_lko`3ooo]Zoon10?l0olcoof`0oookJ_l0
Mooooo]Zool0nOoonf[oZ03oo`2Vo`;ooo]Z00Cojol0oookJ_oonf[oo`H01?oonfX01Ooo0?cooo]Z
oookJ_oonf[ooi8000Gooo]Z00?oo`3ZoookJ_oonfX03_oonfX00ol0Looooo]ZoookJP09oookJP03
okWo0?oonf[ooe8000;ooo]Z00Oo02[ooookJ_loo`3o0=cooookJ_mho`3o0?oO00Oooo]Z00Co0?lK
oa80oooonf[oolX00ooonfX01?l0nOoooo]Zool0Tooo01<5oookJP07om[o0?oQo`3ooo]ZoookJ_lV
0?oo8?l0oh@0o`0AoookJP03oc7o0?oonf[o0?mK00?ooo]Z00KoP_l0o`3o/?l0<?oooo]Zo`3oCOl0
j?l2oookJP03o`H0oooonf[oT_l000?ooo]Z00?o403oool0J_l06Ol01?oonfX01?oo057o5@3ooook
J_l0[Ol3oookJP03ool0NOoonf[ooo]Z00Gooo]Z00?o0?mCoookJ_oonfX00_oonfX01?l0oagooo]Z
oookJ_l0hOl=oookJP03o`3o=?oonf[ooo]Z02Cooo]Z000/oookJP04oiCo0?oonf[o0?n]on_o00Co
0?n]00Go0:Koo`3o[Ol0ojgooo]ZojP0o`03oookJP0<ool0nOoonf[ooo]Zo`1goooonf[oof`0oook
J_l0olcooo]Zoon10?oonf[o>ol01OoonfX00ol0nooooo]ZoookJP02oookJP03ool30?oonf[ooo]Z
00;ooo]Z00KoN@3oool0gOoonf[oW`3ooiCo0?nco`03oookJP03oiCo0?oonf[ooo]Z00;ooo]Z00?o
U?l0ool0QooonfX00_oonfX00ooo06coiOl0onGo0006onGo0003of40oooUo`3oiOl000?ooo]Z00Co
hP3ooookJ_oonf[o0?n@1?oonfX2o`3oTP[ooo]Z00?oJ03ooookJ_oonfX01OoonfX01?m4o`3o603o
oaP0oooVo`07odCo00;ooo]Z0oooT00eoookJP;ooi001?oonfX01?l0M?oo603ooaP0oooVo`04oook
JP;oJ03o2?oonfX2o`3oTP03oookJ_oR0?oohP3o00?ooo]Z0_l0odD01OmQ0?oo0000odd0oooonf[o
o`1/00;ooo]Z00?oo`27o`3og_oMo`000ooonfX01Onco`3o0:?oo`2Soooob@3oN@3o00;oolT01?oo
nfX01Ol0nooooo]Zoc_o0?oonf[ooh4000;oof`000?ooo]Zo`1goooo0?T00_oonfX01OnX0?oo0:Ko
oookJ_oonf[ojol000;ooo]Z00GoiOl0oaP0oooonf[ooo]Zool0o004oookJP03onGo0?oonf[ooo]Z
00?ooo]Z00?oo`3ZoookJ_oonfX03_oonfX00ol0Looooo]ZoookJP09oookJP0<okWo0?oonf[ooe80
onGo0?oonf[o02[ooookJ_oUo`3o0=coonGo0?oonf[o0?oO1ooonfX00ol0oa_ooo]Zooo:0005oook
JP03o`3ioooo09?ooo]Z00Gooo]Z00?of_l0on7o0?oonfX00_oonfX00olV0?oo8?l0oookJP0@oook
JP03oc7o0?oonf[o0?mK00?ooo]Z00?oP_l0o`3o/?l0<?l00_oonfX01_l0odgooo]ZoookJ_l60?oo
oo]Zoi;o00?ooo]Z00Co403oo`1Moooo06[o01Wo1?oonfX01_nDo`3ooo]ZoookJ_l0[Ooooo]Zool0
N@Sooo]Z00?o0?mCoookJ_oonfX00_oonfX01?l0o`So0?lMoookJ_nDo`0=oookJP03o`3o=?oonf[o
0?m>04gooo]Z00Ooo`H0oookJ_oonf[ooo]Zon_o0?oonf[oo`3f00;ooo]Z00Co0:KooookJ_oonf[o
Z03o1?oonfX03?oo0?Wooo]Zo`1goooonf[o0?nJoom/0?oonf[o0?o<oookJ_ooP@3ooo]Zoc_o00Co
oo]Z00?o0?_ooookJ_oonfX00_oonfX00ooo0`3ooo]ZoookJP02oookJP07ogT0oooonf[oo`3Mo`0G
oonO0?oo0:?ook?o0008oookJP03ool0Qooonf[ooo]Z00;ooo]Z00[oo`1/oookJ_oonf[ooo]Zodd0
oooonf[oobh0oookJ_mQ0?oo0?m51OoonfX01?oR0?oooo]ZoookJ_l0oi03oookJP;o0?nB2_oonfX0
0omX0?oooo]ZoookJP07oookJP;o603o00?oi_l0o`1doooonfX01_oonfX3oon@03Kooo]Z0_ooT003
oookJP04o`1doolH0?oo603oonKo00Cooo]Z0_mX0?l8oookJP;o0?nB00?ooo]Zon80oooR0?l01?oo
nfX01Ol0odGoH@3oool^0?m=0?oooo]Z00;oo`1/00Cooo]Zool0Qol0omkogOl01?oonfX01?nco`3o
0:?oo`0Goooo0=d2oookJP09ool30?oonf[ooo]ZoookJ_l0nooooo]Zoc_o0?oonf[ooh4000;oof`0
00[ooo]Zo`1goooonf[oo`3ioookJ_nX0?oooo]Zo`2Voooonf[ojol00_oonfX00ooo1P3o603ooook
JP02oookJP05ool0o?oonf[ooo]ZoookJ_ooTP001_oonfX00ooo0>[ooo]ZoookJP0>oookJP03o`1c
oooonf[ooo]Z00Sooo]Z00Co^Ol0oookJ_oonf[ooe800_oonfX01_l0:_oo?ol0oookJ_l0g?ooN?l0
o`3og`Oooo]Z00Co0?lKoookJ_lB0?ooolX01?oonfX00ol0nOoooo]Zool0T`05oookJP03om[o0?oQ
o`3ooo]Z00;ooo]Z00?o9P3oob3o0?n40?l04?oonfX00olao`3ooo]Zo`3oF`03oookJP06oh;o0?l0
ok3o0?nao`0`oooonf[o0?m=0_oonfX00ol60?oooo]Zoi;o0004oookJP03oa00oooo06[o01Wo00Co
oo]Z00Coo`1AoookJ_oonf[o0:go0_oonfX00ooo07Wooo]ZoookJP05oookJP03o`3oDooonf[ooo]Z
00?ooo]Z00Co0?lMoookJ_oonf[o0>7o3OoonfX00ol0ocCooo]Zo`3oCP0ToookJP00;OoonfX00onD
o`3o0?n]on_o0004o`3o[@05o`2Voooonf[ooo]ZoookJ_nX0?l01?oonfX03?oo0?Wooo]ZoookJ_l0
Moooof`0o`3oV_oonf[o0?o<oookJ_ooP@3ooo]Zoc_o00Gooo]Z00Go0?_ooookJ_oonf[ooo]Zool3
0005oookJP06ool0gOoonf[ooo]Zoil0oonDo`3o/ol02?oonfX00onDo`3oo`27oookJP02oookJP03
ool0K?oUo`3oiOl000KoiOl000?oH@3ooookJ_oonfX00ooonfX2on80o`03oookJ_l0oi3ooo]Z00Co
oo]Z00?o0?nBoookJ_oonfX02?oonfX00omX0?oooo]ZoookJP05oookJP;oA?l00olH0?l01?oVo`3o
A?l0odCo0?m4o`06oookJP;ooi00<?oonfX3oon@00?ooo]Z00Co07CoonKo0?lH0?oo603o1OoonfX2
ofP0o`Sooo]Z0_l0oi800ooonf[o0?n@on80o`04oookJP03o`3oAOmQ0?ooH@3o00;oC@3o0_oo06`2
oookJP03ool0Qol0omkogOl000?ooo]Z00Go/ol0o`2Soooob@3oolT0ogT0o`04ooo900;ooo]Z00_o
0?_ooookJ_lko`3ooo]Zoon10?ooK03o0?nJoookJ_l0Moooo`3ioookJP02ojP0o`04o`2Voooonf[o
oo]Zon_o00;ooo]Z00?oiOl0oaP0oooonfX00_oonfX01Ooo0?cooo]ZoookJ_oonf[oiOl000Gooo]Z
00?oo`3ZoookJ_oonfX03_oonfX00ol0Looooo]ZoookJP0:oookJP05okWo0?ooDP3oiOl0onGo0?l0
:_l00_oUo`001?oonf[o0=coonGo0?l0oml7oookJP04o`3o6ol0S_ooA?l0ooo:00Cooo]Z00?o0?Wo
ool0Tooo01<01OoonfX00ooJo`3ooo]Zon7o0002oookJP03obH0oolPo`3ooo]Z013ooo]Z00?o<Ol0
oookJ_l0oe/01?oonfX01On2o`3o0?n`oookJ_oonf[o0?m=00?ooo]Z00?o1P3oool0mOnBo`000ooo
nfX00ol@0?ooo`1Zo`0Io`04oookJP04oiCo0?lE0?oooo]Zo`2]o`;ooo]Z00?oo`1ioookJ_oonfX0
1OoonfX00ol0oe?ooo]ZoookJP02oookJP04o`3o2?l0oagooo]ZoiCo00kooo]Z00?o0?ldoookJ_l0
odh0C_oonfX01_oo1P3ooo]ZoookJ_o[o`3ooo]Zool0mP;ooo]Z00Go0:KooookJ_oonf[ooo]ZojP0
o`03oookJP06ool0nOoonf[ooo]Zo`1goooonf[oof`00_oonfX01?l0olcooo]Zoon10?lko`05oook
JP05o`3koooonf[ooo]ZoookJ_oo0`001OoonfX01omi0?ooo`3MoookJ_l05ooo0:?ooookJ_nco`00
2?oonfX00ooo08Oooo]ZoookJP02oookJP09ool0K?oonf[ooo]ZoookJ_m=0?oooo]Zool^0?oonf[o
H@3o00Kooo]Z0_oR0?l00ooonf[o0?n@oookJP03oookJP03o`3oT_oonf[ooo]Z00Sooo]Z00?oJ03o
oookJ_oonfX02?oonfX2oaP0o`;oi_l000?o07CooookJ_oonfX01OoonfX2oon@037ooo]Z0oooT002
oookJP04o`1doooVo`3o603ooaP0o`Gooo]Z0_mX0?l9oookJP04o`3oT_oonf[o0?n@on80o`Gooo]Z
00Ko0?m5of40oooo;P3oC@3oo`000?oo06`2oookJP03ool0Qol0omkogOl000Cooo]Z00Co/ol0oook
J_oo0=goo`3M0_oonfX03ooo0`3ooo]ZoookJ_oonf[o0?_ooookJ_lko`3ooo]Zoon10?ooK03ooo]Z
o`3oV_l0Mooooo]Zool0n@02ojP0o`04oookJ_l0Y_oooo]Zon_o00;ooo]Z00?oo`H0oaP0oooonfX0
0ooonfX01Ooo0?cooo]ZoookJ_ooTP3ooaH000Gooo]Z00?oo`3ZoookJ_oonfX03_oonfX00ol0Looo
oo]ZoookJP09oookJP03okWo0?oonf[ooe8000;ooo]Z00Oo02[ooookJ_loo`3o0=cooookJ_mho`3o
0?oO00Oooo]Z00Co0?lKoa80oooonf[oolX00ooonfX01?l0nOoooo]Zool0Tooo01<5oookJP07om[o
0?oQo`3ooo]ZoookJ_lV0?oooo]Zob3o000AoookJP03oc7o0?oonf[o0?mK00?ooo]Z00KoP_l0o`3o
/?l0<?oooo]Zo`3oCOl0j?l2oookJP03o`H0oooonf[oT_l000Cooo]Z00?o403oo`0IoooonfX01?oo
nfX00ooo057ooo]Zo`2]o`03oookJP03ool0NOoonf[ooo]Z00Gooo]Z00?o0?mCoookJ_oonfX00_oo
nfX01?l0oagooo]ZoookJ_l0hOl>oookJP03o`3o=?oonf[o0?m>02Cooo]Z000]oookJP04oiCo0?l0
ojgo0?n]on_o00;o0?n]0_oonfX01Ol0Y_oooo]ZoookJ_oonf[oZ03o00Cooo]Z00_oo`3ioookJ_l0
Mooooo]Zoom/0?l0oi[o0?o<oookJ_ooP@3ooo]Zoc_o0006oookJP05o`3koooonf[ooo]ZoookJ_oo
0`001?oonfX01_mi0?ooo`3MoookJ_l05oooU?l0ok?o00Sooo]Z00?oU?l0ool0QooonfX00ooonfX0
0ooo06coiOl0onGo0005onGo0003oookJ_mQ0?oooo]Z00Gooo]Z00CohP3ooookJ_l0oi3o0?n@1?oo
nfX2o`3oTPWooo]Z00?oJ03ooookJ_oonfX01_oonfX3odCo00;o603o0_oVo`000om4o`3ooo]Zoook
JP05oookJP;ooi00:OoonfX5oon@00?ooo]Z0_oVo`03oaP0o`Gooo]Z0_mX0?l8oookJP;o0?nB00Co
oo]Zo`3oT?oR0?oohP3o0ooonfX2o`3oA@06of40oooo;P3oC@3oo`000?oo06co00000_oonfX00ooo
08Oo0?oNomgo0003oookJP05ok?o0?l0XoooolT0ooo90?mi0?l01_oob@003_l0nooooo]Zoc_o0?oo
nf[ooh40oom/0?l0oi[ooo]Zo`1goooo0?Wooo]ZojP0oooonf[o0:Ko0_oonfX01Oo[o`3ooo]Zoook
J_oo1P3o603o00?ooo]Z00Goo`3loookJ_oonf[ooo]ZonGo0006oookJP03ool0j_oonf[ooo]Z00go
oo]Z00?o07?ooookJ_oonfX02_oonfX01Onio`3ooe80o`3o<ooUo`3o02[o00?oiOl000?o0=coonGo
0?l0oml02?oonfX00ol0oa_oA?l0ooo:0005oookJP03o`3ioooo09?ooo]Z00Gooo]Z00?of_l0on7o
0?oonfX00_oonfX00olV0?oo8?l0oookJP0@oookJP03oc7o0?oonf[o0?mK00Cooo]Z00GoP_l0o`0`
oooonf[ooo]Zo`3oC@02oookJP03o`H0oooonf[oT_l000?ooo]Z00Co403oo`1Moooo06[o01Wo1?oo
nfX01_nDo`3ooo]ZoookJ_l0[Ooooo]Zool0N@Sooo]Z00?o0?mCoookJ_oonfX00_oonfX01?l0o`So
0?lMoookJ_nDo`0=oookJP04o`3o=?oonf[ooo]Zo`3oCTkooo]Z00Woo`H0oookJ_oonf[ooo]Zon_o
0?oonf[oo`3foookJ_l0Y_l00ooonfX00onX0?oooo]ZoookJP02oookJP03ool0nOoonf[o07Oo00;o
oo]Z00Ooof`0oookJ_l0olcooo]Zoon10?oonf[o>ol000Gooo]Z00Go0?_ooookJ_oonf[ooo]Zool3
0004oookJP07ogT0oooonf[oo`3Mo`0Goooonf[o0:?ook?o0008oookJP03o`3og_oo08Oooo]Z00?o
oo]Z00Woo`1/oookJ_oonf[ooo]Zodd0oooonf[oobh0oookJ_mQ0?l01ooonfX01?oR0?oooo]Zo`3o
T?l0oi03oookJP;o0?nB2OoonfX00omX0?oooo]ZoookJP09oookJP;o603o0ooVo`07oookJP;ooi00
:_oonfX5oon@00;ooo]Z0_oVo`03oaP0o`Gooo]Z0_mX0?l9oookJP;o0?nB00?o0?n@on80oooR0?l0
1?oonfX2o`3oA@05of40oom=0?ooC@3oo`000?oo06`00_oonfX00ooo08Oo0?oNomgo0003oookJP;o
/ol000?ooo]Zool0gOmi0?l00_oonfX04?oo0`3ooo]ZoookJ_oonf[o0?_ooookJ_lko`3ooo]Zoon1
0?ooK03ooo]Zo`3oV_l0Mooooo]Zool0nOnX0?l2oookJP03o`2Voooonf[ojol000;ooo]Z00?oo`H0
oaP0oooonfX00ooonfX01Ooo0?cooo]ZoookJ_ooTP3ooaH000Gooo]Z00?oo`3ZoookJ_oonfX03_oo
nfX00ol0Looooo]ZoookJP09oookJP0<okWo0?oonf[ooe80o`3o<ooonf[o02[ooookJ_loo`3ooo]Z
o`3Loomho`3o0?oO1ooonfX01?l0oa_ooo]Zoa80oooobP04oookJP03o`3ioooonf[oo`2C00Gooo]Z
00?of_l0on7o0?oonfX00_oonfX00olV0?oo8?l0oh@0o`0@oookJP03oc7o0?oonf[o0?mK00Cooo]Z
00GoP_l0o`3o/Ol0<?oooo]Zo`3oC@03oookJP03o`H0oooonf[oT_l000?ooo]Z00?o403oool0J_l0
6Ol01?oonfX01?oo057ooo]ZoookJ_l0[Ol2oookJP03ool0NOoonf[ooo]Z00Gooo]Z00?o0?mCoook
J_oonfX00ooonfX01?l0oagooo]ZoookJ_l0hOl=oookJP04o`3o=?oonf[ooo]Zo`3oCRCooo]Z000^
oookJP05oiCo0?l0ojgo0?n]on_o0?l0ojd00_oonfX01Ol0Y_oooo]ZoookJ_oonf[oZ03o00Cooo]Z
00coo`3ioookJ_oonf[o07Oooom/0?l0oi[ooo]Zo`3oc?oonf[ooh40oookJ_lko`05oookJP05o`3k
oooonf[ooo]ZoookJ_oo0`001OoonfX01_oo0=goiOl0oookJ_l05oooU?l0ok?o00Sooo]Z00?oU?l0
ool0QooonfX00ooonfX00ooo06coiOl0onGo0003onGo0003ool^0?oonf[ooo]Z00;oH@3o1OoonfX2
on80o`03oookJ_l0oi3ooo]Z00Cooo]Z00?o0?nBoookJ_oonfX01ooonfX2ofP0o`Oooo]Z1?m4o`02
oaP0o`Coi_l01_oonfX5oon@01oooo]Z1OooT004oookJPCoi_l00_lH0?l6oookJP;oJ03o2?oonfX2
o`3oTP;ooo]Z0_oR0?l3oookJP;o0?m500Kooo]Zof40oom=0?ooC@3oo`000?oo06`2o`0000;oo`27
00?o0?oNomgo0?oonfX00_oonfX01Onco`3o0:?oooo90?oob@3oN@3o00GoolT00_l0nol03Ooob@3o
>ol0oookJ_ooP@3oof`0o`3oV_oonf[o07Ooool0nOoonf[oZ03ooookJ_l0Y_l00_oonfX01Ooo0?Ko
jol0oookJ_oo1P3o603o00?ooo]Z00Goo`3loookJ_oonf[ooo]ZonGo0006oookJP03ool0j_oonf[o
oo]Z00gooo]Z00?o07?ooookJ_oonfX02_oonfX00onio`3ooo]ZoomB0002onGo0007o`0ZoooUo`3o
iOl0onGo0?l0g?ooiOl0o`3og`07oookJP04o`3o6ol0S_ooA?l0ooo:00Cooo]Z00?o0?Woool0Tooo
01<01OoonfX00ooJo`3ooo]Zon7o0003oookJP03obH0oolPo`3ooo]Z00oooo]Z00?o<Ol0oookJ_l0
oe/01?oonfX01On2o`3o0?n`oookJ_oonf[o0?m=00?ooo]Z00?o1P3ooookJ_nBo`000ooonfX00ol@
0?ooo`1Zo`0Io`05oookJP03oiCo0?oonf[o0:go00;ooo]Z00?oo`1ioookJ_oonfX01_oonfX00ol0
oe?ooo]ZoookJP02oookJP04o`3o7Ooonf[ooo]ZoiCo00gooo]Z00Co0?ldoookJ_l0odko0?l^Cooo
nfX01_oo1P3ooo]ZoookJ_o[o`3ooo]Zool0mP;ooo]Z00Go0:KooookJ_oonf[ooo]ZojP0o`04oook
JP05ool0nOoonf[o07OooookJ_ooK0000_oonfX01?l0olcooo]Zoon10?lko`05oookJP05o`3koooo
nf[ooo]ZoookJ_oo0`001OoonfX01omi0?ooo`3MoookJ_l05ooooo]Zo`2Soonco`002?oonfX00ooo
08Oooo]ZoookJP03oookJP06ool0K?oonf[ooo]ZoookJ_m=0?ooobh00_oonfX2of40o`Kooo]Z0_oR
0?l00ooonf[o0?n@oookJP03oookJP03o`3oT_oonf[ooo]Z00Oooo]Z0_mX0?l;oookJP;o603o00Co
oo]ZonKo0?oVo`3oi_l01_oonfX5oon@023ooo]Z1OooT003oookJPCoi_l00_lH0?l6oookJP;oJ03o
2OoonfX2o`3oTP03oookJ_oR0?oohP3o00Cooo]Z0_l0odD2of40o`05odd0ool0003oo`1/ool0K?l0
00000_oo08L00ol0omkogOl0oookJP02oookJP05ok?o0?l0Xooo01Ooool0gOmi0?l00_oonfX00ooo
0`3ooo]ZoookJP02o`3ko`0;oookJ_lko`3ooo]Zoon10?ooK03ooo]Zo`3oV_l0Mooooo]Zool0nOnX
0?l00_oonfX01ol0Y_oooo]Zool0m_o[o`3ooo]Zool60?lH0?l01?oonfX01Ooo0?cooo]ZoookJ_oo
TP3ooaH000Gooo]Z00?oo`3ZoookJ_oonfX03_oonfX00ol0Looooo]ZoookJP09oookJP04okWo0?oo
nf[ooo]ZoomB00;ooo]Z00Oo02[ooookJ_loo`3o0=cooookJ_mho`3o0?oO00Kooo]Z00Go0?lKo`2>
oolB0?oooo]Zooo:0003oookJP04o`3ioooonf[oo`2Cool04`Cooo]Z00?of_l0oookJ_oQo`000ooo
nfX00olV0?oo8?l0oookJP0@oookJP03oc7o0?oonf[o0?mK00?ooo]Z00?oP_l0o`3o/?l0<?l00_oo
nfX01_l0odgooo]ZoookJ_l60?oooo]Zoi;o00Cooo]Z00?o403oo`0IoooonfX01?oonfX00ooo057o
oo]Zo`2]o`03oookJP03ool0NOoonf[ooo]Z00Gooo]Z00?o0?mCoookJ_oonfX00_oonfX01Ol0oago
0?l8oookJ_oonf[o0>7o00gooo]Z00Co0?ldoookJ_l0odko0?l^9?oonfX002[ooo]Z00co603ooook
J_oonf[ooo]ZoiCo0?l0ojgooo]Zon_o0?oonf[o0?n]oookJ_l0Y_l4oookJP03ojP0oooonf[ooo]Z
00;ooo]Z00_oo`3ioookJ_l0Mooooo]Zoom/0?l0oi[ooo]Zo`3oc?ooP@3ooo]Zoc_o0006oookJP05
o`3koooonf[ooo]ZoookJ_oo0`001?oonfX01ooUo`3oo`3MonGo0?oonf[o01OooiCo0?nco`002?oo
nfX00onDo`3oo`27oookJP03oookJP07ool0K?oUo`3oiOl0onGo0?oonf[oiOl0ool^0003oookJP03
of40oooonf[ooo]Z00Cooo]Z00CohP3ooookJ_l0oi3o0?n@1?oonfX00ol0oi;ooo]ZoookJP08oook
JP?oJ03o1OoonfX4odCo0005oookJ_lH0?oo603ooookJ_m4o`000ooVo`08oookJPSooi004_oonfX5
oon@00Kooo]Z0ooVo`02o`1do`;o603o1ooonfX00omX0?oooo]ZoookJP07oookJP05o`3oT_oonf[o
oo]Zo`3oT?oR0?l01?oonfX01Ol0odGooo]Zof40oomQ0?ooC@3o00;ooo]Z00Ooo`1/o`000?l0003o
o`27oookJ_l0omkogOl000?ooo]Z00Go/ol0o`2Soooob@3ooo]ZogT0o`05ooo9000?o`3koooob@3o
oo]Zoc_o0?oonf[ooh40oom/0?l0oi[ooo]Zo`1goooo0?Wooo]ZojP0oooonf[o0:Ko00;ooo]Z00Go
o`3fon_o0?oonf[oo`H0oaP0o`03oookJP05ool0o?oonf[ooo]ZoookJ_oUo`001_oonfX00ooo0>[o
oo]ZoookJP0>oookJP03o`1coooonf[ooo]Z00Wooo]Z00Ko^Ol0oookJ_ooDP3o0?lconGo0?l0:_l3
onGo0004o`3LoooUo`3o0?oOonGo00Oooo]Z00?o0?lKodCo0?oobP001?oonfX00ol0nOoooo]Zool0
T`05oookJP04om[o0?oonf[ooo]Zon7o00;ooo]Z00?o9P3oob3o0?oonfX04?oonfX00olao`3ooo]Z
o`3oF`04oookJP05oh;o0?l0<?oooo]ZoookJ_l0odd00ooonfX00ol60?ooT_l0oookJP03oookJP03
oa00oooo06[o01Wo00Cooo]Z00KoU?l0oookJ_oonf[o0:gooookJ_oo07T8oookJP03o`3oDooonf[o
oo]Z00;ooo]Z00Co0?l8o`3o7Ooonf[oU?l03OoonfX01Ol0ocCooo]ZoookJ_l0odko0?l^04_ooo]Z
00Go603ooookJ_oonf[ooo]Zool60003oookJP05on_o0?oonf[oo`3foookJ_l0Y_l00ooonfX00onX
0?oooo]ZoookJP02oookJP03ool0nOoonf[o07Oo00;ooo]Z00Ooof`0oookJ_oonf[o0?o<oon10?oo
nf[o>ol000Gooo]Z00Go0?_ooookJ_oonf[ooo]Zool30004oookJP08ogT0oooonf[oo`3MoookJ_l0
5ooo0:?ooil0oonco`08oookJP03ool0Qooonf[ooo]Z00?ooo]Z00Koo`1/oookJ_oonf[ooo]Zodd0
oooo;P03oookJP03of40oooonf[ooo]Z00Gooo]Z00CohP3ooookJ_l0oi3o0?n@0ooonfX00ol0oi;o
oo]ZoookJP08oookJP?oJ03o2_oonfX2oaP0o`03oookJ_l0M?ooi_l000?oi_l01ooonfX8oon@01?o
oo]Z1OooT005oookJP?oi_l00_l0M?l2oaP0o`Oooo]Z00?oJ03ooookJ_oonfX01ooonfX2o`3oTP03
oookJ_l0oi3ohP3o00Gooo]Z00?o0?m5oookJ_mQ0?l00_m=0?l02?oonf[oo`1/o`000?l0003oo`27
oookJ_l0omkogOl00ooonfX01Onco`3o0:?oo`0Goooo0=goN@3o00;ooo]Z00Coo`<0oookJ_oonf[o
0?_o0_oonfX02_lko`3ooo]Zoon10?ooK03ooo]Zo`3oV_l0Mooooo]Zool0nOnX0?l2oookJP07o`2V
oooonf[oo`3fon_o0?oonf[oo`H0oaP0o`04oookJP05ool0o?oonf[ooo]ZoookJ_ooTP001_oonfX0
0ooo0>[ooo]ZoookJP0>oookJP03o`1coooonf[ooo]Z00Wooo]Z00co^Ol0oookJ_ooDP3o0?lcoook
J_l0:_oooo]Zocoo0?l0g?oooo]ZogSo0?l0oml7oookJP04o`3o6olB0?oooo]Zooo:00?ooo]Z00Co
0?WooookJ_oonf[oo`2C1OoonfX00ooJo`3ooo]Zon7o0002oookJP03obH0oolPo`3oQ03o013ooo]Z
00?o<Ol0oookJ_l0oe/01?oonfX01On2o`3o0?nao`0`oooonf[o0?m=00?ooo]Z00?o1P3ooookJ_nB
o`000ooonfX00ol@0?ooo`1Zo`0Io`04oookJP04oaD0oooo057ooo]Zo`2]o`;ooo]Z00?oo`1ioook
J_oonfX01_oonfX00ol0oe?ooo]ZoookJP02oookJP04o`3o7Ooonf[ooo]Zo`3Qo`gooo]Z00Go0?ld
oookJ_oonf[o0?m>o`3o;P0ToookJP00:_oonfX01OlH0?oooo]ZoookJ_oonf[oU?l000?ooo]Z00Go
jol0oookJ_l0ojgooo]Zo`2Vo`03oookJP03ojP0oooonf[ooo]Z00;ooo]Z00Koo`3ioookJ_oonf[o
07OooookJ_ooK002oookJP03o`3oc?ooP@3o>ol000Kooo]Z00?o0?_ooookJ_oonfX00_oonfX00ooo
0`3ooo]ZoookJP02oookJP06onGo0?oo0=goiOl0onGo0?nDo`3o/ol02OoonfX00onDo`3oo`27oook
JP02oookJP03onGo0?oo06coiOl000?ooo]Z00?oiOl0ool^0?oonfX00_oonfX00omQ0?oo0?m5oook
JP04oookJP;ohP3o00?ooo]Zo`3oT?oonfX00ooonfX2o`3oTP_ooo]Z0omX0?l3oookJP?oA?l00ooo
nfX2oaP0o`;ooo]Z00CoA?l0onKo0?oVo`3oi_l03OoonfX8oon@00Gooo]Z1OooT007oookJPCoi_l0
00?o07CooaP0oolH0?l00_lH0?l7oookJP;oJ03o2?oonfX2o`3oTP04oookJ_l0oi3ohP3oon80o`?o
oo]Z0_l0odD01Ooonf[oH@3oodd0oom=0?oooo]Z00;oo`1/0_l000001?oo08Oo0000o`3og_oMo`03
oookJP03ok?o0?l0XoooolT000;oN@3o1Ooob@003ol0nooooo]ZoookJ_lko`3ooo]Zoon10?ooK03o
0?nJoookJ_l0Moooo`3ioookJ_nX0?oooo]Zo`2Vo`02oookJP05ool0m_o[o`3ooo]Zool60?lH0?l0
1?oonfX00ooo0?cooo]ZoookJP02onGo00Gooo]Z00?oo`3ZoookJ_oonfX03_oonfX00ol0Looooo]Z
oookJP0:oookJP05okWo0?ooDP3o0?lcoookJ_l0:_l01OoUo`000olm0?oo0?oOoookJP06oookJP04
o`3o6ol0S_ooA?l0ooo:00Cooo]Z00?o0?Woool0Tooo01<01OoonfX00ooJo`3ooo]Zon7o0003oook
JP03obH0oolPo`3ooo]Z00oooo]Z00?o<Ol0oookJ_l0oe/01OoonfX01On2o`3o033ooookJ_l0j?oo
0?m=00;ooo]Z00?o1P3ooookJ_nBo`000ooonfX00ol@0?oooo]Zo`0Io`05oookJP03oiCo0?oonf[o
0:go00;ooo]Z00?oo`1ioookJ_oonfX01_oonfX00ol0oe?ooo]ZoookJP02oookJP04o`3o7Ooonf[o
oo]ZoiCo00gooo]Z00Co0?ldoookJ_oonf[o0?m>C?oonfX00olH0?oooo]ZoookJP02oookJP04ool6
0?oonf[ooo]Zon_o00;ooo]Z00?oo`3foookJ_l0Y_l00_oonfX00onX0?oooo]ZoookJP03oookJP03
ool0nOoonf[o07Oo00;ooo]Z00Koof`0oookJ_l0olcooo]Zoon10?lko`05oookJP03o`3koooonf[o
oo]Z00;ooo]Z00?oo`<0oookJ_oonfX00_oonfX01omi0?oooo]Zool0gOoonf[o01Ooo`2Soonco`00
2OoonfX00ooo08Oooo]ZoookJP03oookJP06ool0K?oonf[ooo]ZoookJ_m=0?ooobh00ooonfX00omQ
0?oo0?m5oookJP05oookJP;ohP3o00?ooo]Zo`3oT?oonfX00_oonfX2o`3oTP_ooo]Z0omX0?l9oook
JP;o603o0_oonfX2o`1do`?oi_l03?oonfX8oon@00Kooo]Z1OooT006oookJPCoi_l000?o07CooaP0
oolH0?l00_lH0?l7oookJP;oJ03o2?oonfX2o`3oTP04oookJ_l0oi3ohP3oon80o`Cooo]Z0_l0odD0
0ooo;P3oH@3oodd0o`02oookJP07ool0K?l0003o0000ool0Qol0003o0?oNomgo0003oookJP05ok?o
0?l0Xooo01Ooool0gOmi0?l00_oonfX01?oo0`3ooo]ZoookJ_l0nol2oookJP0:oc_o0?oonf[ooh40
oom/0?oonf[o0?nJo`1goooonf[oo`3iojP0o`;ooo]Z00Oo0:KooookJ_oo0?Kojol0oookJ_oo1P3o
603o00Gooo]Z00Coo`3loookJ_oonf[ooi801_oonfX00ooo0>[ooo]ZoookJP0>oookJP03o`1coooo
nf[ooo]Z00Wooo]Z00Ko^Ol0oookJ_ooDP3o0?lcoookJ_l0:_l2oookJP05ocoo0?l0g?ooN?l0ocd0
ool0oml01_oonfX01Ol0oa_o08kooa80oooonf[oolX000?ooo]Z00Co0?WooookJ_oo09?oo`0C1?oo
nfX00ooJo`3ooo]Zon7o0003oookJP03obH0oolPo`3ooo]Z013ooo]Z00?o<Ol0oookJ_l0oe/01?oo
nfX01On2o`3o0?nao`0`oooonf[o0?m=00;ooo]Z00?o1P3ooookJ_nBo`001?oonfX00ol@0?oo01Wo
oookJP04oookJP03ool0DOoonf[o0:go00?ooo]Z00?oo`1ioookJ_oonfX01OoonfX00ol0oe?ooo]Z
oookJP02oookJP05o`3o7Ol0o`Sooo]ZoookJ_l0hOl03OoonfX01?l0ocCooo]ZoookJ_l0odhUoook
JP00:ooonfX01OlH0?oooo]ZoookJ_oonf[oU?l000;ooo]Z00?ojol0oookJ_l0ojd00_oonfX01Ol0
Y_oooo]ZoookJ_oonf[oZ03o00Cooo]Z00?oo`3ioookJ_l0Mol00_oonfX01_ooK03ooo]Zo`3oc?oo
P@3ooo]Zoc_o00Kooo]Z00?o0?_ooookJ_oonfX00_oonfX01_oo0`3ooo]ZoookJ_oonf[oiOl0ool0
g@?oiOl000?oU?l0ok?o0?oonfX01ooonfX00onDo`3oo`27oookJP03oookJP03onGo0?oo06coo`1/
00?ooo]Z00?oiOl0ool^0?oonfX00_oonfX00omQ0?oo0?m5oookJP05oookJP03on80oooonf[o0?n@
00Gooo]Z00?o0?nBoookJ_oonfX02ooonfX2ofP0o`;ooo]Z00?oA?l0oookJ_oonfX01?oonfX2oaP0
o`;ooo]Z00?oA?l0o`1doooVo`000ooVo`0AoookJPGooi002OoonfX2onKo00Ko603o2OoonfX2ofP0
o`Sooo]Z0_l0oi801?oonf[o0?n@on80oooR0?l3oookJP;o0?m50_oonfX01OmQ0?ooC@3ooookJ_oo
nf[oo`1/00;ooo]Z00Co0000ool0Qol0omko0?oN0ooonfX2ok?o00;oolT000?oN@3oooo90?oob@00
1?oob@003Ol0nooooo]ZoookJ_lko`3ooo]Zoon10?ooK03o0?nJoookJ_l0Moooo`3ioookJ_nX0?l0
0_oonfX01ol0Y_oooo]Zool0m_o[o`3ooo]Zool60?lH0?l01?oonfX01Ooo0?cooo]ZoookJ_oonf[o
iOl000Kooo]Z00?oo`3ZoookJ_oonfX03OoonfX00ol0Looooo]ZoookJP0:oookJP06okWo0?ooDP3o
oo]Zo`3o<ooonf[o02[o0ooUo`000ol0g?ooiOl0o`3og`08oookJP03o`3o6om4o`3oolX000Cooo]Z
00?o0?Woool0Tooo01<01OoonfX01?oJo`3ooo]ZoookJ_oQo`02oookJP03obH0oolPo`3ooo]Z013o
oo]Z00?o<Ol0oookJ_l0oe/01?oonfX01On2o`3o033ooookJ_oonf[o0?m=00?ooo]Z00?o1P3oool0
mOnBo`000ooonfX00ol@0?ooo`1Zo`0Io`04oookJP06oiCo0?oonf[ooo]Zo`2]oooonf[oo`1i2Ooo
nfX00ol0oe?ooo]ZoookJP02oookJP03o`3o7Ooonf[oU?l000kooo]Z00Co0?ldoookJ_l0odko0?l^
COoonfX01OlH0?oooo]ZoookJ_oonf[oo`H000?ooo]Z00?ojol0oookJ_oo0?H00_oonfX01?l0Y_oo
oo]ZoookJ_nX0?l4oookJP03ool0nOoonf[o07Oo00;ooo]Z00Oo0?nJoom/0?oonf[o0?o<oon10?oo
nf[o>ol000Gooo]Z00?o0?_ooookJ_oonfX00_oonfX00ooo0`3ooo]ZoookJP02oookJP07ogT0oooo
0=gooo]ZoookJ_l05ooo0:?ook?o0008oookJP03o`3og_oo08Oooo]Z00Cooo]Z00Koo`1/oookJ_oo
nf[ooo]Zodd0oooo;P03oookJP03of40ool0odGooo]Z00Kooo]Z00?ohP3ooookJ_l0oi001?oonfX0
0ol0oi;ooo]ZoookJP0;oookJP;oJ03o2OoonfX2oaP0o`;ooo]Z0ol0M?l3onKo017ooo]Z1_ooT008
oookJP;oi_l01_lH0?l9oookJP;oJ03o2?oonfX2o`3oTP04oookJ_l0oi3ohP3oon80o`Cooo]Z0_l0
odD01Ooonf[oobh0of40oom=0?oooo]Z00;oo`1/00?ooo]Zo`000?oo08L00_l0omh3oookJP03oil0
oonco`3o0:?o00;oo`3M0ooonfX01?oo0`3ooo]ZoookJ_l0nol2oookJP0:oc_o0?oonf[ooh40oom/
0?oonf[o0?nJo`1goooonf[oo`3iojP0o`?ooo]Z00Ko0:Koool0m_o[o`3ooo]Zool60?lH0?l5oook
JP04ool0o?oonf[ooo]ZoonB00Kooo]Z00?oo`3ZoookJ_oonfX03_oonfX00ol0Looooo]ZoookJP09
oookJP06okWo0?oonf[ooe80oookJ_l0oc?o02[o0_oonfX01Oloo`3o0=cooookJ_mho`3o0?oO00Oo
oo]Z00Co0?lKoa80oooonf[oolX00ooonfX01?l0nOoooo]Zool0Tooo01<5oookJP03om[o0?oonf[o
hOl000;ooo]Z00?o9P3oob3o0?oonfX04?oonfX00olao`3ooo]Zo`3oF`04oookJP05oh;o0?oonf[o
033ooookJ_l0odd00ooonfX00ol60?oooo]Zoi;o0003oookJP03oa00oooo06[o01Wo00Cooo]Z00Co
5@3oool0DOoonf[o0:go0_oonfX00ooo07Wooo]ZoookJP06oookJP03o`3oDooonf[ooo]Z00;ooo]Z
00Co0?lMo`3o2?oonf[o0>7o3OoonfX01Ol0ocCooo]ZoookJ_l0odko0?l^02Gooo]Z000/oookJP04
oaP0oooonf[ooo]ZoiCo00?ooo]Z00?ojol0oookJ_l0ojd00_oonfX01?l0Y_oooo]ZoookJ_nX0?l4
oookJP0;ool0nOoonf[ooo]Zo`1goooonf[oof`0o`3oV_oonf[o0?o<oon10?lko`001ooonfX00ol0
nooooo]ZoookJP02oookJP06ool30?oonf[ooo]ZoookJ_oUo`3oo`3M0_oUo`000onDo`3oiOl0ok?o
0008oookJP03oiCo0?oo08Oooo]Z00Gooo]Z00Koo`1/oookJ_oonf[ooo]ZonGo0?oo;P03oookJP03
of40ool0odGo0?m500Gooo]Z0_oR0?l2o`3oT0Cooo]Z00?o0?nBoookJ_oonfX03?oonfX3ofP0o`So
oo]Z1olH0?l01?l0M?ooi_l0onKo0?oVo`04o`1do`[ooo]Z2OoVo`07oaP0o`cooo]Z0omX0?l8oook
JP;o0?nB00Cooo]Zo`3oT?l0oi3ohP3o1?oonfX00ol0odGooo]ZoookJP02of40o`04odd0oooonf[o
oo]Zool0K0?ooo]Z00coo`27o`3og_oMo`3o0000ooo90?oonf[o/ol0o`2Soooob@3ooo]ZogT0oooo
nfX5ooo9000=o`3koooonf[ooo]Zoc_o0?oonf[ooh40oom/0?l0oi[ooo]Zo`1goooo0?Wooo]ZojP0
o`02oookJP07o`2Voooonf[oo`3fon_o0?oonf[oo`H0oaP0o`04oookJP05ool0o?oonf[ooo]Zoook
J_oUo`001_oonfX00ooo0>[ooo]ZoookJP0=oookJP03o`1coooonf[ooo]Z00[ooo]Z00Ko^Ol0oook
J_ooDP3o0?lcoookJ_l0:_l3onGo0004o`3LoooUo`3o?@3oo`3og`Oooo]Z00Co0?lKodCo0?oonf[o
olX01?oonfX00ol0nOooo`2Cool04`05oookJP03om[o0?oonf[ohOl000?ooo]Z00?o9P3oob3o0?oo
nfX03ooonfX00olao`3ooo]Zo`3oF`04oookJP06o`3o/?n2o`3o033ooookJ_l0j?oo0?m=0ooonfX0
0ol60?ooT_l0oookJP02oookJP03oa00ool0GOoo01Wo00Gooo]Z00KoU?l0oookJ_oonf[o0:gooook
J_oo07T8oookJP03o`3oDooonf[ooo]Z00;ooo]Z00Co0?l8o`3o7Ooonf[oU?l03OoonfX01?l0ocCo
oo]ZoookJ_l0odi?oookJP05oaP0oooonf[ooo]ZoookJ_oo1P000ooonfX01Oo[o`3ooo]Zool0m_oo
nf[o0:Ko00;ooo]Z00?oZ03ooookJ_oonfX00ooonfX00ooo0?Wooo]Zo`1go`02oookJP06oom/0?oo
nf[ooo]Zo`3oc?ooP@3o>ol01_oonfX00ol0nooooo]ZoookJP02oookJP03ool30?oonf[ooo]Z00;o
oo]Z00OoN@3oool0gOoonf[ooo]Zo`2Soooonf[o/ol000Sooo]Z00?oo`27omgo0?oonfX01?oonfX0
1_oo06cooo]ZoookJ_oonf[oC@3oool^00?ooo]Z00?oH@3oo`3oAOl0odD01_oonfX2on80o`;o0?n@
0ooonfX00ol0oi;ooo]ZoookJP0<oookJP?oJ03o2?oonfX7oaP0o`04o`1doooVo`3oi_l0onKo00Go
07Co2OoonfX9onKo00Oo603o3?oonfX3ofP0o`Sooo]Z0_l0oi801?oonf[o0?n@o`3oT?oR0?l5oook
JP03o`3oAOoonf[oobh000;oH@3o00?oC@3ooookJ_oo06`00ooonfX01?oo08Oo0?oNomgo0?l00002
oookJP;o/ol000?o01Ooool0gOmi0?l00ooonfX01?oo0`3ooo]ZoookJ_l0nol2oookJP04oc_o0?oo
nf[ooh40oom/00;o0?nJ00Co07OooookJ_oo0?WoZ03o0ooonfX01_l0Y_ooo`3fon_o0?oonf[oo`H0
oaP0o`Gooo]Z00Goo`3loookJ_oonf[ooi80oolF0006oookJP03ool0j_oonf[ooo]Z00gooo]Z00?o
07?ooookJ_oonfX02_oonfX01_nio`3ooo]ZoomB0?l0oc?ooo]Zo`0Zo`;ooo]Z00Go?ol0o`3Loomh
o`3ooo]Zo`3og`06oookJP05o`3o6olB0?oooo]ZoookJ_oobP000ooonfX01?l0nOoooo]Zool0Tooo
01<4oookJP03om[o0?oonf[ohOl000?ooo]Z00?o9P3oob3o0?oonfX04?oonfX00olao`3ooo]Zo`3o
F`04oookJP05oh;o0?l0ok7o033ooookJ_l0odd00ooonfX00ol60?oooo]Zoi;o0003oookJP03oa00
ool06Ooooo]Z00Cooo]Z00Coo`1AoookJ_oonf[o0:go0_oonfX00ooo07Wooo]ZoookJP05oookJP03
o`3oDooonf[ooo]Z00?ooo]Z00Co0?lMoookJ_oonf[o0>7o3OoonfX01?l0ocCooo]ZoookJ_l0odhV
oookJP00;?oonfX01OlH0?oooo]ZoookJ_oonf[oU?l000?ooo]Z00Gojol0o`3o[Ooonf[ooo]Zo`2V
o`03oookJP03ojP0oooonf[ooo]Z00;ooo]Z00?oo`3ioookJ_l0Mol00_oonfX01_ooK03ooo]Zoook
J_l0olcooh40oc_o00Kooo]Z00?o0?_ooookJ_oonfX00ooonfX01_oo0`3ooo]ZoookJ_oonf[oiOl0
ool0g@;oiOl000?oU?l0onGo0?nco`002?oonfX00onDo`3oo`27oookJP05oookJP06ool0K?oonf[o
oo]ZoookJ_oUo`3oobh00ooonfX00omQ0?oooo]Zo`3oA@06oookJP03on80oooonf[o0?n@00Cooo]Z
0_l0oi8?oookJP?oJ03o3?oonfX=oaP0o`Goi_l00ooonfX6oaP0o`kooo]Z1OmX0?l9oookJP;o0?nB
00?ooo]Zo`3oT?l0oi000_oR0?l3oookJP;o0?m500Cooo]Zof40oomQ0?ooC@3o0_oonfX2ool0K0;o
oo]Z0_oo08L02?l0omko0000o`000?l0003oolT0ok?o0?l0XoooolT00_mi0?l00ooonf[oolT0ooo9
0002ooo900;o0?_o0_oonfX01?lko`3ooo]Zoon10?ooK002oookJP04o`1goooo0?Wooo]ZojP0o`;o
oo]Z00So0:KooookJ_oo0?Kojol0oookJ_oo1P3ooo]ZoaP0o`?ooo]Z00Goo`3loookJ_oonf[ooo]Z
onGo0006oookJP03ool0j_oonf[ooo]Z00kooo]Z00?o07?ooookJ_oonfX02_oonfX01Onio`3ooe80
o`3o<ooonf[o02[o00KoiOl000?o0?oOoookJ_oonfX01OoonfX01?l0oa_o08koodCo0?oobP04oook
JP03o`3ioooo09?oo`0C00Gooo]Z00Cof_l0oookJ_oonf[ohOl00_oonfX00olV0?oo8?l0oookJP0@
oookJP03oc7o0?oonf[o0?mK00Cooo]Z00GoP_l0o`0`oooonf[ooo]Zo`3oC@03oookJP03o`H0oooo
nf[oT_l000?ooo]Z00?o403ooookJ_l06Ol00_nDo`02oookJP06oaD0oonDo`3ooo]Zo`2]oooonf[o
o`1i2OoonfX00ol0oe?ooo]ZoookJP02oookJP03o`3o7Ooonf[oU?l000kooo]Z00Co0?ldoookJ_oo
nf[o0?m>CooonfX01OlH0?oooo]ZoookJ_oonf[oo`H000?ooo]Z00?ojol0oookJ_oo0?H00_oonfX0
1?l0Y_oooo]ZoookJ_nX0?l4oookJP03ool0nOoonf[o07Oo00?ooo]Z00Koof`0oookJ_oonf[o0?o<
oon10?lko`05oookJP03o`3koooonf[ooo]Z00?ooo]Z00?oo`<0oookJ_oonfX00_oonfX01omi0?oo
o`3MoookJ_oonf[o0:?ooookJ_nco`002?oonfX00ooo08OogOl0oookJP04oookJP06ool0K?oonf[o
oo]ZoookJ_m=0?ooobh00ooonfX00omQ0?oooo]Zo`3oA@07oookJP03on80oooonf[o0?n@00?ooo]Z
0_l0oi8?oookJP?oJ03o3?oonfX=oaP0o`Goi_l00ooonfX6oaP0o`kooo]Z1OmX0?l:oookJP04o`3o
T_oonf[o0?n@o`3oT0;ohP3o1?oonfX2o`3oA@05oookJ_mQ0?ooH@3oodd0oooonfX00_oo06`2oook
JP;oo`2700[o0?oNo`000?l0003o0000oookJ_nco`3o0:?oo`0Goooo0=goN@3o0ooonfX01?oo0`3o
oo]Zo`3kool0nol2oookJP0:oc_o0?oonf[ooh40oom/0?l0oi[ooo]Zo`1goooonf[oo`3iojP0o`?o
oo]Z00Oo0:Koool0m_o[o`3ooo]Zool60?oonf[o603o00Cooo]Z00Goo`3loookJ_oonf[ooi80oolF
0006oookJP03ool0j_oonf[ooo]Z00kooo]Z00?o07?ooookJ_oonfX02OoonfX01_nio`3ooo]ZoomB
0?l0oc?ooo]Zo`0Zo`;ooo]Z00Go?ol0o`3Loooonf[oN?l0o`3og`07oookJP04o`3o6olB0?oooo]Z
ooo:00?ooo]Z00Co0?WooookJ_oo09?oo`0C1OoonfX00ooJo`3ooo]Zon7o0002oookJP03obH0oon4
0?oo8?l0013ooo]Z00?o<Ol0oookJ_l0oe/01?oonfX01_n2o`3ooo]Zo`0`oooonf[o0>Soo`3oC@;o
oo]Z00?o1P3ooookJ_nBo`000ooonfX00ol@0?oo05goo`0Io`04oookJP04oaD0oooo057ooo]Zo`2]
o`;ooo]Z00?oo`1ioookJ_oonfX01_oonfX00ol0oe?ooo]ZoookJP02oookJP04o`3o7Ol0o`Sooo]Z
o`3Qo`kooo]Z00Co0?ldoookJ_oonf[o0?m>9_oonfX002gooo]Z00Co603ooookJ_oonf[oU?l00ooo
nfX00oo[o`3ooo]Zo`3o[@02oookJP04o`2Voooonf[ooo]ZojP0o`Cooo]Z00Coo`3ioookJ_oonf[o
07Oo0_oonfX01OooK03ooo]ZoookJ_ooP@3o>ol000Oooo]Z00?o0?_ooookJ_oonfX00ooonfX01Ooo
0`3ooo]ZoookJ_oUo`3oo`3M00?oiOl000CoU?l0ok?o0?oUo`3oiOl01ooonfX00onDo`3oo`27ool0
Q`05oookJP06ool0K?oonf[ooo]ZoookJ_oUo`3oobh00ooonfX2of40o`;o0?m51OoonfX2on80o`03
o`3oT?oonf[ooo]Z00?ooo]Z00?o0?nBoookJ_oonfX03ooonfX2ofP0oaOooo]Z2?lH0?l00ol0M?oo
oo]ZoookJP0=oookJPCoJ03o3OoonfX01?l0oi;ooo]Zo`3oT?l0oi02on80o`Cooo]Z00Ko0?m5oook
J_mQ0?ooH@3oool^0?m=0?l2oookJP07ool0K?oonf[ooo]ZoookJ_oo08Oo0?oNoookJP03o`000005
ooo90?nco`3oolT0ooo90?mi0?l00ooonfX2ooo90003oookJ_l0nooooo]Z00;ooo]Z00Co>ol0oook
J_ooP@3o0?nJ0_oonfX01?l0Moooo`3ioookJ_nX0?l2oookJP08o`2Voooonf[oo`3fon_o0?oonf[o
o`H0oookJ_lH0?l3oookJP04onGo0?oo0?cooo]ZoookJP;oiOl01OoonfX00ooo0>[ooo]ZoookJP0>
oookJP03o`1coooonf[ooo]Z00[ooo]Z00?o^Ol0oomB0?l0oc<00_oonfX00ol0:_ooiOl0onGo0006
onGo00Kooo]Z00Co0?lKodCo0?oonf[oolX01?oonfX00ol0nOooo`2Cool04`05oookJP03om[o0?oo
nf[ohOl000?ooo]Z00?o9P3oob3o0?oonfX03ooonfX00olao`3ooo]Zo`3oF`04oookJP06o`3o/?n2
o`3o033ooookJ_l0j?oo0?m=0ooonfX00ol60?ooT_l0oookJP02oookJP04oa00ool0GOoo01Wooook
JPGoU?l00_oonfX00ol0[Ooooo]Zool0N@08oookJP03o`3oDooonf[ooo]Z00?ooo]Z00?o0?lMoook
J_nDo`003OoonfX01Ol0ocCooo]ZoookJ_l0obko0?m>053ooo]Z00Go603ooookJ_oonf[ooo]Zool6
0003oookJP03on_o0?oonf[oo`3f00;ooo]Z00?o0:KooookJ_nX0?l01OoonfX00ooo0?Wooo]Zo`1g
o`02oookJP06o`3oV_ooK03ooo]Zo`3oc?ooP@3o>ol01_oonfX00ol0nooooo]ZoookJP03oookJP03
ool30?oonf[ooo]Z00;ooo]Z00Ooo`3MoookJ_oonf[ooo]Zo`2Soonco`3oW`3o00Sooo]Z0_oo08L5
oookJP;oo`1/0_oonfX00om=0?ooobh0oookJP02oookJP;oH@3o0_l0odD6oookJP;ohP3o00?o0?n@
oookJ_oonfX00_oonfX00ol0oi;ooo]ZoookJP0?oookJP;oJ03o5ooonfX8oaP0o`03o`1doooonf[o
oo]Z00gooo]Z1?mX0?l=oookJP;o0?nB0_l0oi02on80o`Gooo]Z00Co0?m5oookJ_mQ0?ooH@3o0_m=
0?l00ooonf[oo`1/oookJP02oookJP03ool0Qol0omkooo]Z00?o000000GoW`3ook?o0?l0Xooooo]Z
ool0g@04oookJP03ool30?oonf[o0?_o00?ooo]Z00[o>ol0oookJ_ooP@3ooo]Zo`3oV_oonf[o07Oo
oookJ_oo0?WoZ03o0ooonfX01ol0Y_ooo`3fon_o0?oonf[oo`H0oookJ_lH0?l01OoonfX01?oo0?co
oo]ZoonB0?oo5P06oookJP03ool0j_oonf[ooo]Z00kooo]Z00?o07?ooookJ_oonfX02OoonfX01_ni
o`3ooo]ZoomB0?l0oc?ooo]Zo`0Zo`;ooo]Z00Ko?ol0oookJ_l0g?ooN?l0oookJ_l0oml6oookJP05
o`3o6olB0?oooo]ZoookJ_oobP000ooonfX01?l0nOoooo]Zool0Tooo01<4oookJP03om[o0?oonf[o
hOl000?ooo]Z00?o9P3oob3o0?oonfX03ooonfX01?lao`3ooo]ZoookJ_l0oe/3oookJP06o`3o/?n2
o`3o0?nao`0`oooonf[o0?m=0ooonfX00ol60?oooo]Zoi;o0003oookJP03oa00ool06Ooooo]Z00Co
oo]Z00Co5@3oool0DOoonf[o0:go0_oonfX00ooo07Wooo]ZoookJP06oookJP03o`3oDooonf[ooo]Z
00;ooo]Z00Co0?lMo`3o2?oonf[o0>7o3OoonfX01Ol0ocCooo]ZoookJ_l0obko0?m>02Kooo]Z000^
oookJP04oaP0oooonf[ooo]ZoiCo00?ooo]Z00?ojol0o`3o[OoonfX00_oonfX00ol0Y_oooo]ZojP0
o`05oookJP03ool0nOoonf[o07Oo00?ooo]Z00Goof`0oookJ_l0olcooh40oc_o0007oookJP03o`3k
oooonf[ooo]Z00?ooo]Z00Goo`<0oookJ_oonf[oiOl0ool0g@02onGo0003oiCo0?oUo`3o/ol000;o
iOl01_oonfX01?nDo`3ogOl0oookJ_oo08L5oookJP06ool0K?oonf[ooo]ZoookJ_oUo`3oobh01?oo
nfX00omQ0?oooo]Zo`3oA@06oookJP03on80ool0oi3o0?n@00Cooo]Z00?o0?nBoookJ_oonfX04?oo
nfX3ofP0obSooo]Z1?mX0?l?oookJP;o0?nB00Cooo]Zo`3oT?oonf[ohP3o1?oonfX2o`3oA@;oH@3o
00?oobh0odd0oom=0?l00_oonfX00ooo06cooo]ZoookJP02ool0Q`03omgo0?oonf[ooo]Z00;o0000
00?oolT0ok?o0?oob@000_oob@03oookJP;oolT000?ooo]Zo`3koooonfX00_oonfX01?lko`3o0?o<
oon10?l0oiX2oookJP04o`1goooo0?Wooo]ZojP0o`;ooo]Z00So0:KooookJ_oo0?Kojol0oookJ_oo
1P3ooo]ZoaP0o`Cooo]Z00?oo`3lonGo0?oonfX00_oUo`06oookJP03ool0j_oonf[ooo]Z00gooo]Z
00?o07?ooookJ_oonfX02_oonfX01_nio`3ooo]ZoomB0?l0oc?ooo]Zo`0Zo`[oiOl01?oonfX01?l0
oa_oA?l0oookJ_oobP04oookJP03o`3ioooo09?oo`0C00Gooo]Z00?of_l0oookJ_oQo`000ooonfX0
0on40?oo9P3oob3o000@oookJP03oc7o0?oonf[o0?mK00Cooo]Z00Ko0?n`oh;o0?oonf[ooo]Zo`3X
ool0odd3oookJP03o`H0oonBo`3ooo]Z00;ooo]Z00Co403ooookJ_l06Ooooo]Z1onDo`000ooonf[o
o`1ioookJP08oookJP03o`3oDooonf[ooo]Z00;ooo]Z00?o0?lMoookJ_nDo`003_oonfX01?l0ocCo
oo]ZoookJ_l0odiBoookJP04oaP0oooonf[ooo]Zool600?ooo]Z00?ojol0oookJ_oo0?H00ooonfX0
0ol0Y_oooo]ZojP0o`04oookJP03ool0nOoonf[o07Oo00?ooo]Z00Ko0?nJoom/0?oonf[o0?o<oon1
0?lko`06oookJP03o`3koooonf[ooo]Z00?ooo]Z00?oo`<0oookJ_oonfX00_oonfX01ooo0=gooo]Z
oookJ_l0Xooo01Oook?o0?nO0?l01ooonfX00ol0omkogOl0ool0Q`06oookJP05ool0K?oonf[ooo]Z
odd0oooo;P001?oonfX00omQ0?oooo]Zo`3oA@07oookJP03on80ool0oi3o0?n@00?ooo]Z00?o0?nB
oookJ_oonfX04?oonfX3ofP0obSooo]Z1?mX0?l?oookJP;o0?nB00Cooo]Zo`3oT?oonf[ohP3o1Ooo
nfX01_l0odGoH@3oof40oomQ0?ooobh0odd0o`;ooo]Z00?oo`1/oookJ_oonfX00_oo08L00ooMo`3o
oo]ZoookJP02o`000003oil0oonco`3o0:?o00;oo`3M1?oonfX00ooo0`3ooo]Zo`3ko`03oookJP0:
oc_o0?l0olcooh40oookJ_l0oi[ooo]Zo`1goooonf[oo`3iojP0o`?ooo]Z00Oo0:KooookJ_o[o`3o
oo]Zool60?oonf[o603o00Gooo]Z00Coo`3loookJ_oonf[ooi801_oonfX00ooo0>[ooo]ZoookJP0>
oookJP03o`1coooonf[ooo]Z00[ooo]Z00Ko^Ol0oookJ_ooDP3o0?lcoookJ_l0:_l2oookJP05ocoo
0?l0g?oo?@3oogSo0?l0oml01ooonfX01?l0oa_o4P3ooookJ_oobP03oookJP04o`3ioooonf[oo`2C
ool04`Gooo]Z00?of_l0on7o0?oonfX00ooonfX00olV0?oo8?l0oookJP0?oookJP03oc7o0?oonf[o
0?mK00Cooo]Z00Ko0?n`oh;o0?l0<?oooo]Zo`3Xool0odd3oookJP03o`H0oonBo`3oo`3e00;ooo]Z
00?o403oo`1Mool06Ol01?oonfX01?lE0?ooo`1AoookJ_l0[Ol2oookJP03ool0NOoonf[ooo]Z00Ko
oo]Z00?o0?mCoookJ_oonfX00_oonfX01?l0oago0?l8oookJ_l0hOl>oookJP04o`3o=?oonf[ooo]Z
o`3oCROooo]Z000^oookJP04oaP0oooonf[ooo]ZoiCo00?ooo]Z00?ojol0oookJ_l0ojd00ooonfX0
0ol0Y_oooo]ZojP0o`04oookJP04ool0nOoonf[ooo]Zo`1go`;ooo]Z00Go0?nJoom/0?oonf[ooh40
oc_o0007oookJP03o`3koooonf[ooo]Z00Cooo]Z00Coo`<0oookJ_oUo`3oo`3M0ooUo`000onDo`3o
iOl0ok?o0002onGo00Kooo]Z00CoU?l0omgo0?oonf[oo`271OoonfX01_oo06cooo]ZoookJ_oonf[o
iOl0ool^00Cooo]Z00CoH@3ooookJ_l0odGo0?m51OoonfX2on80o`03o`3oT?oonf[ooo]Z00;ooo]Z
0ol0oi8BoookJP?oJ03o8?oonfX5ofP0oa3ooo]Z0ol0oi800ooonf[o0?n@o`3oT002on80o`?ooo]Z
0_l0odD2of40o`03oookJ_oo;P3oC@3o00;ooo]Z0_oo06`01?oonf[oo`27ool0Qol0omh4oookJP03
oil0oooob@3o/ol000CoolT000?ooo]Zool30?oob@000_oonfX02?l0nooooo]ZoookJ_oonf[o>ol0
o`3oc?ooP@3o0?nJ0_oonfX01Ol0Moooo`3ioookJ_nX0?oooo]Z00;o0:Ko00Oooo]Zool0m_o[o`3o
oo]Zool60?oonf[o603o00;ooo]Z0_oUo`000ooo0?coiOl0onGo0002onGo00Kooo]Z00?oo`3Zoook
J_oonfX03_oonfX00ol0Looooo]ZoookJP0:oookJP06okWo0?ooDP3o0?lcoookJ_l0:_oooo]Z2OoU
o`05oookJP04o`3o6om4o`3ooo]Zooo:00Cooo]Z00?oo`2CoookJ_oo01<01OoonfX00ooJo`3ooo]Z
on7o0003oookJP03obH0oolPo`3ooo]Z00oooo]Z00?o<Ol0oookJ_l0oe/00_oonfX2onGo0006o`3o
/?n2o`3o033ooookJ_l0j?oo0?m=0ooonfX00ol60?ooo`3eoi;o0003oookJP04oa00ool06Oooo`1Z
oookJPSoU?l000?oo`1ioookJ_oonfX01ooonfX00ol0oe?ooo]ZoookJP02oookJP03o`3o7Ooonf[o
U?l000gooo]Z00Go0?ldoookJ_oonf[ooo]Zo`3oCP1BoookJP05oaP0oooonf[ooo]ZoookJ_oo1P00
0ooonfX00oo[o`3ooo]Zool0mP02oookJP03o`2Voooonf[oZ03o00Gooo]Z00?oo`3ioookJ_l0Mol0
0ooonfX01Ol0oi[oof`0oookJ_ooP@3o>ol000Kooo]Z00?o0?_ooookJ_oonfX01?oonfX01_oo0`3o
oo]ZoookJ_oonf[oo`3MogT0o`;ooo]Z00Co0:?oo`0Goonco`3oW`3o1ooonfX00ol0omkogOl0ool0
Q`06oookJP05ool0K?oonf[ooo]Zodd0oooo;P001?oonfX01?mQ0?oooo]Zo`3oAOl0odD6oookJP;o
hP3o00Co0?n@oookJ_oonf[ooo]Z0ol0oi8BoookJP?oJ03o8?oonfX5ofP0oa3ooo]Z0ol0oi800ooo
nf[o0?n@o`3oT002on80o`Cooo]Z00So0?m5of40oomQ0?oooo]Zool^0?oonf[oC@3ooookJP;oo`1/
00Cooo]Zool0Qooo08Oo0?oN1?oonfX2oil0o`04ok?o0?l0Xoooo`3MogT0o`?ooo]Z0_oo0`000ooo
nf[o0?_ooookJP02oookJP0:oc_o0?l0olcooh40oookJ_l0oi[ooo]Zo`1goooonf[oo`3iojP0o`;o
oo]Z0_l0Y_l01_oonf[ojol0oookJ_oo1P3ooo]ZoaP0o`Gooo]Z00Coo`3loookJ_oonf[ooi801ooo
nfX00ooo0>[ooo]ZoookJP0>oookJP03o`1coooonf[ooo]Z00Wooo]Z00Ko^Ol0oookJ_ooDP3o0?lc
oookJ_l0:_l2oookJP05ocoo0?l0g?oooo]ZogSo0?l0oml01ooonfX01Ol0oa_o4P3ooookJ_oonf[o
olX000?ooo]Z00Co0?Woool0Tooonf[oo`0C1?oonfX00ooJo`3ooo]Zon7o0003oookJP03obH0oolP
o`3ooo]Z00oooo]Z00Co<Ol0oookJ_oonf[o0?mK0ooonfX01_l0ok3oP_l0oookJ_l0<?oooo]Zo`3o
C@?ooo]Z00?o1P3ooookJ_nBo`000ooonfX00ol@0?oo01Woool0JP04oookJP04oaD0oooo057ooo]Z
o`2]o`;ooo]Z00?oo`1ioookJ_oonfX01_oonfX00ol0oe?ooo]ZoookJP02oookJP04o`3o7Ol0o`So
oo]Zo`3Qo`gooo]Z00Go0?ldoookJ_oonf[o0?l^o`3oCP0WoookJP00;ooonfX01?lH0?oooo]Zoook
J_nDo`03oookJP03on_o0?l0ojgooo]Z00;ooo]Z00?o0:KooookJ_nX0?l01OoonfX00ooo0?Wooo]Z
o`1go`03oookJP04oom/0?oonf[ooo]Zoon100;oiOl01_oonfX00ol0nooooo]ZoookJP04oookJP04
ool30?oonf[oiOl0ool0g@?oiOl000CoU?l0ok?o0?oUo`3oiOl01ooonfX00onDo`3ogOl0oookJP02
ool0Q`Cooo]Z00Koo`1/oookJ_oonf[ooo]ZonGo0?oo;P04oookJP04of40oooonf[ooo]Zo`3oA@Ko
oo]Z00?ohP3oo`3oT?oonfX01OoonfX3o`3oTQ;ooo]Z3_mX0?l>oookJPCoJ03o4_oonfX3o`3oTP;o
oo]Z00Co0?n@on80oooR0?oohP3o1?oonfX01Ol0odGoH@3oof40oooonf[oolT000;oC@3o00?ooo]Z
ool0K?oo06`00_oonfX00ooo08Oo0?oNoookJP04oookJP03oil0oooob@3o/ol000KoolT00_oonfX2
o`3ko`?ooo]Z00Co>ol0o`3oc?ooP@3o0?nJ0_oonfX01_l0Moooo`3ioookJ_nX0?oooo]Zo`2Vo`;o
oo]Z00Koo`3fon_o0?oonf[oo`H0oookJ_lH0?l3oookJP;oo`3l1OoUo`05oookJP03ool0j_oonf[o
oo]Z00kooo]Z00?o07?ooookJ_oonfX02_oonfX00onio`3ooe80o`3o<`02oookJP03o`0Zoooonf[o
iOl000OoiOl01OoonfX01?l0oa_oA?l0oookJ_oobP04oookJP03o`3ioooo09?oo`0C00Gooo]Z00?o
f_l0oookJ_oQo`000ooonfX00on40?oo9P3oob3o000@oookJP03oc7o0?oonf[o0?mK00;ooo]Z0_oU
o`001_l0ok3oP_l0onGo0?oonf[o0>Soo`3oC@?ooo]Z00?o1P3ooi;o0?oonfX00_oonfX00ol@0?oo
oo]Zo`0Io`02oookJPSoU?l02OoonfX00ol0oe?ooo]ZoookJP02oookJP03o`3o7Ol0o`SoU?l000ko
oo]Z00Go0?ldoookJ_oonf[o0?l^o`3oCP1CoookJP04oaP0oooonf[ooo]Zool600?ooo]Z00?ojol0
oookJ_oo0?H00ooonfX00ol0Y_ooZ03ooookJP04oookJP03ool0nOoonf[o07Oo00Cooo]Z00Goof`0
oookJ_l0olcooh40oc_o0006oookJP03o`3koooonf[ooo]Z00Cooo]Z00Koo`<0oookJ_oonf[ooo]Z
ool0gOmi0?l2oookJP04o`2Soonco`3ooo]Zoil0o`Oooo]Z00Co0?oNomgo0?oo08Ooo`271OoonfX0
1Ooo06cooo]ZoookJ_m=0?ooobh000Cooo]Z00CoH@3ooookJ_oonf[o0?m51ooonfX00ooR0?oo0?n@
oookJP04oookJP?o0?nB4_oonfX>ofP0o`kooo]Z1?mX0?lBoookJP?o0?nB0_oonfX01?l0oi3ohP3o
on80oooR0?l5oookJP;oH@3o00?ooo]Zool^0?oo;P000_m=0?l2ool0K0;ooo]Z00?oo`27o`3og_oM
o`001?oonfX01OnO0?oo0000ok?o0?l0003oo`3M00Cooo]Z00Coo`<0oookJ_l0nooo0?_o0ooonfX0
0olko`3o0?o<oon10002o`3oVP05oookJ_l0Mooooo]Zool0nOnX0?l00_oonfX02?l0Y_oooo]Zoook
J_o[o`3ooo]Zool60?oonf[o603o1?oonfX2ool0o0;ooo]Z00?ooi80oookJ_oonfX01OoonfX00ooo
0>[ooo]ZoookJP0>oookJP03o`1coooonf[ooo]Z00Wooo]Z00Ko^Ol0oookJ_ooDP3o0?lcoookJ_l0
:_l3oookJP05ocoo0?l0g?ooN?l0oookJ_l0oml01ooonfX01?l0oa_ooo]ZoookJ_oobP03oookJP04
o`3ioooonf[oo`2Cool04`Gooo]Z00?of_l0on7o0?oonfX00ooonfX00olV0?oo8?l0oookJP0?oook
JP04oc7o0?oonf[ooo]Zo`3oF`?ooo]Z00Ko0?n`oh;o0?l0<?oooo]Zo`3Xool0odd3oookJP03o`H0
oonBo`3oo`3e00?ooo]Z00?o403oo`0IoooonfX00ooonfX01?lE0?ooo`1AoookJ_l0[Ol2oookJP03
ool0NOoonf[ooo]Z00Oooo]Z00So0?mCoookJ_oonf[ooo]Zo`3o7Ooonf[o0?l8o`3Qo`kooo]Z00Go
0?ldoookJ_oonf[o0?l^o`3oCP0WoookJP00;ooonfX01?lH0?oooo]ZoookJ_nDo`04oookJP03on_o
0?l0ojgooo]Z00;ooo]Z00?o0:KooookJ_nX0?l01?oonfX01?oo0?Wooo]ZoookJ_l0Mol3oookJP03
oom/0?oonf[ooh4000CoiOl01OoonfX00ol0nooooo]ZoookJP04oookJP03ool30?oUo`3oiOl000;o
o`3M0ooUo`000onco`3o01Oooil0o`07oookJP05oiCo0?l0omkooo]ZoookJ_oo08L01?oonfX2ool0
K0;ooo]Z00?oiOl0ool^0?oo;P000ooonfX00omQ0?oooo]ZoookJP02o`3oA@Gooo]Z0_oR0?l00ol0
oi3ooo]ZoookJP05oookJP?o0?nB7OoonfX>ofP0oa?ooo]Z0ol0oi82oookJP04o`3oT?oR0?oohP3o
on80o`Gooo]Z0omQ0?l2ooo900;oC@3o00?ooo]Zool0K?oo06`00_l007l2ool0Q`03omgo0?oonf[o
oo]Z00?ooo]Z00?oW`3ook?o0?nco`002?oob@000ol0nooooo]ZoookJP02oookJP03oc_o0?ooP@3o
oh4000?ooo]Z00Ko07Ooool0nOoonf[oZ03ooookJ_l0Y_l2oookJP06ool0m_oonf[ojol0ool60?oo
nf[o603o0ooonfX00ooo0?coiOl0onGo0006onGo00?ooo]Z00?oo`3ZoookJ_oonfX03_oonfX00ol0
Looooo]ZoookJP0:oookJP03okWo0?ooDP3o0?lc00;ooo]Z00?o02[ooookJ_oonfX01ooUo`06oook
JP04o`3o6ol0S_oooo]Zooo:00?ooo]Z00Co0?Woool0Tooonf[oo`0C1OoonfX00ooJo`3ohOl0oook
JP02oookJP03oh@0oolV0?oo8?l0013ooo]Z00Co<Ol0oookJ_oonf[o0?mK0_oonfX02?oUo`3o0?n`
oh;o0?l0<?ooiOl0o`3XoooUo`3o0?m=0_oonfX00ol60?ooo`3eoi;o0003oookJP03oa00ool06Ooo
o`1Z00;ooo]Z1onDo`000ooo07Wooo]ZoookJP07oookJP03o`3oDooonf[ooo]Z00;ooo]Z00?o0?lM
oookJ_nDo`003_oonfX01?l0ocCooo]ZoookJ_l0odiDoookJP05oaP0oooonf[ooo]ZoookJ_oo1P00
0ooonfX00oo[o`3ooo]Zool0mP03oookJP03o`2VoonX0?oooo]Z00Cooo]Z00?oo`3ioookJ_l0Mol0
0ooonfX01_l0oi[oof`0oookJ_ooP@3ooo]Zoc_o00Kooo]Z00?o0?_ooookJ_oonfX01?oonfX01?oo
0`3ooo]ZoookJ_oonfX2ool0g@?ooo]Z00?o/ol0oil0oooonfX01ooonfX2o`3ogP03oookJ_oo08Oo
oo]Z00Cooo]Z00Coo`1/oookJ_oonf[oC@3o0_oo;P03oookJP03of40oooonf[ooo]Z00;o0?m51_oo
nfX2on80o`03o`3oT?oonf[ooo]Z00Cooo]Z0ol0oi8MoookJPkoJ03o4ooonfX3o`3oTP;ooo]Z00Co
0?n@on80oooR0?oohP3o1_oonfX2of40o`03o`00Oooo;P3oobh000;oC@3o0_oo06`2o`00O`;oo`27
00?ogOl0oookJ_oonfX00ooonfX01_nO0?oo/ol0ok?o0?l0003oo`3Mo`0000;ooo]Z0_oo0`000ooo
nf[o0?_ooookJP03oookJP04oc_o0?ooP@3ooh40o`3oVP;ooo]Z00Co07OooookJ_oo0?WoZ03o0_oo
nfX02?l0Y_oooo]ZoookJ_oo0?Kojol0ool60?oonf[o603o1?oonfX01_oo0?cooo]ZoookJ_oonf[o
oi80oolF00Kooo]Z00?oo`3ZoookJ_oonfX03_oonfX00ol0Looooo]ZoookJP0:oookJP03okWo0?oo
DP3o0?lc00;ooo]Z00So02[ooookJ_oonf[o?ol0o`3Loooonf[oN?l0o`3og`Oooo]Z00Go0?lKoa80
oooonf[ooo]Zooo:0002oookJP05o`3ioooonf[oo`2CoookJ_oo01<01?oonfX00ooJo`3ooo]Zon7o
0003oookJP03obH0oolPo`3ooo]Z00oooo]Z00Co<Ol0oookJ_oonf[o0?mK0ooonfX01ol0ok3oP_l0
oookJ_l0<?oooo]Zo`3Xool0odd00_oonfX00ol60?oooo]Zoi;o0003oookJP03oa00ool06Oooo`1Z
00Cooo]Z00Co5@3oool0DOoonf[o0:go0_oonfX00ooo07Wooo]ZoookJP06oookJP03o`3oDooonf[o
oo]Z00;ooo]Z00Co0?lMo`3o2?oonf[o0>7o3OoonfX01Ol0ocCooo]ZoookJ_oonf[o0?m>02Sooo]Z
000`oookJP04oaP0oooonf[ooo]ZoiCo00?ooo]Z00?ojol0o`3o[OoonfX00ooonfX00ol0Y_ooZ03o
oookJP04oookJP03ool0nOoonf[o07Oo00?ooo]Z00Co0?nJoom/0?oonf[ooh401?oUo`04oookJP03
o`3koooonf[ooo]Z00Gooo]Z00Goo`<0onGo0?oUo`3oiOl0ool0g@02onGo0004oookJ_nco`3o01Oo
oil0o`Sooo]Z00?o0?oNomgo0?oonfX00_oo08L4oookJP05ool0K?oonf[ooo]ZonGo0?oonfX00_oo
;P02oookJP05of40oooonf[ooo]ZoookJ_l0odD01_oonfX01?oR0?oo0?n@o`3oT?l0oi07oookJP?o
0?nB=ooonfX4o`3oTP;ooo]Z0_l0oi02on80o`Kooo]Z0_mQ0?l00ooonf[oolT0ooo90002odd0o`03
oookJ_oo06coo`1/00;o001o0_oo08L00ol0omko001oo`00O`03oookJP03oil0oonco`3o/ol000So
olT000?ooo]Zo`3koooonfX00_oonfX2oc_o0003oon10?ooK03ooo]Z00;ooo]Z00Ko07Ooool0nOoo
nf[oZ03ooookJ_l0Y_l2oookJP06ool0m_oonf[ojol0ool60?oonf[o603o0ooonfX00ooo0?coiOl0
onGo0008onGo00;ooo]Z00?oo`3ZoookJ_oonfX03OoonfX00ol0Looooo]ZoookJP0;oookJP05okWo
0?ooDP3o0?lcoookJ_l0:_l00_oonfX7onGo00Kooo]Z00Co0?lKodCo0?oonf[oolX01?oonfX00ooo
09?ooo]Zool04`05oookJP03om[o0?oonf[ohOl000?ooo]Z00?oQ03oobH0oooonfX04?oonfX00ola
o`3ooo]Zo`3oF`02oookJP;oiOl000Oo0?n`oh;o0?l0<?ooiOl0o`3Xool0odgoiOl000;ooo]Z00?o
1P3ooi;o0?oonfX00_oonfX00ol@0?oo05goo`0Io`03oookJPKoU?l000?oo`1ioookJ_oonfX02?oo
nfX00ol0oe?ooo]ZoookJP02oookJP03o`3o7OnDo`3ooo]Z00gooo]Z00Go0?ldoookJ_oonf[o0?l^
o`3oCP1EoookJP04oaP0oooonf[ooo]Zool600Cooo]Z00?ojol0ool0m_oonfX00_oonfX00ol0Y_oo
Z03ooookJP04oookJP03ool0nOoonf[o07Oo00Cooo]Z00Ko0?nJoom/0?oonf[ooh40oookJ_lko`05
oookJP03o`3koooonf[ooo]Z00Gooo]Z00?oo`<0oookJ_oonfX00_oonfX01_oo0=gooo]ZoookJ_oo
nf[o/ol0oil0o`Wooo]Z00Co0?oNomgo0?oo08Ooo`271?oonfX01Ooo06cooo]ZoookJ_m=0?oooo]Z
00;oobh00_oonfX01OmQ0?oooo]ZoookJ_oonf[o0?m500Oooo]Z00CohP3oo`3oT?l0oi3o0?n@1_oo
nfX3o`3oTSOooo]Z1?l0oi82oookJP;o0?n@0_oR0?l7oookJP;oH@3o0ooo;P02odd0o`;oo`1/0ol0
07l01?oo08Oo0?oNo`00Ool007l3oookJP06oil0oonco`3o/ol0o`2Soomi0?ooo`3M0_l000001Ooo
nf[oo`<0oookJ_oonf[o0?_o00?ooo]Z0_lko`000oooP@3oof`0o`3oVP02oookJP04o`1goooonf[o
o`3iojP0o`;ooo]Z00So0:KooookJ_oonf[oo`3fon_o0?oo1P3ooo]ZoaP0o`Cooo]Z00Koo`3loook
J_oonf[ooo]ZoonB0?oo5P07oookJP03ool0j_oonf[ooo]Z00gooo]Z00?o07?ooookJ_oonfX02_oo
nfX01_nio`3ooo]ZoomB0?l0oc?ooo]Zo`0Zo`?ooo]Z00Co?ol0o`3Loomho`3o0?oO2?oonfX01?l0
oa_ooo]ZoookJ_oobP03oookJP04o`3ioooo09?ooo]Zool04`Gooo]Z00?of_l0on7o0?oonfX00ooo
nfX00olV0?oooo]ZoookJP0?oookJP04oc7o0?oonf[ooo]Zo`3oF`?ooo]Z00Ko0?n`oh;o0?l0ok7o
033oo`3Xool0odd3oookJP03o`H0oooonf[oT_l000?ooo]Z00?o403oo`0IoooonfX00ooonfX01olE
0?oooo]Zool0DOoonf[o0:gooookJ_oo07T02OoonfX00ol0oe?ooo]ZoookJP02oookJP03o`3o7Ol0
o`So0>7o00kooo]Z00Go0?ldoookJ_oonf[o0?l^o`3oCP0XoookJP00<OoonfX00olH0?oooo]ZoiCo
0004oookJP03on_o0?l0ojgooo]Z00;ooo]Z00?o0:KooookJ_nX0?l01OoonfX00ooo0?Wooo]Zo`1g
o`03oookJP04o`3oV_ooK03ooh40o`3oc0GoiOl00ooonfX00ol0nooooo]ZoookJP05oookJP06ool3
0?oUo`3oiOl0onGo0?oo0=goiOl00_oonfX2ok?o0003oil0oooonf[ooo]Z00Kooo]Z0_l0omh2oook
JP03ool0Qooonf[ooo]Z00;ooo]Z00Koo`1/oookJ_oonf[oiOl0odd0oooonfX2ool^0003oookJ_mQ
0?oooo]Z00;ooo]Z0_l0odD5oookJP;ohP3o00Cooo]Zo`3oT?l0oi3o0?n@1ooonfX3o`3oTQOooo]Z
0onDo`0GoookJP?o0?nB0ooonfX2o`3oT0?ohP3o0_oob@04oookJP;oH@3o00?ooo]Zooo90?oob@00
0_m=0?l2o`00O`07ool0K?oonf[ooo]Zo`00Oooo08Oo0?oNoookJP03o`00O`;ooo]Z00?oW`3ook?o
0?oonfX01_oob@03oookJP08o`3koooonf[ooo]ZoookJ_lko`3ooo]Zoon10?ooK003oookJP06o`1g
oooo0?Wooo]ZojP0oooonf[o0:Ko0_oonfX01?oo0?Kooo]Zon_o0?oo1P02oookJP04oaP0oooonf[o
oo]Zool0o0WoiOl00ooonfX00ooo0>[ooo]ZoookJP0>oookJP03o`1coooonf[ooo]Z00[ooo]Z00?o
^Ol0oomB0?l0oc<00_oonfX00ol0:_oooo]ZoookJP06onGo00Oooo]Z00Co0?lKoookJ_oonf[oolX0
0ooonfX01?l0nOooo`2CoookJ_oo01<5oookJP03om[o0?oQo`3ooo]Z00;ooo]Z00?oQ03oobH0oolP
o`004?oonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP0=onGo0?l0ok3oP_l0o`0`oooUo`3o0>SoonGo
0?l0odgoiOl0oookJ_l60?oooo]Zoi;o0003oookJP03oa00ool06Oooo`1Z00?ooo]Z1_nDo`000ooo
07Wooo]ZoookJP07oookJP03o`3oDooonf[ooo]Z00;ooo]Z00?o0?lMo`3o2?nDo`003_oonfX01?l0
ocCooo]ZoookJ_l0odiGoookJP04oaP0oooonf[ooo]Zool600?ooo]Z00?ojol0oookJ_oo0?H00ooo
nfX00ol0Y_ooZ03ooookJP04oookJP03ool0nOoonf[o07Oo00Cooo]Z00Ko0?nJoom/0?ooP@3o0?o<
oookJ_lko`05oookJP03o`3koooonf[ooo]Z00Gooo]Z00?oo`<0oookJ_oonfX00_oonfX01?oo0=go
oo]ZoookJ_oonfX2ok?o00Wooo]Z0_l0omh00ooonf[oo`27oookJP03oookJP03ool0K?oonf[ooo]Z
00;oC@3o00Gooo]Zool^0?oo;P3ooo]Zof40o`03oookJP;o0?m51_oonfX2on80o`04oookJ_l0oi3o
0?n@o`3oT0Kooo]Z1?l0oi8`oookJP?o0?nB0ooonfX2o`3oT0?ohP3o1ooonfX2of40o`;oobh00om=
0?l01Ol007ooo`1/oookJ_oonf[o001o00;oo`2700CogOl0o`00Ool007oo001o0_oonfX01?nO0?oo
/ol0o`0Gool0Xol2ool0g@;o00000_oo0`02oookJP09o`3koooonf[ooo]ZoookJ_lko`3ooo]Zoon1
0?ooK03o0?nJ00;ooo]Z00Co07OooookJ_oo0?WoZ03o0_oonfX01_l0Y_oooo]ZoookJ_oo0?Kojol0
ool600;ooo]Z00Go603ooookJ_oonf[ooo]Zool0o004oookJP03oonB0?oonf[ooo]Z00Gooo]Z00?o
o`3ZoookJ_oonfX03_oonfX00ol0Looooo]ZoookJP0:oookJP05okWo0?ooDP3o0?lcoookJ_l0:_l0
0ooonfX01?loo`3o0=coocd0oomho`08oookJP05o`3o6olB0?oooo]ZoookJ_oobP000_oonfX01Ol0
nOoooo]Zool0Tooonf[oo`0C00Cooo]Z00?of_l0on7o0?oonfX00ooonfX00olV0?oo8?l0oookJP0?
oookJP04oc7o0?oonf[ooo]Zo`3oF`?ooo]Z00Oo0?n`oh;o0?oonf[o033ooookJ_l0j?oo0?m=00;o
oo]Z00Co1P3ooookJ_nBo`3oo`3e0_oonfX00ol@0?oo01Woool0JP04oookJP04oaD0oooo057ooo]Z
o`2]o`;ooo]Z00?oo`1ioookJ_oonfX01_oonfX00ol0oe?ooo]ZoookJP02oookJP04o`3o7Ooonf[o
0?l8o`3Qo`gooo]Z00Go0?ldoookJ_oonf[ooo]Zo`3oCP0YoookJP00<OoonfX01?lH0?oooo]Zoook
J_nDo`03oookJP03on_o0?oonf[o0?n]00?ooo]Z00?o0:KooookJ_nX0?l01?oonfX00ooo0?Wooo]Z
o`1go`04oookJP03oom/0?oonf[ooh4000OoiOl000?ooo]Zo`3koooonfX01_oonfX01Ooo0`3oiOl0
onGo0?oUo`3ooo]Z00;oo`3M0_oonfX00ol0Xooo/ol0oil0o`09oookJP;o0?oN00?ooo]Zool0Qooo
nfX00ooonfX01?oo06cooo]ZoookJ_oonfX2odd0o`03oookJ_oo;P3oobh000;oH@3o0ooonfX00ol0
odGooo]ZoookJP04oookJP04on80oooonf[ooo]ZoookJP?o0?n@1ooonfX3o`3oTQ3ooo]Z1onDo`0C
oookJPCo0?nB0_oonfX3o`3oT0?ohP3o0_oonfX3ooo900;ooo]Z0_mQ0?l00ol0odGoolT0ooo90002
odd0o`;o001o0_oo06`01Ol007oooo]Zool0Qooo08OogOl000?ooo]Z0_l007l01?nO0?oo/ol0ok?o
0?oonfX5ooo900;o00000_oonfX01Ol0nooooo]ZoookJ_oonf[o>ol000;ooh4000[oof`0oookJ_oo
nf[ooo]Zo`1goooo0?Wooo]ZojP0oooonf[o0:Ko0_oonfX01?oo0?Kooo]Zon_o0?oo1P02oookJP05
oaP0oooonf[ooo]Zool0o?oonfX02OoUo`02oookJP03ool0j_oonf[ooo]Z00kooo]Z00?o07?ooook
J_oonfX02_oonfX00onio`3ooe80o`3o<`02oookJP05o`0Zoooonf[ooo]ZoookJ_loo`001?oUo`07
oookJP04o`3o6om4o`3ooo]Zooo:00Cooo]Z00?oo`2CoookJ_oo01<01OoonfX00ooJo`3ohOl0oook
JP03oookJP03obH0oolPo`3ooo]Z00oooo]Z00Co<Ol0oookJ_oonf[o0?mK0ooonfX02?oUo`3oP_l0
onGo0?l0<?ooiOl0o`3Xool0odgoiOl00_oonfX00ol60?ooo`3eoi;o0002oookJP03oa00ool0GOoo
01Wo00?ooo]Z1_nDo`000ooo07Wooo]ZoookJP08oookJP03o`3oDooonf[ooo]Z00;ooo]Z00?o0?lM
oookJ_nDo`003OoonfX01Ol0ocCooo]ZoookJ_l0obko0?m>05Oooo]Z00Co603ooookJ_oonf[oo`H0
1?oonfX00oo[o`3ooo]Zool0mP03oookJP03o`2VoonX0?oooo]Z00?ooo]Z00?oo`3ioookJ_l0Mol0
1?oonfX00ol0oi[oof`0oookJP02oon10003oookJ_lko`3ooo]Z00?ooo]Z00?o0?_ooookJ_oonfX0
1OoonfX00ooo0`3ooo]ZoookJP03oookJP06ool0gOoonf[ooo]ZoookJ_l0Xooo/ol02_oonfX2o`3o
gP03ool0Qooonf[ooo]Z00;ooo]Z00Coo`1/oookJ_oonf[ooo]Z0_m=0?l00ooonf[oobh0ool^0002
of40o`?ooo]Z00?o0?m5oookJ_oonfX01OoonfX01?oR0?oooo]ZoookJ_oonfX3o`3oT0Oooo]Z0ol0
oi8YoookJPCo0?nB0_oonfX3o`3oT0?ohP3o2?oonfX2of40o`04o`3oAOoo;P3oC@3oodd0o`;o001o
0_oo06`01Ol007oooo]Zool0Qooo08OogOl000?ooo]Z0_l007l01onO0?oo/ol0ok?o0?oonf[o0:?o
ool0gOoonfX00_l000001Ooo0`3o0000oookJ_oonf[o0?_o00?ooo]Z00Go>ol0oon10?ooP@3oof`0
o`3oVP02oookJP04o`1goooonf[oo`3iojP0o`;ooo]Z00Ko0:KooookJ_oonf[oo`3fon_o0?oo1P02
oookJP05oaP0oooonf[ooo]ZoookJ_oo0?`01?oonfX00oooTP3ooo]ZoookJP05oookJP03ool0j_oo
nf[ooo]Z00kooo]Z00?o07?ooookJ_oonfX02_oonfX00onio`3ooe80o`3o<`02oookJP08o`0Zoooo
nf[ooo]ZoookJ_loo`3o0=coogSo0?l0oml7oookJP05o`3o6olB0?oooo]ZoookJ_oobP000ooonfX0
1?l0nOooo`2CoookJ_oo01<5oookJP03om[o0?oQo`3ooo]Z00;ooo]Z00?o9P3oob3o0?oonfX04?oo
nfX01?lao`3ooo]ZoookJ_l0oe/3oookJP06oh;o0?oonf[o0?nao`0`ool0j?oo0?m=0ooonfX00ol6
0?oooo]Zoi;o0003oookJP03oa00ool06Ooooo]Z00?ooo]Z00Oo5@3ooookJ_oo057ooo]Zo`2]oooo
nf[oo`1i00Wooo]Z00?o0?mCoookJ_oonfX00_oonfX01?l0oago0?l8oookJ_l0hOl=oookJP05o`3o
=?oonf[ooo]Zo`3o;_l0odh0:OoonfX002[ooo]Z00?oo`3loookJ_oonfX01OoonfX00olH0?oooo]Z
oiCo0004oookJP03on_o0?l0ojgooo]Z00?ooo]Z00?o0:KooookJ_nX0?l01?oonfX00ooo0?Wooo]Z
o`1go`03oookJP04o`3oV_ooK03ooo]ZoookJPSoiOl000?o0?_ooookJ_oonfX01OoonfX00ooo0`3o
iOl0oookJP03oookJP04ool0gOoonf[ooo]ZoookJP;o/ol02_oonfX01?l0omkogOl0ool0Qooo08L3
oookJP03ool0K?oonf[ooo]Z00;ooo]Z0_m=0?l00ooonf[oobh0ool^0003of40o`03oookJ_l0odGo
0?m500Gooo]Z0ooR0?l3oookJP?o0?n@1ooonfX3o`3oTP[ooo]Z2_nDo`0@oookJP?o0?nB0ooonfX3
o`3oT0?ohP3o1?oonfX3ooo90003o`3oAOmQ0?ooH@3o00;oolT000?ooo]Zodd0oom=0?l00_l007l2
ool0K0;o001o0_oo08L00ol0omko001oo`00O`03oookJP05o`00Oonco`3o/ol0o`0Gool0Xol01?oo
b@001?oo0`3o0000o`000?l00002o`3ko`;ooo]Z0_lko`000oooP@3oof`0oom/0003oookJP04o`1g
oooo0?Wooo]ZojP0o`;o0:Ko0_oonfX01?oo0?Kooo]Zon_o0?oo1P02oookJP05oaP0oooonf[ooo]Z
ool0o?oonfX02?oUo`03oookJP03ool0j_oonf[ooo]Z00kooo]Z00?o07?ooookJ_oonfX02ooonfX0
1Onio`3ooe80oookJ_oonf[o02[o00?ooo]Z00?o?ol0onGo0?oUo`000_oUo`08oookJP03o`3o6ooo
nf[oolX000Cooo]Z00Coo`2CoookJ_oonf[oo`0C1OoonfX00ooJo`3ohOl0oookJP02oookJP03oh@0
oolV0?oooo]Z013ooo]Z00Co<Ol0oookJ_oonf[o0?mK0ooonfX00ol0ok3oP_l0o`0`o`02onGo0007
o`3Xool0odgooo]ZoookJ_l60?oooo]Zoi;o0003oookJP03oa00ool06Ooooo]Z00?ooo]Z1OnDo`00
0ooonf[oo`1ioookJP08oookJP03o`3oDooonf[ooo]Z00;ooo]Z00?o0?lMo`3o2?nDo`003_oonfX0
1?l0ocCooo]ZoookJ_l0odiAoookJP03ool0o?oonf[ooo]Z00Gooo]Z00Co603ooookJ_oonf[oo`H0
0ooonfX00oo[o`3ooo]Zool0mP04oookJP03o`2VoonX0?oooo]Z00?ooo]Z00?oo`3ioookJ_l0Mol0
1?oonfX01ol0oi[oof`0oookJ_l0olcooh40oookJ_lko`001?oonfX00ol0nooooo]ZoookJP05oook
JP03ool30?oonf[ooo]Z00?ooo]Z0_oo0=d2oookJP03o`0Goonco`3ooo]Z00[ooo]Z00?o0?oNool0
Qooo08L00ooonfX00ooo06cooo]ZoookJP02oookJP;oC@3o00?ooo]Zool^0?oo;P000omQ0?l00ooo
nf[o0?m5o`3oA@06oookJP?ohP3o0ooonfX3o`3oT0Oooo]Z0ol0oi8SoookJP?o0?nB0ooonfX3o`3o
T0?ohP3o2?oonfX3of40o`;oobh00_m=0?l2o`00O`;oo`1/0ol007l01?oo08Oo0?oNomgo0?l007l3
oookJP04o`00Oonco`3o/ol0o`0Go`;o0:?o00?oo`3MoookJ_oonfX00_oo0`02o`0000;o0?_o0_oo
nfX2oc_o0004oon10?ooK03oof`0o`3oVP;ooo]Z00Go07OooookJ_oo0?WoZ03ooookJP02o`2Vo`;o
oo]Z00?oo`3fon_o0?oo1P000_oonfX01OlH0?oooo]ZoookJ_oonf[oo`3l00Cooo]Z00?ooi80oook
J_oonfX01OoonfX00ooo0>[ooo]ZoookJP0>oookJP03o`1coooonf[ooo]Z00[ooo]Z00?o^Ol0oook
J_ooDP000_oonfX02?l0:_oooo]ZoookJ_oonf[o?ol0o`3Loolm0?ooN?l02?oonfX01?l0oa_ooo]Z
oookJ_oobP03oookJP05o`3ioooo09?ooo]ZoookJ_oo01<01?oonfX00ooJo`3ohOl0oookJP03oook
JP03obH0oolPo`3ooo]Z00oooo]Z00Co<Ol0oookJ_oonf[o0?mK0ooonfX01ol0ok3oP_l0oookJ_l0
<?oooo]Zo`3Xool0odd00_oonfX01?l60?oooo]Zoi;o0?oo0?D2oookJP03oa00ool06Oooo`1Z00Co
oo]Z00Co5@3ooookJ_oo057o0:go0_oonfX00ooo07Wooo]ZoookJP07oookJP08o`3oDooonf[ooo]Z
oookJ_l0oagooo]Zo`3o2?l0hOl>oookJP04o`3o=?oonf[ooo]Zo`3oCR[ooo]Z000ZoookJP03ool0
o?oonf[ooo]Z00Kooo]Z00?o603ooookJ_nDo`000ooonfX00oo[o`3ooo]Zo`3o[@04oookJP03o`2V
oooonf[oZ03o00?ooo]Z00Coo`3ioookJ_oonf[o07Oo0ooonfX00ol0oi[oof`0oookJP09onGo00;o
0?_o1_oonfX00ooo0`3ooo]ZoookJP03oookJP06ool0gOoonf[ooo]ZoookJ_l0Xooo/ol02_oonfX2
o`3ogP03oookJ_oo08Oooo]Z00;ooo]Z00?oo`1/oookJ_oonfX00ooonfX3odd0o`;oobh000Gooo]Z
of40oomQ0?ooH@3oo`3oA@07oookJPGohP3o00Cooo]Zo`3oT?l0oi3o0?n@1ooonfX3o`3oTP?ooo]Z
3_nDo`000ooonf[oolT0ooo9000:oookJP?o0?nB0_oonfX4o`3oT003oookJ_oR0?oohP3o00Gooo]Z
0_oob@02o`3oA@;oH@3o0_oob@03odd0o`;o001o0_oo06`01_oonf[o001oo`00Oooo08Oo0?oNoook
JP?o001o0ooonfX01?nco`3o01Ooo`2Sool0Xol2ooo90003oookJ_oo0`3ooo]Z00?o000000Go0?_o
oookJ_oonf[ooo]Zoc_o0002oon10003oom/0?oonf[ooo]Z00;ooo]Z00Go07Ooool0nOoonf[oZ03o
o`2Vo`03oookJP04ool0m_oonf[ojol0ool600;ooo]Z00Co603ooookJ_oonf[oo`3l0_oonfX7onGo
00?ooo]Z00?oo`3ZoookJ_oonfX03ooonfX00ol0Looooo]ZoookJP0:oookJP03okWo0?ooDP3o0?lc
00;ooo]Z00Go02[ooookJ_oonf[o?ol0oookJP03onGo00Sooo]Z00Co0?lKoookJ_oonf[oolX01?oo
nfX00ooo09?ooo]Zool04`05oookJP03om[o0?oQo`3ooo]Z00?ooo]Z00?o9P3oob3o0?oonfX03ooo
nfX01?lao`3ooo]ZoookJ_l0oe/3oookJP07o`3o/?n2o`3oiOl0o`0`oooUo`3o0>Soo`3oC@02oook
JP04o`H0oooonf[oo`3eoi;o00?ooo]Z00?o403oo`0IoooonfX00ooonfX5oiCo0003oookJ_oo07Wo
oo]Z00Sooo]Z00?o0?mCoookJ_oonfX00_oonfX00ol0oagooo]ZoiCo000=oookJP05o`3o=?oonf[o
oo]Zo`3o;_l0odh0DOoonfX00ooo0?cooo]ZoookJP06oookJP03oaP0oooonf[oo`H000Cooo]Z00?o
jol0oookJ_oo0?H00ooonfX00ol0Y_oooo]ZojP0o`03oookJP04ool0nOoonf[ooo]Zo`1go`Cooo]Z
00Oo0?nJoom/0?oonf[o0?o<oon10?oonf[o>ol000Cooo]Z0_l0nol6oookJP03ool30?oonf[ooo]Z
00?ooo]Z00GoN@3oool0gOoonf[ooo]Zo`0Go`02ok?o00[ooo]Z0_l0omh01Ooo08Oooo]ZoookJ_oo
nf[oo`1/00Gooo]Z0om=0?l2ool^0005oookJ_mQ0?ooH@3oof40ool0odD02?oonfX5on80o`04oook
J_l0oi3o0?n@o`3oT0Oooo]Z0ol0oi8MoookJP?o0?nB0_oonfX4o`3oT003oookJ_oR0?oohP3o00So
oo]Z00?o0?m5of40oomQ0?l00ooo;P02odd0o`;o001o0_oo06`00ooonf[o001oo`00O`02ool0Q`04
omgo0?l007oo001oo`00O`?ooo]Z00Ko/ol0o`0Gool0Xooo0:?oogT0oooo0=d2oookJP05ool30?l0
003o0000o`000?l0nol00ooonfX01Olko`3ooh40oon10?ooK03o0?nJ00?ooo]Z00Ko07Ooool0nOoo
0?WoZ03ooookJ_l0Y_l3oookJP03ool0m_o[o`3oo`H000;ooo]Z00Go603ooookJ_oonf[ooo]Zool0
o004oookJP03oonB0?oo5P3ooo]Z00Gooo]Z00?oo`3ZoookJ_oonfX03ooonfX00ol0Looooo]Zoook
JP0:oookJP05okWo0?ooDP3o0?lcoookJ_l0:_l00ooonfX01?loo`3o0=coocd0oomho`08oookJP05
o`3o6olB0?oooo]ZoookJ_oobP000ooonfX01?l0nOooo`2CoookJ_oo01<5oookJP03om[o0?oonf[o
oo]Z00;ooo]Z00?o9P3oob3o0?oonfX04?oonfX01?lao`3ooo]ZoookJ_l0oe/3oookJP06oh;o0?oo
nf[ooo]Zo`0`oooonf[o0?m=0_oonfX01?l60?oooo]ZoookJ_nBo`03oookJP03oa00ool06Ooooo]Z
00?ooo]Z00Go5@3ooookJ_oo057ooo]Zo`2]o`02oookJP03ool0NOoonf[ooo]Z00Kooo]Z00?o0?mC
oookJ_oonfX00_oonfX01?l0oago0?l8oookJ_l0hOl=oookJP05o`3o=?oonf[ooo]Zo`3o;_l0odh0
:_oonfX002_ooo]Z00?oo`3loookJ_oonfX01OoonfX00olH0?oooo]ZoiCo0004oookJP03on_o0?l0
ojgooo]Z00?ooo]Z00Co0:KooookJ_oonf[oZ03o0ooonfX01?oo0?Wooo]ZoookJ_l0Mol3oookJP03
o`3oV_ooK03ooo]Z00[oiOl000?o0?_ooookJ_oonfX01?oonfX00ooo0`3ooo]ZoookJP03oookJP06
ool0gOoonf[ooo]ZoookJ_l0Xooo/ol02ooonfX2o`3ogP;oo`270_oonfX00ooo06cooo]ZoookJP05
oookJP;oC@3o0_oo;P02oookJP;oH@3o0_l0odD9oookJPCohP3o0ol0oi07oookJP03o`3oT_nDo`3o
U?l000coU?l01Ooob@09oiCo0003o`3oT_oonf[ooo]Z00?o0?n@0_oonfX3on80o`Kooo]Z0ol0odD2
of40o`;oolT00_m=0?l3oookJP;oo`1/00?o001ooookJ_oonfX00_oo08L00ooMo`3ooo]ZoookJP03
o`00O`03oookJ_nco`3o/ol000;o0:?o00?oo`3Mooo90?oonfX00_oo0`02oookJP;o000000?o0?_o
o`000?oonfX00_lko`000oooP@3o0?o<oom/0003oookJP;o07Oo0_oonfX00onX0?oo0:KooookJP02
oookJP04ool0m_oonf[ojol0ool600;ooo]Z00Co603ooookJ_oonf[oo`3l0_oonfX6onGo00Cooo]Z
00?oo`3ZoookJ_oonfX03ooonfX00ol0Looooo]ZoookJP0:oookJP03okWo0?ooDP3o0?lc00;ooo]Z
00Co02[ooookJ_oonf[o?ol00_oonfX2onGo00Sooo]Z00Co08koo`3o6ooonf[oolX01?oonfX01?oo
09?ooo]ZoookJ_oo01<5oookJP03om[o0?oQo`3ooo]Z00;ooo]Z00?o9P3oob3o0?oonfX04?oonfX0
1?lao`3ooo]ZoookJ_l0oe/3oookJP03o`3o/?n2o`3o033o00;oiOl000Oo0?m=oookJ_oonf[ooo]Z
o`H0oooonf[oT_l000?ooo]Z00?o403oo`0IoooonfX01?oonfX4oiCo0003oookJ_oo07Wooo]Z00Wo
oo]Z00Oo0?mCoookJ_oonf[ooo]Zo`3o7Ol0o`SoU?l000kooo]Z00Co0?ldoookJ_oonf[o0?m>1_oo
nfX00ol0R?oooo]ZoookJP1:oookJP03ool0o?oonf[ooo]Z00Gooo]Z00Co603ooookJ_oonf[oo`H0
0ooonfX00oo[o`3ooo]Zool0mP04oookJP03o`2Voooonf[oZ03o00?ooo]Z00Coo`3ioookJ_oonf[o
07Oo0ooonfX02?l0oi[ooo]Zoom/0?l0olcooo]Zoon10?oonf[o>ol01OoonfX00ol0nooooo]Zoook
JP04oookJP03ool30?oonf[ooo]Z00?ooo]Z00OoN@3oool0gOoonf[ooo]Zo`0Gool0Xooo/ol000_o
oo]Z00?o0?oNool0Qooo08L00_oonfX00ooo06cooo]ZoookJP05oookJP;oC@3o0_oo;P02oookJP;o
H@3o0_l0odD:oookJPCohP3o0ol0oi07oookJQgo0?nB0_oonfX3o`3oT0;ooo]Z0ooR0?l7oookJP;o
0?m50_mQ0?l2ool^0003oookJ_m=0?ooC@3o00;ooo]Z0_oo06`01Ol007oooo]ZoookJ_l007ooo`27
00;ogOl000Gooo]Zo`00Ool007oo001ooookJP02ok?o00;o0:?o00Co001oool0gOoo0=gooo]Z0_oo
0`001Ooonf[o0000o`000?l0nooo000000;ooo]Z00Go>ol0oon10?l0olcoof`0o`3oVP02oookJP;o
07Oo00Goo`3ioookJ_nX0?oooo]Zo`2Vo`03oookJP03ool0m_o[o`3oo`H000;ooo]Z00Go603ooook
J_oonf[ooo]Zool0o004oookJP03oonB0?oo5P3ooo]Z00Gooo]Z00?oo`3ZoookJ_oonfX03ooonfX0
0ol0Looooo]ZoookJP0:oookJP05okWo0?ooDP3o0?lcoookJ_l0:_l00ooonfX01Oloo`3ooo]Zo`3L
oomho`3o0?oO00Oooo]Z00Go08koo`3o6ooonf[ooo]Zooo:0003oookJP05o`3ioooo09?ooo]Zoook
J_oo01<01?oonfX00ooJo`3ohOl0oookJP02oookJP03obH0oolPo`3ooo]Z013ooo]Z00Co<Ol0oook
J_oonf[o0?mK0ooonfX01_l0ok3oP_l0oookJ_l0<?oooo]Zo`3oC@?ooo]Z00Co1P3ooookJ_oonf[o
T_l00_oonfX00ol@0?oo01WooookJP04oookJP04oaD0oooonf[oo`1Ao`2]o`;ooo]Z00?oo`1ioook
J_oonfX01ooonfX02?l0oe?ooo]ZoookJ_oonf[o0?lMoookJ_l0o`So0>7o3_oonfX01?l0ocCooo]Z
oookJ_l0odh6oookJP03o`28oooonf[ooo]Z02;ooo]Z000[oookJP03ool0o?oonf[ooo]Z00Kooo]Z
00?o603ooiCo0?oonfX01?oonfX00oo[o`3o0?n]oookJP03oookJP03o`2Voooonf[oZ03o00?ooo]Z
00Goo`3ioookJ_oonf[ooo]Zo`1go`02oookJP04o`3oV_oonf[oof`0oookJP[oiOl000?o0?_ooook
J_oonfX01?oonfX00ooo0`3ooo]ZoookJP03oookJP;oo`3M0_oonfX00ol0Xooo/ol0ok?o000;oook
JP03o`3og_oMo`3oo`2700;ooo]Z0_oo06`7oookJP;oC@3o0_oo;P02oookJP?oH@3o0ol0odD9oook
JPGohP3o00?o0?n@oookJ_oonfX01_oonfX8oiCo00SoolT02OoonfX3o`3oT0;ooo]Z0ooR0?l6oook
JP?o0?m50omQ0?l2ooo900;oC@3o0_oob@001?oonf[oo`1/ool0K?oonfX2o`00O`;oo`2700?o0?oN
o`00Ool007l00_oonfX2o`00O`;o/ol00_l0Xol2ool0g@03ogT0oooo0`3oo`<000Cooo]Z00Wo0000
o`3kool0003o0000oc_o0?oonf[ooh40o`3oc?ooK0000ooonfX01_l0Moooo`3ioookJ_oonf[oZ03o
o`2Vo`?ooo]Z00Coo`3foookJ_o[o`3oo`H00_oonfX01?lH0?oooo]ZoookJ_oo0?`3oookJPGoiOl0
1?oonfX00ooo0>[ooo]ZoookJP0?oookJP03o`1coooonf[ooo]Z00_ooo]Z00Go^Ol0oomB0?oonf[o
oo]Zo`0Zo`03oookJP04ocoo0?oonf[oiOl0onGo00Wooo]Z00?o0?lKoookJ_oobP001OoonfX00ooo
09?ooo]Zool04`05oookJP03om[o0?oQo`3ooo]Z00?ooo]Z00?o9P3oob3o0?oonfX03ooonfX01?la
o`3ooo]ZoookJ_l0oe/3oookJP07o`3o/?n2o`3oiOl0o`0`oooUo`3o0>Soo`3oC@02oookJP04o`H0
oooonf[ooo]Zoi;o00?ooo]Z00?o403oo`0IoooonfX00ooonfX01olE0?ooU?l0oiCo0?nDo`3o0:go
oookJ_oo07T02OoonfX00ol0oe?ooo]ZoookJP02oookJP03o`3o7Ooonf[oU?l000kooo]Z00Co0?ld
oookJ_l0obko0?m>1_oonfX00ol0R?oooo]ZoookJP1:oookJP03ool0o?oonf[ooo]Z00Kooo]Z00?o
603ooookJ_oo1P001?oonfX00oo[o`3ooo]Zool0mP04oookJP03o`2VoonX0?oooo]Z00;ooo]Z00Go
o`3ioookJ_oonf[ooo]Zo`1go`03oookJP08o`3oV_oonf[oof`0o`3oc?oonf[ooh40oookJ_lko`05
oookJP03o`3koooonf[ooo]Z00Cooo]Z00?oo`<0oookJ_oonfX00ooonfX01_mi0?ooo`3MoookJ_oo
nf[o01Ooo`2So`;o/ol02ooonfX01?l0omkoo`27oookJ_oonfX2ool0K0Oooo]Z0_m=0?l2ool^00;o
oo]Z0omQ0?l3o`3oA@[ooo]Z1?oR0?l2o`3oT23ooo]Z0ol0oi02oookJP?ohP3o1ooonfX2o`3oA@?o
H@3o0_oo;P000ooonf[oC@3oodd0o`02oookJP;oo`1/00Cooo]Zo`00Ool007oo001o0_oo08L01?oM
o`3o001ooookJ_oonfX2o`00O`;o/ol000?o01Ooo`2Sool007l00_oo0=d00ooonf[oo`<0ool30003
oookJP04o`000?l0nooo0000o`0000;o>ol000Cooh40o`3oc?ooK03o0?nJ0_oonfX01ol0Mooooo]Z
ool0nOoonf[oZ03ooookJ_l0Y_l00ooonfX00ooo0?Kojol0ool60002oookJP05oaP0oooonf[ooo]Z
oookJ_oo0?`01?oonfX00oooTP3ooaH0oookJP05oookJP03ool0j_oonf[ooo]Z00oooo]Z00?o07?o
oookJ_oonfX02_oonfX00onio`3ooo]ZoomB0002oookJP08o`0Zoooonf[ooo]Zocoo0?oonf[o0=co
ocd0oomho`08oookJP04o`3o6ooonf[ooo]Zooo:00Cooo]Z00Co0?Woool0Tooonf[oo`0C1OoonfX0
0ooJo`3ooo]ZoookJP02oookJP03obH0oolPo`3ooo]Z013ooo]Z00Co<Ol0oookJ_oonf[o0?mK0ooo
nfX01_n2o`3ooo]ZoookJ_l0<?oooo]Zo`3oC@;ooo]Z00Go1P3ooookJ_oonf[oT_l0ool0m@02oook
JP03oa00ool06Ooooo]Z00?ooo]Z00Go5@3ooookJ_oo057ooo]Zo`2]o`02oookJP03ool0NOoonf[o
oo]Z00Kooo]Z00?o0?mCoookJ_oonfX00_oonfX01?l0oago0?l8oookJ_l0hOl=oookJP05o`3o=?oo
nf[ooo]Zo`3o;_l0odh01_oonfX00ol0R?oooo]ZoookJP0RoookJP00:ooonfX00ooo0?cooo]Zoook
JP07oookJP03oaP0oonDo`3ooo]Z00?ooo]Z00?ojol0o`3o[OoonfX01?oonfX00ol0Y_oooo]ZojP0
o`03oookJP;oo`3i0_oonfX01_l0Mooooo]ZoookJ_l0oi[oof`0oookJPSoiOl00ooonfX00ol0nooo
oo]ZoookJP04oookJP03ool30?oonf[ooo]Z00?ooo]Z00OoiOl0ool0gOoonf[ooo]Zo`0Gool0Xooo
/ol000_ooo]Z0_l0omh01?oo08Oooo]ZoookJ_oonfX3ool0K0Kooo]Z0_m=0?l2ool^00?ooo]Z0_mQ
0?l00ooonf[o0?m5o`3oA@02o`3oA@[ooo]Z1?oR0?l9oookJP03oiCo0?oob@3oolT000WoolT01_l0
oi08ooo900Kooo]Z0_l0odD4of40o`?oolT00_m=0?l3ooo900;oo`1/1?oonfX00ooo08Oo0?oNoook
JP03o`00O`;ooo]Z0_nco`001onO0?oo0:?oool0gOoo0=goN@3oo`00Oooo0`001OoonfX2o`3ko`;o
000000Go>ol0oon10?ooP@3o0?nJoom/0002oookJP;o07Oo00Goo`3ioookJ_oonf[oZ03oo`2Vo`03
oookJP04ool0m_oonf[ojol0ool600;ooo]Z00Co603ooookJ_oonf[oo`3l0ooonfX4onGo00Gooo]Z
00?oo`3ZoookJ_oonfX03ooonfX00ol0Looooo]ZoookJP0;oookJP03okWo0?ooDP3ooo]Z00;ooo]Z
00Co02[ooookJ_oonf[o?ol00_oonfX00ooUo`3ooo]ZoookJP07oookJP04odCo0?l0oa_ooo]Zooo:
00Cooo]Z00Coo`2CoookJ_oonf[oo`0C1OoonfX00ooJo`3ooo]ZoookJP02oookJP03obH0oolPo`3o
oo]Z013ooo]Z00Co<Ol0oookJ_oonf[o0?mK0ooonfX00ol0ok3oP_l0o`0`o`02onGo0008o`3oCOoo
nf[ooo]ZoookJ_l60?oooo]Zool0mOnBo`02oookJP03oa00ool06Ooooo]Z00Cooo]Z00Ko5@3ooiCo
0?nDo`3oU?l0o`2]oooo07T:oookJP03o`3oDooonf[ooo]Z00;ooo]Z00?o0?lMoiCo0?oonfX03Ooo
nfX01?l0ocCooo]ZoookJ_l0odh6oookJP03o`28oooonf[ooo]Z04cooo]Z00?oo`3loookJ_oonfX0
1_oonfX00olH0?oooo]Zool60004oookJP03on_o0?oo0?Kooo]Z00?ooo]Z00?o0:KooookJ_nX0?l0
0ooonfX2ool0n@;ooo]Z00co07OooookJ_oonf[ooo]Zo`3oV_ooK03ooo]Zo`3oc?oonf[ooh40oook
J_lko`05oookJP03o`3koooonf[ooo]Z00Cooo]Z00?oo`<0oookJ_oonfX00ooonfX02?mi0?ooo`3M
ool0gOoonf[o01Oooil0ool0Xooo/ol02ooonfX00ol0omkoo`27oookJP02oookJP?oo`1/1_oonfX2
odd0o`;oobh00ooonfX3of40o`Co0?m52_oonfX5on80o`kooo]Z3?l0oi08on80o`Oooo]Z00?o0?m5
of40oomQ0?l00_mQ0?l01?oonf[oobh0ool^0?oonfX2odd0o`;ooo]Z0_oo06`4oookJP03o`3og_oo
08OogOl000?o001o0_oonfX2ok?o0003oil0ool0Xooo0:?o00;oo`3M0_l007l00ooo0`3ooo]Zoook
JP02oookJP;o0?_o0_l000001_lko`3ooh40oon10?l0olcoof`0o`3oVP;ooo]Z00Oo07Ooool0nOoo
0?Wooo]ZojP0oooonf[o0:Ko00?ooo]Z00?oo`3fon_o0?oo1P000_oonfX01OlH0?oooo]ZoookJ_oo
nf[oo`3l00Gooo]Z00?ooi80oookJ_oonfX01?oonfX00ooo0>[ooo]ZoookJP0?oookJP03o`1coooo
nf[ooo]Z00_ooo]Z00Go^Ol0oomB0?oonf[ooo]Zo`0Zo`03oookJP04ocoo0?oonf[o?@3oogSo00So
oo]Z00Co08koo`3o6ooonf[oolX01?oonfX01Ol0nOooo`2CoookJ_oonf[oo`0C00Cooo]Z00?of_l0
oookJ_oonfX00_oonfX00olV0?oo8?l0oookJP0@oookJP04oc7o0?oonf[ooo]Zo`3oF`?ooo]Z00Ko
0?n`oh;o0?oonf[o033ooookJ_l0odd3oookJP04o`H0oooonf[ooo]Zoi;o00?ooo]Z00?o403ooook
J_oonfX00ooonfX01olE0?oooo]Zool0DOoonf[o0:gooookJ_oo07T02OoonfX00ol0oe?ooo]Zoook
JP02oookJP03o`3o7Ol0o`So0>7o00kooo]Z00Co0?ldoookJ_oonf[o0?m>1_oonfX00ol0R?oooo]Z
oookJP0SoookJP00;?oonfX00ooo0?cooo]ZoookJP06oookJP03oaP0oonDo`3ooo]Z00Cooo]Z00?o
jol0o`3o[OoonfX01?oonfX00ol0Y_oooo]ZojP0o`04oookJP09ool0nOoonf[ooo]Zo`1goooonf[o
0?nJoookJ_ooK03ooo]Z00KoiOl01OoonfX00ol0nooooo]ZoookJP04oookJP03ool30?oonf[ooo]Z
00?ooo]Z00KoiOl0ool0gOoonf[ooo]Zo`0Gool0Xol2ok?o00_ooo]Z00?o0?oNool0Qooo08L01?oo
nfX2ool0K0Kooo]Z0_m=0?l2ool^00?ooo]Z0omQ0?l2oookJPCo0?m52_oonfX5on80o`;o0?n@5?oo
b@0;oookJP03o`3oAOmQ0?ooH@3o00;oH@3o1Ooob@02odd0o`CoolT000?oo`1/ooo90?oob@000_oo
nfX2ool0Q`03omgo0?l007oo001o00?o001o00?ooo]Zok?o0?nO0?l00_l0Xol00ooo0=gooo]ZogT0
o`02ool30003o`00Oooonf[ooo]Z00;ooo]Z00?o0?_ooookJ_l000000_lko`001?ooP@3ooo]Zo`3o
V_ooK002oookJP03o`1goooo0?Wooo]Z00;ooo]Z00?oZ03oo`2VoooonfX00_oonfX01Ooo0?Kojol0
on_o0?oo1P3ooo]Z00;o603o0_oonfX00ooo0?cooo]ZoookJP02oookJP?oiOl01OoonfX00ooo0>[o
oo]ZoookJP0@oookJP03o`1coooonf[ooo]Z00[ooo]Z00?o^Ol0oomB0?l0oc<00_oonfX01?l0:_oo
oo]ZoookJ_loo`02oookJP03ocd0oomho`3ooo]Z00Oooo]Z00Co08koo`3o6ooonf[oolX01?oonfX0
1?oo09?ooo]ZoookJ_oo01<5oookJP03om[o0?oQo`3ooo]Z00;ooo]Z00?o9P3oob3o0?oonfX04?oo
nfX01?lao`3ooo]ZoookJ_l0oe/3oookJP07o`3o/?n2o`3oiOl0o`0`oooUo`3o0>Soo`3oC@02oook
JP04o`H0oooonf[ooo]Zoi;o00?ooo]Z00?o403oo`0IoooonfX00ooonfX01olE0?oooo]ZoiCo0?nD
o`3o0:gooookJ_oo07T02_oonfX01ol0oe?ooo]ZoookJ_oonf[o0?lMoookJ_nDo`003_oonfX01?l0
ocCooo]ZoookJ_l0odh6oookJP03o`28oooonf[ooo]Z04cooo]Z00?oo`3loookJ_oonfX01_oonfX0
0olH0?oooo]Zool60004oookJP03on_o0?oonf[oo`3f00Cooo]Z00?o0:KooookJ_nX0?l01?oonfX0
1?oo0?Wooo]ZoookJ_l0Mol2oookJP09o`3oV_oonf[oof`0oookJ_l0olcooo]Zoon10?oonf[o>ol0
00Gooo]Z00?o0?_ooookJ_oonfX01?oonfX00ooo0`3ooo]ZoookJP03oookJP08ogT0oooonf[oo`3M
oookJ_l05oooW`3oo`2Soonco`0<oookJP;oo`271?oonfX2ool0K0Kooo]Z0_m=0?l2ool^00Cooo]Z
0omQ0?l00ooonf[o0?m5o`3oA@02o`3oA@_ooo]Z1?oR0?l8o`3oT0kohP3o3?oonfX4of40o`;ooo]Z
0ooo;P03odd0o`?ooo]Z00?oo`1/oookJ_oonfX00ooonfX2ool0Q`03omgo0?l007oo001o00;o001o
00?ooo]Zok?o0?nO0?l00_l0Xol2ool0g@04ogT0ool007ooo`<0ool300Cooo]Z00Wo0?_ooookJ_l0
003o0000oc_o0?ooP@3ooo]Zo`3oc?ooK0000_oonfX2o`1go`06ool0nOoonf[ooo]ZojP0oooonf[o
0:Ko0ooonfX2on_o0004ool60?oonf[o603ooaP0o`?ooo]Z00?oo`3loookJ_oonfX00ooonfX00ooo
TP3ooo]ZoookJP04oookJP03ool0j_oonf[ooo]Z013ooo]Z00?o07?ooookJ_oonfX02_oonfX01Oni
o`3ooe80o`3o<ooonf[o02[o00?ooo]Z00Go?ol0oookJ_l0g?oo?@3oogSo0007oookJP05o`2>ool0
oa_ooo]ZoookJ_oobP000ooonfX01Ol0nOooo`2CoookJ_oonf[oo`0C00Cooo]Z00?of_l0on7o0?oo
nfX00ooonfX00olV0?oooo]ZoookJP0@oookJP04oc7o0?oonf[ooo]Zo`3oF`?ooo]Z00KoP_l0oook
J_oonf[o033ooookJ_l0odd2oookJP05o`H0oooonf[ooo]Zoi;o0?oo0?D00_oonfX00ol@0?oo01Wo
oookJP03oookJP05oaD0oooonf[ooo]Zool0DOl0[Ol00_oonfX00ooo07Wooo]ZoookJP07oookJP08
o`3oDooonf[ooo]ZoookJ_l0oago0?l8oookJ_l0hOl=oookJP05o`3o=?oonf[ooo]Zo`3o;_l0odh0
1_oonfX00ol0R?oooo]ZoookJP0SoookJP00;?oonfX00ooo0?cooo]ZoookJP07oookJP03oaP0oonD
o`3ooo]Z00?ooo]Z00?ojol0o`3o[OoonfX01?oonfX01?l0Y_oooo]ZoookJ_nX0?l4oookJP08ool0
nOoonf[ooo]Zo`1goooonf[o0?nJoookJ_ooK006onGo00Kooo]Z00?o0?_ooookJ_oonfX01?oonfX0
0ooo0`3ooo]ZoookJP03oookJP08onGo0?oo0=goo`3MoookJ_l05ooo0:?ooookJ_nco`0;oookJP;o
0?oN00?oo`27oookJ_oonfX00ooonfX3ool0K0Gooo]Z0_m=0?l2ool^00Cooo]Z0omQ0?l3oookJP?o
0?m53?oonfX00ooR0?ooolT0ooo9000>ooo900gooo]Z1?mQ0?l3oookJPCoolT00_m=0?l4ooo900;o
o`1/0ooonfX2ool0Q`03o`3og_oonf[ooo]Z00Co001o0_nco`02o`2So`;oo`3M0_mi0?l00ooo0`3o
001oo`00O`04oookJP09o`3koooonf[ooo]Zoc_o0?l0003ooh40o`000?l0oi[oof`000;ooo]Z00?o
07Ooool0nOoonfX00_oonfX01?nX0?oo0:KooookJ_oonfX2ool0mP05on_o0?oonf[oo`H0oookJ_lH
0?l00ooonfX00ooo0?cooo]ZoookJP02oookJP?oiOl01OoonfX00ooo0>[ooo]ZoookJP0@oookJP03
o`1coooonf[ooo]Z00_ooo]Z00Gooe80o`3o<ooonf[ooo]Zo`0Zo`02oookJP05ocoo0?oonf[ooo]Z
o`3Loomho`002OoonfX00ol0oa_ooo]Zooo:0005oookJP03ool0Tooonf[oo`0C00Kooo]Z00?of_l0
oookJ_oonfX00_oonfX00olV0?oo8?l0oookJP0@oookJP04oc7o0?oonf[ooo]Zo`3oF`?ooo]Z00Ko
P_l0oookJ_oUo`3o033oonGo0?l0odd3oookJP04o`H0oooonf[oo`3eoi;o00;ooo]Z00?o403oo`0I
oooonfX01?oonfX01_lE0?oooo]ZoiCo0?oonf[o0:goool0N@[ooo]Z00?o0?mCoookJ_oonfX00_oo
nfX00ol0oagoU?l0oookJP0=oookJP04o`3o=?oonf[ooo]Zo`3oCPOooo]Z00?o08SooookJ_oonfX0
COoonfX00ooo0?cooo]ZoookJP06oookJP03oaP0oooonf[oo`H000Cooo]Z00?ojol0ool0m_oonfX0
1?oonfX00ol0Y_oooo]ZojP0o`04oookJP04ool0nOoonf[ooo]Zo`1go`;ooo]Z00Co0?nJoookJ_oo
K03o0?o<0_oonfX00oooP@3ooo]Zoc_o0005oookJP;o0?_o1OoonfX00ooo0`3ooo]ZoookJP03oook
JP07ogT0oooonf[oo`3MoookJ_l05oooW`3oo`2So`02ok?o00_ooo]Z00?o0?oNool0QooonfX01?oo
nfX3ool0K0Gooo]Z0_m=0?l2ool^00Gooo]Z0_mQ0?l3oookJP?o0?m53?oonfX8on80oaKooo]Z1?mQ
0?l4oookJP;oobh000?ooo]Zodd0oom=0?l01?oonfX2ool0K0Cooo]Z0_oo08L00ooMo`3ooo]Zo`00
O`03o`00O`;o/ol00_l0Xol01ol05oooo`3MogT0oomi0?oo001oool30?l007l01?oonfX00ol0nooo
oo]ZoookJP02oc_o0004oon10?l0003o0?o<oom/00;ooo]Z00?o07OooookJ_oo0?T00_oonfX00onX
0?oooo]Zo`2Vo`02oookJP06ool0m_o[o`3ooo]Zool60?oonf[o603o1?oonfX00ooo0?cooo]Zoook
JP02oookJP03oolF0?ooTP3ooo]Z00Gooo]Z00?oo`3ZoookJ_oonfX04?oonfX00ol0Looooo]Zoook
JP0:oookJP03okWo0?ooDP3o0?lc00;ooo]Z00So02[ooookJ_oonf[o?ol0oookJ_l0g?oo?@3oogSo
00Sooo]Z00Co0?lKoa80oooonf[oolX01?oonfX01?l0nOooo`2CoookJ_oo01<5oookJP03om[o0?oo
nf[ooo]Z00;ooo]Z00?o9P3oob3o0?oonfX04?oonfX01?lao`3ooo]ZoookJ_l0oe/3oookJP06o`3o
/?n2o`3ooo]Zo`3o/Ol0<?oo0?m=0ooonfX01?l60?oooo]ZoookJ_nBo`03oookJP03oa00oooonf[o
oo]Z00?ooo]Z00Oo5@3ooookJ_oo057ooo]Zo`2]oooonf[oo`1i00Wooo]Z00?o0?mCoookJ_oonfX0
0_oonfX00ol0oago0?l8o`3Qo`0>oookJP04o`3o=?oonf[ooo]Zo`3oCPOooo]Z00?o08SooookJ_oo
nfX08ooonfX002cooo]Z00?oo`3loookJ_oonfX01ooonfX00olH0?ooU?l0oookJP04oookJP03on_o
0?l0ojgooo]Z00Cooo]Z00Co0:KooookJ_oonf[oZ03o1?oonfX02?oo0?Wooo]ZoookJ_l0Mooooo]Z
o`3oV_oonf[oof`00ooUo`000oooP@3ooo]ZonGo0006oookJP;o0?_o1OoonfX00ooo0`3ooo]Zoook
JP03oookJP07onGo0?oonf[oo`3MoookJ_l05ooo0:?oonGo0002ok?o00_ooo]Z00?o0?oNool0Qooo
08L01_oonfX2ool0K0Gooo]Z0om=0?l00ooo;P3ooo]ZoookJP03oookJP;oH@3o1?oonfX4o`3oA@?o
oo]Z2?m4o`02oookJPcoolT02OoonfX4of40o`?ooo]Z0ooo;P03ooo900;oC@3o1?oonfX2ool0K0;o
oo]Z00CogOl0o`3og_oo08Oo0?oN1OoonfX00ol007oo/ol0ok?o0002o`2So`;oo`3M00Co001oogT0
oooo0`3oo`<00ol007l3oookJP04o`3koooonf[ooo]Zoc_o00;ooh4000Co0000o`3oV_ooK03ooo]Z
0_l0Mol01_oo0?Wooo]ZoookJ_oonf[oZ03oo`2Vo`;ooo]Z00Ooo`3foookJ_o[o`3ooo]Zool60?oo
nf[o603o00?ooo]Z00?oo`3loookJ_oonfX00ooonfX00ooUo`3ooo]ZoookJP04oookJP03ool0j_oo
nf[ooo]Z013ooo]Z00?o07?ooookJ_oonfX02ooonfX00onio`3ooe80oookJP02oookJP07o`0Zoooo
nf[ooo]Zocoo0?oonf[o0=coogSo0009oookJP04o`3o6ooonf[ooo]Zooo:00Cooo]Z00Coo`2Coook
J_oonf[oo`0C1OoonfX00ooJo`3ooo]ZoookJP02oookJP03obH0oolPo`3ooo]Z013ooo]Z00Co<Ol0
oookJ_oonf[o0?mK0ooonfX01ol0ok3oP_l0onGo0?l0<?ooiOl0o`3Xool0odd00_oonfX01?l60?oo
oo]ZoookJ_nBo`03oookJP03oa00ool06Ooooo]Z00?ooo]Z00Oo5@3ooookJ_oonf[oo`1Ao`2]oooo
nf[oo`1i00[ooo]Z00Oo0?mCoookJ_oonf[ooo]Zo`3o7Ooonf[oU?l000kooo]Z00Co0?ldoookJ_oo
nf[o0?m>1_oonfX00ol0R?oooo]ZoookJP1>oookJP03ool0o?oonf[ooo]Z00Kooo]Z00?o603ooook
J_oo1P001?oonfX00oo[o`3ooo]Zool0mP04oookJP04o`2Voooonf[ooo]ZojP0o`Cooo]Z00Coo`3i
oookJ_oonf[o07Oo0_oonfX01?l0oi[ooo]Zoom/0?l0ol`2oookJP03oon10?oonf[o>ol000Kooo]Z
00?o0?_ooookJ_oonfX00ooonfX00ooo0`3ooo]ZoookJP03oookJP09ogT0oooonf[oo`3MoookJ_l0
5oooW`3oo`2Soooonf[o/ol000cooo]Z0_oo08L6oookJP;oo`1/1OoonfX3odd0o`03ool^0?oonf[o
oo]Z00?ooo]Z0omQ0?l3oookJPCo0?m58_oonfX4of40o`04o`3oAOoonf[ooo]ZoookJPCoobh000?o
oo]Zodd0oom=0?l01?oonfX2ool0K0?ooo]Z0_l0omh00ooo08Oooo]ZoookJP03oookJP03o`00Oonc
o`3o/ol000;o0:?o00Go01Ooool0gOoo0=goN@3oo`00O`02ool300;o001o0ooonfX01?l0nooooo]Z
oookJ_lko`02oon10004o`000?l0olcoof`0oookJP;o07Oo0_oo0?T2oookJP03ojP0ool0Y_oo0:Ko
00;ooo]Z00Koo`3fon_o0?oonf[oo`H0oookJ_lH0?l4oookJP03ool0o?oonf[ooo]Z00;ooo]Z00?o
oaH0oonB0?oonfX01OoonfX00ooo0>[ooo]ZoookJP0@oookJP03o`1coooonf[ooo]Z00_ooo]Z00Go
^Ol0oomB0?oonf[ooo]Zo`0Zo`02oookJP05ocoo0?oonf[o0=cooookJ_mho`002?oonfX01?l0oa_o
4P3ooookJ_oobP04oookJP05o`3ioooo09?ooo]ZoookJ_oo01<01?oonfX00ooJo`3ohOl0oookJP02
oookJP03obH0oolPo`3ooo]Z017ooo]Z00Co<Ol0oookJ_oonf[o0?mK0ooonfX01_n2o`3ooo]Zoook
J_l0<?oooo]Zo`3oC@;ooo]Z00Go1P3ooookJ_oonf[oT_l0ool0m@02oookJP03oa00ool06Ooooo]Z
00?ooo]Z00Go5@3ooookJ_oonf[oo`1Ao`2]o`02oookJP03ool0NOoonf[ooo]Z00Oooo]Z00So0?mC
oookJ_oonf[ooo]Zo`3o7Ol0o`Sooo]Zo`3Qo`kooo]Z00Co0?ldoookJ_l0obko0?m>1_oonfX00ol0
R?oooo]ZoookJP0ToookJP00;OoonfX00ooo0?cooo]ZoookJP07oookJP03oaP0oonDo`3ooo]Z00Co
oo]Z00?ojol0o`3o[OoonfX01?oonfX01?l0Y_oooo]ZoookJ_nX0?l4oookJP0>ool0nOoonf[ooo]Z
o`1gool0oi[ooo]Zoom/0?oonf[oiOl0o`3oc?oonf[ooh40oookJ_oUo`07oookJP03o`3koooonf[o
oo]Z00?ooo]Z00?oo`<0oookJ_oonfX00ooonfX01OoUo`3ooo]Zool0gOoonf[o01Oo00;o0:?o00?o
iOl0ok?o0?oUo`000ooUo`08oookJP03o`3og_oo08Oooo]Z00Kooo]Z0ooo06`5oookJP;oC@3o00?o
obh0oookJ_oonfX00ooonfX3of40o`?ooo]Z3Om4o`07oookJPOoolT01Ol0odD4of40o`03o`3oAOoo
;P3oobh000Coobh00_oonfX4odd0o`Cooo]Z0_oo06`2oookJP04o`3og_oo08Ooo`27ool0Q`Oooo]Z
00?o/ol0o`2Sool0Xol00_oo0=d2oookJP03ogT0oooo0`3o001o00?o001o0ooonfX01Ol0nooooo]Z
oc_o0?lko`3ooh4000;o00000_nDo`000ooonf[o07Ooool0n@04oookJP0;ojP0oooonf[ooo]Zoook
J_oo0?Kooo]Zon_o0?oonf[oo`H0oookJ_lH0?l00ooonfX00ooo0?cooo]ZoookJP02oookJP03oonB
0?oUo`3ooo]Z00Gooo]Z00?oo`3ZoookJ_oonfX04?oonfX00ol0Looooo]ZoookJP0;oookJP03okWo
0?ooDP3ooo]Z00;ooo]Z00Oo02[ooookJ_oonf[o?ol0oookJ_l0g?ooN?l000Wooo]Z00Co08koo`3o
6ooonf[oolX01?oonfX01?oo09?o0?WooookJ_oo01<6oookJP06om[o0?oonf[ooo]ZoookJ_lV0?oo
8?l04_oonfX01?lao`3ooo]ZoookJ_l0oe/3oookJP06oh;o0?oonf[oiOl0o`0`oooonf[o0?m=0ooo
nfX01?l60?oooo]Zool0mOnBo`02oookJP03oa00ool06Ooooo]Z00Cooo]Z00Ko5@3ooookJ_oo057o
oo]Zo`2]oooo07T:oookJP03o`3oDooonf[ooo]Z00;ooo]Z00?o0?lMoiCo0?oonfX03_oonfX00ol0
ocCooo]Zo`3oCP07oookJP03o`28oooonf[ooo]Z04oooo]Z00?oo`3loookJ_oonfX01_oonfX00olH
0?oooo]Zool60004oookJP03on_o0?oonf[oo`3f00Cooo]Z00Co0:KooookJ_oonf[oZ03o1?oonfX0
2_oo0?Wooo]ZoookJ_l0Mooooo]Zo`3oV_oonf[oof`0oookJ_l0ol`2oookJP03oon10?oonf[o>ol0
00Kooo]Z00?o0?_ooookJ_oonfX00ooonfX00ooo0`3ooo]ZoookJP03oookJP06ogT0oooonf[oo`3M
oookJ_l05ooooo]Z0_l0Xol00onco`3ooo]ZoookJP0;oookJP03ool0QooMo`3ooo]Z00Gooo]Z0ooo
06`5oookJP;oC@3o00?oobh0oookJ_oonfX01?oonfX3of40o`Cooo]Z1?l0odD@oookJP[o0?m51?mQ
0?l2o`3oA@Koobh000?ooo]Zodd0oom=0?l00_m=0?l4oookJP;oo`1/0_oonfX2o`3ogP?oo`271_oo
nfX01?nco`3oW`3oo`2Sool05ol2ool0g@04oookJ_mi0?oo001oool300?o001o0ooonfX01Ol0nooo
oo]ZoookJ_lko`3ooh4000;o00000_ooK0001?oonf[o07OooookJ_oo0?T3oookJP03ojP0ool0Y_oo
oo]Z00;ooo]Z00Koo`3fon_o0?oonf[oo`H0oookJ_lH0?l4oookJP03ool0o?oonf[ooo]Z00;ooo]Z
0_ooTP06oookJP03ool0j_oonf[ooo]Z013ooo]Z00?o07?ooookJ_oonfX02ooonfX01Onio`3ooe80
oookJ_oonf[o02[o00?ooo]Z00Co?ol0o`3Loooonf[oN?l02?oonfX01Ol0S_oo0?lKoookJ_oonf[o
olX000Cooo]Z00Coo`2CoookJ_oonf[oo`0C1OoonfX00ooJo`3ooo]ZoookJP02oookJP03obH0oolP
o`3ooo]Z013ooo]Z00Co<Ol0oookJ_oonf[o0?mK0ooonfX01_n2o`3ooo]ZoookJ_oonf[o033oo`3o
C@?ooo]Z00Co1P3ooookJ_oonf[oT_l00ooonfX00ol@0?oooo]ZoookJP03oookJP07oaD0oooonf[o
o`1AoookJ_l0[Ooooo]Zool0N@0:oookJP07o`3oDooonf[ooo]ZoookJ_l0oago0?l8o`3Qo`0>oook
JP04o`3o=?oonf[ooo]Zo`3oCPOooo]Z00?o08SooookJ_oonfX09?oonfX002gooo]Z00?oo`3loook
J_oonfX02?oonfX2oiCo00Cooo]Z00?ojol0o`3o[OoonfX01OoonfX00ol0Y_oooo]ZojP0o`05oook
JP09ool0nOoonf[ooo]Zo`1gool0oi[ooo]Zoom/0?oonf[o0?o<00;ooo]Z00?ooh40oookJ_oUo`00
1ooonfX00ol0nooooo]ZoookJP03oookJP03ool30?oonf[ooo]Z00?ooo]Z00WoiOl0oookJ_oo0=go
oo]Zo`0Goooonf[o0:?oonGo0?nco`002?oUo`04oookJP03o`3og_oo08Oooo]Z00Sooo]Z0_oo06`5
oookJP;oC@3o1Ooo;P02oookJQ3oA?l02?l0odD4oookJP;oolT000?ooo]Zof40oomQ0?l00_mQ0?l5
ool^00;ooo]Z1_m=0?l5oookJP?oo`1/00?ooo]Zo`3og_oo08L00_oo08L8oookJP;o/ol000?o0:?o
ool0gOoo0=d00_oonfX2ogT0o`03ool30?oonf[ooo]Z00Cooo]Z0_oUo`002?oonf[o>ol0oookJ_oo
P@3ooo]Zo`3oV_nDo`3o00000_l0Mol00ooo0?Wooo]ZoookJP02oookJP03ojP0oooonf[ooo]Z00;o
o`3f0_o[o`001?oonf[oo`H0oaP0oolH0?l2oookJP;oo`3l1?oonfX00oooTP3ooaH0oookJP05oook
JP03ool0j_oonf[ooo]Z017ooo]Z00?o07?ooookJ_oonfX02_oonfX00onio`3ooe80o`3o<`02oook
JP04o`0Zoooonf[ooo]Zocoo00;ooo]Z00?o0=coogSo0?oonfX02?oonfX00ol0oa_ooo]Zooo:0005
oookJP03ool0Tooonf[oo`0C00Kooo]Z00?of_l0oookJ_oonfX00_oonfX00olV0?oo8?l0oookJP0@
oookJP04oc7o0?oonf[ooo]Zo`3oF`?ooo]Z00Ko0?n`oh;o0?oonf[o033ooookJ_l0odd3oookJP05
o`H0oooonf[oo`3eoookJ_nBo`000_oonfX00ol@0?oo01WooookJP03oookJP07oaD0oooonf[ooo]Z
ool0DOl0[Ooooo]Zool0N@0:oookJP07o`3oDooonf[ooo]ZoookJ_l0oagooo]ZoiCo000>oookJP04
o`3o=?oonf[ooo]Zo`3oCPKooo]Z00?o08SooookJ_oonfX0D?oonfX00ooo0?cooo]ZoookJP07oook
JP03oaP0oooo1P3ooo]Z00?ooo]Z00?ojol0oookJ_oo0?H01OoonfX00ol0Y_oooo]ZojP0o`05oook
JP09ool0nOoonf[ooo]Zo`1goooonf[o0?nJoookJ_ooK03o0?o<00?ooo]Z00?ooh40oookJ_lko`00
1_oonfX00ol0nooooo]ZoookJP03oookJP03ool30?oonf[ooo]Z00?ooo]Z00GoN@3ooookJ_oo0=go
o`3Mo`0Go`02oookJP03o`2Soonco`3o/ol000cooo]Z00?oo`27o`3og_oonfX01ooonfX3ool0K0Co
oo]Z0_m=0?l5ool^00?ooo]Z3omQ0?l9o`3oA@Kooo]Z1?mQ0?l6ool^0003oookJ_m=0?ooC@3o00Co
C@3o1OoonfX3ool0K0;ooo]Z00Co0?oNool0Qooo08Ooo`271ooonfX2ok?o00;o0:?o0_oo0=d00ooo
nf[oN@3oogT0o`02ool300Gooo]Z0_l0nol2oookJP0:oc_o0?ooP@3ooo]Zo`000?ooK03o0?nJo`00
0?l0Mooooo]Zool0n@?ooo]Z00GoZ03oo`2Voooonf[ooo]Zool0mP02on_o0004oookJ_oo1P3o603o
oaP0o`?ooo]Z0_oo0?`4oookJP03oonB0?oonf[ooo]Z00Gooo]Z00?oo`3ZoookJ_oonfX04OoonfX0
0ol0Looooo]ZoookJP0:oookJP03okWo0?ooDP3o0?lc00;ooo]Z00So02[ooookJ_oonf[o?ol0oook
J_l0g?ooN?l0o`3og`Sooo]Z00Co0?lKoa80oooonf[oolX01?oonfX01?l0nOooo`2CoookJ_oo01<5
oookJP03om[o0?oonf[ooo]Z00;ooo]Z00?o9P3oob3o0?oonfX04OoonfX01?lao`3ooo]ZoookJ_l0
oe/2oookJP07o`3o/?n2o`3ooo]ZoookJ_l0<?oooo]Zo`3oC@02oookJP05o`H0oooonf[ooo]Zool0
mOnBo`000_oonfX00ol@0?oo01WooookJP03oookJP05oaD0oooonf[ooo]Zool0DOl0[Ol00_oonfX0
0ooo07Wooo]ZoookJP07oookJP08o`3oDooonf[ooo]ZoookJ_l0oago0?l8oookJ_l0hOl>oookJP04
o`3o=?oonf[o0?l^o`3oCPKooo]Z00?o08SooookJ_oonfX09OoonfX002kooo]Z00?oo`3loookJ_oo
nfX01ooonfX00olH0?ooU?l0oookJP04oookJP03on_o0?l0ojgooo]Z00Cooo]Z00Co0:KooookJ_oo
nf[oZ03o1OoonfX01?oo0?Wooo]ZoookJ_l0Mol2o`3oVP03oom/0?oonf[o0?o<00;ooo]Z00?ooh40
oookJ_oUo`001ooonfX00ol0nooooo]ZoookJP03oookJP03ool30?oonf[ooo]Z00?ooo]Z00CoiOl0
oookJ_oo0=goo`3M0_l05ol01?l0XoooiOl0ok?o0?nco`08onGo00Cooo]Z0ooo08L8oookJP;oo`1/
1OoonfX6odd0o`Coobh06om4o`001?mQ0?ooobh0ool^0?oo;P02oookJPKoC@3o1_oonfX5ool0K003
oookJ_oMo`3oo`2700;oo`272OoonfX2ok?o0004o`2Soooonf[oo`3MoookJP?oN@3o00?oo`<0oook
J_oonfX01?oonfX2onGo00;ooo]Z00Co>ol0oon10?ooP@3ooo]Z0_nDo`001?l0003o07Ooool0nOoo
0?T4oookJP06ojP0oooonf[ooo]Zool0m_oonf[ojol00_oonfX00ooo1P3o603ooookJP02oookJP03
ool0o?oonf[ooo]Z00?ooo]Z00?ooi80oolF0?oonfX01OoonfX00ooo0>[ooo]ZoookJP0AoookJP03
o`1coooonf[ooo]Z00_ooo]Z00?o^Ol0oomB0?oonfX00_oonfX00ol0:_oooo]Zocoo0002oookJP03
o`3Loomho`3ooo]Z00Sooo]Z00?o0?lKoookJ_oobP001OoonfX00ooo09?o0?Woool04`06oookJP03
on7o0?oJo`3ooo]Z00;ooo]Z00?o9P3oob3o0?oonfX04OoonfX01?lao`3ooo]ZoookJ_l0oe/3oook
JP06oh;o0?oonf[ooo]Zo`0`oooonf[o0?m=0_oonfX01Ol60?oooo]ZoookJ_oo0?GoT_l000?ooo]Z
00?o403ooookJ_oonfX00ooonfX01_lE0?oooo]Zool0DOoonf[o0:goool0N@_ooo]Z00Ko0?mCoook
J_oonf[ooo]Zo`3o7OnDo`0?oookJP03o`3o=?oonf[o0?m>00Oooo]Z00Co08SooookJ_oonf[o0:Wo
D?oonfX00ooo0?cooo]ZoookJP06oookJP03oaP0oooonf[oo`H000Cooo]Z00?ojol0oookJ_oo0?H0
1OoonfX00ol0Y_oooo]ZojP0o`05oookJP05ool0nOoonf[ooo]Zo`1goooonfX00_l0oiX00oooK03o
0?o<oookJP02oookJP03oon10?oonf[o>ol000Kooo]Z0_l0nol4oookJP03ool30?oonf[ooo]Z00?o
oo]Z00CoN@3ooookJ_oonf[oo`3M0_l05ol01?oonf[o0:?ooil0oonco`0<oookJP?oo`272OoonfX2
ool0K0Cooo]Z1_m=0?l9ool^00Sooo]Z3omQ0?l4ool^0003oookJ_m=0?ooC@3o00CoC@3o1_oonfX5
ool0K0;ooo]Z00Co0?oNool0Qooo08Ooo`272?oonfX2ok?o00;o0:?o0_oo0=d3ogT0o`03oookJ_oo
0`3ooo]Z00Cooo]Z0_l0nol2oookJP;o>ol000Gooh40oookJ_ooK03oof`0o`000002o`1go`;oo`3i
0ooonfX01_nX0?oo0:KooookJ_oonf[oo`3fon_o00;ooo]Z00?oo`H0oaP0oooonfX00ooonfX00ooo
0?cooo]ZoookJP03oookJP03oonB0?oonf[ooo]Z00Gooo]Z00?oo`3ZoookJ_oonfX04OoonfX00ol0
Looooo]ZoookJP0;oookJP05okWo0?ooDP3ooo]ZoookJ_l0:_l00_oonfX01Oloo`3ooo]Zo`3Loooo
nf[oN?l000Sooo]Z00Co0?lKoa80oooonf[oolX01OoonfX00ooo09?ooo]Zool04`06oookJP07om[o
0?oonf[ooo]ZoookJ_lV0?oo8?l0oh@0o`0AoookJP04oc7o0?oonf[ooo]Zo`3oF`?ooo]Z00KoP_l0
oookJ_oonf[ooo]Zo`0`ool0odd2oookJP05o`H0oooonf[ooo]ZoookJ_nBo`000ooonfX00ol@0?oo
oo]ZoookJP03oookJP07oaD0oooonf[oo`1AoookJ_l0[Ooooo]Zool0N@0:oookJP07o`3oDooonf[o
oo]ZoookJ_l0oagooo]Zo`3Qo`0>oookJP04o`3o=?oonf[ooo]Zo`3oCPOooo]Z00Co08SooookJ_oo
nf[o0:Wo9?oonfX002[ooo]Z00?ooi80oookJ_oonfX00_oonfX00ooo0?cooo]ZoookJP07oookJP03
oaP0oooo1P3ooo]Z00?ooo]Z00?ojol0o`3o[OoonfX01OoonfX01?l0Y_oooo]ZoookJ_nX0?l5oook
JP09ool0nOoonf[ooo]Zo`1goooonf[o0?nJoom/0?oonf[o0?o<00;ooo]Z0_ooP@000ooUo`3ooo]Z
oookJP05oookJP03o`3koooonf[ooo]Z00?ooo]Z0_oo0`04oookJP07onGo0?mi0?oooo]Zool0gOoo
nf[o01Ooo`2So`02onGo0003ok?o0?oUo`3oiOl000GoiOl01_oonfX01?l0omkoo`27ool0Qooo08L7
oookJP?oo`1/2?oonfX7odd0o`[oA?l01ooonfX6ool^00;ooo]Z1Om=0?l7oookJPGoo`1/1?oonfX3
ool0Q`[ooo]Z00CoW`3ook?o0?l0Xooooo]Z0_oo0=d2ogT0o`03oookJ_oo0`3oo`<000Gooo]Z0_oU
o`02oookJP;o>ol000Wooh40oookJ_nDo`3oU?l0oookJ_l0003o07Ooool0nOl000000ooonfX2ojP0
o`;ooo]Z00?oo`3foookJ_o[o`000_oonfX00ooo1P3o603ooookJP02oookJP03ool0o?oonf[ooo]Z
00?ooo]Z00?ooi80oolF0?oonfX01OoonfX00ooo0>[ooo]ZoookJP0AoookJP03o`1coooonf[ooo]Z
00_ooo]Z00?o^Ol0oomB0?oonfX00_oonfX01ol0:_oooo]ZoookJ_loo`3ooo]Zo`3Loomho`002Ooo
nfX01?l0oa_oA?l0oookJ_oobP04oookJP04ool0Tol0nOoooo]Zool04`Kooo]Z00?of_l0oookJ_oo
nfX00_oonfX00olV0?oooo]ZoookJP0@oookJP04oc7o0?oonf[ooo]Zo`3oF`?ooo]Z00KoP_l0oook
J_oonf[o033ooookJ_l0odd3oookJP05o`H0oooonf[oo`3eoookJ_nBo`000_oonfX00ol@0?oo01Wo
oookJP03oookJP03oaD0oooonf[oo`1A00;ooo]Z00?o0:goool0NOoonfX02OoonfX01ol0oe?ooo]Z
oookJ_oonf[o0?l8o`3o7OnDo`003_oonfX01?l0ocCooo]ZoookJ_l0odh7oookJP04o`28oooonf[o
oo]Zo`2Yod_ooo]Z00?ooi80oookJ_oonfX00ooonfX00ooo0?cooo]ZoookJP06oookJP03oaP0oooo
1P3ooo]Z00?ooo]Z00?ojol0oookJ_oo0?H01OoonfX01?l0Y_oooo]ZoookJ_nX0?l5oookJP04ool0
nOoonf[ooo]Zo`1go`;ooo]Z00?o0?nJoom/0?l0ol`00ooonfX00oooP@3ooo]Zoc_o0007oookJP03
o`3koooonf[ooo]Z00;ooo]Z0_oo0`04oookJP;oN@3o00?ooo]Zool0gOoonfX00_l05ol01?l0Xooo
oo]Zok?o0?nO0?l=oookJP?oo`272?oonfX3ool0K0Oooo]Z2_m=0?l8ool^00Oooo]Z1_oo;P000ooo
nf[oC@3oodd0o`03odd0o`Oooo]Z1Ooo06`4oookJPCoo`272OoonfX01?nO0?oo/ol0o`2Sool0Xol2
ool0g@;oN@3o0_oonfX2ool300Cooo]Z0_l0nol3oookJP0:oc_o0?ooP@3ooo]Zo`3oc?ooK03o0?nJ
o`000?l0Mooo0000ool0n@?ooo]Z0_nX0?l01Ol0Y_oooo]ZoookJ_oo0?Kojol000;ooo]Z00?oo`H0
oaP0oooonfX00ooonfX00ooo0?cooo]ZoookJP03oookJP03oonB0?oonf[ooo]Z00Gooo]Z00?oo`3Z
oookJ_oonfX04OoonfX00ol0Looooo]ZoookJP0;oookJP05okWo0?ooDP3ooo]ZoookJ_l0:_l00_oo
nfX01Oloo`3ooo]Zo`3Loooonf[oN?l000Sooo]Z00Go08koo`3o6ooonf[ooo]Zooo:0004oookJP04
ool0Tooonf[ooo]Zool04`Gooo]Z00?of_l0oookJ_oonfX00_oonfX00olV0?oo8?l0oookJP0Aoook
JP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00Oo0?n`oh;o0?oonf[ooo]Zo`0`ool0odgo0>So00;ooo]Z
00Go1P3ooookJ_oonf[oo`3eoi;o0002oookJP03oa00ool06Ooooo]Z00?ooo]Z00?o5@3ooookJ_oo
05400_oonfX00ol0[Ooooo]Zool0N@09oookJP03o`3oDooonf[ooo]Z00;ooo]Z00?o0?lMoookJ_l0
hOl03_oonfX01?l0ocCooo]Zo`3o;_l0odh7oookJP04o`28oooonf[ooo]Zo`2YobCooo]Z000Zoook
JP03oonB0?oonf[ooo]Z00?ooo]Z00?oo`3loookJ_oonfX01ooonfX00olH0?ooo`H0oookJP03oook
JP03on_o0?l0ojgoo`3f00Gooo]Z00Co0:KooookJ_oonf[oZ03o1OoonfX02?oo0?Wooo]ZoookJ_l0
Mooooo]Zo`3oV_ooK03ooo]Z0_l0ol`2oookJP03oon10?oUo`3ooo]Z00Kooo]Z0_l0nol5oookJP;o
o`<01?oonfX2ogT0o`03ool0gOoonf[ooo]Z00;o0:?o00?oiOl0ok?o0?nco`001?oUo`08oookJP?o
0?oN1?oo08L6oookJP;oo`1/4?oonfX7odCo00;oC@3o1Ooo;P02oookJPKoC@3o1ooonfX5ool0K0Go
oo]Z1?oo08L:oookJP;oW`3o0_nco`000ooonf[oo`3Mool0g@02ogT0o`;ooo]Z00?oo`<0oookJ_oo
nfX00ooonfX2onGo00?ooo]Z00Oo>ol0oon10?ooP@3ooo]ZoiCo0?l0oi[ooo]Z00;o07Oo00?oo`3i
o`000?l000000_oonfX00onX0?oo0:KooookJP02ool0mP;ojol00_oonfX00ooo1P3o603ooookJP02
oookJP03ool0o?oonf[ooo]Z00?ooo]Z00?ooi80oolF0?oonfX01OoonfX00ooo0>[ooo]ZoookJP0B
oookJP03o`1coooonf[ooo]Z00[ooo]Z00?o^Ol0oomB0?l0oc<00_oonfX02?l0:_oooo]ZoookJ_lo
o`3ooo]Zo`3Loomho`3o0?oO2OoonfX00ol0oa_ooo]Zooo:0005oookJP03ool0Tol0nOooo`0C00Ko
oo]Z00?ohOl0om[o0?oonfX00_oonfX00olV0?oo8?l0oookJP0AoookJP04oc7o0?oonf[ooo]Zo`3o
F`;ooo]Z00Oo0?n`oh;o0?oonf[o0?nao`0`oooonf[o0?m=00;ooo]Z00Go1P3ooookJ_oonf[oo`3e
oi;o0003oookJP03oa00oooonf[ooo]Z00?ooo]Z00Ko5@3ooookJ_oo057ooo]Zo`2]oooo07T;oook
JP07o`3oDooonf[ooo]ZoookJ_l0oagooo]ZoiCo000>oookJP03o`3o=?oonf[o0?m>00Oooo]Z00Co
08SooookJ_oonf[o0:WoC?oonfX00oooTP3ooo]ZoookJP04oookJP03ool0o?oonf[ooo]Z00Kooo]Z
00?o603oool60?oonfX00ooonfX01?o[o`3ooo]Zool0m_oo0?H4oookJP04o`2Voooonf[ooo]ZojP0
o`Gooo]Z00Coo`3ioookJ_oonf[o07Oo0_oonfX01?l0oi[oof`0o`3oc?l0ol`2oookJP03oon10?oo
nf[o>ol000Oooo]Z00?o0?_ooookJ_oonfX00ooonfX2ool300Cooo]Z0_mi0?l01?oo0=gooo]Zoook
J_l05ol2o`2So`;o/ol000?oW`3ooookJ_oonfX02_oonfX2o`3ogPCoo`271ooonfX2ool0K0oooo]Z
2Om=0?l6ool^0003oookJ_m=0?ooC@3o00CoC@3o1ooonfX5ool0K0Kooo]Z0ooo08L:oookJP;oW`3o
0_nco`000ol0Xoooo`3Mool0g@02ogT0o`?ooo]Z00?oo`<0oookJ_oonfX00ooonfX00ol0nooooo]Z
oookJP02oookJP03oc_o0?ooP@3ooo]Z00;oof`000?o0?nJoookJ_l0Mol00_oo0?T02?l0003ooo]Z
oookJ_nX0?oooo]Zo`2Voooonf[oo`3f0_o[o`02oookJP03ool60?lH0?oooo]Z00?ooo]Z00?oo`3l
oookJ_oonfX00ooonfX00oooTP3ooo]ZoookJP05oookJP03ool0j_oonf[ooo]Z01;ooo]Z00?o07?o
oookJ_oonfX02_oonfX00onio`3ooe80o`3o<`02oookJP08o`0Zoooonf[o?ol0oookJ_l0g?oooo]Z
ogSo0?l0oml8oookJP04o`3o6olB0?oooo]Zooo:00Gooo]Z00?oo`2CoookJ_oo01<01OoonfX00ooQ
o`3of_l0oookJP02oookJP03obH0oolPo`3oQ03o017ooo]Z00Co<Ol0oookJ_oonf[o0?mK0ooonfX0
1_n2o`3ooo]ZoookJ_l0ok7o033oo`3oC@;ooo]Z00Go1P3ooookJ_oonf[ooo]Zoi;o0003oookJP03
oa00oooonf[ooo]Z00?ooo]Z00Oo5@3ooookJ_oo057ooo]Zo`2]oooonf[oo`1i00[ooo]Z00Go0?mC
oookJ_oonf[ooo]Zo`3o7@02oookJP03o`3Qoooonf[ooo]Z00_ooo]Z00Co0?ldoookJ_oonf[o0?m>
1ooonfX01?l0R?oooo]ZoookJ_l0ZOlUoookJP00:ooonfX00oooTP3ooo]ZoookJP03oookJP03ool0
o?oonf[ooo]Z00Kooo]Z00?o603ooookJ_oo1P001?oonfX00oo[o`3ooo]Zool0mP04oookJP05o`2V
oooonf[ooo]ZoookJ_nX0?l01OoonfX01ooo0?Wooo]ZoookJ_l0Mooooo]Zoom/0?l0oiX00_oonfX0
1Ol0olcooo]ZoookJ_ooP@3oiOl000Sooo]Z00?o0?_ooookJ_oonfX01?oonfX2ool300Cooo]Z00?o
N@3oool0gOoo0=d00_oonfX01?l0XoooiOl0onGo0?nco`03onGo00[ooo]Z00?ogOl0o`3og_l0omh0
0_l0omh3ool0Q`Gooo]Z0ooo06`@oookJPCoA?l00_oonfX7odd0o`Sooo]Z1Ooo06`7oookJP?oo`27
00?o0?oNoookJ_oonfX02OoonfX01OnO0?oo/ol0ok?o0?nco`3o0:?o00;oo`3M0_mi0?l2oookJP;o
o`<01OoonfX01?oUo`3ooo]ZoookJ_oonfX2oc_o0008oon10?oonf[oU?l0oiCo0?l0oi[ooo]Zo`1g
oooo0?T4o`0000;oZ03o00Go0:KooookJ_oo0?Kooo]Zon_o0002oookJP;oo`H000Go603ooookJ_oo
nf[ooo]Zool0o005oookJP03oonB0?oo5P3ooo]Z00Gooo]Z00?oo`3ZoookJ_oonfX04_oonfX00ol0
Looooo]ZoookJP0;oookJP03okWo0?ooDP3ooo]Z00;ooo]Z00?o02[ooookJ_loo`000_oonfX00ol0
g?ooN?l0oookJP08oookJP03o`3o6om4o`3oolX000Gooo]Z00?oo`2Co`3ioooo01<01_oonfX00ooQ
o`3of_l0oookJP02oookJP03obH0oolPo`3ooo]Z017ooo]Z00Co<Ol0oookJ_oonf[o0?mK0ooonfX0
1_n2o`3ooo]ZoookJ_l0<?oooo]Zo`3oC@?ooo]Z00Co1P3ooookJ_oo0?GoT_l00ooonfX00ol@0?oo
01WooookJP03oookJP03oaD0oooonf[oo`1A00;ooo]Z00?o0:goool0NOoonfX02_oonfX01_l0oe?o
oo]ZoookJ_l0o`So0?lMoiCo00kooo]Z00Co0?ldoookJ_oonf[o0?m>1ooonfX01?l0R?oooo]Zoook
J_l0ZOm=oookJP03oonB0?oonf[ooo]Z00Cooo]Z00?oo`3loookJ_oonfX01OoonfX00olH0?oooo]Z
ool60004oookJP04on_o0?oonf[ooo]Zool0mPCooo]Z00Co0:KooookJ_oonf[oZ03o1OoonfX01?oo
0?Wooo]ZoookJ_l0Mol2oookJP04oom/0?l0oi[ooo]Zo`3oc0;ooo]Z00?ooh40oookJ_lko`001ooo
nfX00ol0nooooo]ZoookJP04oookJP;oo`<01?oonfX00omi0?ooo`3Mool0g@03oookJP03o`2Sool0
5ooo/ol000;oW`3o3?oonfX01?oMo`3o0?oNo`3og_l0omh4ool0Q`Gooo]Z0ooo06`EoookJPOoC@3o
2?oonfX5ool0K0Sooo]Z0ooo08L00ol0omkooo]ZoookJP08oookJP05oil0oonco`3o/ol0ok?o0?l0
Xol00_oo0=d2ogT0o`?ooo]Z0_oo0`04oookJP;o0?_o0ooonfX2oc_o0005oookJ_ooK03oof`0oook
J_l0oiX00_l0Mol01?oo0?Wo0000o`000?l00002ojP0o`;o0:Ko00?ooo]Zool0m_o[o`000_oonfX2
ool60003oaP0oooonf[ooo]Z00;ooo]Z00?oo`3loookJ_oonfX00_oonfX2oonB00Oooo]Z00?oo`3Z
oookJ_oonfX04_oonfX00ol0Looooo]ZoookJP0;oookJP05okWo0?ooDP3ooo]ZoookJ_l0:_l00_oo
nfX01Oloo`3ooo]Zo`3Loomho`3o0?oO00Sooo]Z00Co0?lKoa80oooonf[oolX01OoonfX00ooo09?o
oo]Zool04`06oookJP07om[o0?oonf[ooo]ZoookJ_lV0?oo8?l0oh@0o`0BoookJP04oc7o0?oonf[o
oo]Zo`3oF`;ooo]Z00Oo0?n`oh;o0?oonf[ooo]Zo`0`ool0odgo0>So00;ooo]Z00Co1P3ooookJ_oo
nf[oT_l00ooonfX00ooo06[o403ooookJP03oookJP03oaD0oooonf[oo`1A00;ooo]Z00?o0:gooook
J_oo07T02_oonfX01ol0oe?ooo]ZoookJ_oonf[o0?lMoookJ_l0hOl03_oonfX01?l0ocCooo]Zoook
J_l0odh7oookJP04o`28oooonf[ooo]Zo`2YobGooo]Z000/oookJP03oonB0?oonf[ooo]Z00?ooo]Z
00?oo`3loookJ_oonfX01_oonfX00olH0?oooo]Zool60003oookJP04on_o0?oonf[ooo]Zool0mPCo
oo]Z00Go0:KooookJ_oonf[ooo]ZojP0o`05oookJP07ool0nOoonf[ooo]Zo`1goooonf[oof`0o`3o
VP02oookJP05o`3oc?oonf[ooo]Zoon10?oUo`002?oonfX00ol0nooooo]ZoookJP05oookJP03ool3
0?oonf[ooo]Z00?ooo]Z00GoN@3oool0gOoonf[ooo]Zo`2So`02onGo0004ok?o0?oUo`3oiOl0onGo
00gooo]Z00CogOl0o`3og_l0omko0?oN1?oo08L4oookJQ3oo`1/0ooonfX01?m4o`3oolT0ooo90?oo
b@04oookJP;oiOl00ooonfX5ool0K0Wooo]Z0ooo08L2o`3ogP_ooo]Z0onco`02o`2So`;oo`3M00Co
N@3ooookJ_oonf[ooo]Z0_oo0`05oookJP;oiOl00ooonfX01Olko`3ooo]Zoon10?oob@3oU?l000;o
0?nJ0_l0Mol01?oo0?Wooo]Zo`000?l00002ojP0o`06o`2Voooonf[ooo]Zool0m_oonf[ojol00_oo
nfX00ooo1P3o603ooaP0o`03oookJP03ool0o?oonf[ooo]Z00;ooo]Z0_ooTP07oookJP03ool0j_oo
nf[ooo]Z01;ooo]Z00?o07?ooookJ_oonfX02ooonfX00onio`3ooe80oookJP02oookJP03o`0Zoooo
nf[o?ol000;ooo]Z00?o0=coogSo0?oonfX01?oonfX2odCo00;ooo]Z00Co0?lKodCo0?oonf[oolX0
1OoonfX00ooo09?ooo]Zool04`06oookJP03on7o0?oJo`3ooo]Z00;ooo]Z00?o9P3ooookJ_oonfX0
4OoonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP07o`3o/?n2o`3ooo]Zo`3o/Ol0<?oo0?m=o`3Xo`02
oookJP05o`H0oooonf[ooo]Zool0mOnBo`000ooonfX00ol@0?oooo]ZoookJP03oookJP06oaD0oooo
nf[oo`1AoookJ_l0[Oooo`1i2ooonfX01ol0oe?ooo]ZoookJ_oonf[o0?lMoookJ_nDo`003_oonfX0
1?l0ocCooo]Zo`3o;_l0odh6oookJP04o`28oooonf[ooo]Zo`2Yodoooo]Z00?ooi80oookJ_oonfX0
1?oonfX00ooo0?cooo]ZoookJP05oookJP03oaP0oooonf[oo`H000?ooo]Z00Gojol0oookJ_oonf[o
oo]Zool0mP03oookJP05o`2Voooonf[ooo]ZoookJ_nX0?l01OoonfX01?oo0?Wooo]ZoookJ_l0Mol2
oookJP04oom/0?l0oi[ooo]Zo`3oc0;ooo]Z00?ooh40oookJ_lko`001ooonfX00ol0nooooo]Zoook
JP05oookJP03ool30?oonf[ooo]Z00?ooo]Z00?oN@3oool0gOoonfX00_oonfX01?l0Xooo01Oook?o
0?nco`02oil0o`gooo]Z0_oMo`03o`3ogP?oo`271OoonfX@ool0K0oooo]Z1Ooo06`9oookJPCoo`27
00?o0?oNoookJ_oonfX02OoonfX3ok?o0005o`0Gool0Xooo0:?oool0gOmi0?l01?oonfX2ool300Co
oo]Z0_l0nol4oookJP05oc_o0?ooP@3o0?o<oom/0?oonfX00_l0oiX00ol0Mooooo]Zool0n@03o`00
0003ojP0oooonf[o0:Ko00;ooo]Z00Goo`3fon_o0?oonf[ooo]Zool60002oaP0o`Cooo]Z00?oo`3l
oookJ_oonfX00_oonfX00oooTP3ooaH0oookJP06oookJP03ool0j_oonf[ooo]Z01;ooo]Z00?o07?o
oookJ_oonfX02ooonfX01Onio`3ooe80oookJ_oonf[o02[o00;ooo]Z00Go?ol0oookJ_l0g?oooo]Z
ogSo0008oookJP04o`3o6ooonf[o4P3oooo:00Gooo]Z00Co0?Woool0Tooonf[oo`0C1OoonfX00ooQ
o`3of_l0oookJP02oookJP03obH0oolPo`3ooo]Z017ooo]Z00Co<Ol0oookJ_oonf[o0?mK0ooonfX0
1_n2o`3ooo]ZoookJ_l0ok7o033oo`3oC@;ooo]Z00Go1P3ooookJ_oonf[oo`3eoi;o0003oookJP03
oa00oooonf[ooo]Z00?ooo]Z00Oo5@3ooookJ_oo057ooo]Zo`2]oooonf[oo`1i00[ooo]Z00Go0?mC
oookJ_oonf[ooo]Zo`3o7@02oookJP03o`3Qoooonf[ooo]Z00_ooo]Z00Go0?ldoookJ_oonf[o0?l^
o`3oCP06oookJP04o`28oooonf[ooo]Zo`2YobKooo]Z000ZoookJP03oolF0?oonf[ooi8000Kooo]Z
00?oo`3loookJ_oonfX01_oonfX00olH0?oooo]Zool60003oookJP;ojol000?ooo]Zool0m_oonfX0
0ooonfX01Ol0Y_oooo]ZoookJ_oonf[oZ03o00Gooo]Z00Ooo`3ioookJ_oonf[o07OooookJ_ooK03o
0?nJ00;ooo]Z0_l0ol`00ooonf[ooh40onGo0008oookJP03o`3koooonf[ooo]Z00Gooo]Z0_oo0`05
oookJP04ool0gOmi0?oooo]Zo`2So`;oiOl00_nco`000ooonf[oiOl0onGo000@oookJP?o0?oN0ooo
08LAoookJQ3oo`1/2ooonfX3ool0Q`;o0?oN2ooonfX3ok?o0007o`0Gool0Xooo0:?oogT0oooo0=go
N@3ooookJP02onGo00;oo`<01OoonfX2onGo00Cooo]Z00?o>ol0oon10?ooP@000_nDo`000ol0oi[o
oo]Zo`1go`02ool0n@;ooo]Z00Go0000ojP0ool0003o0:KooookJP02ool0mP06oookJ_o[o`3ooo]Z
oookJ_oo1P3o603o1?oonfX00ooo0?cooo]ZoookJP02oookJP03oonB0?oo5P3ooo]Z00Kooo]Z00?o
o`3ZoookJ_oonfX04_oonfX00ol0Looooo]ZoookJP0;oookJP03okWo0?ooDP3ooo]Z00;ooo]Z00So
02[ooookJ_oonf[o?ol0oookJ_l0g?ooN?l0ocd0o`Gooo]Z0om4o`001?l0S_oo0?lKoookJ_oobP05
oookJP03ool0Tol0nOooo`0C00Kooo]Z00?ohOl0om[o0?oonfX00_oonfX00olV0?oo8?l0oookJP0A
oookJP04oc7o0?oonf[ooo]Zo`3oF`?ooo]Z00KoP_l0oookJ_oonf[o0?nao`0`ool0odd3oookJP04
o`H0oooonf[oo`3eoi;o00?ooo]Z00?o403oo`0IoooonfX00ooonfX00olE0?oooo]Zool0D@02oook
JP03o`2]oooo07Wooo]Z00[ooo]Z00Ko0?mCoookJ_oonf[o0?l8o`3o7OnDo`0?oookJP03o`3o=?oo
nf[o0?m>00Oooo]Z00Co08SooookJ_oonf[o0:WoCOoonfX00ooo5P3ooo]ZoonB0007oookJP03ool0
o?oonf[ooo]Z00Gooo]Z00?o603ooookJ_oo1P000ooonfX2on_o00;ooo]Z00Goo`3foookJ_oonf[o
oo]Zo`2Vo`03oookJP03ojP0oooonf[ooo]Z00?ooo]Z00Coo`3ioookJ_oonf[o07Oo0_oonfX00ooo
K03o0?nJoookJP02o`3oc004oookJ_ooP@3ooo]Zoc_o00Oooo]Z0_l0nol6oookJP;oo`<01OoonfX0
2Ooo0=goN@3ooookJ_oonf[o0:?ooookJ_l05ooo/ol0oookJP02oil0oa3ooo]Z00?ogOl0o`3og_l0
omh01?oo08LAoookJPooo`1/2ooonfX3ool0Q`?o0?oN2_oonfX3ok?o00;o01Oo0_l0Xol2ool0g@?o
oo]Z0ooo0`04oookJP;o0?_o1OoonfX01?lko`3ooh40oom/0?ooK002o`3oVP06oookJ_l0Moooo`3i
ool0nOoonf[o00000_nX0?l00ol0003o0:KooookJP02ool0mP05on_o0?oonf[ooo]Zool60?lH0?l0
1OoonfX00ooo0?cooo]ZoookJP02oookJP03oonB0?oo5P3ooo]Z00Kooo]Z00?oo`3ZoookJ_oonfX0
4_oonfX00ol0Looooo]ZoookJP0;oookJP03okWo0?ooDP3ooo]Z00;ooo]Z00Oo02[ooookJ_loo`3o
oo]Zo`3Loooonf[oN?l000Sooo]Z00Go08koo`3o6olB0?oooo]Zooo:0005oookJP03ool0Tooonf[o
o`0C00Kooo]Z00Oof_l0oookJ_oonf[ooo]ZobH0oolPo`3oQ03o01;ooo]Z00Co<Ol0oookJ_oonf[o
0?mK0_oonfX01on2o`3ooo]ZoookJ_oonf[o0?nao`3oCOl0j?l00_oonfX01?l60?oooo]ZoookJ_nB
o`03oookJP03ool0J_l@0?oooo]Z00?ooo]Z00?o5@3ooookJ_oo05400_oonfX00ol0[Ooooo]Zool0
N@0:oookJP07o`3oDooonf[ooo]ZoookJ_l0oagooo]Zo`3Qo`0>oookJP04o`3o=?oonf[ooo]Zo`3o
CPOooo]Z00Co08SooookJ_oonf[o0:Wo9_oonfX002[ooo]Z00CooaH0oookJ_oonf[ooi801_oonfX0
0ooo0?cooo]ZoookJP05oookJP04oaP0oooonf[ooo]Zool600Cooo]Z00?ojol0oookJ_oo0?H01?oo
nfX01?l0Y_oooo]ZoookJ_nX0?l6oookJP05ool0nOoonf[ooo]Zo`1goooonfX00_ooK0001ol0oi[o
oo]ZoookJ_l0olcooo]Zoon10?oUo`002?oonfX00ol0nooooo]ZoookJP06oookJP;oo`<01?oonfX0
0ooo0=goN@3oogT0o`03o`2So`04oookJ_nco`3o01OooookJP;oiOl04ooonfX00ol0omkoo`27ool0
Q`02ool0Q`[ooo]Z2_oob@06onGo00[ooo]Z00CoiOl0ool0Qooo08Ooo`270_l0omh;oookJP?o/ol0
00Go01Ooo`2Sool0Xooo0:?oogT0o`02ool0g@;ooo]Z0ooUo`05oookJP;oiOl01?oonfX2oc_o0004
oon10?nDo`3oU?l0o`3oVP;ooo]Z00?o07Ooool0nOoonfX00_oonfX2ojP0o`05o`000?l0Y_oo0000
ool0m_oonfX00_o[o`001?oonf[oo`H0ool60?lH0?l4oookJP03ool0o?oonf[ooo]Z00;ooo]Z00?o
oi80oolF0?oonfX01_oonfX00ooo0>[ooo]ZoookJP0CoookJP03o`1coooonf[ooo]Z00_ooo]Z00?o
oe80o`3o<ooonfX00_oonfX01ol0:_oooo]Zocoo0?oonf[o0=coogSo0?l0oml01OoonfX4odCo0003
o`3o6om4o`3oolX000Gooo]Z00?oo`2Co`3ioooo01<01_oonfX00ooQo`3of_l0oookJP02oookJP03
obH0oolPo`3ooo]Z017ooo]Z00Go<Ol0oookJ_oonf[ooo]Zo`3oF`02oookJP07o`3o/?n2o`3ooo]Z
o`3o/Ol0<?oo0?m=o`3Xo`02oookJP05o`H0oooonf[oo`3eoookJ_nBo`000ooonfX00ol@0?oooo]Z
oookJP03oookJP06oaD0oooonf[oo`1AoookJ_l0[Oooo`1i2ooonfX01ol0oe?ooo]ZoookJ_oonf[o
0?lMoookJ_nDo`003_oonfX01?l0ocCooo]Zo`3o;_l0odh7oookJP03o`28oooonf[o0:Wo04kooo]Z
00CooaH0oookJ_oonf[ooi801_oonfX00ooo0?cooo]ZoookJP05oookJP04oaP0oooonf[ooo]Zool6
00Cooo]Z00Cojol0oookJ_oonf[oo`3f0ooonfX01?l0Y_oooo]ZoookJ_nX0?l6oookJP04ool0nOoo
nf[ooo]Zo`1go`;ooo]Z0_ooK0001ol0oi[ooo]Zo`3oc?oonf[ooh40oookJ_lko`002?oonfX00ol0
nooooo]ZoookJP05oookJP;oo`<01?oonfX01?oo0=goN@3oogT0oooonfX3o`2So`03ok?o0?l05ooo
01Oo00;oW`3o4ooonfX00ooMo`3o0?oNool0Q`03ool0Qb?ooo]Z00CogOl0ool0Qooo08Ooo`270ol0
omh:oookJP?o/ol00_l05ol3o`2So`;oo`3M0ooonfX2ool300Gooo]Z0_l0nol5oookJP;o>ol000Go
0?o<oom/0?l0oi[o0?nJoookJP02o`1go`05ool0nOoonf[ooo]ZoookJ_nX0?l00_l000000ol0Y_oo
oo]Zool0mP02on_o0004oookJ_oo1P3oo`H0oaP0o`Gooo]Z00?oo`3loookJ_oonfX00_oonfX00ooo
TP3ooaH0oookJP06oookJP03ool0j_oonf[ooo]Z01;ooo]Z00?o07?ooookJ_oonfX03?oonfX03?oo
DP3o0?lcoookJ_oonf[o02[ooookJ_loo`3ooo]Zo`3Loooonf[oN?l0o`3og`Sooo]Z00Co0?lKoa80
oooonf[oolX01OoonfX00ooo09?ooo]Zool04`06oookJP03om[o0?oonf[ooo]Z00;ooo]Z00?o9P3o
ob3o0?oonfX04OoonfX01Olao`3ooo]ZoookJ_oonf[o0?mK00;ooo]Z00KoP_l0oookJ_oonf[o0?na
o`0`ool0odd2oookJP05o`H0oooonf[ooo]Zool0mOnBo`000ooonfX00ol@0?oo05gooookJP03oook
JP07oaD0oooonf[oo`1AoookJ_l0[Ooooo]Zool0N@0:oookJP05o`3oDooonf[ooo]ZoookJ_l0oad0
0_oonfX00ol0hOoooo]ZoookJP0<oookJP04o`3o=?oonf[o0?l^o`3oCPOooo]Z00?o08SooookJ_l0
ZOl09ooonfX002_ooo]Z00CooaH0oookJ_oonf[ooi801OoonfX00ooo0?cooo]ZoookJP06oookJP04
oaP0oooonf[ooo]Zool600Cooo]Z00?ojol0oookJ_oo0?H00ooonfX01Ol0Y_oooo]ZoookJ_oonf[o
Z03o00Kooo]Z00Coo`3ioookJ_oonf[o07Oo0_oonfX01?ooK03o0?nJoookJ_oonfX2o`3oc003oon1
0?oUo`3ooo]Z00Oooo]Z00?o0?_ooookJ_oonfX01ooonfX2ool300?ooo]Z0_oo0=d2ogT0o`03oook
J_l0Xooo0:?o00?o/ol000?ooo]ZonGo0?oUo`005OoonfX01?l0omkoo`27ool0Qooo08L2omgo0003
oookJ_oob@3oolT001coolT000?oo`27o`3og_l0omh02ooonfX3ok?o0006oil0ool0Xooo0:?oo`2S
oooonf[oN@3o0_oo0=d2oookJP03ool30?oUo`3oiOl000?oiOl00_oonfX2onGo00;ooo]Z00OoU?l0
oookJ_oonf[o>ol0oookJ_ooP@3oU?l000;o0?nJ00Cooo]Zo`1gool0Moooo`3i0ooonfX02?nX0?oo
oo]Zo`000?l0Y_oo0000ool0m_l0003ojol00_oonfX00ooo1P3ooo]ZoaP0o`04oookJP03ool0o?oo
nf[ooo]Z00;ooo]Z00?ooi80oolF0?oonfX01_oonfX00ooo0>[ooo]ZoookJP0CoookJP03o`1coooo
nf[ooo]Z00_ooo]Z00?o^Ol0oomB0?oonfX00_oonfX01ol0:_oooo]Zocoo0?oonf[o0=coogSo0?l0
oml01_oonfX3odCo0004o`3o6om4o`3oA?l0ooo:00Gooo]Z00?oo`2Co`3ioooo01<01_oonfX00ooJ
o`3ooo]ZoookJP02oookJP03obH0oolPo`3ooo]Z017ooo]Z00Co<Ol0oookJ_oonf[o0?mK0ooonfX0
1_n2o`3ooo]Zo`3o/Ooonf[o033oo`3oC@?ooo]Z00Co1P3ooookJ_oo0?GoT_l00ooonfX00ol06Ooo
403ooookJP03oookJP03oaD0oooonf[oo`1A00;ooo]Z00?o0:goool0NOoonfX02_oonfX01_l0oe?o
oo]ZoookJ_l0o`So0?lMoiCo00oooo]Z00?o0?ldoookJ_l0odh01ooonfX01?l0R?oooo]ZoookJ_l0
ZOm?oookJP04oolF0?oonf[ooo]ZoonB00Kooo]Z00?oo`3loookJ_oonfX01OoonfX01?lH0?oooo]Z
oookJ_oo1P04oookJP04on_o0?oonf[ooo]Zool0mP?ooo]Z00Co0:KooookJ_oonf[oZ03o1_oonfX2
ool0n@03oookJ_l0Mooooo]Z00;ooo]Z00?oof`0o`3oV_oonfX00_l0ol`00oooP@3ooo]Zoc_o0008
oookJP03o`3koooonf[ooo]Z00Kooo]Z0_oo0`03oookJP?oo`3M00CoN@3ooookJ_oonf[o0:?o0onc
o`000ol05oooW`3ooil0o`0FoookJP05o`3og_oo08Ooo`27ool0QooMo`003ooonfXAool0Q`?o0?oN
2_oonfX3ok?o0003oil0ool05ooo0:?o00;o0:?o00?oN@3oool0gOoo0=d00ooonfX2ool300Gooo]Z
0_l0nol6oookJP05oc_o0?ooP@3oof`0oom/0?l0oiX00_oonfX00ol0Mooooo]Zool0n@02oookJP;o
Z03o0_l000001?l0Y_oo0000ool0m_o[o`02oookJP03ool60?oonf[o603o00Gooo]Z00Coo`3loook
J_oonf[ooo]Z0_ooTP08oookJP03ool0j_oonf[ooo]Z01;ooo]Z00?o07?ooookJ_oonfX03?oonfX0
1Onio`3ooe80oookJ_oonf[o02[o00;ooo]Z00Go?ol0o`3Loooonf[oN?l0o`3og`08oookJP04o`3o
6ooonf[o4P3oooo:00Kooo]Z00?oo`2Cool04ooonfX01OoonfX00ooJo`3ooo]ZoookJP02oookJP03
obH0oolPo`3oQ03o01;ooo]Z00Co<Ol0oookJ_oonf[o0?mK0_oonfX01on2o`3ooo]ZoookJ_l0ok7o
oo]Zo`3oCOl0j?l00_oonfX01?l60?oooo]ZoookJ_nBo`03oookJP03o`0Iool@0?oooo]Z00?ooo]Z
00?o5@3ooookJ_oo05400_oonfX00ol0[Ooooo]Zool0N@0:oookJP07o`3oDooonf[ooo]ZoookJ_l0
oagooo]Zo`3Qo`0>oookJP04o`3o=?oonf[ooo]Zo`3oCPOooo]Z00Co08SooookJ_oonf[o0:Wo9ooo
nfX002cooo]Z00CooaH0oookJ_oonf[ooi801OoonfX00ooo0?cooo]ZoookJP05oookJP05oaP0oooo
nf[ooo]ZoookJ_oo1P001?oonfX00oo[o`3ooo]Zool0mP03oookJP05o`2Voooonf[ooo]ZoookJ_nX
0?l01_oonfX01?oo0?Wooo]ZoookJ_l0Mol2oookJP;oof`00ooonfX00ol0olcooh40onGo0008oook
JP;o0?_o2OoonfX2ool300?ooo]Z0ooo0=d2ogT0o`03oookJ_l0Xooo0:?o00Co/ol000?oiOl0oook
J_oonfX05OoonfX00ooo08OoolT0ooo9000?ooo900[o0?oN4?oonfX3ok?o00Co0:?o00?ooo]ZogT0
oooo0=d00_oo0=d2oookJP;oo`<02?oUo`000ooonf[oolT0oookJP02oiCo0006oookJ_lko`3oolT0
ooo90?nDo`3o0?nJ0_oonfX00ol0Moooo`3iool0n@02oookJP;oZ03o0_oonfX01_l0Y_ooo`3fool0
m_l0003ojol0oookJP;oo`H00_lH0?l4oookJP03ool0o?oonf[ooo]Z00;ooo]Z00?ooi80oolF0?oo
nfX01_oonfX00ooo0>[ooo]ZoookJP0CoookJP03o`1coooonf[ooo]Z00_ooo]Z00?o^Ol0oomB0?oo
nfX00_oonfX00ol0:_oooo]Zocoo0002oookJP03o`3Loomho`3o?@3o00Kooo]Z0_m4o`001?l0oa_o
A?l0odCo0?oobP02odCo00?ooo]Z00?oo`2Co`3ioooo01<01_oonfX00ooQo`3of_l0oookJP02oook
JP03obH0oolPo`3ooo]Z017ooo]Z00Go<Ol0oookJ_oonf[ooo]Zo`3oF`02oookJP07oh;o0?oonf[o
oo]Zo`3o/Ol0<?oo0?m=o`3Xo`02oookJP04o`H0oooonf[oo`3eoi;o00?ooo]Z00?oo`1Zoa00ool0
GOl01?oonfX00olE0?ooo`1AoookJP02oookJP03o`2]oooo07Wooo]Z00Wooo]Z00Oo0?mCoookJ_oo
nf[ooo]Zo`3o2?l0oagoU?l000kooo]Z00Co0?ldoookJ_oonf[o0?m>1ooonfX00ol0R?oooo]Zo`2Y
o`1AoookJP04oolF0?oonf[ooo]ZoonB00Kooo]Z00?oo`3loookJ_oonfX01?oonfX01OlH0?oooo]Z
oookJ_oonf[oo`H000Cooo]Z00Cojol0oookJ_oonf[oo`3f0_oonfX01Ol0Y_oooo]ZoookJ_oonf[o
Z03o00Oooo]Z00?oo`3ioookJ_l0Mol00ooonfX2oom/00;ooo]Z00Co0?o<oon10?oonf[o>ol02?oo
nfX00ol0nooooo]ZoookJP07oookJP;oo`<01?oonfX3ool0g@04ogT0oooonf[ooo]Zo`2So`Co/ol0
00?oW`3ooookJ_oonfX05_oonfX@ool0Q`co0?oN3ooonfX3ok?o0003oil0ool0Xooo0:?o00;o0:?o
00CoN@3oool0gOoo0=goo`3M0_oonfX3ool300Kooo]Z00?o0?_ooookJ_oonfX01OoonfX00olko`3o
oh40oom/0002o`3oVP03oookJ_l0Mooo07Oo00;oo`3i0_oonfX01OnX0?oooo]ZoookJ_l0003o0:Ko
00;oo`3f00Cojol0oookJ_oo1P3oo`H00_lH0?l5oookJP06ool0o?oonf[ooo]ZoookJ_ooTP3ooaH0
2?oonfX00ooo0>[ooo]ZoookJP0BoookJP03o`1coooonf[ooo]Z00cooo]Z00Go^Ol0oomB0?oonf[o
oo]Zo`0Zo`02oookJP06ocoo0?oonf[o0=coogSo0?l0omoo?@3o1ooonfX01Ol0S_oo0?lKoa80oooo
nf[oolX000Gooo]Z00?oo`2CoookJ_oo01<01_oonfX01ooJo`3ooo]ZoookJ_oonf[o9P3oob3o0?n4
0?l04_oonfX01Olao`3ooo]ZoookJ_oonf[o0?mK00;ooo]Z00KoP_l0oookJ_oonf[o0?nao`0`ool0
odd2oookJP04o`H0oooonf[ooo]Zoi;o00Cooo]Z00?o403oo`1MoooonfX00ooonfX00olE0?oooo]Z
ool0D@02oookJP03o`2]oooonf[oo`1i00Wooo]Z00So0?mCoookJ_oonf[ooo]Zo`3o2?l0oagooo]Z
o`3Qo`kooo]Z00Co0?ldoookJ_l0obko0?m>1ooonfX00ol0R?oooo]Zo`2Yo`0XoookJP00;OoonfX0
0ooo5P3ooo]ZoonB0006oookJP03ool0o?oonf[ooo]Z00Gooo]Z00Go603ooookJ_oonf[ooo]Zool6
0004oookJP03on_o0?oonf[oo`3f00?ooo]Z00Go0:KooookJ_oonf[ooo]ZojP0o`06oookJP04ool0
nOoonf[ooo]Zo`1go`?ooo]Z0_ooK002oookJP03o`3oc?ooP@3oiOl000Wooo]Z00?o0?_ooookJ_oo
nfX02?oonfX00ooo0`3ooo]ZoookJP03oookJP?oo`3M00?oN@3ooookJ_oonfX00ol0Xol3ok?o01Wo
oo]Z00?o0?oNooo90?oob@002ooob@06onGo017ooo]Z0onco`03o`2So`;o01Oo00Cooo]Zool0gOoo
0=goo`3M0ooonfX2ool30003oookJ_oUo`3oiOl000KoiOl000?ooo]Zooo90?oob@000_nDo`02oc_o
0003ooo90?nDo`3o0?nJ00;ooo]Z0_l0Mol01Ooo0?Wooo]ZoookJ_oonf[oZ03o00?ooo]Z00?o0:Ko
ool0m_l000000_o[o`001?oonf[oo`H0oookJ_lH0?l5oookJP04ool0o?oonf[ooo]ZoookJP;ooi80
00?ooaH0oookJ_oonfX01OoonfX00ooo0>[ooo]ZoookJP0CoookJP03o`1coooonf[ooo]Z00cooo]Z
00?ooe80oookJ_oonfX00_oonfX01ol0:_oooo]Zocoo0?oonf[o0=coogSo0?l0oml01_oonfX3odCo
0003o`3o6om4o`3oolX000;oA?l00ooonfX00ooo09?o0?Woool04`07oookJP07om[o0?oonf[ooo]Z
oookJ_lV0?oo8?l0oh@0o`0BoookJP04oc7o0?oonf[ooo]Zo`3oF`?ooo]Z00KoP_l0oookJ_l0ok7o
oo]Zo`0`ool0odd2oookJP05o`H0oooonf[ooo]Zool0mOnBo`000ooonfX00ol06Ooo403ooookJP04
oookJP06oaD0oooo057ooo]ZoookJ_l0[Oooo`1i2ooonfX01_l0oe?ooo]ZoookJ_l0o`So0?lMoiCo
00oooo]Z00?o0?ldoookJ_l0odh01ooonfX01?l0R?oooo]ZoookJ_l0ZOmBoookJP03oolF0?oonf[o
oi8000Oooo]Z00?oo`3loookJ_oonfX01?oonfX01OlH0?oooo]ZoookJ_oonf[oo`H000Cooo]Z00Co
jol0oookJ_oonf[oo`3f0_oonfX01Ol0Y_oooo]ZoookJ_oonf[oZ03o00Oooo]Z00?oo`3ioookJ_l0
Mol01?oonfX2oom/0005oookJ_l0olcooh40oookJ_lko`002?oonfX2o`3ko`Wooo]Z00?oo`<0oook
J_oonfX01?oonfX3ool0g@?ooo]Z0_l0Xol3ok?o01[ooo]Z2Ol0omhKoookJP?o/ol000KoW`3oo`2S
ool0Xooo0:?oo`0GoooonfX3ool0g@?ooo]Z0_oo0`07oookJP;o0?_o1_oonfX2oc_o00;oof`000Ko
0?nJoookJ_oonf[o07OooookJ_oo0?T2oookJP;oZ03o0ooonfX02?l0Y_ooo`3fon_o0?o[o`3ooo]Z
ool60?oonf[o603o1_oonfX01_oo0?cooo]ZoookJ_oonf[ooi80oolF00Sooo]Z00?oo`3ZoookJ_oo
nfX04_oonfX00ol0Looooo]ZoookJP0=oookJP0<oomB0?oonf[ooo]ZoookJ_l0:_oooo]Zocoo0?oo
nf[o0=cooookJ_mho`3o0?oO2?oonfX01?l0oa_ooo]Zoa80oooobP05oookJP03ool0Tooonf[oo`0C
00Kooo]Z00?of_l0oookJ_oonfX00_oonfX00olV0?oo8?l0oh@0o`0BoookJP04oc7o0?oonf[ooo]Z
o`3oF`;ooo]Z00WoP_l0oookJ_oonf[o0?naoookJ_l0odgo0>SooookJ_l60?l00_oonfX00ooo0?Go
T_l0oookJP02oookJP03o`0Iool@0?oooo]Z00Cooo]Z00Oo5@3oool0DOoonf[ooo]Zo`2]oooonf[o
o`1i00[ooo]Z00Oo0?mCoookJ_oonf[ooo]Zo`3o7Ooonf[o0>7o00kooo]Z00Co0?ldoookJ_oonf[o
0?m>1ooonfX01?l0R?oooo]ZoookJ_l0ZOlXoookJP00;OoonfX01?oo5P3ooo]ZoookJ_ooTP06oook
JP03ool0o?oonf[ooo]Z00Gooo]Z00Go603ooookJ_oonf[ooo]Zool60004oookJP03on_o0?oonf[o
o`3f00?ooo]Z0_l0Y_l2oookJP03ojP0oooonf[ooo]Z00Cooo]Z00Coo`3ioookJ_oonf[o07Oo1?oo
nfX01_ooK03ooo]ZoookJ_l0olcooh40onGo00Wooo]Z00?o0?_ooookJ_oonfX02?oonfX2ool300Ko
oo]Z0ooo0=d3oookJP03o`0Gool0Xooo0:?o00Co/ol06ooonfX8ooo900KoiOl03_oonfX3ok?o00?o
0:?o0_l05ol4ool0g@?ooo]Z0ooo0`02oookJPWoiOl00_oob@03oc_o0003ooo90?nDo`3oU?l000?o
oo]Z00?o07OooookJ_oo0?T00_oonfX2ojP0o`;ooo]Z0_l0Y_l00ooo0?Ko0000on_o0002o`000003
ool60?oonf[o603o00Gooo]Z00Goo`3loookJ_oonf[ooo]ZoonB0002oolF00Oooo]Z00?oo`3Zoook
J_oonfX04ooonfX00ol0Looooo]ZoookJP0<oookJP03okWo0?ooDP3ooo]Z00;ooo]Z00Oo02[ooook
J_loo`3ooo]Zo`3Loomho`3o0?oO00Oooo]Z0_m4o`001Ol0oa_oA?l0odCo0?oobP3oA?l000Cooo]Z
00?oo`2CoookJ_oo01<01_oonfX00ooJo`3ooo]ZoookJP02oookJP03obH0oolPo`3ooo]Z017ooo]Z
00Go<Ol0oookJ_oonf[ooo]Zo`3oF`02oookJP07oh;o0?oonf[ooo]Zo`3o/Ol0<?oo0?m=o`3Xo`02
oookJP04o`H0oooonf[oo`3eoi;o00?ooo]Z00?oo`1Zoa00ool0GOl01?oonfX00olE0?ooo`1Aoook
JP02oookJP03o`2]oooo07Wooo]Z00Wooo]Z00Oo0?mCoookJ_oonf[ooo]Zo`3o2?l0oagoU?l000ko
oo]Z00Co0?ldoookJ_oonf[o0?m>1ooonfX00ol0R?oooo]Zo`2Yo`1CoookJP04oolF0?oonf[ooo]Z
oonB00Oooo]Z00?oo`3loookJ_oonfX01?oonfX01OlH0?oooo]ZoookJ_oonf[oo`H000Cooo]Z00Co
jol0oookJ_oonf[oo`3f0_oonfX2o`2Vo`;ooo]Z00?oZ03ooookJ_oonfX01OoonfX00ooo0?Wooo]Z
o`1go`05oookJP06oom/0?oonf[o0?o<oon10?oonf[o>ol02OoonfX00ol0nooooo]ZoookJP07oook
JP;oo`<01ooonfX3ool0g@?ooo]Z0_l0Xol4ok?o03Oooo]Z0onco`04o`2So`03o`0Goooo0=goo`3M
00;oo`3M1?oonfX2ool300Oooo]Z0_l0nol5oookJP?o>ol000?ooo]Zoom/0?l0oiX00ooonfX00ol0
Mooooo]Zool0n@02oookJP04ojP0oooonf[ooo]ZoookJP;o0:Ko00Ooo`3fon_o0?l0003o0000ool6
0?oonf[o603o00Kooo]Z00Koo`3loookJ_oonf[ooo]ZoonB0?oo5P08oookJP03ool0j_oonf[ooo]Z
01;ooo]Z00?o07?ooookJ_oonfX03OoonfX03?nio`3ooe80oookJ_oonf[o02[ooookJ_loo`3ooo]Z
o`3Loooonf[oN?l0o`3og`Sooo]Z00Co0?lKoookJ_lB0?ooolX01OoonfX00ol0nOooo`2Cool04`06
oookJP03om[o0?oonf[ooo]Z00;ooo]Z00?o9P3oob3o0?n40?l04_oonfX01Olao`3ooo]ZoookJ_oo
nf[o0?mK00;ooo]Z00KoP_l0oookJ_l0ok7ooo]Zo`3oCOl0j?l2oookJP04o`H0oooonf[ooo]Zoi;o
00Cooo]Z00?o403oo`1MoooonfX00ooonfX00olE0?ooo`1AoookJP02oookJP03o`2]oooonf[oo`1i
00Wooo]Z00So0?mCoookJ_oonf[ooo]Zo`3o2?l0oagooo]Zo`3Qo`kooo]Z00Co0?ldoookJ_l0obko
0?m>1ooonfX00ol0R?oooo]Zo`2Yo`0YoookJP00;_oonfX01?oo5P3ooo]ZoookJ_ooTP06oookJP03
ool0o?oonf[ooo]Z00Cooo]Z00?o603ooookJ_oonfX00_oonfX00ooo1P3ooo]ZoookJP02oookJP03
on_o0?oonf[oo`3f00Cooo]Z00Co0:KooookJ_oonf[oZ03o1_oonfX01?oo0?Wooo]ZoookJ_l0Mol4
oookJP;oof`00_oonfX00oooP@3oiOl0oc_o0008oookJP03o`3koooonf[ooo]Z00Wooo]Z0_oo0`07
oookJP?oo`3M0ooonfX01?l05ooo0:?oo`2Sool0Xol4ok?o01cooo]Z0ooob@06onGo00[ooo]Z00Co
W`3ook?o0?nco`3o/ol00_l0Xol3o`0Go`?oo`3M0_mi0?l3oookJP;oo`<01?oonfX:onGo00;o>ol0
0_oob@04oiCo00;ooo]Z00Co07Ooool0nOoo0?Wooo]Z0_nX0?l2oookJP;o0:Ko0_oo0?H00ooonf[o
jol0o`000002ool60003oookJ_lH0?oooo]Z00Cooo]Z00Koo`3loookJ_oonf[ooo]ZoonB0?oo5P08
oookJP03ool0j_oonf[ooo]Z01?ooo]Z00?o07?ooookJ_oonfX03?oonfX00onio`3ooe80oookJP02
oookJP08o`0Zoooonf[o?ol0oookJ_l0g?ooN?l0o`3ogolm0?l7oookJP06odCo0?l0oa_oA?l0odCo
0?oobP3oA?l01?oonfX00ooo09?o0?Woool04`06oookJP03on7o0?oJo`3ooo]Z00;ooo]Z00?o9P3o
ob3o0?oonfX04_oonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP07o`3o/?n2o`3ooo]Zo`3o/Ol0<?oo
0?m=o`3Xo`02oookJP05o`H0oooonf[oo`3eoookJ_nBo`000ooonfX00ol06Ooo403ooookJP04oook
JP06oaD0oooo057ooo]ZoookJ_l0[Oooo`1i2_oonfX01ol0oe?ooo]ZoookJ_oonf[o0?l8o`3o7OnD
o`003ooonfX00ol0ocCooo]Zo`3oCP08oookJP03o`28oooonf[o0:Wo05Cooo]Z00CooaH0oookJ_oo
nf[ooi801ooonfX00ooo0?cooo]ZoookJP03oookJP03oaP0oooonf[ooo]Z00;ooo]Z00?oo`H0oook
J_oonfX00_oonfX01?o[o`3ooo]ZoookJ_oo0?H3oookJP04o`2Voooonf[ooo]ZojP0o`Oooo]Z00?o
o`3ioookJ_l0Mol01OoonfX2oom/0003oookJ_ooP@3ooo]Z00;o>ol02?oonfX00ol0nooooo]Zoook
JP08oookJP;oo`<01ooonfX01?mi0?ooo`3Mool0gOoo0=d2oookJP;o01Oo0_l0Xol4ok?o02oooo]Z
00CoW`3ook?o0?nco`3o/ol00ol0Xol2o`0Go`?oo`3M0_mi0?l4oookJP;oo`<01ooonfX2o`3ko`Go
oo]Z0_lko`001?ooP@3ooo]Zoom/0?ooK003oookJP;o07Oo0_oo0?T00ooonf[oZ03oojP0o`02oook
JP;o0:Ko0_oo0?H01_o[o`3o0000ool60?oo1P3ooo]ZoaP0o`Kooo]Z00Koo`3loookJ_oonf[ooo]Z
oonB0?oo5P08oookJP03ool0j_oonf[ooo]Z01;ooo]Z00?o07?ooookJ_oonfX03OoonfX03Onio`3o
oe80oookJ_oonf[o02[ooookJ_loo`3ooo]Zo`3Loooonf[oN?l0o`3ogolm0?l01ooonfX01Ol0oa_o
oo]Zoa80oooonf[oolX000Gooo]Z00?oo`2CoookJ_oo01<01_oonfX01ooJo`3ooo]ZoookJ_oonf[o
9P3oob3o0?n40?l04ooonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP09oh;o0?oonf[ooo]Zo`3o/Ol0
<?oo0?m=o`3Xoooonf[o1P3o00;ooo]Z00?oo`3eoi;o0?oonfX00_oonfX00ol06Ooo403ooookJP04
oookJP07oaD0oooo057ooo]ZoookJ_l0[Ooooo]Zool0N@09oookJP03o`3oDooonf[ooo]Z00;ooo]Z
00?o0?lMoookJ_l0hOl03_oonfX01?l0ocCooo]ZoookJ_l0odh8oookJP03o`28oooonf[o0:Wo02Wo
oo]Z000_oookJP03oolF0?oonf[ooi8000Oooo]Z00?oo`3loookJ_oonfX01?oonfX00olH0?oooo]Z
oookJP02oookJP03ool60?oonf[ooo]Z00;ooo]Z00?ojol0oookJ_oo0?H01?oonfX00ol0Y_oooo]Z
ojP0o`07oookJP04ool0nOoonf[ooo]Zo`1go`Cooo]Z00Ko0?nJoom/0?oonf[ooo]Zoon10?l0ol`2
oc_o00Oooo]Z00?o0?_ooookJ_oonfX02_oonfX2ool300Oooo]Z00CoN@3oool0gOoo0=goo`3M0_oo
nfX2o`0Go`Co0:?o1?nco`03oil0oacooo]Z0_oUo`03oookJPGoW`3o0onco`02o`2So`03o`0Goooo
nf[oo`3M00?oo`3M0_mi0?l4oookJP;oo`<01OoonfX9onGo00;o>ol00_oob@06oiCo00;o07Oo00Co
o`3ioookJ_oonf[oZ03o0ooonfX00ol0Y_oooo]Zool0mP02oookJP04on_o0?l0003oo`H0o`0000;o
603o1OoonfX01_oo0?cooo]ZoookJ_oonf[ooi80oolF00Sooo]Z00?oo`3ZoookJ_oonfX04ooonfX0
0ol0Looooo]ZoookJP0<oookJP03okWo0?ooDP3ooo]Z00?ooo]Z00Oo02[oocoo0?oonf[ooo]Zo`3L
oomho`3o0?oO00Oooo]Z00KoA?l0o`3o6om4o`3oA?l0ooo:0?m4o`04oookJP03ool0Tol0nOooo`0C
00Oooo]Z00Oof_l0oookJ_oonf[ooo]ZobH0oolPo`3oQ03o01;ooo]Z00Go<Ol0oookJ_oonf[ooo]Z
o`3oF`02oookJP07oh;o0?oonf[o0?naoookJ_l0<?oo0?m=o`3Xo`02oookJP04o`H0oooonf[oo`3e
oi;o00?ooo]Z00?oo`1Zoa00oooonfX01?oonfX00olE0?ooo`1AoookJP02oookJP03o`2]oooo07Wo
oo]Z00Wooo]Z00Oo0?mCoookJ_oonf[ooo]Zo`3o2?l0oagoU?l000oooo]Z00?o0?ldoookJ_l0odh0
1ooonfX00ol0R?oooo]Zo`2Yo`05oookJP03o`3o[Ooonf[ooo]Z04kooo]Z00?ooaH0oookJ_ooTP00
1ooonfX00ooo0?cooo]ZoookJP04oookJP03oaP0oooonf[ooo]Z00;ooo]Z00?oo`H0oookJ_oonfX0
0_oonfX01?o[o`3ooo]ZoookJ_oo0?H3oookJP;o0:Ko00?oZ03ooookJ_oonfX01_oonfX00ooo0?Wo
oo]Zo`1go`05oookJP06o`3oV_ooK03ooo]Zoon10?l0olcooo]Z0_lko`07oookJP03o`3koooonf[o
oo]Z00Wooo]Z0_oo0`07oookJP;oN@3o0ooo0=d2oookJP;o01Oo0ol0Xol4ok?o00?oW`3o8OoonfX5
oil0o`?o/ol00ol0Xol00ooonf[oo`3Mool0g@02ool0g@;oN@3o1?oonfX3ool300Oooo]Z0_l0nol5
oookJP;o>ol000Cooh40o`3oc?l0oi[oof`01?oonfX01?l0Mooooo]Zool0nOoonfX2ojP0o`?ooo]Z
00So0:KooookJ_oo0?Kooo]Zon_o0?l0003oo`H0o`0000;o603o1_oonfX00ooo0?cooo]ZoookJP02
oonB0003oolF0?oonf[ooo]Z00Kooo]Z00?oo`3ZoookJ_oonfX04_oonfX00ol0Looooo]ZoookJP0=
oookJP03okWo0?ooDP3ooo]Z00;ooo]Z00So02[ooookJ_loo`3ooo]Zo`3Loomho`3ooo]Zo`3og`So
oo]Z00Co0?lKoookJ_lB0?ooolX01OoonfX00ooo09?ooo]Zool04`06oookJP03om[o0?oonf[ooo]Z
00;ooo]Z00?o9P3oob3o0?n40?l04_oonfX01Olao`3ooo]ZoookJ_oonf[o0?mK00;ooo]Z00WoP_l0
oookJ_l0ok7ooo]Zo`3oCOoonf[o0>SooookJ_l60?l00_oonfX00onBo`3ooo]ZoookJP02oookJP03
oa00oooonf[ooo]Z00?ooo]Z00?o5@3oool0DOoonfX00_oonfX00ol0[Ooooo]Zool0N@09oookJP08
o`3oDooonf[ooo]ZoookJ_l0o`So0?lMoookJ_l0hOl>oookJP04o`3o=?oonf[o0?l^o`3oCPOooo]Z
00?o08SooookJ_l0ZOl01OoonfX00ol01?oooo]ZoookJP0RoookJP00;ooonfX01?oo5P3ooo]Zoook
J_ooTP07oookJP03ool0o?oonf[ooo]Z00Cooo]Z0_lH0?l3oookJP03ool60?oonf[ooo]Z00;ooo]Z
00?ojol0oookJ_oo0?H01?oonfX2o`2Vo`03ojP0oooonf[ooo]Z00Gooo]Z00Coo`3ioookJ_oonf[o
07Oo1?oonfX01ol0oi[oof`0oom/0?oonf[ooh40o`3oc?oonfX00_lko`06oookJP03o`3koooonf[o
oo]Z00_ooo]Z0_oo0`07oookJP;oN@3o0ooo0=d00ooonf[o01Ooo`0Go`02o`0Go`?o0:?o00Cooo]Z
ok?o0?nco`3o/ol01onO0?lDoookJP03oil0oonco`3o/ol000So/ol00_l0Xol00ooonf[oo`3Mool0
g@02ool0g@;oN@3o1_oonfX2ool300Kooo]Z1ooUo`03oc_o00;oolT01onDo`001?l0MoooU?l0ool0
nOoonfX2ojP0o`;ooo]Z0_l0Y_l00ooonf[oo`3foookJP02on_o0005oookJ_oo1P3o0000oaP0ool0
00001OoonfX01_oo0?cooo]ZoookJ_oonf[ooi80oolF00Sooo]Z00?oo`3ZoookJ_oonfX04ooonfX0
0ol0Looooo]ZoookJP0<oookJP03okWo0?ooDP3ooo]Z00?ooo]Z00Oo02[oocoo0?oonf[ooo]Zo`3L
oomho`3o0?oO00Sooo]Z00GoA?l0o`3o6om4o`3oA?l0ooo:0005oookJP03ool0Tooo01?ooo]Z00Ko
oo]Z00?of_l0oookJ_oonfX00_oonfX00olV0?oo8?l0oookJP0BoookJP04oc7o0?oonf[ooo]Zo`3o
F`;ooo]Z00Oo0?n`oh;o0?oonf[o0?nao`0`ool0odgo0>So00;ooo]Z00Co1P3ooookJ_oo0?GoT_l0
1?oonfX00ol06Ooo403ooookJP04oookJP06ool0DOoonf[ooo]ZoookJ_l0[Oooo`1i2_oonfX01ol0
oe?ooo]ZoookJ_oonf[o0?l8o`3o7OnDo`003ooonfX00ol0ocCooo]Zo`3oCP08oookJP03o`28oooo
nf[o0:Wo00Gooo]Z00?o0?n]oookJ_oonfX0CooonfX00ooo5P3ooo]ZoonB0007oookJP03ool0o?oo
nf[ooo]Z00Cooo]Z0_lH0?l3oookJP03ool60?oonf[ooo]Z00;ooo]Z00Cojol0oookJ_oonf[oo`3f
1?oonfX00ol0Y_ooZ03ooookJP07oookJP03ool0nOoonf[o07Oo00Gooo]Z00Go0?nJoom/0?ooK03o
oh40o`3oc002oookJP;o>ol01_oonfX00ol0nooooo]ZoookJP0:oookJP;oo`<01ooonfX2ogT0o`05
oookJ_oo0=goo`3Mool0gOoonfX00ol05ol3o`2So`04oookJ_nco`3o/ol0ok?o00OoW`3o5?oonfX0
0onO0?oo/ol0ok?o0008ok?o00?o0:?o1?oo0=d2ogT0o`Kooo]Z0_oo0`09oookJP03o`3koooonf[o
oo]Z00;ooo]Z0olko`000oooP@3o0?o<oookJP02oom/00Cooo]Z00Go07OooookJ_oo0?Wooo]ZojP0
o`03oookJP;o0:Ko00Wooo]Zool0m_o[o`3ojol0oookJ_oo1P3o0000oaP0ool000001_oonfX01_oo
0?cooo]ZoookJ_ooTP3ooo]ZoolF00Sooo]Z00?oo`3ZoookJ_oonfX04_oonfX00ol0Looooo]Zoook
JP0=oookJP03okWo0?ooDP3ooo]Z00;ooo]Z00So02[ooookJ_loo`3ooo]Zo`3Loooonf[oN?l0o`3o
g`Sooo]Z00Co0?lKoookJ_lB0?ooolX01OoonfX00ol0nOooo`2Cool04`06oookJP03om[o0?oQo`3o
oo]Z00;ooo]Z00?o9P3oob3o0?n40?l04_oonfX01Olao`3ooo]ZoookJ_oonf[o0?mK00;ooo]Z00Wo
P_l0oookJ_oonf[o0?nao`0`ool0odgo0>SooookJ_l60?l00_oonfX00onBo`3ooo]ZoookJP02oook
JP03o`0Iool@0?oooo]Z00Cooo]Z00Oo5@3oool0DOoonf[ooo]Zo`2]oooonf[oo`1i00Wooo]Z00?o
0?mCoookJ_oonfX00_oonfX00ol0oagooo]Zo`3Qo`0?oookJP03o`3o=?oonf[o0?m>00Sooo]Z00?o
08SooookJ_l0ZOl01OoonfX00ol01?oooo]ZoookJP0RoookJP00<?oonfX01?oo5P3ooo]ZoookJ_oo
TP07oookJP03ool0o?oonf[ooo]Z00Gooo]Z00Go603ooookJ_oonf[ooo]Zool60004oookJP;ojol0
00?oo`3foookJ_oonfX00ooonfX00ol0Y_ooZ03ooookJP06oookJP04ool0nOoonf[ooo]Zo`1go`Go
oo]Z00?o0?nJoom/0?oonfX00_ooP@02oookJP;o>ol01OoonfX3o`3ko`cooo]Z00?oo`<0oookJ_oo
nfX01_oonfX2ogT0o`04oookJ_oo0=goo`3Mool0g@Cooo]Z00Go01Ooo`2Sool0Xooo0:?oo`0Go`04
ok?o00;o01Oo00?ooo]Zoil0oonO0?l01?nO0?l?ok?o00Go01Oo0ol0Xol00ooonf[oN@3oool0g@02
ool0g@03ogT0oooonf[ooo]Z00Oooo]Z0_oo0`07oookJP;oolT01?oUo`02oc_o0003oookJ_oob@3o
olT000OoU?l00_l0Mol2ool0n@04oookJ_nX0?oooo]ZoookJP;o0:Ko00Kooo]Zool0m_oo0?Kooo]Z
on_o0?oonfX2ool60004o`000?lH0?oo0000o`0000?ooo]Z0_nDo`03oookJP03oonB0?oo5P3ooo]Z
00Oooo]Z00?oo`3ZoookJ_oonfX04ooonfX00ol0Looooo]ZoookJP0<oookJP03okWo0?oonf[ooe80
00?ooo]Z00So02[ooookJ_loo`3ooo]Zo`3Loomho`3o0?oOocd0o`Sooo]Z00Co0?lKodCo0?m4o`3o
olX01OoonfX00ooo09?ooo]Zool04`06oookJP03om[o0?oonf[ooo]Z00;ooo]Z00?o9P3oob3o0?n4
0?l04_oonfX01Olao`3ooo]ZoookJ_oonf[oA?l000;ooo]Z00OoP_l0oookJ_l0ok7o033ooookJ_l0
odgo0>So00;ooo]Z00Co1P3ooookJ_oo0?GoT_l00ooonfX00ooo06[o01Wooa00o`04oookJP03oaD0
oooo057ooo]Z00;ooo]Z00?o0:goool0NOoonfX02OoonfX01ol0oe?ooo]ZoookJ_oonf[o0?l8o`3o
7OnDo`003ooonfX00ol0ocCooo]Zo`3oCP07oookJP03o`28oooonf[o0:Wo00Gooo]Z00?o0?n]oook
J_oonfX0DOoonfX00ooo5P3ooo]ZoonB0007oookJP03ool0o?oonf[ooo]Z00Gooo]Z00Go603ooook
J_oonf[ooo]Zool60004oookJP;ojol000?ooo]Zool0m_oonfX00ooonfX00ol0Y_ooZ03ooookJP07
oookJP03ool0nOoonf[o07Oo00Kooo]Z00Co0?nJoom/0?ooP@3ooh400ooonfX2oc_o00Gooo]Z0ol0
nol;oookJP03ool30?oonf[ooo]Z00Kooo]Z0_mi0?l2oookJP?oo`3M1?oonfX3o`2So`03o`0Goonc
o`3o/ol000;o/ol00ol05ol6oil0o`oo/ol000?ooo]Zo`0Gool05ol00ol05ol3o`2So`05ogT0oooo
0=goo`3Mool0gOmi0?l02OoonfX2ool300Wooo]Z0_l0nol3oookJP;o>ol00_ooP@001?l0olcooo]Z
oom/0?ooK004oookJP;o07Oo0_oo0?T2ojP0o`;ooo]Z0_l0Y_l01Ooonf[oo`3fool0m_o[o`3ooo]Z
00;oo`H000Co0000oaP0ool0003o00001?oonfX2ool0o0;ooo]Z00?ooi80oookJ_oo5P002?oonfX0
0ooo0>[ooo]ZoookJP0BoookJP03o`1coooonf[ooo]Z00gooo]Z00?o^Ol0oookJ_ooDP000_oonfX0
2Ol0:_oooo]Zocoo0?oonf[o0=cooookJ_mho`3o0?oOocd0o`07oookJP04o`3o6ooonf[o4P3oooo:
00Gooo]Z00?o0?Woool0Tooo01<01_oonfX00ooJo`3ohOl0oookJP02oookJP04obH0oooonf[o8?l0
oh@0oa;ooo]Z00Oo<Ol0oookJ_oonf[ooo]Zo`3oFooonf[oP_l000;ooo]Z00[o0?nao`0`ool0odgo
oo]Zo`3Xoooonf[o1P3ooookJ_oo0?GoT_l00ooonfX00ooo06[o01Wooa00o`04oookJP03oaD0oooo
057ooo]Z00;ooo]Z00?o0:gooookJ_oo07T02OoonfX02?l0oe?ooo]ZoookJ_oonf[o0?l8o`3o7Ooo
nf[o0>7o3_oonfX01?l0ocCooo]Zo`3o;_l0odh7oookJP03o`28oooonf[o0:Wo00Gooo]Z00?o00Co
oookJ_oonfX08ooonfX0037ooo]Z00?ooaH0oookJ_ooTP002?oonfX00ooo0?cooo]ZoookJP05oook
JP05oaP0oooonf[ooo]ZoookJ_oo1P001OoonfX00oo[o`3oo`3fool0mP04oookJP03o`2VoonX0?oo
oo]Z00Kooo]Z00Coo`3ioookJ_oonf[o07Oo1OoonfX01?l0oi[oof`0oom/0?oonfX2oon100;ooo]Z
0_lko`06oookJP?o0?_o2_oonfX2ool300Sooo]Z1?mi0?l3ool0g@Gooo]Z1Ol0Xol9ok?o01Co0:?o
00?oN@3oool0gOoo0=d00_oo0=d:oookJP?oo`<02?oonfX3ooo900;oiOl00_lko`001?oonf[oolT0
ooo90?oob@06oiCo00;o07Oo0_oo0?T01?oonf[oZ03oojP0oooonfX2o`2Vo`;ooo]Z00Koo`3foook
J_oonf[ojol0oookJ_oo1P02oookJP04oaP0ool0003o0000o`0000;ooo]Z00CoU?l0oookJ_oonf[o
oo]Z0_ooTP000ooo5P3ooo]ZoookJP06oookJP03ool0j_oonf[ooo]Z01?ooo]Z00?o07?ooookJ_oo
nfX03?oonfX00onio`3ooo]ZoomB0004oookJP07o`0Zooloo`3ooo]Zo`3Loomho`3o0?oOocd0o`08
oookJP04o`3o6om4o`3oA?l0ooo:00Kooo]Z00?oo`2Cool04ooonfX01_oonfX01ooJo`3ooo]Zoook
J_oonf[o9P3oob3o0?n40?l04ooonfX01?lao`3ooo]ZoookJ_m4o`02oookJP07oh;o0?oonf[ooo]Z
o`3o/Ol0<?oo0?m=o`3Xo`02oookJP04o`H0oooonf[oo`3eoi;o00Cooo]Z00?o01Wooa00oooonfX0
1?oonfX00ooo057ooo]ZoookJP02oookJP03ool0NOoonf[ooo]Z00Sooo]Z00So0?mCoookJ_oonf[o
oo]Zo`3o2?oonf[o0?lMoiCo00kooo]Z00?o0?ldoookJ_l0odh02?oonfX00ol0R?oooo]Zo`2Yo`05
oookJP03o`3o[Ooonf[ooo]Z057ooo]Z00?ooaH0oookJ_ooTP002?oonfX00ooo0?cooo]ZoookJP05
oookJP05oaP0oooonf[ooo]ZoookJ_oo1P001OoonfX01?o[o`3ooo]Zool0m_oo0?H3oookJP03o`2V
oonX0?oooo]Z00Oooo]Z00?oo`3ioookJ_l0Mol01_oonfX00ol0oi[oof`0oom/0002oon100?ooo]Z
0_lko`06oookJP?o0?_o2OoonfX2ool300Sooo]Z1Omi0?l3ool0g@Cooo]Z1Ol0Xol9ok?o01Go0:?o
1?oo0=d:oookJP?oo`<02OoonfX2o`3ko`?ooo]Z0_lko`02oon10004o`3oc?oonf[o0?nJoom/00Co
oo]Z0_l0Mol2ool0n@04oookJ_nX0?oooo]ZoookJP;o0:Ko0_oonfX01Ooo0?Kooo]Zon_o0?oonf[o
o`H000;ooo]Z00Co603oo`000?l0003o00000ooonfX01Ooo0?cooo]ZoookJ_oonf[ooi8000;ooaH0
2?oonfX00ooo0>[ooo]ZoookJP0BoookJP03o`1coooonf[ooo]Z00gooo]Z00?o^Ol0oookJ_ooDP00
0ooonfX02?l0:_oo?ol0oookJ_l0g?oooo]ZogSo0?l0omoo?@3o2?oonfX01?l0oa_ooo]Zoa80oooo
bP05oookJP03o`3ioooo09?oo`0C00Kooo]Z00?of_l0oookJ_oonfX00_oonfX00olV0?oo8?l0oh@0
o`0BoookJP05oc7o0?oonf[ooo]ZoookJ_l0oe/00_oonfX02On2o`3ooo]Zo`3o/Ooonf[o033oo`3o
COl0j?oooo]Zo`H0o`02oookJP03oi;o0?oonf[ooo]Z00;ooo]Z00?o01Wooa00oooonfX01?oonfX0
0olE0?ooo`1AoookJP02oookJP03o`2]oooo07Wooo]Z00Sooo]Z00?o0?mCoookJ_oonfX00_oonfX0
1?l0o`So0?lMoookJ_l0hOl>oookJP03o`3o=?oonf[o0?m>00Sooo]Z00?o08SooookJ_l0ZOl01Ooo
nfX00ol01?oooo]ZoookJP0SoookJP00<_oonfX00ooo5P3ooo]ZoonB0007oookJP03ool0o?oonf[o
oo]Z00Kooo]Z00Go603ooookJ_oonf[ooo]Zool60005oookJP03on_o0?oonf[oo`3f00Gooo]Z00?o
Z03ooookJ_oonfX01OoonfX01?oo0?Wooo]ZoookJ_l0Mol5oookJP;o0?nJ0_ooK0001Ooonf[ooh40
oon10?ooP@3ooo]Z00;o>ol01ooonfX3o`3ko`Wooo]Z0_oo0`0<oookJP04ogT0oooo0=goo`3Mool0
g@OoN@3o3?oonfX7o`0Go`?ooo]Z1Omi0?l3ool0g@cooo]Z0_oo0`08oookJP;o0?_o0ooob@03oc_o
00GoolT01?nDo`03o`1go`;oo`3i0_oonfX01?nX0?oooo]ZoookJ_l0Y_l3oookJP04ool0m_oonf[o
jol0on_o00;oo`H00_oonfX00olH0?oo0000o`000002o`0000;oU?l00ooonfX00oooTP3ooo]ZoolF
0008oookJP03ool0j_oonf[ooo]Z01?ooo]Z00?o07?ooookJ_oonfX03?oonfX00onio`3ooo]ZoomB
0004oookJP07o`0Zooloo`3ooo]Zo`3Loooonf[oN?l0o`3og`08oookJP05o`3o6om4o`3oA?l0odCo
0?oobP001OoonfX00ooo09?oo`0CoookJP06oookJP03om[o0?oonf[ooo]Z00;ooo]Z00?o9P3oob3o
0?n40?l04_oonfX01Olao`3ooo]ZoookJ_oonf[oA?l000;ooo]Z00OoP_l0oookJ_l0ok7o033ooook
J_l0odgo0>So00;ooo]Z00Co1P3ooookJ_oo0?GoT_l00ooonfX00ooo06[o01Wooa00o`04oookJP03
oaD0oooo057ooo]Z00;ooo]Z00?o0:goool0NOoonfX02OoonfX01ol0oe?ooo]ZoookJ_oonf[o0?l8
o`3o7OnDo`003ooonfX00ol0ocCooo]Zo`3oCP08oookJP04o`28oooonf[o0:WooookJP;o0?n]0_oo
nfX00ol0ojgooo]ZoookJP1BoookJP03oolF0?oonf[ooi8000Sooo]Z00?oo`3loookJ_oonfX01Ooo
nfX01OlH0?oooo]ZoookJ_oonf[oo`H000Gooo]Z00Cojol0oookJ_oonf[oo`3f1?oonfX00onX0?oo
oo]ZoookJP06oookJP03ool0nOoonf[o07Oo00Kooo]Z0_l0oiX2oom/00?ooh400_oonfX2oc_o00Oo
oo]Z0ol0nol8oookJP;oo`<03?oonfX2ogT0o`?oo`3M1_mi0?l=oookJPOo01Oo0ooonfX4ogT0o`?o
o`3M3?oonfX2ool300Wooo]Z0ol0nol2oookJP?o>ol00_ooP@000ol0olcooo]Zo`3oVP02oom/00;o
oo]Z0ol0Mol2ool0n@04oookJ_nX0?ooZ03ooookJP;o0:Ko0ooonfX00ooo0?Kojol0on_o0002ool6
00;ooo]Z00?o603oo`000?l000000_l000000ooonf[oo`3lool0o003oookJP03oonB0?oo5P3ooo]Z
00Sooo]Z00?oo`3ZoookJ_oonfX04_oonfX00ol0Looooo]ZoookJP0=oookJP03okWo0?oonf[ooe80
00?ooo]Z00So02[ooookJ_loo`3o0=cooookJ_mho`3ooo]Zo`3og`Sooo]Z00Co0?lKoookJ_lB0?oo
olX01OoonfX00ol0nOooo`2Cool04`06oookJP03om[o0?oQo`3ooo]Z00;ooo]Z00Co9P3oob3o0?oo
nf[oQ03o4_oonfX01olao`3ooo]ZoookJ_oonf[o0?mKoookJ_n2o`000_oonfX02_l0ok7o033oo`3o
COoonf[o0>SooookJ_l60?oooo]Zool0mOnBo`03oookJP03ool0J_l06Ooo403o00Cooo]Z00?o5@3o
ool0DOoonfX00_oonfX00ol0[Ooooo]Zool0N@09oookJP08o`3oDooonf[ooo]ZoookJ_l0o`So0?lM
oookJ_l0hOl>oookJP04o`3o=?oonf[o0?l^o`3oCPSooo]Z00?o08SooookJ_l0ZOl01OoonfX00ol0
1?oooo]ZoookJP0SoookJP00<_oonfX01?oo5P3ooo]ZoookJ_ooTP07oookJP03ool0o?oonf[ooo]Z
00Kooo]Z0_lH0?l2oookJP03ool60?oonf[ooo]Z00?ooo]Z00?ojol0oookJ_oo0?H01OoonfX2ojP0
o`Kooo]Z00?oo`3ioookJ_oonfX00_l0Mol5oookJP06o`3oV_oonf[oof`0oookJ_l0olcooo]Z0_oo
P@000ooonf[o>ol0oc_o0008oookJP?o0?_o2?oonfX5ool300_ooo]Z8_oo0=d:oookJPGoo`<01_oo
nfX4o`3ko`03oookJ_oob@3oolT000;o>ol00ooob@001?oonf[oolT0ooo90?l0oiX3oiCo00;o07Oo
00?ooo]Zool0nOoo0?T00_oonfX2ojP0o`03oookJ_l0Y_oo0:Ko00;ooo]Z0_oo0?H01?oonf[ojol0
oookJ_oo1P02oookJP;o603o00Gooo]Zo`000?l0003o0000oiCo0004oookJP03oonB0?oonf[ooaH0
00Sooo]Z00?oo`3ZoookJ_oonfX04ooonfX00ol0Looooo]ZoookJP0<oookJP04okWo0?oonf[o0?lc
oomB00?ooo]Z00Oo02[oocoo0?oonf[ooo]Zo`3Loomho`3o0?oO00Wooo]Z00Co0?lKodCo0?m4o`3o
olX01OoonfX00ooo09?ooo]Zool04`06oookJP03om[o0?oonf[ooo]Z00;ooo]Z00?o9P3oob3o0?n4
0?l04ooonfX01?lao`3ooo]ZoookJ_m4o`02oookJP07oh;o0?oonf[o0?nao`0`oooonf[o0?m=o`3X
o`02oookJP04o`H0oooonf[oo`3eoi;o00?ooo]Z00?oo`1Zo`0Iool@0?l01OoonfX00ooo057ooo]Z
oookJP02oookJP03ool0NOoonf[ooo]Z00Sooo]Z00So0?mCoookJ_oonf[ooo]Zo`3o2?oonf[o0?lM
oiCo00oooo]Z00?o0?ldo`3oC_oonfX01ooonfX00ol0R?oooo]Zo`2Yo`02oookJPGo0?n]00?o0=Co
oookJ_oonfX0D_oonfX00ooo5P3ooo]ZoonB0008oookJP03ool0o?oonf[ooo]Z00Gooo]Z0_lH0?l2
oookJP03ool60?oonf[ooo]Z00?ooo]Z00Cojol0oookJ_oonf[oo`3f1?oonfX2ojP0o`Oooo]Z00Co
o`3ioookJ_l0Mooo07Oo1_oonfX01Ol0oi[ooo]Zoom/0?l0olcooo]Z00;ooh400_oonfX2oc_o00So
oo]Z0ol0nol7oookJPGoo`<03?oonfXQool0g@[ooo]Z1Ooo0`07oookJPCo0?_o0ooonfX2oc_o0003
oookJ_ooP@3ooh4000;o0?o<0_l0oiX00oooK03ooo]ZoookJP02o`1go`03oookJ_oo0?Woo`3i00;o
oo]Z00CoZ03ooookJ_oonf[o0:Ko0ooonfX2ool0mP03on_o0?oonf[oo`H000;ooo]Z0_lH0?l00ooo
nf[o0000o`000002o`000004ool0o?oonf[ooo]ZoookJP;ooi8000?ooaH0oookJ_oonfX01ooonfX0
0ooo0>[ooo]ZoookJP0BoookJP03o`1coooonf[ooo]Z00gooo]Z00Co^Ol0oookJ_l0oc?ooe800_oo
nfX02?l0:_oooo]Zocoo0?oonf[o0=coogSo0?oonf[o0?oO2?oonfX01?l0oa_ooo]ZoookJ_oobP05
oookJP03o`3ioooo09?oo`0C00Kooo]Z00?of_l0on7o0?oonfX00ooonfX00olV0?oo8?l0oh@0o`0B
oookJP05oc7o0?oonf[ooo]ZoookJ_l0oe/00_oonfX02On2o`3ooo]Zo`3o/Ol0<?oo0?m=oookJ_l0
j?oooo]Zo`H0o`02oookJP03oi;o0?oonf[ooo]Z00;ooo]Z00?o01Wooa00oooonfX01?oonfX00ooo
057ooo]ZoookJP02oookJP03o`2]oooo07Wooo]Z00Sooo]Z00?o0?mCoookJ_oonfX00_oonfX01?l0
o`So0?lMoookJ_l0hOl>oookJP03o`3o=?oonf[o0?m>00Sooo]Z00?o08SooookJ_l0ZOl01OoonfX0
0ol01?oooo]Zo`3Do`0ToookJP00<ooonfX00ooo5P3ooo]ZoonB0008oookJP03ool0o?oonf[ooo]Z
00Oooo]Z00Co603ooookJ_oonf[oo`H01OoonfX00oo[o`3ooo]Zool0mP05oookJP03o`2VoonX0?oo
Z03o00Gooo]Z00Coo`3ioookJ_oonf[ooo]Z0_l0Mol4oookJP04o`3oV_oonf[oof`0oom/00;o0?o<
00Cooo]Zoon10?ooP@3ooo]Z0olko`08oookJP?o0?_o2_oonfX8ool301Cooo]Z1omi0?l<oookJPSo
o`<02?oonfX3o`3ko`Cooo]Z00?oolT0oc_o0?lko`001_oob@001?l0oi[oof`0oiCo0?nDo`02o`1g
o`?oo`3i0_oonfX2ojP0o`03oookJ_l0Y_oo0:Ko00?ooo]Z00Koo`3foookJ_oonf[ojol0oookJ_oo
1P02oookJP05oaP0oooonf[ooo]ZoookJ_l000000_nDo`001Ol0003ooo]ZoookJ_oonf[ooi8000;o
oaH02?oonfX00ooo0>[ooo]ZoookJP0CoookJP03o`1coooonf[ooo]Z00cooo]Z00Co^Ol0oookJ_oo
nf[ooe800ooonfX01ol0:_oooo]Zocoo0?oonf[o0=coogSo0?l0oml02OoonfX01?l0oa_oA?l0odCo
0?oobP05oookJP03o`3ioooo09?oo`0C00Oooo]Z00Sof_l0oookJ_oonf[ooo]ZobH0oolPo`3ooo]Z
oh@0oa;ooo]Z00Co<Ol0oookJ_oonf[oA?l00ooonfX03?n2o`3ooo]Zo`3o/Ol0<?oo0?m=oookJ_l0
j?oooo]Zo`H0oooonf[oo`3eoi;o00Cooo]Z00?oo`1Zo`0Iool@0?l01?oonfX00olE0?ooo`1Aoook
JP02oookJP03o`2]oooo07Wooo]Z00Wooo]Z00Oo0?mCoookJ_oonf[ooo]Zo`3o2?l0oagoU?l000oo
oo]Z00?o0?ldoookJ_l0odh02?oonfX00ol0R?oooo]Zo`2Yo`02oookJPGo0?n]00?o0=CooookJ_oo
nfX0DooonfX00ooo5P3ooi80oookJP08oookJP03ool0o?oonf[ooo]Z00Kooo]Z00Co603ooookJ_oo
nf[oo`H01OoonfX01?o[o`3ooo]ZoookJ_oo0?H5oookJP;oZ03o1_oonfX00ooo0?Wooo]ZoookJP02
o`1go`Gooo]Z00Ko0?nJoookJ_ooK03oof`0o`3oc?oonfX2oon100;ooo]Z0olko`08oookJP?o0?_o
2OoonfX8ool301Gooo]Z1omi0?l;oookJPSoo`<02OoonfX3o`3ko`Gooo]Z0_lko`000ooonf[ooh40
oon10002o`3oc0;o0?nJ0_ooK0000ooonf[o07Ooo`1go`03ool0n@;ooo]Z0_nX0?l00ooonf[o0:Ko
o`2Vo`03oookJP05ool0m_oonf[ojol0oookJ_oo1P000_oonfX01?lH0?oooo]ZoookJ_oonfX2o`00
00;oo`3l0ooonfX00oooTP3ooo]ZoolF0009oookJP03ool0j_oonf[ooo]Z01;ooo]Z00?o07?ooook
J_oonfX03OoonfX01?nio`3ooo]ZoookJ_ooDP02oookJP08o`0Zoooonf[o?ol0oookJ_l0g?oooo]Z
ogSo0?l0oml8oookJP05o`3o6ooonf[ooo]Zoa80oooobP001?oonfX01?l0nOoooo]Zool0Tooo01<6
oookJP03om[o0?oonf[ooo]Z00;ooo]Z00Co9P3oob3o0?oonf[oQ03o4_oonfX01?lao`3ooo]Zoook
J_l0oe/2oookJP09oh;o0?oonf[o0?naoookJ_l0<?oo0?m=oookJ_l0j?oo1P3o00;ooo]Z00?oT_l0
oookJ_oonfX00_oonfX00ooo06[o01Wooa00o`04oookJP03oaD0oooo057ooo]Z00;ooo]Z00?o0:go
oookJ_oo07T02OoonfX02?l0oe?ooo]ZoookJ_oonf[o0?l8o`3o7Ooonf[o0>7o3_oonfX01?l0ocCo
oo]Zo`3o;_l0odh8oookJP03o`28oooonf[o0:Wo00Gooo]Z00?o00CooookJ_l0e?l09?oonfX003Co
oo]Z00?ooaH0oookJ_ooTP002?oonfX00ooo0?cooo]ZoookJP07oookJP04oaP0oooonf[ooo]Zool6
00Gooo]Z00?ojol0oookJ_oo0?H01_oonfX00ol0Y_ooZ03ooookJP04oookJP03ool0nOoonf[ooo]Z
00;ooo]Z0_l0Mol3oookJP;o0?nJ00Cooo]Zoom/0?oonf[o0?o<0_oonfX2oon100;ooo]Z0_lko`09
oookJP?o0?_o3ooonfX8ool301Oooo]Z2?oo0`0<oookJPCo0?_o1OoonfX3oc_o00OoolT00_ooK000
0ooonf[o07Ooo`1go`02ool0n@Cooo]Z00CoZ03ooookJ_l0Y_oo0:Ko1?oonfX01?oo0?Kooo]Zoook
J_o[o`02ool600;ooo]Z00?o603ooookJ_oonfX00_oonfX01?nDo`3o0000o`000?l00002oookJP03
oonB0?oo5P3ooo]Z00Sooo]Z00?oo`3ZoookJ_oonfX04ooonfX00ol0Looooo]ZoookJP0<oookJP04
okWo0?oonf[ooo]ZoomB00?ooo]Z00So02[ooookJ_loo`3ooo]Zo`3Loomho`3o?@3oo`3og`Sooo]Z
00Go0?lKo`2>oom4o`3ooo]Zooo:0004oookJP03o`3ioooo09?oo`0C00Oooo]Z00?of_l0oookJ_oo
nfX00_oonfX00olV0?oo8?l0oh@0o`0CoookJP04oc7o0?oonf[ooo]ZodCo00;ooo]Z00OoP_l0oook
J_l0ok7o033ooookJ_l0odgo0>So00;ooo]Z00Co1P3ooookJ_oo0?GoT_l00ooonfX00ooo06[o01Wo
oa00o`05oookJP03ool0DOoonf[ooo]Z00;ooo]Z00?oo`1ioookJ_oonfX02?oonfX02?l0oe?ooo]Z
oookJ_oonf[o0?l8oookJ_l0oagoU?l03ooonfX00ol0ocCo0?m>o`3o;P08oookJP03o`28ool0ZOoo
oo]Z00;ooo]Z1?l0ojd00ol0e?oo0?n]oookJP1DoookJP03oolF0?oonf[ooi8000Sooo]Z00?oo`3l
oookJ_oonfX01ooonfX01?lH0?oooo]ZoookJ_oo1P05oookJP04on_o0?oonf[ooo]Zool0mPGooo]Z
00?o0:KoojP0oooonfX01OoonfX01?oo0?Wooo]ZoookJ_oonfX2o`1go`Cooo]Z0_l0oiX00ooonf[o
of`0o`3oc002oookJP?ooh400_oonfX2oc_o00Wooo]Z0ol0nol>oookJPSoo`<05ooonfX8ool300go
oo]Z1?l0nol5oookJP?o>ol000?ooo]Zoon10?ooP@000_l0ol`01Ooonf[oof`0oom/0?ooK03ooo]Z
00;o07Oo0_oo0?T4oookJP04ojP0oooonf[o0:Koo`2Vo`Cooo]Z00?oo`3foookJ_o[o`000_oo1P02
oookJP03oaP0oooonf[ooo]Z00;ooo]Z00Co0000ool0o?l0003o00000_oonfX00oooTP3ooo]ZoolF
0009oookJP03ool0j_oonf[ooo]Z01;ooo]Z00?o07?ooookJ_oonfX03OoonfX01?nio`3ooo]Zoook
J_ooDP02oookJP09o`0Zoooonf[o?ol0oookJ_l0g?oooo]ZogSo0?lm0?oo0?oO00Sooo]Z00Co0?lK
oookJ_lB0?ooolX01?oonfX01?l0nOoooo]Zool0Tooo01<6oookJP03om[o0?oQo`3ooo]Z00;ooo]Z
00Co9P3oob3o0?oonf[oQ03o4_oonfX01Olao`3ooo]ZoookJ_oonf[o0?mK00;ooo]Z00WoP_l0oook
J_l0ok7o033oo`3oCOoonf[o0>SooookJ_l60?l00_oonfX00onBo`3ooo]ZoookJP02oookJP03o`0I
ool@0?oooo]Z00Cooo]Z00?oo`1AoookJ_oonfX00_oonfX00ol0[Oooo`1ioookJP08oookJP03o`3o
Dooonf[ooo]Z00;ooo]Z00Co0?l8o`3o7Ooonf[o0>7o3_oonfX00ol0ocCooo]Zo`3oCP09oookJP03
o`28ool0ZOoooo]Z00Cooo]Z00?o00CooookJ_l0e?l09OoonfX003Gooo]Z00?ooaH0oookJ_ooTP00
2?oonfX00ooo0?cooo]ZoookJP07oookJP04oaP0oooonf[ooo]Zool600Gooo]Z00?ojol0oookJ_oo
0?H01_oonfX00ol0Y_ooZ03oojP0o`04oookJP;oo`3i1?oonfX2o`1go`?ooo]Z00Co0?nJoookJ_oo
K03oof`00_l0ol`2oookJP;ooh400_oonfX2oc_o00[ooo]Z0ol0nolDoookJPSoo`<01ooonfX8ool3
013ooo]Z1?l0nol7oookJP;o>ol02_oob@03o`1go`;oo`3i1?oonfX2ojP0o`03oookJ_l0Y_oooo]Z
00?ooo]Z0_oo0?H01?oonf[ojol0on_o0?oo1P03oookJP04oaP0oooonf[ooo]ZoookJP;oU?l01?l0
0002oonB0003oolF0?oonf[ooo]Z00Oooo]Z00?oo`3ZoookJ_oonfX04ooonfX00ol0Looooo]Zoook
JP0<oookJP04okWo0?oonf[ooo]ZoomB00?ooo]Z00So02[ooookJ_loo`3ooo]Zo`3Loooonf[oN?l0
o`3og`Wooo]Z00Co0?lKoookJ_lB0?ooolX01OoonfX00ooo09?ooo]Zool04`06oookJP03om[o0?oo
nf[ooo]Z00;ooo]Z00?o9P3oob3o0?n40?l04ooonfX01?lao`3ooo]ZoookJ_m4o`02oookJP0=oh;o
0?l0ok3ooo]Zo`0`oooonf[o0?m=oookJ_l0j?oooo]Zo`H0oooonf[oo`3eoi;o0004oookJP03ool0
J_l@0?oooo]Z00Cooo]Z00?oo`1AoookJ_oonfX00_oonfX00ol0[Oooo`1ioookJP08oookJP03o`3o
Dooonf[ooo]Z00;ooo]Z00?o0?l8o`3o7OnDo`003ooonfX00ol0ocCooo]Zo`3oCP08oookJP03o`28
oooonf[o0:Wo00?ooo]Z1?l0ojd00ol0e?oo0?n]oookJP1EoookJP03oolF0?oonf[ooi8000Sooo]Z
00?oo`3loookJ_oonfX01ooonfX01?lH0?oooo]ZoookJ_oo1P05oookJP04on_o0?oonf[ooo]Zool0
mPGooo]Z00?o0:KoojP0oonX0?l01OoonfX2ool0n@?ooo]Z0_l0Mol4oookJP05o`3oV_oonf[oof`0
oom/0?l0ol`00ooonfX2oon100;ooo]Z0_lko`0:oookJP?o0?_o4ooonfX8ool300Oooo]Z2?oo0`0A
oookJPCo0?_o1ooonfX2oc_o00;ooo]Z0_ooP@000ol0olcooo]Zoom/0002oom/0004oookJ_l0Mooo
07Ooo`1go`;oo`3i1?oonfX2ojP0o`;o0:Ko1?oonfX2ool0mP;ojol000Goo`H0oookJ_oonf[ooo]Z
oaP0o`04oookJP;oo`3l0ol000001?oonf[ooi80oookJ_oo5P09oookJP03ool0j_oonf[ooo]Z01;o
oo]Z00?o07?ooookJ_oonfX03OoonfX01?nio`3ooo]ZoookJ_ooDP02oookJP09o`0Zoooonf[o?ol0
oookJ_l0g?oooo]ZogSo0?lm0?oo0?oO00Sooo]Z00Co0?lKoookJ_oonf[oolX01OoonfX00ol0nOoo
o`2Cool04`06oookJP03om[o0?oQo`3ooo]Z00?ooo]Z00?o9P3oob3o0?n40?l04ooonfX01?lao`3o
oo]ZoookJ_l0oe/2oookJP09oh;o0?oonf[o0?nao`0`oooonf[o0?m=oookJ_l0j?oo1P3o00;ooo]Z
00?oT_l0oookJ_oonfX00_oonfX00ooo06[o403ooookJP04oookJP03oaD0oooo057ooo]Z00;ooo]Z
00?o0:gooookJ_oo07T02?oonfX00ol0oe?ooo]ZoookJP02oookJP04o`3o2?l0oagooo]Zo`3Qo`oo
oo]Z00?o0?ldoookJ_l0odh02?oonfX00ol0R?oooo]Zo`2Yo`05oookJP03o`04oooonf[o0=Co02Go
oo]Z000ZoookJP;oU?l02OoonfX01?oo5P3ooo]ZoookJ_ooTP08oookJP03ool0o?oonf[ooo]Z00Oo
oo]Z0_lH0?l00ooonf[oo`H0oookJP04oookJP03on_o0?oonf[oo`3f00Kooo]Z0_l0Y_l2ojP0o`Co
oo]Z0_oo0?T4oookJP?o07Oo00Oooo]Zo`3oV_oonf[ooo]Zoom/0?oonf[o0?o<00?ooo]Z0oooP@00
0ooonf[o>ol0oc_o000;oookJP?o0?_o6OoonfX7ool301Gooo]Z0ol0nol9oookJP;o>ol02_oob@02
o`1go`03ooo90?oo0?Woo`3i00Gooo]Z00CoZ03ooookJ_l0Y_oo0:Ko0ooonfX2ool0mP05oookJ_o[
o`3ojol0oookJ_oo1P000_oonfX2oiCo00?ooo]Z00?oU?l0oookJ_oonfX00ol000000oooTP3ooo]Z
oolF0009oookJP03ool0j_oonf[ooo]Z01?ooo]Z00?o07?ooookJ_oonfX03?oonfX01?nio`3ooo]Z
oookJ_ooDP03oookJP03o`0Zoooonf[o?ol000;ooo]Z00?o0=coogSo0?l0oml02OoonfX01?l0oa_o
oo]Zoa80oooobP05oookJP03o`3ioooo09?oo`0C00Kooo]Z00?of_l0on7o0?oonfX00_oonfX01?lV
0?oooo]Zob3o0?n40?lBoookJP04oc7o0?oonf[ooo]ZodCo00?ooo]Z00OoP_l0oookJ_l0ok7o033o
oookJ_l0odgo0>So00;ooo]Z00Co1P3ooookJ_oo0?GoT_l00ooonfX00ooo06[o01Wooa00o`05oook
JP06ool0DOoonf[ooo]ZoookJ_l0[Oooo`1i2_oonfX02?l0oe?ooo]ZoookJ_oonf[o0?l8oookJ_l0
oagoU?l03ooonfX00ol0ocCo0?m>o`3o;P08oookJP03o`28ool0ZOoooo]Z00;ooo]Z1Ol0ojd00ol0
e?oo0?n]oookJP1FoookJP03oolF0?oonf[ooi8000Sooo]Z00?oo`3loookJ_oonfX01ooonfX2oaP0
o`03oookJ_oo1P3ooo]Z00Cooo]Z00Cojol0oookJ_oonf[oo`3f1_oonfX00ol0Y_ooZ03oojP0o`05
oookJP;oo`3i0ooonfX3o`1go`;ooo]Z00Go0?nJoookJ_oonf[oof`0o`3oc004oookJP;ooh400_oo
nfX2oc_o00_ooo]Z0ol0nolHoookJPOoo`<05_oonfX3o`3ko`Wooo]Z0_lko`001Ooonf[o0?o<oon1
0?ooP@3ooo]Z00?oof`000Go0?nJoookJ_l0Mooo07OooookJP02ool0n@Gooo]Z00?oZ03oo`2Vool0
Y_l01?oonfX2ool0mP;ojol000Cooo]Zool60?oonf[ooo]Z0_lH0?l4oookJP03ool0o?oonf[o0000
00;o00000_ooTP000ooonf[ooaH0oookJP08oookJP03ool0j_oonf[ooo]Z01;ooo]Z00?o07?ooook
J_oonfX03OoonfX01?nio`3ooo]Zo`3o<oooDP02oookJP09o`0Zoooonf[ooo]Zocoo0?oonf[o0=co
ogSo0?lm0?oo0?oO00Sooo]Z00Go0?lKoookJ_oonf[o4P3oooo:0004oookJP03o`3ioooonf[oo`2C
00Kooo]Z00?of_l0on7o0?oonfX00ooonfX01?lV0?oo8?l0oookJ_n40?lBoookJP04oc7o0?oonf[o
oo]Zo`3oF`;ooo]Z00goP_l0o`3o/?oonf[o0?nao`0`ool0odgooo]Zo`3Xoooonf[o1P3ooookJ_oo
0?GoT_l000Cooo]Z00?o01Wooa00oooonfX01?oonfX01ooo057ooo]ZoookJ_oonf[o0:gooookJ_oo
07T02OoonfX00ol0oe?ooo]ZoookJP02oookJP04o`3o2?l0oagooo]Zo`3Qo`kooo]Z00?o0?ldoook
J_l0odh02OoonfX00ol0R?oo0:WooookJP04oookJP04o`04oooonf[ooo]Zo`3DobGooo]Z000Zoook
JPCoU?l02?oonfX00ooo5P3ooo]ZoonB0009oookJP03ool0o?oonf[ooo]Z00Sooo]Z00?o603ooook
J_oo1P001OoonfX00oo[o`3ooo]Zool0mP07oookJP04o`2Voooonf[oZ03oojP0o`Cooo]Z0ooo0?T4
oookJP;o07Oo0ol0oiX2oom/0003o`3oc?oonf[ooo]Z00?ooo]Z0_ooP@000ooonf[o>ol0oc_o000<
oookJP?o0?_o;_oonfX4o`3ko`Wooo]Z0olko`000ooonf[oolT0ooo90007ooo900;o07Oo00?ooo]Z
ool0nOoo0?T01OoonfX2ojP0o`;o0:Ko0ooonfX2ool0mP04oookJ_o[o`3ojol0oookJP;oo`H000?o
oo]ZoiCo0?nDo`000ooonfX2oiCo00?ooo]Z0_l000000oooTP3o0000oolF0008oookJP;oo`3Z5Ooo
nfX00ol0Looooo]ZoookJP0=oookJP03okWo0?oonf[ooe8000?ooo]Z00Wo02[ooookJ_oonf[o?ol0
oookJ_l0g?ooN?l0ocd0ool0oml02?oonfX01Ol0oa_o08kooa80oooonf[oolX000Cooo]Z00?o0?Wo
ool0Tooo01<01ooonfX00ooJo`3ooo]ZoookJP02oookJP03obH0oolPo`3oQ03o01?ooo]Z00Co<Ol0
oookJ_oonf[oA?l00_oonfX03On2o`3ooo]Zo`3o/Ol0<?oooo]Zo`3oCOoonf[o0>SooookJ_l60?oo
oo]Zool0mOnBo`001?oonfX00ooo06[o403ooookJP04oookJP03ool0DOoonf[ooo]Z00;ooo]Z00?o
0:goool0NOoonfX02?oonfX00ol0oe?ooo]ZoookJP02oookJP03o`3o2?oonf[o0?lM00oooo]Z00?o
0?ldoookJ_l0odh02?oonfX00ol0R?oooo]Zo`2Yo`03oookJPCo0?n]00?o0=Coo`3o[Ol0ojd0F?oo
nfX00ooo5P3ooi80oookJP08oookJP03ool0o?oonf[ooo]Z00Sooo]Z00?o603ooookJ_oo1P001Ooo
nfX01?o[o`3ooo]ZoookJ_oo0?H6oookJP;o0:Ko0_nX0?l5oookJP;oo`3i1?oonfX2o`1go`04oook
J_l0oi[o0?nJo`3oVP;oof`01OoonfX2oon100;ooo]Z0_lko`0<oookJP?o0?_o;_oonfX4o`3ko`Wo
oo]Z0olko`02o`3oc0;ooh400oooK002o`3oVP04oookJ_l0Mooo07OooookJP;oo`3i1OoonfX2ojP0
o`03o`2Voooonf[ooo]Z00;ooo]Z0_oo0?H2on_o0004oookJ_oo1P3oo`H0oookJP;o603o1?oonfX2
ool0o0;ooo]Z0_l000001?ooTP3o0000oookJ_oo5P08oookJP;oo`3Z5?oonfX00ol0Looooo]Zoook
JP0=oookJP04okWo0?oonf[o0?lcoomB00;ooo]Z00[o02[ooookJ_oonf[o?ol0oookJ_l0g?ooN?l0
ocd0oooonf[o0?oO2?oonfX01?l0oa_ooo]Zoa80oooobP04oookJP04o`3ioooonf[oo`2Cool04`Ko
oo]Z00?of_l0on7o0?oonfX00_oonfX01?lV0?oooo]Zob3o0?n40?lCoookJP04oc7o0?oonf[ooo]Z
o`3oF`;ooo]Z00WoP_l0oookJ_l0ok7o033ooookJ_l0odgooo]Zo`3Xool60?l00_oonfX00onBo`3o
oo]ZoookJP02oookJP03ool0J_l@0?oooo]Z00Cooo]Z00?o5@3oool0DOoonfX00_oonfX00ol0[Ooo
oo]Zool0N@08oookJP03o`3oDooonf[ooo]Z00;ooo]Z00Co0?l8oookJ_l0oago0>7o3ooonfX00ol0
ocCooo]Zo`3oCP08oookJP03o`28oooonf[o0:Wo00Gooo]Z00?o00CooookJ_l0e?l09_oonfX002[o
oo]Z1OnDo`08oookJP03oolF0?oonf[ooi8000Wooo]Z00?oo`3loookJ_oonfX02?oonfX00olH0?oo
oo]Zool60005oookJP;ojol000?oo`3foookJ_oonfX01OoonfX00ol0Y_oooo]ZoookJP02ojP0o`Go
oo]Z0_oo0?T4oookJP;o07Oo00?ooo]Zo`3oV_l0oiX00_ooK002o`3oc0Cooo]Z0_ooP@000ooonf[o
>ol0oc_o000=oookJP?o0?_o9ooonfX4o`3ko`[ooo]Z0olko`000ooonf[o0?o<o`3oc007ooo900?o
07Oo00?ooo]Zool0nOoo0?T01?oonfX3ojP0o`03oookJ_l0Y_oooo]Z00;ooo]Z0_oo0?H00ooonf[o
jol0on_o0002oookJP04ool60?oonf[oU?l0oiCo00Cooo]Z00?oU?l0oookJ_oonfX00ooonfX01?l0
003ooi80o`000?oo5P08oookJP03ool0j_oonf[ooo]Z01Cooo]Z00?o07?ooookJ_oonfX03OoonfX0
0onio`3ooo]ZoomB0003oookJP09o`0Zoooonf[ooo]Zocoo0?oonf[o0=coogSo0?lm0?oo0?oO00So
oo]Z00Go0?lKo`2>oolB0?oooo]Zooo:0004oookJP04o`3ioooo09?ooo]Zool04`Kooo]Z00?of_l0
oookJ_oonfX00_oonfX01?lV0?oo8?l0oookJ_n40?lBoookJP04oc7o0?oonf[ooo]ZodCo00?ooo]Z
00OoP_l0oookJ_l0ok7o033ooookJ_l0odgo0>So00;ooo]Z00?o1P3ooookJ_nBo`001?oonfX00ooo
06[o403ooookJP05oookJP06ool0DOoonf[ooo]ZoookJ_l0[Oooo`1i2_oonfX02?l0oe?ooo]Zoook
J_oonf[o0?l8oookJ_l0oagoU?l03ooonfX00ol0ocCo0?m>o`3o;P08oookJP03o`28ool0ZOoooo]Z
00?ooo]Z1?l0ojd00ol0e?oo0?n]oookJP1HoookJP03oolF0?oonf[ooi8000Wooo]Z00?oo`3loook
J_oonfX02?oonfX00olH0?oooo]Zool60005oookJP;ojol000?ooo]Zool0m_oonfX01_oonfX01?l0
Y_oooo]ZojP0oonX0?l5oookJP;oo`3i1?oonfX2o`1go`;ooo]Z0_l0oiX2oom/0003o`3oc?oonf[o
oo]Z00;ooo]Z0oooP@000ooonf[o>ol0oc_o000=oookJP?o0?_o9ooonfX4o`3ko`[ooo]Z0olko`03
o`3oc0;ooh400_ooK002o`3oVP05oookJ_l0Mooo07Ooo`1goooonfX00_oo0?T4oookJP?oZ03o0_l0
Y_l3oookJP;oo`3f0_o[o`02oookJP04ool60?oonf[o603ooaP0o`Gooo]Z00?oo`3loookJ_oonfX0
0_oonfX01Ol0003ooi80o`000?l0003ooaH000Sooo]Z00?oo`3ZoookJ_oonfX04ooonfX00ol0Looo
oo]ZoookJP0=oookJP04okWo0?oonf[o0?lcoomB00;ooo]Z00[o02[ooookJ_oonf[o?ol0oookJ_l0
g?oooo]ZogSo0?lm0?oo0?oO2?oonfX01?l0oa_ooo]Zoa80oooobP04oookJP04o`3ioooonf[oo`2C
ool04`Kooo]Z00?of_l0on7o0?oonfX00ooonfX01?lV0?oo8?l0oookJ_n40?lBoookJP04oc7o0?oo
nf[ooo]Zo`3oF`;ooo]Z00coP_l0o`3o/?l0ok7ooo]Zo`0`ool0odgooo]Zo`3Xoooonf[o1P3ooook
J_nBo`05oookJP03oa00oooonf[ooo]Z00Cooo]Z00Ooo`1AoookJ_oonf[ooo]Zo`2]oooonf[oo`1i
00Wooo]Z00?o0?mCoookJ_oonfX00_oonfX01?l0o`So0?lMoookJ_l0hOl>oookJP03o`3o=?oonf[o
0?m>00Wooo]Z00?o08Soo`2YoooonfX01OoonfX00ol01?oooo]Zo`3Do`0VoookJP00:_oonfX6oiCo
00Sooo]Z00?ooaH0oookJ_ooTP002?oonfX00ooo0?cooo]ZoookJP09oookJP03oaP0oooonf[oo`H0
00Kooo]Z00?ojol0ool0m_oonfX01_oonfX2o`2Vo`;ooo]Z00?oZ03ooookJ_oonfX01?oonfX2ool0
n@Cooo]Z0_l0Mol2oookJP03o`3oV_ooK03o0?nJ00Co0?o<0_oonfX2oon10003oookJ_lko`3o>ol0
00kooo]Z4ol0nolAoookJP?o0?_o1ooonfX2onGo00Go>ol00_oonfX00ol0olcooh40oon10003ooo9
00;oiOl000?ooo]Zo`1gool0Mol00_oonfX2ool0n@Cooo]Z0_nX0?l2oookJP;o0:Ko0_oonfX2ool0
mP03oookJ_o[o`3ojol000;ooo]Z0_oo1P000ooonf[oU?l0oookJP03oookJP;oU?l01_oonfX01?oo
TP3o0000oolF0?l00007oookJP03ool0j_oonf[ooo]Z01Cooo]Z00?o07?ooookJ_oonfX03OoonfX0
0onio`3ooo]ZoomB0003oookJP09o`0Zoooonf[ooo]Zocoo0?oonf[o0=cooookJ_mho`3o0?oO00Wo
oo]Z00Co0?lKoa80oooonf[oolX01OoonfX00ol0nOooo`2Cool04`06oookJP03om[o0?oQo`3ooo]Z
00;ooo]Z00Co9P3ooookJ_lPo`3oQ03o4ooonfX00olao`3ooo]ZodCo0003oookJP07oh;o0?oonf[o
0?nao`0`oooonf[o0?m=o`3Xo`02oookJP04o`H0oooonf[oo`3eoi;o00?ooo]Z00?oo`1Zo`1Mool@
0?l01OoonfX00ooo057ooo]ZoookJP02oookJP03o`2]oooo07Wooo]Z00Sooo]Z00Go0?mCoookJ_oo
nf[ooo]Zo`3o2002oookJP03o`3o7Ooonf[ooo]Z00kooo]Z00?o0?ldo`3oC_oonfX02?oonfX00ol0
R?oo0:WooookJP03oookJP?o0?n]00?o0=Coo`3o[Ol0ojd0F_oonfX00ooo5P3ooo]ZoonB0009oook
JP03ool0o?oonf[ooo]Z00Sooo]Z00?o603ooookJ_oo1P001_oonfX00oo[o`3ooo]Zool0mP07oook
JP04o`2Voooonf[ooo]ZojP0o`Kooo]Z0ooo0?T3oookJP;o07Oo0ooonfX00ol0oi[oof`0o`3oVP03
o`3oc0?ooo]Z0_ooP@000ooonf[o>ol0oc_o000>oookJQ?o0?_o4OoonfX3o`3ko`Wooo]Z1Olko`00
0ooonf[o0?o<o`3oc003oon10003oom/0?l0oi[o0?nJ00;ooo]Z0_l0Mol2oookJP;oo`3i1?oonfX2
ojP0o`03oookJ_l0Y_oo0:Ko00;ooo]Z0ooo0?H2on_o00;ooo]Z0_oo1P000ooonf[o603ooookJP04
oookJP;oo`3l1OoonfX01?ooTP3o0000o`000?oo5P07oookJP;oo`3Z5OoonfX00ol0Looooo]Zoook
JP0=oookJP04okWo0?oonf[o0?lcoomB00;ooo]Z00[o02[ooookJ_oonf[o?ol0oookJ_l0g?oooo]Z
ogSo0?lm0?oo0?oO2?oonfX01?l0oa_ooo]Zoa80oooobP05oookJP03o`3ioooonf[oo`2C00Kooo]Z
00?of_l0oookJ_oQo`000ooonfX01?lV0?oo8?l0oookJ_n40?lCoookJP03oc7o0?oonf[o0?mK00?o
oo]Z00WoP_l0oookJ_l0ok7o033ooookJ_l0odgo0>SooookJ_l60?l00_oonfX00onBo`3ooo]Zoook
JP02oookJP03ool0J_l@0?oooo]Z00Cooo]Z00?o5@3oool0DOoonfX00_oonfX00ol0[Ooooo]Zool0
N@08oookJP03o`3oDooonf[ooo]Z00;ooo]Z00Co0?l8oookJ_l0oago0>7o3ooonfX00ol0ocCooo]Z
o`3oCP09oookJP03o`28ool0ZOoooo]Z00Cooo]Z00?o00CooookJ_l0e?l09ooonfX002[ooo]Z1?nD
o`0:oookJP03oolF0?oonf[ooi8000Wooo]Z00?oo`3loookJ_oonfX02OoonfX2oaP0o`03ool60?oo
nf[ooo]Z00Cooo]Z00?ojol0ool0m_oonfX01ooonfX00ol0Y_oooo]ZoookJP02ojP0o`Kooo]Z0_oo
0?T4oookJP;o07Oo0_oonfX3oom/00;o0?nJ1?l0ol`2oon10003oookJ_lko`3o>ol001oooo]Z4Ol0
nol7oookJPGo>ol00ooonfX5oon100;oof`000CoiOl0oookJ_oonf[ooo]Z0_l0Mol2oookJP;oo`3i
0ooonfX3ojP0o`;ooo]Z0_l0Y_l2oookJP;oo`3f00?ooo]Zon_o0?o[o`000ooonfX01?oo1P3ooo]Z
oiCo0?nDo`03oookJP;oU?l01ooonfX00oooTP3ooaH0oolF0003o`0000Cooo]Z0_oo0>XFoookJP03
o`1coooonf[ooo]Z00gooo]Z00?o^Ol0oookJ_ooDP000ooonfX02Ol0:_oooo]ZoookJ_loo`3ooo]Z
o`3Loooonf[oN?l0o`3og`09oookJP04o`3o6olB0?oooo]Zooo:00Gooo]Z00?o0?Woool0Tooo01<0
1ooonfX00ooJo`3ooo]ZoookJP02oookJP03obH0oolPo`3oQ03o01?ooo]Z00?o<Ol0oookJ_m4o`00
1?oonfX01on2o`3ooo]Zo`0`oooonf[o0?m=oookJ_l0j?l00_oonfX00ol60?ooo`3eoi;o0004oook
JP03ool0J_l@0?oooo]Z00Gooo]Z00Koo`1AoookJ_oonf[ooo]Zo`2]oooo07T:oookJP08o`3oDooo
nf[ooo]ZoookJ_l0o`Sooo]Zo`3o7OnDo`0?oookJP03o`3o=?l0odko0?l^00Sooo]Z00?o08Soo`2Y
oooonfX01?oonfX3o`3o[@03o`3Dool0ojgooo]Z04cooo]Z00?oo`3ZoookJ_oonfX03?oonfX00ooo
5P3ooi80oookJP08oookJP03ool0o?oonf[ooo]Z00Wooo]Z0_lH0?l00ooo1P3ooo]ZoookJP04oook
JP03on_o0?oonf[oo`3f00Oooo]Z0_l0Y_l00ooonf[oZ03oojP0o`07oookJP;oo`3i0ooonfX2o`1g
o`?ooo]Z0oooK0000ol0oi[o0?o<o`3oc002o`3oc004oookJ_ooP@3ooh40oookJP;o>ol07ooonfXA
o`3ko`Oooo]Z1Olko`03oookJPGooh400_ooK004oookJP;o07Oo0_oonfX2ool0n@?ooo]Z0onX0?l0
0ooonf[o0:Koo`2Vo`02oookJP;oo`3f00?ooo]Zon_o0?o[o`000ooonfX01?oo1P3ooo]ZoaP0oolH
0?l4oookJP;oo`3l1_oonfX01?ooTP3o0000oolF0?oo5P02o`0000Gooo]Z00?oo`3ZoookJ_oonfX0
5?oonfX00ol0Looooo]ZoookJP0=oookJP04okWo0?oonf[o0?lcoomB00;ooo]Z00[o02[ooookJ_oo
nf[ooo]Zocoo0?l0g?oooo]ZogSo0?lm0?oo0?oO2?oonfX01Ol0oa_o08kooa80oooonf[oolX000Co
oo]Z00Co0?WooookJ_oo09?oo`0C1_oonfX00ooJo`3ohOl0oookJP02oookJP04obH0oooonf[o8?l0
oh@0oa?ooo]Z00?o<Ol0oookJ_l0oe/00ooonfX03?n2o`3o0?n`o`3o/Ol0<?oooo]Zo`3oCOoonf[o
0>SooookJ_l60?oooo]Zoi;o00Gooo]Z00?o403ooookJ_oonfX01?oonfX01ooo057ooo]ZoookJ_oo
nf[o0:gooookJ_oo07T02OoonfX02Ol0oe?ooo]ZoookJ_oonf[o0?l8oookJ_l0oagooo]Zo`3Qo`0>
oookJP03o`3o=?oonf[o0?m>00Wooo]Z00?o08Soo`2YoooonfX01OoonfX00ol01?oooo]Zo`3Do`0W
oookJP00:_oonfX3oiCo00cooo]Z00?ooaH0oookJ_ooTP002OoonfX00ooo0?cooo]ZoookJP0:oook
JP03oaP0oooo1P3ooo]Z00Gooo]Z00?ojol0ool0m_oonfX01ooonfX2o`2Vo`;ooo]Z0_nX0?l6oook
JP;oo`3i1?oonfX2o`1go`?ooo]Z1?ooK0001?l0oi[ooo]Zo`3oc?l0ol`3oon100Go>ol0;OoonfX5
oc_o00?oiOl01OooP@001Ol0olcoof`0oom/0?ooK03oiOl000Cooo]Z0_l0Mol01?oonf[oo`3iool0
nOoo0?T3oookJP;oZ03o0ooonfX2o`2Vo`;ooo]Z0_oo0?H00ooonf[ojol0on_o0004oookJP03ool6
0?nDo`3oU?l000Cooo]Z00?oU?l0oookJ_oonfX01OoonfX2oonB0003oolF0?l0003o000000;o0000
1?oonfX00ooo0>[ooo]ZoookJP0EoookJP03o`1coooonf[ooo]Z00gooo]Z00?o^Ol0oookJ_ooDP00
0ooonfX02_l0:_oooo]ZoookJ_oonf[o?ol0oookJ_l0g?ooN?l0oookJ_l0oml8oookJP05o`3o6olB
0?oooo]ZoookJ_oobP001?oonfX00ol0nOoooo]Zool0T`07oookJP03om[o0?oQo`3ooo]Z00;ooo]Z
00?o9P3oob3o0?n40?l05?oonfX00olao`3ooo]ZodCo0003oookJP07oh;o0?oonf[o0?nao`0`oooo
nf[o0?m=o`3Xo`02oookJP04o`H0oooonf[oo`3eoi;o00?ooo]Z00?oo`1Zoa00ool06Ol01OoonfX0
1ooo057ooo]ZoookJ_oonf[o0:gooookJ_oo07T02OoonfX01Ol0oe?ooo]ZoookJ_oonf[o0?l800;o
oo]Z00?o0?lMoookJ_oonfX03_oonfX00ol0ocCo0?m>oookJP08oookJP03o`28ool0ZOoooo]Z00Co
oo]Z0_l0ojd00ol0e?oo0?n]oookJP1>oookJP03ool0j_oonf[ooo]Z00cooo]Z00?ooaH0oonB0?oo
nfX02?oonfX00ooo0?cooo]ZoookJP0:oookJP03oaP0oooo1P3ooo]Z00Gooo]Z00?ojol0oookJ_oo
0?H02?oonfX00ol0Y_oooo]ZoookJP02ojP0o`Oooo]Z0_oo0?T3oookJP;o07Oo1?oonfX4oom/0004
oookJ_l0olco0?o<o`3oc0?ooh401Olko`0]oookJPGo>ol00ooonfX5oon10004oookJ_ooK03oof`0
oom/00Gooo]Z0_l0Mol01?oonf[oo`3iool0nOoo0?T3oookJP;oZ03o0_oonfX2o`2Vo`;ooo]Z0_oo
0?H00ooonf[ojol0on_o0004oookJP03ool60?lH0?oo603o00Gooo]Z00?oo`3loookJ_oonfX01?oo
nfX2oonB00;ooaH00ol00005oookJP03ool0j_oonf[ooo]Z01Cooo]Z00?o07?ooookJ_oonfX03Ooo
nfX01?nio`3ooo]Zo`3o<oooDP02oookJP0;o`0Zoooonf[ooo]ZoookJ_loo`3ooo]Zo`3Loomho`3o
?@3ooookJ_l0oml02?oonfX01?l0oa_o4P3ooookJ_oobP04oookJP04o`3ioooonf[ooo]Zool0T`Ko
oo]Z00?of_l0on7o0?oonfX00ooonfX00olV0?oo8?l0oh@0o`0DoookJP03oc7o0?oonf[o0?mK00?o
oo]Z00coP_l0o`3o/Ooonf[o033oo`3oCOoonf[o0>SooookJ_l60?oooo]Zool0mOnBo`04oookJP03
oa00ool06Ooooo]Z00Cooo]Z00Goo`1AoookJ_oonf[ooo]Zo`2]o`02oookJP03ool0NOoonf[ooo]Z
00Kooo]Z00?o0?mCoookJ_oonfX00_oonfX01?l0o`Sooo]Zo`3o7Ol0hOl?oookJP03o`3o=?oonf[o
0?m>00Wooo]Z00?o08Soo`2YoooonfX01?oonfX00ol01?oooo]Zo`3Do`0XoookJP00:_oonfX2oiCo
00kooo]Z00CooaH0oookJ_ooTP3ooi802?oonfX00ooo0?cooo]ZoookJP0:oookJP03oaP0oooo1P3o
oo]Z00Gooo]Z00?ojol0ool0m_oonfX02?oonfX01?l0Y_oooo]ZoookJ_oonfX2ojP0o`Kooo]Z0ooo
0?T3oookJP;o07Oo1OoonfX5oom/0004oookJ_l0olcooh40oon100;o0?o<00?ooo]Zoc_o0?lko`00
1olko`0PoookJPCo>ol00ooonfX5oon100?oiOl00oooK0000ooUo`3ooo]ZoookJP02oookJP?o07Oo
00?ooo]Zool0nOoo0?T00ooonfX3ojP0o`Cooo]Z00?o0:KooookJ_oonfX00_oo0?H00ooonf[ojol0
on_o0004oookJP;oo`H00onDo`02oookJP;oU?l01_oonfX2oonB0003oolF0?oonf[ooo]Z00Co0000
0_oonfX2ool0jQOooo]Z00?o07?ooookJ_oonfX03OoonfX00onio`3ooo]ZoomB0003oookJP0:o`0Z
oooonf[ooo]ZoookJ_loo`3ooo]Zo`3Loomho`3oU?l0o`3og`Sooo]Z00Go0?lKoa80oooonf[ooo]Z
ooo:0004oookJP04o`3ioooonf[oo`2Cool04`Kooo]Z00?of_l0on7o0?oonfX00_oonfX00olV0?oo
oo]Zob3o000DoookJP03oc7o0?oonf[oA?l000?ooo]Z00OoP_l0o`3o/?l0ok7o033ooookJ_l0odgo
0>So00?ooo]Z00?o1P3oool0mOnBo`001?oonfX00ooo06[o403ooookJP04oookJP03ool0DOlE0?oo
oo]Z00;ooo]Z00?o0:gooookJ_oo07T02OoonfX02?l0oe?ooo]ZoookJ_oonf[o0?l8oookJ_l0oago
U?l03ooonfX00ol0ocCo0?m>o`3o;P08oookJP03o`28ool0ZOoooo]Z00Gooo]Z0_l0ojd00ol0e?oo
oo]ZoookJP1?oookJP03ool0j_oonf[ooo]Z00cooo]Z00?ooaH0oonB0?ooTP002?oonfX00ooo0?co
oo]ZoookJP0:oookJP03oaP0oooo1P3ooo]Z00Gooo]Z00?ojol0oookJ_oo0?H02?oonfX2o`2Vo`;o
oo]Z0_nX0?l7oookJP;oo`3i0ooonfX2o`1go`Kooo]Z1?ooK0000ooonf[o0?o<o`3oc002oon10003
o`3oc?oonf[ooo]Z00So>ol08?oonfX5oc_o00?ooo]Z1OooP@02o`3oc004o`3oV_ooK03oof`0oom/
00Gooo]Z0ol0Mol00ooonf[oo`3iool0n@03oookJP?oZ03o0ooonfX00ol0Y_oooo]ZoookJP02ool0
mP03oookJ_o[o`3ojol000Cooo]Z0_oo1P000olH0?oooo]ZoookJP03oookJP;oo`3l1OoonfX2oonB
0003oookJ_oo5P3ooo]Z00Co00000ooonfX2ool0jQKooo]Z00?o07?ooookJ_oonfX03OoonfX01?ni
o`3ooo]Zo`3o<oooDP02oookJP0;o`0Zoooonf[ooo]ZoookJ_loo`3ooo]Zo`3Loooonf[oN?l0oook
J_l0oml02?oonfX01?l0oa_o4P3ooookJ_oobP04oookJP04o`3ioooonf[ooo]Zool0T`Kooo]Z00?o
f_l0oookJ_oQo`000ooonfX00olV0?oo8?l0oh@0o`0DoookJP03oc7o0?oonf[o0?mK00?ooo]Z00Oo
P_l0o`3o/?l0ok7o033ooookJ_l0odgo0>So00;ooo]Z00?o1P3ooookJ_nBo`001?oonfX00ooo06[o
403ooookJP05oookJP05ool0DOoonf[ooo]ZoookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP06oook
JP09o`3oDooonf[ooo]ZoookJ_l0o`Sooo]Zo`3o7Ooonf[o0>7o00kooo]Z00?o0?ldoookJ_l0odh0
2OoonfX00ol0R?oo0:WooookJP05oookJP03o`04oooonf[o0=Co02Sooo]Z000ZoookJP03oiCo0?oo
nf[oU?l000gooo]Z00GooaH0oookJ_oonf[ooo]ZoonB0008oookJP03ool0o?oonf[ooo]Z00[ooo]Z
00?o603oool60?oonfX01OoonfX00oo[o`3oo`3foookJP08oookJP03o`2Voooonf[ooo]Z00;ooo]Z
00?oZ03ooookJ_oonfX01_oonfX2ool0n@?ooo]Z0ol0Mol6oookJP03o`3oV_ooK03oof`000;oof`0
1oooP@05oookJPSo>ol04ooonfX5oc_o00;ooo]Z1OooP@05onGo00?oof`01_oonfX2o`1go`;ooo]Z
0_oo0?T3oookJP;oZ03o1OoonfX2o`2Vo`?oo`3f00?ooo]Zon_o0?o[o`001?oonfX2ool60003oiCo
0?oonf[oU?l000CoU?l01ooonfX00oooTP3ooaH0oolF0003oookJPCo000000?ooo]Zool0j_oonfX0
5ooonfX00ol0Looooo]ZoookJP0=oookJP03okWo0?oonf[ooe8000?ooo]Z00[o02[ooookJ_oonf[o
oo]Zocoo0?oonf[o0=coocd0oomho`3oU?l02OoonfX01?l0oa_o4P3ooookJ_oobP05oookJP03o`3i
oooo09?oo`0C00Kooo]Z00?of_l0on7o0?oonfX00ooonfX00olV0?oo8?l0oh@0o`0DoookJP03oc7o
0?m4o`3ooo]Z00?ooo]Z00?oP_l0oookJ_l0<?l00_oonfX01ol0odgo0>SooookJ_oonf[o1P3ooook
J_nBo`001?oonfX00ooo06[o403oo`0Io`05oookJP07ool0DOoonf[ooo]ZoookJ_l0[Ooooo]Zool0
N@09oookJP05o`3oDooonf[ooo]ZoookJ_l0o`P00_oonfX00ol0oagoU?l0oookJP0>oookJP03o`3o
=?l0odkooo]Z00Sooo]Z00?o08Soo`2YoooonfX01?oonfX3o`3o[@03o`3Doooonf[ooo]Z053ooo]Z
00?oo`3ZoookJ_oonfX02ooonfX01?oo5P3ooo]ZoookJ_ooTP08oookJP03ool0o?oonf[ooo]Z00[o
oo]Z00?o603oool60?oonfX01OoonfX00oo[o`3ooo]Zool0mP09oookJP05o`2Voooonf[ooo]Zoook
J_nX0?l02?oonfX2ool0n@?ooo]Z0ol0Mol7oookJPCoof`000?ooo]Zoon10?ooP@001OooP@04oook
JPWo>ol04_oonfX5oc_o00?ooo]Z1OooP@001Ooonf[o0?o<o`3oc?l0olco0?nJ00?oof`01_oonfX2
o`1go`;ooo]Z0_oo0?T3oookJP;oZ03o1?oonfX2o`2Vo`04oookJ_oo0?Koo`3foookJP;ojol01?oo
nfX2ool60003oaP0oooonf[ooo]Z00Cooo]Z00?oo`3loookJ_oonfX01?oonfX01?ooTP3ooo]ZoolF
0?oo5P02oookJPCo00000_oonfX00ooo0>[ooo]ZoookJP0EoookJP03o`1coooonf[ooo]Z00gooo]Z
00Co^Ol0oookJ_l0oc?ooe800_oonfX02ol0:_oooo]ZoookJ_oonf[o?ol0oookJ_l0g?oooo]ZogSo
0?oonf[o0?oO00Sooo]Z00Go0?lKo`2>oolB0?oooo]Zooo:0004oookJP03o`3ioooonf[oo`2C00Ko
oo]Z00?of_l0oookJ_oQo`001?oonfX00olV0?oo8?l0oh@0o`0DoookJP03oc7o0?l0oe_ooo]Z00?o
oo]Z00KoP_l0o`3o/Ol0<?oooo]Zo`3oCOl0j?l2oookJP03o`H0oooonf[oT_l000Gooo]Z00?o403o
o`0IoooonfX01?oonfX01Ooo057ooo]ZoookJ_oonf[o0:go00;ooo]Z00?oo`1ioookJ_oonfX01_oo
nfX00ol0oe?ooo]ZoookJP02oookJP05o`3o2?oonf[o0?lMoookJ_l0hOl03_oonfX00ol0ocCooo]Z
o`3oCP09oookJP03o`28ool0ZOoooo]Z00Cooo]Z00Co00CooookJ_oonf[o0=Co:?oonfX002gooo]Z
00?oU?l0oookJ_oonfX02ooonfX01?oo5P3ooo]ZoookJ_oonfX2oonB00Oooo]Z00?oo`3loookJ_oo
nfX02_oonfX00olH0?ooo`H0ool60005oookJP03on_o0?oo0?Koo`3f00Sooo]Z0_l0Y_l3oookJP;o
Z03o2?oonfX2ool0n@Cooo]Z0_l0Mol7oookJP;o0?nJ1?ooK002oookJP03o`3oc?ooP@3ooh4000Wo
oh400_oonfX9oc_o00Gooo]Z1Olko`02oookJPGooh400_oonfX5onGo00?oof`00ooUo`03oookJP?o
07Oo0_oonfX2ool0n@;ooo]Z0onX0?l5oookJP;oiOl00_oo0?H3oookJP04on_o0?oonf[ooo]Zoook
JP?oo`H000?oU?l0oookJ_oonfX01_nDo`05oookJP;ooi8000?ooaH0oookJ_oonfX00ooonfX4o`00
0003ool0j_oonf[ooo]Z01Kooo]Z00?o07?ooookJ_oonfX03OoonfX00onio`3ooo]ZoomB0003oook
JP0:o`0Zoooonf[ooo]ZoookJ_loo`3ooo]Zo`3Loooonf[oN?l0oiCo00Wooo]Z00Go0?lKoa80oooo
nf[ooo]Zooo:0004oookJP03o`3ioooonf[oo`2C00Oooo]Z00?of_l0on7o0?oonfX00_oonfX00olV
0?oo8?l0oh@0o`0DoookJP03oc7o0?oonf[oA?l000?ooo]Z00OoP_l0o`3o/?l0ok7o033ooookJ_l0
odgo0>So00;ooo]Z00Co1P3ooookJ_oo0?GoT_l01?oonfX00ooo06[o403ooookJP04oookJP05ool0
DOlE0?oooo]ZoookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP06oookJP03o`3oDooonf[ooo]Z00;o
oo]Z00Co0?l8oookJ_m4o`3o0?lM3ooonfX00ol0ocCo0?m>o`3o;P09oookJP03o`2Yoooonf[ooo]Z
00Cooo]Z0_l0ojd00ol0e?oooo]ZoookJP1BoookJP03ool0j_oonf[ooo]Z00_ooo]Z00?ooaH0oook
J_oonfX00_ooTP07oookJP03ool0o?oonf[ooo]Z00[ooo]Z00?o603oool60?oo1P001OoonfX01?o[
o`3ooo]Zool0m_oo0?H8oookJP04o`2Voooonf[ooo]ZoookJP;oZ03o2?oonfX2ool0n@Cooo]Z0_l0
Mol8oookJP03o`3oV_ooK03oof`000?oof`000?ooo]Zo`3oc?l0ol`02oooP@02oookJPSo>ol01Ooo
nfX5oc_o00?ooo]Z1OooP@03oookJP;o0?o<0_l0oiX3oom/00Kooo]Z0ol0Mol2oookJP;oo`3i0_oo
nfX3ojP0o`Cooo]Z0_l0Y_l00ooonf[oo`3fool0mP02oookJP04on_o0?oonf[ooo]ZoookJP?oo`H0
00?o603ooookJ_oonfX01?oonfX2ool0o0Gooo]Z0_ooTP02oolF00Cooo]Z1?l00002ool0jQOooo]Z
00?o07?ooookJ_oonfX03_oonfX00onio`3o0?lcoomB0003oookJP0:o`0Zoooonf[ooo]Zocoo0?oo
nf[o0=cooookJ_mho`3ooo]Zo`3og`Wooo]Z00Co0?lKoa80oooonf[oolX01?oonfX01?l0nOoooo]Z
oookJ_oo09<6oookJP03om[o0?oQo`3ooo]Z00?ooo]Z00?o9P3oob3o0?n40?l05?oonfX00olao`3o
oo]Zo`3oF`03oookJP09oh;o0?l0ok3o0?nao`0`oooonf[o0?m=o`3Xoooonf[o1P3o00;ooo]Z00?o
T_l0oookJ_oonfX00_oonfX00ooo06[o403ooookJP05oookJP04ool0DOoonf[ooo]Zo`2]o`?ooo]Z
00?oo`1ioookJ_oonfX01OoonfX00ol0oe?ooo]ZoookJP02oookJP05o`3o2?oonf[ooo]Zo`3o7Ol0
hOl03ooonfX00ol0ocCo0?m>oookJP09oookJP03o`2Yoooonf[ooo]Z00Cooo]Z00?o00CooookJ_l0
e?l0:OoonfX002kooo]Z00?oU?l0oookJ_oonfX02ooonfX00ooo5P3ooo]ZoookJP02oookJP03oonB
0?oonf[ooo]Z00Gooo]Z00?oo`3loookJ_oonfX02_oonfX2oaP0o`;oo`H01?oonfX00oo[o`3ooo]Z
ool0mP02ool0mPOooo]Z00?o0:KooookJ_oonfX00_oonfX2ojP0o`Sooo]Z0_oo0?T4oookJP;o07Oo
2OoonfX2o`3oVP;oof`01OoUo`03o`3oc0Cooo]Z2oooP@05oc_o00;o0?o<1OooP@05o`3oc0Ooof`0
1?oUo`05o`1go`;ooo]Z0ooUo`02oookJP;oZ03o1OoonfX3onGo00;oo`3f0_oonfX00onDo`3ojol0
on_o0002oookJP;oo`H000?ooo]ZoiCo0?nDo`000_oonfX7oiCo00?ooo]Z0_ooTP000ooo5P3ooo]Z
oookJP05oookJP;o00000_oo0>XHoookJP03o`1coooonf[ooo]Z00gooo]Z00?o^Ol0oookJ_ooDP00
0ooonfX00ol0:_oooo]ZoookJP02oookJP05ocoo0?oonf[o0=coogSo0?nDo`002OoonfX01Ol0oa_o
4P3ooookJ_oonf[oolX000Cooo]Z00Co0?WooookJ_oo09?oo`0C1_oonfX00ooJo`3ohOl0oookJP03
oookJP03obH0oolPo`3ooo]Z01?ooo]Z00?o<Ol0oookJ_m4o`001?oonfX00on2o`3o0?nao`0`o`02
oookJP07o`3oCOoonf[ooo]ZoookJ_l60?oooo]Zoi;o0004oookJP03ool0J_l@0?oo01Wo00Gooo]Z
00Ooo`1AoookJ_oonf[ooo]Zo`2]oooonf[oo`1i00Wooo]Z00Go0?mCoookJ_oonf[ooo]Zo`3o2002
oookJP03odCo0?nDo`3ooo]Z00kooo]Z00?o0?ldo`3oC_l0obh02?oonfX00ol0R?oo0:WooookJP05
oookJP;o0?n]00?o0=CooookJ_oonfX0DooonfX00ooo0>[ooo]ZoookJP0;oookJP05oolF0?oonf[o
oo]ZoookJ_ooTP001ooonfX00ooo0?cooo]ZoookJP0:oookJP;o603o0_oo1P04oookJP03on_o0?oo
nf[ooo]Z00?oo`3f1_oonfX2o`2Vo`?ooo]Z0_nX0?l8oookJP;oo`3i1?oonfX2o`1go`Wooo]Z0ol0
oiX4oom/0003oookJ_l0olco0?o<00;o0?o<1OoonfX:oon100Go>ol00ol0ol`5oon100Go0?o<1ooo
K004oookJPGo07Oo0_oonfX3ool0n@;ooo]Z0_nX0?l4oookJP?o0:Ko00?ooo]Zool0m_oo0?H00_oo
nfX2on_o00;ooo]Z0_oo1P000ooonf[o603ooaP0o`06oookJP03ool0o?oonf[ooo]Z00?ooo]Z0_oo
TP02oolF00Kooo]Z0ol000000ooo0>[ooo]ZoookJP0FoookJP03o`1coooonf[ooo]Z00kooo]Z00?o
^Ol0o`3o<oooDP000ooonfX02_l0:_oooo]ZoookJ_oonf[o?ol0oookJ_l0g?ooN?l0oookJ_l0oml9
oookJP04o`3o6olB0?oooo]Zooo:00Cooo]Z00Co0?WooookJ_oonf[oo`2C1_oonfX00ooJo`3ooo]Z
on7o0003oookJP03obH0oooonf[o8?l001Cooo]Z00?o<Ol0oookJ_l0oe/00ooonfX01on2o`3o0?n`
o`3o/Ol0<?oooo]Zo`3oCOl0j?l00_oonfX00ol60?oooo]Zoi;o0005oookJP03oa00ool06Ooooo]Z
00Cooo]Z00Goo`1AoookJ_oonf[ooo]Zo`2]o`02oookJP03ool0NOoonf[ooo]Z00Kooo]Z00?o0?mC
oookJ_oonfX00_oonfX01Ol0o`Sooo]Zo`3o7Ooonf[o0>7o00kooo]Z00?o0?ldoookJ_l0odh02Ooo
nfX00ol0R?oo0:WooookJP05oookJP03o`04oooonf[o0=Co02Wooo]Z000_oookJP03oiCo0?oonf[o
oo]Z00_ooo]Z0_oo5P03oookJP03oonB0?oonf[ooo]Z00Gooo]Z0_oo0?`<oookJP04oaP0oooonf[o
o`H0ool600?ooo]Z00Cojol0oookJ_oonf[ooo]Z0_oo0?H6oookJP03o`2Voooonf[ooo]Z00?ooo]Z
0_nX0?l8oookJP;oo`3i1?oonfX2o`1go`Cooo]Z3?oUo`02oom/0003oookJ_l0olco0?o<00go0?o<
1oooP@08oom/00SoiOl01Ol0Mol7onGo00;ooo]Z0onX0?l4oookJP?oiOl000?ooo]Zool0m_oo0?H0
0ooonfX2on_o00;ooo]Z0_oo1P000ooonf[oU?l0oiCo0003oookJPWoU?l000Cooo]ZoonB0?oo5P3o
oaH02?oonfX01?l0003oo`3Zo`000?l0000GoookJP03o`1coooonf[ooo]Z00gooo]Z00?o^Ol0oook
J_ooDP000ooonfX00ol0:_oooo]ZoookJP02oookJP05ocoo0?oonf[o0=coogSo0?nDo`002OoonfX0
1Ol0oa_o4P3ooookJ_oonf[oolX000Cooo]Z00Co0?WooookJ_oo09?oo`0C1_oonfX00ooJo`3ohOl0
oookJP03oookJP03obH0oolPo`3ooo]Z01?ooo]Z00?o<Ol0oookJ_m4o`001?oonfX00on2o`3o0?n`
o`0`o`02oookJP08o`3oCOl0j?oooo]ZoookJ_l60?oooo]Zool0mOnBo`04oookJP03oa00ool06Ooo
oo]Z00Cooo]Z00Goo`1AoaD0oooonf[ooo]Zo`2]o`02oookJP03ool0NOoonf[ooo]Z00Kooo]Z00Co
0?mCoookJ_oonf[ooo]Z0_nDo`02oookJP03odCo0?oonf[ooo]Z00kooo]Z00?o0?m>o`3o;_oonfX0
2?oonfX00ol0ZOoooo]ZoookJP05oookJP03o`3o[Ol0e?oooo]Z05Kooo]Z00?oo`3ZoookJ_oonfX0
2ooonfX2oolF00;ooo]Z00?ooi80oookJ_oonfX01OoonfX2ool0o0cooo]Z00Co603ooookJ_oo1P3o
o`H00ooonfX00oo[o`3ooo]ZoookJP02oookJP;oo`3f1_oonfX00ol0Y_oooo]ZoookJP02oookJP;o
Z03o2?oonfX3ool0n@?ooo]Z0_l0Mol:oookJP?o0?nJ00?ooo]Zoom/0?ooK0000_ooK0000ooonf[o
0?o<o`3oc00>o`3oc0Oooh402_ooK002o`3oVPCooo]Z1Ol0Mol2oookJPGoo`3i0_oonfX3ojP0o`?o
oo]Z0ol0Y_l2oookJP;oo`3f0_oonfX2on_o00;ooo]Z0_oo1P000ooonf[o603ooaP0o`06oookJP;o
o`3l1OoonfX00oooTP3ooo]ZoolF0008oookJP;o000000?oo`3Zo`000?oonfX05_oonfX00ol0Looo
oo]ZoookJP0>oookJP03okWo0?l0oc?ooe8000?ooo]Z00[o02[ooookJ_oonf[ooo]Zocoo0?oonf[o
0=coogSo0?oonf[o0?oO2OoonfX01Ol0oa_o4P3ooookJ_oonf[oolX000?ooo]Z00Co0?WooookJ_oo
nf[oo`2C1_oonfX00ooJo`3ooo]Zon7o0004oookJP03obH0oolPo`3ooo]Z01?ooo]Z00?o<Ol0oook
J_l0oe/01?oonfX00on2o`3o0?nao`0`o`02oookJP07o`3oCOoonf[ooo]Zo`H0oooonf[oo`3eoi;o
0004oookJP03oa00ool06Ooooo]Z00Gooo]Z00Coo`1AoookJ_oonf[o0:go0ooonfX00ooo07Wooo]Z
oookJP05oookJP03o`3oDooonf[ooo]Z00;ooo]Z00Go0?l8oookJ_oonf[o0?lMo`3Qo`0?oookJP03
o`3o=?l0odkooo]Z00Wooo]Z00?o0:WooookJ_oonfX01?oonfX00ol01?oooo]Zo`3Do`0ZoookJP00
<?oonfX00onDo`3ooo]ZoookJP0<oookJP04oolF0?oonf[ooo]ZoookJP;ooi801ooonfX2ool0o0_o
oo]Z00?o603ooookJ_oonfX00_oo1P02oookJP;ojol00ooonfX3ool0mPCooo]Z0ol0Y_l4oookJP;o
Z03o2?oonfX3ool0n@?ooo]Z4?oUo`02o`3oVPCoof`01ol0oiX;oom/00Oo0?nJ1OoUo`05o`1go`So
iOl01?oonfX2ojP0o`Cooo]Z0ooUo`02oookJP;oo`3f0ooonfX2on_o0005oiCo0?oo1P3oo`H0ool6
0?oonfX00_nDo`04oookJP_oU?l000?ooaH0oookJ_oonfX02?oonfX01?oo0>[o0000o`000?l0000F
oookJP03o`1coooonf[ooo]Z00gooo]Z00?o^Ol0oookJ_ooDP000ooonfX00ol0:_oooo]ZoookJP02
oookJP05ocoo0?oonf[o0=coogSo0?nDo`002_oonfX01Ol0oa_o08kooookJ_oonf[oolX000Cooo]Z
00?o0?Woool0Tooo01<01ooonfX00ooJo`3ohOl0oookJP02oookJP03obH0oolPo`3ooo]Z01Cooo]Z
00?o<Ol0oookJ_m4o`001?oonfX01_n2o`3o0?nao`0`oooonf[o0?m=o`3Xo`?ooo]Z00?o1P3oool0
mOnBo`001?oonfX00ooo06[o403oo`0Io`04oookJP03ool0DOlE0?oooo]Z00;ooo]Z00?o0:gooook
J_oo07T02OoonfX01?l0oe?ooo]ZoookJ_oonfX3oiCo0003odCo0?nDo`3ooo]Z00kooo]Z00?o0?ld
o`3oC_l0obh02?oonfX00ol0R?oo0:WooookJP06oookJP03o`04ool0e?oooo]Z05Oooo]Z00?oo`3Z
oookJ_oonfX03?oonfX00ooo5P3ooo]ZoookJP02oonB00Oooo]Z0_oo0?`;oookJP03oaP0oooonf[o
oo]Z00;oo`H00_oonfX2on_o00Cooo]Z0ooo0?H4oookJP?o0:Ko0ooonfX2ojP0o`Wooo]Z0_oo0?T3
oookJPGo07Oo2?oonfX5o`3oVPCoof`01ol0oiX;oom/00_o0?nJ0_oonfX5o`1go`?ooo]Z1?oo0?T5
oookJP;oZ03o0ooonfX3o`2Vo`?ooo]Z0_oo0?H2oookJP;ojol00_oonfX2ool60003oookJ_lH0?oo
603o00Oooo]Z00?oo`3loookJ_oonfX00ooonfX2oonB00;ooaH02OoonfX2ool0jP;o00005_oonfX0
0ol0Looooo]ZoookJP0>oookJP03okWo0?l0oc?ooe8000?ooo]Z00[o02[ooookJ_oonf[ooo]Zocoo
0?oonf[o0=cooookJ_mho`3o0?oO2OoonfX01Ol0oa_o4P3ooookJ_oonf[oolX000Cooo]Z00Co0?Wo
oookJ_oo09?oo`0C1_oonfX00ooJo`3ooo]Zon7o0003oookJP03obH0oolPo`3ooo]Z01Cooo]Z00?o
<Ol0oookJ_l0oe/00ooonfX01on2o`3o0?n`o`3o/Ol0<?oooo]Zo`3oCOl0j?l00_oonfX00ol60?oo
oo]Zoi;o0004oookJP03o`1Mool@0?oo01Wo00Gooo]Z00Goo`1AoookJ_oonf[ooo]Zo`2]o`02oook
JP03ool0NOoonf[ooo]Z00Kooo]Z00?o0?mCoookJ_oonfX00_oonfX01Ol0o`Sooo]Zo`3o7Ooonf[o
0>7o00kooo]Z00?o0?ldoookJ_l0odh02OoonfX00ol0R?oo0:WooookJP05oookJP03o`04oooonf[o
0=Co02[ooo]Z000aoookJP03oiCo0?oonf[ooo]Z00cooo]Z0_oo5P03oookJP03oonB0?oonf[ooo]Z
00Kooo]Z00?oo`3loookJ_oonfX02OoonfX01?lH0?oooo]ZoookJ_oonfX2ool600;ooo]Z0oo[o`03
oookJP;oo`3f1OoonfX3o`2Vo`?ooo]Z00?oZ03ooookJ_oonfX02?oonfX2ool0n@?ooo]Z3_oUo`06
oookJPOoof`04?oonfX2onGo00Go07Oo1?oonfX4onGo0003oookJ_oUo`3oiOl000?ooo]Z0onX0?l3
oookJP?oiOl00ooonfX2ool0mP?ooo]Z0_o[o`000onDo`3oo`H0ool60004oiCo00Gooo]Z2_nDo`00
0ooo5P3ooo]ZoookJP08oookJP;oo`3Z1?l0000EoookJP03o`1coooonf[ooo]Z00gooo]Z00?o^Ol0
oookJ_ooDP000ooonfX01?l0:_oooo]ZoookJ_oonfX2ocoo0004oookJ_l0g?oo?@3oogSo00[ooo]Z
00Go0?lKo`2>oooonf[ooo]Zooo:0004oookJP04o`3ioooo09?ooo]Zool04`Kooo]Z00?of_l0on7o
0?oonfX00ooonfX00olV0?oo8?l0oookJP0CoookJP03oc7o0?oonf[oA?l000Cooo]Z00?oP_l0oook
J_l0<?l00_oonfX01ol0odgooo]ZoookJ_oonf[o1P3ooookJ_nBo`001?oonfX00ooo06[o403oo`0I
o`05oookJP05ool0DOlE0?oooo]ZoookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP06oookJP03o`3o
Dooonf[ooo]Z00;ooo]Z0_nDo`000om4o`3oU?l0oiCo0002oiCo00gooo]Z00?o0?m>o`3o;_oonfX0
2?oonfX00ol0ZOoooo]ZoookJP05oookJP03o`04oooonf[o0=Co05Wooo]Z00?oo`3ZoookJ_oonfX0
3?oonfX2oolF00;ooo]Z00?ooi80oookJ_oonfX01_oonfX00ooo0?cooo]ZoookJP09oookJP04oaP0
oooonf[ooo]ZoookJP;oo`H00_oonfX3on_o00Cooo]Z0_oo0?H5oookJP?o0:Ko0_oonfX00onX0?oo
oo]ZoookJP08oookJP;oo`3i1_oonfX9o`1go`Sooo]Z1oooK00CoookJPGo07Oo0ooonfX5ool0n@Ko
oo]Z0onX0?l2oookJP?o0:Ko0ooonfX3ool0mP;ooo]Z0_o[o`001Ooonf[oo`H0ool60?oo1P3ooo]Z
00;o603o1ooonfX2ool0o0Cooo]Z0_ooTP02oolF00[ooo]Z00?oo`3Zo`000?l000000_l0000Eoook
JP03o`1coooonf[ooo]Z00kooo]Z00?o^Ol0o`3o<oooDP000ooonfX00ol0:_oooo]ZoookJP02ocoo
0005oookJ_l0g?oooo]ZogSo0?l0oml02_oonfX01?l0oa_ooo]ZoookJ_oobP04oookJP04o`3ioooo
nf[oo`2Cool04`Kooo]Z00?of_l0oookJ_oQo`000ooonfX00olV0?oooo]Zob3o000DoookJP03oc7o
0?oonf[o0?mK00Cooo]Z00KoP_l0o`3o/Ol0<?oooo]Zo`3oCOl0j?l2oookJP03o`H0oooonf[oT_l0
00Gooo]Z00?o403oo`0IoooonfX01?oonfX01Ooo057o5@3ooookJ_oonf[o0:go00?ooo]Z00?oo`1i
oookJ_oonfX01OoonfX00ol0oe?ooo]ZoookJP02oookJP05o`3o2?oonf[o0?lMoookJ_l0hOl03ooo
nfX00ol0ocCo0?m>oookJP09oookJP03o`2Yoooonf[ooo]Z00Cooo]Z00Co00CooookJ_oonf[o0=Co
:_oonfX003;ooo]Z00?oU?l0oookJ_oonfX03OoonfX01?oo5P3ooo]ZoookJ_oonfX2oonB00Oooo]Z
0_oo0?`:oookJP;o603o0ooonfX2ool600?ooo]Z0oo[o`02oookJP;oo`3f1_oonfX4o`2Vo`;oZ03o
2?oonfX2onGo00;oo`3i5OoUo`0DoookJPGo07Oo2OoUo`04oookJP?oiOl000?ooo]ZojP0oonX0?l0
0ooonfX3onGo00Cooo]Z0_oo0?H3oookJP;ojol000?ooo]Zool60?oo1P001OnDo`05oookJPSoU?l0
00?ooi80oolF0?oo5P002_oonfX00ooo0>[ooo]ZoookJP04o`0001Cooo]Z00?o07?ooookJ_oonfX0
3OoonfX00onio`3ooo]ZoomB0003oookJP05o`0Zoooonf[ooo]ZoookJ_loo`000_oonfX00ol0g?oo
?@3oogSo000:oookJP05o`3o6ol0S_oooo]ZoookJ_oobP001?oonfX01?l0nOooo`2CoookJ_oo01<6
oookJP03om[o0?oQo`3ooo]Z00?ooo]Z00?o9P3oob3o0?oonfX04ooonfX00olao`3ooo]ZodCo0004
oookJP03oh;o0?l0ok3o033o00;ooo]Z00?o0?m=o`3XoooonfX00_oonfX00ol60?ooo`3eoi;o0004
oookJP03oa00oooonf[o01Wo00Cooo]Z00Goo`1AoaD0oooonf[ooo]Zo`2]o`02oookJP03ool0NOoo
nf[ooo]Z00Oooo]Z00Co0?mCoookJ_oonf[ooo]Z0onDo`000om4o`3oU?l0oiCo0003oiCo00_ooo]Z
00?o0?ldo`3oC_l0obh02OoonfX00ol0ZOoooo]ZoookJP05oookJP03o`04ool0e?oooo]Z05[ooo]Z
00?oo`3ZoookJ_oonfX03OoonfX00ooo5P3ooo]ZoookJP02oonB00Oooo]Z0_oo0?`:oookJP;o603o
0ooonfX2ool600?ooo]Z0oo[o`03oookJP;oo`3f1_oonfX3o`2Vo`;oZ03o2_oonfX2ool0n@gooo]Z
2Ol0MolDoookJPGo07Oo1?oonfX4ool0n@Wooo]Z0_nX0?l2oookJP?o0:Ko1?oonfX2ool0mP?ooo]Z
0_o[o`000ooonf[oo`H0ool60003oookJP03oaP0oooonf[ooo]Z00Kooo]Z00?oo`3loookJ_oonfX0
0ooonfX00oooTP3ooo]ZoolF000:oookJP;oo`3Z00?ooo]Zo`000?l000000_l0000DoookJP03o`1c
oooonf[ooo]Z00kooo]Z00?o^Ol0o`3o<oooDP000ooonfX01?l0:_oooo]ZoookJ_loo`02oookJP04
o`3Loooonf[oN?l0o`3og`[ooo]Z00Co0?lKoookJ_oonf[oolX01?oonfX01?l0nOoooo]Zool0Tooo
01<6oookJP03om[o0?oonf[ohOl000Cooo]Z00?o9P3oob3o0?oonfX04ooonfX00olao`3ooo]Zo`3o
F`04oookJP03oh;o0?l0ok3o033o00;ooo]Z00Oo0?m=oookJ_oonf[ooo]Zo`H0oooonf[oT_l000Co
oo]Z00?o403oool0J_l06Ol01OoonfX01?oo057ooo]ZoookJ_l0[Ol3oookJP03ool0NOoonf[ooo]Z
00Kooo]Z00?o0?mCoookJ_oonfX00_oonfX01Ol0o`Sooo]Zo`3o7Ooonf[o0>7o00kooo]Z00?o0?ld
oookJ_l0odh02_oonfX00ol0ZOoooo]ZoookJP04oookJP03o`04oooonf[o0=Co02_ooo]Z000coook
JP03oiCo0?oonf[ooo]Z00gooo]Z0_oo5P03oookJP03oonB0?oonf[ooo]Z00Kooo]Z0_oo0?`:oook
JP03oaP0oooonf[ooo]Z00;ooo]Z0_oo1P04oookJP;ojol00_oonfX3ool0mPOooo]Z0_l0Y_l<onGo
00Koo`3i2?oUo`07oookJPWoiOl01_oonfX5o`1go`[oiOl01_oonfX3onGo00?oZ03o0_oonfX3onGo
00Gooo]Z0_oo0?H3oookJP;ojol00ooo1P08oiCo00?ooo]Z1_nDo`001?oonf[ooi80oonB0?oo5P0:
oookJP;oo`3Z0ooonfX4o`0001?ooo]Z00?o07?ooookJ_oonfX03OoonfX00onio`3ooo]ZoomB0003
oookJP05o`0Zoooonf[ooo]ZoookJ_loo`000ooonfX00olm0?ooN?l0oookJP09oookJP03oa80ool0
oa_ooo]Z00;ooo]Z00SoolX0oookJ_oonf[ooo]Zo`3ioooo09?ooo]Zool04`Kooo]Z00?of_l0oook
J_oQo`000ooonfX00olV0?ooQ03oob3o000DoookJP03oc7o0?oonf[oA?l000Cooo]Z00?oP_l0o`3o
/Ol0<?l00_oonfX01ol0odgooo]ZoookJ_oonf[o1P3ooookJ_nBo`001?oonfX00ooo06[o403oo`0I
o`05oookJP05ool0DOlE0?oooo]ZoookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP06oookJP03o`3o
Dooonf[ooo]Z00;ooo]Z0_nDo`000om4o`3oU?l0oiCo0004oiCo00_ooo]Z00?o0?m>o`3o;_oonfX0
2?oonfX00ol0ZOoooo]ZoookJP05oookJP03o`04oooonf[o0=Co05cooo]Z00?oo`3ZoookJ_oonfX0
3OoonfX2oolF00;ooo]Z00?ooi80oookJ_oonfX01_oonfX2ool0o0[ooo]Z00?o603ooookJ_oonfX0
0_oonfX2ool600Cooo]Z0_o[o`03oookJP?oo`3f1ooonfX00ol0Y_ooZ03oojP0o`02ojP0o`Sooo]Z
1ooo0?T?oookJPWo07Oo1_oonfX5o`1go`Cooo]Z1Ooo0?T:oookJP?oZ03o00Cooo]Zo`2Vool0Y_oo
0:Ko1OoonfX2ool0mP?ooo]Z0_o[o`000ooonf[oo`H0ool60003oookJP;o603o1ooonfX2ool0o0Co
oo]Z0_ooTP02oolF00[ooo]Z00Coo`3ZoookJ_oonf[ooo]Z1?l0000CoookJP03o`1coooonf[ooo]Z
00kooo]Z00?o^Ol0o`3o<oooDP000ooonfX01?l0:_oooo]ZoookJ_loo`03oookJP03o`3Loomho`3o
0?oO00[ooo]Z00Go0?lKoookJ_oonf[ooo]Zooo:0003oookJP04o`3ioooonf[oo`2Cool04`Kooo]Z
00Cof_l0oookJ_oonf[ohOl00ooonfX00olV0?oo8?l0oookJP0CoookJP04oc7o0?oonf[ooo]Zo`3o
F`Cooo]Z00KoP_l0o`3o/Ol0<?oooo]Zo`3oCOl0j?l2oookJP03o`H0oooonf[oT_l000Cooo]Z00?o
05gooa00ool06Ol01OoonfX01Ooo057o5@3ooookJ_oonf[o0:go00?ooo]Z00?oo`1ioookJ_oonfX0
1OoonfX00ol0oe?ooo]ZoookJP02oookJP05o`3o2?oonf[o0?lMoookJ_l0hOl03ooonfX00ol0ocCo
0?m>o`3o;P09oookJP03o`2Yoooonf[ooo]Z00Cooo]Z00Co00CooookJ_oonf[o0=Co:ooonfX003Co
oo]Z00?oU?l0oookJ_oonfX03_oonfX01Ooo5P3ooo]ZoookJ_oonf[ooi8000Wooo]Z0_oo0?`9oook
JP03oaP0oooonf[ooo]Z00?ooo]Z0_oo1P04oookJP?ojol00_oonfX2ool0mPSooo]Z00?o0:KoonGo
0?oUo`003?oUo`03oookJP03ool0nOoUo`3oiOl000CoiOl01Ooo0?T;oookJPCoiOl00_l0Mol2oook
JPgoiOl01?oonfX5ojP0o`GoiOl01_oonfX2ool0mP?ooo]Z0_o[o`02ool60003oookJ_nDo`3oU?l0
00SoU?l00_oonfX4oiCo00;ooo]Z0_ooTP000ooo5P3ooo]ZoookJP09oookJP03ool0j_oonf[ooo]Z
00?ooo]Z1?l0000BoookJP03o`1coooonf[ooo]Z00kooo]Z00?o^Ol0oomB0?oonfX00ooonfX01?l0
:_oooo]ZoookJ_loo`03oookJP03o`3Loomho`3ooo]Z00[ooo]Z00Go0?lKoookJ_oonf[ooo]Zooo:
0004oookJP04ool0Tooonf[ooo]Zool04`Kooo]Z00?of_l0on7o0?oonfX00ooonfX00olV0?oo8?l0
oookJP0CoookJP03oc7o0?oonf[oA?l000Cooo]Z00?oP_l0o`3o/?l0<?l00_oonfX00ol0odgooo]Z
oookJP02oookJP03o`H0oooo0?GoT_l000?ooo]Z00Co05gooa00oooonf[o01Wo1?oonfX01Ooo057o
5@3ooookJ_oonf[o0:go00;ooo]Z00?oo`1ioookJ_oonfX01ooonfX01Ol0oe?ooo]ZoookJ_oonf[o
0?l800;oU?l000?oA?l0oiCo0?nDo`000onDo`0;oookJP03o`3o=?l0odko0?l^00Wooo]Z00?o0:Wo
oookJ_oonfX01OoonfX00ol01?oo0=CooookJP1MoookJP03ool0j_oonf[ooo]Z00kooo]Z00CooaH0
oookJ_oonf[ooi802OoonfX2ool0o0Wooo]Z00?o603ooookJ_oonfX00ooonfX2ool600Cooo]Z0oo[
o`03oookJP;oo`3f2?oonfX2o`2Vo`KoZ03o2OoonfX<ool0n@cooo]Z1_l0Mol5oookJPCoo`3i2_oo
nfX5ojP0o`04oookJ_l0Y_oo0:Koo`2Vo`Kooo]Z0_oo0?H3oookJP;ojol000?ooo]Zool60?oo1P00
0ooonfX2oaP0o`Sooo]Z00?oo`3loookJ_oonfX00_oonfX2oonB00;ooaH02ooonfX00ooo0>[ooo]Z
oookJP02oookJPCo00004_oonfX00ol0Looooo]ZoookJP0>oookJP03okWo0?l0oc?ooe8000?ooo]Z
00Co02[ooookJ_oonf[o?ol00ooonfX00ol0g?oo?@3oogSo000:oookJP05o`2>ool0oa_ooo]Zoook
J_oobP001?oonfX01?l0nOooo`2CoookJ_oo01<6oookJP03om[o0?oonf[ohOl000?ooo]Z00?o9P3o
oh@0oolPo`005?oonfX00olao`3ooo]Zo`3oF`04oookJP03oh;o0?l0ok3o033o00;ooo]Z00Oo0?m=
oookJ_oonf[ooo]Zo`H0oooo0?GoT_l000Cooo]Z00?o403oool0J_l06Ol01OoonfX01?oo057ooo]Z
oookJ_l0[Ol3oookJP03ool0NOoonf[ooo]Z00Kooo]Z00?o0?mCoookJ_oonfX00_oonfX01Ol0o`So
oo]Zo`3o7Ooonf[o0>7o00oooo]Z00?o0?ldo`3oC_oonfX02OoonfX00ol0ZOoooo]ZoookJP04oook
JP03o`04oooonf[o0=Co02cooo]Z000eoookJP03oiCo0?oonf[ooo]Z00kooo]Z0_oo5P02oookJP;o
oi802OoonfX00ooo0?cooo]ZoookJP07oookJP03oaP0oooonf[ooo]Z00Cooo]Z0_oo1P05oookJP;o
jol00_oonfX3ool0mPWooo]Z2ooUo`07oookJP?oiOl01OoonfX;ool0n@Kooo]Z3ooUo`04ojP0o`So
iOl01OoonfX3ool0mP?ooo]Z0_o[o`02ool600;ooo]Z2onDo`000ooo0?coU?l0oiCo0004oookJP03
oonB0?oo5P3ooaH000_ooo]Z00?oo`3ZoookJ_oonfX01?oonfX4o`00017ooo]Z00?o07?ooookJ_oo
nfX03_oonfX00onio`3o0?lcoomB0003oookJP04o`0Zoooonf[ooo]Zocoo00?ooo]Z00?o0=cooiCo
0?mho`002_oonfX01Ol0oa_ooo]ZoookJ_oonf[oolX000Cooo]Z00Co0?Woool0Tooonf[oo`0C1_oo
nfX00ooJo`3ohOl0oookJP03oookJP03obH0oolPo`3ooo]Z01?ooo]Z00?o<Ol0oookJ_m4o`001Ooo
nfX01_n2o`3o033ooookJ_oonf[o0?m=o`3Xo`?ooo]Z00?o1P3ooookJ_nBo`001?oonfX00ol@0?oo
oo]Zo`0Io`05oookJP07ool0DOlE0?oooo]ZoookJ_l0[Ooooo]Zool0N@09oookJP03o`3oDooonf[o
oo]Z00;ooo]Z00?o0?l8oiCo0?m4o`001OnDo`0<oookJP03o`3oC_l0obkooo]Z00Sooo]Z00?o0:Wo
oookJ_oonfX01OoonfX00ol01?oooo]Zo`3Do`1OoookJP03ool0j_oonf[ooo]Z00kooo]Z0_oo5P00
0ooonf[ooi80oonB0009oookJP03ool0o?oonf[ooo]Z00Oooo]Z00?o603ooookJ_oonfX01?oonfX3
ool600Cooo]Z0oo[o`02oookJP?oo`3f2OoonfX3o`2Vo`03oookJ_nX0?ooZ03o00CoZ03o3ooonfX;
ool0n@Oooo]Z1Ooo0?T7oookJPOoZ03o0ooonfX3o`2Vo`Kooo]Z0ooo0?H3oookJP;ojol00ooo1P03
oookJP;o603o2?oonfX2ool0o0Cooo]Z00?ooi80oolF0?oo5P002ooonfX2ool0jPGooo]Z1?l0000A
oookJP03o`1coooonf[ooo]Z00kooo]Z00?o^Ol0o`3o<oooDP000ooonfX01?l0:_oooo]ZoookJ_lo
o`03oookJP03o`3Loolm0?ooN?l000[ooo]Z00Go08koo`3o6ooonf[ooo]Zooo:0004oookJP04o`3i
oooo09?ooo]Zool04`Kooo]Z00?of_l0oookJ_oQo`001?oonfX00olV0?oo8?l0oookJP0CoookJP03
oc7o0?oonf[o0?mK00Cooo]Z00?oP_l0o`3o/?l0<?l00_oonfX01ol0odgooo]ZoookJ_oonf[o1P3o
oookJ_nBo`001?oonfX00ol@0?ooo`1Zo`0Io`05oookJP05ool0DOlE0?oooo]ZoookJ_l0[Ol00_oo
nfX00ooo07Wooo]ZoookJP06oookJP03o`3oDooonf[ooo]Z00;ooo]Z00Go0?l8oookJ_l0oagooo]Z
o`3Qo`0?oookJP03o`3o=?l0odko0?l^00Wooo]Z00?o0:WooookJ_oonfX01?oonfX01?l01?oooo]Z
oookJ_l0e?l/oookJP00=_oonfX00onDo`3ooo]ZoookJP0?oookJP05oolF0?oonf[ooo]ZoookJ_oo
TP002OoonfX2ool0o0Sooo]Z0_lH0?l6oookJP;oo`H01OoonfX3on_o00;ooo]Z0_oo0?H9oookJPSo
iOl000?ooo]ZonGo0?oUo`000ooUo`04oookJP03onGo0?oonf[ooo]Z00kooo]Z1Ooo0?T@onGo0003
oookJ_oUo`3oiOl000WoiOl01Ooo0?H3oookJP;ojol00ooo1P03oookJPWoU?l00ooo0?`5oookJP;o
oi8000?ooaH0oookJ_oonfX02OoonfX2ool0jPOooo]Z1?l0000@oookJP03o`1coooonf[ooo]Z00ko
oo]Z00?o^Ol0o`3o<oooDP000ooonfX01?l0:_oooo]ZoookJ_loo`02oookJP;o0=co00?oU?l0ogSo
0?oonfX02OoonfX01Ol0oa_ooo]ZoookJ_oonf[oolX000Cooo]Z00Co0?Woool0Tooonf[oo`0C1_oo
nfX00ooJo`3ohOl0oookJP03oookJP03obH0oon40?oo8?l001?ooo]Z00?o<Ol0oookJ_m4o`001Ooo
nfX00on2o`3o0?n`o`0`o`02oookJP07o`3oCOoonf[ooo]ZoookJ_l60?oooo]Zoi;o0004oookJP04
o`1Mool@0?oooo]Zo`0Io`Cooo]Z00Goo`1AoaD0oooonf[ooo]Zo`2]o`02oookJP03ool0NOoonf[o
oo]Z00Kooo]Z00?o0?mCoookJ_oonfX00_oonfX00ol0o`Sooo]ZodCo0005oiCo00gooo]Z00?o0?m>
o`3o;_oonfX02?oonfX00ol0ZOoooo]ZoookJP04oookJP04o`04oooonf[ooo]Zo`3Dof3ooo]Z00?o
o`3ZoookJ_oonfX03ooonfX01?oo5P3ooo]ZoookJ_ooTP09oookJP;oo`3l2?oonfX2oaP0o`Oooo]Z
0_oo1P05oookJP?ojol00_oonfX2ool0mP[ooo]Z1?l0Y_l3oookJPGoZ03o5OoonfX7ool0n@Cooo]Z
2?nX0?l7oookJP?o0:Ko1?oonfX5ool0mP?ooo]Z0oo[o`02ool600Cooo]Z0_lH0?l7oookJP?oo`3l
1?oonfX2oonB0003oolF0?oonf[ooo]Z00[ooo]Z00?oo`3ZoookJ_oonfX01OoonfX4o`00013ooo]Z
00?o07?ooookJ_oonfX03_oonfX00onio`3o0?lcoomB0003oookJP04o`0Zoooonf[ooo]Zocoo00;o
oo]Z0_l0g?l00olm0?ooN?l0oookJP09oookJP03o`2>ool0oa_ooo]Z00;ooo]Z00SoolX0oookJ_oo
nf[ooo]Zo`3ioooo09?ooo]Zool04`Kooo]Z00?of_l0oookJ_oQo`001?oonfX00olV0?ooQ03oob3o
000CoookJP03oc7o0?oonf[o0?mK00Gooo]Z00?oP_l0o`3o/?l0<?l00_oonfX01_l0odgooo]Zoook
J_l60?oooo]Zoi;o00Gooo]Z00?o403ooookJ_l06Ol01OoonfX01?oo057ooo]ZoookJ_l0[Ol3oook
JP03ool0NOoonf[ooo]Z00Gooo]Z00?o0?mCoookJ_oonfX00ooonfX01Ol0o`So0?lMoookJ_oonf[o
0>7o00oooo]Z00?o0?ldo`3oC_oonfX02?oonfX00ol0R?oo0:WooookJP04oookJP05o`04oooonf[o
oo]ZoookJ_l0e?l0;?oonfX003Oooo]Z00?oU?l0oookJ_oonfX03ooonfX2oolF00;ooo]Z0_ooTP09
oookJP;oo`3l2?oonfX3oaP0o`Gooo]Z0_oo1P06oookJP?ojol000Cooo]Zool0m_oo0?Koo`3f2?oo
nfX6onGo00Kooo]Z1_oUo`0CoookJPOoZ03o2OoonfX>onGo00?ooo]Z1?o[o`02ool600Gooo]Z1onD
o`000ooonf[oo`3lool0o006oookJP;ooi8000?ooaH0oookJ_oonfX02_oonfX00ooo0>[ooo]Zoook
JP07oookJPCo00003ooonfX00ol0Looooo]ZoookJP0>oookJP03okWo0?l0oc?ooe8000?ooo]Z00Co
02[ooookJ_oonf[o?ol00_oonfX01?l0g?oooo]ZoiCo0?mho`0:oookJP05oa80ool0oa_ooo]Zoook
J_oobP001?oonfX01?l0nOooo`2CoookJ_oo01<7oookJP03om[o0?oonf[ooo]Z00?ooo]Z00?o9P3o
ob3o0?oonfX04ooonfX00olao`3ooo]ZodCo0004oookJP03oh;o0?l0ok3o033o00;ooo]Z00?o0?m=
oookJ_oonfX00_oonfX00ol60?ooo`3eoi;o0003oookJP04o`1Mool@0?oooo]Zo`0Io`Cooo]Z00Go
o`1AoookJ_lE0?oooo]Zo`2]o`02oookJP03ool0NOoonf[ooo]Z00Oooo]Z00?o0?mCoookJ_oonfX0
0_oonfX00ol0o`SoU?l0odCo0004oiCo00gooo]Z00?o0?m>o`3o;_oonfX02?oonfX00ol0ZOoooo]Z
oookJP05oookJP03o`04oooonf[o0=Co06;ooo]Z00?oo`3ZoookJ_oonfX03ooonfX2oolF0003oook
J_ooTP3ooi8000Wooo]Z0_oo0?`8oookJP?o603o1_oonfX2ool600Kooo]Z0_o[o`02oookJP?oo`3f
2ooonfX3o`2Vo`Gooo]Z1_nX0?lCoookJPOoZ03o3?oonfX3o`2Vo`;ooo]Z1Ooo0?H4oookJPCojol0
00?ooo]Zool60?oo1P001OoonfX00olH0?oooo]ZoookJP05oookJP;oo`3l1OoonfX2oonB00;ooaH0
2ooonfX2ool0jPSooo]Z1?l0000?oookJP03o`1coooonf[ooo]Z00kooo]Z00?o^Ol0o`3o<oooDP00
0ooonfX01?l0:_oooo]ZoookJ_loo`02oookJP04o`3Loooonf[o?@3oogSo00[ooo]Z00?o08koo`3o
6ooonfX00_oonfX01_oobP3ooo]ZoookJ_oonf[o0?Woool0T`;ooo]Z00?oo`0CoookJ_oonfX01?oo
nfX00ooJo`3ohOl0oookJP04oookJP03obH0oolPo`3ooo]Z01;ooo]Z00Co<Ol0oookJ_oonf[o0?mK
1?oonfX00on2o`3o0?n`o`0`o`02oookJP07o`3oCOoonf[ooo]ZoookJ_l60?oooo]Zoi;o0004oook
JP03oa00oooo06[o01Wo00Gooo]Z00Coo`1AoaD0oooonf[o0:go0ooonfX00ooo07Wooo]ZoookJP06
oookJP03o`3oDooonf[ooo]Z00;ooo]Z00Go0?l8oookJ_l0oagooo]Zo`3Qo`0?oookJP03o`3o=?l0
odko0?l^00Wooo]Z00?o0:WooookJ_oonfX01?oonfX01?l01?oooo]ZoookJ_l0e?l]oookJP00>?oo
nfX00onDo`3ooo]ZoookJP0@oookJP05oolF0?oonf[ooo]ZoookJ_ooTP002_oonfX2ool0o0Wooo]Z
0olH0?l4oookJP;oo`H01ooonfX2on_o00;ooo]Z0_oo0?H9oookJP?oiOl01?l0Y_l8oookJPKoiOl0
1_oonfX7ojP0o`oooo]Z3OoUo`05on_o00;ooo]Z0_oo1P06oookJPGoU?l00_oonfX2ool0o0Oooo]Z
00?ooi80oolF0?oo5P003?oonfX00ooo0>[ooo]ZoookJP08oookJPCo00003_oonfX00ol0Looooo]Z
oookJP0>oookJP03okWo0?l0oc?ooe8000?ooo]Z00Co02[ooookJ_oonf[o?ol00_oonfX01?l0g?oo
oo]ZogSo0?mho`0:oookJP05oa80ool0oa_ooo]ZoookJ_oobP001OoonfX01?oo09?ooo]ZoookJ_oo
01<6oookJP03om[o0?oonf[ooo]Z00?ooo]Z00?o9P3oodCo0?m4o`004ooonfX00olao`3ooo]ZodCo
0005oookJP03oh;o0?l0<?oooo]Z00;ooo]Z00Oo0?m=oookJ_oonf[ooo]Zo`H0oooonf[oT_l000Co
oo]Z00Co403oool0J_oonf[o01Wo1?oonfX01ooo057o5@3ooookJ_oonf[o0:gooookJ_oo07T02Ooo
nfX00ol0oe?ooo]ZoookJP02oookJP03o`3o2?oonf[oA?l000CoU?l03_oonfX00ol0odko0?l^oook
JP07oookJP03o`28ool0ZOoooo]Z00Gooo]Z00Co00CooookJ_oonf[o0=CoHooonfX00ooo0>[ooo]Z
oookJP0@oookJP04oolF0?oonf[ooo]ZoonB00[ooo]Z0_oo0?`9oookJP?o603o1OoonfX2ool600Ko
oo]Z0oo[o`02oookJP;oo`3f3?oonfX4o`2Vo`Oooo]Z1_nX0?l6oookJPOoZ03o4?oonfX3o`2Vo`03
oookJ_oo0?Koo`3f00;oo`3f1OoonfX4on_o00?ooo]Z0_oo1P05oookJP;o603o1OoonfX3ool0o0Ko
oo]Z00?ooi80oolF0?oo5P003?oonfX00ooo0>[ooo]ZoookJP08oookJPCo00003_oonfX00ol0Looo
oo]ZoookJP0>oookJP03okWo0?l0oc?ooe8000?ooo]Z00Co02[ooookJ_oonf[o?ol00_oonfX01?l0
g?oooo]ZogSo0?mho`0:oookJP03o`2>oolB0?oo0?lK00;ooo]Z00?oolX0oookJ_oonfX00_oonfX0
1?l0nOooo`2CoookJ_oo01<6oookJP03om[o0?oQo`3ooo]Z00Cooo]Z00?o9P3oob3o0?oonfX04ooo
nfX00olao`3ooo]Zo`3oF`05oookJP06oh;o0?l0<?oooo]ZoookJ_l0j?oo0?m=0_oonfX00ol60?oo
oo]Zoi;o0004oookJP04oa00oooo06[ooo]Zo`0Io`Gooo]Z00Coo`1AoookJ_oonf[o0:go0_oonfX0
0ooo07Wooo]ZoookJP06oookJP03o`3oDooonf[ooo]Z00?ooo]Z00Go0?l8o`3o7Ooonf[ooo]Zo`3Q
o`0?oookJP03o`3o=?l0odkooo]Z00Sooo]Z00?o08Soo`2YoooonfX01?oonfX01Ol01?oooo]Zoook
J_oonf[o0=Co02gooo]Z000ioookJP03oiCo0?oonf[ooo]Z013ooo]Z0_oo5P02oookJP;ooi802_oo
nfX00ooo0?cooo]ZoookJP09oookJP?o603o0ooonfX2ool600Oooo]Z0oo[o`000ooonf[oo`3fool0
mP09oookJP03onGo0?oonf[ooo]Z00;ooo]Z0ol0Y_l;oookJP?oiOl00onX0?l3oookJQ;o0:Ko2?oU
o`02oookJPCojol01?oonfX3ool600Gooo]Z0_lH0?l2oiCo00?ooo]Z0ooo0?`7oookJP;ooi8000?o
oaH0oookJ_oonfX02_oonfX2ool0jP_ooo]Z1?l0000<oookJP;o07?o4?oonfX00onio`3o0?lcoomB
0003oookJP04o`0Zoooonf[ooo]Zocoo00;ooo]Z00?o0=cooookJ_mho`002ooonfX01OlB0?oo0?lK
oookJ_oonf[oolX000Gooo]Z00Coo`2CoookJ_oonf[oo`0C1_oonfX00ooJo`3ooo]ZoookJP03oook
JP03obH0oooonf[oA?l001?ooo]Z00?o<Ol0oookJ_m4o`001OoonfX00on2o`3ooo]Zo`0`o`02oook
JP03o`3oCOoonf[ooo]Z00;ooo]Z00?o1P3oool0mOnBo`000ooonfX01?l0GOoo403ooookJ_l06Ol4
oookJP05ool0DOoonf[o5@3ooookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP07oookJP03o`3oDooo
nf[ooo]Z00;ooo]Z00?o0?l8odCo0?nDo`001?nDo`0=oookJP03o`3oC_l0obkooo]Z00Sooo]Z00?o
0:WooookJ_oonfX01OoonfX00ol01?oooo]Zo`3Do`1UoookJP03ool0j_oonf[ooo]Z013ooo]Z0_oo
5P000ooonf[ooi80oonB000:oookJP03ool0o?oonf[ooo]Z00Wooo]Z0olH0?l4oookJP;oo`H01ooo
nfX3on_o0003oookJ_oo0?Koo`3f00kooo]Z0ol0Y_l:oookJPKoZ03o0ooonfXDo`2Vo`Coo`3f1Ooo
nfX4on_o00Cooo]Z0ooo1P04oookJP?o603o1OoonfX2ool0o0Oooo]Z0_ooTP000ooo5P3ooo]Zoook
JP0;oookJP03ool0j_oonf[ooo]Z00Wooo]Z1?l0000<oookJP;o07?o4?oonfX00onio`3o0?lcoomB
0003oookJP04o`0Zoooonf[ooo]Zocoo00;ooo]Z00Co0=cooookJ_mho`3o0?oO2_oonfX00ol0S_oo
4P3oo`3o6`02oookJP03ooo:0?oonf[ooo]Z00;ooo]Z00Co0?Woool0Tooonf[oo`0C1_oonfX00ooJ
o`3ohOl0oookJP04oookJP03obH0oooonf[o8?l001?ooo]Z00?o<Ol0oookJ_l0oe/01OoonfX01_n2
o`3o0?nao`0`oooonf[o0>Soo`3oC@?ooo]Z00?o1P3ooookJ_nBo`001?oonfX00ol@0?ooo`1Zo`0I
o`05oookJP04ool0DOlE0?oooo]Zo`2]o`?ooo]Z00?oo`1ioookJ_oonfX01_oonfX00ol0oe?ooo]Z
oookJP02oookJP03o`3o2?l0oagooo]Z00;ooo]Z00?o0>7ooookJ_oonfX03?oonfX00ol0ocCo0?m>
o`3o;P09oookJP03o`2Yoooonf[ooo]Z00Cooo]Z00Co00CooookJ_oonf[o0=Co;_oonfX003[ooo]Z
00?oU?l0oookJ_oonfX04OoonfX2oolF00;ooo]Z00?ooi80oookJ_oonfX02?oonfX2ool0o0cooo]Z
0_lH0?l3oookJP;oo`H02?oonfX2on_o0004oookJ_oo0?Koo`3fool0mPkooo]Z00?o0:KoonGo0?oU
o`000_oUo`0?o`2Vo`oooo]Z1?oo0?H5oookJPCojol01_oonfX2ool600Cooo]Z1?lH0?l5oookJP;o
o`3l2?oonfX2oonB0003oolF0?oonf[ooo]Z00_ooo]Z00?oo`3ZoookJ_oonfX02ooonfX4o`0000_o
oo]Z00?o07?ooookJ_oonfX03ooonfX00onio`3o0?lcoomB0003oookJP04o`0Zoooonf[ooo]Zocoo
00;ooo]Z00?o0=cooookJ_mho`002ooonfX01OlB0?oo0?lKoookJ_oonf[oolX000Gooo]Z00Coo`2C
oookJ_oonf[oo`0C1_oonfX00ooJo`3ohOl0oookJP04oookJP03obH0oom4o`3ooo]Z01;ooo]Z00Co
<Ol0oookJ_oonf[oA?l01OoonfX01_n2o`3o033ooookJ_oonf[o0>Soo`3oC@?ooo]Z00?o1P3ooook
J_nBo`001?oonfX01?l@0?oooo]ZoookJ_l06Ol4oookJP04ool0DOlE0?oooo]Zo`2]o`;ooo]Z00?o
o`1ioookJ_oonfX01ooonfX00ol0oe?ooo]ZoookJP02oookJP03o`3o2?oonf[oA?l000CoU?l03Ooo
nfX00ol0ocCo0?m>o`3o;P08oookJP03o`28ool0ZOoooo]Z00Gooo]Z00Co00CooookJ_oonf[o0=Co
I_oonfX00ooo0>[ooo]ZoookJP0AoookJP04oolF0?oonf[ooo]ZoonB00[ooo]Z0_oo0?`<oookJP;o
603o1?oonfX2ool600Sooo]Z0_o[o`001?oonf[oo`3fool0m_oo0?H>oookJQ?o0:Ko3ooonfX4ool0
mPGooo]Z1Oo[o`06oookJP;oo`H00ooonfX4oaP0o`Kooo]Z0_oo0?`7oookJP;ooi8000?ooaH0oook
J_oonfX02ooonfX2ool0jPcooo]Z1?l0000;oookJP03o`1coooonf[ooo]Z00oooo]Z00?o^Ol0o`3o
<oooDP001?oonfX00ol0:_oooo]Zocoo0002oookJP04o`3Loooonf[oN?l0o`3og`[ooo]Z00?o08ko
o`3o6ol0oa/00_oonfX00ooobP3ooo]ZoookJP02oookJP04o`3ioooo09?ooo]Zool04`Kooo]Z00?o
f_l0on7o0?oonfX01OoonfX00olV0?oo8?l0oookJP0BoookJP04oc7o0?oonf[ooo]Zo`3oF`Cooo]Z
00?o0?n`oh;o0?l0<?l00_oonfX01ol0odgooo]ZoookJ_oonf[o1P3ooookJ_nBo`001?oonfX01?l@
0?ooo`1ZoookJ_l06Ol4oookJP04ool0DOlE0?oooo]Zo`2]o`?ooo]Z00?oo`1ioookJ_oonfX01_oo
nfX00ol0oe?ooo]ZoookJP03oookJP05o`3o2?l0oagooo]ZoookJ_l0hOl03ooonfX00ol0ocCo0?m>
oookJP08oookJP03o`28ool0ZOoooo]Z00Cooo]Z00Go00CooookJ_oonf[ooo]Zo`3Do`0^oookJP00
>ooonfX00onDo`3ooo]ZoookJP0BoookJP04oolF0?oonf[ooo]ZoonB00_ooo]Z0_oo0?`<oookJP?o
603o0_oonfX2ool600Sooo]Z0oo[o`000ooonf[oo`3fool0mP08ool0mPWoiOl06OoonfX5ool0mPGo
oo]Z1?o[o`06oookJPCoo`H00_oonfX4oaP0o`Oooo]Z0_oo0?`9oookJP03oonB0?oo5P3ooaH000go
oo]Z00?oo`3ZoookJ_oonfX03?oonfX5o`0000Sooo]Z0_l0LolAoookJP03okWo0?l0oc?ooe8000?o
oo]Z00Co02[ooookJ_oonf[o?ol00_oonfX01?l0g?oooo]ZogSo0?lm0?l:oookJP05oa80ool0oa_o
oo]ZoookJ_oobP001OoonfX01Ooo09?ooo]ZoookJ_oonf[oo`0C00Kooo]Z00?of_l0oookJ_oonfX0
0ooonfX00olV0?ooA?l0oookJP0CoookJP03oc7o0?oonf[oA?l000Gooo]Z00?oP_l0o`0`ool0ok40
0_oonfX00ol0odgooo]ZoookJP02oookJP03o`H0oonBo`3ooo]Z00?ooo]Z00Co403oool0J_oonf[o
01Wo1?oonfX01ooo057ooo]ZoaD0oooonf[o0:gooookJ_oo07T02_oonfX00ol0oe?ooo]ZoookJP02
oookJP03o`3o2?m4o`3ooo]Z00?oU?l03_oonfX00ol0ocCo0?m>o`3o;P08oookJP03o`2Yoooonf[o
oo]Z00Gooo]Z00?o00CooookJ_l0e?l0J?oonfX00ooo0>[ooo]ZoookJP0AoookJP04oolF0?oonf[o
oo]ZoonB00_ooo]Z0_oo0?`<oookJP?o603o0ooonfX2ool600Sooo]Z0oo[o`000ooonf[oo`3fool0
mP08ool0mR7ooo]Z1Ooo0?H5oookJPCojol01ooonfX4ool60003oookJ_lH0?oo603o00;o603o1ooo
nfX3ool0o0Sooo]Z00?ooi80oolF0?oo5P003OoonfX00ooo0>[ooo]ZoookJP0<oookJPGo00002?oo
nfX2o`1coa7ooo]Z00?o^Ol0o`3o<oooDP001?oonfX00ol0:_oooo]Zocoo0002oookJP04o`3Loooo
nf[oN?l0o`3og`[ooo]Z00?o08koo`3o6ooonfX00_oonfX00ooobP3ooo]ZoookJP02oookJP05o`3i
oooo09?ooo]ZoookJ_oo01<01_oonfX00ooJo`3ooo]ZoookJP04oookJP03obH0oolPo`3ooo]Z01;o
oo]Z00Co<Ol0oookJ_oonf[o0?mK1OoonfX01_n2o`3o033ooookJ_oonf[o0>Soo`3oC@?ooo]Z00?o
1P3ooi;o0?oonfX00ooonfX01?l@0?oo05goool0J_l06Ol5oookJP04ool0DOlE0?oooo]Zo`2]o`;o
oo]Z00?oo`1ioookJ_oonfX01ooonfX00ol0oe?ooo]ZoookJP02oookJP03o`3o2?l0oagooo]Z00;o
oo]Z00?o0>7ooookJ_oonfX03?oonfX00ol0ocCooo]Zo`3oCP08oookJP03o`28ool0ZOoooo]Z00Go
oo]Z00Co00CooookJ_oonf[o0=Co;ooonfX003cooo]Z00?oU?l0oookJ_oonfX04_oonfX2oolF0003
oookJ_ooTP3ooi8000_ooo]Z0_oo0?`=oookJP?o603o00?ooo]Zool60?oo1P002OoonfX3on_o00?o
oo]Z3_oUo`0:ool0mP[ooo]Z1Ooo0?H6oookJPCojol01OoonfX5ool600?ooo]Z0olH0?l8oookJP?o
o`3l2OoonfX2oonB0003oolF0?oonf[ooo]Z00_ooo]Z0_oo0>X?oookJPCo00002?oonfX00ol0Looo
oo]ZoookJP0@oookJP03okWo0?l0oc?ooe8000?ooo]Z00Co02[ooookJ_oonf[o?ol00_oonfX01?l0
g?oooo]ZogSo0?lm0?l:oookJP05oa80ool0oa_ooo]ZoookJ_oobP001OoonfX01Ooo09?ooo]Zoook
J_oonf[oo`0C00Kooo]Z00?of_l0oookJ_oonfX00ooonfX00olV0?ooA?l0oookJP0CoookJP03oc7o
0?oonf[oA?l000Gooo]Z00?o0?n`oh;o0?l0<?l00_oonfX00ol0odgooo]ZoookJP02oookJP03o`H0
oooo0?GoT_l000?ooo]Z00Co05gooa00oooonf[o01Wo1OoonfX01?oo057o5@3ooookJ_l0[Ol2oook
JP03ool0NOoonf[ooo]Z00Oooo]Z00?o0?mCoookJ_oonfX00_oonfX00ol0o`SoA?l0oookJP03oiCo
00kooo]Z00?o0?ldo`3oC_l0obh02?oonfX00ol0R?oo0:WooookJP05oookJP04o`04oooonf[ooo]Z
o`3DofWooo]Z00?oo`3ZoookJ_oonfX04OoonfX2oolF0003oookJ_ooTP3ooi8000_ooo]Z0_oo0?`=
oookJP?o603o0_oonfX2ool600Wooo]Z0oo[o`08oookJQ;oo`3f2_oonfX5ool0mPKooo]Z1?o[o`06
oookJPGoo`H00_oonfX3oaP0o`Wooo]Z0_oo0?`9oookJP;ooi8000?ooaH0oookJ_oonfX02ooonfX2
ool0jPoooo]Z1?l00008oookJP03o`1coooonf[ooo]Z013ooo]Z00?o^Ol0o`3o<oooDP001?oonfX0
0ol0:_oooo]Zocoo0002oookJP04o`3Loooonf[oN?l0o`3og`[ooo]Z00?o08koo`3o6ooonfX00_oo
nfX00ooobP3ooo]ZoookJP02oookJP05o`3ioooo09?ooo]ZoookJ_oo01<01_oonfX00ooJo`3ohOl0
oookJP04oookJP03obH0oolPo`3ooo]Z01;ooo]Z00Co<Ol0oookJ_oonf[o0?mK1OoonfX01_l0ok3o
P_l0o`0`oooonf[o0>Soo`3oC@?ooo]Z00?o1P3ooookJ_nBo`001?oonfX00ol@0?ooo`1Zo`0Io`05
oookJP04ool0DOlE0?oooo]Zo`2]o`?ooo]Z00?oo`1ioookJ_oonfX01_oonfX00ol0oe?ooo]Zoook
JP03oookJP05o`3o7Ooonf[ooo]ZoookJ_l0hOl03_oonfX00ol0ocCooo]Zo`3oCP09oookJP03o`28
ool0ZOoooo]Z00Cooo]Z00Go00CooookJ_oonf[ooo]Zo`3Do`0_oookJP00?OoonfX00onDo`3ooo]Z
oookJP0CoookJP04oolF0?oonf[ooo]ZoonB00cooo]Z00?oo`3loookJ_oonfX03OoonfX3oaP0o`;o
o`H02_oonfXAonGo00[ooo]Z2_oo0?H6oookJPGojol00ooonfX6ool600Cooo]Z1?lH0?l9oookJP;o
o`3l2_oonfX2oonB0003oolF0?oonf[ooo]Z00cooo]Z00?oo`3ZoookJ_oonfX03ooonfX4o`0000Oo
oo]Z00?o07?ooookJ_oonfX04?oonfX00onio`3o0?lcoomB0003oookJP05o`0Zoooonf[ooo]Zocoo
0?oonfX00_l0g?l00ooonf[oN?l0ocd0o`0:oookJP05o`2>ool0oa_ooo]ZoookJ_oobP001_oonfX0
1?oo09?ooo]ZoookJ_oo01<6oookJP03om[o0?oonf[ooo]Z00?ooo]Z00?o9P3oodCo0?oonfX04ooo
nfX01?lao`3ooo]ZoookJ_m4o`04oookJP03o`3o/?n2o`3o033o00;ooo]Z00?o0>Soo`3oCOoonfX0
0ooonfX00ol60?ooT_l0oookJP03oookJP03oa00oooo06[o01Wo00Gooo]Z00Ooo`1AoaD0oooonf[o
oo]Zo`2]oooonf[oo`1i00[ooo]Z00?o0?mCoookJ_oonfX00_oonfX00ol0o`SoA?l0oookJP02oiCo
00oooo]Z00?o0?ldo`3oC_l0obh02?oonfX00ol0ZOoooo]ZoookJP05oookJP04o`04oooonf[ooo]Z
o`3Dof[ooo]Z00?oo`3ZoookJ_oonfX04_oonfX01?oo5P3ooo]ZoookJ_ooTP0<oookJP03ool0o?oo
nf[ooo]Z00gooo]Z0olH0?l00ooonf[oo`H0ool6000:oookJP[ojol04?oonfX:ool0mPOooo]Z1?o[
o`04oookJPKoo`H00ooonfX4oaP0o`Wooo]Z0ooo0?`9oookJP;ooi8000?ooaH0oookJ_oonfX03?oo
nfX00ooo0>[ooo]ZoookJP0?oookJPCo00001ooonfX00ol0Looooo]ZoookJP0@oookJP03okWo0?l0
oc?ooe8000Cooo]Z00?o02[ooookJ_loo`000_oonfX01?l0g?oooo]ZogSo0?l0oml:oookJP03o`2>
ool0oa_o4P3o00;ooo]Z00?oolX0oookJ_oonfX00ooonfX01?oo09?ooo]ZoookJ_oo01<6oookJP03
om[o0?oQo`3ooo]Z00Cooo]Z00?o9P3oob3o0?oonfX04ooonfX01?lao`3ooo]ZoookJ_l0oe/4oook
JP03o`3o/?n2o`3o033o00;ooo]Z00?o0>Soo`3oCOoonfX00_oonfX00ol60?ooT_l0oookJP03oook
JP04oa00oooonf[oo`1Zo`0Io`Gooo]Z00Coo`1AoookJ_oonf[o0:go0_oonfX00ooo07Wooo]Zoook
JP07oookJP03o`3oDooonf[ooo]Z00;ooo]Z00?o0?l8o`3o7OoonfX00_oonfX00ol0hOoooo]Zoook
JP0<oookJP03o`3o=?oonf[o0?m>00Sooo]Z00?o08Soo`2YoooonfX01OoonfX01Ol01?oooo]Zoook
J_oonf[o0=Co02oooo]Z000noookJP03oiCo0?oonf[ooo]Z01?ooo]Z0_oo5P000ooonf[ooi80oonB
000;oookJP;oo`3l4?oonfX2oaP0o`Koo`H01ooonfXJonGo00[ooo]Z1?o[o`03oookJPGoo`H01_oo
nfX4oaP0o`[ooo]Z0ooo0?`;oookJP03oonB0?oo5P3ooaH000gooo]Z0_oo0>XBoookJPCo00001Ooo
nfX2o`1coa;ooo]Z00?o^Ol0o`3o<oooDP000ooonfX01_l0:_oooo]Zocoo0?loo`3ooo]Zo`3Lo`;o
oo]Z00?oN?l0ocd0oooonfX02OoonfX01Ol0S_oo0?lKoookJ_oonf[oolX000Kooo]Z00Coo`2Coook
J_oonf[oo`0C1_oonfX00ooQo`3of_l0oookJP03oookJP03obH0oom4o`3ooo]Z01Cooo]Z00?o<Ol0
oookJ_m4o`001OoonfX00on2o`3o033oo`3o/@02oookJP03o`3oCOoonf[ooo]Z00;ooo]Z00?o1P3o
ool0mOnBo`000ooonfX01?l@0?ooo`1ZoookJ_l06Ol4oookJP07ool0DOlE0?oooo]ZoookJ_l0[Ooo
oo]Zool0N@0:oookJP03o`3oDooonf[ooo]Z00;ooo]Z00Go0?l8odCo0?oonf[ooo]ZoiCo000?oook
JP03o`3o=?l0odko0?l^00Sooo]Z00?o08Soo`2YoooonfX01OoonfX01?l01?oooo]ZoookJ_l0e?m/
oookJP03ool0j_oonf[ooo]Z01;ooo]Z0_oo5P000ooonf[ooi80oonB000;oookJP;oo`3l4?oonfX3
oaP0o`Koo`H03_oonfXCon_o00[ooo]Z1?o[o`03oookJPGoo`H01OoonfX4oaP0o`_ooo]Z0_oo0?`;
oookJP03oonB0?oo5P3ooaH000kooo]Z00?oo`3ZoookJ_oonfX04?oonfX4o`0000Gooo]Z0_l0LolB
oookJP03okWo0?l0oc?ooe8000Cooo]Z00?o02[ooookJ_loo`000_oonfX01?l0g?oooo]ZogSo0?l0
oml:oookJP03o`2>ool0oa_o4P3o00;ooo]Z00?oolX0oookJ_oonfX00ooonfX01Ooo09?ooo]Zoook
J_oonf[oo`0C00Kooo]Z00?of_l0oookJ_oonfX00ooonfX00olV0?oo8?l0oookJP0CoookJP04oc7o
0?oonf[ooo]Zo`3oF`Cooo]Z00?o0?n`oh;o0?l0<?l00_oonfX00ol0j?oo0?m=oookJP02oookJP03
o`H0oooonf[oT_l000?ooo]Z00Co403oo`1Moooo06[o01Wo1OoonfX01?oo057ooo]ZoookJ_l0[Ol2
oookJP03ool0NOoonf[ooo]Z00Oooo]Z00?o0?mCoookJ_oonfX00ooonfX01Ol0oagooo]ZoookJ_oo
nf[o0>7o00kooo]Z00?o0?ldoookJ_l0odh02OoonfX00ol0R?oo0:WooookJP04oookJP05o`04oooo
nf[ooo]ZoookJ_l0e?l0<?oonfX003oooo]Z00?oU?l0oookJ_oonfX05?oonfX01?oo5P3ooo]Zoook
J_ooTP0<oookJP;oo`3l4OoonfX2oaP0o`?ooo]Z2Ooo1P02oookJPWoiOl03OoonfX9onGo0003on_o
0?oonf[ooo]Z00Goo`H01ooonfX4oaP0o`cooo]Z0_oo0?`<oookJP;ooi8000?ooaH0oookJ_oonfX0
3?oonfX00ooo0>[ooo]ZoookJP0BoookJPCo00001?oonfX00ol0Looooo]ZoookJP0AoookJP03okWo
0?l0oc?ooe8000?ooo]Z00?o02[ooookJ_loo`000_oonfX01Ol0g?oooo]ZoookJ_mho`3o?@3o00[o
oo]Z00Go08koo`3o6ooonf[ooo]Zooo:0006oookJP04ool0Tooonf[ooo]Zool04`Kooo]Z00?ohOl0
om[o0?oonfX00ooonfX00olV0?ooA?l0oookJP0DoookJP03oc7o0?oonf[oA?l000Gooo]Z00?o0?n`
oh;o0?l0<?l00_oonfX00ol0j?oo0?m=oookJP02oookJP03o`H0oooonf[oT_l000?ooo]Z00Co05go
oa00oooo06[o01Wo1OoonfX01?oo057o5@3ooookJ_l0[Ol2oookJP03ool0NOoonf[ooo]Z00Oooo]Z
00?o0?mCoookJ_oonfX00ooonfX01Ol0o`SoA?l0oookJ_oonf[o0>7o00kooo]Z00Co0?ldoookJ_l0
odko0?l^2?oonfX00ol0R?oo0:WooookJP04oookJP05o`04oooonf[ooo]ZoookJ_l0e?l0KOoonfX0
0ooo0>[ooo]ZoookJP0CoookJP04oolF0?oonf[ooo]ZoonB00cooo]Z0_oo0?`AoookJP;o603o1?oo
nfX9ool601Sooo]Z2_o[o`02oookJPGoo`H01_oonfX4oaP0o`cooo]Z0ooo0?`;oookJP;ooi8000?o
oaH0oookJ_oonfX03?oonfX2ool0jQ?ooo]Z1?l00004oookJP03o`1coooonf[ooo]Z017ooo]Z00?o
^Ol0o`3o<oooDP001?oonfX00ol0:_oooo]Zocoo0002oookJP04o`3Loooonf[oN?l0o`3og`[ooo]Z
00?o08koo`3o6olB0?l00_oonfX00ooobP3ooo]ZoookJP03oookJP05ool0Tooonf[ooo]ZoookJ_oo
01<01_oonfX00ooJo`3ooo]ZoookJP03oookJP03obH0oolPo`3ooo]Z01?ooo]Z00Co<Ol0oookJ_oo
nf[o0?mK1OoonfX01ol0ok3oP_l0o`0`oooonf[o0>SooookJ_l0odd00_oonfX00ol60?oooo]Zoi;o
0004oookJP03oa00oooonf[o01Wo00Kooo]Z00?oo`1AoookJ_l0[Ol00ooonfX00ooo07Wooo]Zoook
JP06oookJP03o`3oDooonf[ooo]Z00?ooo]Z00?o0?l8o`3o7OoonfX00_oonfX00ol0hOoooo]Zoook
JP0<oookJP03o`3o=?oonf[o0?m>00Sooo]Z00?o08SooookJ_l0ZOl01?oonfX00ol01?oooo]Zoook
JP02oookJP03o`3Doooonf[ooo]Z02kooo]Z0010oookJP03oiCo0?oonf[ooo]Z01Cooo]Z0_oo5P00
0ooonf[ooi80oookJP0<oookJP;oo`3l4OoonfX3oaP0o`Wooo]Z2Ooo1P02onGo01?ooo]Z1_oo1P08
oookJPCo603o3_oonfX2ool0o0_ooo]Z0oooTP000ooo5P3ooo]ZoookJP0=oookJP03ool0j_oonf[o
oo]Z01?ooo]Z1?l00002oookJP;o07?o4_oonfX2okWo0003o`3o<oooDP3ooo]Z00;ooo]Z00?o02[o
oookJ_loo`000_oonfX01Ol0g?oooo]ZoookJ_mho`3o?@3o00[ooo]Z00Go08koo`3o6ooonf[ooo]Z
ooo:0006oookJP04ool0Tooonf[ooo]Zool04`Oooo]Z00?of_l0oookJ_oonfX00ooonfX00olV0?oo
A?l0oookJP0CoookJP04oc7o0?oonf[ooo]ZodCo00Cooo]Z00Oo0?n`oh;o0?l0<?oo0?naoookJ_l0
j?oo0?m=00Cooo]Z00?o1P3ooi;o0?oonfX00ooonfX00ol@0?ooo`1Zo`0Io`05oookJP07ool0DOlE
0?oooo]ZoookJ_l0[Ooooo]Zool0N@0:oookJP03o`3oDooonf[ooo]Z00;ooo]Z00Go0?l8odCo0?oo
nf[ooo]Zo`3Qo`0?oookJP03o`3o=?l0odko0?l^00Sooo]Z00?o08Soo`2YoooonfX01OoonfX01?l0
1?oooo]ZoookJ_l0e?m_oookJP03ool0j_oonf[ooo]Z01?ooo]Z0_oo5P000ooonf[ooi80oookJP0<
oookJP;oo`3l4OoonfX3oaP0o`[ooo]Z2Ooo1P0EoookJPKoo`H01ooonfX4oaP0o`kooo]Z0_oo0?`;
oookJP?ooi8000?ooaH0oookJ_oonfX03OoonfX00ooo0>[ooo]ZoookJP0CoookJPCo00000_oonfX2
o`1coa;ooo]Z0_nio`000ol0oc?ooe80oookJP03oookJP03o`0Zoooonf[o?ol000;ooo]Z00Co0=co
oookJ_mho`3o0?oO2_oonfX00ol0S_oo0?lKoa80o`02oookJP03ooo:0?oonf[ooo]Z00?ooo]Z00Go
o`2CoookJ_oonf[ooo]Zool04`06oookJP03om[o0?oonf[ooo]Z00?ooo]Z00?o9P3oob3o0?oonfX0
4ooonfX01Olao`3ooo]ZoookJ_oonf[o0?mK00Cooo]Z00?o0?n`oh;o0?l0<?l00_oonfX00ol0j?oo
0?m=oookJP02oookJP03o`H0oonBo`3ooo]Z00?ooo]Z00Co403oo`1Moooo06[o01Wo1OoonfX01?oo
057ooo]ZoookJ_l0[Ol2oookJP03ool0NOoonf[ooo]Z00Oooo]Z00?o0?mCoookJ_oonfX00ooonfX0
1Ol0oagooo]ZoookJ_oonf[o0>7o00kooo]Z00?o0?ldoookJ_l0odh02?oonfX00ol0R?oooo]Zo`2Y
o`05oookJP05o`04oooonf[ooo]ZoookJ_l0e?l0<OoonfX0047ooo]Z0_nDo`0FoookJP04oolF0?oo
nf[ooi80oonB00gooo]Z00?oo`3loookJ_oonfX04OoonfX3oaP0o`oooo]Z2Ooo1P07oookJPGoo`H0
2ooonfX3oaP0o`oooo]Z0ooo0?`:oookJP?ooi8000?ooaH0oookJ_oonfX03_oonfX2ool0jQKooo]Z
1?l000000ooonf[o07?ooookJP0BoookJP04okWo0?oonf[o0?lcoomB00?ooo]Z00?o02[ooookJ_lo
o`000_oonfX01Ol0g?oooo]ZoookJ_mho`3o?@3o00[ooo]Z00Go08koo`3o6ooonf[ooo]Zooo:0006
oookJP04ool0Tol0nOoooo]Zool04`Oooo]Z00?of_l0oookJ_oonfX00ooonfX00olV0?ooA?l0oook
JP0CoookJP04oc7o0?oonf[ooo]ZodCo00Cooo]Z00Co0?n`oookJ_n2o`3o033o0_oonfX00ol0j?oo
0?m=oookJP02oookJP03o`H0oooonf[oT_l000?ooo]Z00?o403ooookJ_l06Ol01_oonfX01?oo057o
oo]ZoookJ_l0[Ol2oookJP03ool0NOoonf[ooo]Z00Oooo]Z00?o0?mCoookJ_oonfX00ooonfX01?m4
o`3ooo]ZoookJ_l0hOl?oookJP04o`3o=?oonf[o0?m>o`3o;POooo]Z00?o08SooookJ_l0ZOl01Ooo
nfX01Ol01?oooo]ZoookJ_oonf[o0=Co073ooo]Z0_oo0>XEoookJP04oolF0?oonf[ooi80oonB00go
oo]Z00?oo`3loookJ_oonfX04OoonfX3oaP0oa3ooo]Z2Ooo1P07oookJPGoo`H02_oonfX3oaP0oa3o
oo]Z0_oo0?`:oookJP?ooi8000?ooaH0oookJ_oonfX03_oonfX2ool0jQKooo]Z1?l000000ooonf[o
07?ooookJP0BoookJP04okWo0?oonf[o0?lcoomB00Cooo]Z00Co02[ooookJ_loo`3ooo]Z0_l0g?l0
1?oonf[oN?l0o`3ogolm0?l9oookJP03o`2>ool0oa_o4P3o00;ooo]Z00?oolX0oookJ_oonfX00ooo
nfX01Ooo09?o0?WooookJ_oonf[oo`0C00Kooo]Z00?of_l0oookJ_oonfX00ooonfX00olV0?oo8?l0
oookJP0DoookJP04oc7o0?oonf[ooo]Zo`3oF`Cooo]Z00So0?n`oookJ_n2o`3o033ooookJ_l0j?oo
oo]Zo`3oC@;ooo]Z00?o1P3ooookJ_nBo`000ooonfX01?l@0?oo05goool0J_l06Ol5oookJP04ool0
DOoonf[ooo]Zo`2]o`?ooo]Z00?oo`1ioookJ_oonfX01_oonfX00ol0oe?ooo]ZoookJP03oookJP05
o`3o7Ooonf[ooo]ZoookJ_l0hOl03ooonfX00ol0ocCooo]Zo`3oCP08oookJP03o`28oooonf[o0:Wo
00Cooo]Z00?o00CooookJ_oonfX00_oonfX00ol0e?oooo]ZoookJP0_oookJP00@ooonfX2ool0jQGo
oo]Z0_oo5P000ooonf[ooi80oookJP0<oookJP;oo`3l5?oonfX3oaP0oaGooo]Z1ooo1P0<oookJPCo
603o4?oonfX2ool0o0[ooo]Z0oooTP000ooo5P3ooo]ZoookJP0>oookJP?oo`3Z6?oonfX3o`0000;o
07?o4ooonfX01?nio`3ooo]Zo`3o<oooDP03oookJP03o`0Zoooonf[o?ol000;ooo]Z00Go0=cooook
J_mho`3oN?l0ocd0o`0:oookJP05o`2>ool0oa_ooo]ZoookJ_oobP001_oonfX01?oo09?o0?Wooook
J_oo01<7oookJP03on7o0?oJo`3ooo]Z00?ooo]Z00?o9P3oodCo0?oonfX05?oonfX00olao`3ooo]Z
odCo0005oookJP03o`3o/?n2o`3o033o00;ooo]Z00?o0>Soo`3oCOoonfX00_oonfX00onDo`3o1P3o
oi;o0004oookJP03oa00oooo06[o01Wo00Gooo]Z00Coo`1AoaD0oooonf[o0:go0_oonfX00ooo07Wo
oo]ZoookJP08oookJP03o`3oDooonf[ooo]Z00;ooo]Z00Go0?l8odCo0?oonf[ooo]Zo`3Qo`0>oook
JP04o`3o=?oonf[o0?m>o`3o;PSooo]Z00?o08Soo`2YoooonfX01OoonfX01Ol01?oooo]ZoookJ_oo
nf[o0=Co07;ooo]Z0_oo0>XDoookJP;ooaH000?ooo]ZoonB0?oonfX03?oonfX2ool0o1Cooo]Z0olH
0?lFoookJPOoo`H02ooonfX4oaP0oa3ooo]Z0ooo0?`9oookJP?ooi8000?ooaH0oookJ_oonfX03_oo
nfX3ool0jQSooo]Z0ol00002o`1coa?ooo]Z00Co^Ol0oookJ_l0oc?ooe801?oonfX01_l0:_oooo]Z
ocoo0?oonf[o0=cooookJP;oN?l000?o0?oOocd0oooonfX02?oonfX00ol0S_oo0?lKoa80o`02oook
JP03ooo:0?oonf[ooo]Z00Cooo]Z00Coo`2CoookJ_oonf[oo`0C1_oonfX00ooQo`3of_l0oookJP03
oookJP03obH0oolPo`3ooo]Z01Cooo]Z00Co<Ol0oookJ_oonf[o0?mK1?oonfX02?l0ok3ooo]Zoh;o
0?l0<?oooo]Zo`3Xoooonf[o0?m=0ooonfX00ol60?ooT_l0oookJP03oookJP03oa00oooonf[o01Wo
00Kooo]Z00?oo`1AoookJ_l0[Ol00ooonfX00ooo07Wooo]ZoookJP07oookJP03o`3oDooonf[ooo]Z
00;ooo]Z00Go0?l8o`3o7Ooonf[ooo]Zo`3Qo`0?oookJP03o`3o=?oonf[o0?m>00Sooo]Z00?o08So
oookJ_l0ZOl01OoonfX00ol01?oooo]ZoookJP02oookJP03o`3Doooonf[ooo]Z02oooo]Z0015oook
JP;oo`3Z5OoonfX00ooo5P3ooo]ZoonB0002oonB00cooo]Z1?oo0?`CoookJRSo603o4_oonfX2ool0
o0Wooo]Z0oooTP000ooo5P3ooo]ZoookJP0?oookJP;oo`3Z6ooonfX2o`000003o`1cool0003ooo]Z
01;ooo]Z00Co^Ol0oookJ_l0oc?ooe800ooonfX00ol0:_oooo]Zocoo0002oookJP06o`3Loooonf[o
N?l0oiCo0?oonf[o?@3o2OoonfX01Ol0S_oo0?lKoookJ_oonf[oolX000Kooo]Z00Coo`2Co`3ioooo
nf[oo`0C1ooonfX00ooQo`3of_l0oookJP03oookJP03obH0oom4o`3ooo]Z01Cooo]Z00Co<Ol0oook
J_oonf[oA?l01?oonfX01ol0ok3oP_l0o`0`ool0ok7ooo]Zo`3Xool0odd01?oonfX00onDo`3oo`3e
oi;o0003oookJP03oa00oooo06[o01Wo00Gooo]Z00Ooo`1AoaD0oooonf[ooo]Zo`2]oooonf[oo`1i
00[ooo]Z00?o0?mCoookJ_oonfX00ooonfX01?m4o`3ooo]ZoookJ_l0hOl?oookJP04o`3o=?oonf[o
0?m>o`3o;POooo]Z00?o08SooookJ_l0ZOl01OoonfX01Ol01?oooo]ZoookJ_oonf[o0=Co07Gooo]Z
0_oo0>XDoookJP03oolF0?oonf[ooi8000;ooi803?oonfX4ool0o1?ooo]Z:?lH0?lBoookJP;oo`3l
2OoonfX3oonB0003oolF0?oonf[ooo]Z00oooo]Z0_oo0>XKoookJP;o000000?o07?oo`000?oonfX0
4_oonfX01?nio`3ooo]Zo`3o<oooDP04oookJP0:o`0Zoooonf[o?ol0oookJ_l0g?oooo]ZogSo0?oo
nf[o0?oOocd0o`Wooo]Z00?o08koo`3o6olB0?l00_oonfX00ooobP3ooo]ZoookJP04oookJP04ool0
Tooonf[ooo]Zool04`Kooo]Z00?ohOl0om[o0?oonfX00ooonfX00olV0?ooQ03oob3o000DoookJP05
oc7o0?oonf[ooo]ZoookJ_l0oe/00ooonfX01?l0ok3ooo]Zoh;o0?l0<?l2oookJP03o`3Xool0odgo
oo]Z00;ooo]Z00?o1P3ooookJ_nBo`000ooonfX00ol@0?oo05goo`0Io`06oookJP04ool0DOoonf[o
oo]Zo`2]o`;ooo]Z00?oo`1ioookJ_oonfX01ooonfX00ol0oe?ooo]ZoookJP03oookJP05o`3o7Ooo
nf[ooo]ZoookJ_l0hOl03_oonfX01?l0ocCooo]ZoookJ_l0odh8oookJP03o`28oooonf[o0:Wo00Co
oo]Z00?o00CooookJ_oonfX00_oonfX00ol0e?oooo]ZoookJP0`oookJP00AooonfX2ool0jQCooo]Z
0_oo5P02oookJP?ooi803OoonfX5ool0o4Gooo]Z0ooo0?`7oookJPCooi8000?ooaH0oookJ_oonfX0
3ooonfX3ool0jQgooo]Z00Co0000o`1cool0003o00004OoonfX2okWo0003oookJ_l0oc?ooe8000?o
oo]Z00?o02[ooookJ_loo`000_oonfX01_l0g?oooo]ZogSo0?nDo`3ooo]Zocd0o`Wooo]Z00Go08ko
o`3o6ooonf[ooo]Zooo:0006oookJP04ool0Tol0nOoooo]Zool04`Oooo]Z00?ohOl0om[o0?oonfX0
0ooonfX00olV0?ooA?l0oookJP0DoookJP04oc7o0?oonf[ooo]ZodCo00Cooo]Z00Co0?n`oh;o0?oo
nf[o033o0_oonfX00ol0j?oo0?m=oookJP03oookJP03oiCo0?nBo`3ooo]Z00;ooo]Z00?o05gooa00
ool06Ol01_oonfX01?oo057ooo]ZoookJ_l0[Ol2oookJP03ool0NOoonf[ooo]Z00Sooo]Z00?o0?mC
oookJ_oonfX00_oonfX01?m4o`3ooo]ZoookJ_l0hOl?oookJP04o`3o=?oonf[o0?m>o`3o;PSooo]Z
00?o08Soo`2YoooonfX01OoonfX01Ol01?oooo]ZoookJ_oonf[o0=Co07Oooo]Z0_oo0>XCoookJP;o
oaH00_oonfX3oonB00gooo]Z1Ooo0?a5oookJP?oo`3l1ooonfX4oonB0003oolF0?oonf[ooo]Z013o
oo]Z0_oo0>XMoookJP04o`000?l0Looo0000o`00017ooo]Z0_nio`000ooonf[o0?lcoomB0004oook
JP0:o`0Zoooonf[o?ol0oookJ_l0g?oooo]ZogSo0?oonf[o0?oOocd0o`Wooo]Z00?o08koo`3o6olB
0?l00_oonfX00ooobP3ooo]ZoookJP04oookJP04ool0Tooonf[ooo]Zool04`Oooo]Z00?of_l0oook
J_oonfX00ooonfX00olV0?oo8?l0oookJP0CoookJP05oc7o0?oonf[ooo]ZoookJ_l0oe/01?oonfX0
2?l0ok3oP_l0o`3o/Ol0<?oooo]Zo`3Xoooonf[o0?m=0ooonfX00ol60?ooT_l0oookJP03oookJP03
oa00oooonf[o01Wo00Gooo]Z00Co5@3oool0DOoonf[o0:go0ooonfX00ooo07Wooo]ZoookJP07oook
JP03o`3oDooonf[ooo]Z00;ooo]Z00Go0?lMoookJ_oonf[ooo]Zo`3Qo`0?oookJP04o`3o=?oonf[o
0?m>o`3o;POooo]Z00?o08SooookJ_l0ZOl01OoonfX00ol01?oooo]ZoookJP02oookJP03o`3Doooo
nf[ooo]Z033ooo]Z0019oookJP;oo`3Z5?oonfX00ooo5P3ooo]ZoookJP02oookJPCooi803_oonfX6
ool0o3[ooo]Z1Ooo0?`7oookJP?ooi800_oo5P0BoookJP;oo`3Z7ooonfX2o`1co`?o00004?oonfX0
1Onio`3ooo]ZoookJ_l0oc?ooe8000?ooo]Z00Co02[ooookJ_loo`3ooo]Z0_l0g?l01Ooonf[oN?l0
oiCo0?oonf[o?@3o00Wooo]Z00Go08koo`3o6olB0?oooo]Zooo:0007oookJP03ool0Tol0nOooo`0C
00Oooo]Z00?ohOl0oookJ_oJo`000ooonfX00olV0?ooA?l0oookJP0DoookJP04oc7o0?oonf[ooo]Z
odCo00Gooo]Z00OoP_l0oookJ_l0<?oo0?naoookJ_l0j?oo0?m=00Cooo]Z00?oU?l0oi;o0?oonfX0
0ooonfX00ol@0?ooo`1Zo`0Io`05oookJP07ool0DOoonf[ooo]ZoookJ_l0[Ooooo]Zool0N@0:oook
JP03o`3oDooonf[ooo]Z00?ooo]Z00CoA?l0oookJ_oonf[o0>7o3ooonfX01?l0ocCooo]Zo`3oC_l0
obh7oookJP03o`28oooonf[o0:Wo00Gooo]Z00Go00CooookJ_oonf[ooo]Zo`3Do`1joookJP;oo`3Z
4ooonfX00ooo5P3ooo]ZoookJP02oookJPCooi803_oonfX6ool0o3[ooo]Z1Ooo0?`7oookJP?ooi80
0_oo5P0BoookJP?oo`3Z7_oonfX2o`1co`?o00004?oonfX01Onio`3ooo]ZoookJ_l0oc?ooe8000Co
oo]Z00[o02[ooookJ_loo`3ooo]Zo`3Loooonf[oN?l0oookJ_l0omoo?@3o2OoonfX01_l0S_oo0?lK
oookJ_lB0?oooo]Zooo:00Kooo]Z00Coo`2Co`3ioooonf[oo`0C1ooonfX00ooQo`3of_l0oookJP03
oookJP03obH0oolPo`3ooo]Z01Cooo]Z00Co<Ol0oookJ_oonf[o0?mK1?oonfX02?l0ok3oP_l0oook
J_l0<?oooo]Zo`3Xoooonf[o0?m=0ooonfX00ol60?ooT_l0oookJP03oookJP03oa00ool0GOoo01Wo
00Gooo]Z00Go5@3oool0DOoonf[ooo]Zo`2]o`02oookJP03ool0NOoonf[ooo]Z00Oooo]Z00?o0?mC
oookJ_oonfX00ooonfX01?l0oagooo]ZoookJ_l0hOl?oookJP04o`3o=?oonf[ooo]Zo`3oCPOooo]Z
00Co08SooookJ_oonf[o0:Wo1?oonfX00ol01?oooo]ZoookJP02oookJP03o`3Doooonf[ooo]Z037o
oo]Z001;oookJP;oo`3Z4ooonfX3oolF00Gooo]Z0oooTP0AoookJPGoo`3l;OoonfX8ool0o0Wooo]Z
0oooTP02oolF01;ooo]Z0ooo0>XPoookJP03o`1coooonf[o000000?o00003ooonfX01Onio`3ooo]Z
oookJ_l0oc?ooe8000?ooo]Z00Go02[ooookJ_loo`3ooo]Zo`3Lo`02oookJP04ogSo0?nDo`3ooo]Z
ocd0o`Wooo]Z00Go08koo`3o6olB0?oooo]Zooo:0007oookJP03ool0Tol0nOooo`0C00Oooo]Z00?o
hOl0oookJ_oJo`000ooonfX00olV0?ooQ03oodCo000EoookJP03oc7o0?oonf[oA?l000Gooo]Z00So
P_l0oookJ_l0<?oo0?naoookJ_l0j?oooo]Zo`3oC@?ooo]Z00?oU?l0oookJ_nBo`000ooonfX00ol@
0?oooo]Zo`0Io`06oookJP06ool0DOoonf[ooo]Zo`2]oooonf[oo`1i2ooonfX00ol0oe?ooo]Zoook
JP02oookJP04odCo0?oonf[ooo]Zo`3Qo`oooo]Z00Go0?ldoookJ_l0odkooo]Zo`3o;P07oookJP03
o`28ool0ZOoooo]Z00Gooo]Z00Go00CooookJ_oonf[ooo]Zo`3Do`1loookJP;oo`3Z4_oonfX3oolF
00Gooo]Z0oooTP0AoookJPGoo`3l;OoonfX8ool0o0Wooo]Z0oooTP02oolF01?ooo]Z0_oo0>XPoook
JP03o`1coooonf[o000000?o00003ooonfX01Onio`3ooo]ZoookJ_l0oc?ooe8000Cooo]Z00[o02[o
oookJ_loo`3ooo]Zo`3Loooonf[oN?l0oookJ_l0omoo?@3o2OoonfX01_l0S_oo0?lKoookJ_lB0?oo
oo]Zooo:00Kooo]Z00Coo`2Co`3ioooonf[oo`0C1ooonfX00ooQo`3of_l0oookJP03oookJP03obH0
oolPo`3ooo]Z01Cooo]Z00Co<Ol0oookJ_oonf[o0?mK1?oonfX01_l0ok3oP_l0oookJ_l0<?oooo]Z
o`3Xo`;ooo]Z00Ko0?m=oookJ_oonf[o1P3ooookJ_nBo`03oookJP04oa00ool0GOoo01Woool0JPGo
oo]Z00Co5@3oool0DOoonf[o0:go0_oonfX00ooo07Wooo]ZoookJP08oookJP03o`3oDooonf[ooo]Z
00;ooo]Z00Go0?lMoookJ_oonf[ooo]Zo`3Qo`0?oookJP04o`3o=?oonf[o0?m>o`3o;POooo]Z00?o
08SooookJ_l0ZOl01OoonfX01Ol01?oooo]ZoookJ_oonf[o0=Co03Cooo]Z001=oookJP;oo`3Z5?oo
nfX4oolF00Cooo]Z1?ooTP0BoookJPGoo`3l8?oonfX8ool0o0kooo]Z0oooTP03oolF01;ooo]Z0_oo
0>XQoookJP;o07?o0_oonfX4o`0000kooo]Z00Go^Ol0oookJ_oonf[o0?lcoomB0002oookJP;o02[o
00Cooo]Zocoo0?oonf[o0=co0_oonfX01?mho`3oU?l0oookJ_lm0?l9oookJP05o`2>ool0oa_o4P3o
oookJ_oobP001ooonfX00ooo09?o0?Woool04`08oookJP03on7o0?oJo`3ooo]Z00?ooo]Z00?o9P3o
odCo0?oonfX05?oonfX01?lao`3ooo]ZoookJ_m4o`04oookJP04o`3o/?n2o`3ooo]Zo`0`o`;ooo]Z
00?o0>Soo`3oCOoonfX00_oonfX00onDo`3ooo]Zoi;o0003oookJP03o`1Mool@0?oo01Wo00Kooo]Z
00Coo`1AoookJ_oonf[o0:go0_oonfX00ooo07Wooo]ZoookJP08oookJP03o`3oDooonf[ooo]Z00;o
oo]Z00GoA?l0o`3o2?oonf[ooo]Zo`3Qo`0>oookJP05o`3o=?oonf[ooo]Zo`3oC_l0obh01ooonfX0
0ol0R?oooo]Zo`2Yo`05oookJP05o`04oooonf[ooo]ZoookJ_l0e?l0OooonfX00ooo0>[ooo]Zoook
JP0BoookJPCooaH01?oonfX4oonB01;ooo]Z1Ooo0?`PoookJPSoo`3l3_oonfX3oonB00?ooaH04ooo
nfX2ool0jR3ooo]Z0_l0Lol2oookJPCo00003_oonfX01Onio`3ooo]ZoookJ_l0oc?ooe8000?ooo]Z
0_l0:_l02Ooonf[o?ol0oookJ_l0g?oooo]ZogSo0?oonf[o0?oOocd0o`09oookJP06o`2>ool0oa_o
oo]Zoa80oooonf[oolX01_oonfX01?oo09?o0?WooookJ_oo01<7oookJP03on7o0?oJo`3ooo]Z00?o
oo]Z00?o9P3oob3o0?oonfX05?oonfX01Olao`3ooo]ZoookJ_oonf[o0?mK00?ooo]Z00Wo0?n`oook
J_n2o`3o0?nao`0`oooonf[o0>SooookJ_l0odd00_oonfX00ol60?oooo]Zoi;o0004oookJP03oa00
oooonf[o01Wo00Gooo]Z00Co5@3oool0DOoonf[o0:go0ooonfX00ooo07Wooo]ZoookJP07oookJP03
o`3oDooonf[ooo]Z00;ooo]Z00Go0?lMo`3o2?oonf[ooo]Zo`3Qo`0?oookJP04o`3o=?oonf[ooo]Z
o`3oCPOooo]Z00Co08SooookJ_oonf[o0:Wo1?oonfX00ol01?oooo]ZoookJP02oookJP03o`3Doooo
nf[ooo]Z03;ooo]Z001?oookJP;oo`3Z5_oonfX4oolF00Cooo]Z0oooTP0DoookJPKoo`3l4ooonfX7
ool0o1;ooo]Z1?ooTP03oolF01?ooo]Z0_oo0>X@oookJPGo001o1OoonfX5o`00O`?ooo]Z00?o07?o
oookJ_oonfX00_oonfX4o`0000cooo]Z0_nio`02oookJP;ooe800_oonfX01_l0:_oooo]ZoookJ_lo
o`3oU?l0o`3Lo`;ooo]Z00CoN?l0oiCo0?oonf[o?@3o2OoonfX01Ol0S_oo0?lKoa80oooonf[oolX0
00Oooo]Z00?oo`2Co`3ioooo01<02?oonfX00ooQo`3of_l0oookJP03oookJP03obH0oom4o`3ooo]Z
01Cooo]Z00Co<Ol0oookJ_oonf[oA?l01?oonfX02?l0ok3oP_l0oookJ_l0<?oo0?naoookJ_l0j?oo
0?m=0ooonfX01?nDo`3ooo]ZoookJ_nBo`03oookJP03oa00ool06Ooooo]Z00Gooo]Z00Oo5@3oool0
DOoonf[ooo]Zo`2]oooonf[oo`1i00[ooo]Z00?o0?mCoookJ_oonfX00ooonfX01?m4o`3ooo]Zoook
J_l0hOl?oookJP05o`3o=?oonf[o0?m>oookJ_l0obh01ooonfX00ol0R?oo0:WooookJP04oookJP05
o`04oooonf[ooo]ZoookJ_l0e?l0POoonfX2ool0jQKooo]Z1?oo5P04oookJP?ooi805?oonfX6ool0
o1?ooo]Z1ooo0?`BoookJPCooi800ooo5P0CoookJP?oo`3Z3ooonfX5o`00O`Gooo]Z1Ol007l3oook
JP03o`1coooonf[ooo]Z00;ooo]Z1?l0000<oookJP;o^Ol00_oonfX2oomB00?ooo]Z00_o02[ooook
J_oonf[o?ol0oookJ_l0g?oooo]ZogSo0?oonf[o0?oOocd0o`09oookJP06o`2>ool0oa_ooo]Zoa80
oooonf[oolX01_oonfX01?oo09?o0?WooookJ_oo01<7oookJP03on7o0?oJo`3ooo]Z00?ooo]Z00?o
9P3oob3o0?n40?l05?oonfX01Olao`3ooo]ZoookJ_oonf[o0?mK00Cooo]Z00So0?n`oh;o0?oonf[o
033ooookJ_l0j?oooo]Zo`3oC@;ooo]Z00Co1P3ooookJ_oonf[oT_l00ooonfX00ol@0?oo05goo`0I
o`05oookJP05oaD0oooonf[oo`1AoookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP07oookJP03o`3o
Dooonf[ooo]Z00?ooo]Z00Co0?lMoookJ_oonf[o0>7o4?oonfX01?l0ocCooo]Zo`3oC_l0obh7oook
JP03o`28oooonf[o0:Wo00Cooo]Z00?o00CooookJ_oonfX00_oonfX00ol0e?oooo]ZoookJP0coook
JP00DOoonfX2ool0jQSooo]Z1?oo5P03oookJP?ooi805ooonfX5ool0o0Kooo]Z2?oo0?`FoookJP?o
oi8000Cooo]ZoolF0?oo5P3ooaH04ooonfX3ool0jQ7ooo]Z1ol007l3oookJPOo001o00?ooo]Zo`1c
oooonfX01?oonfX4o`0000_ooo]Z00Go^Ol0oookJ_oonf[ooo]ZoomB0003oookJP05o`0Zoooonf[o
oo]Zocoo0?oonfX00_nDo`000ooonf[oN?l0oiCo0002ocd0o`Wooo]Z00Go08koo`3o6olB0?oooo]Z
ooo:0007oookJP03ool0Tooonf[oo`0C00Sooo]Z00?ohOl0om[o0?oonfX00ooonfX00olV0?ooA?l0
oookJP0EoookJP03oc7o0?oonf[oA?l000Gooo]Z00OoP_l0oookJ_l0<?oo0?naoookJ_l0j?oo0?m=
00?ooo]Z00CoU?l0oookJ_oonf[oT_l00ooonfX00ol@0?ooo`1Zo`0Io`06oookJP06ool0DOoonf[o
oo]Zo`2]oooonf[oo`1i2ooonfX00ol0oe?ooo]ZoookJP02oookJP04odCo0?l0o`Sooo]Zo`3Qo`oo
oo]Z00Go0?ldoookJ_oonf[o0?m>o`3o;P07oookJP03o`28oooonf[o0:Wo00Gooo]Z00Go00Cooook
J_oonf[ooo]Zo`3Do`23oookJP;oo`3Z6?oonfX4oolF00?ooo]Z0oooTP0GoookJPGoo`3l1_oonfX8
ool0o1Kooo]Z0oooTP001?oonf[ooaH0oolF0?oo5P0DoookJP;oo`3Z4OoonfX7o`00O`?ooo]Z1ol0
07l00ooonf[o07?ooookJP04oookJPCo00002ooonfX01Onio`3ooo]ZoookJ_oonf[ooe8000?ooo]Z
0_l0:_l2oookJP08ocoo0?oonf[o0=cooookJ_mho`3ooo]Zo`3ogolm0?l9oookJP06o`2>ool0oa_o
oo]Zoa80oooonf[oolX01_oonfX01?oo09?ooo]ZoookJ_oo01<7oookJP03on7o0?oJo`3ooo]Z00?o
oo]Z00?o9P3oob3o0?n40?l05OoonfX01?lao`3ooo]ZoookJ_l0oe/4oookJP08o`3o/?n2o`3ooo]Z
o`0`oooonf[o0>SooookJ_l0odd3oookJP03o`H0oooonf[oT_l000?ooo]Z00?o403oo`1Mool06Ol0
1_oonfX01?lE0?ooo`1AoookJ_l0[Ol2oookJP03ool0NOoonf[ooo]Z00Sooo]Z00?o0?mCoookJ_oo
nfX00_oonfX01?l0oago0?l8oookJ_l0hOl@oookJP04o`3o=?oonf[ooo]Zo`3oCPOooo]Z00Co08So
oookJ_oonf[o0:Wo1?oonfX01Ol01?oooo]ZoookJ_oonf[o0=Co03Kooo]Z001CoookJP;oo`3Z6_oo
nfX4oolF00;ooo]Z1?ooTP0HoookJPKoo`3l6ooonfX3oonB0004oookJ_oo5P3ooaH0oolF01Cooo]Z
0_oo0>XDoookJP?o001o0_oonfX3o`00O`;ooo]Z0ol007l00ooonf[o001oo`00O`02o`1co`Kooo]Z
1?l0000:oookJP03okWo0?oonf[ooo]Z00;ooe800ooonfX01Ol0:_oooo]ZoookJ_loo`3ooo]Z00?o
U?l000?oN?l0oiCo0?lm0?l02_oonfX01Ol0S_oo0?lKoa80oooonf[oolX000Oooo]Z00?oo`2Coook
J_oo01<02?oonfX00ooQo`3of_l0oookJP03oookJP03obH0oom4o`3ooo]Z01Gooo]Z00Co<Ol0oook
J_oonf[oA?l01?oonfX02?n2o`3ooo]ZoookJ_l0<?oo0?naoookJ_l0j?oo0?m=0_oonfX01?nDo`3o
oo]ZoookJ_nBo`04oookJP03oa00ool06Ooooo]Z00Gooo]Z00Ooo`1AoookJ_oonf[ooo]Zo`2]oooo
nf[oo`1i00[ooo]Z00?o0?mCoookJ_oonfX00ooonfX01?m4o`3ooo]ZoookJ_l0hOl?oookJP05o`3o
=?oonf[o0?m>oookJ_l0obh01_oonfX00ol0R?oooo]Zo`2Yo`05oookJP05o`04oooonf[ooo]Zoook
J_l0e?l0Q_oonfX2ool0jQ[ooo]Z1?oo5P02oookJPCooi806?oonfX6ool0o1_ooo]Z0oooTP001?oo
nf[ooaH0oolF0?oo5P0EoookJP;oo`3Z4ooonfX3o`00O`;ooo]Z0ol007l2oookJP?o001o00?ooo]Z
o`00Ool007l00_l0Lol6oookJPCo00002_oonfX00onio`3ooo]ZoookJP02oomB00?ooo]Z00_o02[o
oookJ_oonf[ooo]Zocoo0?oonf[o0=cooookJ_mho`3ooo]Zo`3og`0:oookJP06o`2>ool0oa_ooo]Z
oa80oooonf[oolX01_oonfX01?oo09?ooo]ZoookJ_oo01<7oookJP03on7o0?oJo`3ooo]Z00?ooo]Z
00?o9P3oob3o0?n40?l05OoonfX01Olao`3ooo]ZoookJ_oonf[o0?mK00?ooo]Z00So0?n`oh;o0?oo
nf[ooo]Zo`0`oooonf[o0>Soo`3oC@?ooo]Z00?o1P3ooookJ_nBo`001?oonfX00ol@0?ooo`1Zo`0I
o`05oookJP05oaD0oooo057ooo]ZoookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP07oookJP03o`3o
Dooonf[ooo]Z00?ooo]Z00Co0?lMoookJ_oonf[o0>7o3ooonfX01Ol0ocCooo]ZoookJ_l0odko0?l^
00Kooo]Z00Co08SooookJ_oonf[o0:Wo1?oonfX00ol01?oooo]ZoookJP02oookJP03o`3Doooonf[o
oo]Z03Cooo]Z001EoookJP;oo`3Z7?oonfX4oolF00;ooo]Z0oooTP0coookJP?ooi8000Cooo]ZoolF
0?oo5P3ooaH05?oonfX3ool0jQGooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX00ol0Looo001oo`00O`06oookJPCo00002OoonfX01Onio`3ooo]ZoookJ_ooDP3o0?lc00?ooo]Z
00Go02[ooookJ_oonf[o?ol0oookJP03oiCo0003ogSo0?nDo`3oU?l000[ooo]Z00Go08koo`3o6olB
0?oooo]Zooo:0007oookJP03ool0Tooonf[oo`0C00Sooo]Z00?ohOl0om[o0?oonfX00ooonfX00olV
0?ooA?l0oookJP0EoookJP04oc7o0?oonf[ooo]ZodCo00Cooo]Z00SoP_l0oookJ_oonf[o033oo`3o
/Ooonf[o0>Soo`3oC@;ooo]Z00GoU?l0oookJ_oonf[ooo]Zoi;o0003oookJP03oa00ool06Ooooo]Z
00Gooo]Z00Oo5@3oool0DOoonf[ooo]Zo`2]oooonf[oo`1i00_ooo]Z00?o0?mCoookJ_oonfX00_oo
nfX01?m4o`3o0?l8oookJ_l0hOl?oookJP05o`3o=?oonf[ooo]Zo`3oC_l0obh01ooonfX00ol0R?oo
oo]Zo`2Yo`05oookJP05o`04oooonf[ooo]ZoookJ_l0e?l0R?oonfX2ool0jQcooo]Z1?oo5P02oook
JP?ooi80<ooonfX3oonB0004oookJ_oo5P3ooaH0oolF01Gooo]Z0ooo0>XDoookJP?o001o0ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z00?o07?oo`00Ool007l01_oonfX4o`0000Wooo]Z00Go
^Ol0oookJ_oonf[ooe80o`3o<`03oookJP0;o`0Zoooonf[ooo]ZoookJ_loo`3ooo]Zo`3Loooonf[o
N?l0oookJ_l0oml02_oonfX01_l0S_oo0?lKoookJ_lB0?oooo]Zooo:00Kooo]Z00Coo`2CoookJ_oo
nf[oo`0C1ooonfX00ooQo`3of_l0oookJP03oookJP03obH0oolPo`3oQ03o01Gooo]Z00Go<Ol0oook
J_oonf[ooo]Zo`3oF`03oookJP08o`3o/?n2o`3ooo]ZoookJ_l0<?oooo]Zo`3Xool0odd3oookJP04
o`H0oooonf[ooo]Zoi;o00?ooo]Z00?o403oool0J_l06Ol01OoonfX01OlE0?oooo]Zool0DOoonf[o
0:go00;ooo]Z00?oo`1ioookJ_oonfX02?oonfX00ol0oe?ooo]ZoookJP02oookJP04o`3o7Ol0o`So
oo]Zo`3Qoa3ooo]Z00Co0?ldoookJ_oonf[o0?m>1ooonfX01?l0R?oooo]ZoookJ_l0ZOl4oookJP05
o`04oooonf[ooo]ZoookJ_l0e?l0=ooonfX005Oooo]Z00?oo`3ZoookJ_oonfX07OoonfX2oolF00?o
oo]Z0_ooTP0_oookJP;ooi800ooonfX00ooo5P3ooo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z01Ko
oo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0_oonfX01?l0Looo001oo`00Ool007l6
oookJPKo00001_oonfX01Onio`3ooo]ZoookJ_ooDP3o0?lc00?ooo]Z00Ko02[ooookJ_oonf[o?ol0
oookJ_l0g?l2oiCo0003ogSo0?nDo`3oU?l000;oU?l02?oonfX01Ol0S_oo0?lKoa80oooonf[oolX0
00Oooo]Z00?oo`2CoookJ_oo01<02?oonfX00ooQo`3of_l0oookJP03oookJP03obH0oom4o`3ooo]Z
01Gooo]Z00Co<Ol0oookJ_oonf[oA?l01?oonfX02?n2o`3ooo]ZoookJ_l0<?oo0?naoookJ_l0j?oo
0?m=0_oonfX01OnDo`3ooo]ZoookJ_oonf[oT_l000?ooo]Z00?o403oo`0IoooonfX01OoonfX01olE
0?ooo`1AoookJ_oonf[o0:gooookJ_oo07T02ooonfX00ol0oe?ooo]ZoookJP02oookJP04odCo0?l0
o`Sooo]Zo`3Qo`oooo]Z00Go0?ldoookJ_oonf[o0?m>o`3o;P07oookJP03o`28oooonf[o0:Wo00Go
oo]Z00Go00CooookJ_oonf[ooo]Zo`3Do`0BoookJP03oon10?oonf[ooo]Z07Kooo]Z00?oo`3Zoook
J_oonfX07OoonfX2oolF00?ooo]Z0_ooTP0_oookJP;ooi800ooonfX00ooo5P3ooo]ZoookJP0Eoook
JP03ool0j_oonf[ooo]Z01Gooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0_oonfX0
1?l0Looo001oo`00Ool007l6oookJPKo00001_oonfX01Onio`3ooo]ZoookJ_ooDP3o0?lc00?ooo]Z
00_o02[ooookJ_oonf[ooo]Zocoo0?oonf[o0=cooookJ_mho`3ooo]Zo`3og`0:oookJP06o`2>ool0
oa_ooo]Zoa80oooonf[oolX01_oonfX01?oo09?ooo]ZoookJ_oo01<7oookJP03on7o0?oJo`3ooo]Z
00?ooo]Z00?o9P3oob3o0?n40?l05OoonfX01Olao`3ooo]ZoookJ_oonf[o0?mK00?ooo]Z00So0?n`
oh;o0?oonf[ooo]Zo`0`oooonf[o0>Soo`3oC@?ooo]Z00Co1P3ooookJ_oonf[oT_l00ooonfX00ol@
0?ooo`1Zo`0Io`05oookJP05oaD0oooonf[oo`1AoookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP08
oookJP03o`3oDooonf[ooo]Z00;ooo]Z00Co0?lMo`3o2?oonf[o0>7o4?oonfX01Ol0ocCooo]Zoook
J_l0odko0?l^00Kooo]Z00Co08SooookJ_oonf[o0:Wo1?oonfX01Ol01?oooo]ZoookJ_oonf[o0=Co
01?ooo]Z00?ooh40oookJ_oonfX08_oonfX00>;ooo]Z1?l007l2oookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`Kooo]Z1?l0003ooookJ]Kooo]Z1?l007l2oookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`Kooo]Z1?l0003goookJP00h_oonfX8o`00O`;ooo]Z0ol007l3oook
JP?o001o1_oonfX4o`000?oooo]Ze_oonfX8o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX4o`00
0?Oooo]Z003RoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`?ooo]Z0ol007oooook
J^3ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o0ooonfX3o`00Oooooo]Z0_oonfX0
0>;ooo]Z0ol007l7oookJP?o001o0ooonfX3o`00Oooooo]Zh?oonfX3o`00O`Oooo]Z0ol007l3oook
JP?o001ooooonfX2oookJP00h_oonfX3o`00O`Oooo]Z0ol007l3oookJP?o001ooooonf[PoookJP?o
001o1ooonfX3o`00O`?ooo]Z0ol007oooookJP;ooo]Z003SoookJP?o001o0_oonfX3o`00O`;ooo]Z
0ol007l01?oonf[o001oo`00Ool007oooookJ^;ooo]Z0ol007l2oookJP?o001o0_oonfX3o`00O`04
oookJ_l007oo001oo`00Oooooo]Z0ooonfX00>?ooo]Z1ol007l3oookJPOo001ooooonf[RoookJPOo
001o0ooonfX7o`00Oooooo]Z0ooonfX00>Gooo]Z1?l007l5oookJPGo001ooooonf[UoookJPCo001o
1OoonfX5o`00Oooooo]Z1?oonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[
oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Z
oooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooook
J_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z
003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooook
J^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooo
nf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oo
oo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]Zjooo
nfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oo
oo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[o
oookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00
oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[
oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Z
oooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooook
J_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z
003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooook
J^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooo
nf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oo
oo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]Zjooo
nfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oo
oo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[o
oookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00
oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[
oookJP00oooonf[ooookJ_oooo]ZjooonfX00>Kooo]Z0ol007l5oookJPGo001ooooonf[VoookJP?o
001o1OoonfX5o`00Oooooo]Z1?oonfX00>Kooo]Z0ol007l4oookJPOo001ooooonf[UoookJP?o001o
1?oonfX7o`00Oooooo]Z0ooonfX00>Kooo]Z0ol007l3oookJPCo001o00Cooo]Zo`00Ool007oo001o
oooonf[UoookJP?o001o0ooonfX4o`00O`04oookJ_l007oo001oo`00Oooooo]Z0ooonfX00=Kooo]Z
2_l007l6oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000oooonf[:oookJP[o001o
1_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX4o`000?Oooo]Z000`oookJP03on7o0?oJ
o`3ooo]Z00Oooo]Z00Koo`0CoookJ_oonf[ooo]Zool0Tol0nOl5oookJP03ooo:0?oonf[ooo]Z00?o
oo]Z00?o0?lKoookJ_oonfX03?oonfX01_l0omooN?l0oookJ_l0g?oooo]Zocoo00Gooo]Z00?o02[o
oookJ_oonfX00_oonfX01?ooDP3ooo]ZoookJ_nio`0DoookJP03o`1coooonf[ooo]Z01Sooo]Z00?o
o`3ZoookJ_oonfX02?oonfX01?oo5P3ooo]ZoonB0?oonfX5ooo900Gooo]Z00?oolT0oookJ_oo1P00
0ooonfX00oo[o`3ooo]Zool0mP02oookJP04o`2Voooonf[ooo]ZojP0o`?ooo]Z00Koo`3ioookJ_l0
Mooooo]Zoomi0?oonfX5oolX0004oc_o0?oo:03ooo]Zo`00O`;o0?_o1Ol007l00ooo0`3o001ooook
JP02ogT0o`;oo`3M00Co01Ooo`2Soonco`3o/ol01_oonfX00ol0omkoo`27ool0Q`03o`00O`03oook
J_oo06coo`1/00?ooo]Z0_m=0?l01Ooo;P3oH@3oof40ool0003ooo]Z00;o0?m51OoonfX2oolX0003
o`3oT?oonf[ooo]Z00;ooo]Z0_oob@0=oookJP;oJ03o2_oonfX2oaP0o`03o`1doooonf[ooo]Z00;o
i_l02?oonfX3oon@05Sooo]Z0oooT00=oookJP;oiOl00_l0M?l2oookJP?o603o2ooonfX2oomi01Go
oo]Z00?o0?nBoookJ_oonfX0CooonfX00ooQo`3of_l0oookJP08oookJP06ool04ooonf[ooo]Zool0
Tooonf[o0?Wo1OoonfX00ooobP3ooo]ZoookJP02oookJP03o`3o6olB0?oooo]Z00cooo]Z00Oo0?oO
ogSo0?lm0?oooo]Zo`3Loooonf[o?ol000Gooo]Z00So02[ooookJ_oonf[ooo]Zo`3o<oooDP3ooo]Z
okWo01Cooo]Z00?o07?ooookJ_oonfX06?oonfX00ooo0>[ooo]ZoookJP08oookJP03oolF0?oonf[o
oi8000Cooo]Z00?oo`3loookJ_oonfX01?oonfX00olH0?oooo]Zool60004oookJP05on_o0?oo0?Ko
oo]ZoookJ_l0Y_l00_oonfX01OnX0?oooo]ZoookJ_oonf[oo`3i00;ooo]Z00Co07OooookJ_l0oi[o
of`00_l0ol`00oooP@3ooo]Zoc_o0002oookJP;o001o00?o0?_oo`00Ool007l00ol007l01Ooo0`3o
001ooookJ_oonf[oN@3o00;oo`3M00Co01Ooo`2Soonco`3o/ol01_oonfX2o`3ogP;oo`270_l007l0
0ooonf[oo`1/ool0K003oookJP;oC@3o00Goobh0of40oomQ0?oo0000oookJP02o`3oA@Gooo]Z0_oR
0?l2o`3oT0?ooo]Z0_l0oi8=oookJP;oJ03o2_oonfX2oaP0o`;o07Co00?ooo]ZonKo0?oVo`002?oo
nfX3oon@05Wooo]Z0oooT00<oookJP;oi_l000Cooo]Zo`1dool0M?oooo]Z0olH0?l;oookJP;oJ03o
5_oonfX00ol0oi;ooo]ZoookJP0RoookJP00<?oonfX00ooQo`3of_l0oookJP07oookJP06ool04ooo
nf[ooo]ZoookJ_oo09?o0?Wo1OoonfX00ooobP3ooo]ZoookJP03oookJP03o`3o6ooonf[ooo]Z00co
oo]Z00Ko0?oOogSo0?oonf[o0=cooookJ_loo`05oookJP03o`0Zoooonf[ooo]Z00;ooo]Z00Cooe80
oookJ_oonf[o^Ol05?oonfX00ol0Looooo]ZoookJP0HoookJP03ool0j_oonf[ooo]Z00Sooo]Z00?o
oaH0oookJ_ooTP001_oob@05oookJP03ooo90?oonf[oo`H000?ooo]Z00?ojol0oookJ_oo0?H00_oo
nfX00ol0Y_oooo]ZojP0o`04oookJP03ool0nOoonf[o07Oo00;oogT000?oof`0o`3oc?oo:0000ooo
:0001?lko`3oobP0oookJ_l0nol7oookJP09ool30?oonf[oN@3ooookJ_oo0=gooo]Zo`0Gool0Xooo
/ol000;o001o1OoonfX01?l0omkoo`27oookJ_oonfX3o`00O`03ool0K?oonf[ooo]Z00;ooo]Z00Go
C@3oo`000?oo;P3oH@3oo`000002oookJP03o`3oAOoonf[ooo]Z00Cooo]Z00?oobP0o`3oT?oonfX0
1?oonfX00ooob@3ooo]ZoookJP0;oookJP;oJ03o2_oonfX2oaP0o`03o`1doooonf[oi_l000;oi_l0
1OoonfX5oon@05kooo]Z0oooT00<oookJP03onGo0?oonf[o07Co00;o07Co0_oonfX3oaP0o`[ooo]Z
00?oogT0oookJ_oonfX0I?oonfX00ooQo`3of_l0oookJP08oookJP06ool04ooonf[ooo]Zool0Tooo
nf[o0?Wo1OoonfX00ooobP3ooo]ZoookJP02oookJP03o`3o6olB0?oooo]Z00cooo]Z00Oo0?oOogSo
0?lm0?oooo]Zo`3Loooonf[o?ol000Gooo]Z00So02[ooookJ_oonf[ooo]Zo`3o<oooDP3ooo]ZokWo
01Cooo]Z00?o07?ooookJ_oonfX06?oonfX00ooo0>[ooo]ZoookJP08oookJP03oolF0?oonf[ooi80
00Cooo]Z00?oo`3loookJ_oonfX01?oonfX00olH0?oooo]Zool60004oookJP07on_o0?oo0?Kooo]Z
oookJ_l0Y_oooo]ZojP0o`04oookJP07ool0nOoonf[ooo]Zo`1gool0oi[oof`0o`3oc002oookJP03
oon10?oonf[o>ol000?ooo]Z00?o0?_ooookJ_oonfX01?oonfX02Ooo0`3ooo]ZoookJ_mi0?ooo`3M
oookJ_l05ooo0:?ook?o0002o`00O`Gooo]Z00Co0?oNomgo0?oo08Oooo]Z0ol007l00ooo06cooo]Z
oookJP02oookJP05odd0ool0003oobh0of40ool000000_oonfX00ol0odGooo]ZoookJP04oookJP03
on80oooonf[o0?n@00Cooo]Z00?o0?nBoookJ_oonfX02ooonfX2ofP0o`[ooo]Z0_lH0?l2o`1do`?o
i_l01OoonfX5oon@05oooo]Z0oooT00;oookJP03onKo0?oonf[ooo]Z00?o07Co00Cooo]ZoaP0oolH
0?oo603o2_oonfX00omX0?oooo]ZoookJP0hoookJP00;ooonfX00ooQo`3of_l0oookJP07oookJP06
ool04ooonf[ooo]ZoookJ_oo09?o0?Wo1OoonfX00ooobP3ooo]ZoookJP03oookJP03o`3o6ooonf[o
oo]Z00cooo]Z00Ko0?oOogSo0?oonf[o0=cooookJ_loo`05oookJP03o`0Zoooonf[ooo]Z00;ooo]Z
00Cooe80oookJ_oonf[o^Ol05?oonfX00ol0Looooo]ZoookJP0HoookJP03ool0j_oonf[ooo]Z00So
oo]Z00?ooaH0oookJ_ooTP001_oob@05oookJP03ooo90?oonf[oo`H000?ooo]Z00?ojol0oookJ_oo
0?H00_oonfX00ol0Y_oooo]ZojP0o`04oookJP07ool0nOoonf[o07OooookJ_l0oi[oof`0o`3oc002
oookJP;oobP000Co>ol0oolX0?oonf[o0?_o1ooonfX02Ooo0`3ooo]ZogT0oooonf[oo`3MoookJ_l0
5ooo0:?ook?o0003o`00O`Cooo]Z00Co0?oNool0Qooonf[ooo]Z0ol007l00ooo06cooo]ZoookJP02
oookJP04odd0oooonf[oobh0of40o`;o00000_l0odD5oookJP;oobP000?o0?n@oookJ_oonfX00_oo
nfX2ooo900gooo]Z00?oJ03ooookJ_oonfX02?oonfX2oaP0o`04o`1doooonf[oi_l0onKo00Cooo]Z
1?ooT01VoookJP?ooi002_oonfX2onGo00;ooo]Z0_l0M?l3oookJP03oaP0oooonf[ooo]Z00Sooo]Z
00?oogT0oookJ_oonfX0H_oonfX00ooQo`3of_l0oookJP08oookJP06ool04ooonf[ooo]Zool0Tooo
nf[o0?Wo1OoonfX00ooobP3ooo]ZoookJP02oookJP03o`3o6olB0?oooo]Z00cooo]Z00Oo0?oOogSo
0?lm0?oooo]Zo`3Loooonf[o?ol000Gooo]Z00So02[ooookJ_oonf[ooo]Zo`3o<oooDP3ooo]ZokWo
01Cooo]Z00?o07?ooookJ_oonfX06?oonfX00ooo0>[ooo]ZoookJP08oookJP03oolF0?oonf[ooi80
00Cooo]Z00?oo`3loookJ_oonfX01?oonfX00olH0?oooo]Zool60004oookJP07on_o0?oo0?Kooo]Z
oookJ_l0Y_oooo]ZojP0o`04oookJP07ool0nOoonf[ooo]Zo`1goooonf[oof`0o`3oc002oookJP03
oon10?oonf[o>ol000?ooo]Z00?o0?_ooookJ_oonfX01?oonfX02Ooo0`3ooo]ZoookJ_mi0?ooo`3M
oookJ_l05ooo0:?ook?o0003o`00O`Cooo]Z00Co0?oNo`00Oooo08Oooo]Z0ol007l00ooo06cooo]Z
oookJP02oookJP04odd0oooonf[oobh0of40o`;o00000_l0odD5oookJP;ohP3o0_l0oi03oookJP;o
0?nB3OoonfX00omX0?oooo]ZoookJP08oookJP;o603o0_l0M?l2onKo00Cooo]Z1?ooT01WoookJP?o
oi002OoonfX2onKo00?ooo]Z0_l0M?l2oookJP03oaP0oooonf[ooo]Z00Sooo]Z0_mX0?lhoookJP00
;_oonfX00ooQo`3ooo]Zom[o0008oookJP06ool04ooonf[ooo]Zool0Tooonf[o0?Wo1OoonfX00ooo
bP3ooo]ZoookJP03oookJP03o`3o6ooonf[ooo]Z00_ooo]Z00Oo0?oOoookJ_mho`3ooo]Zo`3Loooo
nf[o?ol000Cooo]Z00?o02[ooookJ_oonfX00_oonfX01?ooDP3ooo]ZoookJ_nio`0DoookJP03o`1c
oooonf[ooo]Z01Sooo]Z00?oo`3ZoookJ_oonfX02?oonfX00ooo5P3ooo]ZoonB0007ooo900Cooo]Z
00?oolT0oookJ_oo1P000ooonfX00oo[o`3ooo]Zool0mP02oookJP03o`2Voooonf[oZ03o00Cooo]Z
00Ooo`3ioookJ_l0Mooooo]Zo`3oV_ooK03o0?o<00;ooo]Z00?oobP0oookJ_lko`000_oo:0000ol0
nooooo]ZoookJP05oookJP05ool30?oonf[ooo]ZogT0oooo0=d00_l05ol00ol0Xooo/ol0oookJP03
o`00O`?ooo]Z00?o0?oNool0Qol007l01?l007l00ooo06cooo]ZoookJP02oookJP04odd0oooo;P3o
obh0of40o`;o000000?o0?m5oookJ_oonfX01?oonfX00ooo:03o0?n@oookJP03oookJP;oolT03Ooo
nfX2ofP0o`Wooo]Z0_lH0?l01?l0M?ooi_l0onKo0?oVo`03oookJP?ooi00KOoonfX3oon@00Wooo]Z
0_oUo`02oookJP05o`1doooonf[ooo]ZoookJ_lH0?l02_oonfX2oomi067ooo]Z00?ohOl0oookJ_oJ
o`002OoonfX01_oo01?ooo]ZoookJ_oo09?ooo]Zo`3io`Gooo]Z00?oolX0oookJ_oonfX00_oonfX0
0ol0oa_o4P3ooookJP0;oookJP03o`3ogooonf[oN?l000;ooo]Z00?o0=cooookJ_loo`001?oonfX0
2?l0:_oooo]ZoookJ_oonf[o0?lcoomB0?oonf[o^Ol05?oonfX00ol0Looooo]ZoookJP0HoookJP03
ool0j_oonf[ooo]Z00Sooo]Z00?ooaH0oookJ_ooTP001?oonfX00ooo0?cooo]ZoookJP04oookJP03
oaP0oooonf[oo`H000Cooo]Z00Oojol0ool0m_oonf[ooo]Zo`2Voooonf[oZ03o00Cooo]Z00Ooo`3i
oookJ_oonf[o07OooookJ_ooK03o0?o<00;ooo]Z00?ooh40oookJ_lko`000ooonfX00ol0nooooo]Z
oookJP04oookJP0:ool30?oonf[ooo]ZoookJ_oo0=gooo]Zo`0Gool0Xooo/ol0oookJP?o001o0ooo
nfX00ol0omkogOl0ool0Q`04o`00O`03ool0K?oonf[ooo]Z00;ooo]Z00CoC@3oool^0?oo;P3oH@3o
0_l000000ol0odGooo]ZoookJP04oookJP03on80ool0oi3o0?n@00?ooo]Z0_l0oi8=oookJP;oJ03o
2OoonfX2oaP0o`04o`1doooVo`3oi_l0onKo00?ooo]Z0oooT01^oookJP?ooi002?oonfX2onKo00?o
oo]Z00Co07CooookJ_oonf[o603o2ooonfX00omX0?oooo]ZoookJP0eoookJP00;_oonfX00ooQo`3o
f_l0oookJP07oookJP06ool04ooonf[ooo]ZoookJ_oo09?o0?Wo1OoonfX00ooobP3ooo]ZoookJP03
oookJP03o`3o6ooonf[ooo]Z00_ooo]Z00Oo0?oOoookJ_mho`3ooo]Zo`3Loooonf[o?ol000Gooo]Z
00Ko02[ooookJ_oonf[ooo]Zo`3o<oooDP02oookJP03okWo0?oonf[ooo]Z01;ooo]Z00?o07?ooook
J_oonfX06?oonfX00ooo0>[ooo]ZoookJP07oookJP03oolF0?oonf[ooi8000SoolT00ooonfX00ooo
b@3ooo]Zool60003oookJP03on_o0?oonf[oo`3f00;ooo]Z00?o0:KooookJ_nX0?l01?oonfX01ooo
0?Wooo]Zo`1goooonf[o0?nJoom/0?l0ol`00_oonfX01_oo:03ooo]Zoc_o0?oonf[oobP0o`3ko`Oo
oo]Z00Woo`<0oookJ_oonf[oN@3oool0gOl05ooooo]Zo`2Soonco`000_oonfX3o`00O`;ooo]Z00?o
0?oNool0Qol007l01?l007l01?oo06cooo]ZoookJ_oonfX2odd0o`04ool^0?oonf[oH@3oo`0000;o
0?m500?o0000oookJ_oonfX00_oonfX2oolX00Gooo]Z00?oolT0oookJ_oonfX02ooonfX2ofP0o`Wo
oo]Z0_lH0?l3onKo00Cooo]Z0_ooT00UoookJPGoogT0BOoonfX3oon@00Sooo]Z00CoiOl0oookJ_oo
nf[o07Co0ooonfX00olH0?oooo]ZoookJP09oookJP03oomi0?oonf[ooo]Z05kooo]Z00?ohOl0om[o
0?oonfX02?oonfX01_oo01?ooo]ZoookJ_oo09?ooo]Zo`3io`Gooo]Z00?oolX0oookJ_oonfX00_oo
nfX00ol0oa_o4P3ooookJP0;oookJP08o`3ogooonf[oN?l0ocd0oooonf[o0=cooookJ_loo`05oook
JP08o`0Zoooonf[ooo]ZoookJ_l0oc?ooe80oookJ_nio`0DoookJP03o`1coooonf[ooo]Z01Sooo]Z
00?oo`3ZoookJ_oonfX01ooonfX00ooo5P3ooo]ZoonB0005oookJP03ool0o?oonf[ooo]Z00?ooo]Z
00?o603ooookJ_oo1P001?oonfX01oo[o`3oo`3foookJ_oonf[o0:KooookJ_nX0?l01?oonfX01ooo
0?Wooo]ZoookJ_l0Mooooo]Zoom/0?l0ol`00_oonfX00oooP@3ooo]Zoc_o0003oookJP03o`3koooo
nf[ooo]Z00Cooo]Z00Woo`<0oookJ_oonf[ooo]Zool0gOoonf[o01Ooo`2Soonco`000_oonfX3o`00
O`;ooo]Z00?o0?oNomgo0?oo08L01?l007l01?oo06cooo]ZoookJ_oonfX2odd0o`04ool^0?oonf[o
H@3oo`0000;o0?m500?o0000oookJ_oonfX00ooonfX00ooR0?oo0?n@oookJP03oookJP03o`3oT_oo
nf[ooo]Z00_ooo]Z0_mX0?l9oookJP;o603o0ooVo`04oookJP;ooi00M?oonfX3oon@00Oooo]Z00Go
i_l0oookJ_oonf[ooo]Zo`1do`02oookJP03oaP0oooonf[ooo]Z00Wooo]Z00?oJ03ooookJ_oonfX0
=?oonfX002gooo]Z00?ohOl0oookJ_oJo`002?oonfX01_oo01?ooo]ZoookJ_oo09?ooo]Zo`3io`Go
oo]Z00?oolX0oookJ_oonfX00_oonfX00olB0?oo0?lKoookJP0<oookJP07o`3ogolm0?ooN?l0oook
J_l0g?oooo]Zocoo0004oookJP03o`0Zoooonf[ooo]Z00;ooo]Z00Cooe80oookJ_oonf[o^Ol05?oo
nfX00ol0Looooo]ZoookJP0HoookJP03ool0j_oonf[ooo]Z00Sooo]Z00?ooaH0oonB0?oob@001ooo
b@03oookJP03ooo90?oonf[oo`H000?ooo]Z00?ojol0oookJ_oo0?H00_oonfX00ol0Y_oooo]ZojP0
o`04oookJP07ool0nOoonf[o07OooookJ_l0oi[oof`0o`3oc002oookJP03oolX0?oonf[o>ol000;o
oo]Z00?o0?_ooookJ_oonfX01OoonfX00ooo0`3ooo]ZoookJP02ool0g@04o`0Goooonf[o0:?ook?o
00Ko001o00Cooo]Zo`3og_oo08Oooo]Z0_l007l00ooonf[oo`1/ool0K003oookJP05odd0oooonf[o
obh0oookJ_mQ0?l00_l0odD3o`0000?ooo]Z00?oobP0o`3oT?oonfX00ooonfX2ooo900cooo]Z0_mX
0?l9oookJP;o603o0_oVo`05oookJP;ooi009ooonfX<oomi04Gooo]Z0oooT006oookJP;oiOl000?o
oo]Zo`1doooonfX00_oonfX00olH0?oooo]ZoookJP09oookJP03oomi0?oonf[ooo]Z00?ooo]Z00?o
ogT0oookJ_oonfX0E_oonfX00ooQo`3ooo]Zom[o0009oookJP06ool04ooonf[ooo]Zool0Tooonf[o
0?Wo1OoonfX00ooobP3ooo]ZoookJP02oookJP03o`3o6ooonf[ooo]Z00_ooo]Z00?o0?oOoookJ_mh
o`000_oonfX00ol0g?oooo]Zocoo0004oookJP08o`0Zoooonf[ooo]ZoookJ_l0oc?ooe80oookJ_ni
o`0DoookJP03o`1coooonf[ooo]Z01Sooo]Z00?oo`3ZoookJ_oonfX02?oonfX00ooo5P3ooi80oook
JP04oookJP03ool0o?oonf[ooo]Z00?ooo]Z00?o603ooookJ_oo1P001?oonfX01oo[o`3oo`3foook
J_oonf[o0:KooookJ_nX0?l01?oonfX01ooo0?Wooo]ZoookJ_l0Mooooo]Zoom/0?l0ol`00_oonfX0
0oooP@3ooo]Zoc_o0003oookJP03o`3koooonf[ooo]Z00Cooo]Z00Woo`<0oookJ_oonf[ooo]Zool0
gOoonf[o01Ooo`2Soonco`001_l007l01?oonf[o0?oNomgo0?oo08L2o`00O`;ooo]Z00Woo`1/oook
J_oonf[ooo]Zodd0oooonf[oobh0oookJ_mQ0?l00_l0odD3o`0000?ooo]Z0_oR0?l01?l0oi3ooo]Z
oookJ_oonfX2o`3oTPcooo]Z0_mX0?l9oookJP;o603o0_oVo`05oookJP;ooi00NOoonfX3oon@00Go
oo]Z0_oVo`02oookJP04o`1doooonf[ooo]ZoaP0o`_ooo]Z0_mX0?ldoookJP00;OoonfX00ooQo`3o
f_l0oookJP08oookJP05ool04ooonf[ooo]Zool0Tol0nOl01_oonfX00ooobP3ooo]ZoookJP02oook
JP03o`3o6ooonf[ooo]Z00_ooo]Z00Oo0?oOoookJ_mho`3ooo]Zo`3Loooonf[o?ol000Gooo]Z00Go
02[ooookJ_oonf[ooo]ZoomB0003oookJP03okWo0?oonf[ooo]Z017ooo]Z00?o07?ooookJ_oonfX0
6?oonfX00ooo0>[ooo]ZoookJP08oookJP03oolF0?oonf[oolT000SoolT00ooonfX00ooob@3oo`H0
oookJP02oookJP03on_o0?oonf[oo`3f00?ooo]Z00?o0:KoojP0oooonfX00ooonfX01ooo0?Wooo]Z
o`1goooonf[o0?nJoom/0?l0ol`00_oonfX00ooo:03ooo]Zoc_o0002oookJP03o`3koooonf[ooo]Z
00Gooo]Z00[oo`<0oookJ_oonf[oo`3MoookJ_l05ooooo]Zo`2Soonco`3ooo]Z1_l007l01?l0omko
o`27oookJ_oonfX2o`00O`03ool0K?oonf[ooo]Z00;ooo]Z00?oC@3ooookJ_oo;P000_mQ0?l00ol0
odGooo]Zo`000003o`000003oookJ_oo:03oobP000Cooo]Z0_oob@0=oookJP03ofP0oooonf[ooo]Z
00Oooo]Z0_lH0?l2onKo00Gooo]Z0_ooT00YoookJQ3oogT01?oo_P10oookJP?ooi001OoonfX01?oU
o`3ooo]Zo`1dool0M?l2oookJP03oaP0oooonf[ooo]Z00Wooo]Z0_ooN@03oookJP03oomi0?oonf[o
oo]Z05Kooo]Z00?ohOl0om[o0?oonfX02?oonfX01_oo01?ooo]ZoookJ_oo09?ooo]Zo`3io`Kooo]Z
00KoolX0oookJ_oonf[ooo]Zo`3o6olB0?l<oookJP08o`3ogooonf[oN?l0ocd0oooonf[o0=cooook
J_loo`05oookJP05o`0Zoooonf[ooo]Zo`3o<oooDP000_oonfX00onio`3ooo]ZoookJP0AoookJP03
o`1coooonf[ooo]Z01Sooo]Z00?oo`3ZoookJ_oonfX02?oonfX00ooo5P3ooo]ZoonB0004oookJP03
ool0o?oonf[ooo]Z00Cooo]Z00?o603oool60?oonfX00ooonfX00oo[o`3oo`3foookJP02oookJP03
o`2VoonX0?oooo]Z00?ooo]Z00Ooo`3ioookJ_oonf[o07OooookJ_ooK03o0?o<00;ooo]Z00?ooh40
oookJ_lko`000ooonfX00ol0nooooo]ZoookJP04oookJP0:ool30?oonf[ooo]ZoookJ_oo0=gooo]Z
o`0Gool0Xooo/ol0oookJPKo001o00Co0?oNomgo0?oo08Oooo]Z0_l007l2ool0K0?ooo]Z00OoC@3o
oookJ_oo;P3ooo]Zof40ool0odGooo]Z00Co00000_oonfX00ooR0?oo0?n@oookJP03oookJP03o`3o
T_oonf[ooo]Z00_ooo]Z00?oJ03ooookJ_oonfX01ooonfX2oaP0o`;oi_l01OoonfX2oon@03Gooo]Z
2Ooo_P10oookJP;ooi001OoonfX2onKo0005oookJ_l0M?oooo]ZoookJ_lH0?l03?oonfX00omX0?oo
oo]ZoookJP0aoookJP00;?oonfX00ooQo`3ooo]Zom[o0008oookJP06ool04ooonf[ooo]Zool0Tooo
nf[o0?Wo1OoonfX00ooobP3ooo]ZoookJP02oookJP03oa80ool0oa_ooo]Z00_ooo]Z00So0?oOoook
J_lm0?ooN?l0oookJ_l0g?oooo]Zocoo00Cooo]Z00Ko02[ooookJ_oonf[ooo]Zo`3o<oooDP02oook
JP03okWo0?oonf[ooo]Z01;ooo]Z00?o07?ooookJ_oonfX06?oonfX00ooo0>[ooo]ZoookJP07oook
JP03oolF0?oonf[ooi8000;ooo]Z1_oob@03oookJP03ooo90?oo1P3ooo]Z00;ooo]Z00?ojol0oook
J_oo0?H00ooonfX00ol0Y_ooZ03ooookJP03oookJP03ool0nOoonf[o07Oo00;ooo]Z00Soof`0o`3o
c?oonf[ooo]ZoolX0?oonf[o>ol0oookJP;oogT01ooonfX01?oo0`3ooo]ZoookJ_oo0=d2oookJP;o
0:?o00?o/ol0oookJ_oonfX00_oonfX3o`00O`03o`3og_oo08Oooo]Z00?ooo]Z00?oo`1/o`00Ool0
07l00_l007l01?m=0?ooobh0ool^0?mQ0?l2o`3oA@;ooo]Z1?l000000ooo:03o0?n@oookJP03oook
JP03ooo90?oonf[ooo]Z00_ooo]Z0_mX0?l8oookJP;o603o00?oi_l0o`1doooonfX01OoonfX00ooo
T03ooo]ZoookJP0YoookJPkoogT01_oonfX7oonn00;ooo]Z0oooN@0goookJP03oon@0?oonf[ooo]Z
00?ooo]Z0_oUo`001Ooonf[o07CooookJ_oUo`3o603o00cooo]Z00?oogT0oookJ_ooN@000_ooN@1F
oookJP03on7o0?oonf[of_l000Wooo]Z00?oo`0CoookJ_oo09<00_oonfX00ol0nOoooo]ZoookJP03
oookJP03ooo:0?oonf[ooo]Z00;ooo]Z00?o0?lKoookJ_oonfX02_oonfX01?l0omoooo]ZoookJ_mh
o`02oookJP03o`3Loooonf[o?ol000Cooo]Z00So02[ooookJ_oonf[ooo]Zo`3o<oooDP3ooo]ZokWo
01Cooo]Z00?o07?ooookJ_oonfX06?oonfX00ooo0>[ooo]ZoookJP07oookJP03oolF0?oonf[ooi80
00Cooo]Z00?oo`3loookJ_oonfX01?oonfX00olH0?ooo`H0oookJP03oookJP03on_o0?oonf[oo`3f
00;ooo]Z00?o0:KoojP0oooonfX00ooonfX01ooo0?Wooo]ZoookJ_l0Mooooo]Zoom/0?l0oiX00_oo
nfX00oooP@3ooo]Zoc_o0003oookJP03o`3koooonf[ooo]Z00Cooo]Z00Goo`<0oookJ_oonf[ooo]Z
ool0g@02oookJP03o`2Soonco`3ooo]Z00?ooo]Z0ol007l00ol0omkogOl0ool0Q`03oookJP03ool0
K?l007oo001o00;o001o00KoC@3oool^0?oo;P3ooo]Zof40ool0odD2oookJPCo00000_oR0?l01?l0
oi3ooo]ZoookJ_oonfX2o`3oTPcooo]Z0_mX0?l8oookJP;o603o00?oi_l0o`1doooonfX01OoonfX0
0oooT03ooo]ZoookJP0]oookJPSookh02OoonfX7oonn03_ooo]Z00?ooi00oookJ_oonfX01?oonfX0
1OoVo`3ooo]Zo`1dool0M?oooo]Z00;o603o2ooonfX2ofP0oc7ooo]Z000[oookJP03on7o0?oonf[o
f_l000Wooo]Z00Goo`0CoookJ_oo09?ooo]Zo`3io`06oookJP03ooo:0?oonf[ooo]Z00;ooo]Z00?o
0?lKoookJ_oonfX02_oonfX02?oob@3ooo]ZoookJ_mho`3ooo]Zo`3Loooonf[o?ol01?oonfX00ol0
:_oooo]ZoookJP02oookJP04oomB0?oonf[ooo]ZokWo01Cooo]Z00?o07?ooookJ_oonfX06?oonfX0
0ooo0>[ooo]ZoookJP07oookJP03oolF0?oonf[ooi8000Cooo]Z1Ooob@02oookJP03ooo90?oonf[o
o`H000?ooo]Z00?ojol0ool0m_oonfX00_oonfX00ol0Y_ooZ03ooookJP03oookJP03ool0nOoonf[o
07Oo00;ooo]Z00Soof`0o`3oc?oonf[ooo]ZoolX0?oonf[o>ol0oookJP?oogT01_oonfX01?oo0`3o
oo]ZoookJ_oo0=d2oookJP03o`2Soooonf[o/ol000Kooo]Z00?o001oo`3og_oo08L01?oonfX01?oo
06co001oo`00Ool007l2odd0o`04ool^0?l007ooH@3oo`3oA@Cooo]Z0_l00002oolX00Cooo]Z0_oo
b@0<oookJP;oJ03o2?oonfX2oaP0o`03onKo0?l0M?oooo]Z00Gooo]Z0_ooT00XoookJPooogT04?oo
nfX8oonn03Gooo]Z00?ooi00oookJ_oonfX01?oonfX5onGo00;o603o2ooonfX5oomi05Cooo]Z00?o
hOl0oookJ_oJo`002_oonfX01Ooo01?ooo]Zool0Tooonf[o0?Wo00Kooo]Z00KoolX0oookJ_oonf[o
oo]Zo`3o6olB0?l;oookJP04o`3ogooonf[ooo]ZogSo00;ooo]Z00?o0=cooookJ_loo`001?oonfX0
2?l0:_oooo]ZoookJ_oonf[o0?lcoomB0?oonf[o^Ol05?oonfX00ol0Looooo]ZoookJP0HoookJP03
ool0j_oonf[ooo]Z00Oooo]Z00?ooaH0oookJ_ooTP001OoonfX00ooo0?cooo]ZoookJP03oookJP03
oaP0oooonf[oo`H000Cooo]Z00Kojol0ool0m_oonf[ooo]Zo`2VoonX0?l4oookJP07ool0nOoonf[o
oo]Zo`1goooonf[oof`0o`3oVP03oookJP03oon10?lko`3ooo]Z00?ooo]Z00?o0?_ooookJ_oonfX0
0ooonfX00ooo0`3ooo]ZoookJP02ool0g@;ooo]Z00?o0:?ook?o0?oonfX01OoonfX01?l007oo0?oN
omgo0?oo08L3oookJP04ool0K?l007oo001oo`00O`;oC@3o00Coobh0o`00OomQ0?ooH@3o1?oonfX3
o`000003on80ool0oi3ooo]Z00?ooo]Z00?o0?nBoookJ_oonfX02_oonfX2ofP0o`Sooo]Z0_lH0?l0
0ooVo`3o07CooookJP05oookJP;ooi00:?oonfX8oonn01Sooo]Z2?oo_P0doookJP03oon@0?oonf[o
oo]Z00Cooo]Z0_oVo`001Ooonf[o07CooookJ_oonf[o603o00cooo]Z00?oJ03ooookJ_oonfX0;_oo
nfX002_ooo]Z00?ohOl0oookJ_oJo`002?oonfX01_oo01?ooo]ZoookJ_oo09?ooo]Zo`3io`Gooo]Z
00?oolX0oookJ_oonfX00_oonfX00olB0?oo0?lKoookJP0;oookJP08ooo90?oonf[o?@3oogSo0?oo
nf[o0=cooookJ_loo`04oookJP06o`0Zoooonf[ooo]ZoookJ_l0oc?ooe800_oonfX00onio`3ooo]Z
oookJP0AoookJP03o`1coooonf[ooo]Z01Sooo]Z00?oo`3ZoookJ_oonfX02?oonfX00ooo5P3ooi80
oookJP03oookJP03ooo90?oonf[ooo]Z00?oolT000Cooo]Zooo90?oonf[oo`H00ooonfX00oo[o`3o
oo]Zool0mP02oookJP03o`2VoonX0?oooo]Z00?ooo]Z00?oo`3ioookJ_l0Mol00_oonfX02?ooK03o
obP0oookJ_oonf[oobP0oookJ_lko`3ooo]Z0oooN@06oookJP04ool30?oonf[ooo]Zool0g@;ooo]Z
00?o0:?ooookJ_nco`001ooonfX00ol0omkoo`27oookJP03oookJP0:ool0K?oonf[ooo]ZoookJ_m=
0?oooo]Zool^0?oonf[oH@3oo`3oA@Gooo]Z00Co0000oolX0?l0003o00000_oonfX2ooo900cooo]Z
0_mX0?l8oookJP;o603o0_oVo`06oookJP;ooi008_oonfX8oomi00Gooo]Z2oooN@02og00o`Soj`3o
1ooonfX6oomi00Sookh0;_oonfX00oooT03ooo]ZoookJP05oookJPGoiOl000?o603ooookJ_oonfX0
2?oonfX6oomi05?ooo]Z00?ohOl0oookJ_oJo`002OoonfX00ooo01?ooo]Zool0T`02oookJP03o`3i
oooonf[ooo]Z00?ooo]Z00?oolX0oookJ_oonfX00_oonfX00ol0oa_ooo]ZoookJP0:oookJP04o`3o
gooonf[ooo]ZogSo00;ooo]Z00?o0=cooookJ_loo`001?oonfX01Ol0:_oooo]ZoookJ_oonf[ooe80
00;ooo]Z00?o^Ol0oookJ_oonfX04OoonfX00ol0Looooo]ZoookJP0HoookJP03ool0j_oonf[ooo]Z
00Sooo]Z00?ooaH0oonB0?oonfX01?oonfX00ooo0?cooo]ZoookJP03oookJP03oaP0oooonf[oo`H0
00Cooo]Z00Kojol0ool0m_oonf[ooo]Zo`2VoonX0?l5oookJP06ool0nOoonf[o07OooookJ_ooK03o
0?nJ0ooonfX00oooP@3o>ol0oookJP03oookJP03o`3koooonf[ooo]Z00?ooo]Z00Goo`<0oookJ_oo
nf[oo`3MogT0o`02oookJP03o`2Soonco`3ooo]Z00Kooo]Z00?o0?oNomgo0?oo08L00ooonfX02_oo
06cooo]ZoookJ_oonf[oC@3ooookJ_oo;P3ooo]Zof40ool0odD5oookJP04o`000?oR0?oohP3oo`00
00?ooo]Z0_l0oi8;oookJP;oJ03o2OoonfX00olH0?ooi_l0onKo0006oookJP;ooi008ooonfX7oonn
00Wooo]Z2?l0o`D2og00o`Soj`3o3OoonfX8oonn02gooo]Z00?ooi00oookJ_oonfX01OoonfX2onKo
0004o`1doooonf[ooo]ZoaP0o`cooo]Z00?oJ03ooookJ_oonfX0;OoonfX002[ooo]Z00CohOl0oook
J_oonf[of_l02?oonfX01Ooo01?ooo]Zool0Tooonf[o0?Wo00Kooo]Z00OoolX0oookJ_oonf[ooo]Z
oa80ool0oa_o08ko00_ooo]Z0_oob@001_lm0?ooN?l0oookJ_l0g?oooo]Zocoo00Cooo]Z00Ko02[o
oookJ_oonf[ooo]Zo`3o<oooDP02oookJP03okWo0?oonf[ooo]Z01;ooo]Z00?o07?ooookJ_oonfX0
6?oonfX00ooo0>[ooo]ZoookJP07oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00?oolT0oookJ_oonfX0
0_oonfX01Ooob@3ooo]Zooo90?oonf[oo`H000?ooo]Z00?ojol0oookJ_oo0?H00ooonfX00onX0?oo
oo]ZoookJP02oookJP06ool0nOoonf[ooo]Zo`1goooonf[oof`00_oo:002oookJP03oolX0?lko`3o
ogT000CoogT01OoonfX01?oo0`3ooo]ZoookJ_oo0=d2oookJP03o`2Soooonf[o/ol000Oooo]Z00?o
0?oNool0QooonfX00_oonfX2ool0K0?ooo]Z00GoC@3oool^0?oo;P3ooo]Zof40o`06oookJP;oobP0
0ol000000ooonf[oolT0oookJP0;oookJP;oJ03o2?oonfX2oaP0o`;oi_l01_oonfX2oon@01gooo]Z
1oooN@0;oookJP;o0?l51_ooN@07on/0o`GoogT00om`0?l5on/0o`;ooo]Z3?ooN@02oookJPOookh0
:?oonfX00oooT03ooo]ZoookJP03oookJPOoiOl000?o603ooookJ_oonfX01_oonfX8oomi057ooo]Z
00CohOl0oookJ_oonf[of_l02OoonfX01Ooo01?ooo]Zool0Tooonf[o0?Wo00Kooo]Z00KoolX0oook
J_oonf[ooo]Zo`3o6ol0S_l;oookJP04o`3ogooonf[ooo]ZogSo00;ooo]Z00?o0=cooookJ_loo`00
1?oonfX02?l0:_oooo]ZoookJ_oonf[o0?lcoomB0?oonf[o^Ol05?oonfX00ol0Looooo]ZoookJP0H
oookJP03ool0j_oonf[ooo]Z00Oooo]Z00?ooaH0oonB0?oonfX01?oonfX00ooo0?cooo]ZoookJP03
oookJP03oaP0oooonf[oo`H000Cooo]Z00?ojol0ool0m_oonfX00_oonfX00onX0?oooo]ZoookJP03
oookJP07ool0nOoonf[o07OooookJ_ooK03o0?nJo`3oc002oookJP03oon10?oonf[o>ol000?ooo]Z
00?o0?_ooookJ_oonfX00ooonfX01_oo0`3ooo]ZoookJ_oo0=goN@3ooookJP;o0:?o00?o/ol0oook
J_oonfX01OoonfX00ol0omkogOl0ool0Q`03oookJP05ool0K?oonf[ooo]ZoookJ_m=0?l00_oo;P00
0ooonf[oH@3ooookJP06oookJP05on80ool0oi3o0000o`000?oonfX00_l0oi8;oookJP;oJ03o2Ooo
nfX2oaP0o`03onKo0?oonf[ooo]Z00Cooo]Z0_ooT00MoookJPSookh02ooonfX5o`3o1@03oookJ_m`
0?ooL03o00Ooj`3o1Ol0o`D3og00o`Goj`3o4?oonfX7oonn02Oooo]Z00?ooi00oookJ_oonfX01_oo
nfX01OoVo`3o07CooookJ_oonf[o603o00cooo]Z0_mX0?l]oookJP00;?oonfX00ooJo`3ooo]Zoook
JP06oookJP06ool04ooonf[ooo]Zool0Tooonf[o0?Wo1OoonfX00ooobP3ooo]ZoookJP02oookJP03
oa80ool0oa_ooo]Z00[ooo]Z0ooob@001_lm0?ooN?l0oookJ_l0g?oooo]Zocoo00?ooo]Z00Ko02[o
oookJ_oonf[ooo]Zo`3o<oooDP03oookJP03okWo0?oonf[ooo]Z017ooo]Z00?o07?ooookJ_oonfX0
6?oonfX00ooo0>[ooo]ZoookJP07oookJP03oolF0?oonf[ooi8000Cooo]Z00?oolT0oookJ_oonfX0
1?oonfX00ooob@3oo`H0oookJP02oookJP03on_o0?oonf[oo`3f00?ooo]Z00?oZ03ooookJ_oonfX0
0ooonfX01Ooo0?Wooo]Zo`1goooonf[oof`000;oobP00_oonfX00ooo:03o>ol0oomi0004oomi00Go
oo]Z00Coo`<0oookJ_oo0=goo`3M0_oonfX00ol0Xooooo]Zok?o0007oookJP03o`3og_oo08Oooo]Z
00;ooo]Z00?oo`1/oookJ_oonfX00_oonfX01Om=0?ooobh0oookJ_oonf[oH@3o00Kooo]Z00?oobP0
oookJ_l000000_l00002ooo900cooo]Z00?oJ03ooookJ_oonfX01_oonfX2oaP0o`03o`1doooVo`3o
oo]Z00Gooo]Z0_ooT00JoookJP03oonn0?ooN@3oogT000;oogT03OoonfX5o`3o1@Soj`3o4_oonfX2
og00o`Goj`3o3?ooN@06oookJPGookh09?oonfX00oooT03ooo]ZoookJP02oookJPSoiOl000?o603o
oookJ_oonfX01?oonfX:oomi05;ooo]Z00?of_l0oookJ_oonfX01ooonfX00ooo01?ooo]Zool0T`02
oookJP03o`3ioooonf[ooo]Z00?ooo]Z00?oolX0oookJ_oonfX00_oonfX00ol0oa_ooo]ZoookJP0:
oookJP04o`3ogooonf[ooo]ZogSo00;ooo]Z00?o0=cooookJ_loo`000ooonfX01_l0:_oooo]Zoook
J_oonf[o0?lcoomB00;ooo]Z00?o^Ol0oookJ_oonfX04OoonfX00ol0Looooo]ZoookJP0HoookJP03
ool0j_oonf[ooo]Z00Oooo]Z00?ooaH0oookJ_ooTP001OoonfX00ooo0?cooo]ZoookJP03oookJP03
oaP0oooo1P3ooo]Z00?ooo]Z00?ojol0ool0m_oonfX00_oonfX00onX0?oooo]ZoookJP03oookJP07
ool0nOoonf[o07OooookJ_ooK03o0?nJo`3oc002oookJP03oon10?oonf[o>ol000?ooo]Z00?o0?_o
oookJ_oonfX00ooonfX02Ooo0`3ooo]ZoookJ_oo0=goN@3ooookJ_l0Xooo01Oook?o0007oookJP03
o`3og_oo08Ooo`2700?ooo]Z00Koo`1/oookJ_oonf[ooo]Zodd0oooo;P02oookJP03of40oooonf[o
oo]Z00Cooo]Z0_oR0?l4o`000003o`3oT_oonf[ooo]Z00[ooo]Z00?oJ03ooookJ_oonfX01ooonfX2
oaP0o`03onKo0?l0M?oooo]Z00Cooo]Z0_ooT00JoookJPGookh03_oonfX5o`3o1@Soj`3o4_oonfX2
og00o`Goj`3o1_l0o`D<oookJPGookh08ooonfX2oon@00Oooo]Z0_oVo`000ol0M?oooo]ZoaP0o`0=
oookJP03ofP0oooonf[ooo]Z02[ooo]Z000/oookJP03om[o0?oonf[ooo]Z00Kooo]Z00Goo`0Coook
J_oo09?ooo]Zo`3io`06oookJP07ooo:0?oonf[ooo]ZoookJ_lB0?oo0?lKo`2>o`0:oookJP?oolT0
00Ko?@3oogSo0?oonf[o0=cooookJ_loo`04oookJP06o`0Zoooonf[ooo]ZoookJ_l0oc?ooe800_oo
nfX00onio`3ooo]ZoookJP0AoookJP03o`1coooonf[ooo]Z01Sooo]Z00?oo`3ZoookJ_oonfX01ooo
nfX00ooo5P3ooo]ZoonB0004oookJP03ooo90?oonf[ooo]Z00Cooo]Z00?oolT0ool60?oonfX00_oo
nfX00oo[o`3ooo]Zool0mP03oookJP03ojP0oooonf[ooo]Z00?ooo]Z00Koo`3ioookJ_l0Mooooo]Z
oom/0?l0oiX2oolX0004oookJ_oo:03ooo]Zoc_o00GoogT01?oonfX02Ooo0`3ooo]Zool0gOoonf[o
N@3ooookJ_l0Xooooo]Zok?o0007oookJP03o`3og_oo08Oooo]Z00;ooo]Z00?oo`1/oookJ_oonfX0
0_oonfX01Om=0?ooobh0oookJ_oonf[oH@3o00Gooo]Z0_oo:002oookJP04o`000?oob@3oolT0o`00
00_ooo]Z0_mX0?l7oookJP;o603o00?o07CoonKo0?oVo`001OoonfX2oon@01Wooo]Z0ooo_P0=oook
JP;o0?l52?o[0?l2oookJP03oomi0?oonf[ooo]Z01Wooo]Z0_ooN@000om`0?ooj`3oon/0o`04on/0
o`OoogT000?o0?l5oookJ_oonfX01ooonfX2oonn02?ooo]Z0_ooT0000ooonf[oiOl0onGo0008onGo
0003oaP0oooonf[ooo]Z00Gooo]Z2?ooN@1BoookJP03om[o0?oonf[ooo]Z00Oooo]Z00Goo`0Coook
J_oo09?ooo]Zo`3io`06oookJP06ooo:0?oonf[ooo]ZoookJ_l0oa_o08ko2ooonfX01?l0omoooo]Z
oookJ_mho`02oookJP03o`3Loooonf[o?ol000Cooo]Z00Go02[ooookJ_oonf[ooo]ZoomB0002oook
JP03okWo0?oonf[ooo]Z017ooo]Z00?o07?ooookJ_oonfX06?oonfX00ooo0>[ooo]ZoookJP07oook
JP03oolF0?oonf[ooi8000Gooo]Z00?oo`3loookJ_oonfX00ooonfX00olH0?ooo`H0oookJP03oook
JP03on_o0?oo0?Kooo]Z00;ooo]Z00?oZ03ooookJ_oonfX00ooonfX01ooo0?Wooo]Zo`1goooonf[o
of`0oookJ_l0oiX00_oonfX00oooP@3ooo]Zoc_o0003oookJP03o`3koooonf[ooo]Z00?ooo]Z00Wo
o`<0oookJ_oonf[oo`3MogT0oooonf[o0:?oo`0Goonco`001ooonfX00ol0omkoo`27oookJP02oook
JP;oo`1/0ooonfX01Om=0?ooobh0oookJ_oonf[oH@3o00Kooo]Z00?ohP3oo`3oT?oonfX00_l00002
o`3oTP_ooo]Z0_mX0?l8oookJP;o603o0_oVo`05oookJP;ooi006_oonfX2oonn00kooo]Z0_l0o`D8
on/0ob3ooo]Z00?oL03oon/0ooo[0?l01?o[0?l7o`3o1@[ooo]Z0_oo_P0SoookJP03oon@0?oonf[o
oo]Z00Kooo]Z0_oVo`000ooonf[o603ooookJP0<oookJP;oJ03o:_oonfX002_ooo]Z00?of_l0oook
J_oonfX01ooonfX01Ooo01?oo`2CoookJ_oonf[o0?Wo00Kooo]Z00KoolX0oookJ_oonf[ooo]Zoa80
ool0oa/:oookJPCoolT000Ko?@3oogSo0?oonf[o0=cooookJ_loo`03oookJP06o`0Zoooonf[ooo]Z
oookJ_l0oc?ooe800_oonfX00onio`3ooo]ZoookJP0BoookJP03o`1coooonf[ooo]Z01Oooo]Z00?o
o`3ZoookJ_oonfX02?oonfX00ooo5P3ooi80oookJP03oookJP03ooo90?oonf[ooo]Z00Cooo]Z00?o
olT0ool60?oonfX00_oonfX00oo[o`3ooo]Zool0mP03oookJP03o`2VoonX0?oooo]Z00?ooo]Z00?o
o`3ioookJ_l0Mol00_oob@001ol0oi[oobP0oolX0?oonf[oobP0oomi0?lko`001_ooN@03oookJP05
ool30?oonf[oo`3MoookJ_mi0?l00_l0Xol2ok?o00Oooo]Z00?o0?oNool0QooonfX00_oonfX01?oo
06cooo]ZoookJ_oonfX2odd0o`04ool^0?oonf[oH@3oof40o`Gooo]Z00?oobP0o`3oT?oonfX00_oo
nfX01?oob@3o0000o`000?l00009oookJP;oJ03o1ooonfX2oaP0o`;o07Co00?oi_l0oookJ_oonfX0
0ooonfX2oon@01Wooo]Z0_oo_P0;oookJPOoj`3o0_m`0?lToookJPWoogT01Oo[0?l00om`0?oooo]Z
oookJP03o`3o1@Sooo]Z0_oo_P0SoookJP03oon@0?oonf[ooo]Z00WoiOl000?o603ooookJ_oonfX0
1ooonfX6oomi053ooo]Z00?of_l0oookJ_oonfX01ooonfX00ooo01?ooo]Zool0T`02oookJP03o`3i
oooonf[ooo]Z00?ooo]Z00?oolX0oookJ_oonfX00_oonfX00ol0oa_ooo]ZoookJP0:oookJP04o`3o
gooonf[o?@3oogSo00;ooo]Z00?o0=cooookJ_loo`000ooonfX01Ol0:_oooo]ZoookJ_oonf[ooe80
00;ooo]Z00?o^Ol0oookJ_oonfX04_oonfX00ol0Looooo]ZoookJP0HoookJP03ool0j_oonf[ooo]Z
00Oooo]Z00?ooaH0oonB0?oonfX01?oonfX00ooo0?cooo]ZoookJP03oookJP03oaP0oooo1P3ooo]Z
00?ooo]Z00?ojol0ool0m_oonfX00_oonfX00ol0Y_ooZ03ooookJP03oookJP07ool0nOoonf[o07Oo
oookJ_ooK03ooo]Zo`3oVP02oookJP03oon10?oonf[o>ol000?ooo]Z00?o0?_ooookJ_oonfX00ooo
nfX02Ooo0`3ooo]ZoookJ_oo0=goN@3ooookJ_l0Xooo01Oook?o0007oookJP03o`3og_oo08Oooo]Z
00;ooo]Z00Coo`1/oookJ_oonf[ooo]Z0_m=0?l01?oo;P3ooo]ZoookJ_mQ0?l6oookJP06on80ool0
oi3ooo]ZoookJ_l0003o0?nB0_l00009oookJP;oJ03o2?oonfX2oaP0o`03o`1doooVo`3ooo]Z00Co
oo]Z0_ooT00IoookJP?ookh02ooonfX7on/0o`;oL03o;OoonfX5on/0o`03og00oooonf[o0?l500;o
0?l52OoonfX2oonn02;ooo]Z00?ooi00oookJ_oonfX01ooonfX01?oVo`3ooo]ZoaP0oolH0?l=oook
JP03ofP0oooonf[ooo]Z02Oooo]Z000[oookJP03om[o0?oonf[ooo]Z00Kooo]Z00Goo`0CoookJ_oo
09?ooo]Zo`3io`06oookJP07ooo:0?oonf[ooo]ZoookJ_lB0?oooo]Zo`3o6`09oookJPGoolT000Go
N?l0oookJ_l0g?oooo]Zocoo0004oookJP05o`0Zoooonf[ooo]Zo`3o<oooDP000ooonfX00onio`3o
oo]ZoookJP0AoookJP03o`1coooonf[ooo]Z01Sooo]Z00?oo`3ZoookJ_oonfX01ooonfX00ooo5P3o
oi80oookJP04oookJP03ooo90?oonf[ooo]Z00?ooo]Z00?oolT0oookJ_oo1P000_oonfX00oo[o`3o
oo]Zool0mP03oookJP03o`2VoonX0?oooo]Z00?ooo]Z00?oo`3ioookJ_l0Mol00ooob@04oolX0003
oomi0?lko`3oogT000GoogT00ooonfX02Ooo0`3ooo]Zool0gOoonf[oN@3oo`2Sool05ooo/ol0oil0
o`07oookJP04o`3og_oo08Oooo]ZoookJP;oo`1/0ooonfX01_m=0?ooobh0oookJ_oonf[oH@3oo`3o
A@Cooo]Z0_oo:0001?l0oi3ooo]ZoookJ_l0oi82ooo900Co00001_oonfX2ofP0o`Oooo]Z0_lH0?l0
1?oonf[o07CoonKo0?oVo`05oookJP03oon@0?oonf[ooo]Z01Oooo]Z0_oo_P05oookJPGoobP00oo[
0?l2og00ob_ooo]Z1?ooN@0:oookJPGoj`3o0_m`0?l00ol0o`Gooo]ZoookJP06oookJP;ookh08_oo
nfX00oooT03ooo]ZoookJP02oookJPOoiOl000?o603ooookJ_oonfX02?oonfX5oomi04oooo]Z00?o
f_l0oookJ_oonfX01ooonfX01Ooo01?ooo]Zool0Tooonf[o0?Wo00Kooo]Z00KoolX0oookJ_oonf[o
oo]Zoa80ool0oa/;oookJP04o`3ogooonf[ooo]ZogSo00;ooo]Z00?o0=cooookJ_loo`001?oonfX0
1Ol0:_oooo]ZoookJ_l0oc?ooe8000;ooo]Z00?o^Ol0oookJ_oonfX04OoonfX00ol0Looooo]Zoook
JP0HoookJP03ool0j_oonf[ooo]Z00Oooo]Z00?ooaH0oonB0?oonfX01?oonfX00ooo0?cooo]Zoook
JP03oookJP03oaP0oooonf[oo`H000?ooo]Z00?ojol0oookJ_oo0?H00_oonfX00ol0Y_ooZ03ooook
JP03oookJP03ool0nOoonf[o07Oo00;ooo]Z00Ooof`0o`3oV_l0olcooo]Zoon10?oonf[o>ol000Co
oo]Z00?o0?_ooookJ_oonfX00_oonfX02Ooo0`3ooo]ZoookJ_oo0=gooo]ZogT0ool0Xooo01Oook?o
0007oookJP03o`3og_oo08Oooo]Z00;ooo]Z00Koo`1/oookJ_oonf[ooo]Zodd0oooo;P03oookJP03
of40oooonf[ooo]Z00?ooo]Z0_oR0?l00ol0oi3ooo]ZoookJP02o`3oTPCo00001_oonfX2ofP0o`So
oo]Z0_lH0?l00ol0M?ooi_l0onKo0005oookJP03oon@0?oonf[ooo]Z01Oooo]Z0_oo_P09oookJPGo
j`3o0_m`0?lioookJPGoj`3o0_m`0?l9oookJP;ookh08OoonfX00oooT03ooo]ZoookJP07oookJP;o
i_l000?ooo]ZoaP0oooonfX03?oonfX00omX0?oooo]ZoookJP0VoookJP00:_oonfX00ooJo`3ooo]Z
oookJP07oookJP05ool04ooo09?ooo]ZoookJ_l0nOl01_oonfX01_oobP3ooo]ZoookJ_oonf[o4P3o
o`3o6`[ooo]Z1Ooob@001Omho`3ooo]Zo`3Loooonf[o?ol000?ooo]Z00Ko02[ooookJ_oonf[ooo]Z
o`3o<oooDP02oookJP03okWo0?oonf[ooo]Z017ooo]Z00?o07?ooookJ_oonfX06?oonfX00ooo0>[o
oo]ZoookJP07oookJP03oolF0?ooTP3ooo]Z00Cooo]Z00?oolT0oookJ_oonfX00ooonfX00ooob@3o
oo]Zool60003oookJP03on_o0?oo0?Kooo]Z00?ooo]Z00?oZ03ooookJ_oonfX00_oonfX00ooo0?Wo
oo]Zo`1go`03ooo900CoobP000?oogT0oc_o0?ooN@001_ooN@02oookJP09ool30?oonf[oo`3Moook
J_mi0?oo0:?oo`0Goonco`3oW`3o00Oooo]Z00Go0?oNool0Qooonf[ooo]Zool0K004oookJP06odd0
oooo;P3ooo]ZoookJ_mQ0?oo0?m51?oonfX00ooo:03ooo]Zo`3oT002oookJP03o`3oT_oonf[ooo]Z
00Co00001_oonfX00omX0?oooo]ZoookJP05oookJP;o603o00Cooo]Zo`1dool0M?ooi_l01OoonfX2
oon@01Oooo]Z0ooo_P0:oolX0003og00oooonf[ooo]Z04;ooo]Z1Oo[0?l00om`0?oooo]ZoookJP05
oookJP;ookh08OoonfX00oooT03ooo]ZoookJP04oookJPGoiOl00_lH0?l:oookJPCoogT0COoonfX0
0ooJo`3ooo]ZoookJP07oookJP03ool04ooonf[oo`2C00;ooo]Z00?o0?WooookJ_oonfX00ooonfX0
0ooobP3ooo]ZoookJP02oookJP03o`3o6ooonf[ooo]Z00[ooo]Z00Co0?oOoookJ_lm0?ooN?l00_oo
nfX00ol0g?oooo]Zocoo0003oookJP05o`0Zoooonf[ooo]ZoookJ_ooDP000_oonfX00onio`3ooo]Z
oookJP0AoookJP03o`1coooonf[ooo]Z01Sooo]Z00?oo`3ZoookJ_oonfX01ooonfX00ooo5P3ooi80
oookJP05oookJP03ool0o?oonf[ooo]Z00;ooo]Z00?o603ooookJ_oo1P001?oonfX00oo[o`3oo`3f
oookJP02oookJP03ojP0oooonf[ooo]Z00;ooo]Z00coo`3ioookJ_oonf[o07OooookJ_ooK03o0?nJ
o`3oc?oonf[ooh40oookJ_lko`04oookJP03o`3koooonf[ooo]Z00;ooo]Z00Woo`<0oookJ_oonf[o
o`3MoookJ_mi0?oo0:?oo`0Goonco`001ooonfX00ol0omkoo`27oookJP02oookJP06ool0K?oonf[o
oo]ZoookJ_m=0?ooobh00ooonfX00omQ0?oooo]ZoookJP03oookJP03on80oooonf[o0?n@00;ooo]Z
00?o0?nBoookJ_l000000ol00006oookJP03ofP0oooonf[ooo]Z00Kooo]Z0_lH0?l2o`1do`03onKo
0?oonf[ooo]Z00?ooo]Z0_ooT00HoookJP;ookh01ooonfX01Ol0o`Goj`3oon/0ooo[0?ooL03o04Co
oo]Z1Oo[0?l00om`0?oooo]ZoookJP05oookJP;ookh08?oonfX2oon@00Sooo]Z00Co07CoonKo0?oV
o`3o603o3OoonfX2ofP0obKooo]Z000coookJP05ool04ooonf[oo`2CoookJ_l0nOl01_oonfX01ooo
bP3ooo]ZoookJ_oonf[o4P3ooookJ_l0oa/02OoonfX5ooo90005ogSo0?oonf[o0=cooookJ_loo`00
0ooonfX01_l0:_oooo]ZoookJ_oonf[o0?lcoomB00?ooo]Z00?o^Ol0oookJ_oonfX04OoonfX00ol0
Looooo]ZoookJP0GoookJP03ool0j_oonf[ooo]Z00Oooo]Z00?ooaH0oookJ_ooTP001?oonfX00ooo
b@3ooo]ZoookJP04oookJP03ooo90?oo1P3ooo]Z00;ooo]Z00?ojol0ool0m_oonfX00ooonfX00ol0
Y_ooZ03ooookJP02oookJP03ool0nOoonf[o07Oo00CoolT00ooo:0000oooN@3o>ol0oomi0006oomi
00;ooo]Z00Woo`<0oookJ_oo0=gooo]ZogT0ool0Xooooo]Zok?o0?nO0?l01ooonfX2ool0Q`;ooo]Z
00?oo`1/oookJ_oonfX00_oonfX01_m=0?ooobh0oookJ_oonf[oH@3oo`3oA@Cooo]Z00?oobP0oook
J_l0oi000_oonfX01?l0oi;ooo]ZoookJ_oonfX4o`0000Cooo]Z0_mX0?l6oookJP;o603o00?ooo]Z
o`1dool0M?l00_oVo`04oookJP;ooi005ooonfX00ooo_P3oobP0oolX000;oolX04_ooo]Z1?o[0?l6
oookJP;ookh08?oonfX00oooT03ooo]ZoookJP06oookJP?oiOl000?ooo]ZoaP0oooonfX02ooonfX2
oomi05Kooo]Z00Goo`0Cool0Tooonf[ooo]Zo`3io`06oookJP06ooo:0?oonf[ooo]ZoookJ_lB0?oo
0?lK3?oonfX00ol0omoo?@3oogSo0002oookJP03o`3Loooonf[o?ol000?ooo]Z00Go02[ooookJ_oo
nf[ooo]ZoomB0003oookJP03okWo0?oonf[ooo]Z017ooo]Z00?o07?ooookJ_oonfX06?oonfX00ooo
0>[ooo]ZoookJP06oookJP03oolF0?oonf[ooi8000Gooo]Z00?oo`3loookJ_oonfX00ooonfX00olH
0?ooo`H0oookJP03oookJP03on_o0?oo0?Kooo]Z00;ooo]Z00?o0:KoojP0oooonfX00ooonfX01ooo
0?Wooo]Zo`1goooonf[oof`0o`3oV_l0ol`00_oonfX00oooP@3o>ol0oookJP03oookJP03o`3koooo
nf[ooo]Z00;ooo]Z00Woo`<0oookJ_oonf[oo`3MoookJ_mi0?oo0:?ooookJ_nco`001ooonfX00ol0
omkoo`27oookJP02oookJP06ool0K?oonf[ooo]ZoookJ_m=0?ooobh00_oonfX2of40o`Cooo]Z0_oR
0?l01Ooonf[o0?n@oookJ_oonf[o0?nB00;ooo]Z1?l00004oookJP;oJ03o1ooonfX2oaP0o`;o07Co
0_oVo`04oookJP;ooi005ooonfX3oonn00Cooo]Z0ol0o`D3on/0odcooo]Z00?o0?l5on/0ooo[0?l0
0_o[0?l6oookJP03oonn0?oonf[ooo]Z01oooo]Z00?ooi00oookJ_oonfX01_oonfX2o`1do`03onKo
0?lH0?oooo]Z00gooo]Z00?oJ03ooookJ_oonfX08ooonfX003?ooo]Z00Goo`0Cool0Tooonf[ooo]Z
o`3io`06oookJP06ooo:0?oonf[ooo]Zoa80oooonf[o0?lK2OoonfX6ooo90005ogSo0?oonf[o0=co
oookJ_loo`000ooonfX01Ol0:_oooo]ZoookJ_oonf[ooe8000?ooo]Z00?o^Ol0oookJ_oonfX04Ooo
nfX00ol0Looooo]ZoookJP0HoookJP03ool0j_oonf[ooo]Z00Oooo]Z00?ooaH0oonB0?oonfX01?oo
nfX00ooob@3ooo]ZoookJP03oookJP03ooo90?oonf[oo`H000;ooo]Z00?ojol0ool0m_oonfX00ooo
nfX00ol0Y_ooZ03ooookJP02oookJP03ool0nOoonf[o07Oo00CoolT01?oo:0000olko`3ooo]Zoomi
0006oomi000:oookJ_oo0`3ooo]ZoookJ_oo0=goN@3oo`2Soooonf[o/ol0oil0o`Oooo]Z00Goo`27
omgo0?oonf[ooo]Zool0K003oookJP;oC@3o00Goobh0oookJ_oonf[oH@3oo`3oA@04oookJP03on80
oooonf[o0?n@00;ooo]Z00?o0?nBoookJ_oonfX00_oonfX4o`0000;ooo]Z0_mX0?l6oookJP;o603o
00?ooo]Zo`1dool0M?l00_oVo`04oookJP;ooi005ooonfX2oonn0003oookJ_oo:03oobP000[oobP0
CooonfX00om`0?ooj`3oon/0o`06oookJP;ookh07ooonfX2oon@00Sooo]Z00Co07CoonGo0?oonf[o
603o3OoonfX00oooN@3ooo]ZoookJP1BoookJP03ool04ooonf[oo`2C00;ooo]Z00?o0?WooookJ_oo
nfX01?oonfX01OoobP3ooo]ZoookJ_lB0?oo0?lK00cooo]Z00Co0?oOoookJ_lm0?ooN?l00_oonfX0
0ol0g?oooo]Zocoo0003oookJP05o`0Zoooonf[ooo]ZoookJ_ooDP000_oonfX00onio`3ooo]Zoook
JP0AoookJP03o`1coooonf[ooo]Z01Sooo]Z00?oo`3ZoookJ_oonfX01ooonfX00ooo5P3ooi80oook
JP04oookJP03ool0o?oonf[ooo]Z00?ooo]Z00?o603ooookJ_oo1P000ooonfX00oo[o`3oo`3foook
JP02oookJP03o`2VoonX0?oooo]Z00?ooo]Z00Ooo`3ioookJ_l0Mooooo]Zoom/0?oonf[o0?nJ00;o
oo]Z00?ooh40oc_o0?oonfX00ooonfX00ol0nooooo]ZoookJP02oookJP09ool30?oonf[ooo]Zoook
J_oo0=goN@3oo`2Soooonf[o/ol000Oooo]Z00?o0?oNool0QooonfX00_oonfX00ooo06cooo]Zoook
JP02odd0o`05ool^0?oonf[ooo]Zof40ool0odD01?oonfX01?oR0?oooo]ZoookJ_l0oi02oookJP04
o`3oT_oonf[ooo]ZoookJPCo00000_oonfX2ofP0o`Oooo]Z0_lH0?l2o`1do`;oi_l01?oonfX2oon@
01Oooo]Z0_oo_P04oookJP?o0?l500?ooo]Zon/0ooo[0?l0D_oonfX00ol0o`GoL03oon/0o`06oook
JP;ookh08?oonfX00oooT03ooo]ZoookJP07oookJP03o`1doooVo`3o603o00kooo]Z00?oJ03ooook
J_oonfX08_oonfX003;ooo]Z00Goo`0Cool0Tooonf[ooo]Zo`3io`06oookJP07ooo:0?oonf[ooo]Z
oookJ_lB0?oooo]Zo`3o6`08oookJPKoolT000GoN?l0oookJ_l0g?oooo]Zocoo0003oookJP06o`0Z
oooonf[ooo]ZoookJ_l0oc?ooe800_oonfX00onio`3ooo]ZoookJP0AoookJP03o`1coooonf[ooo]Z
01Sooo]Z00?oo`3ZoookJ_oonfX01ooonfX00ooo5P3ooi80oookJP04oookJP03ooo90?oonf[ooo]Z
00?ooo]Z00?oolT0oookJ_oo1P000_oonfX00oo[o`3ooo]Zool0mP03oookJP03o`2VoonX0?oooo]Z
00;ooo]Z00?oo`3ioookJ_l0Mol01Ooob@03oolX0004oc_o0?oonf[ooo]ZoookJPGoogT000_ooo]Z
ool30?oonf[ooo]Zool0gOmi0?oo0:?ooookJ_nco`3ooo]Zoil0o`06oookJP05ool0QooMo`3ooo]Z
oookJ_oo06`00ooonfX00om=0?ooobh0oookJP02oookJP03of40ool0odGooo]Z00?ooo]Z00?ohP3o
oookJ_l0oi000_oonfX00ol0oi;ooo]ZoookJP03oookJPCo000000?ooo]ZofP0oooonfX01_oonfX0
1_lH0?oooo]Zo`1dool0M?oooo]ZonKo00Cooo]Z0_ooT00FoookJP?ookh00ooonfX00ol0o`GoobP0
oolX0007oolX05;ooo]Z0_m`0?l00oo[0?oooo]ZoookJP05oookJP;ookh07ooonfX00oooT03ooo]Z
oookJP06oookJP04onKo0?l0M?oooo]ZoaP0of7ooo]Z00Goo`0Cool0Tooonf[ooo]Zo`3io`06oook
JP06ooo:0?oonf[ooo]ZoookJ_lB0?oo0?lK3?oonfX00ol0omoo?@3oogSo0002oookJP03o`3Loooo
nf[o?ol000?ooo]Z00Go02[ooookJ_oonf[ooo]ZoomB0002oookJP03okWo0?oonf[ooo]Z017ooo]Z
00?o07?ooookJ_oonfX06?oonfX00ooo0>[ooo]ZoookJP07oookJP03oolF0?ooTP3ooo]Z00Gooo]Z
00?oo`3loookJ_oonfX00_oonfX00olH0?oooo]Zool60003oookJP03on_o0?oo0?Kooo]Z00;ooo]Z
00?o0:KoojP0oooonfX00ooonfX00ooo0?Wooo]Zo`1go`02oookJP07oom/0?l0oi[o0?o<oookJ_oo
P@3ooo]Zoc_o0003oookJP03o`3koooonf[ooo]Z00;ooo]Z00[oo`<0oookJ_oonf[ooo]Zool0gOmi
0?oo0:?ooookJ_nco`3oW`3o1_oonfX01?l0omkoo`27oookJ_oonfX2ool0K0;ooo]Z00?oC@3oool^
0?oonfX00_oonfX00omQ0?oo0?m5oookJP03oookJP04on80oooonf[o0?n@o`3oT0;ooo]Z00?o0?nB
oookJ_oonfX00_oonfX4o`000003oookJ_mX0?oooo]Z00Oooo]Z00Go603oo`1dool0M?oooo]ZonKo
0004oookJP;ooi005ooonfX2oonn00Cooo]Z0_l0o`D01?oonf[oj`3oon/0ooo[0?mFoookJP03og00
ooo[0?ooj`3o00Kooo]Z0_oo_P0OoookJP03oon@0?oonf[ooo]Z00Oooo]Z00Coi_l0oookJ_lH0?oo
603o<OoonfX003;ooo]Z00Goo`0Cool0Tooonf[ooo]Zo`3io`06oookJP06ooo:0?oonf[ooo]Zoa80
oooonf[o0?lK2?oonfX7ooo90005ogSo0?l0g?oooo]ZoookJ_loo`000ooonfX01Ol0:_oooo]Zoook
J_oonf[ooe8000?ooo]Z00?o^Ol0oookJ_oonfX04OoonfX00ol0Looooo]ZoookJP0GoookJP03ool0
j_oonf[ooo]Z00Oooo]Z00?ooaH0oonB0?oonfX01?oonfX00ooob@3ooo]ZoookJP03oookJP03ooo9
0?oonf[oo`H000;ooo]Z00?ojol0oookJ_oo0?H00ooonfX00ol0Y_ooZ03ooookJP02oookJP03ool0
nOoonf[o07Oo00KoolT00_oo:0001_lko`3ooo]ZoookJ_oonf[oogT0oookJPCoogT000[ooo]Zool3
0?oonf[oo`3MogT0ool0Xooooo]Zok?o0?oonf[oW`3o1_oonfX00ooo08OogOl0oookJP02ool0K0?o
oo]Z00CoC@3oool^0?oonf[ooo]Z0_mQ0?l00ol0odGooo]ZoookJP02oookJP03on80oooonf[o0?n@
00;ooo]Z00?o0?nBoookJ_oonfX01?oonfX4o`000003ofP0oooonf[ooo]Z00Gooo]Z00Co603oo`1d
ool0M?oooo]Z0_oVo`03oookJP;ooi005_oonfX2oonn00Cooo]Z0_l0o`D9oolX023ooo]Z4_ooE`03
ooo9023ooo]Z00CoL03oon/0ooo[0?oo0?l51_oonfX2oonn01kooo]Z00?ooi00oookJ_oonfX01_oo
nfX01?oVo`3o07CooookJ_lH0?mOoookJP03ool04ooonf[oo`2C00;ooo]Z00?o0?WooookJ_oonfX0
1?oonfX01OoobP3ooo]ZoookJ_lB0?oo0?lK00cooo]Z00Ko0?oOoookJ_lm0?ooN?l0oookJ_l0g?l2
oookJP05ocoo0?oonf[ooo]ZoookJ_l0:_l00_oonfX01OooDP3o0?lcoookJ_oonf[o^Ol001?ooo]Z
00?o07?ooookJ_oonfX06?oonfX00ooo0>[ooo]ZoookJP06oookJP03oolF0?ooTP3ooo]Z00Gooo]Z
00?oo`3loookJ_oonfX00_oonfX00olH0?oooo]Zool60003oookJP03on_o0?oo0?Kooo]Z00;ooo]Z
00?o0:KoojP0oooonfX00ooonfX00ooo0?Wooo]Zo`1go`02oookJP07oom/0?l0oi[o0?o<oookJ_oo
P@3ooo]Zoc_o0003oookJP03o`3koooonf[ooo]Z00?ooo]Z00Woo`<0oookJ_oonf[oo`3MogT0ool0
Xooooo]Zok?o0?nO0?l01_oonfX01Ol0omkoo`27oookJ_oonf[oo`1/00?ooo]Z00?oC@3oool^0?oo
nfX00_oonfX00omQ0?oo0?m5oookJP03oookJP03on80oooonf[o0?n@00?ooo]Z00?o0?nBoookJ_oo
nfX00ooonfX4o`000003ofP0oooonf[ooo]Z00Kooo]Z00?o603oo`1doooonfX00_oVo`03oookJP;o
oi005_oonfX3oonn00Cooo]Z0_l0o`D3on/0obKooo]Z5OooE`0PoookJP03og00ooo[0?ooj`3o00Ko
oo]Z0_oo_P0NoookJP03oon@0?oonf[ooo]Z00Oooo]Z00Coi_l0oookJ_oonf[o603o<?oonfX003;o
oo]Z00Coo`2CoookJ_oonf[o0?Wo1ooonfX01_oobP3ooo]ZoookJ_lB0?oooo]Zo`3o6`Oooo]Z1ooo
b@001Omho`3oolT0o`3Loooonf[o?ol000?ooo]Z00Ko02[ooookJ_oonf[ooo]Zo`3o<oooDP02oook
JP03okWo0?oonf[ooo]Z017ooo]Z00?o07?ooookJ_oonfX06?oonfX00ooo0>[ooo]ZoookJP07oook
JP03oonB0?oonf[ooo]Z00?ooo]Z00?oolT0oookJ_oonfX00ooonfX02?oob@3ooo]ZoookJ_oo1P3o
oo]Zon_o0?oonf[oo`3f1?oonfX02?l0Y_ooZ03ooookJ_oonf[oo`3ioookJ_oob@3o07Oo1Ooob@02
oolX0003oc_o0?oonf[ooo]Z00;ooo]Z00?oogT0oookJ_oonfX00oooN@002Ooo0`3ooo]Zool0gOoo
nf[o0:?ooookJ_nco`3ooo]Zoil0o`06oookJP04ool0QooMo`3ooo]Zool0K0Cooo]Z00OoC@3ooolX
0?oonf[ooo]Zof40oooonf[o0?m500Cooo]Z00?ohP3ooookJ_l0oi000_oonfX00ol0oi;ooo]Zoook
JP05oookJP?o000000?oJ03ooookJ_oonfX01OoonfX01OlH0?oo07CooookJ_oonf[oi_l000?ooo]Z
0_ooT00EoookJP?ookh01?oonfX2o`3o1@;oobP000?oL03ooookJ_oo:0001Ooo:00=oookJQCooeL0
5OoonfX3ooo901oooo]Z00CoL03oon/0ooo[0?oo0?l51_oonfX00ooo_P3ooo]ZoookJP0LoookJP03
oon@0?oonf[ooo]Z00Kooo]Z00Coi_l0o`1doooonf[o603oG_oonfX01Ooo01?oo`2CoookJ_oonf[o
0?Wo00Kooo]Z00KoolX0oookJ_oonf[ooo]Zoa80ool0oa/<oookJP03o`3ogolm0?ooN?l000;ooo]Z
00?o0=cooookJ_loo`000ooonfX01Ol0:_oooo]ZoookJ_oonf[ooe8000;ooo]Z00?o^Ol0oookJ_oo
nfX04OoonfX00ol0Looooo]ZoookJP0HoookJP03ool0j_oonf[ooo]Z00Oooo]Z00?ooi80oookJ_oo
nfX01?oonfX00ooo0?cooo]ZoookJP02oookJP04oaP0oooonf[ooo]Zool600;ooo]Z00?ojol0oook
J_oo0?H00ooonfX00ol0Y_ooZ03ooookJP02oookJP03ool0nOoonf[o07Oo00;ooo]Z00Ooof`0o`3o
V_l0olcooo]Zoon10?oonf[o>ol000Cooo]Z00?o0?_ooookJ_oonfX00_oonfX02Ooo0`3ooo]Zoook
J_oo0=goN@3oo`2Soooonf[o/ol0oil0o`06oookJP05o`3og_oo08Oooo]ZoookJ_oo06`00ooonfX0
0om=0?ooobh0oookJP02oookJP03of40ool0odGooo]Z00?ooo]Z00?ohP3ooookJ_l0oi000ooonfX0
0ol0oi;ooo]ZoookJP04oookJP?o000000?oJ03ooookJ_oonfX01_oonfX01?lH0?oooo]ZoookJ_oV
o`03oookJP;ooi005_oonfX2oonn00Cooo]Z0ol0o`D2on/0o`03og00oooonf[ooo]Z017ooo]Z5Ooo
E`0EoookJP?ooeL07ooonfX00om`0?ooj`3oo`3o1@06oookJP;ookh07OoonfX2oon@00Sooo]Z00Co
i_l0oookJ_oonf[o603o;ooonfX0037ooo]Z00Goo`0Cool0Tooonf[ooo]Zo`3io`06oookJP07ooo:
0?oonf[ooo]Zoa80oooonf[o0?lKo`2>o`09oookJPGoolT000GoN?l0ooo90?oonf[ooo]Zocoo0002
oookJP03o`0Zoooonf[ooo]Z00;ooo]Z00Cooe80oookJ_oonf[o^Ol04ooonfX00ol0Looooo]Zoook
JP0HoookJP03ool0j_oonf[ooo]Z00Oooo]Z00?ooaH0oonB0?oonfX01?oonfX00ooob@3ooo]Zoook
JP03oookJP07ooo90?oonf[oo`H0oookJ_o[o`3ooo]Zool0mP04oookJP03o`2VoonX0?oooo]Z00;o
oo]Z00?oo`3iooo90?l0Mol01_oob@000ooo:03o>ol0oolX0003oookJP03oomi0?oonf[ooo]Z00;o
oo]Z00[oogT0ool30?oonf[oo`3MoookJ_mi0?oo0:?ook?o0?oonf[oW`3o1_oonfX01?oo08OogOl0
oookJ_oo06`4oookJP07odd0oooo:03oobP0oookJ_mQ0?oooo]Zo`3oA@04oookJP03on80ool0oi3o
0?n@00;ooo]Z00?o0?nBoookJ_oonfX01_oonfX2o`000003ofP0ool0003ooo]Z00Cooo]Z0_lH0?l0
1?l0M?oooo]ZonKo0?oVo`03oookJP03oon@0?oonf[ooo]Z01?ooo]Z0_oo_P04oookJP;o0?l50ooo
:0001?m`0?oooo]ZoookJ_oonfX4oolX00cooo]Z0oooE`0/oookJPCoolT02ooonfX2ooo9013ooo]Z
00CoL03oon/0ool0o`Go0?l51OoonfX2oonn01gooo]Z00?ooi00oookJ_oonfX01_oonfX01?oVo`3o
07CooookJ_lH0?mMoookJP05ool04ooo09?ooo]ZoookJ_l0nOl01_oonfX01_oobP3ooo]ZoookJ_lB
0?oo0?lKo`2>o`_ooo]Z00Ko0?oOocd0oooonf[oN?l0oookJ_l0g?l2oookJP04ocoo0?oonf[ooo]Z
o`0Zo`?ooo]Z00Cooe80o`3o<ooonf[o^Ol04ooonfX00ol0Looooo]ZoookJP0HoookJP03ool0j_oo
nf[ooo]Z00Oooo]Z00?ooaH0oonB0?oonfX01?oonfX00ooo0?cooo]ZoookJP03oookJP03oaP0oooo
nf[oo`H000;ooo]Z00?ojol0oookJ_oo0?H00ooonfX00ol0Y_ooZ03ooookJP02oookJP03ool0nOoo
nf[o07Oo00?ooo]Z00Koof`0o`3oc?oonf[ooh40oookJ_lko`04oookJP03o`3koooonf[ooo]Z00;o
oo]Z00Woo`<0oookJ_oonf[oo`3MogT0oooonf[o0:?ook?o0?nO0?l01_oonfX01Ol0omkoo`27oook
J_oonf[oo`1/00?ooo]Z00?oC@3ooookJ_oo;P000_oonfX00omQ0?oo0?m5oookJP03oookJP03on80
oooonf[o0?n@00?ooo]Z00?o0?nBoookJ_oonfX01OoonfX2o`000003ofP0ool0003ooo]Z00Gooo]Z
0_lH0?l00ooonf[oi_l0onKo0003oookJP03oon@0?oonf[ooo]Z01Cooo]Z0_oo_P04oookJP;o0?l5
0oo[0?lCoookJP?ooeL0;OoonfX4oomG01gooo]Z0_o[0?l00ol0o`Gooo]ZoookJP04oookJP;ookh0
7OoonfX00oooT03ooo]ZoookJP06oookJP04onKo0?l0M?oooo]ZoaP0obkooo]Z000aoookJP04ool0
Tooonf[ooo]Zo`3io`Oooo]Z00KoolX0oookJ_oonf[o4P3ooookJ_l0oa/<oookJP;oolT000GoN?l0
ooo90?l0g?oooo]Zocoo0003oookJP05o`0Zoooonf[ooo]ZoookJ_ooDP000ooonfX00onio`3ooo]Z
oookJP0AoookJP03o`1coooonf[ooo]Z01Oooo]Z00?oo`3ZoookJ_oonfX01ooonfX00ooo5P3ooi80
oookJP04oookJP03ooo90?oonf[ooo]Z00?ooo]Z00?oolT0oookJ_oo1P000_oonfX00oo[o`3oo`3f
oookJP03oookJP03o`2VoonX0?oooo]Z00;ooo]Z00?oo`3iooo90?l0Mol01_oob@001?oo:03o>ol0
oolX0?oo:002oookJP03oomi0?oonf[ooo]Z00?ooo]Z00Woo`<0oookJ_oonf[oo`3MogT0ool0Xooo
/ol0oookJ_nO0?l01_oonfX01?oo08OogOl0oookJ_oo06`3oookJP;oobP000KoC@3ooolX0?oonf[o
H@3ooookJ_l0odD4oookJP03on80ool0oi3ooo]Z00;ooo]Z00?o0?nBoookJ_oonfX01ooonfX01?l0
003oJ03oo`000?l00004oookJP03oaP0oooonf[o07Co00;oi_l00ooonfX2oon@01Cooo]Z0_oo_P04
oookJP;o0?l50_oo:0000om`0?oooo]ZoookJP04oookJP?oobP02_oonfX3oomG03?ooo]Z0ooob@08
oookJPCoolT04?oonfX2on/0o`?o0?l51?oonfX2oonn01cooo]Z00?ooi00oookJ_oonfX01_oonfX0
1?oVo`3o07Coo`1doolH0?mKoookJP05ool04ooo09?ooo]ZoookJ_l0nOl01_oonfX01_oobP3ooo]Z
oookJ_oonf[o4P3oo`3o6`cooo]Z00?o0?oOocd0oomho`000_oonfX00ol0g?oooo]Zocoo0003oook
JP05o`0Zoooonf[ooo]ZoomB0?l0oc<00_oonfX00onio`3ooo]ZoookJP0AoookJP03o`1coooonf[o
oo]Z01Sooo]Z00?oo`3ZoookJ_oonfX01_oonfX00ooo5P3ooi80oookJP05oookJP03ool0o?oonf[o
oo]Z00;ooo]Z00?o603ooookJ_oo1P000ooonfX00oo[o`3oo`3foookJP02oookJP03o`2VoonX0?oo
oo]Z00;ooo]Z00?oo`3ioookJ_l0Mol00ooonfX01_ooK03o0?nJo`3oc?ooP@3ooo]Zoc_o00Cooo]Z
00?o0?_ooookJ_oonfX00_oonfX02Ooo0`3ooo]ZoookJ_oonf[oo`3MoookJ_l0Xooo/ol0oil0o`06
oookJP;oo`270_oonfX00ooo06cooo]ZoookJP02oookJP06odd0oooo;P3ooo]ZoookJ_mQ0?oo0?m5
1?oonfX00ooR0?oooo]Zo`3oT003oookJP03o`3oT_oonf[ooo]Z00Kooo]Z00Co0000ofP0ool0003o
00001OoonfX01?lH0?oo07CoonKo0?oVo`03oookJP;ooi005?oonfX3oonn00Cooo]Z0_l0o`D2on/0
o`03og00oooonf[ooo]Z013ooo]Z0oooE`0doookJP?ooeL06ooonfX00om`0?ooj`3oon/0o`02o`3o
1@Gooo]Z0_oo_P0LoookJP03oon@0?oonf[ooo]Z00Kooo]Z00Coi_l0o`1doooonf[o603o;OoonfX0
033ooo]Z00Goo`0Cool0Tooonf[ooo]Zo`3io`06oookJP07ooo:0?oonf[ooo]Zoa80oooonf[o0?lK
o`2>o`0;oookJP05ooo90?lm0?ooolT0ogSo0?oob@000_oonfX01?loo`3ooo]ZoookJ_l0:_l4oook
JP04oomB0?oonf[ooo]ZokWo01?ooo]Z00?o07?ooookJ_oonfX06?oonfX00ooo0>[ooo]ZoookJP06
oookJP03oolF0?ooTP3ooo]Z00Cooo]Z00?oolT0oookJ_oonfX00ooonfX01ooob@3ooo]ZoookJ_oo
1P3ooo]Zon_o0?oo0?H01?oonfX00ol0Y_oooo]ZojP0o`02oookJP03ool0nOoob@3o07Oo00KoolT0
00CoobP0oc_o0?oonf[oobP00_oonfX00oooN@3ooo]ZoookJP03oookJP09ool30?oonf[ooo]Zool0
gOmi0?oo0:?ook?o0?oonf[oW`3o00Kooo]Z00Coo`27omgo0?oonf[oo`1/0_oonfX3oolX0006odd0
oooo:03oobP0of40oooonf[o0?m51?oonfX00ooR0?oo0?n@oookJP02oookJP03o`3oT_oonf[ooo]Z
00Oooo]Z0_mX0?l3o`0000?ooo]Z00Co603oo`1dool0M?ooi_l00ooonfX2oon@01?ooo]Z0ooo_P04
oookJP05o`3o1Ooo:03oobP0oolX0?m`0?l02OoonfX00ooo:03ooo]ZoookJP06oookJP?ooeL0>Ooo
nfX4ooo900Cooo]Z1Ooob@0@oookJP04og00ooo[0?ooj`3ooookJP;o0?l51?oonfX2oonn01_ooo]Z
0_ooT007oookJP03onKo0?oonf[o07Co00;o603oFOoonfX01?oo01?oo`2CoookJ_l0nOl7oookJP06
ooo:0?oonf[ooo]Zoa80ool0oa_o08ko2ooonfX01_l0omoo?@3ooookJ_mho`3ooo]Zo`3Lo`;ooo]Z
00Co?ol0oookJ_oonf[o02[o0ooonfX01?ooDP3o0?lcoookJ_nio`0CoookJP03o`1coooonf[ooo]Z
01Sooo]Z00?oo`3ZoookJ_oonfX01_oonfX00ooo5P3ooi80oookJP05oookJP03ool0o?oonf[ooo]Z
00;ooo]Z00Co603ooookJ_oonf[oo`H00_oonfX00oo[o`3oo`3foookJP02oookJP03o`2Voooonf[o
Z03o00;ooo]Z00?oo`3ioookJ_l0Mol00ooonfX01_ooK03o0?nJo`3oc?oonf[ooh40oc_o00Cooo]Z
00?o0?_ooookJ_oonfX00_oonfX02Ooo0`3ooo]ZoookJ_oonf[oo`3MoookJ_l0Xooo/ol0oil0o`06
oookJP05ool0QooMo`3ooo]ZoookJ_oo06`01?oonfX01_m=0?ooobh0oookJ_oonf[oH@3oo`3oA@Co
oo]Z00?ohP3ooookJ_l0oi000ooonfX00ol0oi;ooo]ZoookJP06oookJP;oJ03o0ol00004oookJP03
oaP0ool0M?ooi_l000?ooo]Z0_ooT00DoookJP;ookh01OoonfX01?l0o`Goj`3oon/0ooo[0?lBoook
JP?ooeL0>_oonfX3oomG01[ooo]Z00?oL03oon/0oooonfX00_l0o`D5oookJP;ookh06ooonfX00ooo
T03ooo]ZoookJP06oookJP04onKo0?l0M?oooo]ZoaP0obcooo]Z000`oookJP05ool04ooo09?ooo]Z
oookJ_l0nOl01_oonfX00ooobP3ooo]Zoa80o`02oookJP03o`3o6ooonf[ooo]Z00[ooo]Z00OoolT0
oookJ_mho`3ooo]Zooo90?oonf[o?ol000;ooo]Z00?o02[ooookJ_oonfX00_oonfX01OooDP3ooo]Z
oookJ_oonf[o^Ol001;ooo]Z00?o07?ooookJ_oonfX06?oonfX00ooo0>[ooo]ZoookJP07oookJP03
oonB0?oonf[ooo]Z00Cooo]Z00?oolT0oookJ_oonfX00_oonfX01ooob@3ooo]ZoookJ_oo1P3ooo]Z
on_o0?oo0?H01?oonfX00ol0Y_oooo]ZojP0o`02oookJP04ool0nOoonf[o07OooookJPGoolT000?o
obP0oookJ_lko`000ooonfX00oooN@3ooo]ZoookJP03oookJP09ool30?oonf[ooo]Zool0gOmi0?oo
0:?ook?o0?l05oooW`3o00Kooo]Z00Coo`27omgo0?oonf[oo`1/0_oonfX3oolX0006odd0oooo:03o
obP0of40oooonf[o0?m51?oonfX00ooR0?oo0?n@oookJP02oookJP03o`3oT_oonf[ooo]Z00Oooo]Z
00?oJ03ooookJ_l000000ol00002oookJP04oaP0ool0M?ooi_l0onKo00;ooo]Z0_ooT00CoookJP;o
okh01OoonfX3oolX00;oL03o4?oonfX4oomG043ooo]Z2ooob@0@oookJP04og00ooo[0?oooo]Zoook
JP;o0?l51?oonfX2oonn01_ooo]Z00?ooi00oookJ_oonfX01?oonfX01_oVo`3ooo]ZoookJ_l0M?oo
oo]ZoaP0oeOooo]Z00Goo`0CoookJ_oo09?ooo]Zo`3io`06oookJP06ooo:0?oonf[ooo]Zoa80oooo
nf[o0?lK3?oonfX00ol0omoooo]ZogSo0002oookJP03o`3Loooonf[o?ol000;ooo]Z00Ko02[ooook
J_oonf[ooo]ZoomB0?l0oc<2oookJP03okWo0?oonf[ooo]Z013ooo]Z00?o07?ooookJ_oonfX06?oo
nfX00ooo0>[ooo]ZoookJP07oookJP03oonB0?oonf[ooo]Z00Cooo]Z00?oo`3loookJ_oonfX00_oo
nfX01?lH0?oooo]ZoookJ_oo1P02oookJP03on_o0?oo0?Kooo]Z00;ooo]Z00?o0:KooookJ_nX0?l0
0ooonfX00ooo0?Wo07OooookJP02oookJP06oom/0?l0oi[o0?o<oookJ_ooP@3o>ol01?oonfX00ol0
nooooo]ZoookJP02oookJP09ool30?oonf[ooo]ZoookJ_oo0=gooo]Zo`2Soonco`3oW`3o00Kooo]Z
00Goo`27omgo0?oonf[ooo]Zool0K004oookJP03odd0oooo;P3ooo]Z00;oH@3o00?o0?m5oookJ_oo
nfX00_oonfX00ooR0?oooo]Zo`3oT003oookJP03o`3oT_oonf[ooo]Z00Kooo]Z00?oJ03ooookJ_l0
00000ol00002oookJP;o603o0_oVo`02oookJP;ooi005?oonfX2oonn00Gooo]Z0oo[0?l00om`0?oo
oo]ZoookJP0>oookJPCooeL0@?oonfX4oomG01Sooo]Z0_o[0?l00ooonf[o0?l5o`3o1@05oookJP;o
okh06_oonfX00oooT03ooo]ZoookJP05oookJP04onKo0?oonf[o07CooookJP;o603o:_oonfX002oo
oo]Z00Goo`0Cool0Tooonf[ooo]Zo`3io`06oookJP07ooo:0?oonf[ooo]Zoa80oooonf[o0?lKo`2>
o`0;oookJP05ooo90?lm0?oooo]ZogSo0?l0g?l00_oonfX01?loo`3ooo]ZoookJ_l0:_l4oookJP04
oomB0?oonf[ooo]ZokWo01?ooo]Z00?o07?ooookJ_oonfX05ooonfX00ooo0>[ooo]ZoookJP07oook
JP03oonB0?oonf[ooo]Z00Cooo]Z00?oolT0oookJ_oonfX00_oonfX01ooob@3ooo]ZoookJ_oo1P3o
oo]Zon_o0?oo0?H01OoonfX01ol0Y_ooZ03ooookJ_oonf[oo`3ioookJ_l0Mol00ooonfX3ooo90003
oolX0?oob@3o>ol000Cooo]Z00?oogT0oookJ_oonfX00_oonfX02Ooo0`3ooo]ZoookJ_oo0=goN@3o
o`2Soonco`3o01Oooil0o`06oookJP05ool0QooMo`3ooo]ZoookJ_oo06`01?oo:0001_m=0?ooobP0
oolX0?mQ0?oooo]Zo`3oA@Cooo]Z00?ohP3oo`3oT?oonfX00_oonfX00ol0oi;ooo]ZoookJP07oook
JP03ofP0oooonf[ooo]Z00Co00000_lH0?l00ol0M?ooi_l0oookJP02oookJP03oon@0?oonf[ooo]Z
017ooo]Z0_oo_P05oookJP;oobP00_m`0?l@oookJP?ooeL0AooonfX:ooo9013ooo]Z0_o[0?l2oook
JP?o0?l50ooonfX2oonn01[ooo]Z00?ooi00oookJ_oonfX01?oonfX01_oVo`3ooo]ZoookJ_l0M?oo
oo]ZoaP0oeKooo]Z00Coo`0Cool0Tooonf[o0?Wo1ooonfX01_oobP3ooo]ZoookJ_lB0?oo0?lKo`2>
o`_ooo]Z00Ko0?oOocd0oooonf[oN?l0oookJ_l0g?l2oookJP04ocoo0?oonf[ooo]Zo`0Zo`?ooo]Z
00Cooe80o`3o<ooonf[o^Ol04ooonfX00ol0Looooo]ZoookJP0HoookJP03ool0j_oonf[ooo]Z00Ko
oo]Z00?ooi80oookJ_oonfX01OoonfX01Ooo0?cooo]ZoookJ_oonf[o603o00;ooo]Z00Goo`H0oook
J_oonf[ojol0ool0mP04oookJP03o`2VoonX0?oooo]Z00;ooo]Z00?oo`3io`1goooonfX00ooonfX0
1OooK03o0?o<oookJ_ooP@3o>ol000Gooo]Z00Go0?_ooookJ_oonf[ooo]Zool30003oookJP05ool0
gOmi0?oo0:?ook?o0?nO0?l01_oonfX00ooo08OogOl0oookJP02oookJP0:ool0K?oonf[ooo]Zoook
J_m=0?ooobh0oookJ_mQ0?oooo]Zo`3oA@Cooo]Z00?ohP3ooookJ_l0oi000_oonfX2o`3oTPSooo]Z
00?oJ03ooookJ_oonfX01?l000001?oonf[o603oo`1doooVo`03oookJP03oon@0?oonf[ooo]Z017o
oo]Z0ooo_P04oookJP03o`3o1Oo[0?ooj`3o00;oL03o3ooonfX3oomG04Sooo]Z0oooE`0GoookJP;o
j`3o00Cooo]Zo`3o1Ol0o`Go0?l51?oonfX00ooo_P3ooo]ZoookJP0HoookJP;ooi001_oonfX01_oV
o`3ooo]Zo`1dool0M?oooo]ZoaP0obWooo]Z000_oookJP05ool04ooo09?ooo]ZoookJ_l0nOl01_oo
nfX00ooobP3ooo]Zoa80o`02oookJP03o`3o6ooonf[ooo]Z00[ooo]Z00OoolT0oookJ_mho`3ooo]Z
o`3Loooonf[o?ol000;ooo]Z00?o02[ooookJ_oonfX00_oonfX01?ooDP3o0?lcoookJ_nio`0Coook
JP03o`1coooonf[ooo]Z01Sooo]Z00?oo`3ZoookJ_oonfX01_oonfX00ooo5P3ooi80oookJP04oook
JP03ooo90?oonf[ooo]Z00?ooo]Z00OoolT0oookJ_oonf[oo`H0on_o0?oonf[oo`3f00Cooo]Z00Oo
0:KooookJ_nX0?oooo]Zool0nOoonf[o07Oo00?ooo]Z00Ko0?nJooo90?oo:03oobP0ooo90?lko`04
oookJP03oomi0?oonf[ooo]Z00;ooo]Z00Woo`<0oookJ_oonf[oo`3MogT0oooonf[o/ol0o`0GoonO
0?l01_oonfX01Ooo08OogOl0oookJ_oonf[oo`1/00CoobP000KoC@3ooolX0?mQ0?ooH@3ooookJ_l0
odD4oookJP03on80ool0oi3ooo]Z00;ooo]Z00?o0?nBoookJ_oonfX01ooonfX01?mX0?oooo]Zoook
J_oonfX3o`000004oaP0oooonf[oi_l0onKo00?ooo]Z00?ooi00oookJ_oonfX03ooonfX3oonn00Co
oo]Z0ooo:002og00o`oooo]Z0oooE`0SoookJPSoo`0]7ooonfX<ooo9013ooo]Z0_o[0?l3oookJP;o
0?l50ooonfX2oonn01Wooo]Z00?ooi00oookJ_oonfX01?oonfX00ooVo`3ooo]ZoookJP02o`1do`03
oaP0oooonf[ooo]Z05;ooo]Z00Goo`0CoookJ_oo09?ooo]Zo`3io`06oookJP06ooo:0?oonf[ooo]Z
oa80oooonf[o0?lK3?oonfX00ol0omoooo]ZogSo0002oookJP03o`3Loooonf[o?ol000;ooo]Z00So
02[ooookJ_oonf[ooo]ZoomB0?oonf[o0?lcokWo01?ooo]Z00?o07?ooookJ_oonfX06?oonfX00ooo
0>[ooo]ZoookJP06oookJP03oolF0?ooTP3ooo]Z00Gooo]Z00?oo`3loookJ_oonfX00_oonfX02?lH
0?oooo]ZoookJ_oo1P3ooo]Zon_o0?oonf[oo`3f0ooonfX00ol0Y_oooo]ZojP0o`02oookJP03ool0
nOl0Mooooo]Z00?ooo]Z00Goof`0oookJ_l0olcooh40oc_o0005oookJP05o`3koooonf[ooo]Zoook
J_oo0`000ooonfX01Ooo0=goN@3ooookJ_nco`3oW`3o00Kooo]Z00?oo`27omgo0?oonfX00_oonfX0
2_oo06cooo]ZoookJ_oonf[oC@3oool^0?oonf[oH@3ooookJ_l0odD4oookJP03on80oooonf[o0?n@
00;ooo]Z00?o0?nBoookJ_oonfX01ooonfX01?mX0?oooo]ZoookJ_oonfX4o`000003oaP0oooVo`3o
i_l000?ooo]Z00?ooi00oookJ_oonfX04?oonfX2oonn00Gooo]Z0oo[0?l00om`0?oooo]ZoookJP0=
oookJP?ooeL08ooonfX8ool0;B?ooo]Z1?ooE`0DoookJP03og00ooo[0?oooo]Z00;ooo]Z0_l0o`D3
oookJP;ookh06_oonfX00oooT03ooo]ZoookJP04oookJP06onKo0?oonf[ooo]Zo`1doooonf[o603o
:?oonfX002oooo]Z00Coo`0Cool0Tooonf[o0?Wo1_oonfX01ooobP3ooo]ZoookJ_lB0?oooo]Zo`3o
6ol0S_l02ooonfX01Olm0?ooolT0oookJ_mho`3o0=co00;ooo]Z00Co?ol0oookJ_oonf[o02[o1?oo
nfX01?ooDP3ooo]ZoookJ_nio`0BoookJP03o`1coooonf[ooo]Z01Sooo]Z00?oo`3ZoookJ_oonfX0
1_oonfX00ooo5P3ooi80oookJP05oookJP03ooo90?oonf[ooo]Z00;ooo]Z00OoolT0oookJ_oonf[o
o`H0on_o0?oonf[oo`3f00Cooo]Z00Oo0:KooookJ_nX0?oooo]Zool0nOoonf[o07Oo00Cooo]Z00Go
olT0oolX0?oo:03ooo]Zoc_o0004oookJP03oomi0?oonf[ooo]Z00;ooo]Z00Woo`<0oookJ_oonf[o
oo]Zool0gOoonf[o/ol0o`0GoonO0?l01_oonfX01Ooo08OogOl0oookJ_oonf[oo`1/00CoobP000Co
C@3ooolX0?mQ0?ooobP00_l0odD4oookJP03on80ool0oi3ooo]Z00;ooo]Z00?o0?nBoookJ_oonfX0
1ooonfX00omX0?oooo]ZoookJP02oookJP;o000000?o603oo`1doooVo`001?oonfX00oooT03ooo]Z
oookJP0>oookJP;ookh01?oonfX3oolX00;oL03o3_oonfX4oomG01gooo]Z2Ooo02d8oookJPGoo`0]
6OoonfX>ooo9017ooo]Z0_o[0?l3oookJP;o0?l50ooonfX2oonn01Sooo]Z00?ooi00oookJ_oonfX0
1?oonfX01_oVo`3ooo]ZoookJ_oonf[o07CooaP0oe?ooo]Z00Coo`0Cool0Tooonf[o0?Wo1ooonfX0
1_oobP3ooo]ZoookJ_lB0?oo0?lKo`2>o`cooo]Z00Go0?oOoookJ_mho`3ooo]Zo`3Lo`02oookJP04
ocoo0?oonf[ooo]Zo`0Zo`?ooo]Z00Cooe80o`3o<ooonf[o^Ol04_oonfX00ol0Looooo]ZoookJP0I
oookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooaH0oonB0?oonfX01OoonfX00ooo0?cooo]ZoookJP02
oookJP08oaP0oooonf[ooo]Zool60?oonf[ojol0oookJ_oo0?H3oookJP03o`2Voooonf[oZ03o00;o
oo]Z00?oo`3io`1goooonfX00ooonfX01_ooK03o0?nJo`3oc?ooP@3ooo]Zoc_o00Cooo]Z00Go0?_o
oookJ_oonf[ooo]Zool30004oookJP04ool0gOoonf[o/ol0oil0o`Kooo]Z00?oo`27omgo0?oonfX0
0_oonfX02?oo06cooo]ZoookJ_oonf[oC@3oool^0?oonf[oH@3o0_l0odD4oookJP03on80ool0oi3o
0?n@00;ooo]Z00?o0?nBoookJ_oonfX01ooonfX00omX0?oooo]ZoookJP02oookJP?o000000?o603o
onKo0?oonfX00ooonfX00oooT03ooo]ZoookJP0?oookJP;ookh01?oonfX3on/0o`;oL03o3OoonfX4
oomG01gooo]Z2Ooo02d8oookJPKoo`0]8OoonfX3oomG01?ooo]Z0_o[0?l3oookJP;o0?l50ooonfX2
oonn01Wooo]Z00?ooi00oookJ_oonfX01?oonfX01_oVo`3ooo]ZoookJ_l0M?oooo]ZoaP0obOooo]Z
000^oookJP05ool04ooo09?ooo]ZoookJ_l0nOl01_oonfX00ooobP3ooo]Zoa80o`02oookJP03o`3o
6ooonf[ooo]Z00[ooo]Z00OoolT0oookJ_mho`3ooo]Zo`3Loooonf[o?ol000;ooo]Z00?o02[ooook
J_oonfX00_oonfX01?ooDP3o0?lcoookJ_nio`0CoookJP03o`1coooonf[ooo]Z01Oooo]Z00?oo`3Z
oookJ_oonfX01ooonfX00oooTP3ooo]ZoookJP04oookJP03ooo90?oonf[ooo]Z00;ooo]Z00OoolT0
oookJ_oonf[oo`H0on_o0?oonf[oo`3f00Cooo]Z00Oo0:KooookJ_nX0?oooo]Zool0nOoonf[o07Oo
00Cooo]Z00GoolT0oookJ_oo:03ooo]Zoc_o0004oookJP03oomi0?oonf[ooo]Z00;ooo]Z00Woo`<0
oookJ_oonf[ooo]Zool0gOoonf[o0:?ook?o0?nO0?l01_oonfX01Ooo08OogOl0oookJ_oonf[oo`1/
00CoobP000GoC@3ooolX0?mQ0?ooobP0o`3oA@05oookJP03on80ool0oi3ooo]Z00;ooo]Z00?o0?nB
oookJ_oonfX01ooonfX00omX0?oooo]ZoookJP03oookJP05o`000?lH0?ooi_l0onKo0?l000000_oo
nfX2oon@013ooo]Z00?ookh0oookJ_oonfX00_oonfX00oo[0?ooobP0o`3o1@02og00o`gooo]Z0ooo
E`0HoookJPWoo`0]5_oonfX6ool0;A?ooo]Z4?oob@0@oookJP03og00ooo[0?oooo]Z00?ooo]Z00?o
0?l5oookJ_oonfX00_oonfX2oonn01Oooo]Z0_ooT005oookJP06onKo0?oonf[ooo]ZoookJ_l0M?oo
603oDOoonfX01Ooo01?ooo]Zool0Tooonf[o0?Wo00Oooo]Z00GoolX0oookJ_lB0?oooo]Zo`3o6`0<
oookJP03o`3ogooonf[oN?l000;ooo]Z00?o0=cooookJ_loo`000_oonfX02?l0:_oooo]ZoookJ_oo
nf[ooe80oookJ_l0oc?o^Ol04ooonfX00ol0Looooo]ZoookJP0HoookJP03ool0j_oonf[ooo]Z00Ko
oo]Z00?ooi80oookJ_oonfX01?oonfX00ooo0?cooo]ZoookJP02oookJP08oaP0oooonf[ooo]Zool6
0?oonf[ojol0oookJ_oo0?H3oookJP03o`2Voooonf[oZ03o00;ooo]Z00?oo`3io`1goooonfX01?oo
nfX01OooK03o0?o<oon10?oonf[o>ol000Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30004oookJP04
ool0gOoonf[o0:?ook?o00Kooo]Z00?oo`27omgo0?oonfX00_oonfX02Ooo06cooo]ZoookJ_oonf[o
C@3oool^0?oonf[oH@3oo`3oA@05oookJP03on80ool0oi3ooo]Z00;ooo]Z00?o0?nBoookJ_oonfX0
1ooonfX00omX0?oooo]ZoookJP03oookJP05o`000?lH0?oo603oonKo0?l000000_oonfX2oon@017o
oo]Z00?ookh0oookJ_oonfX00_oonfX2on/0o`;oL03o3OoonfX3oomG01Sooo]Z2Ooo02dGoookJPGo
o`0]7ooonfX3oomG01;ooo]Z0_o[0?l3oookJP03o`3o1Ooonf[ooo]Z00;ooo]Z0_oo_P0HoookJP03
oon@0?oonf[ooo]Z00Cooo]Z00Koi_l0oookJ_oonf[o07CooookJ_lH0?lVoookJP00;_oonfX01?oo
01?oo`2CoookJ_l0nOl7oookJP06ooo:0?lB0?oooo]ZoookJ_l0oa_o08ko2ooonfX01Olm0?ooolT0
oookJ_mho`3o0=co00;ooo]Z00?o?ol0oookJ_l0:_l01OoonfX01?ooDP3ooo]ZoookJ_nio`0Boook
JP03o`1coooonf[ooo]Z01Sooo]Z00?oo`3ZoookJ_oonfX01_oonfX00oooTP3ooo]ZoookJP04oook
JP03ooo90?oonf[ooo]Z00;ooo]Z00SoolT0oookJ_oonf[ooo]Zool60?o[o`3ooo]Zool0mPCooo]Z
00Co0:KoojP0oooonf[oo`3i0_oonfX01_l0Mooooo]ZoookJ_oonf[o0?nJooo900;oobP000?o>ol0
oookJ_oonfX00_oonfX00oooN@3ooo]ZoookJP02oookJP09ool30?oonf[ooo]ZoookJ_oo0=goN@3o
o`2Soonco`3oW`3o00Kooo]Z00Koo`27omgo0?oonf[ooo]Zool0K?oonfX3oolX0006odd0oooo:03o
H@3ooolX0?l0odGoobP01?oonfX00ooR0?oo0?n@oookJP02oookJP03o`3oT_oonf[ooo]Z00Kooo]Z
0_mX0?l5oookJP;o603o00?oi_l0o`000?l000000_oonfX00oooT03ooo]ZoookJP0>oookJP;ookh0
1?oonfX01?o[0?ooL03oog00oom`0?l<oookJP?ooeL04_oonfX9ool0;BGooo]Z1Ooo02dGoookJPSo
olT000?ooeL0oookJ_oonfX03_oonfX2on/0o`?ooo]Z00?o0?l5oookJ_oonfX00ooonfX00ooo_P3o
oo]ZoookJP0FoookJP03oon@0?oonf[ooo]Z00?ooo]Z00Koi_l0oookJ_oonf[ooo]Zo`1doolH0?m@
oookJP04ool04ooonf[oo`2Co`3io`Oooo]Z00KoolX0oookJ_lB0?oooo]Zo`3o6ol0S_l;oookJP06
ocd0ool0omoooo]ZogSo0?oonf[o0=co0_oonfX00oloo`3ooo]Zo`0Zo`04oookJP04oomB0?l0oc?o
oo]ZokWo01;ooo]Z00?o07?ooookJ_oonfX06?oonfX00ooo0>[ooo]ZoookJP06oookJP03oonB0?oo
nf[ooo]Z00Gooo]Z00Goo`3loookJ_oonf[ooo]ZoaP0o`03oookJP05ool60?oonf[ojol0oookJ_oo
0?H00ooonfX01ol0Y_ooZ03ooookJ_oonf[oo`3ioookJ_l0Mol01?oonfX01OooK03o0?o<oon10?oo
nf[o>ol000Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30004oookJP04ool0gOoonf[o0:?ook?o00Ko
oo]Z00?oo`27omgo0?oonfX00_oonfX02Ooo06cooo]ZoookJ_oonf[oC@3oool^0?oonf[oH@3oo`3o
A@05oookJP03on80ool0oi3ooo]Z00;ooo]Z00?o0?nBoookJ_oonfX01_oonfX2ofP0o`Kooo]Z00Co
603oonKo0?l0003o00000_oonfX00oooT03ooo]ZoookJP0?oookJP;ookh01?oonfX00oo[0?ooL03o
og00o`0<oookJP?ooeL04_oonfX9ool0;BGooo]Z1_oo02dLoookJP?ooeL04?oonfX00om`0?ooj`3o
oookJP02oookJP03o`3o1Ooonf[ooo]Z00?ooo]Z00?ookh0oookJ_oonfX05_oonfX2oon@00Gooo]Z
00Koi_l0oookJ_oonf[o07CooookJ_lH0?lUoookJP00;OoonfX01Ooo01?ooo]Zool0Tooonf[o0?Wo
00Kooo]Z00?oolX0oookJ_lB0?l00_oonfX00ol0oa_o08kooookJP0:oookJP07ooo90?oonf[oN?l0
oookJ_l0g?oooo]Zocoo0002oookJP03o`0Zoooonf[ooo]Z00?ooo]Z00?ooe80oookJ_nio`004_oo
nfX00ol0Looooo]ZoookJP0HoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooi80oookJ_oonfX01Ooo
nfX01Ooob@3ooo]ZoookJ_oonf[oolT000?ooo]Z00Coo`H0on_o0?oonf[oo`3f1?oonfX01?l0Y_oo
oo]ZojP0oooo0?T2oookJP06o`1goooonf[ooo]ZoookJ_l0oi[oolT00_oo:0000olko`3ooo]Zoook
JP02oookJP03oomi0?oonf[ooo]Z00;ooo]Z00Woo`<0oookJ_oonf[ooo]Zool0gOmi0?oooo]Zok?o
0?nO0?l01_oonfX01Ooo08OogOl0oookJ_oonf[oo`1/00?ooo]Z00OoobP0odd0oooo:03oH@3ooolX
0?l0odGoobP000Cooo]Z00?ohP3oo`3oT?oonfX00_oonfX00ol0oi;ooo]ZoookJP06oookJP03ofP0
oooonf[ooo]Z00Cooo]Z00?o603oonKo0?l0M?l00ol000000ooonf[ooi00oookJP0?oookJP03oonn
0?oonf[ooo]Z00;ooo]Z0_o[0?l00om`0?oooo]ZoookJP0:oookJP?ooeL04?oonfX5ool0;C?ooo]Z
1_oo02dJoookJP03oomG0?oonf[ooo]Z00oooo]Z0_o[0?l2oookJP03o`3o1Ooonf[ooo]Z00;ooo]Z
00?ookh0oookJ_oonfX05ooonfX00oooT03ooo]ZoookJP03oookJP06onKo0?oonf[ooo]ZoookJ_l0
M?oo603oC_oonfX01Ooo01?ooo]Zool0Tooonf[o0?Wo00Oooo]Z00KoolX0oookJ_lB0?oooo]Zo`3o
6ol0S_l;oookJP03o`3ogooonf[oN?l000;ooo]Z00?o0=cooookJ_loo`000_oonfX00ol0:_oooo]Z
oookJP02oookJP03oomB0?l0oc?o^Ol001;ooo]Z00?o07?ooookJ_oonfX06OoonfX00ooo0>[ooo]Z
oookJP05oookJP03oonB0?oonf[ooo]Z00Gooo]Z00Goo`3loookJ_oonf[ooo]ZoaP0o`03oookJP05
ool60?oonf[ojol0oookJ_oo0?H00ooonfX01ol0Y_oooo]ZojP0oooonf[oo`3ioookJ_l0Mol01?oo
nfX01OooK03ooo]Zoon10?oonf[o>ol000Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30004oookJP04
ool0gOoonf[o0:?ook?o00Kooo]Z00?oo`27omgo0?oonfX00_oonfX02Ooo06cooo]ZoookJ_oonf[o
C@3oool^0?oonf[oH@3oo`3oA@05oookJP03on80ool0oi3ooo]Z00;ooo]Z00?o0?nBoookJ_oonfX0
1_oonfX00omX0?oooo]ZoookJP05oookJP03oaP0ool0M?oo000000;o000000?ooo]Zoon@0?oonfX0
4?oonfX00ooo_P3ooo]ZoookJP02oookJP;oj`3o3?oonfX3oomG013ooo]Z1Ooo02ddoookJPKoo`0]
6OoonfX00oooE`3ooo]ZoookJP0?oookJP;oj`3o0_oonfX00ol0o`Gooo]ZoookJP02oookJP03oonn
0?oonf[ooo]Z01Sooo]Z00?ooi00oookJ_oonfX00ooonfX01_oVo`3ooo]ZoookJ_l0M?oooo]ZoaP0
obCooo]Z000]oookJP04ool04ooo09?ooo]Zo`3io`Oooo]Z00KoolX0oa80oooonf[ooo]Zo`3o6ol0
S_l;oookJP05ocd0oooob@3ooo]ZogSo0?l0g?l00_oonfX00oloo`3ooo]Zo`0Zo`05oookJP03oomB
0?oonf[o^Ol001?ooo]Z00?o07?ooookJ_oonfX05ooonfX00ooo0>[ooo]ZoookJP06oookJP03oolF
0?ooTP3ooo]Z00Gooo]Z00?oolT0oookJ_oonfX00_oonfX01OlH0?oooo]ZoookJ_oo1P3ojol000;o
oo]Z00_oo`3foookJ_oonf[ooo]Zo`2Voooonf[oZ03ooookJ_oo0?Wooo]Zo`1go`04oookJP04ooo9
0?oo:03oobP0oc_o00Gooo]Z00GoogT0oookJ_oonf[ooo]Zool30003oookJP05ool0gOmi0?oooo]Z
ok?o0?nO0?l01_oonfX00ooo08OogOl0oookJP02oookJP09ool0K?oonf[ooo]ZoookJ_m=0?ooobP0
of40oooo:03o0?m500;oobP00ooonfX01?oR0?oo0?n@oookJ_oonfX2o`3oTPSooo]Z00?oJ03ooook
J_oonfX01?oonfX00olH0?ooi_l0o`1do`04o`000003oon@0?oonf[ooo]Z00kooo]Z00Oookh0oook
J_oonf[ooo]Zo`3o1Oo[0?ooL03o00_ooo]Z0oooE`0@oookJP?oo`0]?_oonfX5ool0;AKooo]Z00?o
oeL0oookJ_oonfX04?oonfX01?o[0?ooL03ooookJ_l0o`D4oookJP03oonn0?oonf[ooo]Z01Oooo]Z
00?ooi00oookJ_oonfX00_oonfX01OoVo`3ooo]ZoookJ_oonf[o07Co04oooo]Z00Coo`0CoookJ_oo
09?o0?Wo1ooonfX01_oobP3ooo]Zoa80oooonf[o0?lKo`2>o`_ooo]Z00Ko?@3oo`3ogooonf[oN?l0
oookJ_l0g?l2oookJP03ocoo0?oonf[o02[o00Cooo]Z00?ooe80o`3o<onio`004ooonfX00ol0Looo
oo]ZoookJP0HoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooaH0oonB0?oonfX01OoonfX00ooo0?co
oo]ZoookJP02oookJP08oaP0oooonf[ooo]Zool60?oonf[ojol0oookJ_oo0?H3oookJP03o`2Voooo
nf[oZ03o00;ooo]Z00?oo`3io`1goooonfX00ooonfX01OooK03o0?nJo`3oc?ooP@3o>ol000Gooo]Z
00Co0?_ooookJ_oonf[oo`<01?oonfX01?oo0=gooo]ZoookJ_nco`06oookJP03ool0QooMo`3ooo]Z
00;ooo]Z00Woo`1/oookJ_oonf[ooo]Zodd0oooonf[oobh0of40ool0odD01OoonfX00ooR0?oo0?n@
oookJP02oookJP03o`3oT_oonf[ooo]Z00Kooo]Z00?oJ03ooookJ_oonfX01?oonfX2oaP0o`03o`1d
ool0003o000000;o000000?ooi00oookJ_oonfX03_oonfX2oonn00;ooo]Z0_l0o`D00oo[0?oooo]Z
oookJP09oookJP?ooeL04?oonfX3ool0;Coooo]Z1Ooo02dEoookJP03oomG0?oonf[ooo]Z013ooo]Z
0_o[0?l00ooonf[o0?l5oookJP03oookJP03oonn0?oonf[ooo]Z01Sooo]Z00?ooi00oookJ_oonfX0
0_oonfX01?oVo`3ooo]ZoookJ_l0M?lVoookJP00;?oonfX01Ooo01?ooo]Zool0Tooonf[o0?Wo00Ko
oo]Z00?oolX0oookJ_lB0?l00_oonfX00ol0oa_o08kooookJP09oookJP08ocd0oooob@3ooo]ZogSo
0?oonf[o0=cooookJ_loo`02oookJP03o`0Zoooonf[ooo]Z00?ooo]Z00?ooe80oookJ_nio`004_oo
nfX00ol0Looooo]ZoookJP0HoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooi80oookJ_oonfX01?oo
nfX00ooob@3ooo]ZoookJP02oookJP08oaP0oooonf[ooo]ZoookJ_oo1P3ojol0oookJ_oo0?H3oook
JP05o`2Voooonf[oZ03ooookJ_oo0?T00_oonfX02?l0Mooooo]ZoookJ_oonf[oolT0oookJ_oo:03o
>ol01OoonfX01OooN@3ooo]ZoookJ_oonf[oo`<000Cooo]Z00Goo`3MoookJ_l0Xooo/ol0oil0o`05
oookJP03ool0QooMo`3ooo]Z00;ooo]Z00Woo`1/oookJ_oonf[ooo]Zodd0oooo:03oH@3ooolX0?l0
odD00_oo:003oookJP05on80ool0oi3ooo]ZoookJ_l0oi802OoonfX00omX0?oooo]ZoookJP04oook
JP04oaP0ool0M?oooo]ZoookJP;o00000_ooT00?oookJP;ookh00_oonfX01?l0o`Goj`3oon/0oom`
0?l:oookJP;ooeL04OoonfX2ool0;DKooo]Z1?oo02dCoookJP;ooeL04OoonfX2on/0o`03oookJ_l0
o`Gooo]Z00?ooo]Z00?ookh0oookJ_oonfX05ooonfX00oooT03ooo]ZoookJP02oookJP05onKo0?oo
nf[ooo]ZoookJ_l0M?l0C_oonfX01?oo01?oo`2CoookJ_l0nOl7oookJP06ooo:0?oonf[o4P3ooook
J_l0oa_o08ko2ooonfX00ol0omoooo]ZogSo0002oookJP03o`3Loooonf[o?ol000;ooo]Z00?o02[o
oookJ_oonfX00_oonfX00oooDP3o0?lcokWo000BoookJP03o`1coooonf[ooo]Z01Sooo]Z00?oo`3Z
oookJ_oonfX01_oonfX00oooTP3ooo]ZoookJP05oookJP05ool0o?oonf[ooo]ZoookJ_lH0?l00ooo
nfX01Ooo1P3ooo]Zon_o0?oonf[oo`3f00;ooo]Z00?o0:KooookJ_nX0?l00_oonfX00ooo0?Wooo]Z
o`1go`04oookJP04oom/0?l0olcooh40oc_o00Gooo]Z00Co0?_ooookJ_oonf[oo`<01?oonfX01Omi
0?ooo`3MoookJ_nco`3oW`3o00Gooo]Z00?oo`27omgo0?oonfX00ooonfX02?oo06cooo]ZoookJ_oo
nf[oC@3oool^0?mQ0?oo0?m51OoonfX00ooR0?oo0?n@oookJP02oookJP03o`3oT_oonf[ooo]Z00Ko
oo]Z00?oJ03ooookJ_oonfX01?oonfX01?lH0?oo07CooookJ_oonfX2o`0000;ooi004?oonfX00ooo
_P3ooo]ZoookJP02o`3o1@;oj`3o2ooonfX00oooE`3ooo]ZoookJP0?oookJP;oo`0]AooonfX4ool0
;A;ooo]Z0_ooE`0BoookJP03on/0oooonf[o0?l500Cooo]Z00?ookh0oookJ_oonfX06?oonfX00ooo
T03ooo]ZoookJP02oookJP04onKo0?oonf[ooo]Zo`1dobGooo]Z000/oookJP04ool04ooo09?ooo]Z
o`3io`Oooo]Z00KoolX0oa80oooonf[ooo]Zo`3o6ol0S_l;oookJP05ocd0oooob@3ooo]ZogSo0?l0
g?l00_oonfX01?loo`3ooo]ZoookJ_l0:_l4oookJP03oomB0?oonf[o^Ol001;ooo]Z00?o07?ooook
J_oonfX06?oonfX00ooo0>[ooo]ZoookJP06oookJP03oolF0?ooTP3ooo]Z00Cooo]Z00?oolT0oook
J_oonfX00ooonfX01olH0?oooo]ZoookJ_oo1P3ojol0oookJ_oo0?H00ooonfX01Ol0Y_oooo]Zoook
J_nX0?ooo`3i00;ooo]Z00So07OooookJ_oonf[ooo]Zo`3oV_oob@3oobP0oc_o00Gooo]Z00GoogT0
oookJ_oonf[ooo]Zool30004oookJP05ool0gOoonf[o0:?ook?o0?nO0?l01?oonfX2ool00005omgo
0?oonf[ooo]ZoookJ_oo06`00ooonfX01Om=0?ooobP0oookJ_mQ0?oo0?m500?oobP00_oonfX01OoR
0?oo0?n@oookJ_oonf[o0?nB00Wooo]Z00?oJ03ooookJ_oonfX01?oonfX00olH0?oo07CooookJP02
oookJP04o`000?ooT03o0000o`0000kooo]Z00Cookh0oookJ_oonf[o0?l50_o[0?l00om`0?oooo]Z
oookJP09oookJP03oomG0?oonf[ooo]Z00kooo]Z0ooo02e<oookJP;oo`0]4ooonfX00oooE`3ooo]Z
oookJP0@oookJP;oj`3o00?o0?l5oookJ_oonfX00_oonfX00ooo_P3ooo]ZoookJP0GoookJP03oon@
0?oonf[ooo]Z00;ooo]Z00Coi_l0oookJ_oonf[o07CoCOoonfX01?oo01?ooo]Zool0Tol0nOl7oook
JP06ooo:0?oonf[o4P3ooookJ_l0oa_o08ko2ooonfX01_lm0?oo0?oOoookJ_mho`3ooo]Zo`3Lo`;o
oo]Z00?o?ol0oookJ_l0:_l01?oonfX00oooDP3o0?lcokWo000BoookJP03o`1coooonf[ooo]Z01Wo
oo]Z00?oo`3ZoookJ_oonfX01OoonfX00ooo5P3ooi80oookJP05oookJP03ool0o?oonf[ooo]Z00;o
oo]Z00So603ooookJ_oonf[oo`H0oookJ_o[o`3ooo]Zool0mP;ooo]Z00So0:KooookJ_oonf[oZ03o
oookJ_oo0?Wooo]Zo`1go`Cooo]Z00Coof`0o`3oc?ooP@3o>ol01OoonfX01?l0nooooo]ZoookJ_oo
0`04oookJP05ogT0oooo0=gooo]Zo`2Soonco`001OoonfX00ooo08OogOl0oookJP03oookJP08ool0
K?oonf[ooo]ZoookJ_m=0?ooobh0oookJ_mQ0?l5oookJP03on80ool0oi3ooo]Z00;ooo]Z00?o0?nB
oookJ_oonfX01_oonfX00omX0?oooo]ZoookJP04oookJP03oaP0ool0M?oooo]Z00;ooo]Z00Co0000
oon@0?l0003o00003ooonfX01?oo_P3ooo]Zo`3o1Ol0o`D2on/0o`_ooo]Z0_ooE`0?oookJP?oo`0]
COoonfX2ool0;A;ooo]Z00?ooeL0oookJ_oonfX04?oonfX2on/0o`03o`3o1Ooonf[ooo]Z00;ooo]Z
00?ookh0oookJ_oonfX06?oonfX00oooT03ooo]ZoookJP02oookJP04onKo0?oonf[ooo]Zo`1dobCo
oo]Z000/oookJP04ool04ooo09?ooo]Zo`3io`Kooo]Z00?oolX0oookJ_lB0?l00_oonfX00ol0oa_o
08kooookJP09oookJP08ocd0oooob@3ooo]ZogSo0?oonf[o0=cooookJ_loo`02oookJP03o`0Zoooo
nf[ooo]Z00?ooo]Z00?ooe80oookJ_nio`004_oonfX00ol0Looooo]ZoookJP0GoookJP03ool0j_oo
nf[ooo]Z00Kooo]Z00?ooaH0oonB0?oonfX01OoonfX00ooob@3ooo]ZoookJP02oookJP08oaP0oooo
nf[ooo]Zool60?oonf[ojol0oookJ_oo0?H3oookJP07o`2Voooonf[oZ03ooookJ_oo0?Wooo]Zo`1g
o`03oookJP04o`3oV_oob@3oobP0oc_o00Gooo]Z00GoogT0oookJ_oonf[ooo]Zool30004oookJP05
ool0gOoonf[o0:?ook?o0?nO0?l01?oonfX3ool000?ooo]Z00Woo`1/oookJ_oonf[ooo]Zodd0oooo
nf[oobP0of40ool0odD00_oonfX01?oo:03ooo]ZoookJ_oR0?l3oookJP03o`3oT_oonf[ooo]Z00Oo
oo]Z00?oJ03ooookJ_oonfX00ooonfX2oaP0o`03o`1doooonf[ooo]Z00;ooo]Z00Cooi00o`000?l0
003o00003?oonfX2oonn0004oookJ_l0o`Go0?l5on/0o`;oL03o2_oonfX2oomG00oooo]Z0_oo02eA
oookJP;oo`0]4_oonfX2oomG01;ooo]Z00?oj`3oo`3o1OoonfX00ooonfX00ooo_P3ooo]ZoookJP0G
oookJP;oogT00ooonfX00ooVo`3ooo]ZoookJP1=oookJP04ool04ooo09?ooo]Zo`3io`Oooo]Z00Ko
olX0oookJ_lB0?oooo]Zo`3o6ol0S_l:oookJP04ocd0ool0omoooo]ZogSo00;ooo]Z00?o0=cooook
J_loo`000_oonfX00ol0:_oooo]ZoookJP02oookJP03oomB0?l0oc?o^Ol001;ooo]Z00?o07?ooook
J_oonfX06?oonfX00ooo0>[ooo]ZoookJP05oookJP03oolF0?ooTP3ooo]Z00Gooo]Z00?oo`3loook
J_oonfX00_oonfX01?lH0?oooo]ZoookJ_oo1P02oookJP03on_o0?oonf[oo`3f00;ooo]Z00?o0:Ko
oookJ_nX0?l00_oonfX00ooo0?Wo07OooookJP03oookJP04oom/0?l0olcooh40oc_o00Gooo]Z00Co
0?_ooookJ_oonf[oo`<01?oonfX01Omi0?ooo`3MoookJ_l0Xooo/ol000Gooo]Z00?o0?oNool0Qooo
nfX00ooonfX02?oo06cooo]ZoookJ_oonf[oC@3oool^0?oonf[oH@3o1OoonfX00ooR0?oo0?n@oook
JP02oookJP03o`3oT_oonf[ooo]Z00Kooo]Z00?oJ03ooookJ_oonfX01?oonfX00olH0?oo07Cooook
JP03oookJP04oon@0?l0003o0000o`0000gooo]Z0_oo_P02o`3o1@03oookJ_o[0?ooL03o00[ooo]Z
0_ooE`0?oookJP;oo`0]D_oonfX2ool0;A7ooo]Z0_ooE`0BoookJP;oj`3o1?oonfX00ooo_P3ooo]Z
oookJP0HoookJP03oon@0?oonf[ooo]Z00;ooo]Z00?oi_l0oookJ_oonfX09?oonfX002_ooo]Z00Co
o`0CoookJ_oo09?o0?Wo1ooonfX01_oobP3ooo]Zoa80oooonf[o0?lKo`2>o`_ooo]Z00Go?@3oooo9
0?mho`3ooo]Zo`3Lo`02oookJP04ocoo0?oonf[ooo]Zo`0Zo`Cooo]Z00?ooe80oookJ_nio`004_oo
nfX00ol0Looooo]ZoookJP0HoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooaH0oookJ_ooTP001Ooo
nfX00ooob@3ooo]ZoookJP02oookJP08oaP0oooonf[ooo]ZoookJ_oo1P3ojol0oookJ_oo0?H3oook
JP05o`2Voooonf[oZ03ooookJ_oo0?T00_oonfX02?l0Mooooo]ZoookJ_l0oi[oolT0oolX0?oonf[o
>ol01?oonfX01OooN@3ooo]ZoookJ_oonf[oo`<000Cooo]Z00Goo`3MoookJ_oonf[o/ol0oil0o`04
oookJP?oo`000ooonfX00ooo06cooo]ZoookJP02oookJP04odd0oooo:03oH@3oo`3oA@Gooo]Z00Go
hP3ooookJ_oonf[ooo]Zo`3oTP09oookJP03ofP0oooonf[ooo]Z00?ooo]Z00?o603oonKo0?l0M?l0
1?oonfX00oooT03o0000o`000002o`0000_ooo]Z00Cookh0oookJ_oonf[o0?l50_o[0?l00om`0?oo
oo]ZoookJP08oookJP;ooeL03ooonfX2ool0;EGooo]Z00?oo`0]oookJ_oonfX04OoonfX00oooE`3o
oo]ZoookJP0?oookJP03og00ooo[0?ooj`3o00Cooo]Z00?ookh0oookJ_oonfX05_oonfX00oooN@3o
oo]ZoookJP03oookJP03onKo0?oonf[ooo]Z04_ooo]Z00Coo`0CoookJ_oo09?o0?Wo1ooonfX01_oo
bP3ooo]ZoookJ_lB0?oo0?lKo`2>o`_ooo]Z00?o?@3oo`3ogomho`000_oonfX01?l0g?oooo]Zoook
J_loo`02oookJP07o`0Zoooonf[ooo]ZoookJ_ooDP3o0?lcokWo000BoookJP03o`1coooonf[ooo]Z
01Sooo]Z00?oo`3ZoookJ_oonfX01OoonfX00ooo5P3ooo]ZoonB0005oookJP03ool0o?oonf[ooo]Z
00;ooo]Z00Wo603ooookJ_oonf[ooo]Zool60?oonf[ojol0oookJ_oo0?H00_oonfX00ol0Y_oooo]Z
ojP0o`02oookJP03ool0nOoonf[o07Oo00?ooo]Z00Go0?nJoom/0?ooP@3ooo]Zoc_o0004oookJP04
o`3koooonf[ooo]Zool300Gooo]Z00Coo`3MoookJ_l0Xooo/ol01OoonfX00ol0omkoo`27oookJP03
oookJP08ool0K?oonf[ooo]ZoookJ_m=0?ooobh0oookJ_mQ0?l5oookJP03on80ool0oi3ooo]Z00;o
oo]Z00?o0?nBoookJ_oonfX01_oonfX00omX0?oooo]ZoookJP03oookJP;o603o00?o07CooookJ_oo
nfX00_oonfX00oooT03o0000o`000002o`0000cooo]Z00Cookh0oookJ_l0o`Gooo]Z0_o[0?l;oook
JP03oomG0?oonf[ooo]Z00gooo]Z0_oo02eFoookJP03ool0;Ooonf[ooo]Z013ooo]Z00?ooeL0oook
J_oonfX03ooonfX00om`0?oooo]Zon/0o`04oookJP03oonn0?oonf[ooo]Z01Oooo]Z00?ooi00oook
J_oonfX00ooonfX00ooVo`3ooo]ZoookJP0SoookJP00:ooonfX01?oo01?oo`2CoookJ_l0nOl7oook
JP06ooo:0?lB0?oooo]ZoookJ_l0oa_o08ko2_oonfX02?lm0?ooolT0oookJ_mho`3ooo]Zo`3Loooo
nf[o?ol00_oonfX00ol0:_oooo]ZoookJP03oookJP03oomB0?nio`3ooo]Z01;ooo]Z00?o07?ooook
J_oonfX05ooonfX00ooo0>[ooo]ZoookJP06oookJP03oolF0?ooTP3ooo]Z00Cooo]Z00?oolT0oook
J_oonfX00ooonfX01OlH0?oooo]ZoookJ_oo1P3ojol000;ooo]Z00Coo`3foookJ_oonf[o0:Ko0_oo
nfX01OnX0?oooo]Zool0nOoonf[o07Oo00?ooo]Z00CoolT0oolX0?oonf[o>ol01?oonfX01OooN@3o
oo]ZoookJ_oonf[oo`<000Cooo]Z00Goo`3MoookJ_oonf[o0:?ook?o0004oookJPCoo`000_oonfX0
0ooo06cooo]ZoookJP02oookJP04odd0oooo:03oH@3oo`3oA@Gooo]Z00GohP3ooookJ_oonf[ooo]Z
o`3oTP08oookJP;oJ03o1OoonfX00olH0?ooi_l0o`1do`03oookJP;ooi0000?ooo]Zo`000?l00000
0_l0000:oookJP06oonn0?oonf[ooo]Zo`3o1Oo[0?ooL03o2ooonfX00oooE`3ooo]ZoookJP0<oook
JP?oo`0]F?oonfX2ool0;A;ooo]Z00?ooeL0oookJ_oonfX03ooonfX00om`0?oooo]Zon/0o`04oook
JP03oonn0?oonf[ooo]Z01Kooo]Z00?oogT0oookJ_oonfX00ooonfX00ooVo`3ooo]ZoookJP1:oook
JP04ool04ooonf[oo`2Co`3io`Oooo]Z00KoolX0oookJ_lB0?oooo]Zo`3o6ol0S_l:oookJP04ocd0
ool0omoooo]ZogSo00;ooo]Z00?o0=cooookJ_loo`000_oonfX00ol0:_oooo]ZoookJP02oookJP03
oomB0?l0oc?ooo]Z01;ooo]Z00?o07?ooookJ_oonfX06?oonfX00ooo0>[ooo]ZoookJP05oookJP03
oolF0?ooTP3ooo]Z00Gooo]Z00?oo`3loookJ_oonfX00_oonfX02?lH0?oooo]ZoookJ_oo1P3ooo]Z
on_o0?oonf[oo`3f0_oonfX02?l0Y_oooo]ZoookJ_nX0?oooo]Zool0nOoonf[o07Oo1?oonfX01?oo
K03ooh40oookJ_lko`04oookJP04o`3koooonf[ooo]Zool300Gooo]Z00Coo`3MoookJ_oonf[o/ol0
1OoonfX00ol0omkoo`27oookJP03oookJP08ool0K?oonf[ooo]ZoookJ_m=0?ooobh0oookJ_mQ0?l5
oookJP03on80oooonf[ooo]Z00;ooo]Z00?o0?nBoookJ_oonfX01OoonfX2ofP0o`Gooo]Z00?o603o
onKo0?l0M?l00ooonfX2oon@0003oookJ_l0003o000000;o00002_oonfX2oonn0004oookJ_l0o`Go
oo]Zon/0o`_ooo]Z0_ooE`0=oookJP?oo`0]FOoonfX2ool0;A7ooo]Z00?ooeL0oookJ_oonfX03ooo
nfX00om`0?oooo]Zon/0o`04oookJP03oonn0?oonf[ooo]Z01Oooo]Z00?ooi00oookJ_oonfX00ooo
nfX00ooVo`3ooo]ZoookJP0RoookJP00:_oonfX01?oo01?ooo]Zool0Tol0nOl7oookJP03ooo:0?oo
nf[o4P3o00;ooo]Z00?o0?lKoookJ_oonfX02OoonfX01Olm0?ooolT0ogSo0?oonf[o0=co00;ooo]Z
00Co?ol0oookJ_oonf[o02[o1?oonfX00oooDP3ooo]ZokWo000BoookJP03o`1coooonf[ooo]Z01Oo
oo]Z00?oo`3ZoookJ_oonfX01_oonfX00ooo5P3ooi80oookJP05oookJP03ooo90?oonf[ooo]Z00;o
oo]Z00So603ooookJ_oonf[oo`H0oookJ_o[o`3ooo]Zool0mP;ooo]Z00So0:KooookJ_oonf[oZ03o
oookJ_oo0?Wooo]Zo`1go`?ooo]Z00Co0?nJoolX0?oo:03o>ol01OoonfX01OooN@3ooo]ZoookJ_oo
nf[oo`<000Cooo]Z00Coo`3MoookJ_l0Xooo/ol01?oonfX4ool000?ooo]Z00Soo`1/oookJ_oonf[o
oo]Zodd0oooo:03oH@3oo`3oA@Gooo]Z00GohP3ooookJ_oonf[ooo]Zo`3oTP08oookJP03ofP0oooo
nf[ooo]Z00Cooo]Z00?o603oonKo0?oonfX00ooonfX01?ooT03ooo]ZoookJ_oonfX4o`0000Sooo]Z
0_oo_P001Ooonf[o0?l5on/0ooo[0?ooL03o00[ooo]Z0_ooE`0=oookJP;oo`0]:OoonfXCoon1027o
oo]Z0_oo02dAoookJP;ooeL04?oonfX00om`0?ooj`3oo`3o1@04oookJP03oonn0?oonf[ooo]Z01Ko
oo]Z00?oogT0oookJ_oonfX0C_oonfX01?oo01?ooo]Zool0Tol0nOl8oookJP05ooo:0?oonf[o4P3o
oookJ_l0oa/02ooonfX00olm0?oo0?oOogSo0002oookJP04o`3Loooonf[ooo]Zocoo00;ooo]Z00Oo
02[ooookJ_oonf[ooo]ZoomB0?l0oc?o^Ol001;ooo]Z00?o07?ooookJ_oonfX06?oonfX00ooo0>[o
oo]ZoookJP05oookJP03oolF0?ooTP3ooo]Z00Gooo]Z00?oo`3loookJ_oonfX00_oonfX01?lH0?oo
oo]ZoookJ_oo1P02oookJP05on_o0?oonf[oo`3foookJ_l0Y_l00_oonfX01OnX0?oooo]ZoookJ_oo
0?Wo07Oo00Cooo]Z00Coof`0oon10?oonf[o>ol01OoonfX01?l0nooooo]ZoookJ_oo0`04oookJP05
ogT0oooo0=gooo]Zo`2Soonco`001?oonfX00ol0omkoo`27oookJP03oookJP08ool0K?oonf[ooo]Z
oookJ_m=0?ooobh0oookJ_mQ0?l5oookJP04on80oooonf[ooo]ZoookJP;o0?nB1ooonfX00omX0?oo
oo]ZoookJP04oookJP03oaP0oooVo`3ooo]Z00?ooo]Z00Cooi00oookJ_oonf[ooo]Z1?l00009oook
JP04oonn0?oonf[o0?l5o`3o1@;oj`3o2_oonfX2oomG00gooo]Z0_oo02dYoookJQ?ooh408_oonfX2
ool0;A3ooo]Z0_ooE`0@oookJP03og00ooo[0?oo0?l500Cooo]Z00?ookh0oookJ_oonfX05ooonfX0
0oooT03ooo]ZoookJP0WoookJP00;?oonfX00ooo09?o0?WooookJP06oookJP06ooo:0?oonf[o4P3o
oookJ_l0oa_o08ko2ooonfX01olm0?ooolT0ogSo0?oonf[o0=cooookJ_loo`000_oonfX00ol0:_oo
oo]ZoookJP03oookJP03oomB0?nio`3ooo]Z01;ooo]Z00?o07?ooookJ_oonfX05_oonfX00ooo0>[o
oo]ZoookJP07oookJP03oolF0?ooTP3ooo]Z00Cooo]Z00?oolT0oookJ_oonfX00ooonfX01olH0?oo
oo]ZoookJ_oo1P3ojol0oookJ_oo0?H00_oonfX01_l0Y_oooo]ZoookJ_nX0?oooo]Zool0n@;ooo]Z
00So07OooookJ_oonf[o0?nJooo90?ooP@3ooo]Zoc_o00Cooo]Z00GoogT0oookJ_oonf[ooo]Zool3
0004oookJP04ool0gOoonf[o0:?ook?o00?ooo]Z1_oo0002oookJP08ool0K?oonf[ooo]ZoookJ_m=
0?ooobP0of40ool0odD5oookJP05on80oooonf[ooo]ZoookJ_l0oi802?oonfX00omX0?oooo]Zoook
JP03oookJP;o603o00?oi_l0oookJ_oonfX00_oonfX00oooT03ooo]ZoookJP02oookJPCo00001ooo
nfX01_oo_P3ooo]ZoookJ_l0o`Goj`3oog00o`[ooo]Z0_ooE`0<oookJP?oo`0]4ooonfX8oolX013o
oh404ooonfX3oon1023ooo]Z0_oo02dAoookJP03oomG0?oonf[ooo]Z00kooo]Z00?oL03oon/0ool0
o`D00ooonfX00ooo_P3ooo]ZoookJP0FoookJP03oomi0?oonf[ooo]Z053ooo]Z00?oo`2Co`3ioooo
nfX01_oonfX01_oobP3ooo]Zoa80oooonf[o0?lKo`2>o`_ooo]Z00?o?@3oo`3ogomho`000_oonfX0
0ol0g?oooo]Zocoo0002oookJP03o`0Zoooonf[ooo]Z00;ooo]Z00?ooe80o`3o<ooonfX04_oonfX0
0ol0Looooo]ZoookJP0GoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oonB0?oonfX01?oonfX0
0ooo0?cooo]ZoookJP03oookJP0:oaP0oooonf[ooo]Zool60?oonf[ojol0oookJ_oo0?Kooo]Zo`2V
o`;ooo]Z00KoZ03ooookJ_oonf[oo`3ioookJ_l0Mol3oookJP05oom/0?l0olcooh40oookJ_lko`00
1?oonfX01?l0nooooo]ZoookJ_oo0`04oookJP05ogT0oooo0=gooo]Zo`2Soonco`001?oonfX00ol0
omkogOl0ool0Q`03oookJP08ool0K?oonf[ooo]ZoookJ_m=0?ooobh0oookJ_mQ0?l5oookJP05on80
oooonf[ooo]ZoookJ_l0oi802?oonfX00omX0?oooo]ZoookJP04oookJP03oaP0oooVo`3ooo]Z00?o
oo]Z00?ooi00oookJ_oonfX00_oonfX4o`0000Oooo]Z0_oo_P001?oonf[o0?l5oookJ_o[0?l;oook
JP03oomG0?oonf[ooo]Z00[ooo]Z0ooo02dHoookJQ?ooh404ooonfX3oon1027ooo]Z0_oo02d@oook
JP03oomG0?oonf[ooo]Z00kooo]Z00?oL03oon/0ool0o`D01?oonfX00ooo_P3ooo]ZoookJP0Foook
JP03oon@0?oonf[ooo]Z02Oooo]Z000[oookJP03ool0Tol0nOoooo]Z00Kooo]Z00?oolX0oookJ_lB
0?l00_oonfX00ol0oa_ooo]ZoookJP09oookJP05ocd0oooob@3oN?l0oookJ_l0g?l00_oonfX01?lo
o`3ooo]ZoookJ_l0:_l4oookJP03oomB0?oonf[o^Ol001;ooo]Z00?o07?ooookJ_oonfX05ooonfX0
0ooo0>[ooo]ZoookJP06oookJP03oolF0?ooTP3ooo]Z00Cooo]Z00?oolT0oookJ_oonfX00ooonfX0
2?lH0?oooo]ZoookJ_oo1P3ooo]Zon_o0?oonf[oo`3f0_oonfX00ol0Y_oooo]ZojP0o`02oookJP03
ool0nOoonf[o07Oo00;ooo]Z00Go0?nJooo90?ooP@3ooo]Zoc_o0004oookJP05oomi0?oonf[ooo]Z
oookJ_oo0`001?oonfX01?oo0=gooo]Zo`0Goonco`03oookJPOoo`0000?ooo]Zool0K?oonfX00_oo
nfX01?m=0?ooobP0of40ool0odD5oookJP05on80oooonf[ooo]ZoookJ_l0oi802?oonfX00omX0?oo
oo]ZoookJP03oookJP03oaP0oooonf[oi_l000Cooo]Z00?ooi00oookJ_oonfX00ooonfX4o`0000Go
oo]Z0_oo_P001Ooonf[o0?l5on/0ooo[0?ooL03o00[ooo]Z00?ooeL0oookJ_oonfX02_oonfX2ool0
;@kooo]Z3_oo:00XoookJP?ooh407ooonfX2ool0;A3ooo]Z00?ooeL0oookJ_oonfX03_oonfX00om`
0?ooj`3oo`3o1@03oookJP03oonn0?oonf[ooo]Z01Kooo]Z00?oogT0oookJ_oonfX0C_oonfX00ooo
09?o0?WooookJP07oookJP05ooo:0?oonf[o4P3ooookJ_l0oa/02ooonfX00olm0?oo0?oOogSo0002
oookJP03o`3Loooonf[o?ol000?ooo]Z00Oo02[ooookJ_oonf[ooo]ZoomB0?l0oc?o^Ol001;ooo]Z
00?o07?ooookJ_oonfX06?oonfX00ooo0>[ooo]ZoookJP05oookJP03oolF0?ooTP3ooo]Z00Gooo]Z
00?oo`3loookJ_oonfX00_oonfX01?lH0?oooo]ZoookJ_oo1P02oookJP07on_o0?oo0?Kooo]Zoook
J_l0Y_oooo]ZojP0o`03oookJP03ool0nOl0Mooooo]Z00;ooo]Z00Go0?nJoom/0?ooP@3ooo]Zoc_o
0004oookJP04o`3koooonf[ooo]Zool300Cooo]Z00GoN@3oool0gOoonf[o0:?ook?o0005oookJP03
o`3og_oo08Oooo]Z00?ooo]Z00Ooo`1/oookJ_oonf[oC@3oool^0?oonf[oH@3o00Gooo]Z00GohP3o
oookJ_oonf[ooo]Zo`3oTP08oookJP03ofP0oooonf[ooo]Z00?ooo]Z0_lH0?l00ooVo`3ooo]Zoook
JP02oookJP03oon@0?oonf[ooo]Z00?ooo]Z1?l00006oookJP04oonn0?oonf[o0?l5o`3o1@;oj`3o
2_oonfX2oomG00_ooo]Z0_oo02dHoookJP?ooh40:OoonfX3oon1023ooo]Z0_oo02d?oookJP03oomG
0?oonf[ooo]Z00kooo]Z00?oL03oon/0ool0o`D01?oonfX00ooo_P3ooo]ZoookJP0FoookJP03oon@
0?oonf[ooo]Z02Kooo]Z000[oookJP03ool0Tol0nOoooo]Z00Kooo]Z00KoolX0oookJ_lB0?oooo]Z
o`3o6ol0S_l;oookJP05ocd0oooob@3oN?l0oookJ_l0g?l00_oonfX01?loo`3ooo]ZoookJ_l0:_l4
oookJP03oomB0?oonf[o^Ol001;ooo]Z00?o07?ooookJ_oonfX05_oonfX00ooo0>[ooo]ZoookJP07
oookJP03oolF0?ooTP3ooo]Z00Cooo]Z00?oolT0oookJ_oonfX00_oonfX02?lH0?oooo]ZoookJ_oo
1P3ooo]Zon_o0?oonf[oo`3f0_oonfX02?l0Y_oooo]ZoookJ_nX0?oooo]Zool0nOoonf[o07Oo0_oo
nfX01Ol0oi[oolT0oon10?oonf[o>ol000Cooo]Z00?oogT0oookJ_oonfX00_oonfX02Ooo0`3ooo]Z
oookJ_oonf[oo`3MoookJ_l05ooo0:?ook?o0002oookJPOoo`0000?ooo]Zool0K?oonfX00_oonfX0
1?m=0?ooobP0oookJ_mQ0?l5oookJP05on80oooonf[ooo]ZoookJ_l0oi802?oonfX00omX0?oooo]Z
oookJP03oookJP03oaP0ool0M?ooi_l000?ooo]Z0_ooT006oookJPCo00001?oonfX01_oo_P3ooo]Z
oookJ_l0o`Goj`3oog00o`[ooo]Z0_ooE`0:oookJP?oo`0]4?oonfX=oolX02cooo]Z0oooP@0Noook
JP;oo`0]3ooonfX2oomG00oooo]Z00?oL03oon/0ool0o`D00ooonfX00ooo_P3ooo]ZoookJP0Foook
JP03oomi0?oonf[ooo]Z04gooo]Z00?oo`2Co`3ioooonfX01_oonfX01_oobP3ooo]ZoookJ_lB0?oo
0?lKo`2>o`_ooo]Z00?o?@3oo`3ogomho`000_oonfX00ol0g?oooo]Zocoo0002oookJP03o`0Zoooo
nf[ooo]Z00;ooo]Z00?ooe80o`3o<onio`004_oonfX00ol0Looooo]ZoookJP0GoookJP03ool0j_oo
nf[ooo]Z00Kooo]Z00?ooaH0oonB0?oonfX01?oonfX00ooo0?cooo]ZoookJP02oookJP04oaP0oooo
nf[ooo]Zool600;ooo]Z00Gojol0oookJ_oo0?Kooo]Zo`2Vo`02oookJP05ojP0oooonf[ooo]Zool0
nOl0Mol00ooonfX01Ol0oi[oof`0oon10?oonf[o>ol000Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool3
0003oookJP05ogT0oooo0=gooo]Zo`2Soonco`001OoonfX00ol0omkoo`27oookJP03oookJP07ool0
K?oonf[ooo]Zodd0oooo;P3ooo]Zof40o`05oookJP05on80oooonf[ooo]ZoookJ_l0oi802?oonfX0
0omX0?oooo]ZoookJP03oookJP03oaP0ool0M?ooi_l000?ooo]Z0_ooT006oookJPCo00001?oonfX2
oonn0004oookJ_l0o`Gooo]Zon/0o`[ooo]Z0_ooE`0:oookJP?oo`0]5ooonfX3oon102oooo]Z0ooo
P@0OoookJP;oo`0]3_oonfX2oomG00oooo]Z00?oL03oon/0ool0o`D01?oonfX00ooo_P3ooo]Zoook
JP0FoookJP03oon@0?oonf[ooo]Z02Gooo]Z000[oookJP03ool0Tooonf[ooo]Z00Gooo]Z00OoolX0
oookJ_oonf[o4P3ooookJ_l0oa_o08ko00[ooo]Z00Go?@3oooo90?mho`3ooo]Zo`3Lo`02oookJP04
ocoo0?oonf[ooo]Zo`0Zo`Cooo]Z00?o0?lcoomB0?nio`004_oonfX00ol0Looooo]ZoookJP0Foook
JP03ool0j_oonf[ooo]Z00Oooo]Z00?ooaH0oonB0?oonfX01?oonfX00ooob@3ooo]ZoookJP03oook
JP07oaP0oooonf[oo`H0oookJ_o[o`3ooo]Zool0mP02oookJP06o`2Voooonf[ooo]ZojP0oooonf[o
o`3i0_oonfX02?l0Mooooo]ZoookJ_l0oi[oolT0oon10?oonf[o>ol00ooonfX00oooN@3ooo]Zoook
JP02oookJP05ool30?oonf[ooo]ZoookJ_oo0=d00_oonfX01?l0Xooo/ol0oookJ_oonfX8ool00008
ool0K?oonf[ooo]ZoookJ_m=0?ooobP0oookJ_mQ0?l5oookJP05on80oooonf[ooo]ZoookJ_l0oi80
2?oonfX00omX0?oooo]ZoookJP03oookJP03oaP0oooVo`3oi_l000?ooo]Z00?ooi00oookJ_oonfX0
1_oonfX4o`0000;ooo]Z0_oo_P02oookJP;oj`3o00?oL03ooookJ_oonfX01ooonfX2oomG00[ooo]Z
0_oo02dCoookJP_oobP0<OoonfX3oon101gooo]Z00?oo`0]oookJ_oonfX03_oonfX00oooE`3ooo]Z
oookJP0=oookJP04og00ooo[0?oo0?l5o`3o1@;ooo]Z00?ookh0oookJ_oonfX05OoonfX00oooN@3o
oo]ZoookJP1=oookJP03ool0Tooonf[ooo]Z00Kooo]Z00KoolX0oookJ_lB0?oooo]Zo`3o6ol0S_l:
oookJP03ocd0ool0omooN?l000;ooo]Z00?o0=cooookJ_loo`000ooonfX00ol0:_oooo]ZoookJP02
oookJP03oomB0?nio`3ooo]Z017ooo]Z00?o07?ooookJ_oonfX05ooonfX00ooo0>[ooo]ZoookJP06
oookJP03oolF0?ooTP3ooo]Z00Cooo]Z00?oo`3loookJ_oonfX00ooonfX00olH0?oooo]Zool60002
oookJP05on_o0?oonf[oo`3foookJ_l0Y_l00_oonfX01_nX0?oooo]ZoookJ_oo0?Wooo]Zo`1go`?o
oo]Z00Goof`0o`3oc?ooP@3ooo]Zoc_o0003oookJP05o`3koooonf[ooo]ZoookJ_oo0`000ooonfX0
1Omi0?ooo`3MoookJ_nO0?oo/ol000Gooo]Z00?o0?oNool0QooonfX00ooonfX02?oo06cooo]Zoook
J_m=0?oooo]Zool^0?l0odGoH@3o1?oonfX01OoR0?oooo]ZoookJ_oonf[o0?nB00Sooo]Z00?oJ03o
oookJ_oonfX00ooonfX00olH0?oo07CoonKo0003oookJP03oon@0?oonf[ooo]Z00Kooo]Z1?l00003
oookJP04oonn0?oonf[ooo]Zo`3o1@;oj`3o2_oonfX00oooE`3ooo]ZoookJP08oookJP;oo`0]5ooo
nfX3oon103Gooo]Z0oooP@0NoookJP03ool0;Ooonf[ooo]Z00gooo]Z00?ooeL0oookJ_oonfX03Ooo
nfX01?m`0?ooj`3oo`3o1Ol0o`D2oookJP03oonn0?oonf[ooo]Z01Kooo]Z00?ooi00oookJ_oonfX0
9OoonfX002[ooo]Z00?oo`2Co`3ioooonfX01_oonfX01_oobP3ooo]Zoa80oooonf[o0?lKo`2>o`_o
oo]Z00Go?@3oooo90?mho`3ooo]Zo`3Lo`02oookJP04ocoo0?oonf[ooo]Zo`0Zo`Cooo]Z00?ooe80
oookJ_nio`004_oonfX00ol0Looooo]ZoookJP0FoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0
oookJ_ooTP001?oonfX00ooob@3ooo]ZoookJP03oookJP0:oaP0oooonf[ooo]Zool60?oonf[ojol0
oookJ_oo0?Kooo]Zo`2Vo`;ooo]Z00KoZ03ooookJ_oonf[oo`3ioookJ_l0Mol2oookJP05o`3oV_oo
b@3ooh40oookJ_lko`000ooonfX00oooN@3ooo]ZoookJP02oookJP09ool30?oonf[ooo]ZoookJ_mi
0?ooo`3MoookJ_l0Xooo/ol000;ooo]Z2?oo00002?oo06cooo]ZoookJ_oonf[oC@3ooolX0?oonf[o
H@3o1OoonfX01OoR0?oooo]ZoookJ_oonf[o0?nB00Oooo]Z0_mX0?l4oookJP;o603o00?oi_l0oook
J_oonfX00_oonfX00oooT03ooo]ZoookJP07oookJPGo000000Kookh0oookJ_oonf[o0?l5on/0oom`
0?l9oookJP;ooeL02_oonfX2ool0;AKooo]Z2?oo:00foookJP?ooh406ooonfX2ool0;@oooo]Z00?o
oeL0oookJ_oonfX03OoonfX01?m`0?ooj`3ooookJ_l0o`D2oookJP03oonn0?oonf[ooo]Z01Gooo]Z
00?oogT0oookJ_oonfX0BooonfX00ooo09?o0?WooookJP06oookJP06ooo:0?oonf[ooo]Zoa80ool0
oa_o08ko2ooonfX00olm0?oo0?oOogSo0002oookJP03o`3Loooonf[o?ol000?ooo]Z00Oo02[ooook
J_oonf[ooo]ZoomB0?l0oc?o^Ol001;ooo]Z00?o07?ooookJ_oonfX05ooonfX00ooo0>[ooo]Zoook
JP06oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00?oo`3loookJ_oonfX00ooonfX01?lH0?oooo]Zoook
J_oo1P02oookJP04on_o0?oo0?Kooo]Zo`2Vo`;ooo]Z00KoZ03ooookJ_oonf[ooo]Zool0nOl0Mol3
oookJP05oom/0?l0olcooh40oookJ_lko`000ooonfX01Ol0nooooo]ZoookJ_oonf[oo`<000?ooo]Z
00KoN@3ooookJ_oo0=goW`3oo`2Soonco`04oookJP03o`3og_oo08Oooo]Z00?ooo]Z00Soo`1/oook
J_oonf[ooo]Zodd0oooo;P3o0?m5of40o`Cooo]Z00GohP3ooookJ_oonf[ooo]Zo`3oTP07oookJP;o
J03o1?oonfX2oaP0o`03o`1doooVo`3ooo]Z00;ooo]Z00?ooi00oookJ_oonfX01ooonfX5o`0000;o
okh000Cooo]Zo`3o1Ol0o`Goj`3o2_oonfX2oomG00Wooo]Z0_oo02dFoookJP?ooh40>ooonfX3oon1
01cooo]Z0_oo02d>oookJP03oomG0?oonf[ooo]Z00gooo]Z00CoL03oon/0oooonf[o0?l50_oonfX0
0ooo_P3ooo]ZoookJP0FoookJP03oon@0?oonf[ooo]Z02Cooo]Z000ZoookJP03o`3ioooonf[ooo]Z
00Gooo]Z00OoolX0oookJ_oonf[o4P3ooookJ_l0oa_o08ko00_ooo]Z00CoolT0ogSo0?oonf[o0=co
0_oonfX01?loo`3ooo]ZoookJ_l0:_l4oookJP03o`3o<oooDP3o^Ol001?ooo]Z00?o07?ooookJ_oo
nfX05OoonfX00ooo0>[ooo]ZoookJP07oookJP03oolF0?ooTP3ooo]Z00Cooo]Z00?oolT0oookJ_oo
nfX00ooonfX01olH0?oooo]Zool60?oonf[ojol0oookJ_oo0?H00_oonfX01_l0Y_oooo]ZoookJ_nX
0?oooo]Zool0n@;ooo]Z00Oo07OooookJ_l0oi[oolT0oon10?oonf[o>ol000Cooo]Z00?oogT0oook
J_oonfX00_oonfX02?oo0`3ooo]ZoookJ_mi0?ooo`3MoookJ_l0Xooo/ol00_oonfX9ool00007ool0
K?oonf[ooo]Zodd0oooo:03ooo]Zof40o`05oookJP05on80oooonf[ooo]ZoookJ_l0oi801ooonfX0
0omX0?oooo]ZoookJP03oookJP03oaP0oooonf[oi_l000Cooo]Z00?ooi00oookJ_oonfX02?oonfX4
o`000003oonn0?oonf[ooo]Z00;oj`3o00?oL03ooookJ_oonfX01ooonfX00oooE`3ooo]ZoookJP07
oookJP?oo`0]5?oonfX;oolX03[ooo]Z0oooP@0JoookJP;oo`0]3_oonfX2oomG00gooo]Z00GoL03o
on/0oooonf[ooo]Zo`3o1@02oookJP03oonn0?oonf[ooo]Z01Cooo]Z00?oogT0oookJ_oonfX0Booo
nfX00ol0nOoooo]ZoookJP06oookJP06ooo:0?oonf[ooo]Zoa80ool0oa_o08ko2ooonfX01ol0omoo
N?l0oookJ_oonf[o0=cooookJ_loo`000ooonfX00ol0:_oooo]ZoookJP02oookJP03oomB0?nio`3o
oo]Z01;ooo]Z00?o07?ooookJ_oonfX05_oonfX00ooo0>[ooo]ZoookJP06oookJP03oolF0?ooTP3o
oo]Z00Cooo]Z00?oo`3loookJ_oonfX00ooonfX00olH0?oooo]Zool60002oookJP05on_o0?oonf[o
o`3foookJ_l0Y_l00_oonfX01_nX0?oooo]ZoookJ_oo0?Wooo]Zo`1go`;ooo]Z00Go0?nJoom/0?oo
P@3ooo]Zoc_o0004oookJP05o`3koooonf[ooo]ZoookJ_oo0`000_oonfX01_mi0?oooo]Zool0gOnO
0?oo0:?ook?o00Gooo]Z00?o0?oNool0QooonfX00_oonfX02?oo06cooo]ZoookJ_oonf[oC@3oool^
0?l0odGoH@3o1?oonfX01OoR0?oooo]ZoookJ_oonf[o0?nB00Oooo]Z00?oJ03ooookJ_oonfX00ooo
nfX01?lH0?oooo]Zo`1doooVo`03oookJP03oon@0?oonf[ooo]Z00Sooo]Z1?l000001?oo_P3ooo]Z
oookJ_l0o`D2on/0o`Wooo]Z0_ooE`08oookJP?oo`0]5?oonfX4oon1047ooo]Z0oooP@0KoookJP;o
o`0]3OoonfX2oomG00gooo]Z00GoL03oon/0oooonf[ooo]Zo`3o1@02oookJP03oonn0?oonf[ooo]Z
01Gooo]Z00?ooi00oookJ_oonfX09?oonfX003;ooo]Z00KoolX0oookJ_lB0?oooo]Zo`3o6ol0S_l;
oookJP05ocd0oooob@3oN?l0oookJ_l0g?l00_oonfX01?loo`3ooo]ZoookJ_l0:_l4oookJP03oomB
0?oonf[o^Ol001;ooo]Z00?o07?ooookJ_oonfX05OoonfX00ooo0>[ooo]ZoookJP07oookJP03oolF
0?oonf[ooi8000Cooo]Z00?oolT0oookJ_oonfX00ooonfX00olH0?oooo]Zool60002oookJP05on_o
0?oonf[oo`3foookJ_l0Y_l00_oonfX03OnX0?oooo]ZoookJ_oo0?Wooo]Zo`1goooonf[o0?nJooo9
0?oo:03ooh40oookJ_lko`000ooonfX00oooN@3ooo]ZoookJP02oookJP09ool30?oonf[ooo]ZogT0
oooo0=gooo]Zoil0ool0Xooo/ol000Cooo]Z1_oo00001ooo06cooo]ZoookJ_m=0?ooobP0oookJ_mQ
0?l01OoonfX01OoR0?oooo]ZoookJ_oonf[o0?nB00Oooo]Z00?oJ03ooookJ_oonfX00ooonfX00olH
0?oo07CoonKo0003oookJP;ooi002ooonfX2o`0000;ookh000Cooo]Zon/0ooo[0?ooL03o2OoonfX2
oomG00Sooo]Z0_oo02dDoookJP?oobP01?oonfX5oolX03oooo]Z0oooP@0IoookJP;oo`0]3_oonfX0
0oooE`3ooo]ZoookJP0;oookJP05og00ooo[0?oooo]ZoookJ_l0o`D00_oonfX00ooo_P3ooo]Zoook
JP0DoookJP03oomi0?oonf[ooo]Z05;ooo]Z00KoolX0oookJ_oonf[o4P3oo`3o6ol0S_l;oookJP03
ocd0ool0omooN?l000;ooo]Z00?o0=cooookJ_loo`000ooonfX01ol0:_oooo]ZoookJ_oonf[ooe80
o`3o<onio`004_oonfX00ol0Looooo]ZoookJP0FoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0
oookJ_ooTP001?oonfX00ooo0?cooo]ZoookJP03oookJP03oaP0oooonf[oo`H000;ooo]Z00Gojol0
oookJ_oo0?Kooo]Zo`2Vo`02oookJP06ojP0oooonf[ooo]Zool0nOoonf[o07Oo0_oonfX01_l0oi[o
of`0o`3oc?ooP@3ooo]Zoc_o00?ooo]Z00Go0?_ooookJ_oonf[ooo]Zool30002oookJP06ogT0oooo
nf[oo`3Moil0ool0Xooo/ol01OoonfX00ol0omkoo`27oookJP02oookJP08ool0K?oonf[ooo]Zoook
J_m=0?ooobh0o`3oAOmQ0?l4oookJP05on80oooonf[ooo]ZoookJ_l0oi801ooonfX00omX0?oooo]Z
oookJP03oookJP04oaP0ool0M?oo07CoonKo00;ooo]Z0_ooT00;oookJP;o00000_oo_P02oookJP;o
j`3o2_oonfX00oooE`3ooo]ZoookJP06oookJP;oo`0]5?oonfX3oon104Sooo]Z0oooP@0JoookJP;o
o`0]3OoonfX00oooE`3ooo]ZoookJP0;oookJP05og00ooo[0?oooo]ZoookJ_l0o`D00_oonfX00ooo
_P3ooo]ZoookJP0EoookJP03oon@0?oonf[ooo]Z02?ooo]Z000boookJP06ooo:0?oonf[o4P3ooook
J_l0oa_o08ko2ooonfX01?oob@3oN?l0oookJ_l0g?l2oookJP04ocoo0?oonf[ooo]Zo`0Zo`Gooo]Z
00?ooe80okWo0?oonfX04_oonfX00ol0Looooo]ZoookJP0EoookJP03ool0j_oonf[ooo]Z00Oooo]Z
00?ooaH0oonB0?oonfX00ooonfX00ooob@3ooo]ZoookJP03oookJP0:oaP0oooonf[ooo]Zool60?oo
nf[ojol0oookJ_oo0?Kooo]Zo`2Vo`;ooo]Z00goZ03ooookJ_oonf[oo`3ioookJ_l0Mooooo]Zo`3o
V_oonf[oolT0oon10?oonf[o>ol000?ooo]Z00?oogT0oookJ_oonfX00_oonfX02Ooo0`3ooo]Zoook
J_mi0?ooo`3MoookJ_nO0?oo0:?ook?o0005oookJP03o`3og_oo003oo`0000;oo`0000Ooo`1/oook
J_oonf[oC@3ooolX0?oonf[oH@3o00Gooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP07oookJP03ofP0
oooonf[ooo]Z00?ooo]Z00?o603oo`1doooVo`000ooonfX00oooT03ooo]ZoookJP0;oookJP05o`00
0?oo_P3o0000o`000?o[0?l00_m`0?l8oookJP;ooeL02OoonfX00ooo02gooo]ZoookJP0AoookJP?o
obP02?oonfX2oolX04Cooo]Z0oooP@0HoookJP;oo`0]3OoonfX2oomG00cooo]Z00GoL03oon/0oooo
nf[ooo]Zo`3o1@02oookJP03oonn0?oonf[ooo]Z01Cooo]Z00?oogT0oookJ_oonfX0DOoonfX01_oo
bP3ooo]ZoookJ_lB0?oo0?lKo`2>o`_ooo]Z00Oo0?oOogSo0?oonf[ooo]Zo`3Loooonf[o?ol000?o
oo]Z00?o02[ooookJ_oonfX00_oonfX00oooDP3o0?lcoookJP0BoookJP03o`1coooonf[ooo]Z01Ko
oo]Z00?oo`3ZoookJ_oonfX01_oonfX00ooo5P3ooi80oookJP03oookJP03ool0o?oonf[ooo]Z00Co
oo]Z00?o603ooookJ_oo1P000_oonfX01?o[o`3ooo]Zool0m_l0Y_l2oookJP06ojP0oooonf[ooo]Z
oookJ_oo0?Wo07Oo0_oonfX01_l0oi[oof`0o`3oc?ooP@3ooo]Zoc_o00?ooo]Z00Go0?_ooookJ_oo
nf[ooo]Zool30002oookJP06ogT0oooonf[oo`3Moil0ool0Xooo/ol01OoonfX00ol0omkoo`27oook
JP02oookJP08ool0K?oonf[ooo]ZoookJ_m=0?ooobh0o`3oAOmQ0?l4oookJP05on80ool0oi3ooo]Z
oookJ_l0oi801ooonfX00omX0?oooo]ZoookJP03oookJP04oaP0ool0M?oooo]ZonKo00;ooo]Z00?o
oi00oookJ_oonfX02ooonfX01ol0003ookh0o`000?l0003o0?l5on/0oom`0?l02OoonfX2oomG00So
oo]Z00?oo`0]oookJ_oonfX04OoonfX3oon104kooo]Z0oooP@0IoookJP;oo`0]3?oonfX2oomG00co
oo]Z00GoL03oon/0oooonf[ooo]Zo`3o1@02oookJP03oonn0?oonf[ooo]Z01Gooo]Z00?ooi00oook
J_oonfX08_oonfX0037ooo]Z00KoolX0oookJ_oonf[o4P3oo`3o6ol0S_l;oookJP05ocd0oooob@3o
N?l0oookJ_l0g?l00_oonfX01?loo`3ooo]ZoookJ_l0:_l4oookJP03oomB0?oonf[o^Ol001;ooo]Z
00?o07?ooookJ_oonfX05OoonfX00ooo0>[ooo]ZoookJP07oookJP03oolF0?ooTP3ooo]Z00?ooo]Z
00?oolT0oookJ_oonfX01?oonfX02OlH0?oooo]Zool60?oonf[ojol0oookJ_oo0?Kooo]Zo`2Vo`03
oookJP03ojP0oooonf[oo`3i00;ooo]Z00Oo07OooookJ_l0oi[oolT0oolX0?ooP@3o>ol000?ooo]Z
00?oogT0oookJ_oonfX00ooonfX02?oo0`3ooo]ZoookJ_oo0=gooo]Zo`0Gool0Xooo/ol01OoonfX0
2_oMo`3oo`00oookJ_oonf[oo`00ool0K?oo003ooo]Zodd0oooo:002oookJP03of40oooonf[ooo]Z
00;ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP07oookJP03ofP0oooonf[ooo]Z00?ooo]Z00?o603o
o`1doooVo`000ooonfX00oooT03ooo]ZoookJP0;oookJP;ookh000Co0000on/0ooo[0?ooL03o2Ooo
nfX00oooE`3ooo]ZoookJP07oookJP;oo`0]4OoonfX3oolX00_ooo]Z00?oobP0oookJ_oonfX0A_oo
nfX3oon101Oooo]Z00?oo`0]oookJ_oonfX03?oonfX00oooE`3ooo]ZoookJP0:oookJP07og00ooo[
0?oooo]ZoookJ_l0o`Gooo]Zoonn001YoookJP06ooo:0?oonf[ooo]Zoa80ool0oa_o08ko2ooonfX0
0olm0?oo0?oOogSo0002oookJP03o`3Loooonf[o?ol000?ooo]Z00Oo02[ooookJ_oonf[ooo]ZoomB
0?l0oc?o^Ol001;ooo]Z00?o07?ooookJ_oonfX05_oonfX00ooo0>[ooo]ZoookJP06oookJP03oolF
0?ooTP3ooo]Z00Cooo]Z00?oo`3loookJ_oonfX00ooonfX00olH0?oooo]Zool60002oookJP04on_o
0?oonf[oo`3fo`2Vo`?ooo]Z00KoZ03ooookJ_oonf[oo`3ioookJ_l0Mol2oookJP05o`3oV_ooK03o
oh40oookJ_lko`000ooonfX00ol0nooooo]ZoookJP02oookJP09ool30?oonf[ooo]ZogT0oooo0=go
oo]Zoil0ool0Xooo/ol000Cooo]Z00?ogOl0ool0QooonfX00ooonfX01ooo06cooo]ZoookJ_m=0?oo
obh0oookJ_mQ0?l01?oonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Oooo]Z00?oJ03ooookJ_oonfX0
0ooonfX01?lH0?oo07CoonKo0?oVo`02oookJP03oon@0?oonf[ooo]Z00cooo]Z00?ookh0o`000?l0
00000_o[0?l9oookJP;ooeL02?oonfX2ool0;A7ooo]Z0oooP@1DoookJP?ooh406?oonfX00ooo02go
oo]ZoookJP0;oookJP03oomG0?oonf[ooo]Z00[ooo]Z00GoL03oon/0oooonf[ooo]Zo`3o1@02oook
JP03oonn0?oonf[ooo]Z03Wooo]Z000aoookJP06ooo:0?oonf[o4P3ooookJ_l0oa_o08ko2ooonfX0
1?oob@3oN?l0oookJ_l0g?l2oookJP05ocoo0?oonf[ooo]ZoookJ_l0:_l01?oonfX00oooDP3ooo]Z
okWo000BoookJP03o`1coooonf[ooo]Z01Cooo]Z00?oo`3ZoookJ_oonfX02?oonfX00ooo5P3ooi80
oookJP03oookJP03ooo90?oonf[ooo]Z00?ooo]Z00?o603ooookJ_oo1P000_oonfX01?o[o`3ooo]Z
ool0m_l0Y_l3oookJP0=ojP0oooonf[ooo]Zool0nOoonf[o07OooookJ_l0oi[oolT0oolX0?ooP@3o
oo]Zoc_o0002oookJP03oomi0?oonf[ooo]Z00?ooo]Z00Soo`<0oookJ_oonf[oN@3oool0gOl05ooo
0:?ook?o00Kooo]Z00co0?oNool00?oonf[ooo]Zool0K?oo003ooo]Zodd0oooonf[oobP0oookJ_mQ
0?l4oookJP05on80ool0oi3ooo]ZoookJ_l0oi801ooonfX00omX0?oooo]ZoookJP04oookJP03oaP0
oooVo`3ooo]Z00;ooo]Z00?ooi00oookJ_oonfX02ooonfX01_oo_P3ooo]Zo`000?o[0?ooL03oo`00
00Sooo]Z0_ooE`08oookJP;oo`0]4?oonfX3oolX05[ooo]Z0oooP@0EoookJP;oo`0]3OoonfX00ooo
E`3ooo]ZoookJP0:oookJP07og00ooo[0?oooo]ZoookJ_l0o`Gooo]Zoonn001XoookJP06ooo:0?oo
nf[ooo]Zoa80ool0oa_o08ko2ooonfX01ol0omooN?l0oookJ_oonf[o0=cooookJ_loo`000ooonfX0
0ol0:_oooo]ZoookJP02oookJP03oomB0?l0oc?o^Ol001;ooo]Z00?o07?ooookJ_oonfX05OoonfX0
0ooo0>[ooo]ZoookJP07oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00?oo`3loookJ_oonfX00ooonfX0
0olH0?oooo]Zool60003oookJP03on_o0?oo0?Ko0:Ko00?ooo]Z00KoZ03ooookJ_oonf[oo`3ioook
J_l0Mol2oookJP06o`3oV_ooK03o0?o<oon10?oonf[o>ol00_oonfX00ol0nooooo]ZoookJP02oook
JP09ool30?oonf[ooo]ZogT0oooonf[oo`3Moil0ool0Xooo/ol000Gooo]Z00?o0?oNool0QooonfX0
0_oonfX01ooo06cooo]ZoookJ_m=0?ooobh0oookJ_mQ0?l01?oonfX01OoR0?oo0?n@oookJ_oonf[o
0?nB00Oooo]Z00?oJ03ooookJ_oonfX01?oonfX00olH0?ooi_l0oookJP02oookJP03oon@0?oonf[o
oo]Z00_ooo]Z0_oo_P001?l0003o0?l5on/0ool00009oookJP03oomG0?oonf[ooo]Z00Oooo]Z00?o
o`0]oookJ_oonfX03_oonfX3oon105[ooo]Z0oooP@0FoookJP;oo`0]3?oonfX00oooE`3ooo]Zoook
JP0:oookJP05og00ooo[0?oooo]ZoookJ_l0o`D00_oonfX00ooo_P3ooo]ZoookJP0hoookJP00<?oo
nfX01_oobP3ooo]ZoookJ_lB0?oo0?lKo`2>o`cooo]Z00CoolT0ogSo0?oonf[o0=co0_oonfX01?lo
o`3ooo]ZoookJ_l0:_l4oookJP03oomB0?oonf[o^Ol001;ooo]Z00?o07?ooookJ_oonfX05OoonfX0
0ooo0>[ooo]ZoookJP07oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00?oolT0oookJ_oonfX01?oonfX0
2OlH0?oooo]Zool60?oonf[ojol0oookJ_oo0?Kooo]Zo`2Vo`02oookJP0=ojP0oooonf[ooo]Zool0
nOoonf[o07OooookJ_l0oi[oolT0oolX0?ooP@3ooo]Zoc_o0003oookJP03oomi0?oonf[ooo]Z00;o
oo]Z00Woo`<0oookJ_oonf[oN@3oool0gOl05oooW`3oo`2Soonco`001OoonfX00ol0omkoo`00oook
JP02oookJP07ool0K?oonf[ooo]Zodd0oooo:03ooo]Zof40o`04oookJP05on80ool0oi3ooo]Zoook
J_l0oi801ooonfX00omX0?oooo]ZoookJP04oookJP04oaP0oooVo`3ooo]ZoookJP;ooi003OoonfX0
1Ooo_P3ooo]Zon/0ooo[0?ooL03o00;o00001_oonfX2oomG00Wooo]Z00?oo`0]oookJ_oonfX03Ooo
nfX00oooP@3oobP0oolX000>oookJQ7oiOl07ol0e?lRoookJP03oon10?oonf[ooo]Z01Cooo]Z0_oo
02d<oookJP;ooeL02ooonfX01oo[0?oooo]ZoookJ_oonf[o0?l5oookJ_oo_P00IooonfX01OoobP3o
oo]ZoookJ_l0oa_o08ko00cooo]Z00Oo0?oOogSo0?oonf[ooo]Zo`3Loooonf[o?ol000?ooo]Z00Oo
02[ooookJ_oonf[ooo]ZoomB0?l0oc?o^Ol001;ooo]Z00?o07?ooookJ_oonfX05_oonfX00ooo0>[o
oo]ZoookJP06oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00?oo`3loookJ_oonfX01?oonfX00olH0?oo
oo]Zool60002oookJP04on_o0?oonf[oo`3fo`2Vo`;ooo]Z00KoZ03ooookJ_oonf[ooo]Zool0nOl0
Mol2oookJP06o`3oV_ooK03o0?o<oon10?oonf[o>ol00ooonfX01Ol0nooooo]ZoookJ_oonf[oo`<0
00;ooo]Z00KoN@3ooookJ_oo0=goW`3oo`2Soonco`05oookJP03o`3og_oo08Oooo]Z00;ooo]Z00Oo
o`1/oookJ_oonf[oC@3oool^0?oonf[oH@3o00Cooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP07oook
JP03ofP0oooonf[ooo]Z00Cooo]Z00Co603oonKo0?oonf[ooo]Z0_ooT00=oookJP03oonn0?oonf[o
oo]Z00;oj`3o0_l00007oookJP;ooeL02?oonfX2ool0;@kooo]Z0oooP@0LoookJR?o0=Co8OoonfX0
0oooP@3ooo]ZoookJP0EoookJP;oo`0]2ooonfX2oomG00_ooo]Z00Goj`3ooookJ_oonf[ooo]Zo`3o
1@02oookJP03oonn0?oonf[ooo]Z03Oooo]Z000`oookJP06ooo:0?oonf[ooo]Zoa80ool0oa_o08ko
2ooonfX01?oob@3oN?l0oookJ_l0g?l2oookJP05ocoo0?oonf[ooo]ZoookJ_l0:_l01?oonfX00ooo
DP3ooo]ZokWo000BoookJP03o`1coooonf[ooo]Z01Cooo]Z00?oo`3ZoookJ_oonfX02?oonfX00ooo
5P3ooi80oookJP02oookJP03ooo90?oonf[ooo]Z00Cooo]Z00?o603ooookJ_oo1P000_oonfX01?o[
o`3oo`3foookJ_l0Y_l3oookJP03ojP0oooonf[oo`3i00;ooo]Z00So07Ooo`3oV_oonf[oolT0oook
J_ooP@3ooo]Zoc_o00;ooo]Z00?oogT0oookJ_oonfX00ooonfX02?oo0`3ooo]ZoookJ_oo0=go01Oo
oookJ_l0Xooo/ol01OoonfX00ol0omkoo`00oookJP02oookJP07ool0K?oonf[ooo]Zodd0oooo:03o
oo]Zof40o`04oookJP03on80ool0oi3ooo]Z00;ooo]Z00?o0?nBoookJ_oonfX01OoonfX00omX0?oo
oo]ZoookJP03oookJP05oaP0oooVo`3ooo]ZoookJ_ooT0003OoonfX2oonn0003oookJ_o[0?ooL03o
00Co00001OoonfX00oooE`3ooo]ZoookJP07oookJP;oo`0]3_oonfX2oon1017ooo]Z3ooUo`0Aoook
JP[o00Co1_oonfX3o`3Dob3ooo]Z00?ooh40oookJ_oonfX05OoonfX00ooob@3ooo]ZoookJP0;oook
JP03oomG0?oonf[ooo]Z00Wooo]Z00Ooj`3ooookJ_oonf[ooo]Zo`3o1Ooonf[ookh006Gooo]Z00Ko
olX0oookJ_oonf[o4P3oo`3o6ol0S_l;oookJP07o`3ogomho`3ooo]ZoookJ_l0g?oooo]Zocoo0003
oookJP03o`0Zoooonf[ooo]Z00;ooo]Z00?ooe80o`3o<onio`004_oonfX00ol0Looooo]ZoookJP0E
oookJP03ool0j_oonf[ooo]Z00Oooo]Z00?ooaH0oonB0?oonfX00_oonfX00ooo0?cooo]ZoookJP04
oookJP03oaP0oooonf[oo`H000;ooo]Z00Cojol0oookJ_oo0?Ko0:Ko0ooonfX03OnX0?oooo]Zoook
J_oo0?Wooo]Zo`1goooonf[o0?nJoom/0?l0olcooh40oookJ_lko`000ooonfX00ol0nooooo]Zoook
JP02oookJP08ool30?oonf[ooo]ZogT0oooo0=go01Ooo`2Soonco`05oookJP03o`3og_oo08Oooo]Z
00;ooo]Z00Soo`1/oookJ_oonf[oC@3oool^0?oonf[o0?m5of40o`?ooo]Z00?ohP3oo`3oT?oonfX0
0_oonfX00ol0oi;ooo]ZoookJP05oookJP03ofP0oooonf[ooo]Z00?ooo]Z00Go603oonKo0?oonf[o
oo]Zoon@000=oookJP;ookh00_oonfX00oo[0?oo0000o`000002o`0000Gooo]Z0_ooE`08oookJP;o
o`0]3_oonfX2oon101_ooo]Z1?l0e?lBoookJP_o00Co1_oonfX3o`3Doaoooo]Z0_ooP@0GoookJP03
ool0;Ooonf[ooo]Z00[ooo]Z00?ooeL0oookJ_oonfX02OoonfX01Oo[0?oooo]ZoookJ_oonf[o0?l5
00;ooo]Z00?ookh0oookJ_oonfX0=_oonfX002oooo]Z00OoolX0oookJ_oonf[o4P3oo`3o6ooonf[o
08ko00_ooo]Z00CoolT0ogSo0?oonf[o0=co0_oonfX01?loo`3ooo]ZoookJ_l0:_l4oookJP03oomB
0?oonf[o^Ol001;ooo]Z00?o07?ooookJ_oonfX05?oonfX00ooo0>[ooo]ZoookJP08oookJP03oolF
0?ooTP3ooo]Z00?ooo]Z00?oolT0oookJ_oonfX00ooonfX00olH0?oooo]Zool60002oookJP05on_o
0?oonf[oo`3foookJ_l0Y_l00_oonfX03OnX0?oooo]ZoookJ_oo0?Wooo]Zo`1gool0oi[ooo]Zooo9
0?oo:03ooh40oookJ_lko`000_oonfX00oooN@3ooo]ZoookJP03oookJP08ool30?oonf[ooo]Zool0
gOoonf[o01Ooo`2Soonco`06oookJP05ool00?oonf[ooo]ZoookJ_oo06`00_oonfX01Om=0?ooobP0
oookJ_mQ0?oo0?m500?ooo]Z00?ohP3ooookJ_l0oi000_oonfX00ol0oi;ooo]ZoookJP05oookJP03
ofP0oooonf[ooo]Z00?ooo]Z00Go603oonKo0?oonf[ooo]Zoon@000=oookJP06oonn0?oonf[oo`00
ool00?m`0?oooo]Z1?l00003oookJP;ooeL02OoonfX00ooo02gooo]ZoookJP0<oookJP;ooh404ooo
nfX=onGo00Cooo]Z3ol01?l:oookJPCo00Co1OoonfX3o`3Doakooo]Z0_ooP@0EoookJP03ooo90?oo
nf[ooo]Z00cooo]Z00?ooeL0oookJ_oonfX02OoonfX01oo[0?oooo]ZoookJ_oonf[o0?l5oookJ_oo
_P00I?oonfX01_oobP3ooo]ZoookJ_l0oa_ooo]Zo`2>o`_ooo]Z00Oo0?oOogSo0?oonf[ooo]Zo`3L
oooonf[o?ol000?ooo]Z00Oo02[ooookJ_oonf[ooo]ZoomB0?l0oc?o^Ol001;ooo]Z00?o07?ooook
J_oonfX05OoonfX00ooo0>[ooo]ZoookJP07oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00?oo`3loook
J_oonfX01?oonfX00olH0?ooo`H0oookJP02oookJP04on_o0?oo0?Kooo]Zo`2Vo`;ooo]Z00koZ03o
oookJ_oonf[oo`3ioookJ_l0Mooooo]Zo`3oV_oonf[oof`0oookJ_ooP@3ooo]Zoc_o00;ooo]Z00?o
0?_ooookJ_oonfX00_oonfX02?oo0`3ooo]ZoookJ_mi0?ooo`3MoookJ_l0Xooo/ol01_oonfX01Ooo
08Oooo]ZoookJ_oonf[oo`1/00;ooo]Z00GoC@3ooookJ_oo;P3ooo]Zof40o`03oookJP03on80oooo
nf[o0?n@00;ooo]Z00?o0?nBoookJ_oonfX01OoonfX00omX0?oooo]ZoookJP03oookJP05oaP0oooV
o`3ooo]ZoookJ_ooT0003OoonfX00ooo_P3ooo]ZoookJP02on/0o`03oookJ_l0003o000000;o0000
1?oonfX00oooE`3ooo]ZoookJP07oookJP03ool0;Ooonf[ooo]Z00cooo]Z0_ooP@0IoookJPCo0=Co
1ooonfX?o`04o`_ooo]Z0ol01?l6oookJP?o0=Co7_oonfX00oooP@3ooo]ZoookJP0DoookJP03ool0
;Ooonf[ooo]Z00_ooo]Z00?ooeL0oookJ_oonfX02OoonfX01Oo[0?oooo]ZoookJ_oonf[o0?l500;o
oo]Z00?ookh0oookJ_oonfX0=OoonfX002oooo]Z00KoolX0oookJ_oonf[o4P3oo`3o6ol0S_l;oook
JP04ocd0oomho`3ooo]Zo`3Lo`;ooo]Z00Go?ol0oookJ_oonf[ooo]Zo`0Zo`04oookJP03oomB0?oo
nf[o^Ol001;ooo]Z00?o07?ooookJ_oonfX05?oonfX00ooo0>[ooo]ZoookJP07oookJP03oolF0?oo
nf[ooi8000?ooo]Z00?oolT0oookJ_oonfX01?oonfX02OlH0?oooo]Zool60?oonf[ojol0oookJ_oo
0?Kooo]Zo`2Vo`02oookJP0=ojP0oooonf[ooo]Zool0nOoonf[o07OooookJ_l0oi[oolT0oolX0?oo
P@3ooo]Zoc_o0002oookJP03oomi0?oonf[ooo]Z00?ooo]Z00Soo`<0oookJ_oonf[oo`3MoookJ_l0
5ooo0:?ook?o00Kooo]Z00Go0?oNool00?oonf[ooo]Zool0K002oookJP05odd0oooo:03ooo]Zof40
ool0odD00ooonfX00ooR0?oooo]Zo`3oT002oookJP03o`3oT_oonf[ooo]Z00Gooo]Z00?oJ03ooook
J_oonfX00ooonfX01OlH0?ooi_l0oookJ_oonf[ooi0000cooo]Z0_oo_P001?oonf[oo`00ool00?oo
0002oookJPCo000000?ooo]ZoomG0?ooE`002OoonfX2ool0;@kooo]Z00?ooh40oookJ_oonfX05?oo
nfX;onGo00Go00Co0_oo:00KoookJP?o00Co1OoonfX3o`3Doagooo]Z00?ooh40oookJ_oonfX04ooo
nfX00ooob@3ooo]ZoookJP0<oookJP03oomG0?oonf[ooo]Z00Sooo]Z00?oL03oon/0oooonfX00_oo
nfX00ol0o`Gooo]Zoonn001RoookJP06ooo:0?oonf[ooo]Zoa80ool0oa_o08ko2ooonfX01olm0?oo
N?l0oookJ_oonf[o0=cooookJ_loo`001?oonfX01ol0:_oooo]ZoookJ_oonf[ooe80o`3o<onio`00
4_oonfX00ol0Looooo]ZoookJP0EoookJP03ool0j_oonf[ooo]Z00Oooo]Z00?ooaH0oonB0?oonfX0
0_oonfX00ooo0?cooo]ZoookJP04oookJP03oaP0oooonf[oo`H000;ooo]Z00Cojol0oookJ_oo0?Ko
0:Ko0_oonfX01_nX0?oooo]ZoookJ_oonf[oo`3io`1go`;ooo]Z00Ko0?nJoom/0?l0olcooh40oook
J_lko`02oookJP03o`3koooonf[ooo]Z00;ooo]Z00Woo`<0oookJ_oonf[oN@3oool0gOoonf[oW`3o
o`2Soonco`001OoonfX01Ol0omkoo`27oookJ_oonf[oo`1/00?ooo]Z00CoC@3oool^0?oonf[oH@3o
0ooonfX00ooR0?oooo]Zo`3oT002oookJP03o`3oT_oonf[ooo]Z00Gooo]Z00?oJ03ooookJ_oonfX0
0ooonfX01OlH0?ooi_l0oookJ_oonf[ooi0000cooo]Z0_oo_P02oookJP04on/0oooonf[ooo]Zoook
JPCo00000_oonfX2oomG00Sooo]Z0_oo02d>oookJP03oon10?oonf[ooo]Z01Gooo]Z1?l0e?l00ooo
nf[o00Coo`04o`08o`04oagooo]Z1?l01?l5oookJP?o0=Co7?oonfX00oooP@3ooo]ZoookJP0Doook
JP03ool0;Ooonf[ooo]Z00_ooo]Z00?ooeL0oookJ_oonfX02?oonfX00om`0?ooj`3ooookJP02oook
JP03o`3o1Ooonf[ookh003Oooo]Z000_oookJP06ooo:0?oonf[o4P3oo`3o6ooonf[o08ko2ooonfX0
0ooob@3oN?l0o`3Lo`03oookJP04ocoo0?oonf[ooo]Zo`0Zo`Cooo]Z00?o0?lcoomB0?nio`004_oo
nfX00ol0Looooo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z00Sooo]Z00?ooaH0oonB0?oonfX00_oo
nfX00ooob@3ooo]ZoookJP04oookJP03oaP0oooonf[oo`H000;ooo]Z00Cojol0oookJ_oo0?Ko0:Ko
0_oonfX04?nX0?oooo]ZoookJ_oonf[oo`3ioookJ_l0Mooo0?nJoookJ_oob@3ooo]Zoon10?oonf[o
>ol0oookJ_ooN@06oookJP07ool30?oonf[ooo]Zool0gOl05ooo0:?ook?o0006oookJP05o`3og_oo
003ooo]ZoookJ_oo06`00_oonfX01Om=0?ooobP0oookJ_mQ0?oo0?m500;ooo]Z0_oo00001Ooonf[o
0?n@oookJ_oonf[o0?nB00Oooo]Z00?oJ03ooookJ_oonfX00ooonfX01OlH0?ooi_l0oookJ_oonf[o
oi0000cooo]Z00?ookh0oookJ_oo00000ooo0003oookJPCo000000?ooeL0oookJ_oonfX01ooonfX2
ool0;@kooo]Z0_ooP@0EoookJP_oiOl04?oo:004o`2Yoa?ooo]Z1?l01?l4oookJP?o0=Co6ooonfX0
0oooP@3ooo]ZoookJP0CoookJP03ooo90?oonf[ooo]Z00_ooo]Z00?ooeL0oookJ_oonfX02OoonfX0
0om`0?ooj`3ooookJP02oookJP03o`3o1Ooonf[ookh0067ooo]Z00KoolX0oookJ_oonf[o0?lKoook
J_l0S_l;oookJP04o`3ogomho`3ooo]Zo`3Lo`;ooo]Z00Go?ol0oookJ_oonf[ooo]Zo`0Zo`04oook
JP03oomB0?nio`3ooo]Z017ooo]Z00?o07?ooookJ_oonfX05OoonfX00ooo0>[ooo]ZoookJP07oook
JP03oolF0?ooTP3ooo]Z00;ooo]Z00?oo`3loookJ_oonfX01OoonfX02?lH0?ooo`H0oookJ_oonf[o
jol0oookJ_oo0?Ko0:Ko0_oonfX03_nX0?oooo]ZoookJ_oonf[oo`3ioookJ_l0Mooooo]Zo`3oV_oo
K03o0?o<oon10?oonf[o>ol00_oonfX00ol0nooooo]ZoookJP03oookJP08ool30?oonf[ooo]ZogT0
oooo0=go01Ooo`2Soonco`05oookJP03o`3og_oo08Oooo]Z00;ooo]Z00Ooo`1/oookJ_oonf[oC@3o
ool^0?oonf[oH@3o00?ooo]Z00?ohP3ooookJ_l0oi000_oonfX00ol0oi;ooo]ZoookJP05oookJP03
ofP0oooonf[ooo]Z00?ooo]Z00Go603oonKo0?oonf[ooo]Zoon@000<oookJP05oonn0?oonf[ooo]Z
oookJ_o[0?l01?oonfX4o`000003oookJ_ooE`3ooo]Z00Sooo]Z00?oo`0]oookJ_oonfX03?oonfX2
oon101Gooo]Z0ol0e?l2oookJP?o00Co3ooonfX8o`2YoaCooo]Z1?l01?l4oookJP?o0=Co6_oonfX2
oon101Gooo]Z00?oo`0]oookJ_oonfX02_oonfX00oooE`3ooo]ZoookJP09oookJP03og00ooo[0?oo
oo]Z00;ooo]Z00?o0?l5oookJ_oo_P00=_oonfX002kooo]Z00KoolX0oookJ_oonf[o4P3oo`3o6ol0
S_l<oookJP03ogSo0?oonf[o0=co00;ooo]Z00Go?ol0oookJ_oonf[ooo]Zo`0Zo`04oookJP03oomB
0?oonf[o^Ol001;ooo]Z00?o07?ooookJ_oonfX05?oonfX00ooo0>[ooo]ZoookJP07oookJP03oolF
0?oonf[ooi8000?ooo]Z00?oo`3loookJ_oonfX01?oonfX02OlH0?ooo`H0oookJ_oonf[ojol0oook
J_oo0?Kooo]Zo`2Vo`02oookJP0?ojP0oooonf[ooo]Zool0nOoonf[o07OooookJ_l0oi[oolT0oook
J_ooP@3ooo]Zoc_o0?oonf[oogT000Kooo]Z00Soo`<0oookJ_oonf[oo`3MoookJ_l05ooo0:?ook?o
00Gooo]Z00Go0?oNool00?oonf[ooo]Zool0K002oookJP05odd0oooo:03ooo]ZoookJ_mQ0?l00_oo
nfX3ool00004o`3oT?oonf[ooo]Zo`3oTPOooo]Z00?oJ03ooookJ_oonfX00ooonfX00olH0?oo07Co
oookJP02oookJP03oon@0?oonf[ooo]Z00Wooo]Z00?ookh0ool00?oo00000ooo0004oookJP?o0000
00?ooeL0oookJ_oonfX01ooonfX00ooo02gooo]ZoookJP0<oookJP;ooh404ooonfX4onGo00;ooo]Z
1ooUo`02oookJPkoobP01_oonfX7o`2Yoa3ooo]Z1?l01?l3oookJP?o0=Co6OoonfX2oon101Cooo]Z
00?oolT0oookJ_oonfX02ooonfX00oooE`3ooo]ZoookJP09oookJP03og00ooo[0?oooo]Z00;ooo]Z
00?o0?l5oookJ_oo_P00GooonfX01_oobP3ooo]ZoookJ_oonf[o0?lKo`2>o`cooo]Z00KoN?l0oook
J_oonf[o0=cooookJ_loo`04oookJP07o`0Zoooonf[ooo]ZoookJ_ooDP3o0?lcokWo000BoookJP03
o`1coooonf[ooo]Z01Gooo]Z00?oo`3ZoookJ_oonfX01ooonfX00ooo5P3ooi80oookJP02oookJP03
ool0o?oonf[ooo]Z00Cooo]Z00?o603oool60?oonfX00_oonfX01?o[o`3oo`3foookJ_l0Y_l2oook
JP06ojP0oooonf[ooo]ZoookJ_oo0?Wo07Oo0_oonfX02?l0oi[oof`0oookJ_ooP@3ooo]Zoc_o0?oo
nf[o0?_o1OoonfX02?oo0`3ooo]ZoookJ_mi0?ooo`3MoookJ_l0Xooo/ol01OoonfX00ol0omkoo`27
oookJP02oookJP08ool0K?oonf[ooo]Zodd0oooo;P3ooo]Zof40ool0odD3oookJP05on80ool0oi3o
oo]ZoookJ_l0oi801ooonfX00omX0?oooo]ZoookJP03oookJP03oaP0oooVo`3ooo]Z00;ooo]Z00?o
oi00oookJ_oonfX02OoonfX01Ooo_P3ooo]ZoookJ_l0o`Goj`3o00Gooo]Z1?l000000oooE`3ooo]Z
oookJP06oookJP;oo`0]3OoonfX2oon101?ooo]Z1?l0e?l2oookJP?o00Co3?oonfX6o`2Yo`Sooo]Z
1ol0ZOlAoookJP?o00Co1?oonfX2o`3Doa[ooo]Z00?ooh40oookJ_oonfX04ooonfX00ooo02gooo]Z
oookJP0:oookJP03oomG0?oonf[ooo]Z00Wooo]Z00?oL03oon/0oooonfX00_oonfX00ol0o`Gooo]Z
oonn000eoookJP00;_oonfX01_oobP3ooo]ZoookJ_l0oa_ooo]Zo`2>o`_ooo]Z00?oolT0ogSo0?l0
g?l00ooonfX01Oloo`3ooo]ZoookJ_oonf[o02[o00?ooo]Z00Co0?lcoomB0?oonf[o^Ol04OoonfX0
0ol0Looooo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z00Sooo]Z00?ooaH0oonB0?oonfX00_oonfX0
0ooo0?cooo]ZoookJP04oookJP03oaP0oooonf[oo`H000;ooo]Z00Cojol0ool0m_oonf[o0:Ko0_oo
nfX03OnX0?oooo]ZoookJ_oo0?Wooo]Zo`1goooonf[o0?nJooo90?oonf[ooh40oookJ_lko`000_oo
nfX00ol0nooooo]ZoookJP03oookJP08ool30?oonf[ooo]Zool0gOoonf[o01Ooo`2Soonco`06oook
JP08ool00?oonf[ooo]ZoookJ_oo06cooo]Zodd0oooo:002oookJP03of40ool0odGooo]Z00?oo`00
00Go0?n@oookJ_oonf[ooo]Zo`3oTP06oookJP03ofP0oooonf[ooo]Z00?ooo]Z00?o603oo`1doooo
nfX00_oonfX00oooT03ooo]ZoookJP09oookJP03oonn0?oo003oo`0000Coo`001?oonfX2o`000003
oomG0?l0003ooo]Z00Kooo]Z0_oo02d=oookJP;ooh404OoonfX4onGo00;ooo]Z1?l01?l5onGo00Co
ogT02ooo:00@o`28o`Oo0:Wo3OoonfX4o`04o`;ooo]Z0ol0e?lHoookJP03oon10?oonf[ooo]Z01;o
oo]Z00?oolT0oookJ_oonfX02ooonfX00oooE`3ooo]ZoookJP09oookJP03on/0oooonf[ooo]Z00;o
oo]Z00?o0?l5oonn0?oonfX0G_oonfX01_oobP3ooo]ZoookJ_l0oa_ooo]Zo`2>o`_ooo]Z00Co0?oO
ogSo0?oonf[o0=co0_oonfX01Oloo`3ooo]ZoookJ_oonf[o02[o00Cooo]Z00?ooe80oookJ_nio`00
4OoonfX00ol0Looooo]ZoookJP0EoookJP03ool0j_oonf[ooo]Z00Oooo]Z00?ooaH0oonB0?oonfX0
0_oonfX00ooo0?cooo]ZoookJP04oookJP03oaP0oooonf[oo`H000;ooo]Z00Cojol0oookJ_oo0?Ko
0:Ko0_oonfX01_nX0?oooo]ZoookJ_oonf[oo`3io`1go`;ooo]Z00Ko0?nJoom/0?oonf[ooh40oook
J_lko`02oookJP03o`3koooonf[ooo]Z00;ooo]Z00Soo`<0oookJ_oonf[oN@3oool0gOoonf[o0:?o
ok?o00Kooo]Z00Goo`27oookJ_oonf[ooo]Zool0K002oookJP05odd0oooo;P3ooo]Zof40ool0odD0
0ooonfX00ooR0?oo0?n@oookJP02oookJP03o`3oT_oonf[ooo]Z00Cooo]Z00?oJ03ooookJ_oonfX0
0ooonfX00olH0?ooi_l0oookJP02oookJP03oon@0?oonf[ooo]Z00Wooo]Z00Gookh0oookJ_oonf[o
0?l5on/0o`06oookJP?o000000?ooeL0oookJ_oonfX01_oonfX00ooo02gooo]ZoookJP0;oookJP;o
oh404OoonfX4o`3Do`;ooo]Z1?l01?l7oookJP;o08So1_l0ZOlEo`28o`So0:Wo3?oonfX4o`04o`;o
oo]Z0ol0e?lHoookJP;ooh405?oonfX00ooo02gooo]ZoookJP0:oookJP03oomG0?oonf[ooo]Z00Wo
oo]Z00?oj`3ooookJ_oonfX00_oonfX00ol0o`Gooo]Zoonn000doookJP00;OoonfX01_oobP3ooo]Z
oookJ_lB0?oo0?lKo`2>o`cooo]Z00?oN?l0oookJ_l0g?l00_oonfX01Oloo`3ooo]ZoookJ_oonf[o
02[o00Cooo]Z00?ooe80oookJ_nio`004_oonfX00ol0Looooo]ZoookJP0DoookJP03ool0j_oonf[o
oo]Z00Oooo]Z00?ooaH0oookJ_ooTP000ooonfX00ooo0?cooo]ZoookJP03oookJP03oaP0oooonf[o
o`H000;ooo]Z00Oojol0oookJ_oo0?Kooo]Zo`2Voooonf[oZ03o00?ooo]Z00coo`3ioookJ_l0Mooo
0?nJooo90?oo:03ooo]Zoon10?oonf[o>ol0oookJ_l0nol6oookJP07ool30?oonf[oo`3MogT0ool0
5ooo0:?ook?o0006oookJP08ool00?oonf[ooo]ZoookJ_oo06cooo]Zodd0oooo:002oookJP03of40
ool0odGoo`0000Coo`0000Co0?n@oookJ_oonf[o0?nB1_oonfX00omX0?oooo]ZoookJP03oookJP03
oaP0ool0M?oooo]Z00;ooo]Z00?ooi00oookJ_oonfX02OoonfX7ool000Gooo]Z00Co0000oomG0?l0
003o00001_oonfX00ooo02gooo]ZoookJP0;oookJP;ooh403ooonfX4onGo00?ooo]Z0ol01?l5oomi
00?oiOl01Ooo:0000ooonf[oobP0oolX0006oolX01Sooo]Z00?o08Soo`2Yool0ZOl01Ol0ZOl:oook
JP?o00Co0_oonfX3o`3DoaKooo]Z00?ooh40oookJ_oonfX04_oonfX00ooob@3ooo]ZoookJP0:oook
JP03oomG0?oonf[ooo]Z00[ooo]Z00?oj`3ooookJ_oonfX00_oonfX00ol0o`Gookh0oookJP1Loook
JP06ooo:0?oonf[ooo]ZoookJ_l0oa_o08ko3?oonfX01_mho`3ooo]ZoookJ_l0g?oooo]Zocoo00Co
oo]Z00Oo02[ooookJ_oonf[ooo]ZoomB0?l0oc?o^Ol001;ooo]Z00?o07?ooookJ_oonfX05OoonfX0
0ooo0>[ooo]ZoookJP07oookJP03oolF0?ooTP3ooo]Z00;ooo]Z00?oo`3loookJ_oonfX01?oonfX0
0olH0?ooo`H0oookJP02oookJP06on_o0?oo0?Kooo]Zo`2Voooonf[oZ03o0ooonfX02_oo0?Wooo]Z
o`1goooonf[o0?nJoom/0?l0olcooh40oookJ_lko`02oookJP03o`3koooonf[ooo]Z00?ooo]Z00So
o`<0oookJ_oonf[oo`3MoookJ_l0XoooW`3ook?o00Gooo]Z00Goo`27oookJ_oonf[ooo]Zool0K002
oookJP05odd0oooo;P3ooo]Zof40ool0odD00ooonfX00ooR0?oooo]Zo`3oT002oookJP03o`3oT_oo
nf[ooo]Z00Gooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?ooi_l0oookJP02oookJP03oon@0?oo
nf[ooo]Z00Wooo]Z00Gookh0oookJ_l0o`Go0?l5on/0o`07oookJP;o000000?ooeL0o`000?oonfX0
1OoonfX2ool0;@cooo]Z0_ooP@0?oookJPCo0=Co0ooonfX3o`04o`Oooo]Z1_l0ZOlQoookJP;o08So
1ol0ZOl9oookJPCo00Co00Cooo]Zo`3Dool0e?oo0=Co5ooonfX00oooP@3ooo]ZoookJP0BoookJP03
ool0;Ooonf[ooo]Z00[ooo]Z00?ooeL0oookJ_oonfX02OoonfX00oo[0?oooo]ZoookJP02oookJP03
o`3o1Ooonf[ookh003?ooo]Z000]oookJP06ooo:0?oonf[ooo]Zo`3o6ooonf[o08ko2ooonfX00ooo
b@3oN?l0o`3Lo`03oookJP05ocoo0?oonf[ooo]ZoookJ_l0:_l00ooonfX01?l0oc?ooe80oookJ_ni
o`0AoookJP03o`1coooonf[ooo]Z01Cooo]Z00?oo`3ZoookJ_oonfX02?oonfX00ooo5P3ooi80oook
JP02oookJP03ool0o?oonf[ooo]Z00Cooo]Z00Wo603oool60?oonf[ooo]Zon_o0?oonf[oo`3foook
J_l0Y_l00_oonfX03OnX0?oooo]ZoookJ_oo0?Wooo]Zo`1goooonf[o0?nJooo90?oonf[ooh40oook
J_lko`000_oonfX00ol0nooooo]ZoookJP03oookJP07ool30?oonf[oo`3MogT0oooonf[o0:?ook?o
0006oookJP08o`3og_oo003ooo]ZoookJ_oo06cooo]Zodd0oooo:002oookJP03of40ool0odGoo`00
00Coo`0000Co0?n@oookJ_oonf[o0?nB1ooonfX00omX0?oooo]ZoookJP02oookJP03oaP0ool0M?oo
oo]Z00;ooo]Z00?ooi00oookJ_oonfX02?oonfX9ool000Cooo]Z0_ooE`04o`0000?ooo]Z0_oo02d<
oookJP;ooh403_oonfX00ol0e?ooiOl0onGo0004oookJP?o00Co00Cooo]Zoomi0?ooN@3oogT01?oo
:0000ooUo`3oobP0oomi0003oomi00?ooo]Z1_oo:00MoookJP?o08So0_oonfX5o`2Yo`Sooo]Z1?l0
1?l01?oonf[o0=Coo`3Dool0e?lDoookJP;ooh404ooonfX00ooob@3ooo]ZoookJP0:oookJP03oomG
0?oonf[ooo]Z00[ooo]Z00Ooj`3ooookJ_oonf[ooo]Zo`3o1Ooonf[ookh005cooo]Z00KoolX0oook
J_oonf[o0?lKoookJ_l0S_l;oookJP04o`3ogomho`3ooo]Zo`3Lo`;ooo]Z00Go?ol0oookJ_oonf[o
oo]Zo`0Zo`04oookJP03oomB0?oonf[o^Ol0017ooo]Z00?o07?ooookJ_oonfX05OoonfX00ooo0>[o
oo]ZoookJP07oookJP03oolF0?ooTP3ooo]Z00;ooo]Z00?oo`3loookJ_oonfX01?oonfX00olH0?oo
o`H0oookJP02oookJP04on_o0?oonf[oo`3fo`2Vo`;ooo]Z00KoZ03ooookJ_oonf[ooo]Zool0nOl0
Mol2oookJP06oom/0?l0olcooo]Zoon10?oonf[o>ol00_oonfX00ol0nooooo]ZoookJP02oookJP04
ool30?oonf[ooo]Zool0g@;ooo]Z00?o0:?ook?o0?oonfX01?oonfX01Ol0omkoo`27oookJ_oonf[o
o`1/00;ooo]Z00GoC@3oool^0?oonf[ooo]Zof40o`03oookJP03on80oooonf[o0?n@00;ooo]Z00?o
0?nBoookJ_oonfX01OoonfX00omX0?oooo]ZoookJP03oookJP05oaP0oooonf[ooo]ZoookJ_ooT000
2ooonfX01Ooo_P3ooo]Zo`3o1Ooonf[oj`3o00Sooo]Z0_ooE`03o`0000Cooo]Z00?oo`0]oookJ_oo
nfX02_oonfX2oon100kooo]Z0ol0e?l4oookJP?o00Co1?oonfX6o`2Yo`03o`28oooonf[ooo]Z02Oo
oo]Z0ol0R?l3oookJPGo0:Wo2?oonfX3o`04o`04oookJ_l0e?oo0=Coo`3DoaGooo]Z00?ooh40oook
J_oonfX04OoonfX00ooo02gooo]ZoookJP0:oookJP03oomG0?oonf[ooo]Z00[ooo]Z00Goj`3ooook
J_oonf[ooo]Zo`3o1@02oookJP03oonn0?oonf[ooo]Z033ooo]Z000/oookJP06ooo:0?oonf[ooo]Z
oookJ_l0oa_o08ko3?oonfX00omho`3ooo]Zo`3Lo`02oookJP05ocoo0?oonf[ooo]ZoookJ_l0:_l0
1?oonfX00oooDP3ooo]ZokWo000BoookJP03o`1coooonf[ooo]Z01Cooo]Z00?oo`3ZoookJ_oonfX0
1ooonfX00ooo5P3ooi80oookJP03oookJP03ool0o?oonf[ooo]Z00?ooo]Z00?o603ooookJ_oo1P00
0_oonfX01oo[o`3ooo]Zool0m_oonf[o0:KooookJ_nX0?l00_oonfX01_oo0?Wooo]Zo`1goooonf[o
0?nJooo900;ooo]Z00Gooh40oc_o0?oonf[ooo]Zo`3ko`05oookJP08ool30?oonf[ooo]Zool0gOoo
nf[o01Ooo`2Soonco`06oookJP07ool00?oonf[ooo]Zool0K?oonf[oC@3ooolX0002oookJP03of40
ool0odGoo`0000Goo`000_oonfX00ol0oi;ooo]ZoookJP05oookJP03ofP0oooonf[ooo]Z00;ooo]Z
00?o603oo`1doooonfX00_oonfX00oooT03ooo]ZoookJP08oookJPWoo`001?oonfX00oooE`3ooo]Z
o`000003o`0000;ooo]Z0_oo02d=oookJP03oon10?oonf[ooo]Z00cooo]Z0_l0e?l3oookJPCo00Co
0ooonfX01?l0ZOooobP0oolX0?oo:005oomi00_oobP02ooonfX3oomi01Gooo]Z0ol0R?l4oookJP;o
0:Wo2_oonfX3o`04o`04oookJ_l0e?oo0=Coo`3Doa?ooo]Z00?ooh40oookJ_oonfX04OoonfX00ooo
b@3ooo]ZoookJP0:oookJP03oomG0?oonf[ooo]Z00[ooo]Z00Ooj`3ooookJ_oonf[ooo]Zo`3o1Ooo
nf[ookh005[ooo]Z00KoolX0oookJ_oonf[ooo]Zo`3o6ol0S_l<oookJP06ogSo0?oonf[ooo]Zo`3L
oooonf[o?ol01?oonfX01ol0:_oooo]ZoookJ_oonf[ooe80o`3o<onio`004_oonfX00ol0Looooo]Z
oookJP0EoookJP03ool0j_oonf[ooo]Z00Oooo]Z00?ooi80oookJ_oonfX00_oonfX00ooo0?cooo]Z
oookJP04oookJP0;oaP0oooo1P3ooo]ZoookJ_o[o`3ooo]Zool0m_oonf[o0:KooookJ_nX0?l00ooo
nfX02_oo0?Wo07OooookJ_oonf[o0?nJoom/0?oonf[ooh40oookJ_lko`02oookJP03o`3koooonf[o
oo]Z00;ooo]Z00Soo`<0oookJ_oonf[oN@3oool0gOoonf[o0:?ook?o00Kooo]Z00Coo`27oookJ_oo
nf[oo`1/0_oonfX01_m=0?ooobh0oookJ_oonf[oH@3oo`3oA@?ooo]Z00GohP3oo`3oT?oonf[ooo]Z
o`3oTP07oookJP03ofP0oooonf[ooo]Z00?ooo]Z00Go603ooookJ_oonf[ooo]Zoon@000;oookJP05
oonn0?oonf[o0?l5oookJ_o[0?l02?oonfX00oooE`3o0000o`000002o`0000?ooo]Z0_oo02d<oook
JP03oon10?oonf[ooo]Z00cooo]Z0_l0e?l3oookJPCo00Co0ooonfX4o`2Yo`04oookJ_l0R?oo08So
o`28oboooo]Z0ol0R?l5oookJP;o0:Wo2OoonfX3o`04o`04oookJ_l0e?oo0=Coo`3Doa?ooo]Z0_oo
P@0BoookJP03ool0;Ooonf[ooo]Z00[ooo]Z00?ooeL0oookJ_oonfX02_oonfX01Oo[0?oooo]Zoook
J_oonf[o0?l500;ooo]Z00?ookh0oookJ_oonfX0;ooonfX002cooo]Z00KoolX0oookJ_oonf[o0?lK
oookJ_l0S_l;oookJP03ooo90?mho`3o0=co00?ooo]Z00Go?ol0oookJ_oonf[ooo]Zo`0Zo`03oook
JP04o`3o<oooDP3ooo]ZokWo017ooo]Z00?o07?ooookJ_oonfX05OoonfX00ooo0>[ooo]ZoookJP07
oookJP03oolF0?ooTP3ooo]Z00;ooo]Z00?oo`3loookJ_oonfX01?oonfX02olH0?ooo`H0oookJ_oo
nf[ojol0oookJ_oo0?Kooo]Zo`2Voooonf[oZ03o00?ooo]Z00Goo`3ioookJ_l0Mooooo]Zooo90002
oookJP05oon10?oonf[o>ol0oookJ_l0nol01_oonfX01ooo0`3ooo]Zool0gOmi0?oo01Ooo`2Soonc
o`001_oonfX01ooo003ooo]ZoookJ_oo06cooo]Zodd0oooo:0000_oonfX00omQ0?ooo`00ool00006
ool00003oookJ_l0oi;ooo]Z00Kooo]Z00?oJ03ooookJ_oonfX00_oonfX00ooVo`3o603ooookJP02
oookJP03oon@0?oonf[ooo]Z00Sooo]Z2Ooo0004oookJP03oomG0?oonf[ooo]Z00Co000000?ooo]Z
ool0;OoonfX03?oonfX2oon100gooo]Z0_l0e?l2oookJP?o00Co1?oonfX3o`2Yo`03oookJ_ooN@3o
ogT000KoogT03ooo:009o`3oCPGoogT05?oonfX3o`28o`?ooo]Z0_l0ZOl;oookJP04o`04oooonf[o
oo]ZoookJP;o0=Co4_oonfX2oon1017ooo]Z00?oolT0oookJ_oonfX02_oonfX00oooE`3ooo]Zoook
JP0;oookJP04on/0oooonf[ooo]Zo`3o1@;ooo]Z00?ookh0oookJ_oonfX0EooonfX01_oobP3ooo]Z
oookJ_l0oa_o4P3oo`2>o`_ooo]Z00Co0?oOogSo0?oonf[o0=co0_oonfX00oloo`3ooo]ZoookJP02
oookJP07o`0Zoooonf[ooo]ZoookJ_ooDP3ooo]ZokWo000AoookJP03o`1coooonf[ooo]Z01Gooo]Z
00?oo`3ZoookJ_oonfX01ooonfX00ooo5P3ooi80oookJP02oookJP03ool0o?oonf[ooo]Z00Cooo]Z
00?o603oool60?oonfX00_oonfX01_o[o`3oo`3foookJ_l0Y_oooo]ZojP0o`?ooo]Z00?oo`3ioook
J_l0Mol00_oonfX01OooK03ooo]Zoon10?oonf[o>ol000;ooo]Z00?o0?_ooookJ_oonfX00ooonfX0
1ooo0`3ooo]ZoookJ_oo0=gooo]Zo`2Soonco`001_oonfX01?oo08Oooo]ZoookJ_oo06`2oookJP06
odd0oooo;P3ooo]ZoookJ_mQ0?oo0?m50ooonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Oooo]Z00?o
J03ooookJ_oonfX00ooonfX01OlH0?oo07CooookJ_oonf[ooi0000_ooo]Z00Gookh0oookJ_l0o`Go
oo]Zon/0o`08oookJP03oomG0?oonf[o000000?o00000_oonfX00ooo02gooo]ZoookJP0:oookJP;o
oh403OoonfX2o`3Do`;ooo]Z0ol01?l4oookJP?o0:Wo00?ooo]Zo`28ool0R?l00_l0R?lBoookJP;o
0?l^2Ol0odhHoookJP?o08So1?oonfX2o`2Yo`[ooo]Z00Co00CooookJ_oonf[ooo]Z0_l0e?lCoook
JP03oon10?oonf[ooo]Z013ooo]Z00?oo`0]oookJ_oonfX02_oonfX00oooE`3ooo]ZoookJP0:oook
JP04on/0oooonf[ooo]Zo`3o1@?ooo]Z00?ookh0oookJ_oonfX0;_oonfX002cooo]Z00KoolX0oook
J_oonf[o0?lKoookJ_l0S_l;oookJP03ogSo0?oonf[o0=co00;ooo]Z00?o?ol0oookJ_oonfX00_oo
nfX01Ol0:_oooo]ZoookJ_oonf[ooe8000;ooo]Z00?o^Ol0oookJ_oonfX03ooonfX00ol0Looooo]Z
oookJP0DoookJP03ool0j_oonf[ooo]Z00Oooo]Z00?ooaH0oonB0?oonfX00ooonfX00ooo0?cooo]Z
oookJP03oookJP03oaP0oooo1P3ooo]Z00;ooo]Z00Oojol0ool0m_oonf[ooo]Zo`2Voooonf[oZ03o
00;ooo]Z00[oo`3ioookJ_l0Mooooo]Zooo90?l0olcooo]Zoon10?oonf[o>ol00_oonfX00ol0nooo
oo]ZoookJP03oookJP07ool30?oonf[oo`3MogT0oooonf[o0:?ook?o0006oookJP07ool00?oonf[o
oo]Zool0K?oonf[oC@3ooolX0003oookJPSoo`0000?ooo]Zo`3oT_oonfX01_oonfX00omX0?oooo]Z
oookJP02oookJP03onKo0?lH0?oooo]Z00;ooo]Z00?ooi00oookJ_oonfX01ooonfX2onGo0003oonn
0?oo003oo`0000Koo`000ooonfX01?ooE`3ooo]ZoookJ_oonfX3o`0000;oo`0]3?oonfX2oon100ko
oo]Z00?o0=CooookJ_l01?l00_l01?l5oookJP;o0:Wo00Gooo]Zoomi0?ooN@3oogT0oookJP07oomi
00WoobP01_l0odh7oookJP;oogT02_l0odhBoookJP?o08So0_oonfX2o`2Yo`[ooo]Z00?o00Cooook
J_oonfX00_oonfX00ol0e?oooo]ZoookJP0AoookJP03oon10?oonf[ooo]Z00oooo]Z00?oolT0oook
J_oonfX02_oonfX00oooE`3ooo]ZoookJP0:oookJP05on/0oooonf[ooo]ZoookJ_l0o`D00_oonfX0
0ooo_P3ooo]ZoookJP1FoookJP06ooo:0?oonf[ooo]Zo`3o6ooonf[o08ko2ooonfX01_mho`3ooo]Z
oookJ_l0g?oooo]Zocoo00Cooo]Z00So02[ooookJ_oonf[ooo]ZoomB0?l0oc?ooo]ZokWo017ooo]Z
00?o07?ooookJ_oonfX05OoonfX00ooo0>[ooo]ZoookJP06oookJP03oolF0?ooTP3ooo]Z00?ooo]Z
00?oo`3loookJ_oonfX00ooonfX00olH0?ooo`H0oookJP02oookJP07on_o0?oonf[oo`3foookJ_l0
Y_oooo]ZojP0o`03oookJP09ool0nOl0Mooooo]ZoookJ_ooK03o0?o<oookJ_ooP@3o>ol000?ooo]Z
00?o0?_ooookJ_oonfX00_oonfX01ooo0`3ooo]ZoookJ_oo0=gooo]Zo`2Soonco`001_oonfX02?oo
08Oooo]ZoookJ_oonf[oo`1/oookJ_m=0?ooobh00_oonfX00omQ0?oo0?m5oookJP02oookJP03on80
ool0oi3ooo]Z00;ooo]Z00?o0?nBoookJ_oonfX01?oonfX00omX0?oooo]ZoookJP03oookJP05oaP0
ool0M?oooo]ZoookJ_ooT0002ooonfX01Ooo_P3ooo]ZoookJ_l0o`Goj`3o00Sooo]Z00?ooeL0oook
J_oonfX01?l00002ool0;@_ooo]Z0_ooP@0>oookJP03o`3Doooonf[o00Co00;o00Co1OoonfX2o`2Y
o`04oookJ_l0R?oo08Soo`28oa7ooo]Z00?o0?l^o`3oC_l0odh01?l0odh6oookJP?o0?l^2Ol0odhB
oookJP?o08So0ooonfX2o`2Yo`Wooo]Z0_l01?l3oookJP03o`3Doooonf[ooo]Z017ooo]Z0_ooP@0A
oookJP03ool0;Ooonf[ooo]Z00Wooo]Z00?ooeL0oookJ_oonfX02_oonfX01Oo[0?oooo]ZoookJ_oo
nf[o0?l500?ooo]Z00?ookh0oookJ_oonfX0;OoonfX002_ooo]Z00KoolX0oookJ_oonf[ooo]Zo`3o
6ol0S_l;oookJP03ooo90?mho`3o0=co00?ooo]Z00Go?ol0oookJ_oonf[ooo]Zo`0Zo`03oookJP04
o`3o<oooDP3ooo]ZokWo01;ooo]Z00?o07?ooookJ_oonfX05?oonfX00ooo0>[ooo]ZoookJP07oook
JP03oolF0?ooTP3ooo]Z00;ooo]Z00?oo`3loookJ_oonfX00ooonfX00olH0?oooo]Zool60002oook
JP07on_o0?oonf[oo`3foookJ_l0Y_oooo]ZojP0o`03oookJP05ool0nOl0Mooooo]ZoookJ_oob@00
0_oonfX01OooP@3o>ol0oookJ_oonf[o0?_o00Gooo]Z00Ooo`<0oookJ_oo0=goN@3ooookJ_l0Xooo
/ol000Kooo]Z00So0?oNool00?oonf[ooo]Zool0K?m=0?oooo]Zool^00;ooo]Z2Ooo00000ooonf[o
0?nBoookJP05oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?oi_l0oaP0ool0M?l00_oonfX00oooT03o
oo]ZoookJP07oookJP;oiOl000?ookh0onGo0?oUo`001_oo0003oookJP03oomG0?oonf[ooo]Z00;o
oo]Z0_l000000ooo02go0000oookJP0:oookJP;ooh403_oonfX2o`3Do`;o00Co1_oonfX2o`2Yo`?o
ogT01?oonfX5oomi00?ooo]Z0_oo:006o`3oCQWoogT02Ol0odh<oookJP?o08So00?ooo]Zo`2Yool0
ZOl02OoonfX2o`04o`?ooo]Z00?o0=CooookJ_oonfX04OoonfX00oooP@3ooo]ZoookJP0?oookJP03
ooo90?oonf[ooo]Z00[ooo]Z00?ooeL0oookJ_oonfX02_oonfX01?o[0?oooo]ZoookJ_l0o`D3oook
JP03oonn0?oonf[ooo]Z05Cooo]Z00KoolX0oookJ_oonf[ooo]Zo`3o6ol0S_l;oookJP04o`3ogomh
o`3ooo]Zo`3Lo`;ooo]Z00?o?ol0oookJ_oonfX00_oonfX01ol0:_oooo]ZoookJ_oonf[ooe80oook
J_nio`004_oonfX00ol0Looooo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z00Oooo]Z00?ooaH0oonB
0?oonfX00_oonfX00ooo0?cooo]ZoookJP04oookJP03oaP0oooo1P3ooo]Z00;ooo]Z00Kojol0ool0
m_oonf[o0:KooookJ_nX0?l3oookJP0:ool0nOl0Mooooo]ZoookJ_l0oi[oof`0oookJ_ooP@3ooo]Z
oc_o00;ooo]Z00?o0?_ooookJ_oonfX00_oonfX02?oo0`3ooo]ZoookJ_oo0=gooo]Zo`2Sool05ooo
/ol01OoonfX03?l0omkoo`27oookJ_oonf[oo`1/oookJ_m=0?oooo]Zool^0?oonf[oH@3oo`3oA@?o
oo]Z00?ohP3ooookJ_l0oi000_oonfX00ol0oi;ooo]ZoookJP04oookJP03ofP0oooonf[ooo]Z00?o
oo]Z00?o603oo`1doooonfX00_oonfX00oooT03ooo]ZoookJP08oookJP05oonn0?oonf[ooo]Zo`3o
1Oo[0?l02?oonfX01?ooE`3ooo]ZoookJ_oonfX2o`0000;oo`0]2ooonfX2oon100kooo]Z0_l0e?l2
o`04o`Kooo]Z0_l0ZOl3o`28o`oooo]Z1_l0odh?o`3o=0Kooo]Z0ol0obh9o`3oCPcooo]Z0ol0R?l2
oookJP;o0:Wo2OoonfX01Ol01?oooo]ZoookJ_oonf[o0=Co01Cooo]Z00?ooh40oookJ_oonfX03ooo
nfX00ooo02gooo]ZoookJP09oookJP03oomG0?oonf[ooo]Z00[ooo]Z00Coj`3ooookJ_oonf[o0?l5
1?oonfX00ooo_P3ooo]ZoookJP0/oookJP00:ooonfX01_oobP3ooo]ZoookJ_l0oa_ooo]Zo`2>o`_o
oo]Z00?oN?l0oookJ_l0g?l00_oonfX00oloo`3ooo]ZoookJP02oookJP05o`0Zoooonf[ooo]Zoook
J_ooDP000_oonfX00onio`3ooo]ZoookJP0?oookJP03o`1coooonf[ooo]Z01Cooo]Z00?oo`3Zoook
J_oonfX01ooonfX00ooo5P3ooi80oookJP03oookJP03ool0o?oonf[ooo]Z00?ooo]Z00_o603oool6
0?oonf[ooo]Zon_o0?oonf[oo`3foookJ_l0Y_oooo]ZojP0o`03oookJP0:ool0nOoonf[o07Oooook
J_oob@3o0?o<oookJ_ooP@3ooo]Zoc_o00;ooo]Z00?o0?_ooookJ_oonfX00ooonfX01ooo0`3oobP0
oookJ_mi0?oo0:?ooookJ_nco`001_oonfX01ooo003ooo]ZoookJ_oo06cooo]Zodd0oooo;P000_oo
nfX9ool00003oookJ_l0oi;ooo]Z00Gooo]Z00?oJ03ooookJ_oonfX00_oonfX00ooVo`3o603oo`1d
o`02oookJP03oon@0?oonf[ooo]Z00Wooo]Z00Gookh0onGo0?oUo`3oo`00onGo0005ool00003oook
J_ooE`3ooeL000Gooo]Z0_oo02d2o`0000Wooo]Z0_ooP@0>oookJP;o0=Co00?o00CooookJ_oonfX0
1?oonfX3o`2Yo`;oogT02?oonfX2oomi00;ooo]Z1Ol0odh4o`3o=0CoobP02ooonfX@oomi00;o0?ld
0ol0obh6o`3oCPWooo]Z0ol0R?l2o`2Yo`Wooo]Z00Go00CooookJ_oonf[ooo]Zo`3Do`0CoookJP;o
oh404?oonfX00ooob@3ooo]ZoookJP0:oookJP03oomG0?oonf[ooo]Z00[ooo]Z00Coj`3ooookJ_oo
nf[o0?l50ooonfX00ooo_P3ooo]ZoookJP1CoookJP06ooo:0?oonf[ooo]Zo`3o6ooonf[o08ko2ooo
nfX01_mho`3ooo]ZoookJ_l0g?oooo]Zocoo00Cooo]Z00So02[ooookJ_oonf[ooo]ZoomB0?l0oc?o
oo]ZokWo017ooo]Z00?o07?ooookJ_oonfX05OoonfX00ooo0>[ooo]ZoookJP06oookJP03oolF0?oo
TP3ooo]Z00?ooo]Z00?oo`3loookJ_oonfX00ooonfX00olH0?ooo`H0oookJP02oookJP06on_o0?oo
0?Kooo]Zo`2Voooonf[oZ03o0ooonfX00ooo0?Wooo]Zo`1go`02oookJP05oom/0?l0olcooh40oook
J_lko`000ooonfX00ol0nooooo]ZoookJP02oookJP07ool30?oonf[oo`3MogT0oooonf[o0:?ook?o
0006oookJP04ool0Qooonf[ooo]Zool0K0;ooo]Z00KoC@3oool^0?oonf[oH@3ooookJ_l0odD3oook
JP05on80ool0oi3ooo]ZoookJ_l0oi801ooonfX00omX0?oooo]ZoookJP02oookJP03oaP0ool0M?oo
oo]Z00;ooo]Z00?ooi00oookJ_oonfX02?oonfX01Ooo_P3ooo]ZoookJ_l0o`Goj`3o00Oooo]Z0_oo
E`04oookJP04o`000?oo02go0000o`0000Wooo]Z0_ooP@0>oookJP;o0=Co00?o00CooookJ_oonfX0
1?oonfX3o`2Yo`;o08So3OoonfX5o`3oCP?o0?ld4_oonfX?o`3o=0?o0?l^1_l0odh9oookJP?o08So
00?ooo]Zo`2Yool0ZOl02?oonfX2o`04o`;ooo]Z00?o0=CooookJ_oonfX04_oonfX00oooP@3ooo]Z
oookJP0?oookJP03ool0;Ooonf[ooo]Z00Wooo]Z00?ooeL0oookJ_oonfX02_oonfX01?o[0?oooo]Z
oookJ_l0o`D4oookJP03oonn0?oonf[ooo]Z02_ooo]Z000ZoookJP06ooo:0?oonf[ooo]ZoookJ_l0
oa_o08ko3?oonfX00omho`3o0=cooookJP02oookJP05ocoo0?oonf[ooo]ZoookJ_l0:_l00ooonfX0
1?l0oc?ooe80oookJ_nio`0BoookJP03o`1coooonf[ooo]Z01Cooo]Z00?oo`3ZoookJ_oonfX01_oo
nfX00ooo5P3ooo]ZoonB0003oookJP03ool0o?oonf[ooo]Z00?ooo]Z00?o603oool60?oonfX00_oo
nfX01_o[o`3oo`3foookJ_oonf[o0:KoojP0o`?ooo]Z00[oo`3ioookJ_l0Mooooo]Zooo90?l0olco
oo]Zoon10?oonf[o>ol00_oonfX00ol0nooooo]ZoookJP03oookJP07ool30?oonf[oobP0ogT0oooo
nf[o0:?ook?o0006oookJP07ool00?oonf[ooo]Zool0K?oonf[oC@3oool^0002oookJP03of40oooo
nf[o0?m500Ooo`0000?o0?nBoookJ_oonfX01?oonfX00omX0?oooo]ZoookJP02oookJP03onKo0?lH
0?oo07Co00?ooo]Z00?ooi00oookJ_oonfX02?oonfX01?oo_P3ooo]ZonGo0?oo0003onGo00?oo`00
00?ooo]ZoomG0?oonfX01?oonfX2ool0;@Co00002?oonfX00oooP@3ooo]ZoookJP0<oookJP;o0=Co
0_l01?l5oookJP;o0:Wo0_ooN@09oookJPKo0?m>00?oobP0o`3o=?l0oc@00_l0oc@6oolX00gooo]Z
3OooN@05oookJP?o0?ld0ooonfX3o`3o;P;o0?m>2_oonfX2o`28o`?o0:Wo1ooonfX2o`04o`;ooo]Z
00?o0=CooookJ_oonfX04_oonfX00oooP@3ooo]ZoookJP0>oookJP03ooo90?oonf[ooo]Z00Wooo]Z
00?ooeL0oookJ_oonfX02ooonfX00oo[0?oooo]Zo`3o1@03oookJP03oonn0?oonf[ooo]Z05;ooo]Z
00KoolX0oookJ_oonf[ooo]Zo`3o6ol0S_l<oookJP03ogSo0?oonf[o0=co00;ooo]Z00?o?ol0oook
J_oonfX00_oonfX01ol0:_oooo]ZoookJ_oonf[ooe80oookJ_nio`004_oonfX00ol0Looooo]Zoook
JP0EoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oonB0?oonfX00_oonfX00ooo0?cooo]Zoook
JP04oookJP0:ool60?oonf[ooo]ZoookJ_o[o`3ooo]Zool0m_oonf[o0:KoojP0o`Cooo]Z00Woo`3i
o`1goooonf[ooo]Zoom/0?l0olcooo]Zoon10?lko`000ooonfX00ol0nooooo]ZoookJP02oookJP07
ool30?oonf[ooo]Zool0gOoonf[o0:?ook?o0006oookJP04ool0Qooonf[ooo]Zool0K0;ooo]Z00Ko
C@3oool^0?oonf[oH@3ooookJ_l0odD3oookJP05on80ool0oi3ooo]ZoookJ_l0oi801ooonfX00omX
0?oooo]ZoookJP02oookJP03oaP0ool0M?oooo]Z00;ooo]Z00?ooi00oookJ_oonfX02?oonfX01Ooo
_P3ooo]ZoookJ_l0o`Goj`3o00Oooo]Z00?ooeL0oookJ_oonfX00ooonfX2ool0;@?o00002?oonfX0
0oooP@3ooo]ZoookJP0<oookJP;o0=Co0_l01?l5oookJP;o0:Wo0_l0R?l:oookJPKo0?m>1?l0oc@U
oookJP?o0?ld0ooonfX3o`3o;P;o0?m>2_oonfX3o`28o`?o0:Wo1ooonfX00ol01?oooo]ZoookJP02
o`3Doa?ooo]Z0_ooP@0?oookJP03ool0;Ooonf[ooo]Z00[ooo]Z00?ooeL0oookJ_oonfX02_oonfX0
0oo[0?oooo]Zo`3o1@04oookJP03oonn0?oonf[ooo]Z02_ooo]Z000]oookJP03o`3o6ooonf[o08ko
00_ooo]Z00?oN?l0ocd0ool0g?l00_oonfX00oloo`3ooo]ZoookJP02oookJP08o`0Zoooonf[ooo]Z
oookJ_l0oc?ooe80oookJ_nio`0AoookJP03o`1coooonf[ooo]Z01Cooo]Z00?oo`3ZoookJ_oonfX0
1ooonfX00ooo5P3ooi80oookJP03oookJP03ool0o?oonf[ooo]Z00?ooo]Z00_o603oool60?oonf[o
oo]Zon_o0?oonf[oo`3foookJ_l0Y_oooo]ZojP0o`03oookJP09ool0nOl0Mooooo]Zooo90?l0oi[o
0?o<oookJ_ooP@3o>ol000;ooo]Z00?o0?_ooookJ_oonfX00ooonfX01ooo0`3ooo]ZoolX0?oo:03o
oo]Zo`2Soonco`001_oonfX03?oo003ooo]ZoookJ_oo06cooo]Zodd0oooonf[oobh0oookJ_mQ0?oo
oo]Zo`3oA@;ooo]Z1Ooo00000ol0oi;ooo]ZoookJP05oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o
603oo`1doooonfX00_oonfX00oooT03ooo]ZoookJP08oookJP04oonn0?oonf[ooo]Zool000GoiOl0
00?oo`00oookJ_ooE`001OoonfX00ooo02gooo]ZoookJP04o`0000Kooo]Z0_ooP@0=oookJP;o0=Co
0_l01?l4oookJP?o0:Wo00?oogT0oookJ_oonfX01OoonfX3ooo900;o0?m>0_oo:005o`3o=0;ooo]Z
1_oo:00?oookJPSoogT03OoonfX3o`3o=0?ooo]Z0_l0obh2o`3oCP_ooo]Z0_l0R?l2o`2Yo`Oooo]Z
00?o00CooookJ_oonfX00_l0e?lCoookJP03oon10?oonf[ooo]Z00kooo]Z00?oolT0oookJ_oonfX0
2OoonfX00oooE`3ooo]ZoookJP0;oookJP03on/0oooonf[o0?l500?ooo]Z00?ookh0oookJ_oonfX0
E?oonfX00ol0oa_o4P3oo`2>o`0;oookJP06ogSo0?lm0?oooo]Zo`3Loooonf[o?ol01?oonfX00ol0
:_oooo]ZoookJP02oookJP03oomB0?oonf[o^Ol0017ooo]Z00?o07?ooookJ_oonfX05OoonfX00ooo
0>[ooo]ZoookJP06oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00?oo`3loookJ_oonfX00ooonfX00olH
0?ooo`H0oookJP02oookJP06on_o0?oo0?Kooo]Zo`2Voooonf[oZ03o0ooonfX02_oo0?Wo07Oooook
J_oonf[oof`0o`3oV_l0olcooh40oookJ_lko`02oookJP03o`3koooonf[ooo]Z00;ooo]Z00Soo`<0
oookJ_oonf[oo`3MoookJ_l0Xooo/ol0oil0o`Gooo]Z00Coo`27oookJ_oonf[oo`1/0_oonfX01_m=
0?oooo]Zool^0?mQ0?oooo]Zo`3oA@?ooo]Z00?ohP3oo`3oT?oonfX00_oonfX00ol0oi;ooo]Zoook
JP04oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603oonKo0?oonfX00_oonfX00oooT03ooo]Zoook
JP08oookJP05oonn0?oonf[ooo]Zo`3o1Oo[0?l01ooonfX00oooE`3ooo]ZoookJP03oookJP03ool0
;Ooonf[o000000?o00001_oonfX2oon100gooo]Z0_l0e?l2o`04o`Gooo]Z0_l0ZOl00ol0R?oooo]Z
oookJP07oookJPCo0?m>00?o0?l^oookJ_l0oc@00ol0oc@/oookJP?o0?ld0ooonfX2o`3o;P;o0?m>
2ooonfX3o`28o`;o0:Wo1_oonfX01Ol01?oooo]ZoookJ_oonf[o0=Co01Cooo]Z00?ooh40oookJ_oo
nfX03OoonfX00ooo02gooo]ZoookJP09oookJP03oomG0?oonf[ooo]Z00_ooo]Z00?oj`3ooookJ_l0
o`D01?oonfX00ooo_P3ooo]ZoookJP0ZoookJP00;OoonfX00ol0oa_o08kooookJP0;oookJP03ogSo
0?l0g?oooo]Z00;ooo]Z00Go?ol0oookJ_oonf[ooo]Zo`0Zo`04oookJP03oomB0?oonf[o^Ol001;o
oo]Z00?o07?ooookJ_oonfX05?oonfX00ooo0>[ooo]ZoookJP06oookJP03oolF0?oonf[ooi8000?o
oo]Z00?oo`3loookJ_oonfX00ooonfX00olH0?ooo`H0oookJP02oookJP06on_o0?oo0?Kooo]Zoook
J_l0Y_ooZ03o0ooonfX02_oo0?Wooo]Zo`1goooonf[oof`0o`3oc?oonf[ooh40oookJ_lko`02oook
JP03o`3koooonf[ooo]Z00?ooo]Z00Ooo`<0oolX0?oo:03oN@3oo`2Soonco`3oW`3o00Gooo]Z00Co
0?oNool00?oonf[oo`1/0_oonfX01_m=0?ooobh0oookJ_mQ0?oooo]Zo`3oA@?ooo]Z1Ooo0007oook
JP03ofP0oooonf[ooo]Z00;ooo]Z00?o603oo`1doooonfX00_oonfX00oooT03ooo]ZoookJP08oook
JP04oonn0?oonf[ooo]Zool000;ooo]Z1?oUo`000ooonf[ooeL0oookJP03oookJP;oo`0]0ooonfX4
o`0000Cooo]Z0_ooP@0>oookJP03o`3Doooonf[o00Co00Cooo]Z0_l0ZOl00ol0R?oooo]ZoookJP03
oookJPKoolT000?oobP0oookJ_l0oc@00ol0oc@8oookJP?oobP04OoonfX3oomi01Gooo]Z0ol0oc@2
oookJP;o0?l^0_l0odh<oookJP03o`28ool0ZOoo0:Wo00Kooo]Z00Go00CooookJ_oonf[ooo]Zo`3D
o`0CoookJP;ooh403ooonfX00ooob@3ooo]ZoookJP09oookJP03oomG0?oonf[ooo]Z00_ooo]Z00?o
j`3oo`3o1OoonfX00_oonfX00ooo_P3ooo]ZoookJP1DoookJP03o`3o6ol0S_oooo]Z00_ooo]Z00?o
N?l0oookJ_l0g?l00_oonfX00oloo`3ooo]ZoookJP02oookJP07o`0Zoooonf[ooo]ZoookJ_ooDP3o
0?lcokWo000BoookJP03o`1coooonf[ooo]Z01Gooo]Z00?oo`3ZoookJ_oonfX01_oonfX00ooo5P3o
oi80oookJP02oookJP03ool0o?oonf[ooo]Z00Cooo]Z00Koo`H0oookJ_oonf[ooo]Zon_o0?oo0?H2
oookJP03o`2VoonX0?oooo]Z00?ooo]Z00Woo`3io`1goooonf[ooo]Zoom/0?l0olcooo]Zoon10?lk
o`000ooonfX00ol0nooooo]ZoookJP02oookJP07ool30?oonf[ooo]Zool0gOl0Xooooo]Zok?o0005
oookJP04o`3og_oo08Oooo]Zool0K0?ooo]Z00GoC@3oool^0?oonf[oH@3oo`3oA@03oookJP03on80
ool0oi3ooo]Z00;ooo]Z00?o0?nBoookJ_oonfX01?oonfX00omX0?oooo]ZoookJP03oookJP05oaP0
oooonf[ooo]ZoookJ_ooT0002_oonfX01Ooo_P3ooo]ZoookJ_l0o`Goj`3o00Oooo]Z00?ooeL0oook
J_oonfX00_oonfX2ool0;@;ooo]Z1?l00004oookJP;ooh403_oonfX00ol0e?oooo]Zo`04o`04oook
JP?o0:Wo2OoonfX3o`3oCP;ooo]Z1?l0oc@coookJP?o0?ld0_oonfX2o`3o;P;o0?m>3?oonfX01?l0
R?oooo]Zo`2Yool0ZOl5oookJP;o00Co0_oonfX00ol0e?oooo]ZoookJP0BoookJP;ooh403_oonfX0
0ooo02gooo]ZoookJP09oookJP03oomG0?oonf[ooo]Z00_ooo]Z00?oj`3ooookJ_l0o`D00ooonfX0
0ooo_P3ooo]ZoookJP0ZoookJP00;?oonfX00ol0oa_o4P3oo`2>o`0;oookJP03ogSo0?lm0?oo0=co
00;ooo]Z00?o?ol0oookJ_oonfX00_oonfX02?l0:_oooo]ZoookJ_oonf[o0?lcoomB0?oonf[o^Ol0
4OoonfX00ol0Looooo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z00Oooo]Z00?ooaH0oonB0?oonfX0
0ooonfX00ooo0?cooo]ZoookJP02oookJP03oaP0oooo1P3ooo]Z00;ooo]Z00Kojol0oookJ_oo0?Ko
oo]Zo`2VoonX0?l4oookJP09ool0nOl0Mooooo]Zoom/0?l0oi[ooo]Zoon10?oonf[o>ol000;ooo]Z
00?o0?_ooookJ_oonfX00ooonfX01ooo0`3oobP0oolX0?oo:03o0:?oo`0Goonco`001_oonfX00ooo
003ooo]Zool0K002oookJP06odd0oooo;P3ooo]Zof40oooonf[o0?m50ooonfX00ooo003ooo]Zo`3o
T003ool000Kooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?oo07CooookJP02oookJP03oon@0?oo
nf[ooo]Z00Sooo]Z00Cookh0oookJ_oonf[oo`001?oonfX3onGo0003oomG0?oonf[ooo]Z00;ooo]Z
00?oo`0]oookJ_oonfX00ooonfX4o`0000;ooo]Z0_oo000>oookJP;o0=Co0_l01?l2oookJP?o0:Wo
00?o08SooookJ_oonfX02_oob@03o`3o=0cooo]Z00?oobP0oookJ_oonfX0;?oonfX3o`3o=003oook
J_l0obko0?l^00;o0?m>2ooonfX01?l0R?oooo]Zo`2Yool0ZOl5oookJP;o00Co0_oonfX00ol0e?oo
oo]ZoookJP0BoookJP03oon10?oonf[ooo]Z00cooo]Z00?oolT0oookJ_oonfX00_oonfX2ooo900Go
oo]Z00?ooeL0oookJ_oonfX02ooonfX00oo[0?ooL03oo`3o1@03oookJP03oonn0?oonf[ooo]Z05;o
oo]Z00?o0?lKoa80ool0S_l02ooonfX01_mho`3o?@3ooookJ_l0g?oooo]Zocoo00Gooo]Z00Oo02[o
oookJ_oonf[ooo]ZoomB0?oonf[o^Ol0017ooo]Z00?o07?ooookJ_oonfX05OoonfX00ooo0>[ooo]Z
oookJP06oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00?oo`3loookJ_oonfX00ooonfX02_oo1P3ooo]Z
oookJ_oonf[ojol0oookJ_oo0?Kooo]Zo`2VoonX0?l4oookJP09ool0nOl0Mooooo]ZoookJ_ooK03o
0?o<oookJ_ooP@3o>ol000?ooo]Z00?o0?_ooookJ_oonfX00_oonfX01ooo0`3ooo]ZoookJ_oo0=go
0:?ooookJ_nco`001_oonfX00ooo08Oooo]Zool0K003oookJP06odd0oooo;P3ooo]Zof40oooonf[o
0?m50ooonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Kooo]Z00?oJ03ooookJ_oonfX00ooonfX01OlH
0?oooo]ZoookJ_oonf[ooi0000[ooo]Z00Gookh0oookJ_oonf[o0?l5on/0o`07oookJP03oomG0?oo
nf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX00_oonfX4o`0000;ooo]Z0_ooP@0>oookJP;o0=Co0_l0
1?l3oookJP;o0:Wo00?o08SooookJ_oonfX01ooonfX2o`3oCP03oookJ_l0ocCo0?ld00;o0?ld>_oo
nfX3o`3o=0;ooo]Z00?o0?l^o`3oC_l0odh02ooonfX00ol0R?oooo]ZoookJP02o`2Yo`Gooo]Z00Co
00CooookJ_oonf[o0=Co5OoonfX00oooP@3ooo]ZoookJP0<oookJP03ool0;Ooonf[ooo]Z00Wooo]Z
00?ooeL0oookJ_oonfX02_oonfX00oo[0?ooL03oo`3o1@04oookJP03oonn0?oonf[ooo]Z02Wooo]Z
000/oookJP03o`3o6ol0S_oooo]Z00_ooo]Z00?oN?l0o`3LoooonfX00_oonfX00oloo`3ooo]Zoook
JP02oookJP05o`0Zoooonf[ooo]ZoookJ_ooDP000_oonfX00onio`3ooo]ZoookJP0?oookJP03o`1c
oooonf[ooo]Z01Cooo]Z00?oo`3ZoookJ_oonfX01_oonfX00ooo5P3ooi80oookJP03oookJP03ool0
o?oonf[ooo]Z00?ooo]Z00Oo603oool60?oonf[ooo]Zon_o0?oonf[oo`3f00;ooo]Z00?o0:KoojP0
oooonfX00_oonfX02Ooo0?Wo07OooookJ_oonf[oof`0o`3oc?oonf[ooh40oc_o0003oookJP03o`3k
oooonf[ooo]Z00;ooo]Z00?oo`<0oolX0?oo:0000_oo:0000ol0Xooo/ol0oookJP05oookJP0;ool0
0?oonf[ooo]Zool0K?oonf[oC@3ooookJ_oo;P3ooo]Zof40ool0odD01?oonfX01Ooo003o0?n@oook
J_oonf[oo`0000Kooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?oo07CooookJP02oookJP03oon@
0?oonf[ooo]Z00Sooo]Z00Gookh0oookJ_l007ooo`00o`00O`05oookJP03onGo0?ooE`3o001o00;o
001o00?ooo]Zool0;OoonfX01OoonfX4o`0000Coo`003?oonfX2o`3Do`;o00Co0_oonfX2o`2Yo`03
oookJ_l0R?oo08So00coolT0@_oonfX3o`3o=004oookJ_l0obko0?m>o`3oCP[ooo]Z0_l0R?l00ooo
nf[o0:Woo`2Yo`05oookJP04o`04oooonf[ooo]Zo`3DoaCooo]Z00?ooh40oookJ_oonfX03?oonfX0
0ooob@3ooo]ZoookJP03ooo900Kooo]Z00?ooeL0oookJ_oonfX02ooonfX00oo[0?ooL03ooookJP02
oookJP03oonn0?oonf[ooo]Z05;ooo]Z00?o0?lKoa80oooonfX02ooonfX00omho`3ooo]Zo`3Lo`02
oookJP03ocoo0?oonf[ooo]Z00;ooo]Z00So02[ooookJ_oonf[ooo]ZoomB0?l0oc?ooo]ZokWo017o
oo]Z00?o07?ooookJ_oonfX05OoonfX00ooo0>[ooo]ZoookJP06oookJP03oonB0?oonf[ooo]Z00;o
oo]Z00?oo`3loookJ_oonfX00ooonfX00olH0?ooo`H0oookJP02oookJP06on_o0?oo0?Kooo]Zoook
J_l0Y_ooZ03o0ooonfX00ooo0?Wo07OooookJP02oookJP05oom/0?l0olcooh40oookJ_lko`000ooo
nfX01Ol0nooooo]ZoookJ_oonf[oo`<000;ooo]Z00Goo`3MoookJ_l0Xooo/ol0oil0o`05oookJP04
ool0Qooonf[ooo]Zool0K0;ooo]Z00KoC@3ooookJ_oo;P3oH@3ooookJ_l0odD3oookJP05on80ool0
oi3ooo]ZoookJ_l0oi801_oonfX00omX0?oooo]ZoookJP03oookJP05oaP0ool0M?oooo]ZoookJ_oo
T0002_oonfX01Ooo_P3ooo]Zo`00Ool0o`Goj`3o00Gooo]Z00?o001ooomG0?ooE`000_l007l2oook
JP03ool0;Ooonf[ooo]Z00?ooo]Z1?l000000ooonf[ooh40oookJP0=oookJP;o0=Co0_l01?l3oook
JP;o0:Wo0_l0R?l8oookJP;o0?m>0ol0ocA1oookJP?o0?ld00Cooo]Zo`3o;_l0odko0?m>2_oonfX2
o`28o`;ooo]Z0_l0ZOl4oookJP;o00Co00?ooo]Zo`3Dool0e?l05?oonfX00oooP@3ooo]ZoookJP0<
oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00?ooeL0oookJ_oonfX02ooonfX00oo[0?ooL03oo`3o1@03
oookJP03oonn0?oonf[ooo]Z02Wooo]Z000[oookJP03o`3o6olB0?oo08ko00_ooo]Z00?oN?l0ocd0
ool0g?l00_oonfX00oloo`3ooo]ZoookJP02oookJP08o`0Zoooonf[ooo]ZoookJ_l0oc?ooe80oook
J_nio`0AoookJP03o`1coooonf[ooo]Z01Cooo]Z00?oo`3ZoookJ_oonfX01ooonfX00ooo5P3ooi80
oookJP03oookJP03ool0o?oonf[ooo]Z00;ooo]Z00?o603oool60?oonfX00_oonfX01_o[o`3oo`3f
oookJ_oonf[o0:KoojP0o`?ooo]Z00[oo`3ioookJ_l0Mooooo]Zoom/0?l0oi[ooo]Zoon10?oonf[o
>ol00_oonfX00ol0nooooo]ZoookJP03oookJPGoobP000?o/ol0oil0oooonfX01?oonfX01?oo003o
oo]ZoookJ_oo06`2oookJP06odd0oooo;P3ooo]Zof40oooonf[o0?m50ooonfX01Ooo003o0?n@oook
J_oonf[o0?nB00Kooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?ooi_l0oookJP02oookJP03oon@
0?oonf[ooo]Z00Sooo]Z00Cookh0oookJ_oonf[oo`000_l007l4oookJP03oomG0?l007oo001o00?o
001o00?oo`0]oookJ_oonfX01OoonfX2o`0000Goo`002ooonfX2o`3Do`04oookJ_l01?oooo]Zoook
JP;o0:Wo00?ooo]Zo`28ool0R?l00_oonfX;ooo904Kooo]Z0ol0oc@00ol0obko0?m>o`3oCP0:oook
JP03o`28oooonf[ooo]Z00;o0:Wo1?oonfX2o`04o`03oookJ_l0e?oooo]Z01?ooo]Z00?ooh40oook
J_oonfX03?oonfX6ooo900Kooo]Z00?ooeL0oookJ_oonfX02ooonfX00oo[0?oo0?l5oookJP02oook
JP03oonn0?oonf[ooo]Z053ooo]Z00?o0?lKoa80ool0S_l02ooonfX01_mho`3o?@3ooookJ_l0g?oo
oo]Zocoo00Gooo]Z00Oo02[ooookJ_oonf[ooo]ZoomB0?oonf[o^Ol0017ooo]Z00?o07?ooookJ_oo
nfX05OoonfX00ooo0>[ooo]ZoookJP06oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00?oo`3loookJ_oo
nfX00ooonfX02_oo1P3ooo]ZoookJ_oonf[ojol0oookJ_oo0?Kooo]Zo`2VoonX0?l4oookJP09ool0
nOl0Mooooo]ZoookJ_ooK03o0?o<oookJ_ooP@3o>ol000?ooo]Z00?o0?_ooookJ_oonfX00_oonfX0
1ooo0`3ooo]ZoookJ_oo0=go0:?ook?o0?nO0?l01OoonfX01?oo08Oooo]ZoookJ_oo06`3oookJP05
odd0oooo;P3oH@3ooookJ_l0odD00ooonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Oooo]Z00?oJ03o
oookJ_oonfX00_oonfX00olH0?oo07CooookJP02oookJP03oon@0?oonf[ooo]Z00Oooo]Z00Kookh0
oookJ_oonf[o0?l5on/0ool007l4oookJP03o`00OoooE`3o001o00Co001o00?oo`0]oookJ_oonfX0
1?oonfX4o`000003oon10?oonf[ooo]Z00_ooo]Z0_l0e?l01?oonf[o00CooookJ_oonfX3o`2Yo`;o
08So1ooonfX3o`3oCP03o`3o=?oonf[ooo]Z04Kooo]Z0ol0oc@00ooonf[o0?m>o`3oCP0:oookJP04
o`28oooonf[ooo]ZoookJP;o0:Wo1?oonfX01?l01?oooo]ZoookJ_l0e?lDoookJP03oon10?oonf[o
oo]Z00cooo]Z00?oo`0]oookJ_oonfX02?oonfX00oooE`3ooo]ZoookJP0;oookJP03on/0ool0o`Go
oo]Z00?ooo]Z00?ookh0oookJ_oonfX0:?oonfX002_ooo]Z00?o0?lKoa80oooonfX02ooonfX00omh
o`3o?@3ooookJP02oookJP03ocoo0?oonf[ooo]Z00;ooo]Z00Go02[ooookJ_oonf[ooo]ZoomB0002
oookJP03okWo0?oonf[ooo]Z00oooo]Z00?o07?ooookJ_oonfX05?oonfX00ooo0>[ooo]ZoookJP06
oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00?oo`3loookJ_oonfX00ooonfX01ooo1P3ooo]ZoookJ_oo
nf[ojol0oookJ_oo0?H00_oonfX00ol0Y_ooZ03ooookJP02oookJP09ool0nOl0Mooooo]ZoookJ_oo
K03o0?o<oon10?oonf[o>ol000?ooo]Z00?o0?_ooookJ_oonfX00_oonfX5oolX0003ok?o0?nO0?oo
oo]Z00Gooo]Z00?oo`00oookJ_oo06`00_oonfX01_m=0?ooobh0oookJ_mQ0?oooo]Zo`3oA@?ooo]Z
00Goo`00o`3oT?oonf[ooo]Zo`3oTP06oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603oonKo0?oo
nfX00_oonfX00oooT03ooo]ZoookJP08oookJP04oonn0?oonf[ooo]Zool000?o001o0ooonfX02?oo
E`3o001oo`00Ool007oooo]Zo`00Oooo02go001o1ooonfX6ool000[ooo]Z0_l0e?l00ooonf[o00Co
o`04o`03o`2Yo`03oookJ_l0R?oo08So00Gooo]Z2Ooob@1:oookJP?o0?ld0_l0odh9oookJP;o08So
0_oonfX2o`2Yo`Cooo]Z00Co00CooookJ_l0e?oo0=Co4_oonfX00oooP@3ooo]ZoookJP0<oookJPKo
olT01_oonfX00oooE`3ooo]ZoookJP0<oookJP05on/0oooonf[ooo]ZoookJ_oo_P00D_oonfX00ol0
oa_o4P3ooookJP0;oookJP03ogSo0?lm0?oo0=co00;ooo]Z00?o?ol0oookJ_oonfX00_oonfX02?l0
:_oooo]ZoookJ_oonf[ooe80o`3o<ooonf[o^Ol04OoonfX00ol0Looooo]ZoookJP0EoookJP03ool0
j_oonf[ooo]Z00Kooo]Z00?ooi80oookJ_oonfX00_oonfX00ooo0?cooo]ZoookJP03oookJP03ool6
0?oonf[ooo]Z00;ooo]Z00Kojol0ool0m_oonf[ooo]Zo`2VoonX0?l3oookJP03ool0nOl0Mooooo]Z
00;ooo]Z00Coof`0o`3oc?ooP@3o>ol01?oonfX01Ol0nooooo]ZoookJ_oonf[oo`<000;ooo]Z00Co
o`3MoookJ_nco`3oW`3o1_oonfX00ooo08Oooo]Zool0K003oookJP03odd0oooo;P3oH@3o00;ooo]Z
00Go0?m5oookJ_oonf[ohP3oo`3oT003oookJP03o`3oT_oonf[ooo]Z00Cooo]Z00?oJ03ooookJ_oo
nfX00_oonfX00olH0?ooi_l0oookJP02oookJP03oon@0?oonf[ooo]Z00Oooo]Z00Gookh0oookJ_oo
nf[o0?l5on/0o`02o`00O`Cooo]Z00CooeL0o`00Ool007oooo]Z0_l007l00ooo02gooo]ZoookJP05
oookJP?o000000?ooh40oookJ_oonfX02_oonfX2o`3Do`04oookJ_l01?oo00CooookJP;o0:Wo00?o
oo]Zo`28ool0R?l01ooonfX2o`3oCP03o`3o=?oonf[ooo]Z04cooo]Z0ol0oc@2o`3oCPWooo]Z0_l0
R?l3oookJP;o0:Wo0ooonfX2o`04o`03oookJ_l0e?oooo]Z01;ooo]Z00?ooh40oookJ_oonfX03?oo
nfX00ooo02gooo]ZoookJP09oookJP03oomG0?oonf[ooo]Z00_ooo]Z00?oj`3oo`3o1OoonfX00_oo
nfX00ooo_P3ooo]ZoookJP0XoookJP00:_oonfX00ol0oa_o4P3oo`2>o`0;oookJP03ogSo0?lm0?oo
0=co00;ooo]Z00?o?ol0oookJ_oonfX00_oonfX02?l0:_oooo]ZoookJ_oonf[o0?lcoomB0?oonf[o
^Ol04OoonfX00ol0Looooo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z00Oooo]Z00?ooaH0oonB0?oo
nfX00ooonfX00ooo0?cooo]ZoookJP02oookJP03oaP0oooo1P3ooo]Z00;ooo]Z00Kojol0ool0m_oo
nf[ooo]Zo`2VoonX0?l3oookJP09ool0nOoonf[o07OooookJ_ooK03o0?o<oookJ_ooP@3o>ol000?o
oo]Z00?o0?_ooookJ_oonfX00_oonfX6oolX0003ok?o0?oonf[ooo]Z00Cooo]Z00_oo`00oookJ_oo
nf[oo`1/oookJ_m=0?oooo]Zool^0?mQ0?oooo]Zo`3oA@03oookJP05ool00?oonf[o0?n@oookJ_l0
oi801_oonfX00omX0?oooo]ZoookJP02oookJP03oaP0oooVo`3ooo]Z00;ooo]Z00?ooi00o`00Ool0
07l01ol007l01_oonf[ookh0oookJ_oonf[oo`00oookJP?o001o0_oonfX01?ooE`3o001oo`00Ool0
07l2oookJP04ool0;Ol007oo001oo`00O`Cooo]Z2?oo0009oookJP04o`3Doooonf[o00Coo`04o`;o
o`000ooonfX00ol0R?oooo]ZoookJP04oookJPSoolT06_oonfX4ool000;ooo]Z1ol0o`PXoookJP;o
0?ld0_l0odh9oookJP05o`28oooonf[ooo]ZoookJ_l0ZOl01?oonfX01?l01?oooo]ZoookJ_l0e?lB
oookJP03oon10?oonf[ooo]Z00[ooo]Z2?oob@06oookJP03oomG0?oonf[ooo]Z00_ooo]Z00?oL03o
on/0oooonfX00_oonfX00ooo_P3ooo]ZoookJP1>oookJP03o`3o6olB0?oo08ko00_ooo]Z00KoN?l0
ocd0oooonf[o0=cooookJ_loo`05oookJP07o`0Zoooonf[ooo]ZoookJ_ooDP3ooo]ZokWo000Aoook
JP03o`1coooonf[ooo]Z01Gooo]Z00?oo`3ZoookJ_oonfX01_oonfX00ooo5P3ooi80oookJP03oook
JP03ool0o?oonf[ooo]Z00?ooo]Z00Koo`H0oookJ_oonf[ooo]Zon_o0?oo0?H2oookJP03o`2VoonX
0?oooo]Z00;ooo]Z00?oo`3ioookJ_l0Mol00_oonfX01OooK03o0?o<oon10?oonf[o>ol000?ooo]Z
00Go0?_ooookJ_oonf[ooo]Zool30002oookJP05ogT0oooo0=go0:?ook?o0?nO0?l01OoonfX01?oo
08Oooo]ZoookJ_oo06`2oookJP03odd0oooonf[oH@3o00;ooo]Z00Ko0?m5oookJ_oonf[ooo]Zon80
ool0oi02oookJP03o`3oT_oonf[ooo]Z00Cooo]Z00?oJ03ooookJ_oonfX00_oonfX01_lH0?ooi_l0
oookJ_oonf[o001ooon@00So001o00Kooo]Zoonn0?oonf[ooo]Zo`3o1Oo[0?l3o`00O`?ooo]Z00?o
oeL0o`00Ool007l00ooonfX00ooo02go001oo`00O`06oookJP;o000000?ooh40o`000?oonfX02_oo
nfX01Ol0e?oooo]Zo`04ool01?oooo]Z00;o0:Wo0_oonfX00ol0R?oooo]ZoookJP05oookJP;o0?m>
00?o0?ldoookJ_oonfX08ooonfX7o`3o22Oooo]Z0_l0oc@2o`3oCP03o`3o;_oonf[ooo]Z00Kooo]Z
00?o08SooookJ_oonfX00_oonfX00ol0ZOoooo]ZoookJP02oookJP03o`04oooonf[o0=Co01?ooo]Z
00?ooh40oookJ_oonfX03?oonfX00ooo02gooo]ZoookJP09oookJP03oomG0?oonf[ooo]Z00[ooo]Z
00?oL03oon/0oooonfX00ooonfX00ooo_P3ooo]ZoookJP0WoookJP00:ooonfX00olB0?oo08kooook
JP0:oookJP03ogSo0?lm0?oo0=co00;ooo]Z00?o?ol0oookJ_oonfX00_oonfX01Ol0:_oooo]Zoook
J_oonf[ooe8000;ooo]Z00?o^Ol0oookJ_oonfX03ooonfX00ol0Looooo]ZoookJP0DoookJP03ool0
j_oonf[ooo]Z00Kooo]Z00?ooaH0oonB0?oonfX00ooonfX00ooo0?cooo]ZoookJP02oookJP03oaP0
oooo1P3ooo]Z00;ooo]Z00Oojol0ool0m_oonf[ooo]Zo`2Voooonf[oZ03o00;ooo]Z00?oo`3ioook
J_l0Mol00_oonfX01OooK03o0?o<oon10?oonf[o>ol000;ooo]Z00?o0?_ooookJ_oonfX00_oonfX6
oolX0003ok?o0?oonf[ooo]Z00Cooo]Z00Coo`00oookJ_oonf[oo`1/0_oonfX01Om=0?ooobh0of40
oooonf[o0?m500Cooo]Z00Coo`00o`3oT?oonf[o0?nB1_oonfX00omX0?oooo]ZoookJP03oookJP03
oaP0oooonf[ooo]Z00;ooo]Z00?ooi00o`00Ool007l01ol007l01?oo_P3ooo]ZoookJ_oo0002oook
JP?o001o00?ooo]ZoomG0?oonfX00ol007l00ooonf[oo`0]oookJP03o`00O`;ooo]Z2Ooo00000ol0
003ooo]ZoookJP05oookJP;o0=Co00?ooo]Zo`04oooo00000ooo00000ooonf[o08Soo`28o`05oook
JP;oolT000?o0?ldoookJ_oob@001?oob@0GoookJPCo0?lM2Ooo0003o`3o7@03oookJ_l0o`So0?l8
00?o0?l83?oonfX2ool001Sooo]Z00?o0?ldo`3oC_l0odh02?oonfX01?l0R?oooo]ZoookJ_l0ZOl5
oookJP;o00Co00?ooo]Zo`3DoooonfX04OoonfX00oooP@3ooo]ZoookJP08oookJPWoolT01ooonfX0
0oooE`3ooo]ZoookJP0:oookJP03og00ooo[0?oooo]Z00;ooo]Z00?ookh0oookJ_oonfX0CooonfX0
0olB0?oo08kooookJP0:oookJP03ogSo0?lm0?oo0=co00;ooo]Z00?o?ol0oookJ_oonfX00_oonfX0
2?l0:_oooo]ZoookJ_oonf[ooe80o`3o<ooonf[o^Ol04OoonfX00ol0Looooo]ZoookJP0EoookJP03
ool0j_oonf[ooo]Z00Kooo]Z00?ooi80oookJ_oonfX00_oonfX00ooo0?cooo]ZoookJP03oookJP0;
ool60?oonf[ooo]ZoookJ_o[o`3ooo]Zool0m_oonf[o0:KooookJ_nX0?l00ooonfX02Ooo0?Wo07Oo
oookJ_oonf[oof`0o`3oV_l0olcooh40oc_o0003oookJP03o`3koooonf[ooo]Z00;ooo]Z00Ooo`<0
oookJ_oonf[oo`3Mo`2Soonco`3oW`3o00Gooo]Z00Coo`27oookJ_oonf[oo`1/0ooonfX01Om=0?oo
H@3ooookJ_oonf[o0?m500?ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP03ofP0oooonf[o
oo]Z00;ooo]Z00?o603oonKo0?oonfX00_oonfX00oooT03o001oo`00O`07o`00O`06oonn0?oonf[o
oo]Zo`3o1Oo[0?oooo]Z0ol007l2oookJP04oomG0?l007oo001oo`00O`;ooo]Z00Coo`0]o`00Ool0
07oo001o1_oonfX00ol0003ooh40o`000003o`0000Oooo]Z0_l0e?l01Ooonf[o00CooookJ_oonf[o
0:Wo00;ooo]Z0_l0R?l5oookJP?o0?m>00?o0?ldoookJ_oonfX06_oonfX@o`3o7@;ooo]Z1Ol0o`P;
oookJP;o0>7o6?oonfX01?l0ocCo0?m>o`3oC_l0obh7oookJP05o`28oooonf[ooo]ZoookJ_l0ZOl0
1OoonfX2o`04o`03o`3Doooonf[ooo]Z017ooo]Z00?ooh40oookJ_oonfX03?oonfX00ooo02gooo]Z
oookJP08oookJP03oomG0?oonf[ooo]Z00_ooo]Z00?oj`3oo`3o1OoonfX00_oonfX00ooo_P3ooo]Z
oookJP0WoookJP00:ooonfX00olB0?oooo]ZoookJP09oookJP03ooo90?mho`3o0=co00;ooo]Z00?o
?ol0oookJ_oonfX00_oonfX02?l0:_oooo]ZoookJ_oonf[o0?lcoomB0?oonf[o^Ol04OoonfX00ol0
Looooo]ZoookJP0EoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooaH0oookJ_ooTP001?oonfX00ooo
0?cooo]ZoookJP02oookJP07oaP0oooo1P3ooo]ZoookJ_o[o`3ooo]Zool0mP02oookJP03o`2VoonX
0?oooo]Z00;ooo]Z00Woo`3io`1goooonf[ooo]Zoom/0?l0olcooo]Zoon10?lko`000ooonfX01?l0
nooooo]ZoookJ_oonfX6oolX0003ok?o0?nO0?oooo]Z00Cooo]Z00Woo`00oookJ_oonf[ooo]Zool0
K?oonf[oC@3oool^0?mQ0?l00_oonfX01_l0odGooo]ZoookJ_oonf[oo`00o`3oT0;ooo]Z00?o0?nB
oookJ_oonfX01?oonfX00omX0?oooo]ZoookJP02oookJP03oaP0oooVo`3ooo]Z00;ooo]Z00?ooi00
oookJ_oonfX01ooonfX01?oo_P3ooo]ZoookJ_oo0003oookJP;o001o0_ooE`02oookJP?o001o00?o
o`0]oookJ_oonfX00ol007l:ool000Oooo]Z0_l0e?l00ooonf[o00Coo`04o`04ool000;o08So1Ooo
nfX2ooo90004o`3o=?oonf[ooo]ZoookJPCoolT04ooonfX5o`3o7@?o0?l800?ooo]Zool00?oo0000
3?oo000<o`3o7@Kooo]Z0_oo000HoookJP04o`3o=?l0odko0?m>o`3o;PKooo]Z0_l0R?l00ooonf[o
0:WooookJP05oookJP03o`04oooonf[o0=Co017ooo]Z00?ooh40oookJ_oonfX02_oonfX8ooo900Ko
oo]Z00?ooeL0oookJ_oonfX02ooonfX00om`0?ooj`3ooookJP02oookJP03oonn0?oonf[ooo]Z04ko
oo]Z00?o4P3ooookJ_oonfX02OoonfX01_l0omooN?l0oookJ_l0g?oooo]Zocoo00Gooo]Z00Oo02[o
oookJ_oonf[ooo]ZoomB0?oonf[o^Ol0017ooo]Z00?o07?ooookJ_oonfX05OoonfX00ooo0>[ooo]Z
oookJP06oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00?oo`3loookJ_oonfX00ooonfX01_oo1P3ooo]Z
oookJ_oonf[ojol0ool0mP;ooo]Z00?o0:KoojP0oooonfX00_oonfX00ooo0?Wo07OooookJP02oook
JP04oom/0?l0olcooh40oc_o00Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30002oookJP04ool0gOoo
nf[o/ol0oil0o`Gooo]Z00Goo`27oookJ_oonf[ooo]Zool0K002oookJP05odd0oomQ0?oooo]Zoook
J_l0odD00ooonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Kooo]Z00?oJ03ooookJ_oonfX00_oonfX0
0olH0?ooi_l0oookJP02oookJP03oon@0?oonf[ooo]Z00Oooo]Z00Gookh0oookJ_oonf[o0?l5on/0
o`02oookJP?o001o0_ooE`001ooonf[o001oo`00Ool007oooo]Zool0;OoonfX00ol007l5oookJP;o
oh400ol00007oookJP;o0=Co00Cooo]Zo`04ool01?oooo]Z0_l0ZOl00ooonf[o08Soo`28o`05oook
JP;o0?m>0_l0oc@IoookJPGo0?lM1?l0o`P<oookJPko0?lM1_oonfX2o`3QoaSooo]Z00?o0?ldo`3o
C_l0odh00_l0obh5oookJP;o08So0_oonfX00ol0ZOoooo]ZoookJP04oookJP03o`04ool0e?oo0=Co
017ooo]Z00?ooh40oookJ_oonfX03OoonfX00ooo02gooo]ZoookJP08oookJP03oomG0?oonf[ooo]Z
00[ooo]Z00?oL03oon/0oooonfX00ooonfX00ooo_P3ooo]ZoookJP0VoookJP00:_oonfX00olB0?oo
08kooookJP0:oookJP03ogSo0?lm0?oo0=co00;ooo]Z00?o?ol0oookJ_oonfX00_oonfX01Ol0:_oo
oo]ZoookJ_oonf[ooe8000;ooo]Z00?o^Ol0oookJ_oonfX03ooonfX00ol0Looooo]ZoookJP0Doook
JP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oonB0?oonfX00ooonfX00ooo0?cooo]ZoookJP02oook
JP03oaP0oooo1P3ooo]Z00;ooo]Z00Oojol0ool0m_oonf[ooo]Zo`2Voooonf[oZ03o00;ooo]Z00[o
o`3ioookJ_l0Mooooo]Zoom/0?l0oi[o0?o<oon10?oonf[o>ol00_oonfX01?l0nooooo]ZoookJ_oo
nfX6oolX0003ok?o0?oo:03ooo]Z00Cooo]Z00Goo`00o`3og_oonf[ooo]Zool0K002oookJP05odd0
oooo;P3oH@3ooookJ_l0odD00ooonfX01Ooo003o0?n@oookJ_oonf[o0?nB00Kooo]Z00?oJ03ooook
J_oonfX00_oonfX00olH0?ooi_l0oookJP02oookJP03oon@0?oonf[ooo]Z00Oooo]Z00Cookh0oook
J_oonf[oo`001?oonfX00ol007oooeL0o`00O`03oookJP;o001o00Coo`0]oookJ_oonf[ooo]Z0_l0
07l:ool00003o`000?oonf[ooo]Z00?ooo]Z0_l0e?l00ooonf[o00Coo`04o`05ool00003o`28oooo
nf[ooo]Z00?ooo]Z0_oob@000ol0ocCooo]ZoookJP03oookJP?oolT03ooonfX00ol0o`So0?lMo`3o
7@02o`3o7@;o0?l81ooonfX@ool000;o0?mC1OoonfX3o`3o20?o0?lM1OoonfX2ool000Kooo]Z0_oo
000?oookJP05o`3o=?oonf[o0?m>o`3oC_l0obh01_oonfX00ol0R?oooo]Zo`2Yo`06oookJP;o00Co
00?o0=CooookJ_oonfX03ooonfX00oooP@3ooo]ZoookJP0:oookJPOoolT01ooonfX00oooE`3ooo]Z
oookJP0:oookJP03og00ooo[0?oooo]Z00;ooo]Z00?ookh0oookJ_oonfX0COoonfX00olB0?oo08ko
oookJP0:oookJP06ogSo0?lm0?oooo]Zo`3Loooonf[o?ol01?oonfX02?l0:_oooo]ZoookJ_oonf[o
oe80o`3o<ooonf[o^Ol04OoonfX00ol0Looooo]ZoookJP0EoookJP03ool0j_oonf[ooo]Z00Kooo]Z
00?ooi80oookJ_oonfX00_oonfX00ooo0?cooo]ZoookJP03oookJP06ool60?oonf[ooo]ZoookJ_o[
o`3oo`3f0_oonfX00ol0Y_oooo]ZojP0o`02oookJP03ool0nOoonf[o07Oo00;ooo]Z00Goof`0oook
J_ooP@3ooo]Zoc_o0003oookJP05o`3koooonf[ooo]ZoookJ_oo0`000ooonfX01?oo0=go/ol0o`0G
oonO0?l4oookJP05ool0Qol0omkooo]ZoookJ_oo06`00ooonfX01Om=0?ooH@3ooookJ_oonf[o0?m5
00;ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP06oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603o
o`1doooVo`000_oonfX00oooT03ooo]ZoookJP07oookJP05oonn0?oonf[ooo]Zo`3o1Oo[0?l00ooo
nfX2o`00O`04oomG0?oonf[ooo]ZoookJP?o001o00?oo`0]oookJ_oonfX00ol007l4oookJP03oon1
0?oonf[o000000?o00001OoonfX2o`3Do`03oookJ_l01?oo00Co00;ooo]Z00Co0:WooookJ_l0R?oo
08So1OoonfX2o`3oCP;o0?ld5_oonfX00ol0o`So0?lMo`3o7@02o`3o7@;o0?l84?oonfX9o`3oD`Ko
oo]Z0_l0o`P3o`3o7@Gooo]Z0_l0hOlGoookJP05o`3o=?oonf[o0?m>o`3oC_l0obh01_oonfX01?l0
R?oooo]ZoookJ_l0ZOl6oookJP03o`04oooonf[o0=Co017ooo]Z00?ooh40oookJ_oonfX03OoonfX0
0ooo02gooo]ZoookJP08oookJP03oomG0?oonf[ooo]Z00[ooo]Z00?oj`3oo`3o1OoonfX00_oonfX0
0ooo_P3ooo]ZoookJP0VoookJP00:_oonfX00ol0S_oooo]ZoookJP0:oookJP05ogSo0?lm0?oo0=co
oookJ_loo`001OoonfX01Ol0:_oooo]ZoookJ_l0oc?ooe8000;ooo]Z00?o^Ol0oookJ_oonfX03_oo
nfX00ol0Looooo]ZoookJP0EoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooaH0oookJ_ooTP001?oo
nfX00ooo0?cooo]ZoookJP02oookJP07oaP0oooo1P3ooo]ZoookJ_o[o`3ooo]Zool0mP02oookJP03
o`2VoonX0?oooo]Z00;ooo]Z00Woo`3io`1goooonf[ooo]Zoom/0?l0olcooh40oookJ_lko`000ooo
nfX00ol0nooooo]ZoookJP02oookJP03ool30?oo:03oobP000;oobP000?o/ol0oolX0?oonfX01?oo
nfX01?oo003ooo]ZoookJ_oo06`2oookJP05odd0oooo;P3oH@3ooookJ_l0odD00ooonfX01Ooo003o
0?n@oookJ_oonf[o0?nB00Kooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?ooi_l0oookJP02oook
JP03oon@0?oonf[ooo]Z00Oooo]Z00Cookh0oookJ_oonf[oo`001OoonfX00oooE`3o001oo`00O`03
oookJP03o`00Oooo02go001o00?ooo]Z0_l007l:ool00003o`000?oonf[ooo]Z00;ooo]Z00Co0=Co
ool00?oo003o00Co1_oo0004oookJP?oolT000?o0?ldoookJ_oonfX01_oonfX00ooob@3ooo]Zoook
JP07oookJP?oogT01Ol0oad9oookJQ;oo`001?oonfX3o`3oD`Oooo]Z00Go0?l8o`3o7Ol0oago0?lM
o`3o2003oookJP;oo`001?oonfX3ool000oooo]Z00?o0?ldoookJ_oonfX00_l0odh6oookJP;o08So
00?o0:WooookJ_oonfX01OoonfX00ol01?oo0=CooookJP0@oookJP03oon10?oonf[ooo]Z00_ooo]Z
1_oob@07oookJP03oomG0?oonf[ooo]Z00[ooo]Z00Goj`3oo`3o1Ooonf[ooo]Zoonn001?oookJP03
o`2>oooonf[ooo]Z00[ooo]Z00GoN?l0ocd0ool0g?oooo]Zocoo0005oookJP05o`0Zoooonf[ooo]Z
oookJ_ooDP000_oonfX00onio`3ooo]ZoookJP0>oookJP03o`1coooonf[ooo]Z01Gooo]Z00?oo`3Z
oookJ_oonfX01_oonfX00ooo5P3ooi80oookJP03oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Oo603o
ool60?oonf[ooo]Zon_o0?oonf[oo`3f00;ooo]Z00?o0:KoojP0oooonfX00_oonfX00ooo0?Wo07Oo
oookJP02oookJP04oom/0?l0olcooh40oc_o00Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30002oook
JP04ool0gOoonf[o/ol0oil0o`Gooo]Z00Coo`27oookJ_oonf[oo`1/0ooonfX01Om=0?ooH@3ooook
J_oonf[o0?m500?ooo]Z00GohP3ooookJ_oonf[ooo]Zo`3oTP06oookJP03ofP0oooonf[ooo]Z00;o
oo]Z00?o603oonKo0?oonfX00_oonfX00oooT03ooo]ZoookJP06oookJP05oonn0?oonf[ooo]Zo`3o
1Oo[0?l01?oonfX00ol007oooeL0o`00O`03oookJP;o001o00Coo`0]oookJ_oonf[ooo]Z0ol007l3
oookJP03oon10?oonf[ooo]Z00Co00001?oonfX01?l0e?oooo]ZoookJ_l01?l3oookJP03o`2Yoooo
nf[o08So00Cooo]Z0ol0odh2o`3o=1Cooo]Z1Ol0oad9oookJPgo0?mC2OoonfX3o`3oD`Sooo]Z0ol0
oad2o`3o20;ooo]Z0_l0hOlFoookJP03o`3o=?oonf[ooo]Z00;o0?m>1_oonfX2o`28o`03oookJ_l0
ZOoooo]Z00Gooo]Z0_l01?l00ol0e?oooo]ZoookJP0?oookJP03oon10?oonf[ooo]Z00gooo]Z00?o
o`0]oookJ_oonfX01ooonfX00oooE`3ooo]ZoookJP0:oookJP03og00ooo[0?oooo]Z00;ooo]Z00?o
okh0oookJ_oonfX09_oonfX003Kooo]Z00?oolT0ogSo0?l0g?l00_oonfX00oloo`3ooo]ZoookJP02
oookJP08o`0Zoooonf[ooo]ZoookJ_l0oc?ooe80oookJ_nio`0AoookJP03o`1coooonf[ooo]Z01Co
oo]Z00?oo`3ZoookJ_oonfX01_oonfX00ooo5P3ooi80oookJP03oookJP03ool0o?oonf[ooo]Z00;o
oo]Z00?o603oool60?oonfX00_oonfX01oo[o`3oo`3foookJ_oonf[o0:KooookJ_nX0?l00_oonfX0
2Ooo0?Wo07OooookJ_oonf[oof`0o`3oV_l0olcooh40oc_o0003oookJP03o`3koooonf[ooo]Z00;o
oo]Z00?oo`<0oookJ_oonfX00_oo:0000onco`3oobP0oolX0004oookJP0;ool00?oonf[ooo]Zoook
J_oo06cooo]Zodd0oooo;P3oH@3ooookJ_l0odD00ooonfX01Ooo003ooo]Zo`3oT?oonf[o0?nB00Ko
oo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?ooi_l0oookJP02oookJP03oon@0?oonf[ooo]Z00Oo
oo]Z00Cookh0oookJ_oonf[oo`001OoonfX01?ooE`3o001oo`00Ool007l3oookJP03ool0;Ol007oo
001o00?ooo]Z0ol007l8ool000;o00000ooonfX01?l0e?ooo`00o`04ool01?l6ool000?ooo]Z0_oo
b@000ol0obko0?ldoookJP0;oookJPOoogT01?l0oad7oookJPOoo`001?oonfX;ool000[ooo]Z1?l0
oe<7oookJP?o0?lM0_l0o`P01?oonf[oo`00ool00?oonfX5ool000oooo]Z00Go0?ldoookJ_oonf[o
oo]Zo`3oCP07oookJP03o`28ool0ZOoooo]Z00Kooo]Z00?o00Coo`3Dool0e?l03ooonfX00oooP@3o
oo]ZoookJP0<oookJPGoolT01ooonfX00oooE`3ooo]ZoookJP0:oookJP03og00ooo[0?oooo]Z00;o
oo]Z00?ookh0oookJ_oonfX0F?oonfX01_l0omooN?l0oookJ_l0g?oooo]Zocoo00Gooo]Z00Oo02[o
oookJ_oonf[ooo]ZoomB0?oonf[o^Ol0017ooo]Z00?o07?ooookJ_oonfX05OoonfX00ooo0>[ooo]Z
oookJP05oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00?oo`3loookJ_oonfX00ooonfX01_oo1P3ooo]Z
oookJ_oonf[ojol0ool0mP;ooo]Z00?o0:KooookJ_nX0?l00_oonfX00ooo0?Wo07OooookJP02oook
JP04oom/0?oonf[ooh40oc_o00Cooo]Z00Go0?_ooookJ_oonf[ooo]Zool30002oookJP04ogT0oooo
0=go/ol0oil0o`Gooo]Z00Goo`27oookJ_oonf[ooo]Zool0K002oookJP05odd0oomQ0?oooo]Zoook
J_l0odD00ooonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Kooo]Z00?oJ03ooookJ_oonfX00_oonfX0
0olH0?ooi_l0oookJP02oookJP03oon@0?oonf[ooo]Z00Kooo]Z00Gookh0oookJ_oonf[ooo]Zon/0
o`05oookJP03oomG0?l007oo001o00?ooo]Z00?o001oool0;Ol007l00ooonfX3o`00O`;ooo]Z00Co
oh40oookJ_oonf[ooo]Z1?l00003oookJP04o`3Doooonf[o00Coo`04o`;ooo]Z0_l0ZOl2o`28o`?o
oo]Z0_l0odh2o`3o;P03o`3o=?oonf[ooo]Z013ooo]Z1?l0oad7oookJPOo0?mC6OoonfX4o`3oD`Oo
oo]Z0ol0oad3o`3o20;o0>7o5OoonfX01Ol0ocCooo]ZoookJ_oonf[o0?m>00Oooo]Z00?o08Sooook
J_l0ZOl01ooonfX00ol01?oo0=CooookJP0?oookJP03oon10?oonf[ooo]Z00gooo]Z00?oo`0]oook
J_oonfX02?oonfX00oooE`3ooo]ZoookJP09oookJP03og00ooo[0?oo0?l500?ooo]Z00?ookh0oook
J_oonfX09OoonfX003Kooo]Z00GoN?l0ocd0ool0g?oooo]Zocoo0005oookJP05o`0Zoooonf[ooo]Z
o`3o<oooDP000_oonfX00onio`3ooo]ZoookJP0>oookJP03o`1coooonf[ooo]Z01Gooo]Z00?oo`3Z
oookJ_oonfX01OoonfX00ooo5P3ooo]ZoonB0004oookJP07ool0o?oonf[ooo]ZoookJ_lH0?oooo]Z
ool60002oookJP03on_o0?oo0?Kooo]Z00;ooo]Z00Oo0:KoojP0oooonf[ooo]Zool0nOoonf[o07Oo
00;ooo]Z00Goof`0o`3oc?ooP@3ooo]Zoc_o0003oookJP05o`3koooonf[ooo]ZoookJ_oo0`000_oo
nfX01Ooo:03oN@3oo`2Soonco`3oobP000Cooo]Z00Goo`00omgo0?oonf[ooo]Zool0K002oookJP05
odd0oooo;P3oH@3ooookJ_l0odD00ooonfX01?oo003o0?n@oookJ_l0oi86oookJP03ofP0oooonf[o
oo]Z00;ooo]Z00?o603oo`1doooVo`000_oonfX00oooT03ooo]ZoookJP07oookJP04oonn0?oonf[o
oo]Zool000Cooo]Z00?o001ooomG0?l007l00ol007l2oookJP04ool0;Ol007oo001oo`00O`?ooo]Z
0ol007l00ooonf[oo`00ool00004ool000?o00000_oonfX00ol0e?oo00Coo`04o`07ool000;ooo]Z
00?o0?m>ooo90?l0obh00_l0oc@9oookJPKoogT01Ol0oad3oomi01?ooo]Z2?oo000AoookJPCo0?mC
1_oonfX3o`3o7@03o`3o2?oonf[oo`0000Koo`003ooonfX01Ol0ocCooo]ZoookJ_l0odko0?l^00Oo
oo]Z00?o08Soo`2YoooonfX01_oonfX00onDo`3ooo]Zo`3Do`0?oookJP03oon10?oonf[ooo]Z00go
oo]Z1?oob@07oookJP03oomG0?oonf[ooo]Z00[ooo]Z00Goj`3oo`3o1Ooonf[ooo]Zoonn001Joook
JP05ogSo0?lm0?oooo]Zo`3Looloo`001OoonfX01Ol0:_oooo]ZoookJ_oonf[ooe8000;ooo]Z00?o
^Ol0oookJ_oonfX03_oonfX00ol0Looooo]ZoookJP0EoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?o
oaH0oonB0?oonfX00ooonfX00ooo0?cooo]ZoookJP02oookJP06oaP0oooo1P3ooo]ZoookJ_o[o`3o
o`3f0ooonfX01ol0Y_ooZ03ooookJ_oonf[oo`3ioookJ_l0Mol00ooonfX01?ooK03ooh40oookJ_lk
o`04oookJP04o`3koooonf[ooo]Zool300?ooo]Z00Coo`3Mo`2Soonco`3oW`3o1?oonfX01Ooo08Oo
gOl0oookJ_oonf[oo`1/00?ooo]Z00CoC@3oof40oooonf[o0?m50ooonfX01OoR0?oo0?n@oookJ_oo
nf[o0?nB00Kooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?ooi_l0oookJP02oookJP03oon@0?oo
nf[ooo]Z00Kooo]Z00Gookh0oookJ_oonf[ooo]Zon/0o`03oookJP;o001o00CooeL0o`00Ool007oo
001o0ooonfX00ooo02go001oo`00O`03oookJP?o001o00?ooo]Zoon10?oonfX00ooonfX4o`0000;o
oo]Z00?o0=Coo`04ool01?l00ooonfX00ol0ZOoo08Soo`28o`03oookJP;o0?m>0_l0obh2o`3o=0ko
oo]Z1Ol0oad00ol0o`Sooo]ZoookJP0/oookJPCo0?mC1_oonfX3o`3o7@;o0?l80_l0hOlDoookJP05
o`3o=?oonf[ooo]Zo`3oC_l0obh01ooonfX00ol0R?oooo]Zo`2Yo`07oookJP03o`04ool0e?oo0=Co
00oooo]Z00?ooh40oookJ_oonfX03OoonfX00ooo02gooo]ZoookJP08oookJP03oomG0?oonf[ooo]Z
00Wooo]Z00?oL03oon/0oooonfX00_oonfX00ooo_P3ooo]ZoookJP0UoookJP00=OoonfX01_oob@3o
N?l0ocd0ool0g?oooo]Zocoo00Cooo]Z00So02[ooookJ_oonf[ooo]Zo`3o<oooDP3ooo]ZokWo017o
oo]Z00?o07?ooookJ_oonfX05?oonfX00ooo0>[ooo]ZoookJP06oookJP03oolF0?ooTP3ooo]Z00?o
oo]Z00?oo`3loookJ_oonfX00_oonfX01olH0?oooo]Zool60?oonf[ojol0oookJ_oo0?H00_oonfX0
0ol0Y_oooo]ZojP0o`02oookJP09ool0nOl0Mooooo]ZoookJ_ooK03ooo]Zoon10?oonf[o>ol000?o
oo]Z00?o0?_ooookJ_oonfX00_oonfX02?oo0`3ooo]ZoookJ_oo:03ooo]Zok?o0?oonf[oobP00ooo
nfX00ooo003o0?oNoookJP02oookJP07ool0K?oonf[oC@3oool^0?mQ0?oooo]Zo`3oA@03oookJP05
ool00?l0oi3ooo]ZoookJ_l0oi801OoonfX00omX0?oooo]ZoookJP02oookJP03oaP0ool0M?ooi_l0
00;ooo]Z00?ooi00oookJ_oonfX01ooonfX01?oo_P3ooo]ZoookJ_oo0005oookJP03oomG0?l007oo
001o00?o001o00Cooo]Zool0;Ooonf[ooo]Z0ol007l01?oonf[o001oo`00Ool007l2ool00003oook
J_oo003oo`0000?oo`000ol00002o`3Do`03o`04oooo003oo`0000Ooo`0000?ooo]Zo`3oC_l0obh0
0_l0oc@;oookJP?oogT00ol0oad6oomi01Gooo]Z1Ooo000HoookJP?o0?mC1_oonfX2o`3o7@Soo`00
3ooonfX01Ol0ocCooo]ZoookJ_l0odko0?l^00Oooo]Z00?o08Soo`2YoooonfX01OoonfX01?nDo`3o
oo]ZoookJ_l0e?l?oookJP03oon10?oonf[ooo]Z00gooo]Z0ooob@08oookJP03oomG0?oonf[ooo]Z
00Wooo]Z00?oL03oon/0oooonfX00_oonfX00ooo_P3ooo]ZoookJP1FoookJP06o`3ogomho`3o?@3o
o`3Loooonf[o?ol01OoonfX01ol0:_oooo]ZoookJ_oonf[ooe80oookJ_nio`004OoonfX00ol0Looo
oo]ZoookJP0EoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooaH0oonB0?oonfX00ooonfX00ooo0?co
oo]ZoookJP03oookJP06oaP0oooo1P3ooo]ZoookJ_o[o`3oo`3f0_oonfX00ol0Y_oooo]ZojP0o`02
oookJP03ool0nOl0Mooooo]Z00;ooo]Z00Coof`0oookJ_ooP@3o>ol01?oonfX01Ol0nooooo]Zoook
J_oonf[oo`<000;ooo]Z00Coo`3MoookJ_nco`3oW`3o1?oonfX00ooo08Oo0?oNoookJP02oookJP05
ool0K?oonf[ooo]Zodd0oomQ0?l00_oonfX01Ol0odGooo]ZoookJ_oonf[ohP3o00;ooo]Z00?o0?nB
oookJ_oonfX01?oonfX00omX0?oooo]ZoookJP02oookJP03oaP0oooVo`3ooo]Z00;ooo]Z00?ooi00
oookJ_oonfX01_oonfX01Ooo_P3ooo]ZoookJ_oonf[oj`3o00Cooo]Z00?o001ooomG0?l007l00ol0
07l2oookJP03ool0;Ooonf[o001o00;o001o00Cooo]Zo`00Ool007oo001o0_ooP@05oookJPCo0000
0_l0e?l01?l01?oooo]ZoookJ_oonfX2o`2Yo`03o`28oooonf[ooo]Z00;ooo]Z00?o0?m>o`3o;_l0
obh00_l0oc@=oookJP?o0?lM00?ooo]Zo`3o2?l0o`P0=OoonfX3o`3oD`Kooo]Z0_l0oad00ol0o`So
oo]Zo`3Qo`02o`3Qoa;ooo]Z00Go0?ldoookJ_oonf[o0?m>o`3o;P07oookJP;o08So00?o0:Wooook
J_oonfX01?oonfX01?l01?oooo]ZoookJ_l0e?l?oookJP03oon10?oonf[ooo]Z00gooo]Z00?oo`0]
oookJ_oonfX02?oonfX00oooE`3ooo]ZoookJP08oookJP03og00ooo[0?oo0?l500?ooo]Z00?ookh0
oookJ_oonfX09?oonfX003Gooo]Z00?oolT0ogSo0?l0g?l00_oonfX00oloo`3ooo]ZoookJP02oook
JP05o`0Zoooonf[ooo]Zo`3o<oooDP000_oonfX00onio`3ooo]ZoookJP0>oookJP03o`1coooonf[o
oo]Z01Gooo]Z00?oo`3ZoookJ_oonfX01OoonfX00ooo5P3ooi80oookJP04oookJP07ool0o?oonf[o
oo]ZoookJ_lH0?oooo]Zool60002oookJP03on_o0?oo0?Kooo]Z00;ooo]Z00Ko0:KoojP0oooonf[o
oo]Zool0nOl0Mol3oookJP04oom/0?l0olcooh40oc_o00?ooo]Z00?o0?_ooookJ_oonfX00_oonfX0
1ooo0`3ooo]ZoookJ_oo:03ooo]Zok?o0?nO0?l01OoonfX02ol0omkooo]ZoookJ_oonf[oo`1/oook
J_m=0?ooobh0oookJ_mQ0?oo0?m500?ooo]Z00Goo`00o`3oT?oonf[ooo]Zo`3oTP05oookJP03ofP0
oooonf[ooo]Z00;ooo]Z00?o603oo`1doooVo`000_oonfX00oooT03ooo]ZoookJP07oookJP04oonn
0?oonf[ooo]Zool000Kooo]Z00?ooeL0oookJ_l007l00ol007l01?oo02gooo]ZoookJ_oonfX6o`00
O`03ool00?oonf[ooo]Z00;ooo]Z0ooo0003o`000004o`3Dool01?oo00CooookJPSoo`000_l0odh2
o`3o=0kooo]Z0_l0oad8oomi01Kooo]Z0_oo000NoookJPCo0?mC1?oonfX3o`3o7@Ooo`003_oonfX2
o`3o=003oookJ_l0odko0?l^00Sooo]Z00?o0:WooookJ_oonfX01?oonfX01?nDo`3ooo]ZoookJ_l0
e?l?oookJP03oon10?oonf[ooo]Z00gooo]Z0ooob@07oookJP03oomG0?oonf[ooo]Z00Wooo]Z00?o
L03oon/0ool0o`D00_oonfX00ooo_P3ooo]ZoookJP1FoookJP06o`3ogomho`3ooo]Zo`3Loooonf[o
?ol01?oonfX01Ol0:_oooo]ZoookJ_oonf[ooe8000;ooo]Z00?o^Ol0oookJ_oonfX03_oonfX00ol0
Looooo]ZoookJP0EoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooi80oookJ_oonfX00ooonfX00ooo
0?cooo]ZoookJP02oookJP06oaP0oooo1P3ooo]ZoookJ_o[o`3oo`3f0ooonfX01_l0Y_ooZ03ooook
J_oonf[oo`3io`1go`?ooo]Z00Co0?nJoom/0?ooP@3o>ol01?oonfX01Ol0nooooo]ZoookJ_oonf[o
o`<000;ooo]Z00CoN@3oool0gOl0Xooo/ol01OoonfX01Ol0omkooo]ZoookJ_oonf[oo`1/00;ooo]Z
00GoC@3oool^0?mQ0?oooo]Zo`3oA@03oookJP04on80oooonf[ooo]Zo`3oTPKooo]Z00?oJ03ooook
J_oonfX00_oonfX00olH0?oo07CoonKo0002oookJP03oon@0?oonf[ooo]Z00Kooo]Z00Gookh0oook
J_oonf[ooo]Zon/0o`06oookJP03oomG0?l007oo001o00;o001o0_oo02d2oookJPKo001o00?ooh40
oookJ_oonfX01OoonfX3o`000003o`3Dool01?oo00Co00?ooo]Z00?o0:Woo`28oooonfX01?oonfX0
1?l0odko0?l^o`3o=?l0oc@=oookJP;o0?lM00Cooo]Zo`3o2?l0o`So0?l8>_oonfX4o`3oD`Cooo]Z
0ol0oad2oookJP;o0>7o4OoonfX2o`3o=003oookJ_l0odko0?l^00Sooo]Z00?o08Soo`2YoooonfX0
1OoonfX01?l01?oooo]ZoookJ_l0e?l>oookJP03oon10?oonf[ooo]Z00kooo]Z00?oo`0]oookJ_oo
nfX01ooonfX00oooE`3ooo]ZoookJP09oookJP03on/0ool0o`Gooo]Z00;ooo]Z00?ookh0oookJ_oo
nfX09?oonfX003Cooo]Z00KoolT0ogSo0?lm0?oo0=cooookJ_loo`04oookJP06o`0Zoooonf[ooo]Z
oookJ_l0oc?ooe800_oonfX00onio`3ooo]ZoookJP0>oookJP03o`1coooonf[ooo]Z01Cooo]Z00?o
o`3ZoookJ_oonfX01_oonfX00ooo5P3ooi80oookJP03oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Oo
603ooookJ_oo1P3ooo]Zon_o0?oonf[oo`3f00;ooo]Z00Oo0:KooookJ_nX0?oooo]Zool0nOoonf[o
07Oo00;ooo]Z00Goof`0o`3oc?ooP@3ooo]Zoc_o0003oookJP05o`3koooonf[ooo]ZoookJ_oo0`00
0ooonfX00ooo:03o01Oook?o0005oookJP05o`3og_oonf[ooo]ZoookJ_oo06`00_oonfX01?m=0?oo
obh0of40ool0odD3oookJP05ool00?l0oi3ooo]ZoookJ_l0oi801_oonfX01omX0?oooo]ZoookJ_oo
nf[o603oo`1doooVo`000_oonfX00oooT03ooo]ZoookJP07oookJP04oonn0?oonf[ooo]Zool000Ko
oo]Z00CooeL0oookJ_oonf[ooo]Z0_l007l00ooo02gooo]ZoookJP03oookJPCo001o00?oo`00oook
J_oonfX01?oonfX01_oo003ooo]Zo`000?l0003o0=Coo`04o`?ooo]Z1ooo00000ol0odko0?ldo`3o
=00>oookJP;o0?lM2?ooN@0DoookJP[oo`1i7_oonfX3o`3oD`04oookJ_oo003oo`00ool000?o0?lM
1Ooo000?oookJP04o`3o=?oonf[o0?m>o`3o;PSooo]Z00?o0:Woo`28oooonfX01?oonfX01?nDo`3o
oo]ZoookJ_l0e?l>oookJP03oon10?oonf[ooo]Z00oooo]Z00?oolT0oookJ_oonfX01_oonfX00ooo
E`3ooo]ZoookJP09oookJP03on/0ool0o`Gooo]Z00;ooo]Z00?ookh0oookJ_oonfX0E?oonfX01_l0
omooN?l0ocd0oooonf[o0=coocoo00Gooo]Z00Go02[ooookJ_oonf[ooo]ZoomB0002oookJP03okWo
0?oonf[ooo]Z00kooo]Z00?o07?ooookJ_oonfX05OoonfX00ooo0>[ooo]ZoookJP05oookJP03oolF
0?ooTP3ooo]Z00?ooo]Z00?oo`3loookJ_oonfX00_oonfX01olH0?oooo]Zool60?oonf[ojol0oook
J_oo0?H00_oonfX00ol0Y_oooo]ZojP0o`02oookJP03ool0nOl0Mooooo]Z00;ooo]Z00Coof`0oon1
0?oonf[o>ol01?oonfX01?l0nooooo]ZoookJ_oo0`03oookJP04ool0gOoonf[o/ol0oil0o`Cooo]Z
00Go0?oNoookJ_oonf[ooo]Zool0K003oookJP04odd0oomQ0?oooo]Zo`3oA@?ooo]Z00GohP3ooook
J_oonf[ooo]Zo`3oTP05oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603oo`1doooVo`000_oonfX0
0oooT03ooo]ZoookJP06oookJP05oonn0?oonf[ooo]ZoookJ_o[0?l01_oonfX00oooE`3ooo]Zoook
JP02o`00O`03ool0;Ooonf[ooo]Z00?ooo]Z1?l007l00oooP@3ooo]ZoookJP06oookJP;o000000?o
0=Coo`04oooonfX00_oonfX2o`2Yo`03o`28oooonf[ooo]Z00;ooo]Z0_l0odh2o`3o=0gooo]Z0_l0
oad00ooonf[o0?l8o`3o200JoookJP[oo`1i7OoonfX3o`3oD`Cooo]Z0ol0oad00ooonf[o0>7oo`3Q
o`0AoookJP04o`3o=?oonf[o0?m>o`3o;PSooo]Z00?o08Soo`2YoooonfX01OoonfX01?l01?oooo]Z
oookJ_l0e?l>oookJP03oon10?oonf[ooo]Z00kooo]Z00?oo`0]oookJ_oonfX01ooonfX00oooE`3o
oo]ZoookJP08oookJP03og00ooo[0?oo0?l500?ooo]Z00?ookh0oookJ_oonfX08ooonfX003Cooo]Z
00KoolT0ogSo0?oonf[o0=cooookJ_loo`04oookJP05o`0Zoooonf[ooo]Zo`3o<oooDP000_oonfX0
0onio`3ooo]ZoookJP0?oookJP03o`1coooonf[ooo]Z01Cooo]Z00?oo`3ZoookJ_oonfX01OoonfX0
0ooo5P3ooi80oookJP04oookJP07ool0o?oonf[ooo]ZoookJ_lH0?oooo]Zool60002oookJP07on_o
0?oo0?Kooo]ZoookJ_l0Y_oooo]ZojP0o`02oookJP03ool0nOl0Mooooo]Z00;ooo]Z00Coof`0oon1
0?oonf[o>ol00ooonfX00ol0nooooo]ZoookJP02oookJP06ool30?oonf[ooo]ZoolX0?oonf[o/ol0
1_oonfX02ol0omkooo]ZoookJ_oonf[oo`1/oookJ_m=0?ooobh0of40oooonf[o0?m500?ooo]Z00Co
o`00o`3oT?oonf[o0?nB1_oonfX02?mX0?oooo]ZoookJ_oonf[o603oo`1doooonf[oi_l00_oonfX0
0oooT03ooo]ZoookJP06oookJP04oonn0?oonf[ooo]Zool000Kooo]Z00?ooeL0oookJ_oonfX00ooo
nfX00ooo02gooo]ZoookJP07oookJP03ool00?oonf[ooo]Z00Oooo]Z00Co0000o`3Dool01?oo0000
0_oonfX00ooo003o08Soool00003ool000;o0?m>00?o0?ldool00?oonfX03?oonfX2o`3o7@WoogT0
3ooonfX6ool0N@[ooo]Z3Ooo07TDoookJP03o`3oDooo:03oobP000Coo`000ol0oad3ool000oooo]Z
00Co0?ldoookJ_l0odko0?l^2?oonfX00ol0ZOoo08SooookJP04oookJP04oiCo0?oonf[ooo]Zo`3D
o`kooo]Z00?ooh40oookJ_oonfX03ooonfX00ooob@3ooo]ZoookJP06oookJP03oomG0?oonf[ooo]Z
00Sooo]Z00?oL03oon/0ool0o`D00_oonfX00ooo_P3ooo]ZoookJP1DoookJP06o`3ogomho`3ooo]Z
o`3Loooonf[o?ol01?oonfX01Ol0:_oooo]ZoookJ_oonf[ooe8000;ooo]Z00?o^Ol0oookJ_oonfX0
3ooonfX00ol0Looooo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooi80oookJ_oonfX0
0ooonfX00ooo0?cooo]ZoookJP02oookJP06oaP0oooo1P3ooo]ZoookJ_o[o`3oo`3f0_oonfX00ol0
Y_oooo]ZojP0o`02oookJP03ool0nOl0Mooooo]Z00;ooo]Z00Coof`0oookJ_ooP@3o>ol01?oonfX0
1Ol0nooooo]ZoookJ_oonf[oo`<000;ooo]Z00CoN@3oool0gOnco`3oW`3o1OoonfX01Ol0omkooo]Z
oookJ_oonf[oo`1/00;ooo]Z00CoC@3oof40oooonf[o0?m50ooonfX01OoR0?oo0?n@oookJ_oonf[o
0?nB00Kooo]Z00OoJ03ooookJ_oonf[ooo]ZoaP0ool0M?ooi_l000;ooo]Z00?ooi00oookJ_oonfX0
1_oonfX01Ooo_P3ooo]ZoookJ_oonf[oj`3o00Kooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02go
oo]ZoookJP07oookJP03oon10?oonf[ooo]Z00Oooo]Z00Co0000o`3Dool01?oo00000_oonfX00ol0
ZOoo08SooookJP04oookJP03o`3oC_l0ocCo0?ld00gooo]Z0_l0oad3o`3o21Kooo]Z1_oo07T:oook
JPcoo`1i5?oonfX3o`3oD`?ooo]Z00Co0?l8o`3o7Ol0oago0?lM0_l0hOl@oookJP04o`3o=?oonf[o
0?m>o`3o;PWooo]Z00?o0:WooookJ_oonfX00ooonfX01Ol01?oooo]ZoookJ_oonf[o0=Co00kooo]Z
00?ooh40oookJ_oonfX03_oonfX00ooo02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z00Sooo]Z
00?oj`3oo`3o1OoonfX00_oonfX00ooo_P3ooo]ZoookJP0SoookJP00<ooonfX01?oob@3ooo]ZogSo
0?l0g?l2oookJP03ocoo0?oonf[ooo]Z00;ooo]Z00Go02[ooookJ_oonf[o0?lcoomB0002oookJP03
okWo0?oonf[ooo]Z00kooo]Z00?o07?ooookJ_oonfX05?oonfX00ooo0>[ooo]ZoookJP06oookJP03
oolF0?ooTP3ooo]Z00?ooo]Z00Goo`3loookJ_oonf[ooo]ZoaP0o`02oookJP04ool60?oonf[ojol0
ool0mP?ooo]Z00Ko0:KooookJ_nX0?oooo]Zool0nOl0Mol3oookJP04oom/0?l0olcooh40oc_o00Co
oo]Z00Go0?_ooookJ_oonf[ooo]Zool30002oookJP04oolX0?oonf[o0:?ook?o00Gooo]Z00_o0?oN
oookJ_oonf[ooo]Zool0K?oonf[oC@3oool^0?oonf[oH@3oo`3oA@03oookJP04ool00?l0oi3ooo]Z
o`3oTPKooo]Z00SoJ03ooookJ_oonf[ooo]ZoaP0ool0M?oooo]ZonKo00;ooo]Z00?ooi00oookJ_oo
nfX01_oonfX01?oo_P3ooo]ZoookJ_oUo`06oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oook
J_oonfX01ooonfX00ooo003ooo]ZoookJP07oookJP;o0=Co00?o00Coo`000?l000000_oo0002oook
JP?oo`0000Co0?m>o`3o=?oo003oo`003?oonfX2o`3o7@;oogT00ooonfX5oomi00Wooo]Z1ooo07TM
oookJP;oo`1i0_oo0003ool0NA3ooo]Z00?oobP0ool00?oo00001?oo0002o`3o7@;oo`003ooonfX0
1?l0ocCooo]Zo`3oC_l0obh8oookJP03o`2Yool0R?oooo]Z00?ooo]Z00CoU?l0oookJ_oonf[o0=Co
3ooonfX00oooP@3ooo]ZoookJP0>oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX0
2?oonfX00oo[0?oo0?l5oookJP02oookJP03oonn0?oonf[ooo]Z05;ooo]Z00Oo0?oOoookJ_mho`3o
oo]Zo`3Loooonf[o?ol000Cooo]Z00Go02[ooookJ_oonf[ooo]ZoomB0002oookJP03okWo0?oonf[o
oo]Z00kooo]Z00?o07?ooookJ_oonfX05OoonfX00ooo0>[ooo]ZoookJP05oookJP03oolF0?ooTP3o
oo]Z00?ooo]Z00?oo`3loookJ_oonfX00_oonfX01_lH0?oooo]Zool60?oonf[ojol0ool0mP?ooo]Z
00Ko0:KooookJ_nX0?oooo]Zool0nOl0Mol4oookJP03oom/0?ooP@3o>ol000Gooo]Z00Co0?_ooook
J_oonf[oo`<00_oonfX01?mi0?ooo`3Mo`2Soonco`05oookJP05o`3og_oonf[ooo]ZoookJ_oo06`0
0_oonfX01Om=0?ooobh0of40oooonf[o0?m500?ooo]Z00CohP3ooookJ_oonf[o0?nB1_oonfX01omX
0?oooo]ZoookJ_oonf[o603oo`1doooVo`000ooonfX00oooT03ooo]ZoookJP05oookJP05oonn0?oo
nf[ooo]ZoookJ_m`0?l01_oonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Oooo]Z
00?ooh40oookJ_oonfX01ooonfX2o`3Do`05o`04ool0003o0000oookJ_l0ZOl01OoonfX2o`3oCP03
o`3o=?oonf[ooo]Z00_ooo]Z0_l0oad2o`3o21;ooo]Z1ooo07TLoookJPOoo`1i4?oonfX00ol0oe?o
oo]ZoookJP02oookJP;o0?l80_l0oad2o`3Qo`oooo]Z00Co0?ldoookJ_l0odko0?l^2OoonfX00ol0
ZOoooo]ZoookJP03oookJP04o`04oooonf[ooo]Zo`3Do`kooo]Z00?ooh40oookJ_oonfX03_oonfX0
0ooo02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z00Sooo]Z00?oL03oon/0ool0o`D00ooonfX0
0ooo_P3ooo]ZoookJP0RoookJP00<ooonfX01_oob@3oN?l0ocd0ool0g?oooo]Zocoo00Cooo]Z00Go
02[ooookJ_oonf[o0?lcoomB0002oookJP03okWo0?oonf[ooo]Z00oooo]Z00?o07?ooookJ_oonfX0
5?oonfX00ooo0>[ooo]ZoookJP05oookJP03oolF0?ooTP3ooo]Z00Cooo]Z00_oo`3loookJ_oonf[o
oo]ZoaP0oooonf[oo`H0oookJ_o[o`3ooo]Zool0mP02oookJP03o`2Voooonf[oZ03o00;ooo]Z00?o
o`3io`1goooonfX00_oonfX01?ooK03ooh40oookJ_lko`03oookJP05o`3koooonf[ooo]ZoookJ_oo
0`000ooonfX00ooo:03o01Oook?o0005oookJP05o`3og_oonf[ooo]ZoookJ_oo06`00_oonfX01?m=
0?ooobh0of40ool0odD3oookJP04ool00?l0oi3ooo]Zo`3oTPKooo]Z00?oJ03ooookJ_oonfX00_oo
nfX00olH0?oooo]ZonKo0002oookJP03oon@0?oonf[ooo]Z00Oooo]Z00?ookh0oookJ_oUo`001_oo
nfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX01ooo
nfX00ol0e?oooo]Zo`04o`02o`000003ool00?l0R?ooo`0000?oo`0000?o0?ldo`3oC_oo00000_oo
000;oookJP;o0?lM00?oogT0oookJ_oonfX01?oonfX3oomi00Gooo]Z1_oo07TLoookJP?oo`001ooo
nfX4ool00003oookJ_oo07Woo`1i00oooo]Z00?oobP0oookJ_oonfX00_oonfX3ool00003o`3o7Ooo
003oo`0000oooo]Z00Co0?ldoookJ_l0odko0?l^2?oonfX00ol0ZOoo08SooookJP03oookJP04oiCo
0?oonf[ooo]Zo`3Do`kooo]Z00?ooh40oookJ_oonfX03ooonfX00ooo02gooo]ZoookJP06oookJP03
oomG0?oonf[ooo]Z00Sooo]Z00?oL03oon/0ool0o`D0EooonfX01_l0omooN?l0ocd0oooonf[o0=co
ocoo00Gooo]Z00Co02[ooookJ_oonf[ooe800_oonfX00onio`3ooo]ZoookJP0?oookJP03o`1coooo
nf[ooo]Z01Cooo]Z00?oo`3ZoookJ_oonfX01_oonfX00oooTP3ooo]ZoookJP03oookJP03ool0o?oo
nf[ooo]Z00;ooo]Z00Ko603oool60?oonf[ooo]Zon_o0?oo0?H2oookJP03o`2Voooonf[oZ03o00;o
oo]Z00?oo`3io`1goooonfX00_oonfX01?ooK03ooh40o`3oc?lko`04oookJP04o`3koooonf[ooo]Z
ool300?ooo]Z00Coo`3MoookJ_nco`3oW`3o1?oonfX01Ol0omkooo]ZoookJ_oonf[oo`1/00?ooo]Z
00CoC@3oof40oooonf[o0?m50ooonfX01?oR0?oooo]ZoookJ_l0oi86oookJP03ofP0oooonf[ooo]Z
00;ooo]Z00?o603ooookJ_oVo`000_oonfX00oooT03ooo]ZoookJP06oookJP04oonn0?oonf[ooo]Z
og00o`Kooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP07oookJP03oon10?oonf[o
oo]Z00Oooo]Z00?o0=CooookJ_l01?l00_l00002o`2Yo`Gooo]Z00?o0?m>o`3o=?oonfX03?oonfX2
o`3o7@03o`3o2?oonf[ooo]Z00gooo]Z1_oo07TKoookJP?oo`1A3?oonfX2ool0N@oooo]Z00?o0?mC
oookJ_oonfX00ooonfX01?l0o`Sooo]Zo`3o7OoonfX2o`3Qo`kooo]Z00Co0?ldoookJ_l0odko0?l^
2OoonfX00ol0ZOoooo]ZoookJP03oookJP04o`04oooonf[ooo]Zo`3Do`kooo]Z00?ooh40oookJ_oo
nfX03_oonfX00ooo02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z00Sooo]Z00?oj`3ooookJ_l0
o`D09ooonfX003;ooo]Z00OoolT0oookJ_mho`3ooo]Zo`3Loooonf[o?ol000Cooo]Z00Go02[ooook
J_oonf[o0?lcoomB0002oookJP03okWo0?oonf[ooo]Z00kooo]Z00?o07?ooookJ_oonfX05?oonfX0
0ooo0>[ooo]ZoookJP05oookJP03oolF0?oonf[ooi8000Cooo]Z00Goo`3loookJ_oonf[ooo]ZoaP0
o`02oookJP04ool60?oonf[ojol0ool0mP?ooo]Z00Ko0:KooookJ_nX0?oooo]Zool0nOl0Mol3oook
JP04oom/0?l0olcooh40oc_o00?ooo]Z00?o0?_ooookJ_oonfX00_oonfX01ooo0`3ooo]ZoookJ_oo
:03ooo]Zo`2Soonco`001?oonfX00ol0omkogOl0oookJP02oookJP06ool0K?oonf[oC@3oool^0?mQ
0?oo0?m50ooonfX01Ooo003o0?n@oookJ_oonf[o0?nB00Gooo]Z00?oJ03ooookJ_oonfX00_oonfX0
0olH0?oooo]ZonKo0002oookJP03oon@0?oonf[ooo]Z00Oooo]Z00Cookh0oookJ_l0o`GoL03o1Ooo
nfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00Kooo]Z0_oo0009oookJP03o`3Doooo
nf[o00Co00;o00001_oo0002o`3oCP?oo`002_oonfX2o`3o7@03oomi0?oonf[ooo]Z00Oooo]Z00?o
ogT0oookJ_oonfX01?oo07TUoookJPCoo`000ooonfX6ool00003oookJ_oo07Woo`1i00kooo]Z0_oo
:004oookJP;o0?l800Co0?lMool00?oo003o0>7o3_oonfX01?l0ocCooo]Zo`3oC_l0obh8oookJP03
o`2Yoooonf[ooo]Z00?ooo]Z00CoU?l0oookJ_oonf[o0=Co3_oonfX00oooP@3ooo]ZoookJP0>oook
JP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX02?oonfX00oo[0?oo0?l5oookJP1Eoook
JP07o`3ogooonf[oN?l0oookJ_l0g?oooo]Zocoo0004oookJP05o`0Zoooonf[ooo]ZoookJ_ooDP00
0_oonfX00onio`3ooo]ZoookJP0>oookJP03o`1coooonf[ooo]Z01Gooo]Z00?oo`3ZoookJ_oonfX0
1OoonfX00ooo5P3ooi80oookJP03oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Ko603ooookJ_oo1P3o
oo]Zon_o0?oo0?H3oookJP06o`2Voooonf[oZ03ooookJ_oo0?Wo07Oo0ooonfX01?l0oi[oof`0oon1
0?lko`04oookJP05o`3koooonf[ooo]ZoookJ_oo0`000_oonfX01?mi0?ooo`3Mo`2Soonco`04oook
JP03o`3og_oMo`3ooo]Z00;ooo]Z00Ooo`1/oookJ_oonf[oC@3oof40oooonf[o0?m500?ooo]Z00Go
hP3ooookJ_oonf[ooo]Zo`3oTP05oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603ooookJ_oVo`00
0_oonfX00oooT03ooo]ZoookJP06oookJP05oonn0?oonf[ooo]Zo`3o1Om`0?l01OoonfX00oooE`3o
oo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Kooo]Z0_ooP@09oookJP03o`3Doooonf[o00Co00;o
000000?o0:Woo`28oooonfX01?oonfX00ol0odko0?l^oookJP0;oookJP;o0?lM00?o0?l8oookJ_oo
nfX02ooonfX4ool0NBCooo]Z1?oo054:oookJP;oo`1i3_oonfX2o`3oD`Cooo]Z0_l0o`P01?l0oago
oo]ZoookJ_l0hOl>oookJP04o`3o=?oonf[o0?m>o`3o;PSooo]Z00?o0:WooookJ_oonfX00ooonfX0
1Ol01?oooo]ZoookJ_oonf[o0=Co00kooo]Z00?ooh40oookJ_oonfX03OoonfX00ooo02gooo]Zoook
JP08oookJP03oomG0?oonf[ooo]Z00Oooo]Z00?oL03oon/0ool0o`D09ooonfX003;ooo]Z00CoolT0
oookJ_mho`3o0=co0_oonfX01Oloo`3ooo]ZoookJ_oonf[o02[o00?ooo]Z00Cooe80oookJ_oonf[o
^Ol04OoonfX00ol0Looooo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooaH0oonB0?oo
nfX00ooonfX00ooo0?cooo]ZoookJP02oookJP07oaP0oooonf[oo`H0oookJ_o[o`3ooo]Zool0mP02
oookJP07o`2Voooonf[oZ03ooookJ_oo0?Wooo]Zo`1go`03oookJP03oom/0?ooP@3o>ol000Cooo]Z
00Go0?_ooookJ_oonf[ooo]Zool30002oookJP04ogT0oooo:03o01Oook?o00Gooo]Z00_o0?oNoook
J_oonf[ooo]Zool0K?oonf[oC@3oool^0?oonf[oH@3oo`3oA@03oookJP04ool00?oonf[ooo]Zo`3o
TPGooo]Z00?oJ03ooookJ_oonfX00_oonfX01_lH0?oo07CooookJ_oVo`3ooo]Zoon@00Wooo]Z00Co
okh0oookJ_l0o`GoL03o1_oonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Kooo]Z
00?oo`00oookJ_oonfX02?oonfX01?l0e?oooo]Zo`04oooonfX7ool00003o`3oC_oo003oo`0000;o
o`002OoonfX00ol0o`So0?lMoookJP0<oookJP;oo`1i;OoonfX;ool00003oookJ_oo07Woo`1i00ko
oo]Z00?oobP0oookJ_oonfX00ooonfX01Ooo:03o0?lMoookJ_oonf[o0>7o00kooo]Z0_l0oc@00ol0
odko0?l^oookJP07oookJP03o`2Yoooonf[ooo]Z00;ooo]Z00CoU?l0oookJ_oonf[o0=Co3ooonfX0
0oooP@3ooo]ZoookJP0=oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00?ooeL0oookJ_oonfX01ooonfX0
0om`0?ooj`3oo`3o1@1EoookJP07o`3ogooonf[oN?l0oookJ_l0g?oooo]Zocoo0004oookJP07o`0Z
oooonf[ooo]ZoomB0?l0oc?ooo]ZokWo000AoookJP03o`1coooonf[ooo]Z01Gooo]Z00?oo`3Zoook
J_oonfX01OoonfX00oooTP3ooo]ZoookJP03oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Ko603oool6
0?oonf[ojol0oookJ_oo0?H2oookJP07o`2Voooonf[oZ03ooookJ_oo0?Wooo]Zo`1go`03oookJP03
oom/0?ooP@3o>ol000Gooo]Z00Co0?_ooookJ_oonf[oo`<00_oonfX01Omi0?ooo`3MoookJ_nco`3o
W`3o00Cooo]Z00Go0?oNoookJ_oonf[ooo]Zool0K002oookJP05odd0oooo;P3oH@3ooookJ_l0odD0
0_oonfX01OoR0?oooo]ZoookJ_oonf[o0?nB00Gooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?oo
07CoonKo0002oookJP03oon@0?oonf[ooo]Z00Kooo]Z00Gookh0oookJ_oonf[o0?l5og00o`06oook
JP05oomG0?oonf[ooo]ZoookJ_oo02d02?oonfX00oooP@3ooo]ZoookJP08oookJP04o`3Doooonf[o
00CooookJP;o0:Wo00?o08Soo`000?oonfX00_oonfX2o`3oCPcooo]Z00?o0?l8o`3o7OoonfX03Ooo
nfX2ool0NBcooo]Z1?oo0548oookJP;oo`1i3_oonfX00ol0oe?ooo]ZoookJP03oookJP05o`3o2?l0
oagooo]ZoookJ_l0hOl03_oonfX2o`3o=003o`3oC_l0obkooo]Z00Oooo]Z00?o0:WooookJ_oonfX0
0ooonfX01?l01?oooo]ZoookJ_l0e?l>oookJP03oon10?oonf[ooo]Z00kooo]Z00?oo`0]oookJ_oo
nfX02?oonfX00oooE`3ooo]ZoookJP07oookJP03on/0oooonf[o0?l502Kooo]Z000boookJP06ooo9
0?mho`3ooo]Zo`3Loooonf[o?ol01?oonfX01Ol0:_oooo]ZoookJ_l0oc?ooe8000;ooo]Z00?o^Ol0
oookJ_oonfX03_oonfX00ol0Looooo]ZoookJP0EoookJP03ool0j_oonf[ooo]Z00Cooo]Z00?ooaH0
oookJ_ooTP001?oonfX01Ooo0?cooo]ZoookJ_oonf[o603o00;ooo]Z00Coo`H0oookJ_o[o`3oo`3f
0ooonfX01_l0Y_oooo]ZojP0oooonf[oo`3io`1go`?ooo]Z00Coof`0oon10?oonf[o>ol00ooonfX0
1Ol0nooooo]ZoookJ_oonf[oobP000?ooo]Z00?oobP0o`0Goonco`001OoonfX00ol0omkooo]Zoook
JP02oookJP06ool0K?oonf[oC@3oool^0?mQ0?oo0?m50ooonfX01?oo003o0?n@oookJ_l0oi85oook
JP03ofP0oooonf[ooo]Z00?ooo]Z00Go603ooookJ_oVo`3ooo]Zoon@0009oookJP04oonn0?oonf[o
0?l5og00o`Kooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP06oookJP03ool00?oo
nf[ooo]Z00Sooo]Z00Oo0=Coo`04ool01?oooo]Zool00?l0R?oo000000?oo`000_l0odh5ool000So
oo]Z0_l0oad<oookJP;oo`1i<OoonfX:ool000;ooo]Z0_oo07T=oookJP;oobP00ooonfX00ooo:03o
oo]Zo`3o7@02oookJP03o`3Qoooonf[ooo]Z00gooo]Z00?o0?ldo`3oC_l0obh02?oonfX00ol0ZOoo
oo]ZoookJP02oookJP04oiCo0?oonf[ooo]Zo`3Do`kooo]Z00?ooh40oookJ_oonfX03_oonfX00ooo
02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z00Oooo]Z00?oL03oon/0ool0o`D0EOoonfX01_l0
omooN?l0oookJ_oonf[o0=coocoo00Cooo]Z00Go02[ooookJ_oonf[ooo]ZoomB0002oookJP03okWo
0?oonf[ooo]Z00kooo]Z00?o07?ooookJ_oonfX05OoonfX00ooo0>[ooo]ZoookJP05oookJP03oolF
0?ooTP3ooo]Z00Cooo]Z00[oo`3loookJ_oonf[ooo]ZoaP0oooonf[oo`H0oookJ_o[o`3oo`3f0ooo
nfX01_l0Y_oooo]ZojP0oooonf[oo`3io`1go`?ooo]Z00Co0?nJoon10?l0olco>ol01?oonfX01?l0
nooooo]ZoookJ_oo0`03oookJP04ogT0oooo0=go0:?ook?o00Cooo]Z00?o0?oNoookJ_oonfX00_oo
nfX01ooo06cooo]ZoookJ_m=0?ooH@3ooookJ_l0odD00ooonfX01?oR0?oooo]ZoookJ_l0oi85oook
JP03ofP0oooonf[ooo]Z00?ooo]Z00Go603oonKo0?oonf[ooo]Zoon@0008oookJP05oonn0?oonf[o
oo]Zo`3o1Om`0?l01_oonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00Sooo]Z00?ooh40oookJ_oonfX0
2?oonfX01Ol0e?oo00Coo`04oooonf[o0:Wo00;o08So0ol000000ooonf[o0?m>o`3o=00<oookJP;o
0?lM3OoonfX2ool0NC;ooo]Z0ooo0547oookJP;oo`1i3OoonfX2o`3oD`Gooo]Z00Co0?lMo`3o2?oo
nf[o0>7o3ooonfX00ol0ocCo0?m>o`3o;P08oookJP03o`2Yoooonf[ooo]Z00?ooo]Z00Co00Cooook
J_oonf[o0=Co3_oonfX00oooP@3ooo]ZoookJP0=oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00?ooeL0
oookJ_oonfX01ooonfX00om`0?ooj`3oo`3o1@0VoookJP00<OoonfX01ooob@3ooo]ZogSo0?oonf[o
0=cooookJ_loo`001?oonfX01Ol0:_oooo]ZoookJ_l0oc?ooe8000;ooo]Z00?o^Ol0oookJ_oonfX0
3_oonfX00ol0Looooo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooaH0oonB0?oonfX0
0ooonfX01Ooo0?cooo]ZoookJ_oonf[o603o00;ooo]Z00Goo`H0oookJ_o[o`3ooo]Zool0mP02oook
JP07o`2Voooonf[oZ03ooookJ_oo0?Wooo]Zo`1go`02oookJP04o`3oV_ooK03ooh40oc_o00Cooo]Z
00Go0?_ooookJ_oonf[ooo]ZoolX0002oookJP04oolX0?oonf[oW`3ook?o00Cooo]Z00?ogOl0o`3o
g_oonfX00_oonfX01_oo06cooo]Zodd0oooo;P3ooo]Zof40o`?ooo]Z00Coo`00o`3oT?oonf[o0?nB
1_oonfX00omX0?oooo]ZoookJP02oookJP05oaP0oooonf[oi_l0oookJ_ooT0002_oonfX00ooo_P3o
0?l5og00o`06oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX01_oonfX00ooo003o
oo]ZoookJP07oookJP;o0=Co00Go00CooookJ_oo003oo`00o`28o`03o`000003ool00?l0odko0?ld
00Goo`001ooonfX2o`3o7@cooo]Z0_oo07TFoookJPWo403o5?oonfX<ool000;ooo]Z0ooo07T<oook
JP03oolX0?oonf[oobP000;oobP000Gooo]Zo`3o7Ol0o`Sooo]Zo`3Qo`0?oookJP03o`3o=?l0odko
0?l^00Oooo]Z00?o08Soo`2YoooonfX00ooonfX01?nDo`3ooo]ZoookJ_l0e?l>oookJP03oon10?oo
nf[ooo]Z00gooo]Z00?oo`0]oookJ_oonfX02?oonfX00oooE`3ooo]ZoookJP07oookJP03on/0oooo
nf[o0?l505?ooo]Z00Oo0?oOoookJ_mho`3ooo]Zo`3Loooonf[o?ol000Cooo]Z00Go02[ooookJ_oo
nf[ooo]ZoomB0002oookJP03okWo0?oonf[ooo]Z00kooo]Z00?o07?ooookJ_oonfX05OoonfX00ooo
0>[ooo]ZoookJP05oookJP03oonB0?oonf[ooo]Z00?ooo]Z00_oo`3loookJ_oonf[ooo]ZoaP0oooo
nf[oo`H0oookJ_o[o`3ooo]Zool0mP02oookJP07o`2Voooonf[oZ03ooookJ_oo0?Wooo]Zo`1go`03
oookJP03oom/0?ooP@3o>ol000Gooo]Z00Co0?_ooookJ_oonf[oo`<00_oonfX01?mi0?ooo`3Moook
J_nco`04oookJP03omgo0?l0omkooo]Z00;ooo]Z00Ooo`1/oookJ_oonf[oC@3oool^0?mQ0?oo0?m5
00?ooo]Z00CohP3ooookJ_oonf[o0?nB1_oonfX00omX0?oooo]ZoookJP02oookJP05oaP0oooVo`3o
oo]ZoookJ_ooT0002OoonfX01?oo_P3ooo]Zo`3o1Om`0?l6oookJP05oomG0?oonf[ooo]ZoookJ_oo
02d02?oonfX00oooP@3ooo]ZoookJP07oookJP;o0=Co00Go00CooookJ_oonf[o0:Woo`28o`04o`00
00;o0?m>00?o0?ldoookJ_oonfX02OoonfX2o`3o7@gooo]Z0_oo07TFoookJPWo403o6?oonfX4ool0
D@Gooo]Z0ooo07T<oookJP03o`3oDooonf[ooo]Z00?ooo]Z00Co0?lMo`3o2?oonf[o0>7o3ooonfX0
0ol0ocCo0?m>o`3o;P07oookJP03o`28ool0ZOoooo]Z00Cooo]Z00?o00CooookJ_l0e?l03_oonfX0
0oooP@3ooo]ZoookJP0=oookJP03ool0;Ooonf[ooo]Z00Wooo]Z00?ooeL0oookJ_oonfX01ooonfX0
0oo[0?oooo]Zo`3o1@0UoookJP00<OoonfX01?oob@3ooo]ZogSo0?l0g?l2oookJP05ocoo0?oonf[o
oo]ZoookJ_l0:_l00_oonfX01Ol0oc?ooe80oookJ_oonf[o^Ol0013ooo]Z00?o07?ooookJ_oonfX0
5OoonfX00ooo0>[ooo]ZoookJP04oookJP03oolF0?ooTP3ooo]Z00Cooo]Z00Goo`3loookJ_oonf[o
oo]ZoaP0o`02oookJP05ool60?oonf[ojol0oookJ_oo0?H00_oonfX01ol0Y_oooo]ZojP0oooonf[o
o`3ioookJ_l0Mol00_oonfX01?ooK03ooh40oookJ_lko`03oookJP04o`3koooonf[ooo]ZoookJP;o
obP000Gooo]ZogT0oooo:03o01Oook?o0005oookJP0:o`3og_oonf[ooo]ZoookJ_oo06cooo]Zodd0
oooo;P3ooo]Zof40o`?ooo]Z00Coo`00oookJ_l0oi3o0?nB1_oonfX00omX0?oooo]ZoookJP02oook
JP03oaP0ool0M?ooi_l000;oobP02_oonfX01?oo_P3o0?l5oookJ_m`0?l5oookJP03oomG0?oonf[o
oo]Z00;ooo]Z00?oo`0]oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP07oookJP08o`3Doooonf[o
00CooookJ_oo003ooo]Zo`28oooonfX2o`0000;o0?m>00?o0?ldool00?oo00000ooo0006oookJP;o
0?lM3?oonfX2ool0NA?ooo]Z1Ol@0?l9oookJPco403o1ooonfX?ool000?ooo]Z0_oo07T;oookJPGo
obP000Gooo]Zo`3o7Ol0o`So0?l8o`3Qo`0?oookJP03o`3o=?l0odko0?l^00Oooo]Z00?o08Soo`2Y
oooonfX00ooonfX00onDo`3ooo]Zo`3Do`0?oookJP03oon10?oonf[ooo]Z00gooo]Z00?oo`0]oook
J_oonfX02?oonfX00oooE`3ooo]ZoookJP06oookJP03og00ooo[0?oo0?l505?ooo]Z00Oo0?oOoook
J_mho`3ooo]Zo`3Loooonf[o?ol000?ooo]Z00Go02[ooookJ_oonf[ooo]ZoomB0002oookJP03okWo
0?oonf[ooo]Z00kooo]Z00?o07?ooookJ_oonfX05OoonfX00ooo0>[ooo]ZoookJP05oookJP03oonB
0?oonf[ooo]Z00Cooo]Z00_oo`3loookJ_oonf[ooo]ZoaP0oooonf[oo`H0oookJ_o[o`3ooo]Zool0
mP02oookJP07o`2Voooonf[oZ03ooookJ_oo0?Wooo]Zo`1go`02oookJP04o`3oV_ooP@3o0?o<oc_o
00Cooo]Z00Co0?_ooookJ_oonf[oo`<00_oonfX01Omi0?ooo`3MoookJ_l0Xooo/ol000Cooo]Z00Go
0?oNoookJ_oonf[ooo]Zool0K002oookJP04odd0oooo;P3oH@3oo`3oA@?ooo]Z00CohP3oo`3oT?oo
nf[o0?nB1_oonfX00omX0?oooo]ZoookJP02oookJP05oaP0ool0M?ooi_l0oookJ_ooT0002OoonfX0
1?oo_P3ooo]Zo`3o1Om`0?l6oookJP05oomG0?oonf[ooo]ZoookJ_oo02d02?oonfX00oooP@3ooo]Z
oookJP07oookJP04o`3Doooonf[o00CooookJP;o0:Wo00?o08SooookJ_l000000_l000000ol0odko
0?ldo`3o=00:oookJP;o0?lM3OoonfX2ool0NA?ooo]Z1Ol@0?l9oookJP_o403o4OoonfX4ool0D@Co
oo]Z0_oo07T;oookJP03o`3oDooonf[ooo]Z00?ooo]Z0_l0oad00ol0o`So0>7ooookJP0>oookJP03
o`3o=?l0odko0?l^00Oooo]Z00?o08Soo`2YoooonfX00ooonfX01?l01?oooo]ZoookJ_l0e?l>oook
JP03oon10?oonf[ooo]Z00gooo]Z00?oo`0]oookJ_oonfX02OoonfX00oooE`3ooo]ZoookJP06oook
JP03og00ooo[0?oo0?l502Gooo]Z000`oookJP07ooo90?oonf[oN?l0oookJ_l0g?oooo]Zocoo0004
oookJP05o`0Zoooonf[ooo]Zo`3o<oooDP000_oonfX00onio`3ooo]ZoookJP0>oookJP03o`1coooo
nf[ooo]Z01Cooo]Z00?oo`3ZoookJ_oonfX01OoonfX00ooo5P3ooi80oookJP03oookJP05ool0o?oo
nf[ooo]ZoookJ_lH0?l00ooonfX01?oo1P3ojol0oookJ_oo0?H2oookJP07o`2Voooonf[oZ03ooook
J_oo0?Wooo]Zo`1go`02oookJP04o`3oV_oo003o0?o<oc_o00Cooo]Z00?o0?_ooookJ_oonfX00_oo
:002oookJP04oolX0?oonf[o0:?ook?o00Cooo]Z00?ogOl0o`3og_oonfX00_oonfX01_oo06cooo]Z
odd0oooo;P3oH@3oo`3oA@;ooo]Z00Goo`00oookJ_l0oi3ooo]Zo`3oTP06oookJP03ofP0oooonf[o
oo]Z00;ooo]Z00?o603ooookJ_oVo`000_oo:009oookJP04oonn0?l0o`Gooo]Zog00o`Gooo]Z00?o
oeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP06oookJP03ool00?oonf[ooo]Z00Oooo]Z00Go
0=CooookJ_l01?oooo]Zool00002o`28o`;ooo]Z00Co0000o`3oC_l0ocCo00001Ooo0005oookJP;o
0?lM00?o0?l8oookJ_oonfX02OoonfX2ool0NA3ooo]Z1Ol@0?lJoookJPOo403o4?oo00001?oo057o
oo]ZoookJ_oonfX2ool0N@Wooo]Z1_oo:0001Ooonf[o0?lMoookJ_l0o`So0>7o00oooo]Z00?o0?m>
oookJ_l0obh01ooonfX00ol0R?oo0:WooookJP02oookJP04oiCo0?oonf[ooo]Zo`3Do`kooo]Z00?o
oh40oookJ_oonfX03OoonfX00ooo02gooo]ZoookJP08oookJP03oomG0?oonf[ooo]Z00Oooo]Z00?o
j`3ooookJ_l0o`D0DOoonfX00ol0omoooo]ZogSo0002oookJP03o`3Looloo`3ooo]Z00?ooo]Z00Go
02[ooookJ_oonf[ooo]ZoomB0002oookJP03okWo0?oonf[ooo]Z00kooo]Z00?o07?ooookJ_oonfX0
5OoonfX00ooo0>[ooo]ZoookJP05oookJP03oonB0?oonf[ooo]Z00?ooo]Z00Goo`3loookJ_oonf[o
oo]ZoaP0o`02oookJP04ool60?oonf[ojol0ool0mP;ooo]Z00Oo0:KooookJ_nX0?oooo]Zool0nOoo
nf[o07Oo00?ooo]Z00?ooh40oookJ_lko`001OoonfX01?l0nooooo]ZoookJ_oo0`02oookJP04ogT0
oooo0=go0:?ook?o00Cooo]Z00?ogOl0o`3og_oonfX00_oonfX01ooo06cooo]ZoookJ_m=0?ooH@3o
oookJ_l0odD00_oonfX01OoR0?oo0?n@oookJ_oonf[o0?nB00Gooo]Z00?oJ03ooookJ_oonfX00ooo
nfX01OlH0?ooi_l0oookJ_oonf[ooi0000Sooo]Z00Gookh0oookJ_l0o`Gooo]Zog00o`05oookJP05
oomG0?oonf[ooo]ZoookJ_oo02d02?oonfX00oooP@3ooo]ZoookJP07oookJP07o`3Doooonf[o00Co
oookJ_l0ZOoooo]Zo`28o`02oookJP;o000000?o0?m>o`3o=?oonfX02OoonfX2o`3o7@03o`3o2?oo
nf[ooo]Z00[ooo]Z0_oo07T@oookJPGo403o6OoonfX7oa00o`kooo]Z0ooo0543oookJP;oo`1i2_oo
nfX2o`3oD`Gooo]Z00?o0?lMo`3o2?l0hOl03ooonfX00ol0ocCo0?m>o`3o;P07oookJP03o`28ool0
ZOoooo]Z00?ooo]Z00Co00CooookJ_oonf[o0=Co3_oonfX00oooP@3ooo]ZoookJP0<oookJP03ool0
;Ooonf[ooo]Z00Wooo]Z00?ooeL0oookJ_oonfX01_oonfX01?m`0?ooj`3ooookJ_l0o`DToookJP00
<?oonfX01ooob@3ooo]ZogSo0?oonf[o0=cooookJ_loo`000ooonfX01Ol0:_oooo]ZoookJ_l0oc?o
oe8000;ooo]Z00?o^Ol0oookJ_oonfX03_oonfX00ol0Looooo]ZoookJP0EoookJP03ool0j_oonf[o
oo]Z00Cooo]Z00?ooaH0oonB0?oonfX01?oonfX01Ooo0?cooo]ZoookJ_oonf[o603o00;ooo]Z00Oo
o`H0oookJ_o[o`3ooo]Zool0m_oonf[o0:Ko00;ooo]Z00GoZ03ooookJ_oo0?Wooo]Zo`1go`02oook
JP04oom/0?oo003ooo]Zoc_o00?ooo]Z00?o0?_ooookJ_oonfX00ooo:0001Ooonf[oN@3ooolX0?nO
0?oo/ol000Gooo]Z00[o0?oNoookJ_oonf[ooo]Zool0K?oonf[oC@3oool^0?oonf[oH@3o0ooonfX0
1?oo003o0?n@oookJ_l0oi86oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603oo`1doooVo`000_oo
:00:oookJP03oonn0?oonf[oL03o00Gooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]Zoook
JP06oookJP03ool00?oonf[ooo]Z00Oooo]Z00Ko0=CooookJ_l01?oooo]Zool00?l0R?l3oookJP;o
0?m>00Co0?ldo`000?l0003ooo]Z0ooo0004oookJP;o0?lM00?o0?l8oookJ_oonfX02OoonfX2ool0
N@Wooo]Z4OooN@0Hoi;o00Kooo]Z0ol@0?l>oookJP03ool0DOoonf[ooo]Z00;ooo]Z0_oo07T6oook
JPSoobP000Gooo]Zo`3o7Ol0o`Sooo]Zo`3Qo`0?oookJP03o`3oC_oonf[o0?l^00Kooo]Z00?o08So
oookJ_l0ZOl00ooonfX00onDo`3ooo]Zo`3Do`0?oookJP03oon10?oonf[ooo]Z00gooo]Z00?oo`0]
oookJ_oonfX01ooonfX00oooE`3ooo]ZoookJP07oookJP03og00ooo[0?oooo]Z057ooo]Z00Oo0?oO
oookJ_mho`3ooo]Zo`3Loooonf[o?ol000?ooo]Z00Go02[ooookJ_oonf[ooo]ZoomB0002oookJP03
okWo0?oonf[ooo]Z00kooo]Z00?o07?ooookJ_oonfX05OoonfX00ooo0>[ooo]ZoookJP05oookJP03
oonB0?oonf[ooo]Z00Cooo]Z00goo`3loookJ_oonf[ooo]ZoaP0oooonf[oo`H0oookJ_o[o`3ooo]Z
ool0m_oonf[o0:Ko00;ooo]Z00GoZ03ooookJ_oo0?Wooo]Zo`1go`02oookJP04o`3oV_ooP@3o0?o<
oc_o00Cooo]Z00Co0?_ooookJ_oonf[oo`<00_oonfX01Omi0?ooo`3MoookJ_l0Xooo/ol000Cooo]Z
00Go0?oNoookJ_oonf[ooo]Zool0K002oookJP04odd0oooo;P3oH@3oo`3oA@?ooo]Z00CohP3ooook
J_oonf[o0?nB1_oonfX00omX0?oooo]ZoookJP02oookJP05oaP0oooVo`3ooo]ZoookJ_ooT0002Ooo
nfX01?oo_P3o0?l5oookJ_m`0?l5oookJP05oomG0?oonf[ooo]ZoookJ_oo02d02?oonfX00oooP@3o
oo]ZoookJP07oookJP07o`3Doooonf[o00CooookJ_l0ZOoooo]Zo`28o`03oookJP;o0?m>00?o0?ld
o`000?oonfX01ooonfX2o`3o7@03o`3o2?oonf[ooo]Z00[ooo]Z0_oo07T=oookJPGo403o1?oonfXK
oi;o00Kooo]Z0ol@0?l>oookJP03ool0DOoonf[ooo]Z00;ooo]Z0_oo07T:oookJP03o`3oDooonf[o
oo]Z00?ooo]Z00?o0?lMoookJ_l0hOl03ooonfX00ol0ocCo0?m>o`3o;P06oookJP03o`28oooonf[o
0:Wo00Cooo]Z00?o00CooookJ_l0e?l03_oonfX00oooP@3ooo]ZoookJP0=oookJP03ool0;Ooonf[o
oo]Z00Sooo]Z00?ooeL0oookJ_oonfX01ooonfX00oo[0?oooo]ZoookJP0ToookJP00;ooonfX01Ooo
b@3ooo]Zocd0oomho`3o0=co00;ooo]Z00Go?ol0oookJ_oonf[ooo]Zo`0Zo`02oookJP05o`3o<ooo
DP3ooo]ZoookJ_nio`004?oonfX00ol0Looooo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z00Gooo]Z
00?ooaH0oonB0?oonfX00ooonfX01Ooo0?cooo]ZoookJ_oonf[o603o00?ooo]Z00Coo`H0oookJ_o[
o`3oo`3f0_oonfX00ol0Y_oooo]ZojP0o`02oookJP05ool0nOl0Mooooo]ZoookJ_ooK0000_oo0000
1Olko`3ooo]ZoookJ_oonf[o0?_o00;ooo]Z1?oo:0001Omi0?ooobP0o`0Gool0Xooo/ol000Cooo]Z
00?ogOl0o`3og_oonfX00_oonfX01_oo06coC@3oool^0?oonf[oH@3oo`3oA@;ooo]Z00Goo`00oook
J_l0oi3ooo]Zo`3oTP05oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603oo`1doooVo`000ooo:009
oookJP03oonn0?l0o`GoL03o00Kooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@0AoookJP;o0=Co00Go
oo]Zo`04oooonf[ooo]Zo`28o`03oookJP03o`3oC_oo003o0?ld00?o00000_oonfX01?oo003ooo]Z
oookJ_oonfX2o`3o7@;o0?l82_oonfX2ool0N@_ooo]Z3oooN@0;oookJP;oobP03OoonfX3oi;o00Ko
oo]Z0_l@0?l=oookJP;oo`1A1?oonfX2ool0N@?ooo]Z2_oo:0001Ooonf[o0?lMo`3o7Ooonf[o0>7o
00oooo]Z00?o0?m>oookJ_l0obh01_oonfX00ol0R?oooo]Zo`2Yo`03oookJP03oiCo0?oonf[o0=Co
00oooo]Z00?ooh40oookJ_oonfX03?oonfX00ooo02gooo]ZoookJP08oookJP03oomG0?oonf[ooo]Z
00Oooo]Z00?oj`3ooookJ_oonfX0CooonfX02?l0omoooo]Zocd0oomho`3ooo]Zo`3Loooonf[o?ol0
0ooonfX01Ol0:_oooo]ZoookJ_oonf[ooe8000;ooo]Z00?o^Ol0oookJ_oonfX03_oonfX00ol0Looo
oo]ZoookJP0EoookJP03ool0j_oonf[ooo]Z00Cooo]Z00?ooaH0oonB0?oonfX01?oonfX01Ooo0?co
oo]ZoookJ_oonf[o603o00;ooo]Z00Coo`H0oookJ_o[o`3oo`3f0_oonfX00ol0Y_oooo]ZojP0o`02
oookJP09ool0nOl0Mooooo]ZoookJ_l0oi[ooh40oookJ_l0olco>ol000?ooo]Z00_o0?_ooookJ_oo
nf[ooo]Zool30?oonf[oN@3ooookJ_oo0=go0:?ook?o0004oookJP03omgo0?l0omkooo]Z00;ooo]Z
00Ooo`1/oookJ_m=0?ooobh0of40oooonf[o0?m500;ooo]Z00GohP3oo`3oT?oonf[ooo]Zo`3oTP05
oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603oonKo0?oonf[ooo]Zoon@0009oookJP04oonn0?oo
nf[o0?l5og00o`Kooo]Z00CooeL0oookJ_oonf[oo`0]4OoonfX2o`3Do`04oookJ_l01?oooo]Zoook
JP;o08So0ooonfX00ol0odko0?l^o`3o=002o`0000Kooo]Z0_l0oad2o`3o20_ooo]Z0_oo07T:oook
JPGo403o1OoonfX4oi;o01_ooo]Z0onBo`06oookJP;o403o3OoonfX2ool0D@Cooo]Z0_oo07T9oook
JP03o`3oDooonf[ooo]Z00?ooo]Z00?o0?lMoookJ_l0hOl03ooonfX00ol0ocCo0?m>o`3o;P06oook
JP03o`28oooonf[o0:Wo00?ooo]Z00Co00CooookJ_oonf[o0=Co3_oonfX00oooP@3ooo]ZoookJP0<
oookJP03ool0;Ooonf[ooo]Z00Wooo]Z00?ooeL0oookJ_oonfX01_oonfX00om`0?ooj`3ooookJP0T
oookJP00;ooonfX01ol0omoooo]ZogSo0?oonf[o0=cooookJ_loo`000ooonfX01Ol0:_oooo]Zoook
J_l0oc?ooe8000;ooo]Z00?o^Ol0oookJ_oonfX03_oonfX00ol0Looooo]ZoookJP0EoookJP03ool0
j_oonf[ooo]Z00Cooo]Z00?ooaH0oomi0?oonfX01?oonfX01Ooo0?cooo]ZoookJ_oonf[o603o00;o
oo]Z00Ooo`H0oookJ_o[o`3ooo]Zool0m_oonf[o0:Ko00;ooo]Z00GoZ03ooookJ_oo0?Wooo]Zo`1g
o`02oookJP;oo`0000?ooo]Zoc_o0?oonfX00_oonfX00ol0nooooo]ZoolX0004oolX0004ogT0oooo
:03oW`3ook?o00Gooo]Z00[o0?oNoookJ_oonf[ooo]Zool0K?oonf[oC@3oool^0?oonf[oH@3o0_oo
nfX01Ooo003ooo]Zo`3oT?oonf[o0?nB00Kooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?ooi_l0
oolX0003oolX00Sooo]Z00Cookh0o`3o1Ooonf[oL03o1OoonfX01OooE`3ooo]ZoookJ_oonf[oo`0]
017ooo]Z00Co0=CooookJ_oonf[o00Co0_oonfX01ol0R?oooo]ZoookJ_oonf[o0?m>ool00?l0oc@0
1?l00005oookJP03o`3o7Ooonf[o0?l800[ooo]Z0_oo07T9oookJP?oU?l000?o403ooomi0?ooN@00
2oooN@0=oookJPGoobP03OoonfX3oi;o00Gooo]Z0ol@0?l<oookJP03ool0DOoonf[ooo]Z00?ooo]Z
0_oo07T3oookJPSoobP00ooonfX00ol0oagooo]Zo`3Qo`0?oookJP03o`3oC_oonf[o0?l^00Kooo]Z
00?o08SooookJ_l0ZOl00ooonfX00onDo`3ooo]Zo`3Do`02oiCo00cooo]Z00?ooh40oookJ_oonfX0
3?oonfX00ooo02gooo]ZoookJP08oookJP03oomG0?oonf[ooo]Z00Oooo]Z00?oj`3ooookJ_oonfX0
CooonfX00ol0omoooo]ZogSo0002oookJP03o`3Looloo`3ooo]Z00?ooo]Z00Co02[ooookJ_oonf[o
oe800_oonfX00onio`3ooo]ZoookJP0>oookJP03o`1coooonf[ooo]Z01Gooo]Z00?oo`3ZoookJ_oo
nfX01OoonfX00oooTP3ooo]ZoookJP04oookJP0=ool0o?oonf[ooo]ZoookJ_lH0?oooo]Zool60?oo
nf[ojol0oookJ_oo0?Kooo]Zo`2Vo`02oookJP05ojP0oooonf[oo`3ioookJ_l0Mol00_oonfX01?oo
K03ooh40o`3oc?lko`04oookJP04o`3koooonf[ooo]Zool300;ooo]Z00CoN@3oool0gOoonf[o/ol0
1OoonfX01Ol0omkooo]ZoookJ_oonf[oo`1/00;ooo]Z00CoC@3oool^0?mQ0?oo0?m50_oonfX01OoR
0?oo0?n@oookJ_oonf[o0?nB00Kooo]Z00?oJ03ooookJ_oonfX00_oonfX01OlH0?ooi_l0oookJ_oo
nf[ooi0000Sooo]Z00Cookh0oookJ_l0o`GoL03o1_oonfX01?ooE`3ooo]ZoookJ_oo02dAoookJP04
o`3Doooonf[ooo]Zo`04o`;ooo]Z00Co08SooookJ_oonf[ooo]Z0_l0odh00ol0obko0?ldo`000002
o`0000Gooo]Z00?o0?lMoookJ_l0o`P02ooonfX2ool0N@Wooo]Z0ol@0?l6oookJPCoT_l08_oonfX3
oi;o00Gooo]Z0ol@0?l<oookJP03ool0DOoonf[ooo]Z00?ooo]Z0_oo07T8oookJP;o0?mC1?oonfX0
0ol0oagooo]Zo`3Qo`0?oookJP03o`3o=?l0odko0?l^00Kooo]Z00?o08SooookJ_l0ZOl00ooonfX0
0ol01?oooo]Zo`3Do`0?oookJP03oon10?oonf[ooo]Z00cooo]Z00?oo`0]oookJ_oonfX02?oonfX0
0oooE`3ooo]ZoookJP07oookJP03on/0oooonf[ooo]Z02?ooo]Z000_oookJP07o`3ogooonf[oN?l0
oookJ_l0g?oooo]Zocoo0003oookJP05o`0Zoooonf[ooo]Zo`3o<oooDP000_oonfX00onio`3ooo]Z
oookJP0>oookJP03o`1coooonf[ooo]Z01Cooo]Z00?oo`3ZoookJ_oonfX01?oonfX00ooo5P3ooo]Z
oomi0004oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Oo603ooookJ_oonf[oo`H0oookJ_o[o`3oo`3f
00;ooo]Z00?o0:KooookJ_nX0?l00_oonfX01?oo0?Wo07OooookJ_oonfX3ool00006oc_o0?oonf[o
oo]ZoookJ_l0nooooo]Z1Ooo:0001Omi0?ooobP0oil0ool0Xooo/ol000Cooo]Z00go0?oNoookJ_oo
nf[ooo]Zool0K?oonf[oC@3oool^0?oonf[oH@3oo`3oAOoonf[oo`0000;ooo]Z00?o0?n@o`3oT_oo
nfX01OoonfX00omX0?oooo]ZoookJP02oookJP03oaP0oooo:03oi_l000?oobP02?oonfX01?oo_P3o
0?l5oookJ_m`0?l5oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX03_oonfX01Ol0
e?oooo]ZoookJ_l01?oooo]Z00;o08So0_oonfX2o`3oCP;o0?ld00?ooo]Zo`000?l000000_l00004
oookJP03o`3o7Ol0o`So0?l800Wooo]Z0_oo07T7oookJPGoU?l01?oonfX;oomi00kooo]Z2?oo:00=
oookJP?oT_l01OoonfX2oa00o`_ooo]Z00?oo`1AoookJ_oonfX01?oonfX00oooN@3ooo]ZoookJP03
oookJPKoobP00ooonfX00ol0oagooo]Zo`3Qo`0>oookJP04o`3o=?l0odkooo]Zo`3o;PGooo]Z00Co
08SooookJ_oonf[o0:Wo0_oonfX00onDo`3ooo]Zo`3Do`02oiCo00gooo]Z00?ooh40oookJ_oonfX0
3?oonfX00ooo02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z00Oooo]Z00?oL03oon/0oooonfX0
CooonfX01ol0omoooo]ZogSo0?oonf[o0=cooookJ_loo`000ooonfX01Ol0:_oooo]ZoookJ_oonf[o
oe8000;ooo]Z00?o^Ol0oookJ_oonfX03_oonfX00ol0Looooo]ZoookJP0EoookJP03ool0j_oonf[o
oo]Z00Cooo]Z00?ooaH0oonB0?oonfX01?oonfX00ooo0?cooo]ZoookJP02oookJP06oaP0oooonf[o
o`H0oookJ_o[o`3oo`3f0_oonfX00ol0Y_oooo]ZojP0o`02oookJP09ool0nOl0Mooooo]ZoookJ_l0
oi[ooh40o`3oc?oonf[o>ol000?ooo]Z00_o0?_ooookJ_oonf[ooo]Zool30?oonf[oN@3oool0gOoo
nf[o0:?ook?o0004oookJP05o`3og_oonf[ooo]ZoookJ_oo06`00_oonfX02om=0?ooobh0of40oooo
nf[o0?m5oookJ_oR0?oooo]Zo`3oT?oonf[o0?nB00Kooo]Z00?oJ03ooookJ_oonfX00_oonfX01OlH
0?ooi_l0oookJ_oonf[ooi0000Sooo]Z00Gookh0oookJ_l0o`Gooo]Zog00o`05oookJP05oomG0?oo
nf[ooo]ZoookJ_oo02d04?oonfX01?l0e?oooo]ZoookJ_l01?l2oookJP06o`28oooonf[ooo]Zoook
J_l0odko0?l^0_l0oc@4o`0000Cooo]Z00?o0?lMo`3o2?l0o`P02_oonfX2ool0N@Wooo]Z0_l@0?l6
oookJP?oT_l0:OoonfX3oi;o00Gooo]Z0_l@0?l;oookJP03ool0DOoonf[ooo]Z00Cooo]Z0_oo07T8
oookJP03o`3oDooonf[ooo]Z00;ooo]Z00?o0?lMoookJ_l0hOl03_oonfX01?l0ocCooo]Zo`3oC_l0
obh5oookJP04o`28oooonf[ooo]Zo`2Yo`?ooo]Z00?o00CooookJ_l0e?l03_oonfX00oooP@3ooo]Z
oookJP0<oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00?ooeL0oookJ_oonfX01ooonfX00om`0?ooj`3o
oookJP0SoookJP00;_oonfX01Ol0omoooo]Zocd0oomho`3o0=co00;ooo]Z00Go?ol0oookJ_oonf[o
oo]Zo`0Zo`02oookJP05oomB0?oonf[ooo]ZoookJ_nio`003ooonfX00ol0Looooo]ZoookJP0Eoook
JP03ool0j_oonf[ooo]Z00Cooo]Z00?ooaH0oomi0?ooN@001?oonfX01Ooo0?cooo]ZoookJ_oonf[o
603o00;ooo]Z00Ooo`H0oookJ_o[o`3ooo]Zool0m_oonf[o0:Ko00;ooo]Z00OoZ03ooookJ_oo0?Wo
oo]Zo`1goooonf[o0?nJ00?oo`0000Go>ol0oookJ_oonf[ooo]Zo`3ko`05oolX0005ogT0oooo:03o
01Ooo`2Soonco`001OoonfX02_l0omkooo]ZoookJ_oonf[oo`1/odd0oooo;P3ooo]Zof40ool0odD4
oookJP03o`3oT?oonf[o0?nB00Kooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?ooi_l0oolX0003
oolX00Sooo]Z00?ookh0o`3o1Om`0?l01OoonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[o
oo]Z00kooo]Z00Ko0=CooookJ_l01?oo00CooookJ_l0R?l3oookJP03o`3oC_oo003o0?ld00?ooo]Z
1?l00003oookJP03o`3o7Ol0o`Sooo]Z00Sooo]Z0_oo07T5oookJPSoU?l00ooonfX;oomi00Kooo]Z
0_l0<?l7oolX0003oookJ_oo:03oobP000WoobP03OoonfX2oi;o00Gooo]Z0_l@0?l:oookJP;oo`1A
1OoonfX00oooN@3ooo]ZoookJP04oookJPGoobP00ooonfX00ol0oagooo]Zo`3Qo`0>oookJP04o`3o
=?l0odkooo]Zo`3o;PGooo]Z00Go08SooookJ_oonf[o0:WooookJP03oiCo0003o`3DoonDo`3oU?l0
00gooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP08oookJP03oomG0?oonf[ooo]Z
00Oooo]Z00?oL03ooookJ_oonfX0COoonfX02?l0omoooo]Zocd0oomho`3ooo]Zo`3Loooonf[o?ol0
0ooonfX01Ol0:_oooo]ZoookJ_ooDP3o0?lc00;ooo]Z00?o^Ol0oookJ_oonfX03OoonfX00ol0Looo
oo]ZoookJP0EoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooi80oookJ_oonfX01?oonfX01ooo0?co
oo]ZoookJ_oonf[o603ooookJ_oo1P000_oonfX01?o[o`3oo`3foookJ_l0Y_l2oookJP05ojP0oooo
nf[oo`3ioookJ_l0Mol00_oonfX01?ooK03ooh40o`3oc?lko`04oookJP0:o`3koooonf[ooo]Zool3
0?oonf[oN@3ooookJ_oo0=go0:?ook?o00Gooo]Z00_o0?oNoookJ_oonf[ooo]Zool0K?oonf[oC@3o
ool^0?mQ0?oooo]Zo`3oA@03oookJP04o`3oT?oonf[ooo]Zo`3oTPGooo]Z00?oJ03ooookJ_oonfX0
0_oonfX01OlH0?ooi_l0oookJ_oonf[ooi0000Wooo]Z00Cookh0oookJ_l0o`GoL03o1OoonfX01Ooo
E`3ooo]ZoookJ_oonf[oo`0]013ooo]Z00Co0=CooookJ_l01?oo00Co0_oonfX01ol0R?oooo]Zoook
J_oonf[o0?m>o`3o;_l0oc@00_oonfX4o`0000?ooo]Z00?o0?lMo`3o2?oonfX02OoonfX2ool0N@Wo
oo]Z0_l@0?l4oookJPCoT_l03_oonfX9o`0`oaSooo]Z0_nBo`05oookJP;o403o2_oonfX2ool0D@Ko
oo]Z00?oo`1ioookJ_oonfX01_oonfX2o`3oD`?ooo]Z00?o0?lMoookJ_l0hOl03_oonfX01?l0ocCo
oo]Zo`3oC_l0obh5oookJP04o`28oooonf[ooo]Zo`2Yo`;ooo]Z00Co00CooookJ_oonf[o0=Co3_oo
nfX00oooP@3ooo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z00Wooo]Z00?ooeL0oookJ_oonfX01ooo
nfX00om`0?oooo]ZoookJP0RoookJP00;_oonfX01ol0omoooo]ZogSo0?oonf[o0=cooookJ_loo`00
0ooonfX01Ol0:_oooo]ZoookJ_l0oc?ooe8000;ooo]Z00?o^Ol0oookJ_oonfX03_oonfX00ol0Looo
oo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z00Cooo]Z00CooaH0oomi0?ooN@3oogT00ooonfX00ooo
0?cooo]ZoookJP02oookJP0<oaP0oooonf[ooo]Zool60?oonf[ojol0oookJ_oo0?Kooo]Zo`2Voooo
nf[oZ03o0_oonfX01?oo0?Wo07OooookJ_oonfX4ool00004oc_o0?oonf[ooo]Zo`3ko`KoobP000Co
N@3ooolX0?nO0?oo/ol01OoonfX02_l0omkooo]ZoookJ_oonf[oo`1/oookJ_m=0?ooobh0oookJ_mQ
0?l4oookJP03o`3oT?oonf[o0?nB00Kooo]Z00?oJ03ooookJ_oonfX00_oonfX00olH0?ooi_l0oolX
0004oolX00Oooo]Z00?ookh0o`3o1Om`0?l01OoonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooo
nf[ooo]Z00kooo]Z00?o0=CooookJ_l01?l00_oonfX01ol0R?oooo]ZoookJ_oonf[o0?m>oookJ_l0
oc@01?oonfX4o`000004oookJ_l0oago0?lMo`3o20Sooo]Z0_oo07T3oookJP_oU?l01?ooN@02oook
JPOoogT00ooonfX5o`0`o`Wooo]Z3ooo:00<oookJP?oT_l01?oonfX3oa00o`Wooo]Z00?oo`1Aoook
J_oonfX00ooonfX00oooN@3ooo]ZoookJP05oookJPCoobP00ooonfX00ol0oagooo]Zo`3Qo`0>oook
JP04o`3o=?l0odkooo]Zo`3o;PGooo]Z00?o08SooookJ_oonfX01OnDo`000ol0e?ooU?l0oookJP0=
oookJP03oon10?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX01ooonfX00oooE`3ooo]ZoookJP1G
oookJP03o`3ogooonf[oN?l000;ooo]Z00?o0=coocoo0?oonfX00_oonfX01Ol0:_oooo]ZoookJ_oo
nf[ooe8000;ooo]Z00?o^Ol0oookJ_oonfX03_oonfX00ol0Looooo]ZoookJP0EoookJP03ool0j_oo
nf[ooo]Z00Cooo]Z00?ooaH0oonB0?oonfX01?oonfX00ooo0?cooo]ZoookJP02oookJP0;oaP0oooo
nf[oo`H0oookJ_o[o`3ooo]Zool0m_oonf[o0:KooookJ_nX0?l00_oonfX02Ooo0?Wo07OooookJ_oo
nf[o0?nJoom/0?ooP@3ooo]Zoc_o0003oookJP0;o`3koooonf[ooo]ZoookJ_oo0`3ooo]ZogT0oooo
0=gooo]Zo`2Soonco`001?oonfX01Ol0omkooo]ZoookJ_oonf[oo`1/00;ooo]Z00CoC@3oool^0?mQ
0?oo0?m50ooonfX01?l0oi3ooo]ZoookJ_l0oi86oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603o
oookJ_oonf[ooo]Zoon@0008oookJP04oonn0?oonf[o0?l5og00o`Gooo]Z00GooeL0oookJ_oonf[o
oo]Zool0;@0@oookJP03o`3Doooonf[o00Co00?ooo]Z00Oo08SooookJ_oonf[ooo]Zo`3oC_oonf[o
0?ld00?ooo]Z1?l000001?oonf[o0?lMo`3o7Ol0o`P9oookJP;oo`1i2OoonfX2oa00o`;ooo]Z1?nB
o`0=oookJPGo033o2OoonfX;o`0`o`oooo]Z0onBo`04oookJP?o403o2OoonfX00ooo057ooo]Zoook
JP04oookJP03ool0NOoonf[ooo]Z00Oooo]Z00Co0?mCoookJ_oonf[ooo]Z0_l0oad00ol0hOoooo]Z
oookJP0<oookJP04o`3o=?oonf[o0?m>o`3o;PGooo]Z00Co08SooookJ_oonf[o0:Wo0_oonfX00ol0
1?oooo]Zo`3Do`0?oookJP03oon10?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX02?oonfX00ooo
E`3ooo]ZoookJP0/oookJP00;_oonfX01ol0omoo?@3oogSo0?oonf[o0=cooookJ_loo`000ooonfX0
1?l0:_oooo]ZoookJ_ooDP03oookJP03okWo0?oonf[ooo]Z00gooo]Z00?o07?ooookJ_oonfX05Ooo
nfX00ooo0>[ooo]ZoookJP04oookJP04oolF0?ooN@3oogT0oomi00?ooo]Z00Goo`3loookJ_oonf[o
oo]ZoaP0o`02oookJP07ool60?oonf[ojol0oookJ_oo0?Kooo]Zo`2Vo`02oookJP06ojP0oooonf[o
o`3ioookJ_l0Mooooo]Z1?oo00001Olko`3ooo]ZoookJ_oonf[o0?_o00GoobP000GoN@3ooolX0?l0
5ooo0:?ook?o0005oookJP0:o`3og_oonf[ooo]ZoookJ_oo06coC@3oool^0?oonf[oH@3oo`3oA@Co
oo]Z00?o0?n@oookJ_l0oi801OoonfX00omX0?oooo]ZoookJP02oookJP03oaP0oooVo`3oobP000Co
obP01ooonfX01?oo_P3o0?l5oookJ_m`0?l4oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oook
J_oonfX03ooonfX01Ol0e?oo00CooookJ_oonf[o08So00?ooo]Z00?o0?m>oookJ_l0oc@01OoonfX4
o`000003o`3o7Ol0o`Sooo]Z00Oooo]Z0_oo07T3oookJP[oU?l000?oT_l0oomi0?ooN@001_oonfX5
oomi0003oookJ_l0<?oo033o00;o033o3_oonfX@oolX0003o`0`oooonf[ooo]Z00_ooo]Z0onBo`04
oookJP;o403o2?oonfX2ool0D@Cooo]Z00?oogT0oookJ_oonfX01ooonfX2oolX00;ooo]Z00Co0?l8
o`3o7Ooonf[o0>7o3OoonfX01Ol0ocCooo]Zo`3oC_oonf[o0?l^00Cooo]Z00?o08SooookJ_nDo`00
1OnDo`000ol0e?ooU?l0oiCo000=oookJP03oon10?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX0
1ooonfX00oooE`3ooo]ZoookJP1GoookJP07o`3ogolm0?ooN?l0oookJ_l0g?oooo]Zocoo0003oook
JP05o`0Zoooonf[ooo]ZoomB0?l0oc<00_oonfX00onio`3ooo]ZoookJP0=oookJP03o`1coooonf[o
oo]Z01Gooo]Z00?oo`3ZoookJ_oonfX01OoonfX00ooo5P3ooi80oookJP04oookJP07ool0o?oonf[o
oo]ZoookJ_lH0?oooo]Zool60002oookJP04on_o0?oo0?Kooo]Zo`2Vo`;ooo]Z00_oZ03ooookJ_oo
0?Wooo]Zo`1goooonf[o0?nJoom/0?ooP@3o0?o<oc_o0004oookJP0:o`3koooonf[ooo]Zool30?oo
nf[oN@3ooookJ_oo0=go0:?ook?o00Gooo]Z00_o0?oNoookJ_oonf[ooo]Zool0K?oonf[oC@3oool^
0?mQ0?oooo]Zo`3oA@03oookJP04o`3oT?oonf[ooo]Zo`3oTPGooo]Z00?oJ03ooookJ_oonfX00_oo
nfX01OlH0?oo07CooookJ_oonf[ooi0000Sooo]Z00Cookh0oookJ_l0o`GoL03o1OoonfX01OooE`3o
oo]ZoookJ_oonf[oo`0]017ooo]Z00Co0=Coo`04oooonf[ooo]Z0_l0R?l3oookJP03o`3oC_oonf[o
0?ld00Cooo]Z1?l000000ol0oago0?l8oookJP08oookJP;oo`1i2OoonfX2oa00o`04oookJ_nBo`3o
T_l0oi;o00cooo]Z1Ol0<?lIoookJPKo033o3?oonfX3oi;o00Cooo]Z0_l@0?l8oookJP;oo`1A1Ooo
nfX00ooo07Wooo]ZoookJP07oookJP07o`3oDooonf[ooo]Zo`3o2?oonf[o0?lMo`3Qo`0=oookJP05
o`3o=?oonf[ooo]Zo`3oC_l0obh01?oonfX01?l0R?oooo]ZoookJ_l0ZOl3oookJP03o`04oooonf[o
0=Co00kooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP08oookJP03oomG0?oonf[o
oo]Z02cooo]Z000^oookJP07o`3ogolm0?ooN?l0oookJ_l0g?oooo]Zocoo0002oookJP05o`0Zoooo
nf[ooo]ZoookJ_ooDP000_oonfX00onio`3ooo]ZoookJP0>oookJP03o`1coooonf[ooo]Z01Gooo]Z
00?oo`3ZoookJ_oonfX00ooonfX4oomi00?ooo]Z00?oo`3loookJ_oonfX00_oonfX03?lH0?oooo]Z
oookJ_oo1P3ooo]Zon_o0?oonf[oo`3foookJ_l0Y_oooo]ZojP0o`;ooo]Z00?oo`3io`1goooonfX0
1Ooo00001?lko`3ooo]ZoookJ_l0nol6oolX0004ogT0oooo:03oW`3ook?o00Gooo]Z00[o0?oNoook
J_oonf[ooo]Zool0K?oonf[oC@3ooookJ_mQ0?oo0?m51?oonfX00ol0oi3ooo]Zo`3oTP06oookJP07
ofP0oooonf[ooo]ZoookJ_oo:03o603oonKo0005oolX00Kooo]Z00Cookh0o`3o1Ooonf[oL03o1Ooo
nfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00kooo]Z00?o0=Coo`04oooonfX00_l0
R?l3oookJP03o`3oC_oonf[o0?ld00Kooo]Z0ol000000ol0oago0?l8oookJP07oookJP03ool0NOoo
nf[ooo]Z00?ooo]Z2?nDo`02oi;o0003oiCo0?oonf[ooo]Z00Oooo]Z0oooN@02o`0`oa;ooo]Z2ooo
:006oookJP?o033o3OoonfX3oi;o00?ooo]Z0ol@0?l7oookJP03ool0DOoonf[ooo]Z00;ooo]Z00?o
ogT0oookJ_oonfX02?oonfX01ooo:03ooo]ZoookJ_l0o`So0?lMoookJ_l0hOl03OoonfX01?l0ocCo
oo]Zo`3oC_l0obh5oookJP03o`28oooonf[ooo]Z00GoU?l000?o0=CooiCo0?oonfX03OoonfX00ooo
P@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00?ooeL0oookJ_oonfX0E_oonfX01ol0
omoo?@3oogSo0?oonf[o0=cooookJ_loo`000_oonfX02?l0:_oooo]ZoookJ_oonf[ooe80o`3o<ooo
nf[o^Ol04?oonfX00ol0Looooo]ZoookJP0EoookJP03ool0j_oonf[ooo]Z00Cooo]Z00?ooaH0oonB
0?oonfX01?oonfX00ooo0?cooo]ZoookJP02oookJP0;oaP0oooonf[oo`H0oookJ_o[o`3ooo]Zool0
m_oonf[o0:KooookJ_nX0?l00_oonfX02Ooo0?Wo07OooookJ_oonf[o0?nJoom/0?ooP@3ooo]Zoc_o
0003oookJP0;o`3koooonf[ooo]ZoookJ_oo0`3ooo]ZogT0oooo0=go01Ooo`2Soonco`001?oonfX0
1Ol0omkooo]ZoookJ_oonf[oo`1/00;ooo]Z00CoC@3oof40oooonf[o0?m50ooonfX01?l0oi3ooo]Z
oookJ_l0oi86oookJP06ofP0oooonf[ooo]ZoookJ_lH0?ooi_l00_oonfX00oooT03ooo]ZoookJP06
oookJP04oonn0?oonf[o0?l5og00o`Kooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@0@oookJP05o`3D
ool01?oooo]ZoookJ_l0R?l01?oonfX00ol0odkooo]Zo`3o=005oookJP?o000000?o0?lMo`3o2?oo
nfX02?oonfX00ooo07Wooo]ZoookJP06oookJP?o403o00?ooo]Zoi;o0?nBo`002ooonfX4o`0`obCo
oo]Z0ol0<?l<oookJP?oT_l00ooonfX3oa00o`Oooo]Z00?oo`1AoookJ_oonfX00ooonfX00ooo07Wo
oo]ZoookJP07oookJP07o`3oDooonf[ooo]Zo`3o2?oonf[o0?lMo`3Qo`0=oookJP04o`3o=?oonf[o
oo]Zo`3oCPGooo]Z00Co08SooookJ_oonf[o0:Wo0_oonfX01?l01?oooo]ZoookJ_l0e?l>oookJP03
oon10?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX02?oonfX00oooE`3ooo]ZoookJP0[oookJP00
;OoonfX01ol0omoooo]ZogSo0?oonf[o0=cooookJ_loo`000ooonfX01Ol0:_oooo]ZoookJ_l0oc?o
oe8000;ooo]Z00?o^Ol0oookJ_oonfX03_oonfX00ol0Looooo]ZoookJP0DoookJP03ool0j_oonf[o
oo]Z00Cooo]Z1?ooN@03oookJP03ool0o?oonf[ooo]Z00;ooo]Z00?o603ooookJ_oo1P000_oonfX0
1?o[o`3oo`3foookJ_l0Y_l2oookJP06ojP0oooonf[oo`3ioookJ_l0Mooooo]Z1?oo00001?lko`3o
oo]ZoookJ_l0nol2oookJPCoobP000GoN@3ooolX0?oo:03o0:?ook?o0005oookJP0:o`3og_oonf[o
oo]Zool0K?oonf[oC@3oool^0?oonf[oH@3oo`3oA@Cooo]Z00?o0?n@oookJ_l0oi801OoonfX01omX
0?oooo]ZoookJ_oonf[oobP0oaP0oooVo`001_oo:006oookJP03oonn0?l0o`GoL03o00Gooo]Z00?o
oeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP0>oookJP04o`3Dool01?oooo]Zo`28o`Cooo]Z
00?o0?m>o`3o=?l0oc@01ooonfX01?l0003o0?lMo`3o7Ol00007oookJP;oo`1i1ooonfX5oiCo00;o
T_l000?oU?l0oookJ_oonfX01OoonfX4o`0`o`03oomi0?oonf[ooo]Z00cooo]Z2_l0oe/2oolX013o
oo]Z0ol0<?l=oookJP;oT_l01?oonfX2oa00o`Kooo]Z00?oo`1AoookJ_oonfX00_oonfX00oooN@3o
oo]ZoookJP07oookJP08o`3oDooonf[ooo]ZoookJ_l0o`So0?lMoookJ_l0hOl<oookJP05o`3o=?oo
nf[ooo]Zo`3oC_l0obh01OoonfX00ol0R?oooo]Zo`2Yo`05oiCo0003o`3Doooonf[ooo]Z00gooo]Z
00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z05Gooo]Z
00?o0?oOoookJ_mho`000_oonfX00ol0g?oo?ol0oookJP02oookJP05o`0Zoooonf[ooo]ZoookJ_oo
DP000_oonfX00onio`3ooo]ZoookJP0>oookJP03o`1coooonf[ooo]Z01Cooo]Z00?oo`3ZoookJ_oo
nfX01OoonfX00ooo5P3ooi80oookJP04oookJP03ool0o?oonf[ooo]Z00;ooo]Z00So603oool60?oo
nf[ooo]Zon_o0?oo0?Kooo]Zo`2Vo`;ooo]Z00_oZ03ooookJ_oonf[oo`3io`1goooonf[o0?nJoom/
0?ooP@3o0?o<oc_o0003oookJP0;o`3koooonf[ooo]ZoookJ_oo0`3ooo]ZogT0oooo0=gooo]Zo`2S
oonco`001OoonfX01?l0omkooo]ZoookJ_oo06`2oookJP05odd0oooo;P3oH@3ooookJ_l0odD00ooo
nfX01?l0oi3ooo]ZoookJ_l0oi85oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Go603ooookJ_oonf[o
oo]Zoon@0008oookJP04oonn0?oonf[o0?l5og00o`Gooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@0@
oookJP05o`3Dool01?oooo]ZoookJ_l0R?l01?oonfX00ol0odko0?ldo`3o=006oookJP04o`000?l0
oago0?lMo`0000Sooo]Z0_oo07T7oookJP;o403o0_oonfX2oi;o00Sooo]Z1Ol0<?l>oookJP[o0?mK
4ooonfX2o`0`o`gooo]Z0_nBo`04oookJP;o403o1_oonfX00ooo057ooo]ZoookJP03oookJP03ool0
NOoonf[ooo]Z00Kooo]Z00So0?mCoookJ_oonf[ooo]Zo`3o2?oonf[o0?lMo`3Qo`cooo]Z00Go0?ld
oookJ_oonf[ooo]Zo`3oCP05oookJP03o`28oooonf[o0:Wo00?ooo]Z00?o00CooookJ_l0e?l03ooo
nfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00?ooeL0oookJ_oonfX0:ooo
nfX002gooo]Z00Oo0?oOocd0oomho`3ooo]Zo`3Loooonf[o?ol000;ooo]Z00Go02[ooookJ_oonf[o
oo]ZoomB0003oookJP03okWo0?oonf[ooo]Z00gooo]Z00?o07?ooookJ_oonfX05OoonfX00ooo0>[o
oo]ZoookJP03oookJPGoogT00_oonfX00ooo0?cooo]ZoookJP02oookJP09oaP0oooonf[ooo]Zool6
0?oonf[ojol0oookJ_oo0?Ko0:Ko00;ooo]Z00KoZ03ooookJ_oonf[oo`3ioookJ_l0Mol5ool00004
oc_o0?oonf[ooo]Zo`3ko`?ooo]Z0ooo:0001?mi0?ooobP0oil0oonco`05oookJP0:o`3og_oonf[o
oo]ZoookJ_oo06coC@3oool^0?oonf[oH@3oo`3oA@Cooo]Z00?o0?n@oookJ_l0oi801_oonfX01_mX
0?oooo]ZoookJ_oonf[o603oonKo00KoobP01_oonfX00ooo_P3o0?l5og00o`05oookJP03oomG0?oo
nf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX03_oonfX01?l0e?oo00CooookJ_l0R?l4oookJP03o`3o
C_l0ocCooo]Z00Sooo]Z00Co0?lMo`3o2?l0003o00001_oonfX00ooo07Wooo]ZoookJP06oookJPGo
U?l000?oT_l0oiCo0?nDo`001?oonfX3ool00003o`0`oooonf[ooo]Z00[ooo]Z1ol0oe/:oookJP_o
0?mK2_oonfX2o`0`o`gooo]Z00?oT_l0oookJ_oonfX00ooonfX00ol@0?oooo]ZoookJP04oookJP;o
o`1A0ooonfX00oooN@3ooo]ZoookJP02oookJP03oomi0?oonf[ooo]Z00;ooo]Z00So0?mCoookJ_oo
nf[ooo]Zo`3o2?l0oagooo]Zo`3Qo`cooo]Z00Co0?ldoookJ_oonf[o0?m>1OoonfX01?l0R?oooo]Z
oookJ_l0ZOl4oiCo0003o`3DoonDo`3ooo]Z00gooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02go
oo]ZoookJP07oookJP03oomG0?oonf[ooo]Z05Gooo]Z00Oo0?oOocd0oomho`3ooo]Zo`3Loooonf[o
?ol000?ooo]Z00Go02[ooookJ_oonf[ooe80o`3o<`02oookJP03okWo0?oonf[ooo]Z00gooo]Z00?o
07?ooookJ_oonfX05OoonfX00ooo0>[ooo]ZoookJP04oookJP03oolF0?oonf[ooi8000Cooo]Z00?o
o`3loookJ_oonfX00_oonfX02?lH0?oooo]Zool60?oonf[ojol0oookJ_oo0?Ko0:Ko0_oonfX03?nX
0?oooo]ZoookJ_oo0?Wooo]Zo`1goooonf[o0?nJoom/0?ooP@3ooo]Zoc_o00?ooo]Z00_o0?_ooook
J_oonf[ooo]Zool30?oonf[oN@3oool0gOl05ooo0:?ook?o0004oookJP0;o`3og_oonf[ooo]Zoook
J_oo06cooo]Zodd0oooo;P3oH@3ooookJ_l0odD00ooonfX01?l0oi3ooo]ZoookJ_l0oi85oookJP03
ofP0oooonf[ooo]Z00;ooo]Z00Go603oo`1doooonf[ooo]Zoon@0008oookJP04oonn0?oonf[o0?l5
og00o`Gooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@0@oookJP05o`3Dool01?oooo]ZoookJ_l0R?l0
1?oonfX00ol0odko0?ldoookJP07oookJP04o`3o7Ol0o`So0000o`0000Oooo]Z00?oo`1ioookJ_oo
nfX01OoonfX2oa00o`?ooo]Z00?oT_l0oookJ_oonfX01OoonfX3o`0`o`cooo]Z1ol0oe/:oookJP_o
0?mK2_oonfX3o`0`o`cooo]Z00?oT_l0oookJ_oonfX00ooonfX00ol@0?oooo]ZoookJP04oookJP;o
o`1A1?oonfX00ooo07Wooo]ZoookJP06oookJP08o`3oDooonf[ooo]ZoookJ_l0o`Sooo]Zo`3o7Ol0
hOl<oookJP05o`3o=?oonf[ooo]Zo`3o;_l0odh01?oonfX01?l0R?oooo]ZoookJ_l0ZOl3oookJP03
o`04oooonf[o0=Co00kooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP07oookJP03
oomG0?oonf[ooo]Z02_ooo]Z000]oookJP07o`3ogolm0?ooN?l0oookJ_l0g?oooo]Zocoo0002oook
JP05o`0Zoooonf[ooo]ZoookJ_ooDP000_oonfX00onio`3ooo]ZoookJP0>oookJP03o`1coooonf[o
oo]Z01Cooo]Z00?oo`3ZoookJ_oonfX00ooonfX6oomi00;ooo]Z00?oo`3loookJ_oonfX00_oonfX0
2OlH0?oooo]ZoookJ_oo1P3ooo]Zon_o0?oo0?Kooo]Zo`2Vo`02oookJP05ojP0oooonf[oo`3ioook
J_l0Mol01Ooo00001?lko`3oo`00oookJ_l0nol4oookJP03oolX0?oonf[oN@3o00;oobP000?o0:?o
ok?o0?oonfX01?oonfX01_l0omkooo]ZoookJ_oo06cooo]Zodd0o`;ooo]Z00?oH@3oo`3oAOoonfX0
0ooonfX00ol0oi3o0?nBoookJP05oookJP03ofP0oooonf[ooo]Z00;ooo]Z00?o603ooookJ_oonfX0
1Ooo:005oookJP04oonn0?l0o`Gooo]Zog00o`Cooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02go
oo]ZoookJP0>oookJP04o`3Dool01?oooo]Zo`28o`Cooo]Z00?o0?m>o`3o=?oonfX02?oonfX00ol0
oago0000o`000002o`0000Cooo]Z0_oo07T7oookJP;oU?l00_oonfX00onDo`3oT_l0oi;o0002oiCo
00Koo`002?oonfX7o`3oFacooo]Z1_l0oe/6oookJP?o033o2ooonfX00onBo`3ooo]ZoookJP03oook
JP03oa00oooonf[ooo]Z00Gooo]Z00Goo`1AoookJ_oonf[ooo]Zoomi0002oookJP;oogT01OoonfX0
2?l0oe?ooo]ZoookJ_oonf[o0?l8o`3o7Ooonf[o0>7o3?oonfX01?l0ocCooo]Zo`3oC_l0obh5oook
JP04o`28oooonf[o0:WooookJPCoU?l000?o0=CooookJ_oonfX03OoonfX00oooP@3ooo]ZoookJP0:
oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX0E?oonfX01ol0omoo?@3oogSo0?oo
nf[o0=cooookJ_loo`000_oonfX02?l0:_oooo]ZoookJ_oonf[ooe80o`3o<ooonf[o^Ol04?oonfX0
0ol0Looooo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooaH0oonB0?oonfX01?oonfX0
0ooo0?cooo]ZoookJP02oookJP08oaP0oooonf[oo`H0oookJ_o[o`3oo`3foookJ_l0Y_l2oookJP0;
ojP0oooonf[ooo]Zool0nOl0Mooooo]Zo`3oV_ooK03ooh40o`3oc?lko`000ooonfX00ol0nooooo]Z
oookJP02oookJP06ool30?mi0?ooo`3MoookJ_l0Xooo/ol01OoonfX01?l0omkooo]ZoookJ_oo06`2
oookJP05odd0oooonf[oH@3ooookJ_l0odD00ooonfX00ol0oi3ooo]Zo`3oTP06oookJP06ofP0oooo
nf[ooo]ZoookJ_lH0?oo07Co0_oonfX00oooT03ooo]ZoookJP06oookJP04oonn0?oonf[o0?l5og00
o`Gooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@0@oookJP05o`3Dool01?oooo]ZoookJ_l0R?l01?oo
nfX00ol0odko0?ldoookJP07oookJP03o`3o7Ol0003o000000;o00001OoonfX2ool0N@Kooo]Z0_l@
0?l3oookJP;oT_l01_oonfX2o`0`o`Sooo]Z1ol0oe/LoookJPKo0?mK1ooonfX2o`0`o`_ooo]Z00?o
T_l0oookJ_oonfX00ooonfX00ol@0?oooo]ZoookJP05oookJP03ool0DOoonf[ooo]Z00;ooo]Z00?o
o`1ioookJ_oonfX01_oonfX02?l0oe?ooo]ZoookJ_oonf[o0?l8oookJ_l0oago0>7o3?oonfX01?l0
ocCooo]ZoookJ_l0odh5oookJP03o`28oooonf[o0:Wo00Cooo]Z00?o00Coo`3DoooonfX03_oonfX0
0oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00?ooeL0oookJ_oonfX0:_oonfX0
02cooo]Z00Oo0?oOocd0oomho`3ooo]Zo`3Loooonf[o?ol000?ooo]Z00Go02[ooookJ_oonf[ooe80
o`3o<`02oookJP03okWo0?oonf[ooo]Z00gooo]Z00?o07?ooookJ_oonfX05OoonfX00ooo0>[ooo]Z
oookJP03oookJPKoogT000?ooo]Zool0o?oonfX01?oonfX02?lH0?oooo]Zool60?oonf[ojol0oook
J_oo0?Ko0:Ko0_oonfX01_nX0?oooo]ZoookJ_oo0?Wooo]Zo`1go`Goo`0000Co>ol0ool00?oonf[o
0?_o1?oonfX01_oo:03ooo]ZoolX0?oo:03o0:?ook?o00Gooo]Z00[o0?oNoookJ_oonf[oo`1/oook
J_m=0?ooobh0oookJ_mQ0?oo0?m51?oonfX00ol0oi3ooo]Zo`3oTP05oookJP03ofP0oooonf[ooo]Z
00;ooo]Z00Ko603oonKo0?oonf[ooo]ZoolX0?oonfX3oolX00Gooo]Z00?ookh0o`3o1Om`0?l01?oo
nfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00gooo]Z00Co0=Coo`04oooonf[o08So
1?oonfX00ol0odko0?ldoookJP07oookJP03o`3o2?l0oagooo]Z00Go00000_oonfX00ooo07Wooo]Z
oookJP05oookJP;oU?l00ooonfX2oi;o00?oU?l01_oo0004oookJPGo0?mK:OoonfX2o`3oF`Oooo]Z
0_l0<?l:oookJP03oi;o0?oonf[ooo]Z00?ooo]Z00?o403ooookJ_oonfX01OoonfX2ool0D@;ooo]Z
1OooN@05oookJP08o`3oDooonf[ooo]ZoookJ_l0o`So0?lMoookJ_l0hOl;oookJP04o`3o=?oonf[o
oo]Zo`3oCPGooo]Z00Go08SooookJ_oonf[o0:WooookJP04oiCo0003o`3Doooonf[ooo]Z00gooo]Z
00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z05?ooo]Z
00?o0?oOocd0oomho`000_oonfX00ol0g?oo?ol0oookJP02oookJP05o`0Zoooonf[ooo]ZoomB0?l0
oc<00_oonfX00onio`3ooo]ZoookJP0=oookJP03o`1coooonf[ooo]Z01Gooo]Z00?oo`3ZoookJ_oo
nfX01OoonfX00ooo5P3ooi80oookJP03oookJP03ool0o?oonf[ooo]Z00;ooo]Z00?o603ooookJ_oo
1P000_oonfX00oo[o`3oo`3fo`2Vo`02oookJP0<ojP0oooonf[ooo]Zool0nOoonf[o07Ooo`3oV_oo
nf[oof`0oon10?oonf[o>ol00ooonfX02ol0nooooo]ZoookJ_oonf[oo`<0oookJ_mi0?ooo`3Mo`2S
oonO0?oo/ol000Cooo]Z00Co0?oNoookJ_oonf[oo`1/0_oonfX01Om=0?ooobh0of40oooonf[o0?m5
00?ooo]Z00Co0?n@oookJ_oonf[o0?nB1OoonfX01_mX0?oooo]ZoookJ_oonf[o603oonKo00?ooo]Z
00?ooi00oookJ_oonfX01_oonfX00ooo_P3ooo]Zog00o`05oookJP03oomG0?oonf[ooo]Z00;ooo]Z
00?oo`0]oookJ_oonfX03OoonfX01Ol0e?oo00CooookJ_oonf[o08So00Cooo]Z00?o0?m>o`3o=?oo
nfX01_oonfX00ol0o`So0?lMoookJP05o`0000?ooo]Z00?oo`1ioookJ_oonfX01?oonfX2oa00o`?o
oo]Z0_nBo`06oookJP;o033o1OoonfX5o`3oFbWooo]Z0_l0oe/7oookJP?o033o2OoonfX00onBo`3o
oo]ZoookJP03oookJP03oa00oooonf[ooo]Z00Gooo]Z0_oo0543oookJP03ool0NOoonf[ooo]Z00Ko
oo]Z00So0?mCoookJ_oonf[ooo]Zo`3o2?oonf[o0?lMo`3Qo`_ooo]Z00Go0?ldoookJ_oonf[o0?l^
o`3oCP04oookJP04o`28oooonf[ooo]Zo`2Yo`?ooo]Z00?o00CooookJ_l0e?l03ooonfX00oooP@3o
oo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX0:_oonfX002cooo]Z
00Oo0?oOocd0oomho`3ooo]Zo`3Loooonf[o?ol000;ooo]Z00Go02[ooookJ_oonf[ooo]ZoomB0002
oookJP03okWo0?oonf[ooo]Z00kooo]Z00?o07?ooookJ_oonfX05?oonfX00ooo0>[ooo]ZoookJP03
oookJPOoogT000?ooo]Zool0o?oonfX00ooonfX02OlH0?oooo]ZoookJ_oo1P3ooo]Zon_o0?oo0?Ko
oo]Zo`2Vo`02oookJP07ojP0oooonf[ooo]Zool0nOl0Mooooo]Zo`3oVP03ool00004oc_o0?oo003o
oo]Zo`3ko`Cooo]Z00?oobP0oookJ_mi0?l00_oo:0000onco`3ooo]ZoookJP04oookJP0:o`3og_oo
nf[ooo]Zool0K?m=0?ooobh0oookJ_mQ0?oooo]Zo`3oA@?ooo]Z00?o0?n@oookJ_l0oi801_oonfX0
1_mX0?oooo]ZoookJ_oonf[o603oonKo00;ooo]Z00GoobP0oookJ_oonf[ooo]ZoolX0005oookJP03
oonn0?l0o`GoL03o00Cooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP0=oookJP05
o`3Doooonf[o00CooookJ_l0R?l00ooonfX00ol0odko0?ldoookJP07oookJP;o0?lM0_oonfX4o`00
0003oookJ_oo07Woo`1i00Kooo]Z0_nDo`03oookJP;oT_l00ooo00000onDo`3oo`00ool00004ool0
00;ooo]Z0ol0oe/`oookJP;o0?mK1ooonfX3o`0`o`Sooo]Z0_nBo`04oookJP03oa00oooonf[ooo]Z
00Kooo]Z00?oo`1AoookJ_ooN@001OooN@04oookJP06o`3oDooonf[ooo]ZoookJ_l0o`So0?lM0_oo
nfX00ol0hOoooo]ZoookJP09oookJP04o`3o=?oonf[o0?m>o`3o;PGooo]Z00?o08SooookJ_l0ZOl0
0ooonfX2oiCo0003o`3Doooonf[ooo]Z00gooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]Z
oookJP06oookJP03oomG0?oonf[ooo]Z05?ooo]Z00Oo0?oOocd0oomho`3ooo]Zo`3Loooonf[o?ol0
00;ooo]Z00So02[ooookJ_oonf[ooo]ZoomB0?l0oc?ooo]ZokWo013ooo]Z00?o07?ooookJ_oonfX0
5?oonfX00ooo0>[ooo]ZoookJP05oookJP03oolF0?oonf[ooi8000Cooo]Z00?oo`3loookJ_oonfX0
0_oonfX02?lH0?oooo]Zool60?oonf[ojol0ool0m_oonf[o0:Ko0_oonfX03?nX0?oooo]ZoookJ_oo
0?Wo07OooookJ_l0oi[oof`0oookJ_ooP@3ooo]Zoc_o00;ooo]Z00?o0?_ooookJ_oonfX00_oonfX0
1_oo0`3oN@3oool0gOoonf[o0:?ook?o00Gooo]Z00So0?oNoookJ_oonf[oo`1/oookJ_m=0?ooobh0
of40o`;ooo]Z00Co0?m5oookJ_oonf[o0?n@0_oonfX00ol0oi;ooo]ZoookJP03oookJP03ofP0oooo
nf[ooo]Z00;ooo]Z00Go603oo`1doooonf[ooo]Zoon@0008oookJP04oonn0?oonf[o0?l5og00o`Co
oo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP0=oookJP03o`3Doooonf[o00Co00;o
oo]Z00Ko08SooookJ_oonf[ooo]Zo`3oC_l0oc@7oookJP;o0?lM0_oonfX4o`0000;ooo]Z0_oo07T5
oookJP;o403o0ooonfX2oi;o00Kooo]Z0_l0<?l4oookJP?o0?mK<?oonfX2o`3oF`Sooo]Z0_l0<?l8
oookJP;oT_l01?oonfX00ol@0?oooo]ZoookJP06oookJP05ool0DOoonf[ooo]ZoookJ_oo07T01ooo
nfX02Ol0oe?ooo]ZoookJ_oonf[o0?l8oookJ_l0oagooo]Zo`3Qo`0;oookJP04o`3o=?oonf[ooo]Z
o`3oCPGooo]Z00?o08SooookJ_l0ZOl01?oonfX00ol01?oooo]Zo`3Do`0>oookJP03oon10?oonf[o
oo]Z00[ooo]Z00?oo`0]oookJ_oonfX01ooonfX00oooE`3ooo]ZoookJP0ZoookJP00;?oonfX01ol0
omoo?@3oogSo0?oonf[o0=cooookJ_loo`000_oonfX01Ol0:_oooo]ZoookJ_oonf[ooe8000;ooo]Z
00?o^Ol0oookJ_oonfX03OoonfX00ol0Looooo]ZoookJP0EoookJP03ool0j_oonf[ooo]Z00?ooo]Z
1oooN@000ooo0?cooo]ZoookJP03oookJP08oaP0oooonf[oo`H0oookJ_o[o`3ooo]Zool0m_l0Y_l2
oookJP09ojP0oooonf[ooo]Zool0nOoonf[o07Ooo`3oV_ooK03o0?o<00;oo`0000?o>ol0ool00?l0
nol01OoonfX01_oo:03ooo]ZoolX0?oo:03o0:?ook?o00Gooo]Z00Ko0?oNoookJ_oonf[oo`1/oook
J_m=0?l2oookJP03of40ool0odGooo]Z00?ooo]Z00?o0?n@oookJ_l0oi801OoonfX00omX0?oooo]Z
oookJP02oookJP04oaP0oooVo`3ooo]ZoolX00Wooo]Z00?ookh0o`3o1Om`0?l01OoonfX00oooE`3o
oo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00gooo]Z00Go0=CooookJ_l01?oooo]Zo`28o`03oook
JP03o`3oC_l0ocCooo]Z00Oooo]Z00?o0?lMoookJ_oonfX00_oonfX4o`000003ool0NOoonf[ooo]Z
00Cooo]Z00?o403ooiCo0?oonfX00_oonfX2oi;o00_oo`0000?ooo]Zo`3oFol0oe/0=OoonfX2o`3o
F`Sooo]Z0ol0<?l7oookJP03oi;o0?oonf[ooo]Z00;ooo]Z00?o403ooookJ_oonfX01_oonfX00ooo
057oogT0oomi0004oomi00Gooo]Z00Ko0?mCoookJ_oonf[ooo]Zo`3o2?l0oad2oookJP03o`3Qoooo
nf[ooo]Z00Wooo]Z00?o0?ldoookJ_l0odh01_oonfX00ol0R?oooo]Zo`2Yo`03oookJP;oU?l000?o
0=CooookJ_oonfX03?oonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?o
oeL0oookJ_oonfX0D_oonfX01ol0omoo?@3oogSo0?oonf[o0=cooookJ_loo`000_oonfX02?l0:_oo
oo]ZoookJ_oonf[ooe80o`3o<ooonf[o^Ol03ooonfX00ol0Looooo]ZoookJP0EoookJP03ool0j_oo
nf[ooo]Z00Gooo]Z00?ooaH0oonB0?oonfX00ooonfX00ooo0?cooo]ZoookJP03oookJP07oaP0oooo
1P3ooo]ZoookJ_o[o`3oo`3fo`2Vo`02oookJP0<ojP0oooonf[ooo]Zool0nOoonf[o07Ooo`3oV_oo
K03ooo]Zoon10?oonf[o>ol00_oonfX00ol0nooooo]ZoookJP02oookJP07ool30?oonf[oo`3Moook
J_l0Xooooo]Zok?o0004oookJP04o`3og_oonf[ooo]Zool0K0;ooo]Z00GoC@3ooookJ_mQ0?oooo]Z
o`3oA@03oookJP04o`3oT?oonf[ooo]Zo`3oTPGooo]Z00KoJ03ooookJ_oonf[ooo]ZoaP0oooVo`02
oookJP03oon@0?oonf[ooo]Z00Kooo]Z00Cookh0oookJ_l0o`GoL03o1OoonfX01OooE`3ooo]Zoook
J_oonf[oo`0]00oooo]Z00?o0=CooookJ_l01?l00_oonfX01_l0R?oooo]ZoookJ_oonf[o0?m>o`3o
=0Oooo]Z00?o0?lMoookJ_oonfX00_oonfX4o`000003oookJ_oo07Wooo]Z00Cooo]Z0_l@0?l3oook
JP;oT_l01_oonfX2o`0`o`Cooo]Z0_l0oe/eoookJP;o0?mK2?oonfX3o`0`o`Oooo]Z00?oT_l0oook
J_oonfX00_oonfX00ol@0?oooo]ZoookJP06oookJP05ool0DOoonf[ooo]ZoookJ_oo07T01ooonfX0
2Ol0oe?ooo]ZoookJ_oonf[o0?l8oookJ_l0oagooo]Zo`3Qo`0;oookJP04o`3o=?oonf[o0?l^o`3o
CPGooo]Z00?o08SooookJ_l0ZOl01?oonfX00ol01?oo0=CooookJP0=oookJP03oon10?oonf[ooo]Z
00[ooo]Z00?oo`0]oookJ_oonfX02?oonfX00oooE`3ooo]ZoookJP0YoookJP00;?oonfX01?l0omoo
N?l0oookJ_l0g?l2oookJP03ocoo0?oonf[o02[o00?ooo]Z00Cooe80o`3o<ooonf[o^Ol04?oonfX0
0ol0Looooo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z00?ooo]Z2?ooN@000ooo0?cooo]ZoookJP02
oookJP09oaP0oooonf[ooo]Zool60?oonf[ojol0oookJ_oo0?Ko0:Ko00;ooo]Z00koZ03ooookJ_oo
nf[oo`3io`1goooonf[o0?nJoom/0?oo003ooo]Zoc_o0?oonf[oo`00o`3ko`Cooo]Z00?oobP0oook
J_oo:0000_oo:0000onco`3oobP0oookJP04oookJP0:o`3og_oonf[ooo]Zool0K?m=0?ooo`00oook
J_mQ0?oooo]Zo`3oA@?ooo]Z00?o0?n@oookJ_l0oi801_oonfX01_mX0?oooo]ZoookJ_oonf[o603o
onKo00;ooo]Z00?oobP0oookJ_oonfX01_oonfX01?oo_P3ooo]Zo`3o1Om`0?l4oookJP03oomG0?oo
nf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX03OoonfX01?l0e?oo00CooookJ_l0R?l3oookJP03o`3o
C_oonf[o0?ld00Oooo]Z00?o0?lMoookJ_oonfX00ooonfX3o`000003ool0NOoonf[ooo]Z00Cooo]Z
00Co403ooookJ_oonf[ooo]Z0_nBo`03oookJPWoo`000_l0oe/ioookJP;o0?mK2OoonfX2o`0`o`Ko
oo]Z00?oT_l0oookJ_oonfX00_oonfX00ol@0?oooo]ZoookJP04oookJP;oogT000?oobP0oomi0?oo
N@001?ooN@05oookJP06o`3oDooonf[ooo]ZoookJ_l0o`So0?lM0_oonfX00ooo:03ooo]ZoookJP08
oookJP04o`3o=?oonf[o0?m>o`3o;PGooo]Z00?o08SooookJ_l0ZOl01?oonfX2oiCo0003o`3Doooo
nf[ooo]Z00cooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP07oookJP03oomG0?oo
nf[ooo]Z05;ooo]Z00Wo0?oOogSo0?oonf[ooo]Zo`3Loooonf[o?ol0oookJ_l0:_l00ooonfX01?oo
DP3ooo]Zo`3o<onio`0@oookJP03o`1coooonf[ooo]Z01Cooo]Z00?oo`3ZoookJ_oonfX01_oonfX0
0ooo5P3ooi80oookJP03oookJP03ool0o?oonf[ooo]Z00;ooo]Z00So603ooookJ_oo1P3ooo]Zon_o
0?oonf[oo`3fo`2Vo`;ooo]Z00coZ03ooookJ_oonf[oo`3io`1goooonf[o0?nJoom/0?oonf[ooh40
oookJ_lko`02oookJP03o`3koooonf[ooo]Z00;ooo]Z00Koo`<0oookJ_oo0=gooo]Zo`2Soonco`05
oookJP08o`3og_oonf[ooo]Zool0K?oonf[oC@3oool^0?mQ0?l2oookJP04o`3oAOoonf[ooo]Zo`3o
T0;ooo]Z00?o0?nBoookJ_oonfX00ooonfX01_mX0?oooo]ZoookJ_oonf[o603oonKo00?ooo]Z00?o
oi00oookJ_oonfX01OoonfX01?oo_P3ooo]ZoookJ_m`0?l5oookJP03oomG0?oonf[ooo]Z00;ooo]Z
00?oo`0]oookJ_oonfX03OoonfX01Ol0e?oo00CooookJ_oonf[o08So00?ooo]Z00?o0?m>oookJ_l0
oc@01_oonfX00ol0oagooo]ZoookJP03oookJPCo000000?oo`1ioookJ_oonfX00ooonfX01?l@0?oo
oo]ZoookJ_oonfX2oi;o00Gooo]Z0ol0<?l4oookJP;o0?mK>OoonfX2o`3oF`Wooo]Z0_l0<?l6oook
JP03oi;o0?oonf[ooo]Z00;ooo]Z00?o403ooookJ_oonfX01_oonfX01Ooo057ooo]ZoookJ_oonf[o
o`1i00Oooo]Z00Ko0?mCoookJ_oonf[ooo]Zo`3o2?l0oad2oookJP03o`3Qoooonf[ooo]Z00Sooo]Z
00Co0?ldoookJ_oonf[o0?m>1OoonfX00ol0R?oooo]Zo`2Yo`04oookJP03o`04oooonf[o0=Co00ko
oo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z02Wo
oo]Z000[oookJP07o`3ogolm0?ooN?l0oookJ_l0g?oooo]Zocoo0002oookJP05o`0Zoooonf[ooo]Z
oookJ_ooDP000_oonfX00onio`3ooo]ZoookJP0=oookJP03o`1coooonf[ooo]Z01Gooo]Z00?oo`3Z
oookJ_oonfX00_oonfX8oomi0003ool0o?oonf[ooo]Z00?ooo]Z00?o603ooookJ_oo1P000_oonfX0
0oo[o`3oo`3fo`2Vo`02oookJP0>ojP0oooonf[ooo]Zool0nOoonf[o07Ooo`3oV_ooK03o0?o<ool0
0?oonf[o>ol0oookJ_l0nol5oookJPCoobP000?o0:?ook?o0?oonfX01?oonfX01Ol0omkooo]Zoook
J_oo06coC@3o00;oo`0000?oH@3ooookJ_l0odD01?oonfX00ol0oi3ooo]Zo`3oTP05oookJP06ofP0
oooonf[ooo]ZoookJ_lH0?ooi_l00_oonfX00ooo:03ooo]ZoookJP07oookJP03oonn0?l0o`GoL03o
00Cooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP0=oookJP04o`3Dool01?oooo]Z
o`28o`?ooo]Z00?o0?m>oookJ_l0oc@01_oonfX2o`3o7@Kooo]Z00Co0000ool0NOoo07Wo00001Ooo
nfX01Ol@0?oooo]ZoookJ_oonf[oT_l000Gooo]Z1_oo0003o`3oFcgooo]Z0_l0oe/9oookJP03o`0`
oooonf[ooo]Z00Cooo]Z0_nBo`03oookJP03oa00oooonf[ooo]Z00Gooo]Z00?oobP0oomi0?ooN@00
1?ooN@06oookJP05o`3oDooonf[ooo]ZoookJ_l0oad00_oonfX00ooo:03ooo]ZoookJP09oookJP03
o`3o=?oonf[o0?m>00Kooo]Z00?o08Soo`2YoooonfX01?oonfX00onDo`3o0=CooookJP0=oookJP03
oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX01_oonfX00oooE`3ooo]ZoookJP1AoookJP07
o`3ogolm0?ooN?l0oookJ_l0g?oooo]Zocoo0002oookJP08o`0Zoooonf[ooo]ZoookJ_ooDP3o0?lc
oookJ_nio`0?oookJP03o`1coooonf[ooo]Z01Gooo]Z00?oo`3ZoookJ_oonfX01OoonfX00ooo5P3o
oi80oookJP03oookJP03ool0o?oonf[ooo]Z00?ooo]Z00Oo603oool60?oonf[ooo]Zon_o0?oo0?Ko
0:Ko00;ooo]Z00coZ03ooookJ_oonf[ooo]Zool0nOl0Mooo0?nJoom/0?oonf[ooh40oookJ_lko`02
oookJP03o`3koooonf[ooo]Z00;ooo]Z00Ooo`<0oookJ_oo0=gooo]Zo`2Soonco`3oW`3o00Cooo]Z
00So0?oNoookJ_oonf[oo`1/oookJ_m=0?ooobh0of40o`;ooo]Z00Go0?m5oookJ_oonf[ooo]Zo`3o
T002oookJP03o`3oT_oonf[ooo]Z00?ooo]Z00KoJ03ooookJ_oonf[ooo]ZoaP0ool0M?l2oookJP03
oon@0?oonf[ooo]Z00Kooo]Z00?ookh0oookJ_m`0?l01OoonfX00oooE`3ooo]ZoookJP02oookJP03
ool0;Ooonf[ooo]Z00gooo]Z00Go0=Coo`04oooonf[ooo]Zo`28o`03oookJP03o`3oC_oonf[o0?ld
00Gooo]Z0_l0oad6oookJP;o00000_oo07T5oookJP05oa00oooonf[ooo]ZoookJ_nBo`001OoonfX2
o`0`o`Cooo]Z0ol0oe/moookJP;o0?mK2OoonfX00ol0<?oooo]ZoookJP04oookJP;oT_l00ooonfX0
0ol@0?oooo]ZoookJP05oookJP03ool0DOoonf[ooo]Z00;ooo]Z00?oo`1ioookJ_oonfX01OoonfX0
2?l0oe?ooo]ZoookJ_oonf[o0?l8o`3o7Ooonf[o0>7o2ooonfX01?l0ocCooo]ZoookJ_l0odh5oook
JP03o`28oooonf[o0:Wo00Cooo]Z00?o00Coo`3DoooonfX03OoonfX00oooP@3ooo]ZoookJP0:oook
JP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX0:OoonfX002_ooo]Z00Wo0?oOoookJ_mh
o`3ooo]Zo`3Loooonf[o?ol0oookJ_l0:_l01?oonfX01?ooDP3ooo]ZoookJ_nio`0?oookJP03o`1c
oooonf[ooo]Z01Cooo]Z00?oo`3ZoookJ_oonfX00ooonfX8oomi0003ool0o?oonf[ooo]Z00?ooo]Z
00So603ooookJ_oo1P3ooo]Zon_o0?oonf[oo`3fo`2Vo`;ooo]Z00_oZ03ooookJ_oonf[oo`3io`1g
oooonf[o0?nJoom/0?oonf[oo`00oc_o0002oookJP03o`3koooonf[ooo]Z00;ooo]Z00OoobP0oook
J_oo:03oobP0o`2Soonco`3oobP000Gooo]Z00Wo0?oNoookJ_oo06cooo]Zodd0oooo003ooo]Zof40
ool0odD01?oonfX00ol0oi3ooo]Zo`3oTP05oookJP03ofP0oooonf[ooo]Z00;ooo]Z00Co603oonKo
0?oonf[oobP02OoonfX00ooo_P3o0?l5og00o`04oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]
oookJ_oonfX03OoonfX01?l0e?oo00CooookJ_l0R?l3oookJP03o`3oC_oonf[o0?ld00Kooo]Z00?o
0?lMo`3o2?oonfX01_oonfX01?oo07Wo0000o`000?l00003oookJP;o403o0_oonfX2oi;o00Cooo]Z
0_oo00001?oonf[oo`00ool00?oo0002o`3oFd;ooo]Z0_l0oe/8oookJP03o`0`oooonf[ooo]Z00Go
oo]Z00GoT_l0oookJ_oonf[ooo]Zoa00o`07oookJP03oolX0?ooN@3oogT000CoogT01OoonfX00ol0
oe?ooo]ZoookJP02oookJP04o`3o7Ooonf[ooo]ZoolX00[ooo]Z00Co0?ldoookJ_l0odko0?l^1_oo
nfX00ol0R?oo0:WooookJP04oookJP03oiCo0?l0e?oooo]Z00cooo]Z00?ooh40oookJ_oonfX02_oo
nfX00ooo02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z053ooo]Z00Oo0?oOoookJ_mho`3ooo]Z
o`3Loooonf[o?ol000;ooo]Z00So02[ooookJ_oonf[ooo]ZoomB0?l0oc?ooo]ZokWo00oooo]Z00?o
07?ooookJ_oonfX05OoonfX00ooo0>[ooo]ZoookJP05oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00?o
o`3loookJ_oonfX00_oonfX00olH0?oooo]Zool60002oookJP03on_o0?oo0?Ko0:Ko00;ooo]Z00co
Z03ooookJ_oonf[oo`3io`1goooonf[o0?nJoom/0?l0olcooh40oookJ_lko`02oookJP03o`3koooo
nf[ooo]Z00;ooo]Z00Koo`<0oookJ_oo0=go0:?oo`0Goonco`05oookJP03o`3og_oonf[oo`1/00;o
oo]Z00GoC@3oool^0?mQ0?oooo]Zo`3oA@03oookJP04o`3oT?oonf[ooo]Zo`3oTPGooo]Z00KoJ03o
oookJ_oonf[ooo]ZoaP0oooVo`02oookJP03oon@0?oonf[ooo]Z00Kooo]Z00?ookh0oookJ_m`0?l0
1OoonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00gooo]Z00Go0=Coo`04oooonf[o
oo]Zo`28o`03oookJP03o`3oC_oonf[o0?ld00Gooo]Z00?o0?lMo`3o2?oonfX01_oonfX01?l0003o
o`1io`000?l00004oookJP03oa00oooonf[ooo]Z00;oT_l01?oonfX2o`0`o`Cooo]Z0_l0oe]2oook
JP;o0?mK2?oonfX00ol0<?oooo]ZoookJP05oookJP04oi;o0?oonf[ooo]ZoookJP;o403o1_oonfX0
0ooo057ooo]ZoookJP02oookJP03ool0NOoonf[ooo]Z00Cooo]Z00?o0?mCoookJ_oonfX00_oonfX0
1?l0o`So0?lMoookJ_l0hOl:oookJP04o`3o=?oonf[ooo]Zo`3oCPKooo]Z00?o08Soo`2YoooonfX0
1?oonfX00ol01?oo0=CooookJP0<oookJP03oon10?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX0
1ooonfX00oooE`3ooo]ZoookJP0XoookJP00:ooonfX01?l0omooN?l0oookJ_l0g?l2oookJP03ocoo
0?oonf[o02[o00Cooo]Z00?ooe80oookJ_nio`004?oonfX00ol0Looooo]ZoookJP0DoookJP03ool0
j_oonf[ooo]Z00;ooo]Z2?ooN@000ooo0?cooo]ZoookJP03oookJP03oaP0oooonf[oo`H000;ooo]Z
00Kojol0ool0m_oonf[o0:KooookJ_nX0?l2oookJP0;ool0nOoonf[o07OooookJ_ooK03o0?o<ool0
0?oonf[o>ol0oookJ_l0nol01OoonfX4oolX0003o`2Soonco`3oobP000Cooo]Z00Go0?oNoookJ_oo
nf[oo`1/odd0o`02ool00003of40oooonf[o0?m500?ooo]Z00?o0?n@oookJ_l0oi801_oonfX01_mX
0?oooo]ZoookJ_oonf[o603oonKo00;ooo]Z00?oobP0oookJ_oonfX01_oonfX00ooo_P3o0?l5og00
o`04oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX03OoonfX01Ol0e?oo00Cooook
J_oonf[o08So00;ooo]Z00?o0?m>oookJ_l0oc@01_oonfX00ol0oago0?l8oookJP05oookJP;oo`1i
1?l00002oookJP03oa00oooonf[ooo]Z00;oT_l01?oonfX2ool000?ooo]Z00Coo`00o`3oFol0oe_o
o`00AOoonfX2o`3oF`Oooo]Z00?o033ooookJ_oonfX01OoonfX01OnBo`3ooo]ZoookJ_oonf[o403o
00Oooo]Z00?oobP0oomi0?ooN@001?ooN@05oookJP05o`3oDooonf[ooo]ZoookJ_l0oad00_oonfX0
0ooo:03ooo]ZoookJP09oookJP03o`3o=?oonf[o0?m>00Kooo]Z00?o08Soo`2YoooonfX01?oonfX0
0ol01?oo0=CooookJP0=oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX01_oonfX0
0oooE`3ooo]ZoookJP1@oookJP09o`3ogomho`3ooo]ZoookJ_l0g?oooo]Zocoo0?oonf[o02[o00Co
oo]Z00?ooe80o`3o<onio`004?oonfX00ol0Looooo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z00Ko
oo]Z00?ooaH0oonB0?oonfX00_oonfX00ooo0?cooo]ZoookJP03oookJP0:oaP0oooo1P3ooo]Zoook
J_o[o`3oo`3foookJ_l0Y_oooo]ZojP0o`?ooo]Z00Soo`3io`1goooonf[oof`0oookJ_ooP@3ooo]Z
oc_o00;ooo]Z00?o0?_ooookJ_oonfX00_oonfX01ooo0`3ooo]Zool0gOoonf[o0:?ook?o0?nO0?l0
1?oonfX02?l0omkooo]ZoookJ_oo06cooo]Zodd0oooo;P3oH@3o0_oonfX01?l0odGooo]ZoookJ_l0
oi02oookJP03o`3oT_oonf[ooo]Z00?ooo]Z00KoJ03ooookJ_oonf[ooo]ZoaP0oooVo`03oookJP03
oon@0?oonf[ooo]Z00Gooo]Z00Cookh0oookJ_l0o`GoL03o1?oonfX00oooE`3ooo]ZoookJP02oook
JP03ool0;Ooonf[ooo]Z00gooo]Z00Go0=Coo`04oooonf[ooo]Zo`28o`03oookJP03o`3oC_oonf[o
0?ld00Gooo]Z00?o0?lMo`3o2?oonfX01_oonfX2ool0N@?o00000_oonfX2oa00o`03oookJ_nBo`3o
T_l000Cooo]Z0_l0<?l4oookJP;o0?mKA_oonfX2o`3oF`Oooo]Z00?o033ooookJ_oonfX01OoonfX0
0onBo`3ooo]ZoookJP02oookJP03oa00oooonf[ooo]Z00Cooo]Z00?oo`1AoookJ_oonfX00_oonfX0
0ooo07Wooo]ZoookJP04oookJP08o`3oDooonf[ooo]ZoookJ_l0o`So0?lMoookJ_l0hOl;oookJP04
o`3o=?oonf[ooo]Zo`3oCPGooo]Z00?o08SooookJ_l0ZOl01?oonfX00ol01?oooo]Zo`3Do`0=oook
JP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX01ooonfX00oooE`3ooo]ZoookJP0Xoook
JP00:ooonfX01_l0omooN?l0oookJ_l0g?oooo]Zocoo00;ooo]Z00So02[ooookJ_oonf[ooo]ZoomB
0?l0oc?ooo]ZokWo00oooo]Z00?o07?ooookJ_oonfX05?oonfX00ooo0>[ooo]ZoookJP03oookJPKo
ogT00_oonfX00ooo0?cooo]ZoookJP03oookJP08oaP0oooonf[oo`H0oookJ_o[o`3ooo]Zool0m_l0
Y_l2oookJP0;ojP0oooonf[ooo]Zool0nOl0Mooooo]Zoom/0?l0olcooo]Zool00?lko`000_oonfX0
0ol0nooooo]ZoookJP02oookJP?oobP000?oN@3oo`2Soonco`000_oo:003oookJP06o`3og_oMo`3o
oo]Zool0K?oo003oC@3o0_oo00000omQ0?oo0?m5oookJP03oookJP03o`3oT?oonf[o0?nB00Gooo]Z
00WoJ03ooookJ_oonf[ooo]ZoaP0ool0M?ooi_l0oookJ_oo:0002?oonfX01?oo_P3ooo]Zo`3o1Om`
0?l3oookJP03oomG0?oonf[ooo]Z00Cooo]Z00?oo`0]oookJ_oonfX03?oonfX01Ol0e?oooo]Zo`04
oooonf[o08So00;ooo]Z00?o0?m>oookJ_l0oc@01_oonfX00ol0oago0?l8oookJP05oookJP03ool0
NOoonf[ooo]Z00Co000000?ooo]Zoa00oooonfX00_nBo`04oookJP;oo`000ooonfX3o`3oF`;oo`00
B?oonfX2o`3oF`Kooo]Z00?o033ooookJ_oonfX01OoonfX01OnBo`3ooo]ZoookJ_oonf[o403o00Ko
oo]Z00?oobP0oookJ_oonfX01?ooN@06oookJP05o`3oDooonf[ooo]ZoookJ_l0oad00_oonfX00ooo
:03ooo]ZoookJP09oookJP03o`3o=?l0odko0?l^00Kooo]Z00?o08Soo`2YoooonfX01?oonfX00ol0
1?oo0=CooookJP0<oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX01_oonfX00ooo
E`3ooo]ZoookJP1@oookJP06o`3ogomho`3ooo]Zo`3Loooonf[o?ol00_oonfX02?l0:_oooo]Zoook
J_oonf[ooe80o`3o<ooonf[o^Ol03ooonfX00ol0Looooo]ZoookJP0EoookJP03ool0j_oonf[ooo]Z
00Gooo]Z00?ooaH0oonB0?oonfX00ooonfX00ooo0?cooo]ZoookJP03oookJP07oaP0oooo1P3ooo]Z
oookJ_o[o`3oo`3fo`2Vo`02oookJP0<ojP0oooonf[ooo]Zool0nOl0Mooooo]Zo`3oV_ooK03o0?o<
oon10?oonf[o>ol00_oonfX00ol0nooooo]ZoookJP02oookJP06ool30?oo0=goN@3oo`2Sool05ooo
/ol01?oonfX01?l0omkogOl0oookJ_oo06`2oookJP05odd0oooo;P3oH@3ooookJ_l0odD00ooonfX0
1?l0oi3ooo]ZoookJ_l0oi85oookJP06ofP0oooonf[ooo]ZoookJ_lH0?ooi_l00_oonfX00oooT03o
oo]ZoookJP05oookJP04oonn0?oonf[ooo]Zog00o`Cooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo
02gooo]ZoookJP0<oookJP03o`3Doooonf[o00Co00;ooo]Z00Ko08SooookJ_oonf[o0?m>oookJ_l0
oc@5oookJP03o`3o7Ol0o`Sooo]Z00Kooo]Z00?oo`1ioookJ_l000000ol000000ooonf[o403ooook
JP02oi;o00Cooo]Z0_l0<?l3oookJP?o0?mKB_oonfX2o`3oF`Kooo]Z00?o033ooookJ_oonfX01Ooo
nfX00onBo`3ooo]ZoookJP02oookJP03oa00oooonf[ooo]Z00Cooo]Z00?oo`1AoookJ_oonfX00_oo
nfX00ooo07Wooo]ZoookJP04oookJP08o`3oDooonf[ooo]ZoookJ_l0o`So0?lMoookJ_l0hOl;oook
JP03o`3o=?oonf[o0?m>00Kooo]Z00?o08Soo`2YoooonfX01?oonfX00ol01?oo0=CooookJP0<oook
JP03oon10?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX01_oonfX00oooE`3ooo]ZoookJP0Xoook
JP00:_oonfX02Ol0omoooo]ZogSo0?oonf[o0=cooookJ_loo`3ooo]Zo`0Zo`04oookJP03oomB0?oo
nf[o^Ol0013ooo]Z00?o07?ooookJ_oonfX05?oonfX00ooo0>[ooo]ZoookJP02oookJPOoogT000?o
oo]Zool0o?oonfX01?oonfX00olH0?oooo]Zool60002oookJP06on_o0?oo0?Kooo]Zo`2Voooonf[o
Z03o0_oonfX02Ooo0?Wooo]Zo`1goooonf[oof`0o`3oc?oo003ooo]Zoc_o0002oookJP03o`3koooo
nf[ooo]Z00;ooo]Z1?oo:0001?nco`3oW`3ooolX0?oo:003oookJP05o`3og_oonf[ooo]Zool0K?m=
0?l00_oo00000omQ0?oooo]Zo`3oA@03oookJP03o`3oT?oonf[o0?nB00Kooo]Z00KoJ03ooookJ_oo
nf[ooo]ZoaP0oooVo`02oookJP03oolX0?oonf[ooo]Z00Kooo]Z00?ookh0o`3o1Om`0?l01?oonfX0
0oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00cooo]Z00Go0=CooookJ_l01?oooo]Zo`28
o`02oookJP03o`3oC_oonf[o0?ld00Gooo]Z0_oo:0000ol0o`Sooo]ZoookJP03oookJP;oo`1i0ooo
nfX3o`0000;o403o00?ooo]Zoi;o0?oonfX01?oonfX01?oo003ooo]ZoookJ_oonfX2o`3oF`?ooo]Z
00?oo`00oookJ_oonfX05OoonfX=ob3o00oooo]Z0_ooN@0FoookJP;o0?mK1OoonfX00ol0<?oooo]Z
oookJP05oookJP;oT_l00_oonfX00ol@0?oooo]ZoookJP04oookJP03oolX0?oonf[ooo]Z00CoogT0
1_oonfX01ol0oe?ooo]ZoookJ_oonf[o0?lMoookJ_oo:0002ooonfX00ol0ocCooo]Zo`3oCP07oook
JP03o`2Yoooonf[ooo]Z00?ooo]Z00?o00CooookJ_l0e?l03?oonfX00oooP@3ooo]ZoookJP0:oook
JP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX0C_oonfX02Ol0omoooo]ZogSo0?oonf[o
0=cooookJ_loo`3ooo]Zo`0Zo`04oookJP03oomB0?l0oc?o^Ol0013ooo]Z00?o07?ooookJ_oonfX0
5?oonfX00ooo0>[ooo]ZoookJP06oookJP03oolF0?ooTP3ooo]Z00;ooo]Z00?oo`3loookJ_oonfX0
0ooonfX02_lH0?ooo`H0oookJ_oonf[ojol0ool0m_oonf[o0:KooookJ_nX0?l3oookJP08ool0nOl0
Mooooo]Zoom/0?oonf[o0?o<oon10?lko`03oookJP0;o`3koooonf[ooo]ZoookJ_oo0`3ooo]Zool0
gOoonf[o0:?ook?o0?nO0?l01?oonfX02?l0omkooo]ZoookJ_oo06cooo]Zodd0oooo;P3oH@3o0_oo
nfX01?l0odGooo]ZoookJ_l0oi02oookJP03o`3oT_oonf[ooo]Z00?ooo]Z00KoJ03ooookJ_oonf[o
oo]ZoaP0oooVo`03oookJP03oon@0?oonf[ooo]Z00Gooo]Z00?ookh0oookJ_m`0?l01OoonfX00ooo
E`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00cooo]Z00?o0=CooookJ_l01?l00_oonfX01_l0
R?oooo]ZoookJ_l0odkooo]Zo`3o=0Gooo]Z00?o0?lMo`3o2?oonfX01OoonfX2ool0N@;ooo]Z1?l0
00000ol@0?oooo]Zoi;o0005oookJP04o`0`oooonf[ooo]ZoookJP;o0?mK7?oonfX=ob3o02Kooo]Z
0_l0oe/5oookJP03o`0`oooonf[ooo]Z00Gooo]Z0_nBo`03oookJP03oa00oooonf[ooo]Z00?ooo]Z
00?oo`1AoookJ_oonfX00ooonfX00ooo07Wooo]ZoookJP04oookJP07o`3oDooonf[ooo]ZoookJ_l0
oagooo]Zo`3Qo`0;oookJP04o`3o=?oonf[ooo]Zo`3oCPKooo]Z00?o08Soo`2YoooonfX00ooonfX0
0ol01?oooo]Zo`3Do`0<oookJP03oon10?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX01ooonfX0
0oooE`3ooo]ZoookJP0WoookJP00:_oonfX01?l0omooN?l0oookJ_l0g?l2oookJP03ocoo0?oonf[o
02[o00Cooo]Z00?ooe80oookJ_nio`004?oonfX00ol0Looooo]ZoookJP0DoookJP04ool0j_oonf[o
oo]ZoookJPSoogT000?ooo]Zool0o?oonfX01?oonfX02olH0?oooo]Zool60?oonf[ojol0oookJ_oo
0?Kooo]Zo`2Voooonf[oZ03o00;ooo]Z00Soo`3ioookJ_l0Moooof`0o`3oc?oonf[oo`00oc_o00;o
oo]Z00?o0?_ooookJ_oonfX00_oonfX01_oo:03ooo]ZoolX0?mi0?oo0:?ook?o00;oobP00ooonfX0
2_l0omkooo]ZoookJ_oo06coo`00odd0oooo003oH@3oool00?l0odD4oookJP03o`3oT?oonf[o0?nB
00Gooo]Z00WoJ03ooookJ_oonf[ooo]ZoaP0ool0M?ooi_l0oookJ_oo:0002?oonfX00ooo_P3o0?l5
og00o`04oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX03?oonfX01Ol0e?oooo]Z
o`04oooonf[o08So00;ooo]Z00?o0?m>oookJ_l0oc@01OoonfX3oolX00Gooo]Z00?oo`1ioookJ_oo
nfX00ooonfX2o`000004oa00ool0003ooo]Zoi;o00Sooo]Z0_l0oe/IoookJPCo8?l000?ooo]ZobH0
oolV0?l02olV0?l:ob3o00Cooo]Z0oooN@0GoookJP03o`3oFooonf[ooo]Z00?ooo]Z00?o033ooook
J_oonfX01?oonfX00ooo003ooo]Zoi;o0002oookJP03oa00oooonf[ooo]Z00Cooo]Z00CoobP0oook
J_oonf[ooo]Z0_ooN@06oookJP08o`3oDooonf[ooo]ZoookJ_l0oago0?l8oookJ_oo:00;oookJP03
o`3o=?l0odko0?l^00Kooo]Z00?o08Soo`2YoooonfX00ooonfX00ol01?oooo]Zo`3Do`0=oookJP03
oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX01_oonfX00oooE`3ooo]ZoookJP1>oookJP09
o`3ogomho`3ooo]ZoookJ_l0g?oooo]Zocoo0?oonf[o02[o00Cooo]Z00?ooe80o`3o<onio`004?oo
nfX00ol0Looooo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oonB0?oonfX00_oo
nfX00ooo0?cooo]ZoookJP03oookJP0:oaP0oooo1P3ooo]ZoookJ_o[o`3oo`3foookJ_l0Y_oooo]Z
ojP0o`;ooo]Z00Woo`3ioookJ_l0Mooo0?nJoom/0?l0olcooh40oookJ_lko`000_oonfX00ol0nooo
oo]ZoookJP02oookJP06ool30?oo0=goN@3oo`2Sool05ooo/ol01?oonfX01?l0omkooo]ZoookJ_oo
06`2oookJP05odd0oomQ0?oooo]ZoookJ_l0odD00ooonfX01?l0oi3ooo]ZoookJ_l0oi85oookJP06
ofP0oooonf[ooo]ZoaP0ool0M?ooi_l00_oonfX00oooT03ooo]ZoookJP05oookJP03oonn0?oonf[o
L03o00Gooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP0<oookJP03o`3Doooonf[o
00Co00;ooo]Z00Ko08SooookJ_oonf[o0?m>oookJ_l0oc@6oookJP03o`3o7Ooonf[ooo]Z00Cooo]Z
00?oo`1ioookJ_oonfX00_oonfX3o`000003oa00oooonf[oT_l000Sooo]Z0_l0oe/JoookJPCo8?l0
3OlV0?l:ob3o01kooo]Z00?o0?mKoookJ_oonfX00ooonfX00ol0<?oooo]ZoookJP04oookJP03o`H0
oooonf[oT_l000?ooo]Z00?o403ooookJ_oonfX00ooonfX00ooo057ooo]ZoookJP03oookJP03ool0
NOoonf[ooo]Z00?ooo]Z00?o0?mCoookJ_oonfX00_oonfX00ol0oagooo]Zo`3Qo`0;oookJP03o`3o
=?oonf[o0?m>00Kooo]Z00?o08Soo`2YoooonfX00ooonfX00ol01?oooo]Zo`3Do`0=oookJP03oon1
0?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX01_oonfX00oooE`3ooo]ZoookJP0WoookJP00:ooo
nfX01Omho`3ooo]Zo`3Loooonf[o?ol000;ooo]Z00Oo02[ooookJ_oonf[ooo]ZoomB0?l0oc?o^Ol0
013ooo]Z00?o07?ooookJ_oonfX05?oonfX00ooo0>[ooo]ZoookJP04oookJPKoogT000?oo`3loook
J_oonfX01?oonfX02_lH0?oooo]Zool60?oonf[ojol0oookJ_oo0?Ko0:KooookJ_nX0?l2oookJP09
ool0nOoonf[o07OooookJ_ooK03o0?o<ool00?oonf[o>ol000;ooo]Z00?o0?_ooookJ_oonfX00_oo
nfX01_oo:03ooo]Zool0gOl0Xooo/ol0oil0o`;oobP00ooonfX00ol0omkooo]Zoomi0002ool00005
odd0oooo003oH@3ooookJ_l0odD00ooonfX00ol0oi3ooo]Zo`3oTP06oookJP08ofP0oooonf[ooo]Z
oookJ_lH0?ooi_l0oookJ_oo:008oookJP03oonn0?oonf[oL03o00Cooo]Z00?ooeL0oookJ_oonfX0
0ooonfX00ooo02gooo]ZoookJP0<oookJP05o`3Doooonf[o00CooookJ_l0R?l00_oonfX00ol0odko
oo]Zo`3o=004oookJPCoobP01OoonfX00ooo07Wooo]ZoookJP04oookJP05o`000?l@0?oo0000o`00
0?nBo`002?oonfX00ol0oe_ooo]ZoookJP0EoookJPCo8?l01OlV0?l=oookJPSo9P3o0_ooN@03ob3o
00GoogT05_oonfX00ol0oe_ooo]ZoookJP04oookJP03o`0`oooonf[ooo]Z00?ooo]Z00Coo`00oook
J_oonf[oT_l00_oonfX00ol@0?oooo]ZoookJP04oookJP03oolX0?oonf[ooo]Z00;ooo]Z00?oogT0
oookJ_oonfX01?oonfX01ol0oe?ooo]ZoookJ_oonf[o0?lMo`3o2?oo:0002ooonfX00ol0ocCooo]Z
o`3oCP07oookJP03o`2Yoooonf[ooo]Z00?ooo]Z00?o00CooookJ_l0e?l03?oonfX00oooP@3ooo]Z
oookJP0:oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0oookJ_oonfX0CooonfX01Omho`3ooo]Z
o`3Loooonf[o?ol000;ooo]Z00Oo02[ooookJ_oonf[ooo]ZoomB0?l0oc?o^Ol0013ooo]Z00?o07?o
oookJ_oonfX05?oonfX00ooo0>[ooo]ZoookJP06oookJP03oolF0?ooTP3ooo]Z00;ooo]Z00?oo`3l
oookJ_oonfX00ooonfX00olH0?oooo]Zool60002oookJP05on_o0?oo0?Ko0:KooookJ_nX0?l00ooo
nfX02?oo0?Wo07OooookJ_ooK03ooo]Zo`3oc?ooP@3o>ol00ooonfX02ol0nooooo]ZoookJ_oonf[o
o`<0oookJ_oo0=go0:?ooookJ_nco`3oW`3o00Cooo]Z00?o0?oNoookJ_oo06`00_oonfX00om=0?oo
obh0of40o`02oookJP04o`3oAOoonf[ooo]Zo`3oT0;ooo]Z00?o0?nBoookJ_oonfX00ooonfX01_mX
0?oooo]ZoookJ_oonf[o603oonKo00;ooo]Z00?ooi00oookJ_oonfX01OoonfX01?oo_P3ooo]Zoook
J_m`0?l4oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX03?oonfX00ol0e?oooo]Z
o`04o`02oookJP06o`28oooonf[ooo]Zo`3oC_oonf[o0?ld1_oonfX00ol0oagooo]ZoookJP04oook
JP03ool0NOoonf[ooo]Z00?ooo]Z00Go0000oa00ool@0?oo0000oi;o0008oookJP03o`3oFooonf[o
oo]Z01Kooo]Z0olPo`05obH0o`gooo]Z2olV0?l2ob3o01_ooo]Z00?o0?mKoookJ_oonfX01?oonfX0
0ol0<?oooo]ZoookJP03oookJP04o`H0oooonf[ooo]Zoi;o00?ooo]Z00?o403ooookJ_oonfX00ooo
nfX00ooo057ooo]ZoookJP03oookJP03ool0NOoonf[ooo]Z00?ooo]Z00?o0?mCoookJ_oonfX00_oo
nfX00ol0oago0>7ooookJP0:oookJP04o`3o=?oonf[ooo]Zo`3oCPKooo]Z00?o08Soo`2YoooonfX0
0ooonfX00ol01?oooo]Zo`3Do`0<oookJP03oon10?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX0
1_oonfX00oooE`3ooo]ZoookJP0WoookJP00:ooonfX01omho`3ooo]Zo`3Loooonf[o?ol0oookJ_l0
:_l01?oonfX00oooDP3ooo]ZokWo000@oookJP03o`1coooonf[ooo]Z01Cooo]Z00?oo`3ZoookJ_oo
nfX01OoonfX00oooN@3ooo]Zoomi0002oomi0003ool0o?oonf[ooo]Z00?ooo]Z00?o603ooookJ_oo
1P000_oonfX01_o[o`3oo`3foookJ_l0Y_oooo]ZojP0o`;ooo]Z00_oo`3ioookJ_l0Moooof`0o`3o
V_oonf[oo`00oookJ_lko`3ooo]Zo`3ko`04oookJP06oolX0?oonf[oo`3MogT0ool0Xooo/ol00_oo
nfX01?oo:03ooo]ZoookJ_l0omh2oookJP07oomi0?oo003oC@3oool00?mQ0?ooo`00o`3oA@03oook
JP03o`3oT?oonf[o0?nB00Kooo]Z00KoJ03ooookJ_oonf[ooo]ZoaP0oooVo`02oookJP03oolX0?oo
nf[ooo]Z00Kooo]Z00?ookh0o`3o1Om`0?l01?oonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooo
nf[ooo]Z00_ooo]Z00?o0=CooookJ_l01?l00_oonfX01Ol0R?oooo]Zo`3oC_oonf[o0?ld00Cooo]Z
1Ooo:005oookJP03ool0NOoonf[ooo]Z00Cooo]Z00Co403oo`000?nBo`3oT_l02?oonfX00ol0oe_o
oo]ZoookJP0CoookJP;o8?l01OlV0?lLoookJP[oogT05OoonfX00ol0oe_ooo]ZoookJP04oookJP03
o`0`oooonf[ooo]Z00?ooo]Z00Coo`00oookJ_oonf[oT_l00_oonfX00ol@0?oooo]ZoookJP03oook
JP03oolX0?oonf[ooo]Z00?ooo]Z00?oogT0oookJ_oonfX01?oonfX01ol0oe?ooo]ZoookJ_oonf[o
0?lMo`3o2?oo:0002ooonfX00ol0ocCo0?m>o`3o;P07oookJP03o`2Yoooonf[ooo]Z00;ooo]Z00Co
00CooookJ_oonf[o0=Co2ooonfX00oooP@3ooo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z00Kooo]Z
00?ooeL0oookJ_oonfX0C_oonfX01omho`3ooo]Zo`3Loooonf[o?ol0oookJ_l0:_l01?oonfX00ooo
DP3o0?lcokWo000@oookJP03o`1coooonf[ooo]Z01Cooo]Z00?oo`3ZoookJ_oonfX01_oonfX00ooo
5P3ooi80oookJP02oookJP03ool0o?oonf[ooo]Z00?ooo]Z00[o603oool60?oonf[ooo]Zon_o0?oo
0?Kooo]Zo`2Voooonf[oZ03o0_oonfX02Ooo0?Wooo]Zo`1gooooK03o0?nJo`3oc?ooP@3ooo]Zoc_o
0002oookJP03o`3koooonf[ooo]Z00;ooo]Z00Koo`<0ool0gOmi0?oo0:?oo`0Goonco`04oookJP04
o`3og_oonf[ooo]Zool0K0;ooo]Z00GoC@3oof40oooonf[ooo]Zo`3oA@02oookJP04o`3oT?oonf[o
oo]Zo`3oTPGooo]Z00KoJ03ooookJ_oonf[ooo]ZoaP0oooVo`03oookJP03oon@0?oonf[ooo]Z00Go
oo]Z00?ookh0oookJ_m`0?l01OoonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00_o
oo]Z00?o0=CooookJ_l01?l00_oonfX01_l0R?oooo]ZoookJ_l0odkooo]Zo`3o=0Kooo]Z00?o0?lM
oookJ_oonfX01OoonfX00ooo07Wooo]ZoookJP03oookJP04oa00ool0003oT_l0oi;o00Sooo]Z00?o
0?mKoookJ_oonfX04ooonfX2ob3o00Go9P3o7OoonfX3obH0o`03ob3o0?oonf[ooo]Z01Sooo]Z00?o
0?mKoookJ_oonfX01?oonfX00ol0<?oooo]ZoookJP03oookJP04o`H0oooonf[ooo]Zoi;o00?ooo]Z
00?o403ooookJ_oonfX00ooonfX00ooo057ooo]ZoookJP03oookJP03ool0NOoonf[ooo]Z00?ooo]Z
00Oo0?mCoookJ_oonf[ooo]Zo`3o7Ol0o`So0>7o00_ooo]Z00?o0?ldoookJ_l0odh01ooonfX00ol0
ZOoooo]ZoookJP02oookJP04o`04oooonf[ooo]Zo`3Do`_ooo]Z00?ooh40oookJ_oonfX02ooonfX0
0ooo02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z02Kooo]Z000ZoookJP03ogSo0?oonf[o0=co
00;ooo]Z00?o?ol0oookJ_l0:_l01?oonfX00oooDP3ooo]ZokWo000@oookJP03o`1coooonf[ooo]Z
01?ooo]Z00?oo`3ZoookJ_oonfX01_oonfX2oomi00;ooo]Z00?oo`3loookJ_oonfX01?oonfX02_lH
0?oooo]Zool60?oonf[ojol0oookJ_oo0?Ko0:KooookJ_nX0?l3oookJP04ool0nOl0Mooooo]Zoom/
00;oo`0000Gooo]Zoc_o0?oonf[ooo]Zo`3ko`04oookJP06oolX0?oonf[oo`3Mo`2Soonco`3oW`3o
1OoonfX02_l0omkooo]Zoomi0?ooN@3oo`00odd0oooo003oH@3oool00?l0odD3oookJP03o`3oT?oo
nf[o0?nB00Gooo]Z00WoJ03ooookJ_oonf[ooo]ZoaP0ool0M?ooi_l0oookJ_oo:0002?oonfX00ooo
_P3o0?l5og00o`04oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX03?oonfX02Ol0
e?oo00CooookJ_oonf[o08SooookJ_l0odkooo]Zo`3o=003oookJPKoobP01OoonfX00ooo07Wooo]Z
oookJP03oookJP;o403o00Co0000oi;o0?l0003o00001_oonfX2o`3oFa;ooo]Z00?o8?l0obH0oolV
0?l00olV0?lSoookJPWoogT05OoonfX00ol0oe_ooo]ZoookJP04oookJP03o`0`oooonf[ooo]Z00?o
oo]Z00Coo`00oookJ_oonf[oT_l00_oonfX00ol@0?oooo]ZoookJP03oookJP04oolX0?oonf[ooo]Z
oookJP;oobP01ooonfX01_l0oe?ooo]ZoookJ_l0oago0?l8oolX00cooo]Z00?o0?ldo`3oC_oonfX0
1_oonfX00ol0ZOoooo]ZoookJP02oookJP04o`04oooonf[ooo]Zo`3Do`_ooo]Z00?ooh40oookJ_oo
nfX02ooonfX00ooo02gooo]ZoookJP06oookJP03oomG0?oonf[ooo]Z04gooo]Z00SoN?l0oookJ_oo
nf[o0=cooookJ_loo`3ooo]Zo`0Zo`Cooo]Z00?ooe80o`3o<onio`004?oonfX00ol0Looooo]Zoook
JP0CoookJP03ool0j_oonf[ooo]Z00Oooo]Z00Gooi80oookJ_oonf[ooo]Zool0o006oookJP09oaP0
oooo1P3ooo]ZoookJ_o[o`3oo`3fo`2Voooonf[oZ03o00?ooo]Z00Woo`3io`1goooonf[oof`0oook
J_l0olcooh40oookJ_lko`000_oonfX02ol0nooooo]ZoookJ_oonf[oo`<0oookJ_oo0=go0:?ooook
J_nco`3oW`3o00Cooo]Z00?o0?oNoookJ_oo06`00ooonfX01Om=0?ooH@3ooookJ_oonf[o0?m500;o
oo]Z00Co0?n@oookJ_oonf[o0?nB1OoonfX01_mX0?oooo]ZoookJ_lH0?oooo]ZonKo00;ooo]Z00?o
oi00oookJ_oonfX01OoonfX00ooo_P3ooo]Zog00o`05oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?o
o`0]oookJ_oonfX03?oonfX01Ol0e?oo00CooookJ_oonf[o08So00;ooo]Z00?o0?m>oookJ_l0oc@0
1_oonfX00ol0oagooo]ZoookJP05oookJP03ool0NOoonf[ooo]Z00?ooo]Z00?o403oo`000?nBo`00
0_l00006oookJP;o0?mK4_oonfX00olPo`3o9P3oobH0o`03obH0obGooo]Z0_lV0?l2ob3o01Sooo]Z
00?o0?mKoookJ_oonfX01?oonfX00ol0<?oooo]ZoookJP03oookJP04o`H0oooonf[ooo]Zoi;o00?o
oo]Z00?o403ooookJ_oonfX00_oonfX00ooo057ooo]ZoookJP03oookJP03ool0NOoonf[ooo]Z00Co
oo]Z00Oo0?mCoookJ_oonf[ooo]Zo`3o7Ooonf[o0>7o00_ooo]Z00?o0?ldoookJ_l0odh01_oonfX0
0ol0R?oo0:WooookJP02oookJP04o`04oooonf[ooo]Zo`3Do`cooo]Z00?ooh40oookJ_oonfX02ooo
nfX00ooo02gooo]ZoookJP06oookJP03oomG0?oonf[ooo]Z02Kooo]Z000ZoookJP05ogSo0?oonf[o
0=cooookJ_loo`000_oonfX00ol0:_oooo]ZoookJP02oookJP03oomB0?nio`3ooo]Z013ooo]Z00?o
07?ooookJ_oonfX04ooonfX00ooo0>[ooo]ZoookJP05oookJP03oomi0?oonf[oogT000;ooo]Z00?o
o`3loookJ_oonfX01?oonfX02_lH0?ooo`H0oookJ_oonf[ojol0ool0m_oonf[o0:KooookJ_nX0?l2
oookJP05ool0nOoonf[o07Oooom/0?l0oiX00_oo00001Ooonf[o>ol0oookJ_oonf[o0?_o00?ooo]Z
00KoobP0oookJ_oonf[oo`3Mo`2Soonco`05oookJP0:o`3og_oonf[oogT0oomi0?oo003oC@3oool0
0?mQ0?ooo`00o`3oA@?ooo]Z00?o0?n@oookJ_l0oi801_oonfX02?mX0?oooo]ZoookJ_oonf[o603o
onKo0?oonf[oobP02?oonfX00ooo_P3ooo]Zog00o`05oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?o
o`0]oookJ_oonfX03?oonfX02Ol0e?oo00CooookJ_oonf[o08SooookJ_l0odkooo]Zo`3o=003oook
JPOoobP01?oonfX00ooo07Wooo]ZoookJP03oookJP04oa00oooonf[ooo]Zoi;o00?o00001OoonfX0
0ol0oe_ooo]ZoookJP0?oookJPCo9P3o:?oonfX:oomi01Gooo]Z00?o0?mKoookJ_oonfX01?oonfX0
0ol0<?oooo]ZoookJP02oookJP04ool00?oonf[ooo]Zoi;o00?ooo]Z00?o403ooookJ_oonfX00ooo
nfX5oolX0003ool0NOoonf[ooo]Z00Cooo]Z00Oo0?mCoookJ_oonf[ooo]Zo`3o7Ol0o`SoobP000_o
oo]Z00?o0?ldo`3oC_l0obh01_oonfX00ol0R?oo0:WooookJP03oookJP03o`04oooonf[o0=Co00co
oo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP06oookJP03oomG0?oonf[ooo]Z04go
oo]Z00GoN?l0oookJ_l0g?oooo]Zocoo0002oookJP03o`0Zoooonf[ooo]Z00;ooo]Z00?ooe80o`3o
<ooonfX04?oonfX00ol0Looooo]ZoookJP0CoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oonB
0?oonfX00_oonfX00ooo0?cooo]ZoookJP03oookJP0:oaP0oooo1P3ooo]ZoookJ_o[o`3oo`3foook
J_l0Y_oooo]ZojP0o`?ooo]Z00Soo`3io`1gooooK03o0?nJo`3oc?ooP@3ooo]Zoc_o00?ooo]Z00[o
0?_ooookJ_oonf[ooo]Zool30?oonf[oo`3Mo`2Sool05ooo/ol01?oonfX01?l0omkooo]ZoookJ_oo
06`2oookJP05odd0oomQ0?oooo]ZoookJ_l0odD00_oonfX01?l0oi3ooo]ZoookJ_l0oi85oookJP06
ofP0oooonf[ooo]ZoookJ_lH0?ooi_l00_oonfX00oooT03ooo]ZoookJP05oookJP04oonn0?oonf[o
L03oo`3o1@Cooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP0<oookJP05o`3Dool0
1?oooo]ZoookJ_l0R?l00_oonfX00ol0odkooo]Zo`3o=006oookJP03o`3o7Ooonf[ooo]Z00Gooo]Z
00?oo`1ioookJ_oonfX00ooonfX00ol@0?oooo]Zoi;o0003o`0000Gooo]Z00?o0?mKoookJ_oonfX0
3ooonfX01?lPo`3o9P3oobH0oolV0?l/oookJP?o9P3o0_lPo`0FoookJP03o`3oFooonf[ooo]Z00Co
oo]Z00?o033ooookJ_oonfX00ooonfX00ol60?oooo]Zoi;o0004oookJP03oa00oooonf[ooo]Z00;o
oo]Z00?oo`1AoookJ_oonfX00ooonfX00ooo07Wooo]ZoookJP03oookJP07o`3oDooonf[ooo]Zoook
J_l0oago0?l8o`3Qo`0;oookJP03o`3o=?oonf[o0?m>00Oooo]Z00?o0:WooookJ_oonfX00_oonfX0
0ol01?oooo]Zo`3Do`0<oookJP03oon10?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX01_oonfX0
0oooE`3ooo]ZoookJP0VoookJP00;?oonfX00ol0g?oooo]Zocoo0002oookJP07o`0Zoooonf[ooo]Z
oookJ_ooDP3o0?lcokWo000@oookJP03o`1coooonf[ooo]Z01?ooo]Z00?oo`3ZoookJ_oonfX01_oo
nfX00oooN@3ooo]Zoomi0002oookJP03ool0o?oonf[ooo]Z00?ooo]Z00[o603ooookJ_oo1P3ooo]Z
on_o0?oonf[oo`3foookJ_l0Y_ooZ03o0ooonfX02?oo0?Wo07OooookJ_ooK03o0?nJool00?oonf[o
>ol00_oonfX00ol0nooooo]ZoookJP02oookJP06oolX0?oonf[oo`3Mo`2Soonco`3oW`3o1OoonfX0
2_l0omkoogT0oomi0?ooN@3oo`00odd0oomQ0?ooo`00o`3oAOoo0003oookJP03o`3oT?oonf[o0?nB
00Gooo]Z00WoJ03ooookJ_oonf[ooo]ZoaP0ool0M?ooi_l0oookJ_oo:0001ooonfX00ooo_P3ooo]Z
og00o`05oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX03?oonfX01ol0e?oooo]Z
o`04oooonf[o08SooookJ_l0odh00_oonfX00ol0ocCooo]ZoookJP07oolX00Cooo]Z00?oo`1ioook
J_oonfX00ooonfX01?l@0?oooo]ZoookJ_nBo`05o`0000?ooo]Z00?o0?mKoookJ_oonfX03_oonfX2
obH0obcooo]Z3?ooN@0DoookJP03o`3oFooonf[ooo]Z00Cooo]Z00?o033ooookJ_oonfX00_oonfX0
1?oo003ooo]ZoookJ_nBo`03oookJP03oa00oooonf[ooo]Z00;ooo]Z1_oo:007oookJP06o`3oDooo
nf[ooo]ZoookJ_l0oagoobP03?oonfX00ol0ocCo0?m>oookJP06oookJP03o`2Yoooonf[ooo]Z00;o
oo]Z00Co00CooookJ_oonf[o0=Co2ooonfX00oooP@3ooo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z
00Kooo]Z00?ooeL0oookJ_oonfX0C_oonfX00ol0g?oooo]Zocoo0002oookJP07o`0Zoooonf[ooo]Z
oookJ_ooDP3o0?lcokWo000@oookJP03o`1coooonf[ooo]Z01?ooo]Z00?oo`3ZoookJ_oonfX01ooo
nfX00ooo5P3ooi80oookJP02oookJP03ool0o?oonf[ooo]Z00?ooo]Z00Wo603oool60?oonf[ooo]Z
on_o0?oo0?Kooo]Zo`2VoonX0?l00ooonfX02Ooo0?Wo07OooookJ_ooK03o0?nJo`3oc?ooP@3ooo]Z
oc_o0002oookJP0;o`3koooonf[ooo]ZoookJ_oo0`3ooo]Zool0gOl0Xooooo]Zok?o0?nO0?l01?oo
nfX00ol0omkooo]Zool0K003oookJP04of40oooonf[ooo]Zo`3oA@?ooo]Z00Co0?n@oookJ_oonf[o
0?nB1?oonfX01omX0?oooo]ZoookJ_oonf[o603oo`1doooVo`000_oonfX00oooT03ooo]ZoookJP04
oookJP04oonn0?oonf[oL03oo`3o1@Gooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@0>oookJP03o`3D
oooonf[o00Co00;ooo]Z00Go08SooookJ_l0odkooo]Zo`3o=006oookJP03o`3o7Ooonf[ooo]Z00Go
oo]Z00?oo`1ioookJ_oonfX00_oonfX2oa00o`03oookJ_nBo`3o000000Co00000ooonfX00ol0oe_o
oo]ZoookJP0>oookJP03ob3o0?lV0?oo9P3o03;ooo]Z0olV0?l00olPo`3ooo]ZoookJP0CoookJP03
o`3oFooonf[ooo]Z00Cooo]Z00?o033ooookJ_oonfX00_oonfX01?l60?oooo]ZoookJ_nBo`04oook
JP03oa00oooonf[ooo]Z00;ooo]Z00?oo`1AoookJ_oonfX00_oonfX00ooo07Wooo]ZoookJP04oook
JP07o`3oDooonf[ooo]ZoookJ_l0oagooo]Zo`3Qo`0;oookJP03o`3o=?oonf[o0?m>00Kooo]Z00?o
08Soo`2YoooonfX00_oonfX01?l01?oooo]ZoookJ_l0e?l;oookJP03oon10?oonf[ooo]Z00cooo]Z
00?oo`0]oookJ_oonfX01_oonfX00oooE`3ooo]ZoookJP0UoookJP00:ooonfX01_l0g?oooo]Zoook
J_loo`3ooo]Zo`0Zo`Cooo]Z00?ooe80oookJ_nio`004?oonfX00ol0Looooo]ZoookJP0CoookJP03
ool0j_oonf[ooo]Z00Kooo]Z0_ooN@02oookJP03ool0o?oonf[ooo]Z00Cooo]Z00[o603oool60?oo
nf[ooo]Zon_o0?oo0?Kooo]Zo`2Voooonf[oZ03o0_oonfX01Ooo0?Wooo]Zo`1gooooK03o0?nJ00;o
o`0000Gooo]Zoc_o0?oonf[ooo]Zo`3ko`03oookJP06oolX0?oonf[ooo]Zool0gOl0Xooo/ol01Ooo
nfX00ol0omkoogT0oomi0002oomi0005odd0oooo003oH@3oool00?l0odD00ooonfX00ol0oi3ooo]Z
o`3oTP06oookJP08ofP0oooonf[ooo]ZoaP0ool0M?ooi_l0oookJ_oo:008oookJP03oonn0?l0o`Go
L03o00Cooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP0;oookJP07o`3Doooonf[o
00CooookJ_l0R?oooo]Zo`3oCP02oookJP03o`3o=?oonf[oobP000SoobP00ooonfX00ooo07Wooo]Z
oookJP02oookJP;o403o00Cooo]Zoi;o0?nBo`3ooo]Z1?l00002oookJP;o0?mK3ooonfX2obH0obgo
oo]Z3_ooN@000olPo`3ooo]ZoookJP0AoookJP03o`3oFooonf[ooo]Z00Cooo]Z00?o033ooookJ_oo
nfX00_oonfX01?oo003ooo]ZoookJ_nBo`02oookJP03oa00oooonf[ooo]Z00SoobP000?oo`1ioook
J_oonfX01OoonfX01_l0oe?ooo]ZoookJ_l0oago0?l8oolX00cooo]Z00?o0?m>o`3o;_oonfX01Ooo
nfX00ol0R?oo0:WooookJP02oookJP04o`04oooonf[ooo]Zo`3Do`_ooo]Z00?ooh40oookJ_oonfX0
2ooonfX00ooo02gooo]ZoookJP06oookJP03oomG0?oonf[ooo]Z04kooo]Z00Go0=cooookJ_loo`3o
oo]Zo`0Zo`04oookJP03oomB0?l0oc?o^Ol0013ooo]Z00?o07?ooookJ_oonfX04ooonfX00ooo0>[o
oo]ZoookJP07oookJP05oonB0?oonf[ooo]ZoookJ_oo0?`01OoonfX02_lH0?ooo`H0oookJ_oonf[o
jol0ool0m_oonf[o0:KooookJ_nX0?l3oookJP08ool0nOl0Moooof`0o`3oV_oonf[o0?o<oon10?lk
o`03oookJP0:o`3koooonf[ooo]ZoookJ_oo0`3ooo]Zool0gOl0Xooo/ol0oil0o`Cooo]Z00Co0?oN
oookJ_oonf[oo`1/0_oonfX01Om=0?ooH@3ooookJ_oonf[o0?m500;ooo]Z00Co0?n@oookJ_oonf[o
0?nB1OoonfX01_mX0?oooo]ZoookJ_lH0?oooo]ZonKo00;ooo]Z00?ooi00oookJ_oonfX01OoonfX0
0ooo_P3ooo]Zog00o`05oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX02ooonfX0
0ol0e?oooo]Zo`04o`02oookJP05o`28oooonf[o0?m>oookJ_l0oc@01_oonfX00ol0oagooo]Zoook
JP05oookJP03ool0NOoonf[ooo]Z00;ooo]Z00Go403ooookJ_nBo`3oT_l0oookJP04o`0000;ooo]Z
0_l0oe/?oookJP03ob3o0?lV0?oo9P3o03Oooo]Z0_lV0?l2ob3o01?ooo]Z00?o0?mKoookJ_oonfX0
1?oonfX00ol0<?oooo]ZoookJP02oookJP04o`H0oooonf[ooo]Zoi;o00?ooo]Z00?o403ooookJ_oo
nfX00ooonfX00ooo057ooo]ZoookJP02oookJP03ool0NOoonf[ooo]Z00Cooo]Z00Ko0?mCoookJ_oo
nf[ooo]Zo`3o7Ol0hOl<oookJP03o`3o=?l0odkooo]Z00Gooo]Z00?o08Soo`2YoooonfX00_oonfX0
1?l01?oooo]ZoookJ_l0e?l<oookJP03oon10?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX01_oo
nfX00oooE`3ooo]ZoookJP0UoookJP00:ooonfX00ol0g?oooo]Zocoo0002oookJP03o`0Zoooonf[o
oo]Z00;ooo]Z00?ooe80okWo0?oonfX04?oonfX00ol0Looooo]ZoookJP0CoookJP03ool0j_oonf[o
oo]Z00Gooo]Z00?oogT0oookJ_ooN@000_oonfX00ooo0?cooo]ZoookJP03oookJP0:oaP0oooonf[o
o`H0oookJ_o[o`3ooo]Zool0m_oonf[o0:KoojP0o`?ooo]Z00Goo`3io`1goooonf[oof`0o`3oVP02
ool00004oc_o0?oonf[ooo]Zo`3ko`Cooo]Z00KoobP0oookJ_oo0=gooo]Zok?o0?nO0?l5oookJPGo
ogT000GoC@3oof40oooo003o0?m5ool00003oookJP03o`3oT?oonf[o0?nB00Gooo]Z00SoJ03ooook
J_oonf[ooo]ZoaP0ool0M?ooi_l0oolX00Sooo]Z00?ookh0oookJ_m`0?l01OoonfX00oooE`3ooo]Z
oookJP02oookJP03ool0;Ooonf[ooo]Z00_ooo]Z00?o0=CooookJ_l01?l00_oonfX01_l0R?oo0?m>
oookJ_oonf[o0?ldoookJPWoobP00ooonfX00ooo07Wooo]ZoookJP02oookJP04oa00oooonf[ooo]Z
oi;o00?ooo]Z1?l000000ooonf[o0?mKoookJP0>oookJP;o9P3o=?oonfX:oomi00;o8?l04_oonfX0
0ol0oe_ooo]ZoookJP04oookJP05o`0`oooonf[ooo]ZoookJ_oo00000_oonfX01OnBo`3oo`00ool0
0?oonf[o403o00WoobP000?oo`1ioookJ_oonfX01_oonfX01Ol0oe?ooo]ZoookJ_l0oagoobP000co
oo]Z00?o0?ldo`3oC_oonfX01OoonfX00ol0R?oo0:WooookJP03oookJP03o`04oooonf[o0=Co00co
oo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP05oookJP03oomG0?oonf[ooo]Z04go
oo]Z00?o0=cooookJ_loo`000_oonfX00ol0:_oooo]ZoookJP02oookJP03oomB0?l0oc?ooo]Z013o
oo]Z00?o07?ooookJ_oonfX04ooonfX00ooo0>[ooo]ZoookJP06oookJP03oolF0?ooTP3ooo]Z00;o
oo]Z00?oo`3loookJ_oonfX00ooonfX02OlH0?ooo`H0oookJ_oonf[ojol0ool0m_oonf[o0:KoojP0
o`03oookJP09ool0nOl0Mooooo]Zoom/0?l0oi[o0?o<oon10?oonf[o>ol000;ooo]Z00_o0?_ooook
J_oonf[ooo]Zool30?oonf[oo`3MoookJ_l0Xooo/ol0oil0o`04oookJP04o`3og_oonf[ooo]Zool0
K0;ooo]Z00CoH@3ooookJ_oonf[o0?m50ooonfX01?l0oi3ooo]ZoookJ_l0oi84oookJP09ofP0oooo
nf[ooo]ZoookJ_lH0?oo07CoonKo0?oonf[ooi0000Oooo]Z00Cookh0oookJ_m`0?oo0?l51OoonfX0
1OooE`3ooo]ZoookJ_oonf[oo`0]00gooo]Z00?o0=CooookJ_l01?l00_oonfX01Ol0R?oooo]Zo`3o
C_oonf[o0?ld00Kooo]Z00?o0?lMoookJ_oonfX01OoonfX00ooo07Wooo]ZoookJP02oookJP03oa00
oooonf[oT_l000?ooo]Z1?l000000ooonf[o0?mKoookJP0>oookJP03ob3o0?lV0?oo9P3o03_ooo]Z
0olV0?l00olPo`3ooo]ZoookJP0@oookJP03o`3oFooonf[ooo]Z00Cooo]Z00?o033ooookJ_oonfX0
0_oonfX00ol60?oooo]Zoi;o0004oookJP03oa00oooonf[ooo]Z00;ooo]Z00?oo`1AoookJ_oonfX0
0_oonfX00ooo07Wooo]ZoookJP05oookJP06o`3oDooonf[ooo]Zo`3o7Ooonf[o0>7o2ooonfX00ol0
ocCooo]Zo`3oCP06oookJP03o`28ool0ZOoooo]Z00;ooo]Z00?o00CooookJ_l0e?l03?oonfX00ooo
P@3ooo]ZoookJP0<oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooeL0oookJ_oonfX09OoonfX002_o
oo]Z00?o0=cooookJ_loo`000_oonfX00ol0:_oooo]ZoookJP02oookJP03oomB0?nio`3ooo]Z013o
oo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP06oookJP03oomi0?oonf[oogT000;o
oo]Z00?oo`3loookJ_oonfX00ooonfX02_lH0?ooo`H0oookJ_oonf[ojol0oookJ_oo0?Kooo]Zo`2V
oonX0?l2oookJP05ool0nOoonf[o07Oooom/0?l0oiX00ooo00001?lko`3ooo]ZoookJ_l0nol3oook
JP07oolX0?oonf[ooo]Zool0gOnco`3oobP0oil0o`04oookJP03o`3og_ooN@3oogT000?oogT000Go
o`00of40oooonf[o0?m5ool00002oookJP03o`3oT?oonf[o0?nB00Gooo]Z00WoJ03ooookJ_oonf[o
oo]ZoaP0ool0M?ooi_l0oookJ_oo:0002?oonfX00ooo_P3o0?l5og00o`04oookJP03oomG0?oonf[o
oo]Z00;ooo]Z00?oo`0]oookJ_oonfX02ooonfX00ol0e?oooo]Zo`04o`02oookJP06o`28oooonf[o
0?m>oookJ_l0ocCooo]Z2_oo:002oookJP03ool0NOoonf[ooo]Z00;ooo]Z00Co403ooookJ_oonf[o
T_l01?oonfX3o`0000;o0?mK3OoonfX00olPo`3o9P3oobH0o`0moookJPCoogT000?o9P3oob3o0?oo
nfX04OoonfX00ol0oe_ooo]ZoookJP04oookJP0;o`0`oooonf[ooo]ZoookJ_oo003ooo]Zool00?nB
o`3oo`00oookJ_l@0?l00_oonfX8oolX0003ool0NOoonf[ooo]Z00Gooo]Z00Ko0?mCoookJ_oonf[o
0?lMoookJ_oo:00<oookJP03o`3oC_l0obkooo]Z00Gooo]Z00?o08Soo`2YoooonfX00_oonfX01?l0
1?oooo]ZoookJ_l0e?l;oookJP03oon10?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX01_oonfX0
0oooE`3ooo]ZoookJP1<oookJP03o`3Loooonf[o?ol000;ooo]Z00?o02[ooookJ_oonfX00_oonfX0
0oooDP3o^Ol0oookJP0@oookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01ooonfX0
0ooo5P3ooi80oookJP02oookJP03ool0o?oonf[ooo]Z00;ooo]Z00?o603oool60?oonfX00_oonfX0
1Oo[o`3oo`3foookJ_l0Y_ooZ03o00?ooo]Z00Soo`3io`1gooooK03o0?nJoookJ_l0olcooh40oc_o
00?ooo]Z00_o0?_ooookJ_oonf[ooo]Zool30?oonf[oo`3Mo`2Soonco`3ooo]Zoil0o`03oookJP04
o`3og_oonf[ooo]Zool0K0;ooo]Z00GoC@3oof40oooonf[ooo]Zo`3oA@02oookJP04o`3oT?oonf[o
oo]Zo`3oTPGooo]Z00KoJ03ooookJ_oonf[o603oo`1doooVo`02oookJP03oon@0?oonf[ooo]Z00Go
oo]Z00?ookh0oookJ_m`0?l01OoonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00gooo]Z00?o0=Cooook
J_l01?l00_oonfX01Ol0R?oooo]ZoookJ_l0odko0?ld00Kooo]Z00?o0?lMoookJ_oonfX01OoonfX0
0ooo07Wooo]ZoookJP02oookJP03oa00oooonf[oT_l000Cooo]Z0ol00002o`3oF`kooo]Z0olV0?m0
oookJP;o9P3o4_oonfX00ol0oe_ooo]ZoookJP04oookJP05o`0`oooonf[ooo]ZoookJ_l60?l00_oo
nfX01OnBo`3ooo]ZoookJ_oonf[o403o00Gooo]Z00?oo`1AoookJ_oonfX00_oonfX00ooo07Wooo]Z
oookJP04oookJP06o`3oDooonf[ooo]Zo`3o2?l0oago0>7o3?oonfX00ol0ocCo0?m>oookJP05oook
JP03o`28ool0ZOoooo]Z00;ooo]Z00Co00CooookJ_oonf[o0=Co2ooonfX00oooP@3ooo]ZoookJP0<
oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0oookJ_oonfX09?oonfX002[ooo]Z00Co0=cooook
J_oonf[o?ol00_oonfX01ol0:_oooo]ZoookJ_oonf[ooe80oookJ_nio`004?oonfX00ol0Looooo]Z
oookJP0CoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?oogT0oookJ_ooN@000_oonfX00ooo0?cooo]Z
oookJP04oookJP09oaP0oooo1P3ooo]ZoookJ_o[o`3oo`3foookJ_l0Y_ooZ03o00?ooo]Z00Goo`3i
o`1goooonf[oof`0o`3oVP02ool00004oc_o0?oonf[ooo]Zo`3ko`Cooo]Z00KoobP0oookJ_oonf[o
o`3Mok?o0?nO0?l5oookJPGoogT000CoC@3oool00?mQ0?oo0?m50ooonfX00ol0oi3ooo]Zo`3oTP06
oookJP08ofP0oooonf[ooo]ZoaP0oooonf[oi_l0oookJ_oo:008oookJP03oonn0?l0o`GoL03o00Go
oo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP0:oookJP03o`3Doooonf[o00Co00;o
oo]Z00Go08SooookJ_l0odkooo]Zo`3o=004oookJPOoobP00_oonfX00ooo07Wooo]ZoookJP02oook
JP04oa00oooonf[ooo]Zoi;o00Gooo]Z0_l000000ol0oe_o0000oookJP0;oookJP03ob3o0?lV0?oo
9P3o04Cooo]Z00?o9P3oob3o0?oonfX04OoonfX00ol0oe_ooo]ZoookJP04oookJP04o`0`oooonf[o
oo]ZoookJP?oo`0000CoT_l0ool00?oonf[o403o0_oonfX7oolX0003ool0NOoonf[ooo]Z00Kooo]Z
00Go0?mCoookJ_oonf[o0?lMoolX0003oookJP;oobP01ooonfX00ol0ocCo0?m>oookJP05oookJP03
o`28ool0ZOoooo]Z00;ooo]Z00Co00CooookJ_oonf[o0=Co2ooonfX00oooP@3ooo]ZoookJP0<oook
JP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooeL0oookJ_oonfX0C?oonfX00ol0g?oooo]Zocoo0002oook
JP07o`0Zoooonf[ooo]ZoookJ_ooDP3o0?lcokWo000@oookJP03o`1coooonf[ooo]Z01?ooo]Z00?o
o`3ZoookJ_oonfX01_oonfX00ooo5P3ooi80oookJP02oookJP03ool0o?oonf[ooo]Z00?ooo]Z00Wo
603oool60?oonf[ooo]Zon_o0?oo0?Kooo]Zo`2VoonX0?l00ooonfX02Ooo0?Wo07OooookJ_ooK03o
0?nJoookJ_ooP@3ooo]Zoc_o0002oookJP05o`3koooonf[ooo]ZoookJ_oo0`000_oonfX01?oo0=go
0:?ook?o0?nO0?l4oookJP04o`3og_oonf[ooo]Zool0K0;ooo]Z00CoC@3oof40oooonf[o0?m50_oo
nfX01?l0oi3ooo]ZoookJ_l0oi85oookJP06ofP0oooonf[ooo]ZoaP0oooonf[oi_l00_oonfX00ooo
T03ooo]ZoookJP05oookJP03oonn0?oonf[oL03o00Gooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo
02gooo]ZoookJP0:oookJP03o`3Doooonf[o00Co00;ooo]Z00Go08SooookJ_oonf[o0?m>o`3o=006
oookJP03o`3o7Ooonf[ooo]Z00Gooo]Z00?oo`1ioookJ_oonfX00_oonfX00ol@0?oooo]Zoi;o0005
oookJP;o000000?o0?mKo`000?oonfX03?oonfX2obH0odGooo]Z00?o9P3ooookJ_oonfX04?oonfX0
0ol0oe_ooo]ZoookJP04oookJP05o`0`oooonf[ooo]ZoookJ_l60?l00_oonfX01OnBo`3ooo]Zoook
J_oonf[o403o00Gooo]Z00Goo`1AoookJ_oonf[ooo]Zool0N@07oookJP06o`3oDooonf[ooo]Zo`3o
7Ooonf[o0>7o2ooonfX00ol0ocCooo]Zo`3oCP05oookJP03o`28oooonf[o0:Wo00;ooo]Z00Co00Co
oookJ_oonf[o0=Co3?oonfX00oooP@3ooo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?o
oeL0oookJ_oonfX09?oonfX002[ooo]Z00?o0=cooookJ_loo`000_oonfX00ol0:_oooo]ZoookJP02
oookJP03oomB0?oonf[o^Ol0013ooo]Z00?o07?ooookJ_oonfX04ooonfX00ooo0>[ooo]ZoookJP05
oookJP03oomi0?oonf[oogT000;ooo]Z00?oo`3loookJ_oonfX00ooonfX02_lH0?ooo`H0oookJ_oo
nf[ojol0oookJ_oo0?Kooo]Zo`2VoonX0?l2oookJP06ool0nOoonf[o07Ooool00?ooK03o0?nJ0_oo
00001?lko`3ooo]ZoookJ_l0nol3oookJP07oolX0?oonf[ooo]Zool0gOoUo`3o0:?ooil0o`04oook
JPKoogT000CoC@3oof40oooonf[o0?m50ooonfX00ol0oi3ooo]Zo`3oTP05oookJP08ofP0oooonf[o
oo]ZoookJ_lH0?oo07CoonKo0?oo:009oookJP03oonn0?oonf[oL03o00Cooo]Z00?ooeL0oookJ_oo
nfX00_oonfX00ooo02gooo]ZoookJP0:oookJP03o`3Doooonf[o00Co00;ooo]Z00Go08SooookJ_l0
odkooo]Zo`3o=006oookJPKoobP000?ooo]Zool0NOoonfX01?oonfX00ol@0?ooT_l0oi;o0006oook
JP04o`000?l0oe_o0000o`0000[ooo]Z00?o8?l0obH0oolV0?l0AooonfX00olV0?oo8?l0oookJP0A
oookJP03o`3oFooonf[ooo]Z00Cooo]Z00?o033ooookJ_oo00000ooo00001OnBo`3oo`00oookJ_oo
nf[o403o00;ooo]Z1_oo:0000ooonf[oo`1ioookJP07oookJP04o`3oDooonf[o0?l8o`3o7@GoobP0
2?oonfX00ol0odko0?l^oookJP04oookJP03o`28oooonf[o0:Wo00?ooo]Z00?o00CooookJ_l0e?l0
3?oonfX00oooP@3ooo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooeL0oookJ_oonfX0
BooonfX00ol0g?oooo]Zocoo0002oookJP03o`0Zoooonf[ooo]Z00;ooo]Z00?ooe80o`3o<onio`00
4?oonfX00ol0Looooo]ZoookJP0CoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oonB0?oonfX0
0_oonfX00ooo0?cooo]ZoookJP03oookJP09ool60?oonf[ooo]ZoookJ_o[o`3oo`3foookJ_l0Y_oo
Z03o00?ooo]Z00Soo`3io`1goooonf[oof`0o`3oV_l0olcooh40oc_o00?ooo]Z00_o0?_ooookJ_oo
nf[ooo]Zool30?oonf[oo`3MoookJ_nco`3ooo]Zoil0o`03oookJP04o`3og_oonf[ooo]Zool0K0;o
oo]Z00GoC@3oof40oooonf[ooo]Zo`3oA@02oookJP04o`3oT?oonf[ooo]Zo`3oTPCooo]Z00WoJ03o
oookJ_oonf[ooo]ZoaP0ool0M?ooi_l0oookJ_ooT0002?oonfX00ooo_P3o0?l5og00o`05oookJP05
oomG0?oonf[ooo]ZoookJ_oo02d03?oonfX00ol0e?oooo]Zo`04o`02oookJP05o`28oooonf[ooo]Z
o`3oC_l0oc@01_oonfX00ol0oagooo]ZoookJP05oookJP03ool0NOoonf[ooo]Z00?ooo]Z0_nBo`06
oookJP04o`000?l0oe_o0000o`0000_ooo]Z0_lV0?m8oookJP03obH0oooonf[ooo]Z013ooo]Z00?o
0?mKoookJ_oonfX01?oonfX01ol0<?oooo]ZoookJ_oonf[o1P3ooookJ_nBo`001?oonfX00ol@0?oo
oo]ZoookJP02oookJP03ool0DOoonf[ooo]Z00;ooo]Z00?oo`1ioookJ_oonfX01OoonfX01Ol0oe?o
oo]Zo`3o2?l0oago0>7o00cooo]Z00?o0?ldo`3oC_oonfX01OoonfX00ol0R?oo0:WooookJP02oook
JP03o`04oooonf[o0=Co00cooo]Z00?ooh40oookJ_oonfX03?oonfX00ooo02gooo]ZoookJP05oook
JP03oomG0?oonf[ooo]Z02Cooo]Z000/oookJP04ocoo0?oonf[ooo]Zo`0Zo`Cooo]Z00?ooe80okWo
0?oonfX04?oonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?oogT0oook
J_ooN@000_oonfX00ooo0?cooo]ZoookJP03oookJP06oaP0oooo1P3ooo]ZoookJ_o[o`3oo`3f0_oo
nfX02OnX0?oooo]ZoookJ_oonf[oo`3ioookJ_l0Moooof`0o`3oVP02ool00005oc_o0?oonf[ooo]Z
oookJ_l0nol00ooonfX01_oo:03ooo]ZoookJ_oo0=goiOl0oil0o`Cooo]Z1oooN@000ooo003oH@3o
o`3oA@03oookJP03o`3oT?oonf[o0?nB00Kooo]Z00SoJ03ooookJ_oonf[o603oo`1doooVo`3ooo]Z
oolX00Sooo]Z00?ookh0o`3o1Om`0?l01?oonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[o
oo]Z00_ooo]Z00Go0=CooookJ_l01?oooo]Zo`28o`02oookJP03o`3oC_l0ocCooo]Z00Gooo]Z00?o
0?l8oolX0?oo:0000ooo:0000ooonf[oo`1ioookJP04oookJP03oa00oonBo`3ooo]Z00Kooo]Z0_l0
oe/3o`0000Sooo]Z00?o8?l0obH0oolV0?l06OoonfX<oa80obGooo]Z00?o9P3oob3o0?oonfX04Ooo
nfX00ol0oe_ooo]ZoookJP04oookJPKoo`0000CoT_l0oookJ_oonf[o403o0ooonfX6oolX0003ool0
NOoonf[ooo]Z00Oooo]Z00?o0?mCoolX0?l0oad01Ooo:009oookJP03o`3oC_oonf[ooo]Z00Cooo]Z
00?o08Soo`2YoooonfX00_oonfX00ol01?oooo]Zo`3Do`0<oookJP03oon10?oonf[ooo]Z00_ooo]Z
00?oo`0]oookJ_oonfX01_oonfX00oooE`3ooo]ZoookJP1<oookJP04ocoo0?oonf[ooo]Zo`0Zo`Co
oo]Z00?ooe80okWo0?oonfX04?oonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Oo
oo]Z00?ooaH0oonB0?oonfX00_oonfX00ooo0?cooo]ZoookJP02oookJP06oaP0oooo1P3ooo]Zoook
J_o[o`3oo`3f0_oonfX00onX0?oooo]ZoookJP02oookJP08ool0nOl0Moooof`0o`3oV_oonf[ooh40
oookJ_lko`03oookJP04o`3koooonf[ooo]Zool300;ooo]Z00Coo`3Mo`2Soonco`3oW`3o1?oonfX0
1?l0omkooo]ZoookJ_oo06`2oookJP04odd0oomQ0?oooo]Zo`3oA@;ooo]Z00Co0?n@oookJ_oonf[o
0?nB1OoonfX01_mX0?oooo]ZoookJ_lH0?oo07CoonKo00;ooo]Z00?ooi00oookJ_oonfX01OoonfX0
0ooo_P3ooo]Zog00o`05oookJP05oomG0?oonf[ooo]ZoookJ_oo02d03OoonfX00ol0e?oooo]Zo`04
o`02oookJP04o`28oooonf[o0?m>o`3o=0Kooo]Z00?o0?l8o`3o7OoonfX01OoonfX00ooo07Wooo]Z
oookJP03oookJP03oi;o0?oonf[ooo]Z00Gooo]Z0_l0oe/3o`0000Wooo]Z0_lV0?lJoookJPco4P3o
9OoonfX00olV0?oooo]ZoookJP0@oookJP03o`3oFooonf[ooo]Z00Cooo]Z00Oo033ooookJ_oonf[o
oo]Zo`H0oooonf[oT_l000?ooo]Z00?o403ooookJ_oonfX00ooonfX01Ooo057ooo]ZoookJ_oonf[o
o`1i00Sooo]Z00Go0?mCoookJ_l0o`So0?lMo`3Qo`0<oookJP03o`3o=?l0odkooo]Z00Cooo]Z00?o
08SooookJ_l0ZOl00_oonfX00ol01?oooo]Zo`3Do`0<oookJP03oon10?oonf[ooo]Z00cooo]Z00?o
o`0]oookJ_oonfX01_oonfX00oooE`3ooo]ZoookJP0SoookJP00;?oonfX01?loo`3ooo]ZoookJ_l0
:_l4oookJP03oomB0?nio`3ooo]Z00oooo]Z00?o07?ooookJ_oonfX04ooonfX00ooo0>[ooo]Zoook
JP05oookJP03oomi0?oonf[oogT000;ooo]Z00?oo`3loookJ_oonfX00ooonfX02_lH0?oooo]Zool6
0?oonf[ojol0oookJ_oo0?Kooo]Zo`2VoonX0?l2oookJP06ool0nOoonf[o07Ooool00?ooK03o0?nJ
0_oo00001?lko`3ooo]ZoookJ_l0nol3oookJP04oolX0?oonf[ooo]Zool0g@;oiOl000CoW`3ooook
J_oonf[ooo]Z2?ooN@000omQ0?oooo]Zo`3oA@03oookJP03o`3oT?oonf[o0?nB00Gooo]Z00SoJ03o
oookJ_oonf[ooo]ZoaP0ool0M?ooi_l0oolX00Wooo]Z00?ookh0og00oooonfX01?oonfX01OooE`3o
oo]ZoookJ_oonf[oogT000gooo]Z00?o0=CooookJ_l01?l00_oonfX01?l0R?oooo]Zo`3oC_l0oc@7
oookJP03oolX0?oonf[ooo]Z00?oobP000?oo`1ioookJ_oonfX00ooonfX00ol@0?ooT_l0oookJP06
oookJP03o`3oFooonf[o000000?o00001_oonfX00olPo`3o9P3oobH0o`0GoookJPCo4P3o3?oonfX9
oa80oagooo]Z00?o9P3oob3o0?oonfX04OoonfX00ol0oe_ooo]ZoookJP02oookJPSoo`0000CoT_l0
oookJ_oonf[o403o0ooonfX5oolX0003oookJ_oo07Wooo]Z00Oooo]Z00Co0?mCoolX0?oo:03o0?lM
1Ooo:008oookJP03o`3oC_l0obkooo]Z00Cooo]Z00?o08Soo`2YoooonfX00_oonfX01?l01?oooo]Z
oookJ_l0e?l;oookJP03oon10?oonf[ooo]Z00cooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooE`3o
oo]ZoookJP1<oookJP04ocoo0?oonf[ooo]Zo`0Zo`Cooo]Z00?ooe80okWo0?oonfX03ooonfX00ol0
Looooo]ZoookJP0CoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oonB0?oonfX00_oonfX00ooo
0?cooo]ZoookJP03oookJP09oaP0oooo1P3ooo]ZoookJ_o[o`3oo`3foookJ_l0Y_ooZ03o00?ooo]Z
00Woo`3io`1goooonf[oof`0o`3oV_l0olcooh40oookJ_lko`000_oonfX02ol0nooooo]ZoookJ_oo
nf[oo`<0oookJ_oo0=gooo]Zok?o0?l05oooW`3o00?ooo]Z00Co0?oNoookJ_oonf[oo`1/0_oonfX0
1Om=0?ooH@3ooookJ_oonf[o0?m500;ooo]Z00Co0?n@oookJ_oonf[o0?nB1?oonfX02OmX0?oooo]Z
oookJ_oonf[o603oo`1doooVo`3ooo]Zoon@0008oookJP03oonn0?m`0?oooo]Z00Cooo]Z00GooeL0
oookJ_oonf[ooo]Zool0;@0=oookJP03o`3Doooonf[o00Co00;ooo]Z00Co08SooookJ_oonf[o0?m>
1ooonfX00ol0oagooo]ZoookJP04oookJP03ool0NOoonf[ooo]Z00?ooo]Z00?oT_l0oookJ_oonfX0
1OoonfX00ol0oe_ooo]Zo`000003o`0000Oooo]Z0_lV0?lGoookJPGo4P3o3?oonfX9oa80oagooo]Z
00?o9P3ooookJ_oonfX04?oonfX00ol0oe_ooo]ZoookJP03oookJP05o`0`oooonf[ooo]ZoookJ_l6
0?l00_oonfX01OnBo`3ooo]ZoookJ_oonf[o403o00Gooo]Z00Goo`1AoookJ_oonf[ooo]Zool0N@07
oookJP05o`3oDooonf[o0?l8o`3o7Ol0hOl03?oonfX00ol0ocCo0?m>o`3o;P04oookJP03o`28oooo
nf[o0:Wo00?ooo]Z00?o00CooookJ_l0e?l03?oonfX00oooP@3ooo]ZoookJP0<oookJP03ool0;Ooo
nf[ooo]Z00Gooo]Z00?ooeL0oookJ_oonfX08ooonfX002_ooo]Z00Go?ol0oookJ_oonf[ooo]Zo`0Z
o`03oookJP03oomB0?oonf[o^Ol0013ooo]Z00?o07?ooookJ_oonfX04ooonfX00ooo0>[ooo]Zoook
JP05oookJP03oomi0?oonf[oogT000;ooo]Z00?oo`3loookJ_oonfX00ooonfX01_lH0?ooo`H0oook
J_oonf[ojol0ool0mP;ooo]Z00Wo0:KoojP0oooonf[ooo]Zool0nOoonf[o07Ooool00?ooK0000_oo
00001Olko`3oo`00oookJ_oonf[o0?_o00?ooo]Z00?oobP0oookJ_oonfX00ooUo`03oookJPWoogT0
00?oH@3oo`3oAOoonfX00_oonfX00ol0oi3ooo]Zo`3oTP05oookJP08ofP0oooonf[ooo]ZoookJ_lH
0?oo07CoonKo0?oo:009oookJP03oonn0?oonf[oL03o00Cooo]Z00CooeL0oookJ_oonf[ooo]Z0_oo
N@0<oookJP03o`3Doooonf[o00Co00;ooo]Z00Co08SooookJ_l0odko0?ld1ooonfX00ooo:03ooo]Z
oookJP02oookJP03oolX0?oo07Wooo]Z00Cooo]Z00?o403ooi;o0?oonfX01_oonfX00ol0oe_ooo]Z
oookJP04o`0000Cooo]Z00?oobP0obH0oolV0?l05?oonfX5oa80oa7ooo]Z0_oUo`06oookJP?o4P3o
6ooonfX00olV0?oo8?l0oookJP0AoookJP03o`3oFooonf[ooo]Z00?ooo]Z1_oo00001?nBo`3ooo]Z
oookJ_l@0?l5oookJP?oobP000?ooo]Zool0NOoonfX01ooonfX01Ooo:03o0?mCoolX0?oo:03o0?lM
00CoobP02?oonfX00ol0ocCo0?m>oookJP04oookJP03o`28oooonf[o0:Wo00?ooo]Z00?o00Cooook
J_l0e?l03?oonfX00oooP@3ooo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooeL0oook
J_oonfX0BooonfX01Oloo`3ooo]ZoookJ_oonf[o02[o00?ooo]Z00?ooe80o`3o<onio`004?oonfX0
0ol0Looooo]ZoookJP0CoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oonB0?oonfX00_oonfX0
0ooo0?cooo]ZoookJP02oookJP03oaP0oooo1P3ooo]Z00;ooo]Z00Gojol0oookJ_oonf[o0:KoojP0
o`03oookJP08ool0nOl0Mooooo]Zoom/0?oonf[o0?o<oon10?lko`03oookJP0:o`3koooonf[ooo]Z
oookJ_oo0`3ooo]Zool0gOl0Xooo/ol0oil0o`?ooo]Z00Go0?oNomgo0?oonf[ooo]Zool0K002oook
JP04odd0oomQ0?oooo]Zo`3oA@;ooo]Z00Co0?n@oookJ_oonf[o0?nB1OoonfX02?mX0?oooo]Zoook
J_lH0?oo07CoonKo0?oonf[ooi002?oonfX00ooo_P3o0?l5og00o`05oookJP05oomG0?oonf[ooo]Z
oookJ_oo02d03?oonfX00ol0e?oooo]Zo`04o`02oookJP04o`28oooonf[ooo]Zo`3oCPOooo]Z00?o
0?lMoookJ_oonfX01?oonfX00ooo07Wooo]ZoookJP03oookJP03oi;o0?oonf[ooo]Z00Gooo]Z00?o
0?mKoookJ_oonfX01?l00005oookJP;o9P3o5OoonfX4oa80oa[ooo]Z0olB0?lKoookJP03obH0oooo
nf[ooo]Z013ooo]Z00?o0?mKoookJ_oonfX00ooonfX01ol0<?oooo]ZoookJ_oonf[o1P3ooookJ_nB
o`000ooonfX00ol@0?oooo]ZoookJP04oookJP04ool0DOoonf[ooo]Zool0N@Sooo]Z00Go0?mCoook
J_l0o`So0?lMo`3Qo`0;oookJP03o`3o=?oonf[o0?m>00Gooo]Z00?o08SooookJ_l0ZOl00_oonfX0
0ol01?oooo]Zo`3Do`0<oookJP03oon10?oonf[ooo]Z00cooo]Z00?oo`0]oookJ_oonfX01OoonfX0
0oooE`3ooo]ZoookJP0SoookJP00:ooonfX01?loo`3ooo]ZoookJ_l0:_l4oookJP03oomB0?oonf[o
^Ol0013ooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP06oookJP;oogT00ooonfX0
0ooo0?cooo]ZoookJP03oookJP09oaP0oooo1P3ooo]Zon_o0?oonf[oo`3foookJ_l0Y_ooZ03o00?o
oo]Z00Goo`3io`1goooo003oof`0o`3oVP02ool00004oc_o0?oo003ooo]Zo`3ko`?ooo]Z00CoobP0
oookJ_oonf[oN@3o0ooUo`04oookJP03o`3og_ooN@3oogT000CoogT000?oH@3ooookJ_l0odD00_oo
nfX01?l0oi3ooo]ZoookJ_l0oi85oookJP08ofP0oooonf[ooo]ZoookJ_lH0?oo07CoonKo0?ooT008
oookJP03oonn0?l0o`GoL03o00Cooo]Z00CooeL0oookJ_oonf[ooo]Z0oooN@0<oookJP05o`3Dool0
1?oooo]ZoookJ_l0R?l00_oonfX00ol0odkooo]ZoookJP05oookJP03oolX0?oonf[ooo]Z00?ooo]Z
00?oo`1ioookJ_oonfX00ooonfX00ol@0?ooT_l0oookJP05oookJP;oobP00ooonfX4o`0000;ooo]Z
0_oo:0000olV0?ooobP0oookJP0@oookJPCo4P3o5_oonfX3onGo00Sooo]Z0olB0?lIoookJP03obH0
oolPo`3ooo]Z017ooo]Z00?o0?mKoookJ_oonfX00_oonfX00ol0<?ooo`00ool00004ool00004oi;o
0?oonf[ooo]Zoa00o`Gooo]Z0ooo:0000ooonf[oo`1ioookJP07oookJP04o`3oDooo:03oobP0o`3o
7@CoobP02OoonfX00ol0odko0?l^oookJP04oookJP03o`28ool0ZOoooo]Z00;ooo]Z00?o00Cooook
J_l0e?l03?oonfX00oooP@3ooo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0oook
J_oonfX0B_oonfX01?loo`3ooo]ZoookJ_l0:_l4oookJP03oomB0?oonf[o^Ol0013ooo]Z00?o07?o
oookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP07oookJP03oonB0?oonf[ooo]Z00;ooo]Z00?oo`3l
oookJ_oonfX00_oonfX02OlH0?ooo`H0oookJ_oonf[ojol0ool0m_oonf[o0:KoojP0o`03oookJP09
ool0nOl0Mooooo]Zoom/0?l0oi[ooo]Zoon10?oonf[o>ol000;ooo]Z00_o0?_ooookJ_oonf[ooo]Z
ool30?oonf[oN@3oool0gOl0Xooo/ol0oil0o`03oookJP0=o`3og_oonf[ooo]ZoookJ_oo06cooo]Z
odd0oooo;P3oH@3ooookJ_l0odGooo]Zo`3oT003oookJP03o`3oT_oonf[ooo]Z00;ooo]Z00WoJ03o
oookJ_oonf[ooo]ZoaP0ool0M?ooi_l0oookJ_ooT0001ooonfX00ooo_P3ooo]Zog00o`05oookJP05
oomG0?oonf[ooo]ZoookJ_oo02d03OoonfX01Ol0e?oo00CooookJ_oonf[o08So00;ooo]Z00?o0?m>
oookJ_oonfX01OoonfX00ol0oagooo]ZoookJP04oookJP03ool0NOoonf[ooo]Z00?ooo]Z00?oT_l0
oookJ_oonfX01OoonfX01?l0oe_ooo]ZoookJ_oonfX4o`0000Cooo]Z00?o9P3ooookJ_oonfX04?oo
nfX5oa80ob7ooo]Z0olB0?lIoookJP03obH0oolPo`3ooo]Z013ooo]Z00?o0?mKoookJ_oonfX00_oo
nfX00ol0<?oooo]ZoookJP02oookJP03o`H0oooonf[oT_l000?ooo]Z00?o403ooookJ_oonfX00ooo
nfX01Ooo057ooo]ZoookJ_oonf[oo`1i00Oooo]Z00Go0?mCoookJ_l0o`So0?lMo`3Qo`0<oookJP03
o`3o=?l0odko0?l^00Cooo]Z00?o08SooookJ_l0ZOl00_oonfX00ol01?oooo]Zo`3Do`0<oookJP03
oon10?oonf[ooo]Z00cooo]Z00?oo`0]oookJ_oonfX01_oonfX00oooE`3ooo]ZoookJP0RoookJP00
:ooonfX01?loo`3ooo]ZoookJ_l0:_l4oookJP03oomB0?nio`3ooo]Z013ooo]Z00?o07?ooookJ_oo
nfX04_oonfX00ooo0>[ooo]ZoookJP05oookJP03oomi0?oonf[oogT000;ooo]Z00?oo`3loookJ_oo
nfX00ooonfX01_lH0?ooo`H0oookJ_oonf[ojol0ool0mP;ooo]Z00co0:KoojP0oooonf[ooo]Zool0
nOoonf[o07OooookJ_ooK03o0?nJool00?lko`02ool00003oookJ_l0nooooo]Z00;ooo]Z00?oobP0
oookJ_oonfX01?oUo`03oookJP04o`3og_oMo`3ooo]ZoookJPCoogT000?oH@3oo`3oAOoonfX00_oo
nfX00ol0oi3ooo]Zo`3oTP05oookJP08oolX0?oonf[ooo]ZoookJ_lH0?oo07CoonKo0?ooT009oook
JP03oonn0?oonf[oL03o00Cooo]Z00?ooeL0oookJ_oonfX00oooN@0<oookJP05o`3Dool01?oooo]Z
oookJ_l0R?l00_oonfX00ol0odkooo]ZoookJP05oookJP03oolX0?oonf[ooo]Z00?ooo]Z00?oo`1i
oookJ_oonfX00ooonfX00ol@0?oooo]Zoi;o0005oookJP?oobP00ooonfX4o`0000?oobP000?o9P3o
oolX0?oonfX03_oonfX3oa80oa3ooo]Z0ooo0007oookJPGoiOl02OoonfX3oa80oaOooo]Z0_lV0?lB
oookJP03o`3oFooonf[ooo]Z00;ooo]Z00?o033oool00?oo00001?oo00000onBo`3ooo]Zoa00o`06
oookJP;oobP000?ooo]Zool0NOoonfX01ooonfX01Ol0oe?oobP0oolX0?oo:03o0?lM00?oobP02Ooo
nfX00ol0ocCo0?m>oookJP04oookJP03o`28oooonf[o0:Wo00;ooo]Z00Co00CooookJ_oonf[o0=Co
2ooonfX00oooP@3ooo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0oookJ_oonfX0
B_oonfX01?loo`3ooo]ZoookJ_l0:_l4oookJP03oomB0?nio`3ooo]Z013ooo]Z00?o07?ooookJ_oo
nfX04_oonfX00ooo0>[ooo]ZoookJP06oookJP03oolF0?ooTP3ooo]Z00;ooo]Z00?oo`3loookJ_oo
nfX00ooonfX01Ooo1P3ooo]ZoookJ_oonf[ojol000;ooo]Z00?o0:KoojP0oooonfX00_oonfX02?oo
0?Wo07OooookJ_ooK03o0?nJo`3oc?ooP@3o>ol00ooonfX02_l0nooooo]ZoookJ_oonf[oo`<0oook
J_oo0=gooo]Zok?o0?nO0?l3oookJP05o`3og_oMo`3ooo]ZoookJ_oo06`00_oonfX01?m=0?ooH@3o
oookJ_l0odD2oookJP04o`3oT?oonf[ooo]Zo`3oTPCooo]Z00WoJ03ooookJ_oonf[ooo]ZoaP0ool0
M?ooi_l0oookJ_ooT0002?oonfX00ooo_P3o0?l5og00o`04oookJP03oomG0?oonf[ooo]Z00;ooo]Z
00?oo`0]oookJ_oonfX02_oonfX01Ol0e?oo00CooookJ_oonf[o08So00;ooo]Z00?o0?ldo`3oC_oo
nfX01OoonfX00ol0oagooo]ZoookJP04oookJP03ool0NOoonf[ooo]Z00?ooo]Z00?o403ooi;o0?oo
nfX01OoonfX00ol0oe_ooo]ZoookJP02oookJPCo00000ooonfX00olV0?oooo]ZoookJP0>oookJP?o
4P3o:OoonfX2oa80oaSooo]Z00?o9P3oob3o0?oonfX04?oonfX00ol0oe_ooo]ZoookJP02oookJP03
o`0`oooonf[ooo]Z00;ooo]Z00?o1P3ooookJ_nBo`000_oonfX00ol@0?oooo]ZoookJP04oookJP04
ool0DOoonf[ooo]Zool0N@Oooo]Z00Ko0?mCoookJ_l0o`Sooo]Zo`3o7Ol0hOl;oookJP03o`3o=?oo
nf[o0?m>00Cooo]Z00Co08SooookJ_oonf[o0:Wo0_oonfX00ol01?oooo]Zo`3Do`0<oookJP03oon1
0?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX01_oonfX00oooE`3ooo]ZoookJP0RoookJP00:_oo
nfX01Oloo`3ooo]ZoookJ_oonf[o02[o00?ooo]Z00?ooe80oookJ_nio`004?oonfX00ol0Looooo]Z
oookJP0CoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?oogT0oookJ_ooN@000_oonfX00ooo0?cooo]Z
oookJP03oookJP06oaP0oooo1P3ooo]ZoookJ_o[o`3oo`3f0_oonfX01_l0Y_ooZ03ooookJ_oonf[o
o`3io`1go`;ooo]Z00Coof`0ool00?oo003o>ol00_oo00001Ooonf[o0?_ooookJ_oonf[oobP000;o
oo]Z00?oN@3oonGo0?oUo`000_oUo`03oookJP09o`3og_oonf[ooo]ZoookJ_ooN@3ooo]Zodd0oooo
N@3oH@3o00?ooo]Z00?o0?n@oookJ_l0oi801_oonfX02?oo:03ooo]ZoookJ_oonf[o603oo`1doooV
o`3ooi002?oonfX00ooo_P3o0?l5og00o`04oookJP03oomG0?oonf[ooo]Z00CoogT02ooonfX01Ol0
e?ooiOl0oookJ_oonf[o08So00;ooo]Z00?o0?m>o`3o=?oonfX01OoonfX00ooo:03o0?l8oookJP03
oookJP03ool0NOoonf[ooo]Z00?ooo]Z00?o403ooookJ_nBo`001?oonfX4oolX00Cooo]Z0_l00003
oolX00;o9P3o00?oobP0oookJ_oonfX03?oonfX2oa80oa?ooo]Z1_oo0003oookJPSoiOl02_oonfX3
oa80oaKooo]Z00?o9P3ooookJ_oonfX04?oonfX01_l0oe_ooo]ZoookJ_oonf[o033ooookJPGoo`00
00CoT_l0oookJ_oonf[o403o1_oonfX01?oo:03ooo]ZoookJ_oo07T8oookJP04o`3oDooo:03oobP0
o`3o7@?oobP02OoonfX00ol0ocCo0?m>o`3o;P04oookJP03o`28oooonf[o0:Wo00?ooo]Z00?o00Co
oookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP0<oookJP03ool0;Ooonf[ooo]Z057ooo]Z00Go?ol0
oookJ_oonf[ooo]Zo`0Zo`03oookJP03oomB0?l0oc?o^Ol0013ooo]Z00?o07?ooookJ_oonfX04ooo
nfX00ooo0>[ooo]ZoookJP06oookJP03oolF0?ooTP3ooo]Z00;ooo]Z00?oo`3loookJ_oonfX00_oo
nfX01_lH0?ooo`H0oookJ_oonf[ojol0ool0mP;ooo]Z00Ko0:KoojP0oooonf[ooo]Zool0nOl0Mol2
oookJP05oom/0?oonf[ooh40oookJ_lko`000ooonfX02_l0nooooo]ZoookJ_oo0`3ooo]ZogT0oooo
0=go0:?ook?o0?nO0?l3oookJP0:o`3og_oonf[ooo]ZoookJ_oo06cooo]Zodd0oooo;P3oH@3oo`3o
A@;ooo]Z00Co0?n@oookJ_oonf[o0?nB1OoonfX02OmX0?oooo]ZoookJ_oonf[o603oo`1doooVo`3o
oo]Zoon@0007oookJP03oonn0?oonf[oL03o00Gooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@0<oook
JP05o`3Dool01?oooo]ZoookJ_l0R?l00ooonfX00ol0odkooo]ZoookJP04oookJP03o`3o7Ol0o`So
oo]Z00Cooo]Z00?oo`1ioookJ_oonfX00ooonfX00ol@0?ooT_l0oookJP05oookJP03o`3oFooonf[o
oo]Z00?ooo]Z1?l000000ooonf[o9P3oobH0o`0?oookJP;o4P3o;_oonfX3oa80oaKooo]Z00?o9P3o
ob3o0?oonfX04?oonfX01Ol0oe_ooo]ZoookJ_oonf[o033o00Cooo]Z00?o1P3ooookJ_nBo`000ooo
nfX00ol@0?oooo]ZoookJP04oookJP04ool0DOoonf[ooo]Zool0N@Oooo]Z00Go0?mCoookJ_l0o`So
oo]Zo`3o7@0;oookJP04o`3o=?oonf[o0?m>o`3o;PCooo]Z00?o08SooookJ_l0ZOl00_oonfX00ol0
1?oooo]Zo`3Do`0<oookJP03oon10?oonf[ooo]Z00cooo]Z00?oo`0]oookJ_oonfX0:_oonfX002[o
oo]Z00Go?ol0oookJ_oonf[ooo]Zo`0Zo`03oookJP03oomB0?oonf[o^Ol0013ooo]Z00?o07?ooook
J_oonfX04ooonfX00ooo0>[ooo]ZoookJP05oookJP;oogT00ooonfX00ooo0?cooo]ZoookJP03oook
JP09oomi0?oonf[ooo]Zon_o0?oonf[oo`3foookJ_l0Y_ooZ03o00;ooo]Z00Soo`3ioookJ_l0Mooo
oo]Zoom/0?l0oi[oo`00oc_o00;ooo]Z00?oo`00o`3koooonfX00_oonfX00ooo:03ooo]ZoookJP05
onGo00;ooo]Z00[o0?oNomgo0?oonf[ooo]Zoomi0?oonf[oC@3oool00?mQ0?oo0?m50ooonfX00ol0
oi3ooo]Zo`3oTP05oookJP;oobP00ooonfX00olH0?ooi_l0oon@0009oookJP03oonn0?oonf[oL03o
00Cooo]Z00?ooeL0oookJ_ooN@001?ooN@0;oookJP05o`3DoooUo`3ooo]ZoookJ_l0R?l00_oonfX0
0ol0odkooo]ZoookJP04oookJP03oolX0?l0o`Sooo]Z00?ooo]Z00?oo`1ioookJ_oonfX00ooonfX0
0ol@0?oooo]Zoi;o0003oookJPGoobP01OoonfX4oolX0004obH0oooo:03oobP0oolX00cooo]Z0_lB
0?l;oookJP[o0=co2Ooo0009onGo00cooo]Z0olB0?lDoookJP03obH0oooonf[ooo]Z013ooo]Z00Ko
0?mKoookJ_oonf[ooo]Zo`0`oooonfX5ool00003oi;o0?oonf[o403o00Oooo]Z00?oobP0oookJ_oo
07T02?oonfX01Ol0oe?ooo]ZoolX0?oo:03o0?lM00?oobP02?oonfX00ol0ocCooo]Zo`3oCP04oook
JP04o`28oooonf[ooo]Zo`2Yo`;ooo]Z00?o00CooookJ_l0e?l03?oonfX00oooP@3ooo]ZoookJP0;
oookJP03ool0;Ooonf[ooo]Z057ooo]Z00Go?ol0oookJ_oonf[ooo]Zo`0Zo`03oookJP03oomB0?l0
oc?o^Ol0013ooo]Z00?o07?ooookJ_oonfX04ooonfX00ooo0>[ooo]ZoookJP06oookJP03oonB0?oo
nf[ooo]Z00;ooo]Z00?oo`3loookJ_oonfX00_oonfX02Ooo1P3ooo]ZoookJ_oonf[ojol0ool0m_oo
nf[o0:KoojP0o`03oookJP08ool0nOl0Mooooo]Zoom/0?l0oi[o0?o<oon10?lko`03oookJP0:o`3k
oooonf[ooo]ZoookJ_oo0`3ooo]Zool0gOoonf[o0:?ook?o00?ooo]Z00Go0?oNomgo0?oonf[ooo]Z
ool0K002oookJP04odd0oomQ0?oooo]Zo`3oA@;ooo]Z00Co0?n@oookJ_oonf[o0?nB1?oonfX00omX
0?oooo]ZoookJP02oookJP04oaP0oooVo`3ooo]Zoon@00Sooo]Z00?ookh0o`3o1Om`0?l01?oonfX0
1OooE`3ooo]ZoookJ_oonf[oo`0]00gooo]Z00Go0=Coo`04oooonf[ooo]Zo`28o`02oookJP03o`3o
C_oonf[ooo]Z00Cooo]Z00?o0?lMo`3o2?oonfX01?oonfX00ooo07Wooo]ZoookJP03oookJP03oa00
oonBo`3ooo]Z00Gooo]Z00?o0?mKoookJ_oonfX01?oonfX4o`000003obH0oooonf[ooo]Z00gooo]Z
0_lB0?l<oookJQCo0=co4ooonfX3oa80oaCooo]Z00?o9P3oob3o0?oonfX04?oonfX01Ol0oe_ooo]Z
oookJ_oonf[o033o00Cooo]Z00?o1P3ooookJ_nBo`000_oonfX00ol@0?oooo]ZoookJP05oookJP03
ool0DOoonf[oo`1i00Oooo]Z00Ko0?mCoookJ_l0o`Sooo]Zo`3o7Ol0hOl;oookJP03o`3o=?oonf[o
0?m>00Cooo]Z00So08SooookJ_oonf[o0:WooookJ_l01?oooo]Zo`3Do`cooo]Z00?ooh40oookJ_oo
nfX03?oonfX00ooo02gooo]ZoookJP0ZoookJP00;_oonfX01ol0:_oooo]ZoookJ_oonf[ooe80oook
J_nio`004?oonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?oogT0oook
J_ooN@000_oonfX00ooo0?cooo]ZoookJP03oookJP06oaP0ooooN@3ooo]ZoookJ_o[o`3oo`3f0_oo
nfX01_l0Y_ooZ03ooookJ_oonf[oo`3io`1go`;ooo]Z00Coof`0o`3oV_oo003o>ol00ooonfX01?l0
nooooo]ZoookJ_oo:002oookJPKoiOl00_oonfX02Ol0omkooo]ZoookJ_oonf[oogT0oookJ_m=0?oo
o`00of40o`03oookJP03o`3oT?oonf[o0?nB00Gooo]Z0ooo:002oookJP04oaP0oooVo`3ooo]Zoon@
00Sooo]Z00?ookh0o`3o1Om`0?l01?oonfX00oooE`3ooo]Zoomi0005oomi00[ooo]Z00Go0=CoonGo
0?oonf[ooo]Zo`28o`02oookJP03o`3oC_oonf[ooo]Z00Cooo]Z00?oobP0o`3o2?oonfX00ooonfX0
0ooo07Wooo]ZoookJP03oookJP03oa00oooonf[oT_l000?ooo]Z1_oo:003oookJPGoobP000Co9P3o
oolX0?oo:03oobP02ooonfX2oa80o`[ooo]Z0ol0g?l:oookJPcoo`002?oUo`0=oookJP;o4P3o4ooo
nfX00olV0?oooo]ZoookJP0?oookJP03o`3oFooonf[ooo]Z00;ooo]Z00?o033ooookJ_oonfX00ooo
00001?nBo`3ooo]ZoookJ_l@0?l6oookJP04ool0DOoonf[ooo]Zool0N@Oooo]Z00?o0?mCoookJ_oo
nfX00_oo:0000oooN@3oobP0oolX0009oookJP03o`3o=?l0odko0?l^00Cooo]Z00?o08SooookJ_l0
ZOl00_oonfX01?l01?oooo]ZoookJ_l0e?l;oookJP03oon10?oonf[ooo]Z00_ooo]Z00?oo`0]oook
J_oonfX0EOoonfX01ol0:_oooo]ZoookJ_oonf[ooe80oookJ_nio`004?oonfX00ol0Looooo]Zoook
JP0BoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oonB0?oonfX00_oonfX00ooo0?cooo]Zoook
JP02oookJP03oaP0oooo1P3ooo]Z00;ooo]Z00Gojol0oookJ_oonf[o0:KoojP0o`03oookJP08o`1g
oooonf[ooo]Zoom/0?l0oi[ooh40oookJ_lko`03oookJP0:o`3koooonf[ooo]Zool30?oonf[oN@3o
ool0gOl0Xooo/ol0oil0o`?ooo]Z00Go0?oNoookJ_oonf[ooo]Zool0K002oookJP03odd0oomQ0?oo
0?m500;ooo]Z00Co0?n@oookJ_oonf[o0?nB1OoonfX01_mX0?oooo]ZoookJ_oonf[o603oonKo00;o
oo]Z00?ooi00oookJ_oonfX01OoonfX00ooo_P3ooo]Zog00o`04oookJP03oomG0?oonf[ooo]Z00;o
oo]Z00?oo`0]oookJ_oonfX02_oonfX01Ol0e?oo00CooookJ_oonf[o08So00;ooo]Z00?o0?m>oook
J_oonfX01?oonfX00ol0oago0?l8oookJP04oookJP03ool0NOoonf[ooo]Z00?ooo]Z00?o403ooi;o
0?oonfX01OoonfX00ol0oe_ooo]ZoookJP05oookJP?o000000?o9P3ooookJ_oonfX03?oonfX2oa80
o`_ooo]Z0ol0g?lDoookJPCo0=co4_oonfX2oa80oa?ooo]Z00?o9P3oob3o0?oonfX03ooonfX00ol0
oe_ooo]ZoookJP02oookJP03o`0`oooonf[ooo]Z00;ooo]Z00?o1P3ooi;o0?oonfX00_oonfX00ol@
0?oooo]ZoookJP04oookJP04ool0DOoonf[ooo]Zool0N@Kooo]Z00Oo0?mCoookJ_oonf[o0?l8oook
J_l0oago0>7o00[ooo]Z00Co0?ldoookJ_l0odko0?l^0ooonfX01?l0R?oooo]ZoookJ_l0ZOl2oook
JP03o`04oooonf[o0=Co00cooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP0Zoook
JP00;OoonfX00ol0:_oooo]ZoookJP02oookJP03oomB0?nio`3ooo]Z00oooo]Z00?o07?ooookJ_oo
nfX04ooonfX00ooo0>[ooo]ZoookJP05oookJP03oomi0?oonf[oogT000;ooo]Z00?oo`3loookJ_oo
nfX00ooonfX2oomi0004oookJ_o[o`3ooo]Zool0mP;ooo]Z00Ko0:KoojP0oooonf[oo`3ioookJ_l0
Mol2oookJP04oom/0?oo003ooo]Zoc_o00;ooo]Z00Go0?_ooookJ_oonf[ooo]ZoolX0002oookJPGo
iOl00_oonfX01Ol0omkogOl0oookJ_oonf[oogT000;ooo]Z00?oC@3oof40ool0odD00ooonfX00ol0
oi3ooo]Zo`3oTP04oookJPCoobP00_oonfX01?lH0?ooi_l0oookJ_ooT008oookJP03oonn0?oonf[o
L03o00?ooo]Z00?ooeL0oookJ_ooN@001OooN@0:oookJP05o`3DoooUo`3oiOl0oookJ_l0R?l00_oo
nfX00ol0odko0?ldoookJP04oookJP03oolX0?l0o`Sooo]Z00?ooo]Z00?oo`1ioookJ_oonfX00ooo
nfX00ol@0?oooo]Zoi;o0002oookJPOoobP00_oonfX5oolX00;o9P3o0ooo:009oookJP?o4P3o2Ooo
nfX3o`3Lo`cooo]Z4?oo0007onGo00gooo]Z00?o4P3ooookJ_oonfX04OoonfX00olV0?oooo]Zoook
JP0?oookJP05o`3oFooonf[ooo]ZoookJ_l0<?l00ooonfX3ool00004oi;o0?oonf[ooo]Zoa00o`Ko
oo]Z00?oo`1AoookJ_oo07T02?oonfX01Ol0oe?ooo]ZoolX0?oo:03oogT000;oobP02OoonfX00ol0
ocCooo]Zo`3oCP04oookJP04o`28oooonf[ooo]Zo`2Yo`;ooo]Z00?o00CooookJ_l0e?l02ooonfX0
0oooP@3ooo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z05Cooo]Z00?o02[ooookJ_oonfX00_oonfX0
0oooDP3o^Ol0oookJP0?oookJP03o`1coooonf[ooo]Z01?ooo]Z00?oo`3ZoookJ_oonfX01_oonfX0
0ooo5P3ooi80oookJP02oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Ko603oool60?oonf[ooo]Zon_o
0?oo0?H2oookJP06o`2VoonX0?oooo]ZoookJ_oo0?Wo07Oo0_oonfX01?ooK03ooo]Zoon10?lko`03
oookJP0:o`3koooonf[ooo]ZoookJ_oo0`3ooo]ZogT0oooo0=go0:?ook?o00?ooo]Z00Go0?oNomgo
0?oonf[ooo]Zool0K002oookJP04odd0oooo;P3oH@3oo`3oA@;ooo]Z00Co0?n@oookJ_oonf[o0?nB
1OoonfX02?mX0?oooo]ZoookJ_oonf[o603oonKo0?oonf[ooi002?oonfX00ooo_P3o0?l5og00o`04
oookJP05oomG0?oonf[ooo]ZoookJ_oo02d03?oonfX01Ol0e?oo00CooookJ_oonf[o08So00?ooo]Z
00?o0?m>oookJ_oonfX00ooonfX00ol0oago0?l8oookJP04oookJP03ool0NOoonf[ooo]Z00?ooo]Z
00?o403ooi;o0?oonfX01OoonfX00ol0oe_ooo]ZoookJP06oookJP03o`000?lV0?oo9P3o00;o0000
2ooonfX2oa80o`[ooo]Z0ol0g?l<oookJPWo02[o1_oonfX4o`3Loa3ooo]Z00?o4P3ooookJ_oonfX0
4OoonfX00olV0?oo8?l0oookJP0?oookJP05o`3oFooonf[ooo]ZoookJ_l0<?l01?oonfX00ol60?oo
oo]Zoi;o0003oookJP03oa00oooonf[ooo]Z00?ooo]Z00Coo`1AoookJ_oonf[oo`1i1ooonfX01_l0
oe?ooo]Zo`3o2?oonf[o0?lMo`3Qo`[ooo]Z00Co0?ldoookJ_oonf[o0?m>1?oonfX02?l0R?oooo]Z
oookJ_l0ZOoooo]Zo`04oooonf[o0=Co3?oonfX00oooP@3ooo]ZoookJP0;oookJP03ool0;Ooonf[o
oo]Z02[ooo]Z000]oookJP07o`0Zoooonf[ooo]ZoookJ_ooDP3ooo]ZokWo000@oookJP03o`1coooo
nf[ooo]Z01?ooo]Z00?oo`3ZoookJ_oonfX01OoonfX2oomi00?ooo]Z00?oo`3loookJ_oonfX00_oo
nfX3oomi0003oookJ_o[o`3oo`3f00;ooo]Z00Ko0:KoojP0oooonf[ooo]Zool0nOl0Mol2oookJP04
oom/0?l0oi[oo`00oc_o00?ooo]Z00Co0?_ooookJ_oonf[oobP00_oonfX6onGo00;ooo]Z00Wo0?oN
oookJ_oonf[ooo]Zoomi0?oonf[oC@3oool00?mQ0?l01?oonfX00ol0oi3o0?nBoookJP04oookJP?o
obP00_oonfX01?lH0?ooi_l0oookJ_ooT008oookJP03oonn0?l0o`GoL03o00Cooo]Z00?ooeL0oomi
0?ooN@001OooN@09oookJP09onGo0?l0e?ooiOl0onGo0?oonf[o08SooookJ_l0odko0?ld00Gooo]Z
00?oobP0o`3o2?oonfX00ooonfX00ooo07Wooo]ZoookJP04oookJP03oa00oonBo`3ooo]Z00WoobP0
00?ooo]ZoolX0?oo:0000ooo:0000olV0?ooobP0oolX0002oolX00Sooo]Z0_lB0?l:oookJP;o0=co
3OoonfX9oomB00[oo`0000?o02[oonGo0?oUo`001?oUo`0=oookJP03oa80oooonf[ooo]Z017ooo]Z
00?o9P3ooookJ_oonfX03_oonfX00ol0oe_ooo]ZoookJP02oookJP04o`0`oooonf[ooo]ZoookJP;o
o`0000Cooo]Zoi;o0?oonf[o403o1_oonfX01?oo057ooo]ZoookJ_oo07T7oookJP05o`3oDooonf[o
oo]ZoolX0?ooN@000_oo:009oookJP03o`3o=?oonf[o0?m>00Cooo]Z00Co08SooookJ_oonf[o0:Wo
0_oonfX00ol01?oooo]Zo`3Do`0<oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX0
E?oonfX01ol0:_oooo]ZoookJ_oonf[ooe80o`3o<onio`004?oonfX00ol0Looooo]ZoookJP0Coook
JP03ool0j_oonf[ooo]Z00Kooo]Z00?ooi80oookJ_oonfX00_oonfX00ooo0?cooo]ZoookJP02oook
JP05ool60?oonf[ooo]ZoookJ_o[o`000_oonfX00ol0Y_ooZ03ooookJP02oookJP08o`1goooonf[o
oo]Zoom/0?l0oi[o0?o<oon10?lko`03oookJP0:o`3koooonf[ooo]Zool30?oonf[oN@3oool0gOoo
nf[o/ol0oil0o`?ooo]Z00Go0?oNoookJ_oonf[ooo]Zool0K002oookJP03odd0oomQ0?oo0?m500?o
oo]Z00?o0?n@oookJ_l0oi801OoonfX01_mX0?oooo]ZoookJ_oonf[o603oonKo00;ooo]Z00?ooi00
oookJ_oonfX01OoonfX00ooo_P3ooo]Zog00o`04oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]
oookJ_oonfX02_oonfX01Ol0e?oo00CooookJ_oonf[o08So00;ooo]Z00?o0?m>oookJ_oonfX00ooo
nfX00ol0oago0?l8oookJP04oookJP03ool0NOoonf[ooo]Z00?ooo]Z00?o403ooi;o0?oonfX01Ooo
nfX00ol0oe_ooo]ZoookJP07oookJP04obH0ool0003o0000o`0000[ooo]Z0_lB0?l:oookJP;o0=co
3?oonfX9oomB0003o`3o<ooonf[ooo]Z00So02[o0_oonfX4o`3Lo`gooo]Z00?o4P3ooookJ_oonfX0
4OoonfX00olV0?oo8?l0oookJP0>oookJP03o`3oFooonf[ooo]Z00;ooo]Z00?o033ooookJ_oonfX0
0_oonfX00ol60?oooo]Zoi;o0002oookJP03oa00oooonf[ooo]Z00Cooo]Z00Coo`1AoookJ_oonf[o
o`1i1_oonfX01ol0oe?ooo]ZoookJ_l0o`So0?lMoookJ_l0hOl02OoonfX01?l0ocCooo]ZoookJ_l0
odh4oookJP08o`28oooonf[ooo]Zo`2Yoooonf[o00CooookJ_l0e?l<oookJP03oon10?oonf[ooo]Z
00_ooo]Z00?oo`0]oookJ_oonfX0:_oonfX002gooo]Z00Oo02[ooookJ_oonf[ooo]ZoomB0?oonf[o
^Ol0013ooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP05oookJP03oomi0?oonf[o
ogT000;ooo]Z00?oo`3loookJ_oonfX00ooonfX3oomi0003on_o0?oonf[oo`3f00;ooo]Z00Ko0:Ko
ojP0oooonf[oo`3ioookJ_l0Mol2oookJP04oom/0?oo003ooo]Zoc_o00?ooo]Z00Co0?_ooookJ_oo
nf[oobP00_oonfX6onGo0003oookJ_l0omkogOl000?ooo]Z00GoogT0oookJ_m=0?oooo]Zof40o`03
oookJP03o`3oT?oonf[o0?nB00Cooo]Z1?oo:002oookJP04oaP0oooVo`3ooo]Zoon@00Sooo]Z00?o
okh0oookJ_m`0?l00ooonfX00oooE`3oogT0oomi0006oomi00Sooo]Z00KoiOl0o`3DoooUo`3oiOl0
oookJ_l0R?l2oookJP03o`3oC_oonf[ooo]Z00Cooo]Z00?o0?lMo`3o2?oonfX00_oonfX00ooo07Wo
oo]ZoookJP04oookJP03oa00oooonf[oT_l000WoobP00_oonfX4oolX0003obH0oooo:03oobP000?o
obP01_oonfX2oa80o`Wooo]Z0ol0g?l7oookJPSooe8000?o0?lcoookJ_oonfX01_oo0007oomB00?o
obP000?oiOl0o`0Zool0:_l01OoUo`000ol0g?oooo]ZoookJP0:oookJP03oa80oooonf[ooo]Z017o
oo]Z00?o9P3ooookJ_oonfX03_oonfX01Ol0oe_ooo]ZoookJ_oonf[o033o00Cooo]Z00?oo`00oook
J_nBo`000_oonfX00ol@0?oooo]ZoookJP03oookJP04ool0DOoonf[ooo]Zool0N@Oooo]Z00Oo0?mC
oookJ_oonf[o0?l8oolX0?ooN@3oobP000Wooo]Z00Co0?ldoookJ_oonf[o0?m>1?oonfX00ol0R?oo
oo]Zo`2Yo`02oookJP03o`04oooonf[o0=Co00cooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02go
oo]ZoookJP1DoookJP07o`0Zoooonf[ooo]ZoookJ_ooDP3ooo]ZokWo000@oookJP03o`1coooonf[o
oo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01_oonfX00ooo5P3ooi80oookJP02oookJP03ool0o?oonf[o
oo]Z00;ooo]Z00Ko603oool60?oonf[ooo]Zon_o0?oo0?H2oookJP06o`2VoonX0?oooo]ZoookJ_oo
0?Wo07Oo0_oonfX01?ooK03ooo]Zoon10?lko`04oookJP09o`3koooonf[ooo]Zool30?oonf[oN@3o
ool0gOl0Xooo/ol000?ooo]Z00?o0?oNomgo0?oonfX00_oonfX01_oo06cooo]Zodd0oooo;P3oH@3o
o`3oA@;ooo]Z00Co0?n@oookJ_oonf[o0?nB1OoonfX01_mX0?oooo]ZoookJ_oonf[o603oonKo00;o
oo]Z00?ooi00oookJ_oonfX01OoonfX00ooo_P3o0?l5og00o`03oookJP03oomG0?oonf[ooo]Z00;o
oo]Z00?oo`0]oookJ_oonfX02_oonfX01Ol0e?oo00CooookJ_oonf[o08So00;ooo]Z00?o0?m>oook
J_oonfX01?oonfX00ol0oago0?l8oookJP03oookJP03ool0NOoonf[ooo]Z00?ooo]Z00?o403ooook
J_nBo`001OoonfX00ol0oe_ooo]ZoookJP07oookJP03obH0ool0003o000000;o00002?oonfX2oa80
o`Wooo]Z0ol0g?l6oookJPSooe800_l0oc<7oookJPOooe801?oonfX2o`0Zo`Cooo]Z0ol0g?l;oook
JP03oa80oooonf[ooo]Z017ooo]Z00?o9P3oob3o0?oonfX03_oonfX01Ol0oe_ooo]ZoookJ_oonf[o
033o00Gooo]Z00?o1P3ooi;o0?oonfX00_oonfX00ol@0?oooo]ZoookJP03oookJP04ool0DOoonf[o
oo]Zool0N@Kooo]Z00Oo0?mCoookJ_oonf[o0?l8oookJ_l0oago0>7o00[ooo]Z00Co0?ldoookJ_l0
obko0?m>0ooonfX01?l0R?oooo]ZoookJ_l0ZOl2oookJP03o`04ool0e?oooo]Z00cooo]Z00?ooh40
oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP0ZoookJP00;OoonfX01ol0:_oooo]ZoookJ_oonf[o
oe80oookJ_nio`004?oonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?o
ogT0oookJ_ooN@000_oonfX00ooo0?cooo]ZoookJP02oookJPCoogT000_ojol0ool0m_oonf[ooo]Z
o`2Voooonf[oZ03ooookJ_oo0?Wooo]Zo`1go`02oookJP03oom/0?oo003o>ol000?ooo]Z00Co0?_o
oookJ_oonf[oobP00_oonfX7onGo0003oookJ_l0omkooo]Z00;ooo]Z00GoogT0oookJ_m=0?ooo`00
of40o`04oookJP03o`3oT?oonf[o0?nB00?ooo]Z1Ooo:0001Ooonf[o603oonKo0?oonf[ooi0000So
oo]Z00?ookh0o`3o1Om`0?l01?oonfX00oooE`3oogT0oomi0005oomi00Sooo]Z00?oiOl0o`3DoooU
o`000_oUo`001Ol0R?oooo]ZoookJ_l0odko0?ld00Gooo]Z00?o0?lMo`3o2?oonfX00ooonfX00ooo
07Wooo]ZoookJP03oookJP03oa00oooonf[oT_l000WoobP01?oonfX2oolX0003obH0oooo:03oobP0
00?oobP01OoonfX2oa80o`Sooo]Z0ol0g?l4oookJP03ool00?ooDP3ooe8000?ooe800_l0oc<9oook
JPCoo`002Ooo:005oomB0003oookJ_l0:_oo02[o00Cooo]Z00?o0=cooookJ_oonfX02_oonfX00olB
0?oooo]ZoookJP0@oookJP03ob3o0?lV0?oooo]Z00kooo]Z00Ko0?mKoookJ_oonf[ooo]Zool00?l0
<?l4oookJP05ool00?oonf[oT_l0oookJ_l@0?l01_oonfX01?oo057ooo]ZoookJ_oo07T7oookJP05
o`3oDooonf[ooo]Zo`3o2?ooN@000_oo:009oookJP03o`3o=?oonf[o0?m>00Cooo]Z00?o08Sooook
J_l0ZOl00ooonfX00ol01?oooo]Zo`3Do`0;oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oook
J_oonfX0E?oonfX01ol0:_oooo]ZoookJ_oonf[ooe80oookJ_nio`004?oonfX00ol0Looooo]Zoook
JP0BoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oonB0?oonfX00_oonfX00ooo0?cooo]Zoook
JP02oookJP05oaP0oooo1P3ooo]ZoookJ_o[o`000_oonfX00ol0Y_oooo]ZojP0o`02oookJP08ool0
nOl0Mooooo]ZoookJ_ooK03ooo]Zoon10?lko`03oookJP0:o`3koooonf[ooo]Zool30?oonf[oN@3o
ool0gOoonf[o0:?ook?o00?ooo]Z00Go0?oNoookJ_oonf[ooo]Zool0K002oookJP03odd0oomQ0?oo
0?m500?ooo]Z00Co0?n@oookJ_oonf[o0?nB1?oonfX01_mX0?oooo]ZoookJ_oonf[o603oonKo00;o
oo]Z00?ooi00oookJ_oonfX01OoonfX00ooo_P3ooo]Zog00o`04oookJP03oomG0?oonf[ooo]Z00;o
oo]Z00?oo`0]oookJ_oonfX02OoonfX01Ol0e?oooo]Zo`04oooonf[o08So00?ooo]Z00?o0?m>oook
J_oonfX00ooonfX00ol0oago0?l8oookJP04oookJP03ool0NOoonf[ooo]Z00;ooo]Z00?o403ooook
J_nBo`001OoonfX00ol0oe_ooo]ZoookJP07oookJP03obH0oooonf[o000000?o00001_oonfX2oa80
o`Sooo]Z0ol0g?l4oookJPGooe800_l0oc<EoookJP03o`3o<oooDP3ooe8000?ooe8000?ooo]Zo`0Z
ool0:_l01OoonfX00ol0g?oooo]ZoookJP09oookJP03oa80oooonf[ooo]Z017ooo]Z00?o9P3ooook
J_oonfX03OoonfX00ol0oe_ooo]ZoookJP02oookJP03o`3o/?oonf[ooo]Z00?ooo]Z00Go1P3ooi;o
0?oonf[ooo]Zoa00o`05oookJP05ool0DOoonf[ooo]ZoookJ_oo07T01_oonfX01ol0oe?ooo]Zoook
J_l0o`So0?lMoookJ_l0hOl02OoonfX01?l0ocCooo]ZoookJ_l0odh4oookJP03o`28oooonf[o0:Wo
00;ooo]Z00?o00CooookJ_l0e?l03?oonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z
02[ooo]Z000/oookJP07o`0Zoooonf[ooo]ZoookJ_l0oc?ooe80okWo000@oookJP03o`1coooonf[o
oo]Z01?ooo]Z00?oo`3ZoookJ_oonfX01OoonfX2oomi00?ooo]Z00?oo`3loookJ_oonfX00_oonfX4
oomi000:on_o0?oo0?Kooo]ZoookJ_l0Y_ooZ03ooookJ_oo0?Wooo]Zo`1go`;ooo]Z00Coof`0ool0
0?oo003o>ol00ooonfX01Ol0nooooo]ZoookJ_oo:03ooo]Z00SoiOl000?ooo]Zo`3og_oonfX00_oo
nfX01OooN@3ooo]Zodd0oooonf[oH@3o00?ooo]Z00?o0?n@oookJ_l0oi800ooonfX6oolX0005oook
J_lH0?ooi_l0oookJ_ooT0002?oonfX00ooo_P3oL03ooookJP03oookJP03oomG0?ooN@3oogT000Ko
ogT01ooonfX2onGo0008o`3DoooUo`3oiOl0onGo0?l0R?oooo]Zo`3oC_l0oc@5oookJP03o`3o7Ol0
o`Sooo]Z00?ooo]Z00?oo`1ioookJ_oonfX00ooonfX00ol@0?oooo]Zoi;o0002oookJPSoobP00ooo
nfX00ooo:03o9P3oobH0o`05oolX0004o`000?oonf[ooo]ZoookJP;o4P3o2?oonfX00ol0g?ooo`00
ool00005ool000;ooe800_oo000@oookJQ3oobP00_ooDP000ooonf[o02[oo`0Zo`03oookJP;o0=co
2ooonfX00olB0?oooo]ZoookJP0@oookJP03obH0oooonf[ooo]Z00kooo]Z00Go0?mKoookJ_oonf[o
o`00o`0`o`04oookJP06o`H0oooonf[ooo]Zoi;o0?oonf[o403o1OoonfX01?oo057ooo]ZoookJ_oo
07T7oookJP05o`3oDooonf[ooo]Zo`3o2?ooN@000_oo:009oookJP03o`3o=?oonf[o0?m>00Cooo]Z
00Co08SooookJ_oonf[o0:Wo0_oonfX00ol01?oooo]Zo`3Do`0<oookJP03oon10?oonf[ooo]Z00[o
oo]Z00?oo`0]oookJ_oonfX0D_oonfX00ol0:_oooo]ZoookJP02oookJP03oomB0?nio`3ooo]Z00oo
oo]Z00?o07?ooookJ_oonfX04ooonfX00ooo0>[ooo]ZoookJP06oookJP03oonB0?oonf[ooo]Z00;o
oo]Z00Koo`3loookJ_oonf[ooo]ZoaP0oooo1P02oookJP06on_o0?oo0?Kooo]ZoookJ_l0Y_ooZ03o
0_oonfX02Ooo0?Wo07OooookJ_oonf[oof`0o`3oV_ooP@3ooo]Zoc_o0003oookJP0:o`3koooonf[o
oo]Zool30?oonf[oN@3oool0gOl05ooo/ol0oil0o`?ooo]Z00[o0?oNoookJ_oonf[ooo]Zool0K?oo
nf[oC@3oool^0?mQ0?oo0?m50ooonfX00ol0oi3ooo]Zo`3oTP05oookJP06ofP0oooonf[ooo]Zoook
J_lH0?ooi_l00_oonfX00oooT03ooo]ZoookJP05oookJP03oonn0?m`0?oooo]Z00?ooo]Z00?ooeL0
oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP0:oookJP05o`3Dool01?oooo]ZoookJ_l0R?l00_oo
nfX00ol0odkooo]ZoookJP03oookJP03o`3o7Ol0o`Sooo]Z00Cooo]Z00?oo`1ioookJ_oonfX00_oo
nfX00ol@0?oooo]Zoi;o0005oookJP03o`3oFooonf[ooo]Z00Kooo]Z0_lV0?l2oookJPCo00001?oo
nfX2oa80o`Sooo]Z0_l0g?l5oookJP;ooe800_l0oc<OoookJP04o`3o<oooDP3ooe80oookJP?o02[o
0ooonfX2o`3Lo`[ooo]Z00?o4P3ooookJ_oonfX04?oonfX00olV0?oo8?l0oookJP0>oookJP05o`3o
Fooonf[ooo]ZoookJ_l0ok001OoonfX00ol60?oooo]Zoi;o0002oookJP03oa00oooonf[ooo]Z00?o
oo]Z00Coo`1AoookJ_oonf[oo`1i1_oonfX01ol0oe?ooo]ZoookJ_l0o`So0?lMoookJ_l0hOl02Ooo
nfX01?l0ocCooo]ZoookJ_l0odh4oookJP04o`28oooonf[ooo]Zo`2Yo`;ooo]Z00?o00Coo`3Doooo
nfX02ooonfX00oooP@3ooo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z02Wooo]Z000/oookJP07o`0Z
oooonf[ooo]ZoookJ_ooDP3ooo]ZokWo000@oookJP03o`1coooonf[ooo]Z01?ooo]Z00?oo`3Zoook
J_oonfX01?oonfX00oooN@3ooo]Zoomi0003oookJP04ool0o?oonf[ooo]ZoookJPGoogT000[ooo]Z
ool0m_oonf[ooo]Zo`2VoonX0?oooo]Zool0nOoonf[o07Oo0_oonfX00oooK03oo`00oc_o0003oook
JP04o`3koooonf[ooo]ZoolX00?ooo]Z00?oo`3MonGo0?oUo`001?oUo`002_l0omkooo]ZoookJ_oo
nf[oogT0oookJ_m=0?ooo`00of40ool0odD3oookJP03o`3oT?oonf[o0?nB00?ooo]Z1_oo:0001?lH
0?ooi_l0oookJ_ooT008oookJP03oonn0?l0o`GoL03o00?ooo]Z00?ooeL0oookJ_oonfX01oooN@06
oookJP;oiOl000Go0=CoonGo0?oUo`3oiOl0o`28o`02oookJP03o`3oC_l0ocCooo]Z00Cooo]Z00?o
0?lMoookJ_oonfX00_oonfX00ooo07Wooo]ZoookJP03oookJP03oa00oooonf[oT_l000Cooo]Z1_oo
:003oookJP04oolX0?lV0?oooo]ZoookJPGoobP000Co0000oookJ_oonf[o4P3o1ooonfX9ool000;o
oe800ooo000AoookJPSoobP02_oonfX00oooDP3ooo]ZoookJP02o`0Zo`?ooo]Z00?o0=cooookJ_oo
nfX02OoonfX2oa80oa3ooo]Z00?o8?l0obH0oooonfX03_oonfX01_l0oe_ooo]ZoookJ_oonf[oo`00
o`0`o`Cooo]Z00Go1P3ooookJ_nBo`3ooo]Zoa00o`05oookJP05ool0DOoonf[ooo]ZoookJ_oo07T0
1_oonfX01ol0oe?ooo]ZoookJ_l0o`SoogT0oookJ_oo:0002OoonfX00ol0ocCooo]Zo`3oCP05oook
JP03o`28oooonf[o0:Wo00;ooo]Z00?o00CooookJ_l0e?l03?oonfX00oooP@3ooo]ZoookJP0:oook
JP03ool0;Ooonf[ooo]Z05;ooo]Z00Oo02[ooookJ_oonf[ooo]ZoomB0?oonf[o^Ol0013ooo]Z00?o
07?ooookJ_oonfX04ooonfX00ooo0>[ooo]ZoookJP05oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00Ko
o`3loookJ_oonf[ooo]ZoaP0oooo1P02oookJP06on_o0?oo0?Kooo]ZoookJ_l0Y_ooZ03o0_oonfX0
2?oo0?Wo07OooookJ_oonf[oof`0oookJ_ooP@3o>ol00ooonfX01?l0nooooo]ZoookJ_oo0`02oook
JP04ool0gOoonf[o0:?ook?o00?ooo]Z00Go0?oNoookJ_oonf[ooo]Zool0K002oookJP04odd0oooo
nf[oH@3oo`3oA@;ooo]Z00Co0?n@oookJ_oonf[o0?nB1?oonfX01_mX0?oooo]ZoookJ_oonf[o603o
onKo00;ooo]Z00?ooi00oookJ_oonfX01OoonfX00ooo_P3ooo]Zog00o`04oookJP05oomG0?oonf[o
oo]ZoookJ_oo02d03?oonfX01Ol0e?oo00CooookJ_oonf[o08So00;ooo]Z00?o0?m>o`3o=?oonfX0
1?oonfX00ol0oagooo]ZoookJP03oookJP03ool0NOoonf[ooo]Z00;ooo]Z00?o403ooookJ_nBo`00
1OoonfX00ol0oe_ooo]ZoookJP06oookJP03obH0oooonf[ooo]Z00;ooo]Z1?l00003oookJP03oa80
oooonf[ooo]Z00Kooo]Z0_l0g?l5oookJP;ooe8000?o0?lcoookJ_oonfX08ooonfX01?ooDP3o0?lc
oookJ_oonfX2o`0Zo`?ooo]Z00?o0=cooookJ_oonfX02?oonfX2oa80oa7ooo]Z00?o9P3ooookJ_oo
nfX03OoonfX00ol0oe_ooo]ZoookJP02oookJP03o`3o/?oonf[ooo]Z00?ooo]Z00Go1P3ooi;o0?oo
nf[ooo]Zoa00o`05oookJP05ool0DOoonf[ooo]Zo`2]oooo07T01_oonfX01?l0oe?ooo]Zo`3o2?l0
oad2oookJP03o`3Qoooonf[ooo]Z00Oooo]Z00?o0?ldoookJ_l0odh01?oonfX01?l0R?oooo]Zoook
J_l0ZOl2oookJP03o`04ool0e?oooo]Z00cooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]Z
oookJP0YoookJP00;?oonfX01ol0:_oooo]ZoookJ_oonf[ooe80oookJ_nio`004?oonfX00ol0Looo
oo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Gooo]Z0_ooN@03oookJP04ool0o?oonf[ooo]Zoook
JPGoogT000[ojol0ool0m_oonf[ooo]Zo`2Voooonf[oZ03ooookJ_oo0?Wo07Oo0_oonfX01?ooK03o
o`00ool00?lko`03oookJP04o`3koooonf[ooo]Zool300;ooo]Z00GoN@3oool0gOoo:03oiOl0oook
JP03onGo0009o`3og_oonf[ooo]ZoookJ_ooN@3ooo]Zodd0oooonf[oH@3o00Cooo]Z00?o0?n@oook
J_l0oi800_oonfX7oolX0004oaP0ool0M?oooo]Zoon@00Sooo]Z00?ookh0og00oooonfX00ooonfX0
0oooE`3ooo]ZoookJP02oookJPGoogT01OoonfX3onGo0004o`3DoooUo`3oiOl0onGo00;ooo]Z00?o
0?m>o`3o=?oonfX01?oonfX00ol0oago0?l8oookJP02oookJP03ool0NOoonf[ooo]Z00?ooo]Z00?o
403ooookJ_nBo`001?oonfX00ooo:03ooo]ZoolX0004oolX00;ooo]Z00?oobP0obH0oooonfX00ooo
nfX3oolX00;o000000?ooo]Zoa80oooonfX01ooonfX6ool000?ooe800ooo000VoookJP;ooe800_oo
nfX2o`0Zo`;ooo]Z0_l0g?l;oookJP03oa80oooonf[ooo]Z00kooo]Z00?o9P3ooookJ_oonfX03_oo
nfX01Ol0oe_ooo]ZoookJ_oo003o033o00Cooo]Z00Ko1P3ooookJ_oonf[oT_l0oookJ_l@0?l5oook
JP04ool0DOoonf[ooo]Zool0N@Oooo]Z00Ko0?mCoookJ_oonf[o0?l8oomi0?l0hOl9oookJP04o`3o
=?oonf[o0?l^o`3oCPCooo]Z00?o08SooookJ_l0ZOl00ooonfX00ol01?oooo]Zo`3Do`0;oookJP03
oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX0D_oonfX01ol0:_oooo]ZoookJ_oonf[ooe80
oookJ_nio`004?oonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooi80
oookJ_oonfX00_oonfX00ooo0?cooo]ZoookJP02oookJP05oaP0oooo1P3ooo]ZoookJ_o[o`000_oo
nfX00ol0Y_oooo]ZojP0o`02oookJP08o`1goooonf[ooo]ZoookJ_ooK03ooh40oookJ_lko`03oook
JP0:o`3koooonf[ooo]Zool30?oonf[oN@3oool0gOl05ooo0:?ook?o00?ooo]Z00[o0?oNoookJ_oo
nf[ooo]Zool0K?oonf[oC@3oool^0?mQ0?oo0?m50ooonfX00ol0oi3ooo]Zo`3oTP05oookJP06ofP0
oooonf[ooo]ZoookJ_lH0?oo07Co0_oonfX00oooT03ooo]ZoookJP05oookJP03oonn0?m`0?oooo]Z
00?ooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP0:oookJP08o`3Dool01?oooo]Z
oookJ_l0R?oooo]Zo`3oC_l0oc@5oookJP03o`3o7Ol0o`Sooo]Z00?ooo]Z00?oo`1ioookJ_oonfX0
0_oonfX00ol@0?oooo]Zoi;o0005oookJP03o`3oFooonf[ooo]Z00Kooo]Z00?o9P3ooookJ_oonfX0
0ooonfX4o`0000;ooo]Z00?o4P3ooookJ_oonfX01_oonfX00ol0g?oooo]ZoookJP02oookJP?ooe80
00?o0?lcoookJ_oonfX09_oonfX2oomB00?ooo]Z0_l0:_l2oookJP;o0=co2_oonfX00olB0?oooo]Z
oookJP0>oookJP03obH0oolPo`3ooo]Z00kooo]Z00Go0?mKoookJ_oonf[ooo]Zo`3o/005oookJP03
o`H0oooonf[oT_l000;ooo]Z00?o403ooookJ_oonfX00_oonfX01Ooo057ooo]ZoookJ_l0[Oooo`1i
00Kooo]Z00Oo0?mCoookJ_oonf[o0?l8o`3o7Ooonf[o0>7o00Wooo]Z00Co0?ldoookJ_l0obko0?m>
1?oonfX00ol0R?oooo]Zo`2Yo`02oookJP03o`04oooonf[o0=Co00cooo]Z00?ooh40oookJ_oonfX0
2_oonfX00ooo02gooo]ZoookJP0YoookJP00;?oonfX01ol0:_oooo]ZoookJ_oonf[ooe80oookJ_ni
o`003ooonfX00ol0Looooo]ZoookJP0CoookJP03ool0j_oonf[ooo]Z00Gooo]Z0_ooN@03oookJP04
ool0o?oonf[ooo]ZoookJPGoogT000[ooo]Zool0m_oonf[ooo]Zo`2VoonX0?oooo]Zool0nOoonf[o
07Oo0_oonfX00oooK03oo`00oc_o0004oookJP04o`3koooonf[ooo]Zool300;ooo]Z00?oN@3oool0
gOoUo`001?oonfX01OoUo`3o0?oNoookJ_oonf[oogT000;ooo]Z00?oC@3oof40ool0odD00ooonfX0
0ol0oi3ooo]Zo`3oTP02oookJPOoobP000Go603oonKo0?oonf[ooo]Zoon@0007oookJP03oonn0?l0
o`GoL03o00?ooo]Z00?ooeL0oookJ_oonfX00_oonfX00oooN@3ooo]Zoomi0002oomi00Gooo]Z0ooU
o`000ol0e?ooiOl0onGo0002onGo0003oookJ_l0odko0?ld00Gooo]Z00?o0?lMo`3o2?oonfX00ooo
nfX00ooo07Wooo]ZoookJP02oookJP03oa00oooonf[oT_l000Cooo]Z00CoobP0oookJ_oonf[ooo]Z
0ooo:002oookJP03oolX0?lV0?oooo]Z00Gooo]Z00GoobP0o`000?l0003o0000oa80o`07oookJP;o
0=co00Cooo]Zool00?oo003oo`000_ooDP05ool002Wooo]Z0_ooDP02oookJP;o02[o0_oonfX2o`3L
o`[ooo]Z00?o4P3ooookJ_oonfX03_oonfX00olV0?oooo]ZoookJP0=oookJP06o`3oFooonf[ooo]Z
ool00?oonf[o033o0ooonfX01_l60?oooo]ZoookJ_oonf[oT_l0oa00o`Gooo]Z00Goo`1AoookJ_oo
nf[oo`00ool0N@06oookJP06o`3oDooonf[ooo]Zo`3o2?ooN@3o0>7o2_oonfX00ol0ocCooo]Zo`3o
CP04oookJP03o`28oooonf[o0:Wo00?ooo]Z00?o00CooookJ_l0e?l02ooonfX00oooP@3ooo]Zoook
JP0:oookJP03ool0;Ooonf[ooo]Z05;ooo]Z00Oo02[ooookJ_oonf[ooo]ZoomB0?oonf[o^Ol000oo
oo]Z00?o07?ooookJ_oonfX04ooonfX00ooo0>[ooo]ZoookJP06oookJP03oonB0?oonf[ooo]Z00;o
oo]Z00Koo`3loookJ_oonf[ooo]ZoaP0oooo1P02oookJP0:on_o0?oo0?Kooo]ZoookJ_l0Y_oooo]Z
ojP0oooonf[oo`3io`1go`;ooo]Z00Coof`0oookJ_ooP@3o>ol01?oonfX02Ol0nooooo]ZoookJ_oo
0`3ooo]ZogT0oooo0=go0:?ook?o0004oookJP04o`3og_oonf[ooo]Zool0K0;ooo]Z00CoC@3ooook
J_mQ0?oo0?m50ooonfX00ol0oi3ooo]Zo`3oTP05oookJP05ofP0oooonf[ooo]ZoaP0oooVo`000_oo
nfX00oooT03ooo]ZoookJP05oookJP03oonn0?oonf[oL03o00?ooo]Z00?ooeL0oookJ_oonfX00_oo
nfX00ooo02gooo]ZoookJP0:oookJP05o`3Dool01?oooo]ZoookJ_l0R?l00_oonfX00ol0odkooo]Z
oookJP04oookJP03o`3o7Ooonf[ooo]Z00?ooo]Z00Ooo`1ioookJ_oonf[ooo]Zoa00oooonf[oT_l0
00Gooo]Z00?o0?mKoookJ_oonfX01_oonfX00olV0?oooo]ZoookJP04oookJPCo000000?ooo]Zoa80
oooonfX01_oonfX2o`3Lo`?ooo]Z0_ooDP000ol0oc?ooo]ZoookJP0[oookJP;ooe800ooonfX2o`0Z
o`;ooo]Z00?o0=cooookJ_oonfX02?oonfX00olB0?oooo]ZoookJP0>oookJP03obH0oolPo`3ooo]Z
00gooo]Z00Ko0?mKoookJ_oonf[ooo]Zo`3o/?l0<?l4oookJP06o`H0oooonf[ooo]Zoi;o0?oonf[o
403o1OoonfX01Ooo057ooo]Zo`2]oooonf[oo`1i00Gooo]Z00Oo0?mCoookJ_oonf[o0?l8o`3o7Ooo
nf[o0>7o00Wooo]Z00Co0?ldoookJ_l0obko0?m>1?oonfX00ol0R?oooo]Zo`2Yo`03oookJP03o`04
ool0e?oooo]Z00_ooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP0YoookJP00:ooo
nfX01ol0:_oooo]ZoookJ_oonf[ooe80oookJ_nio`004?oonfX00ol0Looooo]ZoookJP0CoookJP03
ool0j_oonf[ooo]Z00Cooo]Z00?oogT0oookJ_ooN@000ooonfX00ooo0?cooo]ZoookJP06oomi000:
odCo0?oonf[ooo]ZoookJ_l0Y_ooZ03ooookJ_oo0?Wooo]Zo`1go`;ooo]Z00?oof`0ool00?lko`00
0ooonfX01?l0nooooo]ZoookJ_oo0`02oookJP04ogT0oooo0=goobP0onGo00Cooo]Z00[o0?oNoook
J_oonf[ooo]Zoomi0?oonf[oC@3ooookJ_mQ0?oo0?m50ooonfX01?l0oi3ooo]Zo`3oT_oonfX8oolX
0004oaP0ool0M?oooo]Zoon@00Sooo]Z00?ookh0og00oooonfX00ooonfX00oooE`3ooo]ZoookJP02
oookJP05oomi0?oonf[ooo]ZoookJ_ooN@001?oonfX3onGo0003o`3DoooUo`3oiOl000;oiOl00_oo
nfX00ol0odko0?ldoookJP04oookJP03o`3o7Ooonf[ooo]Z00;ooo]Z00?oo`1ioookJ_oonfX00_oo
nfX00ol@0?oooo]Zoi;o0004oookJP03oolX0?oonf[ooo]Z00?ooo]Z00KoobP0oookJ_oonf[ooo]Z
ob3o0?lV0?l6oookJP;o00000_lB0?l6oookJP;o0=co0ooonfX00ooo003ooe80oomB0005ool002go
oo]Z0_ooDP02oookJP04oolX0?oonf[ooo]ZoookJP;oobP02OoonfX00olB0?oooo]ZoookJP0=oook
JP03obH0oooonf[ooo]Z00kooo]Z00Go0?mKoookJ_oonf[oo`00o`0`o`04oookJP06o`H0oooonf[o
oo]Zoi;o0?oonf[o403o1?oonfX01Ooo057ooo]ZoookJ_oonf[oo`1i00Kooo]Z00Oo0?mCoookJ_oo
nf[ooo]Zoomi0?oonf[o0>7o00Wooo]Z00?o0?ldoookJ_l0odh01OoonfX00ol0R?oo0:WooookJP02
oookJP03o`04oooonf[o0=Co00cooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP1A
oookJP07o`0Zoooonf[ooo]ZoookJ_ooDP3o0?lcokWo000@oookJP03o`1coooonf[ooo]Z01?ooo]Z
00?oo`3ZoookJ_oonfX01OoonfX00ooo5P3ooi80oookJP03oookJP06ool0o?oonf[ooo]ZoookJ_lH
0?ooo`H00_oonfX01_o[o`3ooo]ZoookJ_oonf[o0:KoojP0o`;ooo]Z00Soo`3io`1goooonf[ooo]Z
oom/0?oonf[ooh40oc_o00?ooo]Z00[o0?_ooookJ_oonf[oo`<0oookJ_mi0?ooo`3MoookJ_l0Xooo
/ol00ooonfX02ol0omkooo]ZoookJ_oonf[oo`1/oookJ_m=0?ooobh0of40oooonf[o0?m500;ooo]Z
00Co0?n@oookJ_oonf[o0?nB1?oonfX01_mX0?oooo]ZoookJ_oonf[o603oo`1do`;ooo]Z00?ooi00
oookJ_oonfX01OoonfX00ooo_P3oL03ooookJP03oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]
oookJ_oonfX02OoonfX01Ol0e?oooo]Zo`04oooonf[o08So00;ooo]Z00?o0?m>o`3o=?oonfX01?oo
nfX00ol0oagooo]ZoookJP03oookJP07ool0NOoonf[ooo]ZoookJ_l@0?oooo]Zoi;o0005oookJP03
o`3oFooonf[ooo]Z00Oooo]Z00?o9P3ooookJ_oonfX01?oonfX3o`0000;o4P3o1_oonfX2o`3Lo`?o
oo]Z0_ooDP000ol0oc?ooo]ZoookJP0_oookJP;ooe800ooonfX01?l0:_oooo]ZoookJ_l0g?l:oook
JP03oa80oooonf[ooo]Z00kooo]Z00?o9P3ooookJ_oonfX03OoonfX01Ol0oe_ooo]ZoookJ_oonf[o
0?n`00Gooo]Z00?o1P3ooookJ_nBo`000_oonfX00ol@0?oooo]ZoookJP02oookJP05ool0DOoonf[o
oo]Zo`2]oooo07T01_oonfX01?l0oe?ooo]ZoookJ_l0oad2oookJP03o`3Qoooonf[ooo]Z00Kooo]Z
00Co0?ldoookJ_oonf[o0?m>1?oonfX00ol0R?oooo]Zo`2Yo`03oookJP03o`04ool0e?oooo]Z00co
oo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP0YoookJP00:ooonfX01ol0:_oooo]Z
oookJ_oonf[ooe80oookJ_nio`004?oonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z
00Gooo]Z0_ooN@03oookJP04ool0o?oonf[ooo]ZoookJPKoogT000WoA?l0oookJ_oonf[o0:Kooook
J_nX0?ooo`3ioookJ_l0Mol00_oonfX01?ooK03oo`00ool00?lko`03oookJP04o`3koooonf[ooo]Z
ool300;ooo]Z00CoN@3oool0gOnO0?ooiOl01?oonfX02Ol0omkooo]ZoookJ_oonf[oogT0oookJ_m=
0?oooo]Zof40o`04oookJP03o`3oT?l0oi;ooo]Z00?ooo]Z1Ooo:0001OlH0?ooolT0oookJ_oonf[o
oi0000Oooo]Z00?ookh0o`3o1Om`0?l00ooonfX00oooE`3ooo]ZoookJP02oookJP03oomi0?oonf[o
oo]Z00Wooo]Z00?oiOl0o`3DoooUo`000ooUo`000ooonf[o0?m>o`3o=005oookJP03o`3o7Ooonf[o
oo]Z00;ooo]Z00?oo`1ioookJ_oonfX00_oonfX01?l@0?oooo]ZoookJ_nBo`03oookJP03oolX0?oo
nf[ooo]Z00Oooo]Z00?o8?l0obH0oooonfX01_oonfX01?l0003o4P3oo`000?l00005oookJP03o`3L
oooonf[ooo]Z00;ooo]Z0_ooDP06ool002oooo]Z00Co0?lcoomB0?oonf[oobP00_oonfX3oolX0003
o`3Loooonf[ooo]Z00Oooo]Z00?o4P3ooookJ_oonfX03OoonfX00olV0?oooo]ZoookJP0=oookJP06
o`3oFooonf[ooo]Zool00?oonf[o033o0ooonfX01?l60?oooo]ZoookJ_nBo`02oookJP03oa00oooo
nf[ooo]Z00;ooo]Z00Goo`1AoookJ_oonf[oo`00ool0N@06oookJP06o`3oDooonf[ooo]Zoomi0?oo
nf[o0>7o2OoonfX00ol0ocCooo]Zo`3oCP05oookJP03o`28oooonf[o0:Wo00?ooo]Z00?o00Coo`3D
oooonfX02ooonfX00oooP@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z057ooo]Z00Oo02[ooook
J_oonf[ooo]ZoomB0?oonf[o^Ol0013ooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]Zoook
JP06oookJP03oonB0?oonf[ooo]Z00;ooo]Z00[oo`3loookJ_oonf[ooo]ZoaP0oooonf[oo`H0oook
J_o[o`3oo`3f0_oonfX01_l0Y_oooo]ZojP0oooonf[oo`3io`1go`?ooo]Z00Coof`0oon10?oonf[o
>ol00ooonfX02_l0nooooo]ZoookJ_oo0`3ooo]ZogT0oooo0=go01Ooo`2Soonco`03oookJP0:o`3o
g_oonf[ooo]ZoookJ_oo06cooo]Zodd0oooonf[oH@3oo`3oA@?ooo]Z00?o0?n@oookJ_l0oi801Ooo
nfX01OmX0?oooo]ZoookJ_lH0?ooi_l000;ooo]Z00?ooi00oookJ_oonfX01OoonfX00ooo_P3ooo]Z
og00o`03oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX02_oonfX02?l0e?oo00Co
oookJ_oonf[o08SooookJ_l0odko0?ld1OoonfX00ol0oagooo]ZoookJP03oookJP05ool0NOoonf[o
oo]ZoookJ_l@0?l00_oonfX00onBo`3ooo]ZoookJP02oookJP03o`3oFooonf[ooo]Z00Oooo]Z00?o
9P3ooookJ_oonfX01OoonfX2o`000003oa80ool0003ooo]Z00Gooo]Z00Co0=cooookJ_oonf[ooo]Z
0_ooDP0foookJP04oomB0?l0oc?ooo]Zo`0Zo`?ooo]Z0_l0g?l9oookJP03oa80oooonf[ooo]Z00go
oo]Z00?o9P3oob3o0?oonfX03OoonfX01_l0oe_ooo]ZoookJ_oonf[o0?n`o`0`o`Cooo]Z00?o1P3o
oookJ_nBo`000ooonfX01Ol@0?oooo]ZoookJ_oonf[oo`1A00;ooo]Z00?o0:gooookJ_oo07T01Ooo
nfX01ol0oe?ooo]ZoookJ_l0o`So0?lMoookJ_l0hOl02OoonfX00ol0ocCooo]Zo`3oCP05oookJP03
o`28oooonf[o0:Wo00;ooo]Z00?o00Coo`3DoooonfX03?oonfX00oooP@3ooo]ZoookJP09oookJP03
ool0;Ooonf[ooo]Z02Wooo]Z000[oookJP07o`0Zoooonf[ooo]ZoookJ_ooDP3ooo]ZokWo000@oook
JP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01?oonfX00oooN@3ooo]Zoomi0003oook
JP03ool0o?oonf[ooo]Z00OoogT000WoA?l0oookJ_oonf[o0:KoojP0oooonf[oo`3ioookJ_l0Mol0
0_oonfX00oooK03oo`00oc_o0003oookJP0:o`3koooonf[ooo]ZoookJ_oo0`3ooo]ZogT0oooo0=go
obP0onGo00Gooo]Z00Wo0?oNoookJ_oonf[oogT0oookJ_m=0?oooo]Zof40ool0odD00ooonfX00ol0
oi3ooo]Zo`3oTP05oookJP08oolX0?oonf[oobP0oolX0?lH0?ooolT0oookJ_ooT008oookJP03oonn
0?m`0?oooo]Z00;ooo]Z00?ooeL0oookJ_oonfX00ooonfX00oooN@3ooo]ZoookJP09oookJP03o`3D
oooUo`3oiOl000?oiOl000?o0?m>o`3o=?oonfX01?oonfX00ol0oagooo]ZoookJP03oookJP03ool0
NOoonf[ooo]Z00;ooo]Z00?o403ooookJ_nBo`000ooonfX00ooo:03ooo]ZoookJP04oookJP?o001o
00?o8?l0obH0oooonfX01ooonfX01?lB0?oo0000o`000?l00003oookJP;o0=co0ooonfX2oomB00;o
oo]Z1Ooo000boookJP;ooe801_oo:0000ol0g?oooo]ZoookJP07oookJP03oa80oooonf[ooo]Z00co
oo]Z00?o9P3ooookJ_oonfX03_oonfX01Ol0oe_ooo]ZoookJ_oo003o033o00?ooo]Z00Oo1P3ooook
J_oonf[ooo]Zoi;o0?oonf[o403o00Cooo]Z00Goo`1AoookJ_oonf[oo`00ool0N@06oookJP06o`3o
Dooonf[ooo]ZoookJ_ooN@3o0>7o2OoonfX00ol0ocCooo]Zo`3oCP05oookJP03o`28oooonf[o0:Wo
00?ooo]Z00?o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z
053ooo]Z00Oo02[ooookJ_oonf[ooo]ZoomB0?oonf[o^Ol0013ooo]Z00?o07?ooookJ_oonfX04_oo
nfX00ooo0>[ooo]ZoookJP05oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00[oo`3loookJ_oonf[ooo]Z
oaP0oooonf[oo`H0oookJ_o[o`3oo`3f0_oonfX01_l0Y_oooo]ZojP0oooonf[oo`3io`1go`;ooo]Z
00Coof`0oookJ_ooP@3o>ol00ooonfX02_l0nooooo]ZoookJ_oonf[oo`<0ogT0oooo0=gooo]Zo`2S
oonco`04oookJP0:o`3og_oonf[ooo]Zool0K?oonf[oC@3oool^0?oonf[oH@3oo`3oA@;ooo]Z00Co
0?n@oookJ_oonf[o0?nB1?oonfX01_mX0?oooo]ZoookJ_oonf[o603oo`1do`;ooo]Z00?ooi00oook
J_oonfX01OoonfX00ooo_P3oL03ooookJP02oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oook
J_oonfX02OoonfX01Ol0e?oo00CooookJ_oonf[o08So00;ooo]Z00?o0?m>oookJ_oonfX00ooonfX0
0ol0o`So0?lMoookJP03oookJP03ool0NOoonf[ooo]Z00;ooo]Z00?o403ooookJ_nBo`001?oonfX0
0ol0oe_ooo]ZoookJP03oookJPCo001o00?o9P3ooookJ_oonfX01_oonfX01?l0003o4P3oo`000?l0
0004oookJP;o0=co0_oonfX2oomB03Wooo]Z0_ooDP000ooonf[o02[ooookJP03oookJP03o`3Loooo
nf[ooo]Z00Oooo]Z00?o4P3ooookJ_oonfX03OoonfX00olV0?oooo]ZoookJP0=oookJP05o`3oFooo
nf[ooo]Zo`3o/?l0<?l01?oonfX01?l60?oooo]ZoookJ_nBo`02oookJP03oa00oooonf[ooo]Z00;o
oo]Z00Goo`1AoookJ_l0[Ooooo]Zool0N@05oookJP07o`3oDooonf[ooo]ZoookJ_l0oagooo]Zo`3Q
o`09oookJP03o`3o=?oonf[o0?m>00Gooo]Z00?o08SooookJ_l0ZOl00ooonfX00ol01?oo0=Cooook
JP0;oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX0:?oonfX002_ooo]Z00Oo02[o
oookJ_oonf[o0?lcoomB0?oonf[o^Ol000oooo]Z00?o07?ooookJ_oonfX04ooonfX00ooo0>[ooo]Z
oookJP04oookJP03oomi0?oonf[oogT000?ooo]Z00?oo`3loookJ_ooN@001oooN@002Om4o`3ooo]Z
o`2Voooonf[oZ03ooookJ_oo0?Wooo]Zo`1go`02oookJP;oo`0000Go>ol0oookJ_oonf[ooo]Zo`3k
o`02oookJP07ool30?oonf[ooo]ZogT0oooo0=goW`3oonGo0004oookJP0:o`3og_oonf[ooo]Zoook
J_ooN@3ooo]Zodd0oooonf[oH@3oo`3oA@?ooo]Z00?o0?n@oookJ_l0oi801OoonfX02?oo:03ooo]Z
oookJ_oob@3o603oooo90?oonf[ooi001ooonfX00ooo_P3o0?l5og00o`03oookJP03oomG0?oonf[o
oo]Z00;ooo]Z00?oogT0oookJ_oonfX02OoonfX02Ol0e?ooiOl0oookJ_oonf[o08SoonGo0?oonf[o
0?m>o`3o=005oookJP03o`3o7Ooonf[ooo]Z00;ooo]Z00?oo`1ioookJ_oonfX00_oonfX00ol@0?oo
oo]Zoi;o0003oookJP03oolX0?oonf[ooo]Z00Cooo]Z0ol007l01?lPo`3o9P3oo`00Ool007l6oook
JP03oa80ool0003o000000;o000000?ooo]Zo`3Lool0g?l01?oonfX00oooDP3ooo]ZoookJP02oook
JP?oo`00=_oonfX00oooDP3oobP0oolX0003oolX0003oookJ_l0g?oooo]Z00Sooo]Z00?o4P3ooook
J_oonfX03?oonfX00olV0?oooo]ZoookJP0=oookJP06o`3oFooonf[ooo]Zool00?oonf[o033o0ooo
nfX01?l60?oooo]ZoookJ_nBo`02oookJP05oa00oooonf[ooo]ZoookJ_oo05400_oonfX00ooo003o
oo]Zool0N@05oookJP06o`3oDooonf[ooo]ZoookJ_ooN@3o0>7o2_oonfX00ol0ocCooo]Zo`3oCP04
oookJP03o`28oooonf[o0:Wo00?ooo]Z00?o00CooookJ_l0e?l03?oonfX00oooP@3ooo]ZoookJP09
oookJP03ool0;Ooonf[ooo]Z053ooo]Z00Oo02[ooookJ_oonf[ooo]ZoomB0?oonf[o^Ol000oooo]Z
00?o07?ooookJ_oonfX04ooonfX00ooo0>[ooo]ZoookJP05oookJP03oolF0?ooTP3ooo]Z00?ooo]Z
00Koo`3loookJ_oonf[ooo]ZoaP0oooo1P02oookJP06on_o0?oonf[ooo]Zo`2Voooonf[oZ03o0_oo
nfX02?oo0?Wo07OooookJ_oonf[oof`0oon10?l0olco>ol00ooonfX02_l0nooooo]ZoookJ_oo0`3o
oo]ZogT0oooo0=go01Ooo`2Soonco`03oookJP0:o`3og_oonf[ooo]ZoookJ_oo06cooo]Zodd0oooo
nf[oH@3oo`3oA@?ooo]Z00?o0?n@oookJ_l0oi801OoonfX01OmX0?oooo]ZoookJ_oonf[o603o00;o
oo]Z00?ooi00oookJ_oonfX01OoonfX00ooo_P3ooo]Zog00o`03oookJP03oomG0?oonf[ooo]Z00;o
oo]Z00?oo`0]oookJ_oonfX02OoonfX01Ol0e?oooo]Zo`04oooonf[o08So00;ooo]Z00?o0?m>o`3o
=?oonfX01?oonfX00ol0oagooo]ZoookJP03oookJP07ool0NOoonf[ooo]ZoookJ_l@0?oooo]Zoi;o
0004oookJP03o`3oFooonf[ooo]Z00?ooo]Z1?l007l00olV0?oo001oo`00O`07oookJP04oa80ool0
003o0000o`0000;ooo]Z0_l0g?l3oookJP03oomB0?oonf[ooo]Z03_ooo]Z00?ooe80o`3o<ol0:_l0
1?oonfX00ol0g?oooo]ZoookJP07oookJP03oa80oooonf[ooo]Z00cooo]Z00?o9P3oob3o0?oonfX0
3OoonfX01_l0oe_ooo]ZoookJ_oonf[o0?n`o`0`o`Cooo]Z00?o1P3ooookJ_nBo`000ooonfX01ol@
0?oooo]ZoookJ_oonf[oo`1AoookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP03oookJP06o`3oDooo
nf[ooo]Zo`3o7Ooonf[o0>7o2OoonfX01?l0ocCooo]Zo`3o;_l0odh4oookJP03o`28oooonf[o0:Wo
00?ooo]Z00?o00Coo`3DoooonfX03?oonfX00oooP@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z
02Sooo]Z000ZoookJP07o`0Zoooonf[ooo]ZoookJ_ooDP3ooo]ZokWo000@oookJP03o`1coooonf[o
oo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01OoonfX2oomi00?ooo]Z00?oo`3loookJ_oonfX00_oonfX0
0olH0?ooogT0oomi0003oomi0008odCo0?oonf[o0:KooookJ_nX0?ooo`3ioookJ_l0Mol2oookJP04
oom/0?l0oi[oo`00oc_o00?ooo]Z00Wo0?_ooookJ_oonf[oo`<0oookJ_mi0?oooo]Zool0gOoUo`00
1OoonfX02Ol0omkooo]ZoookJ_ooN@3ooo]Zodd0oooo003oH@3oo`3oA@03oookJP03o`3oT?oonf[o
0?nB00Gooo]Z00GoobP0oookJ_oonf[ooo]ZoaP0o`02ooo90003oon@0?oonf[ooo]Z00Gooo]Z00?o
okh0oookJ_m`0?l00ooonfX00oooE`3ooo]ZoookJP03oookJP03oomi0?oonf[ooo]Z00Wooo]Z00Co
0=CoonGo0?oonf[o08So0_oonfX00ol0odko0?ldoookJP04oookJP03o`3o7Ooonf[ooo]Z00;ooo]Z
00?oo`1ioookJ_oonfX00_oonfX00ol@0?oooo]Zoi;o0004oookJP03o`3oFooonf[ooo]Z00?ooo]Z
0ol007l00olPo`3o9P3oo`00O`02o`00O`Cooo]Z0_lB0?l00ooonf[o0000o`000002o`000003o`3L
oooonf[ooo]Z00;ooo]Z0_ooDP06oookJP03ool00?oonf[ooo]Z03Cooo]Z00?oobP0oomB0?oo:000
1Ooo:0000ol0g?oooo]ZoookJP07oookJP03oa80oooonf[ooo]Z00cooo]Z00?o9P3ooookJ_oonfX0
3OoonfX01?l0oe_ooo]ZoookJ_oo0002oookJP04o`0`oooonf[ooo]Zo`H0o`;ooo]Z00CoT_l0oook
J_oonf[o403o1?oonfX01Ooo057ooo]ZoookJ_oo003oo`1i00Kooo]Z00Ko0?mCoookJ_oonf[oogT0
oookJ_l0hOl9oookJP03o`3o=?oonf[o0?m>00Gooo]Z00?o08Soo`2YoooonfX00ooonfX00ol01?oo
0=CooookJP0;oookJP03oon10?oonf[ooo]Z00Wooo]Z00?oo`0]oookJ_oonfX0CooonfX01ol0:_oo
oo]ZoookJ_oonf[ooe80oookJ_nio`004?oonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[o
oo]Z00Kooo]Z00?ooi80oookJ_oonfX00_oonfX02_oo0?cooo]ZoookJ_oonf[o603ooookJ_oo1P3o
oo]Zon_o0?oo0?H2oookJP06o`2Voooonf[oZ03ooookJ_oo0?Wo07Oo0ooonfX01?ooK03o0?o<oook
J_lko`03oookJP09o`3koooonf[ooo]Zool30?mi0?oooo]Zool0gOl0Xooo/ol000Cooo]Z00[o0?oN
oookJ_oonf[oo`1/oookJ_m=0?ooobh0oookJ_mQ0?oo0?m50ooonfX00ol0oi3ooo]Zo`3oTP04oook
JP06ofP0oooonf[ooo]ZoookJ_lH0?ooi_l00_oonfX00oooT03ooo]ZoookJP04oookJP03oonn0?oo
nf[oL03o00?ooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP09oookJP08o`3Dool0
1?oooo]ZoookJ_l0R?oooo]Zo`3oC_l0oc@5oookJP03o`3o7Ooonf[ooo]Z00?ooo]Z00Ooo`1ioook
J_oonf[ooo]Zoa00oooonf[oT_l000Gooo]Z00?o0?mKoookJ_oonfX00_oonfX4o`00O`04obH0ool0
07oo001oo`00O`Gooo]Z0_lB0?l4o`000003oookJ_l0g?oooo]Z00;ooo]Z0_ooDP0noookJP04oomB
0?oonf[o0?lco`0Zo`?ooo]Z00?o0=cooookJ_oonfX01ooonfX00olB0?oooo]ZoookJP0=oookJP03
obH0oooonf[ooo]Z00cooo]Z00Oo0?mKoookJ_oonf[ooo]Zo`3o/?oonf[o033o00?ooo]Z00?o1P3o
oookJ_nBo`000ooonfX01Ol@0?oooo]ZoookJ_oonf[oo`1A00;ooo]Z00?o0:gooookJ_oo07T01Ooo
nfX01_l0oe?ooo]ZoookJ_l0oagooo]Zo`3Qo`[ooo]Z00?o0?ldo`3o;_l0odh01OoonfX00ol0R?oo
0:WooookJP02oookJP03o`04ool0e?oooo]Z00cooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02go
oo]ZoookJP0XoookJP00:_oonfX01ol0:_oooo]ZoookJ_oonf[ooe80oookJ_nio`004?oonfX00ol0
Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Cooo]Z00?oogT0oookJ_ooN@000ooonfX00ooo
0?cooo]ZoookJP02oookJP04oaP0oooonf[oogT0on_o00;oogT000SoA?l0oookJ_l0Y_ooZ03ooook
J_oo0?Wooo]Zo`1go`;ooo]Z00?oof`0ool00?lko`000ooonfX02_l0nooooo]ZoookJ_oonf[oo`<0
oookJ_mi0?ooo`3MoolX0?oUo`05oookJP09o`3og_oonf[ooo]Zoomi0?oonf[oC@3ooookJ_mQ0?oo
0?m500?ooo]Z00?o0?n@oookJ_l0oi801OoonfX02?oo:03ooo]ZoookJ_oob@3o603oooo90?oonf[o
oi001ooonfX00ooo_P3o0?l5og00o`03oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oogT0oookJ_oo
nfX02OoonfX01?l0e?ooiOl0oookJ_l0R?l2oookJP03o`3oC_l0ocCooo]Z00Cooo]Z00?o0?lMoook
J_oonfX00_oonfX00ooo07Wooo]ZoookJP03oookJP03oa00oonBo`3o001o00?o001o00?o0?mKo`00
Ool007l00_l007l2oookJP;o001o00Co8?l0obH0oooonf[ooo]Z0ol007l2oookJP04oa80oooonf[o
oo]ZoookJP;o00000_l0g?l4oookJP03oomB0?oonf[ooo]Z03cooo]Z0ooo:0000oooDP3oobP0oolX
0003oolX0003oookJ_l0g?oooo]Z00Sooo]Z00?o4P3ooookJ_oonfX03?oonfX00olV0?oooo]Zoook
JP0=oookJP06o`3oFooonf[ooo]Zool00?oonf[o033o0ooonfX01_l60?oooo]ZoookJ_nBo`3ooo]Z
oa00o`Cooo]Z00Goo`1AoookJ_oonf[oo`00ool0N@06oookJP06o`3oDooonf[ooo]Zoomi0?l0o`So
0>7o2OoonfX00ol0ocCooo]Zo`3oCP05oookJP03o`28ool0ZOoooo]Z00?ooo]Z00?o00CooookJ_l0
e?l02ooonfX00oooP@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z04oooo]Z00Oo02[ooookJ_oo
nf[ooo]ZoomB0?oonf[o^Ol0013ooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP05
oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00[oo`3loookJ_oonf[ooo]ZoaP0oooonf[oo`H0oookJ_o[
o`3oo`3f0_oonfX01_l0Y_oooo]ZojP0oooonf[oo`3io`1go`;ooo]Z00Coof`0oookJ_l0olco>ol0
0ooonfX02_l0nooooo]ZoookJ_oonf[oo`<0ogT0oooo0=go01Ooo`2Soonco`04oookJP06o`3og_oo
nf[ooo]Zool0K?oonf[oC@3o0_oonfX01OmQ0?oo0?m5oookJ_oonf[o0?n@00;ooo]Z00?o0?nBoook
J_oonfX00_oonfX02?mX0?oooo]ZoookJ_oonf[o603oo`1doooonf[ooi001ooonfX00ooo_P3ooo]Z
og00o`03oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX02OoonfX02?l0e?oo00Co
oookJ_oonf[o08SooookJ_l0odko0?ld1OoonfX00ol0o`So0?lMoookJP03oookJP03ool0NOoonf[o
oo]Z00;ooo]Z00?o403ooi;o0?l007l01?l007l01?l0oe_o001oo`00Ool007l2oookJP?o001o00?o
9P3ooookJ_oonfX00ol007l3oookJP03oa80oooonf[ooo]Z00?o00000_l0g?l3oookJP03oomB0?oo
nf[ooo]Z03oooo]Z00Cooe80o`3o<ooonf[o02[o0ooonfX00ol0g?oooo]ZoookJP07oookJP03oa80
oooonf[ooo]Z00cooo]Z00?o9P3oob3o0?oonfX03OoonfX01_l0oe_ooo]ZoookJ_l0ok3ooo]Zo`0`
o`?ooo]Z00Co1P3ooookJ_oonf[oT_l00_oonfX00ol@0?oooo]ZoookJP02oookJP05ool0DOoonf[o
0:gooookJ_oo07T01OoonfX01ol0oe?ooo]ZoookJ_oonf[o0?lMoookJ_l0hOl02OoonfX00ol0ocCo
oo]Zo`3oCP05oookJP03o`28ool0ZOoooo]Z00?ooo]Z00?o00Coo`3DoooonfX02ooonfX00oooP@3o
oo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z02Sooo]Z000^oookJP03oomB0?oonf[o^Ol0013ooo]Z
00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP04oookJP;oogT01?oonfX02Ooo0?cooo]Z
oookJ_oonf[o603ooookJ_ooN@3ooo]Zon_o0003odCo0007o`2Voooonf[oZ03ooookJ_oo0?Wooo]Z
o`1go`02oookJP03oom/0?oo003o>ol000?ooo]Z00Co0?_ooookJ_oonf[oo`<00_oonfX01?mi0?oo
o`3Moil0oooUo`04oookJP0:o`3og_oonf[ooo]Zoomi0?oonf[oC@3oool00?mQ0?oooo]Zo`3oA@?o
oo]Z00?o0?n@oookJ_l0oi801OoonfX01?oo:03ooo]Zooo90?lH0?l2ooo90003oookJ_ooT03ooo]Z
00Gooo]Z00?ookh0oookJ_m`0?l00ooonfX00oooE`3ooo]ZoookJP02oookJP03oomi0?oonf[ooo]Z
00Wooo]Z00Go0=CoonGo0?oonf[ooo]Zo`28o`02oookJP03o`3oC_l0ocCooo]Z00?ooo]Z00?o0?l8
o`3o7OoonfX00ooonfX00ooo07Wooo]ZoookJP02oookJP03oa00oonBo`3o001o00?o001o00?o0?mK
o`00Ool007l00ol007l3oookJP03ob3o0?lV0?oooo]Z00;ooo]Z0ol007l00ooonf[o4P3ooookJP03
oookJP03o`000?l0g?oo000000?o00000_ooDP11oookJP;oobP000?ooe80oolX0?oo:0000ooo:000
0ooonf[o0=cooookJP07oookJP03oa80oooonf[ooo]Z00gooo]Z00?o9P3ooookJ_oonfX03?oonfX0
1?l0oe_ooo]ZoookJ_oo0002oookJP04o`0`oooonf[ooo]Zo`H0o`;ooo]Z00CoT_l0oookJ_oonf[o
403o0ooonfX01_oo057ooo]ZoookJ_oo003ooo]Zool0N@Gooo]Z00Ko0?mCoookJ_oonf[ooo]Zoomi
0?l0hOl:oookJP03o`3o=?l0odkooo]Z00Cooo]Z00?o08Soo`2YoooonfX00ooonfX00ol01?oooo]Z
o`3Do`0<oookJP03oon10?oonf[ooo]Z00Sooo]Z00?oo`0]oookJ_oonfX0DooonfX00oooDP3ooo]Z
okWo000@oookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01OoonfX00oooTP3ooo]Z
oookJP03oookJP06ool0o?oonf[ooo]ZoaP0oooonf[oo`H00_oonfX01_o[o`3oo`3foookJ_l0Y_oo
oo]ZojP0o`;ooo]Z00Soo`3io`1goooonf[ooo]Zoom/0?l0olcooo]Zoc_o00?ooo]Z00[o0?_ooook
J_oonf[oo`<0oookJ_mi0?ooo`3Mo`0Gool0Xooo/ol00ooonfX01?l0omkooo]ZoookJ_oo06`2oook
JP04odd0oooonf[oH@3oo`3oA@?ooo]Z00?o0?n@oookJ_l0oi801OoonfX01OmX0?oooo]ZoookJ_lH
0?ooi_l000;ooo]Z00?ooi00oookJ_oonfX01?oonfX00ooo_P3ooo]Zog00o`04oookJP05oomG0?oo
nf[ooo]ZoookJ_oo02d02ooonfX01Ol0e?oooo]Zo`04oooonf[o08So00;ooo]Z00?o0?m>o`3o=?oo
nfX00ooonfX00ol0o`So0?lMoookJP03oookJP03ool0NOoonf[ooo]Z00;ooo]Z00?o403ooi;o0?l0
07l01?l007l00ol0oe_o001oo`00O`02o`00O`Cooo]Z00Co9P3ooookJ_oonf[ooo]Z0ol007l2oook
JP04oa80oooonf[ooo]ZoookJP;o000000Co0=coo`000?l0003o00000_ooDP13oookJP04oomB0?l0
oc?ooo]Zo`0Zo`?ooo]Z00?o0=cooookJ_oonfX01_oonfX00olB0?oooo]ZoookJP0=oookJP03obH0
oolPo`3ooo]Z00cooo]Z00Oo0?mKoookJ_oonf[ooo]Zo`3o/?oonf[o033o00?ooo]Z00?o1P3ooook
J_nBo`000ooonfX02Ol@0?oooo]ZoookJ_oonf[oo`1AoookJ_l0[Ooooo]Zool0N@06oookJP06o`3o
Dooonf[ooo]Zo`3o7Ooonf[o0>7o2OoonfX00ol0ocCooo]Zo`3oCP05oookJP03o`28ool0ZOoooo]Z
00?ooo]Z00?o00Coo`3DoooonfX03?oonfX00oooP@3ooo]ZoookJP08oookJP03ool0;Ooonf[ooo]Z
02Sooo]Z000]oookJP04o`3o<oooDP3ooo]ZokWo00oooo]Z00?o07?ooookJ_oonfX04ooonfX00ooo
0>[ooo]ZoookJP04oookJP;oogT00ooonfX00ooo0?cooo]ZoookJP02oookJP04oaP0oooonf[oogT0
on_o00CoA?l000co0:KooookJ_nX0?oooo]Zool0nOoonf[o07OooookJ_ooK03ooo]Zool00?lko`02
oookJP0:o`3koooonf[ooo]ZoookJ_oo0`3ooo]ZogT0oooo0=goobP0onGo00Gooo]Z00Wo0?oNoook
J_oonf[oogT0oookJ_m=0?oooo]Zof40ool0odD00ooonfX00ol0oi3ooo]Zo`3oTP05oookJP05oolX
0?oonf[oolT0ooo90?lH0?l00_oob@000oooT03ooo]ZoookJP05oookJP03oonn0?m`0?oooo]Z00?o
oo]Z00?ooeL0oookJ_oonfX00_oonfX00oooN@3ooo]ZoookJP09oookJP04o`3DoooUo`3ooo]Zo`28
o`;ooo]Z00?o0?m>o`3o=?oonfX01?oonfX00ol0oagooo]ZoookJP02oookJP03ool0NOoonf[ooo]Z
00;ooo]Z00?o403ooookJ_nBo`001?oonfX00ol0oe_ooo]ZoookJP05oookJP03ob3o0?lV0?oooo]Z
00?ooo]Z0ol007l00olB0?oooo]ZoookJP03oookJP04o`3Lool0003o0000o`0000;ooe80A?oonfX2
oolX0003oomB0?oo:03oobP000?oobP000?o0=cooookJ_oonfX01ooonfX00olB0?oooo]ZoookJP0<
oookJP03obH0oooonf[ooo]Z00gooo]Z00Ko0?mKoookJ_oonf[oo`00oookJ_l0<?l2ool00004o`H0
oooonf[ooo]Zoi;o00;ooo]Z00?o403ooookJ_oonfX00_oonfX01Ooo057ooo]Zool00?oonf[oo`1i
00Kooo]Z00Go0?mCoookJ_oonf[oogT0o`3Qo`0:oookJP03o`3o=?l0odkooo]Z00Gooo]Z00?o08So
o`2YoooonfX00ooonfX00ol01?oo0=CooookJP0;oookJP03oon10?oonf[ooo]Z00Sooo]Z00?oo`0]
oookJ_oonfX0D_oonfX01?l0oc?ooe80oookJ_nio`0?oookJP03o`1coooonf[ooo]Z01?ooo]Z00?o
o`3ZoookJ_oonfX01OoonfX00oooTP3ooo]ZoookJP02oookJP0:ool0o?oonf[ooo]ZoookJ_lH0?oo
oo]Zool60?oonf[ojol0ool0mP;ooo]Z00go0:KooookJ_nX0?oooo]Zool0nOoonf[o07OooookJ_l0
oi[oof`0o`3oc?oonf[o>ol000;ooo]Z00[o0?_ooookJ_oonf[ooo]Zool30?mi0?ooo`3Mo`0Gool0
Xooo/ol01?oonfX01_l0omkooo]ZoookJ_oo06cooo]Zodd0o`;ooo]Z00?oH@3oo`3oAOoonfX00_oo
nfX00ol0oi3ooo]Zo`3oTP04oookJP06ofP0oooonf[ooo]ZoookJ_lH0?ooi_l00_oonfX00oooT03o
oo]ZoookJP04oookJP03oonn0?m`0?oo0?l500?ooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02go
oo]ZoookJP09oookJP08o`3Dool01?oooo]ZoookJ_l0R?oooo]Zo`3oC_l0oc@5oookJP03o`3o2?l0
oagooo]Z00;ooo]Z00?oo`1ioookJ_oonfX00_oonfX00ol@0?oooo]Zoi;o0004oookJP03o`3oFooo
nf[ooo]Z00Kooo]Z00?o9P3ooookJ_oonfX00_oonfX3o`00O`03oookJ_lB0?oooo]Z00?ooo]Z00Co
0000o`3Lool0003o00000_ooDP16oookJP04oomB0?l0oc?ooo]Zo`0Zo`;ooo]Z00?o0=cooookJ_oo
nfX01ooonfX00olB0?oooo]ZoookJP0=oookJP03obH0oooonf[ooo]Z00cooo]Z00Ko0?mKoookJ_oo
nf[o0?n`oookJ_l0<?l3oookJP03o`H0oooonf[oT_l000?ooo]Z00Go403ooookJ_oonf[ooo]Zool0
D@02oookJP03o`2]oooonf[oo`1i00Gooo]Z00Ko0?mCoookJ_oonf[o0?lMo`3o2?l0hOl9oookJP03
o`3o=?oonf[o0?m>00Kooo]Z00?o08Soo`2YoooonfX00_oonfX00ol01?oo0=CooookJP0<oookJP03
oon10?oonf[ooo]Z00Sooo]Z00?oo`0]oookJ_oonfX0:?oonfX002gooo]Z00?ooe80oookJ_nio`00
4?oonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Cooo]Z00?oogT0oookJ_ooN@00
0ooonfX00ooo0?cooo]ZoookJP02oookJP04oaP0oooonf[oogT0on_o00CoA?l000Ko0:KoojP0oooo
nf[oo`3ioookJ_l0Mol2oookJP04oom/0?oo003ooo]Zoc_o00;ooo]Z00[o0?_ooookJ_oonf[ooo]Z
ool30?oonf[oN@3oool0gOl05oooiOl01OoonfX02Ol0omkooo]ZoookJ_ooN@3ooo]Zodd0oooonf[o
H@3oo`3oA@03oookJP03o`3oT?oonf[o0?nB00Gooo]Z00CoobP0oookJ_oob@3o603o0ooob@000ooo
T03ooo]ZoookJP04oookJP03oonn0?oonf[oL03o00Cooo]Z00GooeL0oookJ_oonf[ooo]Zoomi000;
oookJP04o`3DoooUo`3ooo]Zo`28o`?ooo]Z00?o0?m>o`3o=?oonfX00ooonfX00ol0oagooo]Zoook
JP02oookJP03ool0NOoonf[ooo]Z00;ooo]Z00?o403ooookJ_nBo`001?oonfX00ol0oe_ooo]Zoook
JP06oookJP03obH0ool007oo001o00;ooo]Z0_l007l2oolX00Gooo]Z00Go0=coo`000?l0003o0000
oomB0018oookJP03oolX0?ooDP3oobP000?oobP000?ooo]Zo`3LoooonfX02?oonfX00olB0?oooo]Z
oookJP0<oookJP03obH0oooonf[ooo]Z00cooo]Z00?o0?mKoookJ_oonfX01Ooo00001?oonf[o1P3o
oookJ_nBo`02oookJP03oa00oooonf[ooo]Z00;ooo]Z00Goo`1AoookJ_oo003ooo]Zool0N@06oook
JP05o`3oDooonf[ooo]Zoomi0?l0hOl02_oonfX00ol0ocCooo]Zo`3oCP05oookJP03o`28ool0ZOoo
oo]Z00?ooo]Z00?o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP08oookJP03ool0;Ooonf[o
oo]Z05;ooo]Z00?ooe80oookJ_nio`004?oonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[o
oo]Z00Gooo]Z00?ooaH0oonB0?oonfX00ooonfX02_oo0?cooo]ZoookJ_oonf[o603ooookJ_oo1P3o
oo]Zon_o0?oo0?H2oookJP06o`2Voooonf[oZ03ooookJ_oo0?Wo07Oo0_oonfX01OooK03ooo]Zo`3o
c?oonf[o>ol000;ooo]Z00[o0?_ooookJ_oonf[ooo]Zool30?mi0?ooo`3Mo`0Gool0Xooo/ol01?oo
nfX02Ol0omkooo]ZoookJ_oo06cooo]Zodd0oooonf[oH@3oo`3oA@03oookJP03o`3oT?oonf[o0?nB
00Gooo]Z00GoJ03ooookJ_oonf[o603oonKo0002oookJP03oon@0?oonf[ooo]Z00Cooo]Z00?ookh0
oookJ_m`0?l01?oonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00_ooo]Z00Go0=CooookJ_l01?oooo]Z
o`28o`02oookJP03o`3oC_l0ocCooo]Z00?ooo]Z00?o0?l8o`3o7OoonfX00ooonfX01ooo07Wooo]Z
oookJ_oonf[o403ooookJ_nBo`001OoonfX00ol0oe_ooo]ZoookJP05oookJP03obH0ool007oo001o
00;ooo]Z1?l007l00olB0?oooo]ZoookJP03oookJP04o`3Lool0003o0000oomB04Wooo]Z00Cooe80
o`3o<ooonf[o02[o0_oonfX00ol0g?oooo]ZoookJP07oookJP03oa80oooonf[ooo]Z00cooo]Z00?o
9P3oob3o0?oonfX03?oonfX01?l0oe_ooo]ZoookJ_l0ok02oookJP06o`0`oooonf[ooo]Zo`H0oooo
nf[oT_l00ooonfX01Ol@0?oooo]ZoookJ_oonf[oo`1A00;ooo]Z00?o0:gooookJ_oo07T01_oonfX0
1Ol0oe?ooo]Zo`3o7Ol0o`So0>7o00[ooo]Z00?o0?ldo`3o;_l0odh01OoonfX00ol0R?oo0:Wooook
JP03oookJP03o`04ool0e?oooo]Z00_ooo]Z00?ooh40oookJ_oonfX02?oonfX00ooo02gooo]Zoook
JP0XoookJP00;OoonfX00oooDP3ooo]ZokWo000@oookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3Z
oookJ_oonfX01?oonfX2oomi00Cooo]Z00Goo`3loookJ_oonf[ooo]ZoaP0o`02oookJP03oomi0?o[
o`3oA?l000;oA?l000Oo0:KooookJ_nX0?oooo]Zool0nOoonf[o07Oo00;ooo]Z00?oof`0ool00?lk
o`000_oonfX00ol0nooooo]ZoookJP02oookJP06ool30?oonf[oN@3oool0gOnO0?ooiOl01?oonfX0
2Ol0omkooo]ZoookJ_ooN@3ooo]Zodd0oooonf[oH@3oo`3oA@03oookJP03o`3oT?oonf[o0?nB00Go
oo]Z00GoobP0oookJ_oob@3oolT0oaP0o`03ooo900Oooo]Z00?ookh0og00oooonfX00ooonfX00ooo
E`3ooo]ZoookJP02oookJP03oomi0?oonf[ooo]Z00Sooo]Z00Go0=CoonGo0?oonf[ooo]Zo`28o`02
oookJP03o`3oC_l0ocCooo]Z00Cooo]Z00?o0?lMoookJ_oonfX00_oonfX00ooo07Wooo]ZoookJP02
oookJP03oa00oonBo`3ooo]Z00?ooo]Z00?o0?mKoookJ_oonfX01_oonfX00olV0?oooo]Zo`00O`04
o`00O`?oobP01?oonfX00ol0g?oooo]Zo`000002oomB0003o`000?oonf[ooo]Z04Sooo]Z00?ooe80
oolX0?oo:0000_oo:0000ooonf[o0=cooookJP07oookJP03oa80oooonf[ooo]Z00cooo]Z00?o9P3o
oookJ_oonfX03OoonfX00ol0oe_oo`00ool00004ool00007oookJ_l60?oooo]ZoookJ_nBo`3ooo]Z
oa00o`04oookJP05ool0DOoonf[ooo]Zool00?oo07T01_oonfX01_l0oe?ooo]ZoookJ_ooN@3o0?l8
o`3Qo`Wooo]Z00?o0?ldoookJ_l0odh01OoonfX00ol0R?oo0:WooookJP03oookJP03o`04oooonf[o
0=Co00_ooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP1AoookJP03oomB0?oonf[o
^Ol0013ooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP05oookJP03oonB0?oonf[o
oo]Z00?ooo]Z00Coo`3loookJ_oonf[o603o0_oonfX02?oo1P3ooo]Zon_o0?oo0?Kooo]Zo`2Voooo
nf[oZ03o0_oonfX02?oo0?Wo07OooookJ_oonf[oof`0o`3oc?oonf[o>ol00_oonfX02ol0nooooo]Z
oookJ_oonf[oo`<0oookJ_mi0?ooo`3Mo`0Gool0Xooo/ol000?ooo]Z00Ko0?oNoookJ_oonf[oo`1/
oookJ_m=0?l2oookJP03of40ool0odGooo]Z00;ooo]Z00?o0?n@oookJ_l0oi801?oonfX01_mX0?oo
oo]ZoookJ_oonf[o603oonKo00;ooo]Z00?ooi00oookJ_oonfX01?oonfX00ooo_P3oL03oo`3o1@03
oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX02?oonfX00ol0e?oooo]Zo`04o`02
oookJP04o`28oooonf[o0?m>o`3o=0Gooo]Z00?o0?lMoookJ_oonfX00_oonfX00ooo07Wooo]Zoook
JP02oookJP03oa00oonBo`3ooo]Z00Cooo]Z00?o0?mKoookJ_oonfX01OoonfX00olV0?oooo]Zo`00
O`06o`00O`03oookJ_lB0?oooo]Z00;ooo]Z0_l0g?l01?l0003ooe80oomB0?l0001:oookJP04oomB
0?l0oc?ooo]Zo`0Zo`;ooo]Z00?o0=cooookJ_oonfX01_oonfX00olB0?oooo]ZoookJP0=oookJP03
obH0oooonf[ooo]Z00cooo]Z00Ko0?mKoookJ_oonf[o0?n`oookJ_l0<?l3oookJP03o`H0oooonf[o
T_l000;ooo]Z00?o403ooookJ_oonfX00_oonfX01Ooo057ooo]Zo`2]oooonf[oo`1i00Kooo]Z00Go
0?mCoookJ_oonf[o0?lMo`3Qo`0:oookJP03o`3o=?l0obko0?m>00Gooo]Z00?o08Soo`2YoooonfX0
0ooonfX00ol01?oo0=CooookJP0;oookJP03oon10?oonf[ooo]Z00Wooo]Z00?oo`0]oookJ_oonfX0
9ooonfX002cooo]Z00Co0?lcoomB0?oonf[o^Ol03ooonfX00ol0Looooo]ZoookJP0CoookJP03ool0
j_oonf[ooo]Z00Cooo]Z0_ooN@03oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Go603ooookJ_ooN@3o
A?l0on_o0003odCo000<o`2Voooonf[oZ03ooookJ_oo0?Wooo]Zo`1goooonf[oof`0oookJ_oo003o
>ol00_oonfX02_l0nooooo]ZoookJ_oonf[oo`<0oookJ_mi0?ooo`3Mo`0GoooUo`05oookJP09o`3o
g_oonf[ooo]Zoomi0?oonf[oC@3ooookJ_mQ0?oo0?m500?ooo]Z00?o0?n@oookJ_l0oi801OoonfX0
1?oo:03oolT0ooo90?lH0?l4ooo900Kooo]Z00?ookh0oookJ_m`0?l01?oonfX01OooE`3ooo]Zoook
J_oonf[oogT000_ooo]Z00Co0=CoonGo0?oonf[o08So0ooonfX00ol0odkooo]ZoookJP03oookJP03
o`3o7Ooonf[ooo]Z00;ooo]Z00?oo`1ioookJ_oonfX00_oonfX00ol@0?oooo]Zoi;o0004oookJP03
o`3oFooonf[ooo]Z00Gooo]Z00?o9P3ooookJ_oonfX00ol007l4oolX00?ooo]Z0_l0g?l2oookJP04
oomB0?l0003o0000o`0004[ooo]Z00?o0?lcoomB0?oo:0000_oo:0000ooonf[o0=cooookJP08oook
JP03oa80oooonf[ooo]Z00cooo]Z00?o9P3ooookJ_oonfX02ooonfX00ooo003o0?mKool00005ool0
00;ooo]Z00?o1P3ooookJ_nBo`000_oonfX00ol@0?oooo]ZoookJP02oookJP04ool0DOoonf[oo`00
ool0N@Oooo]Z00Go0?mCoookJ_oonf[oogT0o`3Qo`0:oookJP03o`3o=?l0odkooo]Z00Gooo]Z00?o
0:WooookJ_oonfX00_oonfX00ol01?oooo]Zo`3Do`0;oookJP03oon10?oonf[ooo]Z00Wooo]Z00?o
o`0]oookJ_oonfX0DOoonfX00oooDP3ooo]ZokWo000?oookJP03o`1coooonf[ooo]Z01?ooo]Z00?o
o`3ZoookJ_oonfX01OoonfX00oooTP3ooo]ZoookJP02oookJP07ool0o?oonf[ooo]ZoookJ_lH0?oo
oo]Zool60002oookJP06on_o0?oonf[ooo]Zo`2Voooonf[oZ03o0_oonfX02?oo0?Wo07OooookJ_l0
oi[oof`0o`3oc?oonf[o>ol00_oonfX02_l0nooooo]ZoookJ_oonf[oo`<0ogT0oooo0=go01Ooo`2S
oonco`04oookJP06o`3og_oonf[ooo]Zool0K?oonf[oC@3o0_oonfX01OmQ0?oo0?m5oookJ_oonf[o
0?n@00;ooo]Z00?o0?nBoookJ_oonfX00_oonfX01OmX0?oooo]ZoookJ_lH0?ooi_l000;ooo]Z00?o
oi00oookJ_oonfX01?oonfX00ooo_P3ooo]Zog00o`04oookJP05oomG0?oonf[ooo]ZoookJ_oo02d0
2ooonfX01Ol0e?oo00CooookJ_oonf[o08So00;ooo]Z00?o0?m>oookJ_oonfX00ooonfX00ol0o`So
0?lMoookJP02oookJP03ool0NOoonf[ooo]Z00;ooo]Z00?o403ooookJ_nBo`001?oonfX00ol0oe_o
oo]ZoookJP05oookJP03obH0oooonf[ooo]Z00Ko001o00?ooo]Zoa80oooonfX00_oonfX01?l0g?oo
oo]ZoookJ_ooDP03o`0004_ooo]Z00Kooe80oookJ_oonf[o02[ooookJ_l0g?l9oookJP03oa80oooo
nf[ooo]Z00cooo]Z00?o9P3oob3o0?oonfX03?oonfX01_l0oe_ooo]ZoookJ_l0ok3ooo]Zo`0`o`?o
oo]Z00?o1P3ooookJ_nBo`000ooonfX02Ol@0?oooo]ZoookJ_oonf[oo`1AoookJ_l0[Ooooo]Zool0
N@06oookJP06o`3oDooonf[ooo]Zo`3o7Ooonf[o0>7o2OoonfX00ol0ocCooo]Zo`3oCP06oookJP03
o`2Yoooonf[ooo]Z00;ooo]Z00?o00Coo`3DoooonfX02ooonfX00oooP@3ooo]ZoookJP09oookJP03
ool0;Ooonf[ooo]Z02Oooo]Z000/oookJP04o`3o<oooDP3ooo]ZokWo00oooo]Z00?o07?ooookJ_oo
nfX04_oonfX00ooo0>[ooo]ZoookJP04oookJP03oomi0?oonf[oogT000?ooo]Z00?oo`3loookJ_oo
nfX00_oonfX01?lH0?oooo]Zoomi0?o[o`04odCo0006o`2VoonX0?oooo]ZoookJ_oo0?Wo07Oo0_oo
nfX01?ooK03oo`00oookJ_lko`02oookJP0:o`3koooonf[ooo]ZoookJ_oo0`3ooo]ZogT0oooo0=go
01OoonGo00Gooo]Z00Wo0?oNoookJ_ooN@3ooo]Zodd0oooonf[oH@3ooookJ_l0odD00ooonfX00ol0
oi3ooo]Zo`3oTP05oookJP04oolX0?oob@3oolT0oaP0o`CoolT01_oonfX00ooo_P3oL03ooookJP03
oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oogT0oookJ_oonfX02?oonfX01?l0e?ooiOl0oookJ_l0
R?l3oookJP03o`3oC_l0ocCooo]Z00?ooo]Z00?o0?lMo`3o2?oonfX00_oonfX00ooo07Wooo]Zoook
JP02oookJP03oa00oooonf[oT_l000Cooo]Z00?o0?mKoookJ_oonfX01OoonfX01OlV0?oooo]Zoook
J_oonf[o001o00KoobP00_oonfX01Ol0g?oooo]ZoookJ_oonf[ooe8000Co0000BooonfX00oooDP3o
oo]ZoolX0002oolX0003oookJ_l0g?oooo]Z00Oooo]Z00?o4P3ooookJ_oonfX03?oonfX00olV0?oo
oo]ZoookJP0;oookJP;oo`0000?o0?mKool00?oo00000ooo0002oookJP03o`H0oooonf[oT_l000;o
oo]Z00?o403ooookJ_oonfX00_oonfX01Ooo057ooo]Zool00?oonf[oo`1i00Kooo]Z00Go0?mCoook
J_oonf[oogT0o`3Qo`0:oookJP03o`3o=?l0odkooo]Z00Gooo]Z00?o0:WooookJ_oonfX00_oonfX0
0ol01?oooo]Zo`3Do`0;oookJP03oon10?oonf[ooo]Z00Wooo]Z00?oo`0]oookJ_oonfX0D?oonfX0
1?l0oc?ooe80oookJ_nio`0?oookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01Ooo
nfX00ooo5P3ooi80oookJP03oookJP0:ool0o?oonf[ooo]ZoookJ_lH0?oooo]Zool60?oonf[ojol0
ool0mP;ooo]Z00Ko0:KooookJ_nX0?oooo]Zool0nOl0Mol2oookJP05oom/0?oonf[o0?o<oookJ_lk
o`000_oonfX02_l0nooooo]ZoookJ_oonf[oo`<0ogT0oooo0=go01Ooo`2Soonco`04oookJP05o`3o
g_oonf[oo`1/oookJ_m=0?l00_oonfX00omQ0?oo0?m5oookJP02oookJP03o`3oT?oonf[o0?nB00Go
oo]Z00GoJ03ooookJ_oonf[o603oonKo0002oookJP03oon@0?oonf[ooo]Z00Cooo]Z00?ookh0og00
ool0o`D01?oonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00[ooo]Z00Go0=CooookJ_l01?oooo]Zo`28
o`02oookJP03o`3oC_l0ocCooo]Z00Cooo]Z00Go0?lMoookJ_oonf[ooo]Zool0N@04oookJP03oa00
oooonf[oT_l000Cooo]Z00?o0?mKoookJ_oonfX01OoonfX01?lV0?oooo]ZoookJ_oonfX2o`00O`Co
oo]Z00Go4P3ooookJ_oonf[ooo]Zo`3Lo`02oookJP03oomB0?l0003o000000;o0000C?oonfX01_oo
DP3ooo]ZoookJ_l0:_oooo]Zo`3Lo`Sooo]Z00?o4P3ooookJ_oonfX03OoonfX00olV0?oooo]Zoook
JP0<oookJP06o`3oFooonf[ooo]Zo`3o/?oonf[o033o0_oonfX00ol60?oooo]Zoi;o0003oookJP05
oa00oooonf[ooo]ZoookJ_oo05400_oonfX00ol0[Oooo`1ioookJP06oookJP05o`3oDooonf[o0?lM
o`3o2?l0hOl02OoonfX00ol0ocCooo]Zo`3oCP06oookJP03o`2Yoooonf[ooo]Z00;ooo]Z00?o00Co
o`3DoooonfX02ooonfX00oooP@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z02Oooo]Z000/oook
JP03oomB0?oonf[o^Ol0013ooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP04oook
JP;oogT01?oonfX02Ooo0?cooo]ZoookJ_oonf[o603ooookJ_m4o`3oogT0on_o0003odCo000<o`2V
oom4o`3oZ03ooookJ_oo0?Wooo]Zo`1goooonf[o0?nJoom/0?oo003o>ol00_oonfX00ol0nooooo]Z
oookJP02oookJP06ool30?oonf[oo`3MoookJ_oUo`3oW`3o1?oonfX02Ol0omkooo]ZoookJ_ooN@3o
oo]Zodd0oooonf[oH@3oo`3oA@03oookJP03o`3oT?oonf[o0?nB00Gooo]Z00CoobP0ooo90?oob@3o
603o1?oob@06oookJP03oonn0?oonf[oL03o00Cooo]Z00GooeL0oookJ_oonf[ooo]Zoomi000;oook
JP04o`3Doooonf[ooo]Zo`28o`?ooo]Z00?o0?m>oookJ_oonfX00ooonfX01Ol0oagooo]ZoookJ_oo
nf[oo`1i00Gooo]Z00?o403ooi;o0?oonfX00ooonfX00ol0oe_ooo]ZoookJP05oookJP03obH0oooo
nf[ooo]Z00;ooo]Z1_oo:002oookJP06o`3Loooonf[ooo]ZoookJ_ooDP3ooo]Z1?l0001<oookJP04
oomB0?oonf[ooo]ZoolX00;ooo]Z00?o0=cooookJ_oonfX01_oonfX00olB0?oooo]ZoookJP0<oook
JP03obH0oooonf[ooo]Z00_ooo]Z00?oo`00o`3oFooo00001Ooo00001ooonf[o1P3ooookJ_oonf[o
T_l0oookJ_l@0?l01?oonfX01Ooo057ooo]Zool00?oonf[oo`1i00Kooo]Z00Go0?mCoookJ_oonf[o
ogT0o`3Qo`03oomi00Oooo]Z00?o0?ldo`3oC_l0obh01OoonfX00ol0R?oo0:WooookJP02oookJP04
o`04oooonf[ooo]Zo`3Do`[ooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP1@oook
JP03oomB0?oonf[o^Ol0013ooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP05oook
JP03oonB0?oonf[ooo]Z00?ooo]Z00Coo`3loookJ_oonf[o603o0_oonfX01_oo1P3ooo]Zon_o0?oo
0?Kooo]Zo`2Vo`;ooo]Z00[oZ03ooookJ_oo0?Wo07OooookJ_l0oi[oof`0o`3oc?oonf[o>ol00_oo
nfX02ol0nooooo]ZoookJ_oonf[oo`<0oookJ_oo0=gooo]Zo`2Soonco`3oW`3o00?ooo]Z00Ko0?oN
oookJ_oonf[oo`1/oookJ_m=0?l2oookJP03of40ool0odGooo]Z00;ooo]Z00?o0?n@oookJ_l0oi80
1?oonfX02?mX0?oooo]ZoookJ_lH0?oo07CoonKo0?oonf[ooi001_oonfX00ooo_P3ooo]Zog00o`04
oookJP05oomG0?oonf[ooo]ZoookJ_oo02d02ooonfX01Ol0e?oo00CooookJ_oonf[o08So00;ooo]Z
00?o0?m>oookJ_oonfX00ooonfX00ol0oagooo]ZoookJP02oookJP03ool0NOoonf[ooo]Z00;ooo]Z
00?o403ooi;o0?oonfX01?oonfX00ol0oe_ooo]ZoookJP04oookJP03obH0oooonf[ooo]Z00;ooo]Z
0_l007l3oookJP03oa80oooonf[ooo]Z00;o0=co0_oonfX00oooDP3ooo]Zo`000003o`0004gooo]Z
00Kooe80oookJ_oonf[o02[ooookJ_l0g?l8oookJP03oa80oooonf[ooo]Z00cooo]Z00?o9P3oob3o
0?oonfX03?oonfX01_l0oe_ooo]ZoookJ_l0ok3ooo]Zo`0`o`?ooo]Z00?o1P3ooookJ_nBo`000_oo
nfX00ol@0?oooo]ZoookJP02oookJP05ool0DOoonf[o0:gooookJ_oo07T01_oonfX01Ol0oe?ooo]Z
oookJ_l0oago0>7o00[ooo]Z00?o0?ldo`3oC_oonfX01OoonfX00ol0R?oo0:WooookJP02oookJP03
o`04oooonf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP0WoookJP00
;?oonfX00oooDP3ooo]ZokWo000@oookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX0
1?oonfX2oomi00?ooo]Z00?oo`3loookJ_oonfX00_oonfX01OlH0?oooo]Zoomi0?m4o`3ojol000?o
A?l000co0:KoodCo0?nX0?oooo]Zool0nOoonf[o07OooookJ_ooK03oo`00oookJ_lko`02oookJP05
o`3koooonf[ooo]ZoookJ_oo0`000_oonfX00ooo0=gooo]ZonGo0005oookJP03o`3og_oonf[oogT0
00;ooo]Z00CoC@3ooookJ_mQ0?oo0?m50ooonfX00ol0oi3ooo]Zo`3oTP05oookJP04oolX0?oob@3o
olT0oaP0o`CoolT01_oonfX00ooo_P3oL03oo`3o1@03oookJP05oomG0?oonf[ooo]ZoookJ_ooN@00
2ooonfX01?l0e?ooiOl0oookJ_l0R?l3oookJP03o`3oC_oonf[ooo]Z00?ooo]Z00?o0?lMoookJ_oo
nfX00_oonfX00ooo07Wooo]ZoookJP02oookJP03oa00oooonf[oT_l000?ooo]Z00?o0?mKoookJ_oo
nfX01OoonfX01?lV0?oooo]ZoookJ_oonfX8oolX0003o`00Ool0g?oooo]Z00;ooo]Z00?ooe80oook
J_oonfX01?l0001=oookJP04oomB0?oonf[ooo]ZoolX00;ooo]Z00?o0=cooookJ_oo00001OoonfX0
0olB0?oooo]ZoookJP0<oookJP03obH0oolPo`3ooo]Z00cooo]Z00?oo`00o`3oFooo00001?oo0002
oookJP05o`H0oooonf[oT_l0oookJ_l@0?l01OoonfX01?oo057ooo]Zool00?oo07T7oookJP03o`3o
DoooN@3oogT000CoogT01ooonfX00ol0ocCooo]Zo`3oCP06oookJP05o`2Yoooonf[ooo]ZoookJ_l0
1?l00_oonfX00ol0e?oooo]ZoookJP08oookJP03oon10?oonf[ooo]Z00Wooo]Z00?oo`0]oookJ_oo
nfX0D?oonfX00oooDP3ooo]ZokWo000@oookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oo
nfX01OoonfX00oooTP3ooo]ZoookJP02oookJP07ool0o?oonf[ooo]ZoookJ_lH0?oooo]Zool60002
oookJP06on_o0?oo0?Kooo]Zo`2Voooonf[oZ03o0_oonfX02?oo0?Wo07OooookJ_l0oi[oof`0o`3o
c?oonf[o>ol00_oonfX02_l0nooooo]ZoookJ_oonf[oo`<0oookJ_oo0=gooo]Zo`2Soonco`04oook
JP03o`3og_oonf[oo`1/00;ooo]Z00GoC@3ooookJ_mQ0?oooo]Zo`3oA@02oookJP03o`3oT?oonf[o
0?nB00Gooo]Z00GoJ03ooookJ_oonf[o603oonKo0002oookJP03oon@0?oonf[ooo]Z00Cooo]Z00?o
okh0og00ool0o`D01?oonfX01?ooE`3ooo]ZoookJ_oo02d;oookJP05o`3Doooonf[o00CooookJ_l0
R?l00_oonfX00ol0odkooo]ZoookJP03oookJP03o`3o2?l0oagooo]Z00;ooo]Z00?oo`1ioookJ_oo
nfX00_oonfX00ol@0?oooo]Zoi;o0004oookJP03o`3oFooonf[ooo]Z00Cooo]Z00?o9P3ooookJ_oo
nfX01?oonfX3o`00O`04oa80ool007oo001oo`3Lo`?ooo]Z00?ooe80oookJ_oonfX01?l0001>oook
JP06oomB0?oonf[ooo]Zo`0Zoooonf[o0=co0_oonfX00ol0omoooo]ZoookJP02oookJP03oa80oooo
nf[ooo]Z00gooo]Z00?o9P3oob3o0?oonfX03?oonfX01Ol0oe_ooo]Zo`3o/?oonf[o033o00?ooo]Z
00?o1P3ooookJ_nBo`000_oonfX00ol@0?oooo]ZoookJP02oookJP05ool0DOoonf[o0:gooookJ_oo
07T01_oonfX01Ol0oe?ooo]ZoookJ_l0oago0>7o00[ooo]Z00?o0?ldo`3o;_l0odh01_oonfX01ol0
ZOoooo]ZoookJ_oonf[o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP09oookJP03ool0;Ooo
nf[ooo]Z02Oooo]Z000[oookJP04o`3o<oooDP3ooo]ZokWo00oooo]Z00?o07?ooookJ_oonfX04ooo
nfX00ooo0>[ooo]ZoookJP03oookJP03oomi0?oonf[oogT000?ooo]Z00?oo`3loookJ_oonfX00_oo
nfX01OlH0?ooA?l0oomi0?m4o`3ojol000;oA?l000?o0:KoodCo0?nX0?l00_oonfX02_oo0?Wooo]Z
o`1goooonf[oof`0ool00?oonf[o>ol0oookJ_l0nol4oookJP06ool30?oonf[oN@3oool0gOl05ooo
iOl01OoonfX02Ol0omkooo]Zoomi0?oonf[oC@3ooookJ_mQ0?oooo]Zo`3oA@02oookJP04o`3oT?oo
nf[ooo]Zo`3oTPCooo]Z00GoobP0oookJ_oonf[ooo]ZoaP0o`04ooo900Gooo]Z00?ookh0oookJ_m`
0?l01?oonfX01OooE`3ooo]ZoookJ_oonf[oogT000_ooo]Z00?o0=CooookJ_l0R?l01?oonfX00ol0
odkooo]ZoookJP02oookJP03o`3o7Ol0o`Sooo]Z00;ooo]Z00?oo`1ioookJ_oonfX00_oonfX00ol@
0?oooo]Zoi;o0004oookJP03o`3oFooonf[ooo]Z00Cooo]Z00?o9P3ooookJ_oonfX02Ooo:0000ol0
07oo0=coo`00O`02oookJP04oomB0?oonf[ooo]ZoookJPCo0000COoonfX01?l0oc?ooe80oookJ_l0
:_l2oookJP03o`3Loooonf[oo`0000Kooo]Z00?o4P3ooookJ_oonfX03?oonfX00olV0?oooo]Zoook
JP0;oookJP03ool00?l0oe_oo`0000Coo`000_oonfX01Ol60?oooo]Zoi;o0?oonf[o403o00Gooo]Z
00Coo`1AoookJ_oo003oo`1i1_oonfX00oooN@3o0?mCoomi0005oomi00Sooo]Z00?o0?ldo`3oC_oo
nfX01OoonfX01Ol0ZOoooo]ZoookJ_oonf[o00Co00;ooo]Z00?o0=CooookJ_oonfX02OoonfX00ooo
P@3ooo]ZoookJP08oookJP03ool0;Ooonf[ooo]Z04oooo]Z00Co0?lcoomB0?oonf[o^Ol03ooonfX0
0ol0Looooo]ZoookJP0CoookJP03ool0j_oonf[ooo]Z00Cooo]Z00?ooaH0oonB0?oonfX00ooonfX0
1ooo0?cooo]ZoookJ_oonf[o603ooookJ_oo1P000_oonfX00oo[o`3ooo]Zo`2Vo`02oookJP08ojP0
oooonf[oo`3ioookJ_l0Mooooo]Zoom/0?l0ol`2oookJP03oc_o0?oonf[o0?_o00Cooo]Z00Koo`<0
ogT0oooo0=go01Ooo`2Soonco`04oookJP05o`3og_oonf[oo`1/oookJ_m=0?l00_oonfX00omQ0?oo
0?m5oookJP02oookJP03o`3oT?oonf[o0?nB00Cooo]Z00SoJ03ooookJ_oonf[ooo]ZoaP0oooVo`3o
oo]Zoon@00Kooo]Z00?ookh0oookJ_m`0?l01?oonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00_ooo]Z
00Co0=Coo`04oooonf[o08So0ooonfX00ol0odkooo]ZoookJP03oookJP05o`3o7Ooonf[ooo]Zoook
J_oo07T01?oonfX00ol@0?oooo]Zoi;o0004oookJP03o`3oFooonf[ooo]Z00Cooo]Z00?o9P3ooook
J_oonfX01OoonfX2o`00O`05oa80ool007oo001oo`3Lool007l00_oonfX01?ooDP3ooo]ZoookJ_oo
nfX4o`0004kooo]Z00Ko0?lcoomB0?oonf[o02[ooookJ_l0g?l2oookJP03o`3ogooonf[ooo]Z00?o
oo]Z00?o4P3ooookJ_oonfX03OoonfX00olV0?oooo]ZoookJP0;oookJP05o`3oFooonf[ooo]Zo`3o
/?l0<?l00ooonfX00ol60?oooo]Zoi;o0002oookJP03oa00oooonf[ooo]Z00;ooo]Z00Goo`1Aoook
J_l0[Ooooo]Zool0N@07oookJP04o`3oDooonf[o0?lMo`3Qo`[ooo]Z00?o0?ldo`3o;_l0odh01_oo
nfX01ol0ZOoooo]ZoookJ_oonf[o00CooookJ_l0e?l03?oonfX00oooP@3ooo]ZoookJP08oookJP03
ool0;Ooonf[ooo]Z02Oooo]Z000[oookJP04oomB0?oonf[ooo]ZokWo00oooo]Z00?o07?ooookJ_oo
nfX04_oonfX00ooo0>[ooo]ZoookJP04oookJP;oogT01?oonfX00ooo0?cooo]ZoookJP02oookJP04
oaP0oooonf[oogT0on_o00?oA?l000oo0:KoodCo0?nX0?oooo]Zool0nOoonf[o07OooookJ_ooK03o
oo]Zool00?oonf[o>ol0oookJ_l0nol01?oonfX01_oo0`3ooo]Zool0gOoonf[oiOl0oil0o`Cooo]Z
00Wo0?oNoookJ_oonf[oogT0oookJ_m=0?oooo]Zof40ool0odD00ooonfX00ol0oi3ooo]Zo`3oTP05
oookJP07oolX0?oonf[ooo]ZoaP0ool0M?ooolT0oookJP02ooo900Gooo]Z00?ookh0oookJ_m`0?l0
1?oonfX01?ooE`3ooo]ZoookJ_ooN@0;oookJP04o`3Doooonf[ooo]Zo`28o`?ooo]Z00?o0?m>oook
J_oonfX00ooonfX01Ol0oagooo]ZoookJ_oonf[oobP000Gooo]Z00?o403ooi;o0?oonfX00ooonfX0
0ol0oe_ooo]ZoookJP03oookJP;oo`0000?o9P3ooookJ_oo:0002?oo:0000ooonf[o0=cooookJP02
oookJP03oomB0?oonf[ooo]Z00;ooo]Z1?l0001>oookJP04o`3o<oooDP3ooo]Zo`0Zo`;ooo]Z00?o
0=cooookJ_oo00001OoonfX00olB0?oooo]ZoookJP0<oookJP03obH0oolPo`3ooo]Z00cooo]Z00?o
o`00oomi0?oo00000ooo0002oookJP06o`H0oooonf[ooo]Zoi;o0?oonf[o403o1?oonfX01Ooo057o
oo]Zool00?oonf[oo`1i00Gooo]Z00?oogT0o`3oDoooN@001OooN@08oookJP03o`3o=?l0odkooo]Z
00Gooo]Z00?o0:WooookJ_oonfX00_oonfX01?l01?oooo]ZoookJ_l0e?l:oookJP03oon10?oonf[o
oo]Z00Wooo]Z00?oo`0]oookJ_oonfX0C_oonfX01?ooDP3ooo]ZoookJ_nio`0?oookJP03o`1coooo
nf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01OoonfX00oooTP3ooo]ZoookJP03oookJP0<ool0o?oo
nf[ooo]ZoookJ_lH0?oooo]Zool60?oonf[ojol0ool0m_oonf[o0:Ko0_oonfX02?nX0?oooo]Zool0
nOl0Mooooo]Zo`3oV_ooK03o0?o<0_oonfX00olko`3ooo]Zo`3ko`03oookJP07ool30?oonf[oo`3M
oookJ_l0Xooo/ol0oil0o`03oookJP06o`3og_oonf[ooo]Zool0K?oonf[oC@3o0_oonfX00omQ0?oo
0?m5oookJP02oookJP03o`3oT?oonf[o0?nB00Cooo]Z00SoJ03ooookJ_oonf[o603oo`1doooVo`3o
oo]Zoon@00Kooo]Z00?ookh0oookJ_m`0?l01?oonfX01?ooE`3ooo]ZoookJ_oo02d<oookJP04o`3D
oooonf[ooo]Zo`28o`;ooo]Z00?o0?m>oookJ_oonfX00ooonfX01Ol0o`So0?lMoookJ_oonf[oo`1i
00Gooo]Z00?o403ooi;o0?oonfX01?oonfX00ol0oe_ooo]ZoookJP03oookJP03ob3o0?lV0?oooo]Z
00Oooo]Z00Co4P3ooookJ_oonf[o0=co0ooonfX00oooDP3ooo]ZoookJP02oookJPCo0000CooonfX0
1_l0oc?ooe80oookJ_l0:_oooo]Zo`3Lo`;ooo]Z00?o0?oOoookJ_oonfX00_oonfX00olB0?oooo]Z
oookJP0=oookJP03obH0oolPo`3ooo]Z00cooo]Z00Go0?mKoookJ_l0ok3ooo]Zo`0`o`03oookJP03
o`H0oooonf[oT_l000;ooo]Z00?o403ooookJ_oonfX00_oonfX01?oo057ooo]Zo`2]oooo07T7oook
JP05o`3oDooonf[o0?lMoookJ_l0hOl02_oonfX00ol0ocCo0?m>oookJP05oookJP03o`2Yoooonf[o
oo]Z00;ooo]Z00?o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP09oookJP03ool0;Ooonf[o
oo]Z02Kooo]Z000[oookJP03oomB0?oonf[o^Ol0013ooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo
0>[ooo]ZoookJP04oookJP03oomi0?ooTP3ooo]Z00?ooo]Z01Soo`3loookJ_oonf[ooo]ZoaP0oooo
nf[oogT0oookJ_o[o`3ooo]ZodCo0?oonf[o0:KoodCo0?nX0?oooo]Zool0nOoonf[o07OooookJ_oo
K03oo`00oookJ_lko`02oookJP05o`3koooonf[ooo]ZoookJ_oo0`000_oonfX00ooo0=gooo]ZonGo
0005oookJP03o`3og_oonf[oogT000;ooo]Z00CoC@3oof40oooonf[o0?m50ooonfX00ol0oi3ooo]Z
o`3oTP04oookJP08oolX0?oonf[ooo]ZoookJ_lH0?ooolT0oookJ_ooT007oookJP03oonn0?m`0?oo
oo]Z00?ooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@0;oookJP03o`3Doooonf[o08So00Cooo]Z00?o
0?m>oookJ_oonfX00_oonfX00ol0oago0?l8oookJP02oookJP03oolX0?oonf[ooo]Z00;ooo]Z00?o
403ooookJ_nBo`000ooonfX00ol0oe_ooo]ZoookJP03oookJP;oo`0000?o9P3ooookJ_oo:0002Ooo
:0001Ol0g?oooo]ZoookJ_oonf[ooe8000Gooo]Z1?l0000HoookJPOoo`3f<?oonfX00ol0oc?oolT0
o`0Zo`03oookJP03o`3Loooo003ooo]Z00Gooo]Z00?o4P3ooookJ_oonfX03?oonfX00olV0?oooo]Z
oookJP0<oookJP03oomi0?oo003oo`0000;oo`000ooonfX01Ol60?oooo]Zoi;o0?oonf[o403o00Go
oo]Z00Coo`1Aool00?oonf[oo`1i0_oo0004oookJP03oomi0?l0oe?oogT000CoogT02?oonfX00ol0
ocCo0?m>oookJP05oookJP03o`2Yoooonf[ooo]Z00;ooo]Z00Co00CooookJ_oonf[o0=Co2_oonfX0
0oooP@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z04kooo]Z00?ooe80oookJ_nio`004?oonfX0
0ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooi80oookJ_oonfX00ooonfX0
1_oo0?cooo]ZoookJ_oonf[o603oool600;ooo]Z00Kojol0ool0m_oonf[o0:KooookJ_nX0?l2oook
JP08ool0nOl0Mooooo]Zo`3oV_ooK03o0?o<oookJ_lko`02oookJP0:o`3koooonf[ooo]ZoookJ_oo
0`3ooo]Zool0gOoonf[o0:?ook?o00Cooo]Z00?o0?oNoookJ_oo06`00_oonfX01?m=0?oooo]Zof40
ool0odD3oookJP03o`3oT?oonf[o0?nB00Cooo]Z00SoJ03ooookJ_oonf[ooo]ZoaP0oooVo`3ooo]Z
oon@00Oooo]Z00?ookh0og00oooonfX01?oonfX01?ooE`3ooo]ZoookJ_oo02d;oookJP04o`3Dool0
1?oooo]Zo`28o`?ooo]Z00?o0?m>oookJ_oonfX00ooonfX01Ol0oagooo]ZoookJ_oonf[oo`1i00Co
oo]Z00?o403ooookJ_nBo`001?oonfX00ol0oe_ooo]ZoookJP04oookJP03obH0oooonf[ooo]Z00Ko
oo]Z00Co4P3ooookJ_oonf[o0=co0ooonfX00oooDP3ooo]ZoookJP03oookJPCo00006?oonfX7ool0
mS7ooo]Z00?o0?lcoomB0?l0:_l00_oonfX00ol0g?oooo]Zo`3og`05oookJP03oa80oooonf[ooo]Z
00gooo]Z00?o9P3ooookJ_oonfX02ooonfX01Ol0oe_ooo]Zo`3o/?oonf[o033o00?ooo]Z00?o1P3o
oookJ_nBo`000_oonfX00ol@0?oooo]ZoookJP02oookJP04ool0DOoonf[o0:goool0N@Oooo]Z00Go
0?mCoookJ_l0o`So0?lMo`3Qo`0:oookJP03o`3o=?l0odkooo]Z00Gooo]Z00?o0:WooookJ_oonfX0
0_oonfX00ol01?oooo]Zo`3Do`0;oookJP03oon10?oonf[ooo]Z00Wooo]Z00?oo`0]oookJ_oonfX0
9_oonfX002[ooo]Z00Co0?lcoomB0?oonf[o^Ol03ooonfX00ol0Looooo]ZoookJP0CoookJP03ool0
j_oonf[ooo]Z00?ooo]Z00?oogT0oookJ_ooTP000ooonfX00ooo0?cooo]ZoookJP02oookJP0:oaP0
oooonf[oogT0oookJ_o[o`3ooo]ZodCo0?l0Y_oooo]ZojP0o`;ooo]Z00[oo`3ioookJ_l0Mooooo]Z
oom/0?oo003ooo]Zoc_o0?oonf[o0?_o1?oonfX01_oo0`3ooo]Zool0gOoonf[o0:?oonGo00Gooo]Z
00Wo0?oNoookJ_ooN@3ooo]Zodd0oooonf[oH@3ooookJ_l0odD00_oonfX00ol0oi3ooo]Zo`3oTP05
oookJP08oolX0?oonf[ooo]ZoaP0ool0M?ooolT0oookJ_ooT006oookJP03oonn0?oonf[oL03o00Co
oo]Z00CooeL0oookJ_oonf[oo`0]2ooonfX01?l01?oo0=CooookJ_l0R?l3oookJP03o`3oC_oonf[o
oo]Z00;ooo]Z00?oo`00o`3o2?oonfX00_oonfX2oolX00?ooo]Z00?o403ooookJ_nBo`001?oonfX0
0ol0oe_ooo]ZoookJP02oookJP;oo`0000?o9P3ooookJ_oonfX00_oonfX7oolX0005oookJ_l0g?oo
oo]ZoookJ_ooDP001_oonfX4o`0001?ooo]Z1Ooo0?H7oookJPGoo`3f;?oonfX00ooob@3ooo]Zo`0Z
o`02oookJP03o`3Loooonf[oo`0000;ooo]Z0_oo0002oookJP03oa80oooonf[ooo]Z00_ooo]Z00?o
9P3ooookJ_oonfX03?oonfX00oooN@3oo`00ool00002ool000?ooo]Z00Go1P3ooookJ_nBo`3ooo]Z
oa00o`05oookJP04ool0DOoo003oo`00ool0N@;oo`001?oonfX00oooN@3o0?mCoomi0004oomi00So
oo]Z00?o0?ldo`3oC_l0obh01OoonfX00ol0ZOoooo]ZoookJP02oookJP04o`04oooonf[ooo]Zo`3D
o`[ooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP1=oookJP04o`3o<oooDP3ooo]Z
okWo00oooo]Z00?o07?ooookJ_oonfX04ooonfX00ooo0>[ooo]ZoookJP04oookJP03oolF0?ooTP3o
oo]Z00?ooo]Z00Ooo`3loookJ_oonf[ooo]ZoaP0oooonf[oo`H000;ooo]Z00?ojol0ool0m_l0Y_l0
0_oonfX02?nX0?oooo]ZoookJ_oo0?Wo07OooookJ_ooK03o0?o<0_oonfX00olko`3ooo]Zo`3ko`04
oookJP06ool30?oo0=gooo]Zo`2Soooonf[o/ol01?oonfX01Ol0omkooo]Zool0K?oonf[oC@3o00;o
oo]Z00?oH@3oo`3oAOoonfX00_oonfX00ol0oi3ooo]Zo`3oTP04oookJP08ofP0oooonf[ooo]ZoaP0
ool0M?ooi_l0oookJ_ooT006oookJP03oonn0?oonf[oL03o00Cooo]Z00CooeL0oookJ_oonf[oo`0]
3?oonfX01?l0e?oooo]ZoookJ_l0R?l2oookJP03o`3oC_oonf[ooo]Z00?ooo]Z00Go0?lMoookJ_oo
nf[ooo]Zool0N@04oookJP03oa00oooonf[oT_l000Cooo]Z00?o0?mKoookJ_oonfX01?oonfX00olV
0?oooo]ZoookJP06oookJP05oa80oooonf[ooo]ZoookJ_l0g?l00_oonfX00oooDP3ooo]ZoookJP04
oookJPCo00004ooonfX5ool0mPOooo]Z1Ooo0?H]oookJP07oomB0?oonf[o02[ooookJ_l0g?oooo]Z
o`3og`06oookJP03oa80oooonf[ooo]Z00cooo]Z00?o9P3ooookJ_oonfX02ooonfX01Ol0oe_ooo]Z
oookJ_l0ok3o033o00?ooo]Z00?o1P3ooookJ_nBo`000_oonfX00ol@0?oooo]ZoookJP02oookJP05
ool0DOoonf[o0:gooookJ_oo07T01ooonfX01?l0oe?o0?l8o`3o7Ol0hOl:oookJP03o`3o=?l0odko
oo]Z00Gooo]Z00?o0:WooookJ_oonfX00_oonfX00ol01?oooo]Zo`3Do`0;oookJP03oon10?oonf[o
oo]Z00Wooo]Z00?oo`0]oookJ_oonfX09_oonfX002[ooo]Z00Co0?lcoomB0?oonf[o^Ol03ooonfX0
0ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Cooo]Z00?oogT0oonB0?oonfX00ooonfX0
0ooo0?cooo]ZoookJP02oookJP0:oaP0oooonf[oogT0oookJ_o[o`3oA?l0oookJ_l0Y_oooo]ZojP0
o`;ooo]Z00[oo`3ioookJ_l0Moooof`0oookJ_oo003ooo]Zoc_o0?oonf[o0?_o1?oonfX01_oo0`3o
oo]Zool0gOoonf[oiOl0oil0o`Cooo]Z00?o0?oNoookJ_ooN@000_oonfX01?m=0?ooH@3ooookJ_l0
odD3oookJP03o`3oT?oonf[o0?nB00Gooo]Z00OoobP0oookJ_oonf[o603oooo90?oonf[ooi0000Oo
oo]Z00?ookh0o`3o1Om`0?l00ooonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00_ooo]Z00Co0=Cooook
J_oonf[o08So0_oonfX00ol0odko0?ldoookJP03oookJP04ool00?l0o`Sooo]ZoookJP;oobP00ooo
nfX01?l@0?oooo]ZoookJ_nBo`03oookJP03o`3oFooonf[ooo]Z00;ooo]Z0ooo00000olV0?oooo]Z
oookJP03oookJPKoobP000Co0=cooookJ_oonf[ooe801ooonfX4o`0000oooo]Z1?oo0?HAoookJPCo
o`3f:OoonfX00ooob@3o02[ooookJP02oookJP03o`3Loooo003oo`0000?oo`000_oonfX00olB0?oo
oo]ZoookJP0;oookJP03obH0oolPo`3ooo]Z00cooo]Z00?oogT0ool00?oo00000_oo0004oookJP04
o`H0oonBo`3ooo]Zoa00o`?ooo]Z0_oo00001?oo057oo`00ool00?oo07T2ool000Gooo]Z00?o0?mC
oomi0?ooN@000oooN@09oookJP03o`3oC_l0obkooo]Z00Cooo]Z00?o08Soo`2YoooonfX00_oonfX0
1?l01?oooo]ZoookJ_l0e?l:oookJP03oon10?oonf[ooo]Z00Wooo]Z00?oo`0]oookJ_oonfX0COoo
nfX01?l0oc?ooe80oookJ_nio`0?oookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX0
1OoonfX00oooTP3ooo]ZoookJP03oookJP07ool0o?oonf[ooo]ZoookJ_lH0?oooo]Zool60002oook
JP03on_o0?oonf[o0:Ko00;ooo]Z00SoZ03ooookJ_oo0?Wooo]Zo`1gool0oi[oof`0o`3oc0;ooo]Z
00?o>ol0oookJ_l0nol00ooonfX01ooo0`3ooo]Zool0gOoonf[o0:?ook?o0?nO0?l00ooonfX00ol0
omkooo]Zool0K002oookJP05odd0oooonf[oH@3ooookJ_l0odD00ooonfX00ol0oi3o0?nBoookJP04
oookJP05ofP0oooonf[ooo]ZoaP0oooVo`000_oonfX00oooT03ooo]ZoookJP04oookJP03oonn0?l0
o`GoL03o00Cooo]Z00CooeL0oookJ_oonf[oo`0]2ooonfX01?l0e?oo00CooookJ_l0R?l2oookJP03
o`3oC_l0ocCooo]Z00Cooo]Z00Go0?lMoookJ_oonf[ooo]Zool0N@03oookJP04oa00oooonf[ooo]Z
oi;o00?ooo]Z00?o0?mKoookJ_oonfX01?oonfX00olPo`3o9P3ooookJP06oookJP05oa80oooonf[o
oo]ZoookJ_l0g?l00_oonfX00oooDP3ooo]ZoookJP05oookJPCo00003ooonfX4ool0mQ7ooo]Z1?oo
0?HZoookJP07oomB0?l0:_oooo]ZoookJ_l0g?oooo]Zo`3og`05oookJP03oa80oooonf[ooo]Z00co
oo]Z00?o9P3oob3o0?oonfX02ooonfX01Ol0oe_ooo]ZoookJ_l0ok3o033o00Cooo]Z00Go1P3ooi;o
0?oonf[ooo]Zoa00o`05oookJP04ool0DOl0[Ooooo]Zool0N@Oooo]Z00Co0?mCoookJ_l0oago0>7o
2_oonfX00ol0ocCo0?m>oookJP05oookJP03o`28ool0ZOoooo]Z00;ooo]Z00?o00CooookJ_l0e?l0
2ooonfX00oooP@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z02Kooo]Z000ZoookJP04oomB0?oo
nf[ooo]ZokWo00oooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP04oookJP03oomi
0?ooTP3ooo]Z00?ooo]Z00?oo`3loookJ_oonfX00_oonfX04olH0?oooo]Zoomi0?o[o`3ooo]ZodCo
0?oonf[o0:KooookJ_nX0?oooo]Zool0nOoonf[o07OooookJ_ooK03oo`00oookJ_lko`000_oonfX0
0ol0nooooo]ZoookJP02oookJP06ool30?oonf[oo`3MoookJ_oUo`3oW`3o1?oonfX00ol0omkooo]Z
ool0K002oookJP04odd0oomQ0?oooo]Zo`3oA@;ooo]Z00Co0?n@oookJ_oonf[o0?nB1?oonfX02?oo
:03ooo]ZoookJ_lH0?oo07Coooo90?oonf[ooi001ooonfX00ooo_P3oL03ooookJP03oookJP05oomG
0?oonf[ooo]ZoookJ_oo02d02ooonfX00ol0e?oooo]Zo`28o`03oookJP03o`3oC_oonf[ooo]Z00;o
oo]Z0_oo0002oookJP?oobP00ooonfX00ol@0?oooo]Zoi;o0003oookJP03o`3oFooonf[ooo]Z00;o
oo]Z0ooo00000olV0?ooo`00oookJP05oookJPCoobP000Co0=cooookJ_oonf[ooe802?oonfX4o`00
00gooo]Z0_oo0?HIoookJP;oo`3f9ooonfX01?oob@3ooo]Zo`0ZoooonfX2ooo900Goo`000ooonfX0
0olB0?oooo]ZoookJP0;oookJP03obH0oooonf[ooo]Z00cooo]Z00CoogT0ool00?oo003oo`001?oo
nfX01Ol60?oooo]Zoi;o0?oonf[o403o00;ooo]Z0ooo00000ooo057oo`00ool0N@02ool000Gooo]Z
00?o0?mCoomi0?ooN@000oooN@09oookJP03o`3o=?l0odkooo]Z00Cooo]Z00?o08Soo`2YoooonfX0
0_oonfX01?l01?oooo]ZoookJ_l0e?l:oookJP03oon10?oonf[ooo]Z00Wooo]Z00?oo`0]oookJ_oo
nfX0COoonfX01?ooDP3ooo]ZoookJ_nio`0?oookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3Zoook
J_oonfX01OoonfX00oooTP3ooo]ZoookJP03oookJP0>ool0o?oonf[ooo]ZoookJ_lH0?oooo]Zool6
0?oonf[ojol0ool0m_oonf[o0:KooookJ_nX0?l2oookJP05ool0nOl0Mooooo]Zo`3oV_ooK0000_oo
nfX01?lko`3ooo]ZoookJ_l0nol3oookJP07ool30?oonf[oo`3MoookJ_l0Xooo/ol0oil0o`03oook
JP03o`3og_oonf[oo`1/00;ooo]Z00CoC@3ooookJ_mQ0?oo0?m50ooonfX00ol0oi3ooo]Zo`3oTP04
oookJP08ofP0oooonf[ooo]ZoaP0ool0M?ooi_l0oookJ_ooT007oookJP03oonn0?m`0?oooo]Z00?o
oo]Z00GooeL0oookJ_oonf[ooo]Zool0;@0;oookJP04o`3Dool01?oooo]Zo`28o`;ooo]Z00?o0?m>
oookJ_oonfX00ooonfX01Ol0oagooo]ZoookJ_oonf[oo`1i00Cooo]Z00?o403ooookJ_nBo`001?oo
nfX00ol0oe_ooo]ZoookJP04oookJP03obH0oooonf[ooo]Z00Gooo]Z00Go4P3ooookJ_oonf[ooo]Z
o`3Lo`02oookJP03oomB0?oonf[ooo]Z00Kooo]Z1?l0000=oookJP;oo`3f6OoonfX2ool0mRSooo]Z
00?ooe80oookJ_l0:_l00_oonfX00ol0g?oo0?oOoookJP05oookJP03oa80oooonf[ooo]Z00cooo]Z
00?o9P3ooookJ_oonfX02ooonfX01Ol0oe_ooo]Zo`3o/?oonf[o033o00?ooo]Z00?o1P3ooookJ_nB
o`000_oonfX00ol@0?oooo]ZoookJP02oookJP04ool0DOoonf[o0:goool0N@Oooo]Z00Go0?mCoook
J_l0oagooo]Zo`3Qo`0:oookJP03o`3o=?l0odkooo]Z00Cooo]Z00?o08Soo`2YoooonfX00_oonfX0
0ol01?oooo]Zo`3Do`0;oookJP03oon10?oonf[ooo]Z00Wooo]Z00?oo`0]oookJ_oonfX09_oonfX0
02[ooo]Z00?ooe80oookJ_nio`004?oonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z
00?ooo]Z00?oogT0oookJ_ooTP000ooonfX00ooo0?cooo]ZoookJP02oookJP0:oaP0oooonf[oogT0
oookJ_o[o`3ooo]ZodCo0?l0Y_oooo]ZojP0o`;ooo]Z00[oo`3ioookJ_l0Mooooo]Zoom/0?oo003o
oo]Zoc_o0?oonf[o0?_o1?oonfX01_oo0`3ooo]Zool00?mi0?oo0:?oonGo00Gooo]Z00?o0?oNoook
J_oo06`00_oonfX01?m=0?ooH@3ooookJ_l0odD2oookJP03o`3oT?oonf[o0?nB00Gooo]Z00SoobP0
oookJ_oonf[o603oo`1doooob@3ooo]Zoon@00Kooo]Z00?ookh0o`3o1Om`0?l00ooonfX01OooE`3o
oo]ZoookJ_oonf[oo`0]00_ooo]Z00Co0=CooookJ_oonf[o08So0_oonfX00ol0odko0?ldoookJP02
oookJP;oo`0000?o0?l8oookJ_oo:0000ooo:002oookJP03oa00oooonf[oT_l000Cooo]Z00Co0?mK
oookJ_oonf[ooo]Z0ooo00000olV0?ooo`00oookJP05oookJP03oolX0?oonf[oobP000;oobP00_oo
nfX00oooDP3ooo]ZoookJP07oookJPGo00002OoonfX3ool0mQgooo]Z0_oo0?HVoookJPGoolT01Ooo
0003oookJP03oa80oooonf[ooo]Z00_ooo]Z00?o9P3ooookJ_oonfX03?oonfX00oooN@3ooo]Zool0
0002ool000?ooo]Z00Go1P3ooookJ_nBo`3ooo]Zoa00o`03oookJP;oo`0000Goo`1Aool00?oo003o
o`1iool00005oookJP03o`3oDoooN@3oogT000?oogT02OoonfX00ol0ocCo0?m>oookJP04oookJP03
o`28ool0ZOoooo]Z00;ooo]Z00Co00CooookJ_oonf[o0=Co2_oonfX00oooP@3ooo]ZoookJP09oook
JP03ool0;Ooonf[ooo]Z04gooo]Z00?ooe80oookJ_nio`004?oonfX00ol0Looooo]ZoookJP0Boook
JP03ool0j_oonf[ooo]Z00Cooo]Z00?ooaH0oonB0?oonfX00ooonfX00ooo0?cooo]ZoookJP02oook
JP07oaP0oooo1P3ooo]ZoookJ_o[o`3oo`3fo`2Vo`02oookJP08ojP0oooonf[ooo]Zool0nOl0Mooo
oo]Zoom/0?l0ol`2oookJP03oc_o0?oonf[o0?_o00Cooo]Z00Koo`<0ool0gOmi0?oo0:?oo`0Goonc
o`04oookJP03o`3og_oonf[oo`1/00;ooo]Z00CoC@3ooookJ_mQ0?oo0?m50ooonfX00ol0oi3ooo]Z
o`3oTP04oookJP08ofP0oooonf[ooo]ZoaP0ool0M?ooi_l0oookJ_ooT006oookJP03oonn0?l0o`Go
L03o00Cooo]Z00CooeL0oookJ_oonf[oo`0]2ooonfX02?l0e?oo00CooookJ_oonf[o08SooookJ_l0
odko0?ld1OoonfX01Ol0oagooo]ZoookJ_oonf[oo`1i00?ooo]Z00?o403ooookJ_nBo`001?oonfX0
0ol0oe_ooo]ZoookJP04oookJP03obH0oooonf[ooo]Z00Gooo]Z00Go4P3ooookJ_oonf[ooo]Zo`3L
o`02oookJP03oomB0?oonf[ooo]Z00Oooo]Z1Ol00009oookJP?oo`3f7OoonfX3ool0mRKooo]Z00Oo
oe80o`0Zoooonf[ooo]Zo`3Loooonf[o0?oO00Gooo]Z00?o4P3ooookJ_oonfX03?oonfX00olV0?oo
oo]ZoookJP0;oookJP05o`3oFooonf[ooo]Zo`3o/?l0<?l00ooonfX00ol60?oooo]Zoi;o0002oook
JP03oa00oooonf[ooo]Z00;ooo]Z00Coo`1AoookJ_l0[Oooo`1i1ooonfX01Ol0oe?ooo]Zo`3o2?l0
oago0>7o00[ooo]Z00?o0?ldo`3oC_oonfX01?oonfX00ol0R?oo0:WooookJP02oookJP03o`04oooo
nf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP0VoookJP00;?oonfX0
0onio`3ooo]ZoookJP0=oookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01?oonfX0
0ooo5P3ooo]ZoonB0003oookJP03ool0o?oonf[ooo]Z00;ooo]Z00[o603ooookJ_ooN@3ooo]Zon_o
0?oonf[oA?l0o`2Voooonf[oZ03o0_oonfX02_oo0?Wooo]Zo`1gooooK03ooo]Zool00?oonf[o>ol0
oookJ_l0nol4oookJP06ool30?oonf[oo`00oookJ_oUo`3oW`3o1?oonfX00ol0omkooo]Zool0K002
oookJP04odd0oomQ0?oooo]Zo`3oA@?ooo]Z00?o0?n@oookJ_l0oi801?oonfX02?oo:03ooo]Zoook
J_oonf[o603oooo90?oonf[ooi001ooonfX00ooo_P3o0?l5og00o`03oookJP05oomG0?oonf[ooo]Z
oookJ_oo02d02ooonfX00ol0e?oooo]Zo`28o`03oookJP04o`3oC_oonf[ooo]ZoookJP?oo`0000?o
oo]ZoolX0?oo:0000ooo:0001Ooonf[o403ooookJ_oonf[oT_l000?ooo]Z00Co0?mKoookJ_oonf[o
oo]Z0ooo00000olV0?ooo`00ool00005oookJP05oolX0?oonf[ooo]ZoookJ_oo:0000_oonfX00ooo
DP3ooo]ZoookJP08oookJPCo00002?oonfX2ool0mR;ooo]Z0_oo0?HRoookJPOoolT01_oo0003oook
JP03oomi0?oonf[ooo]Z00[ooo]Z00?o9P3ooookJ_oonfX03?oonfX00oooN@3ooo]Zool00002ool0
00Cooo]Z00Co1P3ooi;o0?oonf[o403o0ooonfX2ool00005ool0DOoo003oo`00ool0NOoo00001Ooo
nfX00ol0oe?oogT0oomi0003oomi00Wooo]Z00?o0?ldo`3oC_oonfX01?oonfX00ol0R?oo0:Wooook
JP02oookJP04o`04oooonf[ooo]Zo`3Do`[ooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]Z
oookJP1?oookJP03okWo0?oonf[ooo]Z00gooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]Z
oookJP05oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00Ooo`3loookJ_oonf[ooo]ZoaP0oooonf[oo`H0
00;ooo]Z00?ojol0ool0m_l0Y_l00_oonfX02?nX0?oooo]ZoookJ_oo0?Wo07Ooo`3oV_ooK03o0?o<
0_oonfX00olko`3ooo]Zo`3ko`03oookJP07ool30?oonf[oo`3MoookJ_l0Xooo/ol0oil0o`03oook
JP03o`3og_oonf[oo`1/00;ooo]Z00GoC@3ooookJ_mQ0?oooo]Zo`3oA@02oookJP03o`3oT?oonf[o
0?nB00Cooo]Z00SoJ03ooookJ_oonf[ooo]ZoaP0oooVo`3ooo]Zoon@00Oooo]Z00?ookh0o`3o1Om`
0?l00ooonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00_ooo]Z00Co0=Coo`04oooonf[o08So0_oonfX0
0ol0odkooo]ZoookJP03oookJP05o`3o7Ooonf[ooo]ZoookJ_oo07T00ooonfX01?l@0?oooo]Zoook
J_nBo`03oookJP03o`3oFooonf[ooo]Z00Cooo]Z00?o8?l0obH0oooonfX01OoonfX01OlB0?oooo]Z
oookJ_oonf[o0=co00;ooo]Z00?ooe80oookJ_oonfX02?oonfX4o`0000Sooo]Z0_oo0?HSoookJP;o
o`3f9?oonfX00oooDP3ooo]Zo`0Zo`02oookJP03o`3Lool0omoooo]Z00Gooo]Z00?o4P3ooookJ_oo
nfX02ooonfX00olV0?oooo]ZoookJP0;oookJP05o`3oFooonf[ooo]Zo`3o/?l0<?l01?oonfX01Ol6
0?ooT_l0oookJ_oonf[o403o00Gooo]Z00?oo`1Ao`2]oooo07T01ooonfX01Ol0oe?ooo]Zo`3o2?l0
oago0>7o00[ooo]Z00?o0?ldo`3oC_oonfX01?oonfX00ol0R?oo0:WooookJP02oookJP03o`04oooo
nf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP0VoookJP00;?oonfX0
0onio`3ooo]ZoookJP0=oookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01?oonfX0
0ooo5P3ooo]ZoonB0003oookJP03ool0o?oonf[ooo]Z00;ooo]Z00[o603ooookJ_ooN@3ooo]Zon_o
0?m4o`3ooo]Zo`2Voooonf[oZ03o0_oonfX01Ooo0?Wo07OooookJ_ooK03oo`0000;ooo]Z00?o>ol0
oookJ_l0nol01?oonfX01_oo0`3oo`00ool00?oonf[oiOl0oil0o`Cooo]Z00?o0?oNoookJ_oo06`0
0_oonfX01?m=0?ooH@3ooookJ_l0odD2oookJP04o`3oT?oonf[ooo]Zo`3oTPCooo]Z00SoobP0oook
J_oonf[o603oo`1doooob@3ooo]Zoon@00Oooo]Z00?ookh0og00oooonfX00_oonfX00oooE`3ooo]Z
oookJP02oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00Co0=CooookJ_oonf[o08So0_oonfX00ol0odko
0?ldoookJP02oookJP?oo`0000?ooo]ZoolX0?oo:0000ooo:0001?oonf[o403ooookJ_nBo`03oook
JP04ool00?oonf[ooo]ZoookJPCoo`0000?o9P3oool00?oo00001?oonfX00ooo:03ooo]ZoookJP02
oookJP03o`3Loooonf[ooe8000_ooo]Z1?l00006oookJP;oo`3f9_oonfX2ool0mQoooo]Z2?oob@06
ool000?ooo]Z00?oogT0oookJ_oonfX02_oonfX00olV0?oo8?l0oookJP0<oookJP03oomi0?oonf[o
oo]Z00;oo`001?oonfX01?l60?oooo]Zoi;o0?l@0?l4oookJP;oo`0000Coo`1Aool00?oo07Woo`00
1OoonfX00ol0oe?ooo]Zoomi0003oomi00[ooo]Z00?o0?m>o`3o;_oonfX00ooonfX00ol0R?oo0:Wo
oookJP02oookJP04o`04oooonf[ooo]Zo`3Do`[ooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02go
oo]ZoookJP1>oookJP03okWo0?oonf[ooo]Z00gooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[o
oo]ZoookJP05oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00Ooo`3loookJ_oonf[ooo]ZoaP0oooonf[o
o`H000;ooo]Z00Gojol0oookJ_l0Y_oooo]ZojP0o`02oookJP05ool0nOl0Mooooo]Zo`3oV_ooK000
0ooonfX00olko`3ooo]Zo`3ko`03oookJP07ool30?oonf[oo`3MoookJ_l0Xooo/ol0oil0o`03oook
JP03o`3og_oonf[oo`1/00;ooo]Z00CoC@3ooookJ_mQ0?oo0?m50ooonfX00ol0oi3ooo]Zo`3oTP04
oookJP08ofP0oooonf[ooo]ZoaP0ool0M?ooi_l0oookJ_ooT007oookJP03oonn0?m`0?oooo]Z00?o
oo]Z00GooeL0oookJ_oonf[ooo]Zool0;@0;oookJP07o`3Doooonf[ooo]Zo`28oooonf[o0?m>o`3o
=005oookJP05o`3o7Ooonf[ooo]ZoookJ_oo07T00ooonfX00ol@0?oooo]Zoi;o0003oookJP03o`3o
Fooonf[ooo]Z00Gooo]Z00?o9P3ooookJ_oonfX01?oonfX00olB0?oooo]ZoookJP02oookJP03o`3L
oooonf[ooe8000_ooo]Z1?l00006oookJP;oo`3f9ooonfX2ool0mR;ooo]Z00?ooe80oookJ_l0:_l0
0_oonfX00ol0g?oo0?oOoookJP05oookJP03oa80oooonf[ooo]Z00_ooo]Z00?o9P3ooookJ_oonfX0
2ooonfX01Ol0oe_ooo]ZoookJ_l0ok3o033o00Cooo]Z00Go1P3ooookJ_nBo`3ooo]Zoa00o`05oook
JP04ool0DOl0[Ooooo]Zool0N@Kooo]Z00Go0?mCoookJ_l0o`So0?lMo`3Qo`0;oookJP03o`3oC_oo
nf[ooo]Z00?ooo]Z00?o08Soo`2YoooonfX00_oonfX00ol01?oooo]Zo`3Do`0;oookJP03oon10?oo
nf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX09OoonfX002cooo]Z00?o^Ol0oookJ_oonfX03OoonfX0
0ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Cooo]Z00?ooaH0oonB0?oonfX00_oonfX0
0ooo0?cooo]ZoookJP03oookJP09oaP0ooooN@3ooo]Zon_o0?oonf[oA?l0oookJ_l0Y_ooZ03o00;o
oo]Z00Soo`3ioookJ_l0Mooooo]Zoom/0?oo003ooo]Zoc_o00;ooo]Z00Ko0?_ooookJ_oonf[ooo]Z
ool30?oonfX2ool00003onGo0?nO0?oooo]Z00Cooo]Z00?o0?oNoookJ_oo06`00_oonfX00om=0?oo
H@3oo`3oA@03oookJP03o`3oT?oonf[o0?nB00Cooo]Z00SoobP0oookJ_oonf[ooo]ZoaP0oooob@3o
oo]Zool000Oooo]Z00?ookh0o`3o1Om`0?l00ooonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00_ooo]Z
00Co0=CooookJ_oonf[o08So0_oonfX01?l0odkooo]ZoookJ_oonfX4ool000GoobP000Cooo]Zoa00
oooonf[oT_l01?oonfX00ooo003ooo]ZoookJP04ool00003obH0oooo003oo`0000Gooo]Z00Go4P3o
oookJ_oonf[ooo]Zo`3Lo`02oomi00cooo]Z1?l00004oookJP;oo`3f:_oonfX00ooo0?Kooo]Zoook
JP0LoookJPSoolT01_oo0003oookJP03oomi0?oonf[ooo]Z00_ooo]Z00?o9P3ooookJ_oonfX02ooo
nfX01OooN@3ooo]ZoookJ_oonf[oo`0000Cooo]Z00Go1P3ooookJ_nBo`3ooo]Zoa00o`03oookJP;o
o`0000Coo`1Aool00?oo07Woo`001_oonfX00ol0oe?oogT0oomi0002oomi00[ooo]Z00?o0?m>o`3o
;_oonfX01?oonfX01Ol0R?oo0:WooookJ_oonf[o00Co00;ooo]Z00?o0=CooookJ_oonfX02?oonfX0
0oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z04kooo]Z00?o^Ol0oookJ_oonfX03OoonfX0
0ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooi80oookJ_oonfX00_oonfX0
0ooo0?cooo]ZoookJP02oookJP0:oaP0oooo1P3ooo]ZoookJ_o[o`3oo`3foookJ_l0Y_oooo]ZojP0
o`;ooo]Z00Goo`3io`1goooonf[oof`0o`3oc002oookJP04oc_o0?oonf[ooo]Zo`3ko`?ooo]Z00Ko
o`<0ool0gOmi0?oo0:?ook?o0?nO0?l4oookJP03o`3og_oonf[oo`1/00;ooo]Z00CoC@3ooookJ_mQ
0?oo0?m50ooonfX00ol0oi3o0?nBoookJP03oookJP08ofP0oooonf[ooo]ZoookJ_lH0?ooi_l0oook
J_ooT007oookJP03oonn0?l0o`GoL03o00Cooo]Z00CooeL0oookJ_oonf[oo`0]2ooonfX01?l0e?oo
00CooookJ_l0R?l2oookJP03o`3oC_oonf[ooo]Z00?ooo]Z00Go0?lMoookJ_oonf[ooo]Zool0N@03
oookJP03oa00oooonf[oT_l000Cooo]Z00?o0?mKoookJ_oonfX01?oonfX00olV0?oooo]ZoookJP05
oookJP07oa80oooonf[ooo]ZoookJ_l0g?oooo]ZoomB000<oookJPCo00001?oonfX2ool0mR_ooo]Z
00?oo`3foookJ_oonfX08?oonfX01oooDP3ooo]Zo`0Zoooonf[o0=cooookJ_l0oml01OoonfX00olB
0?oooo]ZoookJP0;oookJP03obH0oolPo`3ooo]Z00_ooo]Z00Ko0?mKoookJ_oonf[ooo]Zo`3o/?l0
<?l3oookJP03o`H0oooonf[oT_l000;ooo]Z00?o403ooookJ_oonfX00_oonfX01?oo057ooo]Zo`2]
oooo07T6oookJP05o`3oDooonf[o0?l8oookJ_l0oad02ooonfX00ol0odkooo]ZoookJP04oookJP07
o`28ool0ZOoooo]ZoookJ_l01?oooo]Zo`3Do`0;oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]
oookJ_oonfX09OoonfX002_ooo]Z00?o^Ol0oookJ_oonfX03OoonfX00ol0Looooo]ZoookJP0Coook
JP03ool0j_oonf[ooo]Z00?ooo]Z00?ooaH0oookJ_ooTP000ooonfX00ooo0?cooo]ZoookJP02oook
JP0:oaP0oooonf[oogT0oookJ_o[o`3ooo]ZodCo0?l0Y_oooo]ZojP0o`;ooo]Z00Soo`3ioookJ_l0
Moooof`0o`3oV_oo003ooo]Zoc_o00;ooo]Z00Go0?_ooookJ_oonf[ooo]Zool30003ool00003onGo
0?nO0?oooo]Z00?ooo]Z00Wo0?oNoookJ_oonf[oo`1/oookJ_m=0?ooH@3ooookJ_l0odD00ooonfX0
0ol0oi3ooo]Zo`3oTP04oookJP08oolX0?oonf[ooo]ZoookJ_lH0?ooolT0oookJ_oo0007oookJP03
oonn0?m`0?oooo]Z00?ooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@0:oookJP04o`3Dool01?oooo]Z
o`28o`;ooo]Z00Co0?m>o`3o=?oonf[ooo]Z1Ooo0005oolX0004oookJ_l@0?oooo]Zoi;o00?ooo]Z
0_oo00000ooonf[oo`00ool00002ool00004obH0oooo003oo`00ool000Cooo]Z00Go4P3ooookJ_oo
nf[ooo]Zo`3Lo`03oomi00cooo]Z1?l00003oookJP03ool0m_oonf[ooo]Z02_ooo]Z00?oo`3foook
J_oonfX07?oonfX8ooo900Goo`001?oonfX00oooN@3ooo]ZoookJP0:oookJP03obH0oooonf[ooo]Z
00cooo]Z00GoogT0oookJ_oonf[o0?n`o`0`o`04oookJP04oolX0?nBo`3ooo]Zoa00o`Cooo]Z00Go
o`00ool0DOoo003oo`00ool0N@06oookJP03o`3oDooonf[oogT000;oogT02_oonfX00ol0ocCo0?m>
oookJP04oookJP05o`28ool0ZOoooo]ZoookJ_l01?l00_oonfX00ol0e?oooo]ZoookJP08oookJP03
oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX0COoonfX00onio`3ooo]ZoookJP0=oookJP03
o`1coooonf[ooo]Z01?ooo]Z00?oo`3ZoookJ_oonfX01?oonfX00ooo5P3ooi80oookJP03oookJP03
ool0o?oonf[ooo]Z00;ooo]Z00Oo603oool60?oonf[ooo]Zon_o0?oo0?Ko0:Ko00;ooo]Z00SoZ03o
oookJ_oonf[oo`3io`1goooonf[oof`0o`3oc0;ooo]Z00?o>ol0oookJ_l0nol01?oonfX01_oo0`3o
o`3MoookJ_l0Xooo/ol0oil0o`?ooo]Z00Wo0?oNoookJ_oonf[oo`1/oookJ_m=0?oooo]Zof40ool0
odD00ooonfX00ol0oi3ooo]Zo`3oTP04oookJP08ofP0oooonf[ooo]ZoookJ_lH0?ooi_l0oookJ_oo
T007oookJP03oonn0?l0o`GoL03o00?ooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@0;oookJP07o`3D
ool01?oooo]Zo`28oooonf[o0?m>o`3o=005oookJP05o`3o7Ooonf[ooo]ZoookJ_oo07T00ooonfX0
0ol@0?oooo]Zoi;o0003oookJP03o`3oFooonf[ooo]Z00Cooo]Z00?o8?l0obH0oooonfX01OoonfX0
1OlB0?oooo]ZoookJ_oonf[o0=co00;ooo]Z00?ooe80oookJ_oonfX02_oonfX4o`0000?ooo]Z00?o
o`3foookJ_oonfX0:ooonfX00ooo0?Kooo]ZoookJP0PoookJP03oomB0?oonf[o02[o00;ooo]Z00?o
0=coo`3ogooonfX01OoonfX00olB0?oooo]ZoookJP0;oookJP03obH0oooonf[ooo]Z00_ooo]Z00Go
0?mKoookJ_oonf[o0?n`o`0`o`04oookJP05o`H0oonBo`3ooo]ZoookJ_l@0?l01?oonfX01?oo057o
oo]Zo`2]oooo07T6oookJP06o`3oDooonf[o0?l8oookJ_l0oago0>7o2_oonfX00ol0ocCo0?m>oook
JP04oookJP07o`28ool0ZOoooo]ZoookJ_l01?oooo]Zo`3Do`0;oookJP03oon10?oonf[ooo]Z00[o
oo]Z00?oo`0]oookJ_oonfX09OoonfX002_ooo]Z00?o^Ol0oookJ_oonfX03OoonfX00ol0Looooo]Z
oookJP0BoookJP03ool0j_oonf[ooo]Z00Cooo]Z00?ooaH0oookJ_ooTP000ooonfX00ooo0?cooo]Z
oookJP02oookJP0:oaP0oooonf[oogT0oookJ_o[o`3ooo]ZodCo0?l0Y_oooo]ZojP0o`;ooo]Z00Go
o`3ioookJ_l0Moooof`0o`3oVP02oookJP03oc_o0?oonf[o0?_o00Cooo]Z00Koo`<0ool00?oo003o
o`00onGo0?nO0?l4oookJP03o`3og_oonf[oo`1/00;ooo]Z00CoC@3oof40oooonf[o0?m50_oonfX0
0ol0oi3ooo]Zo`3oTP05oookJP06oolX0?oonf[ooo]ZoaP0ool0M?ooolT00_oo0006oookJP03oonn
0?oonf[oL03o00?ooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP08oookJP04o`3D
oooonf[ooo]Zo`28o`;ooo]Z00?o0?m>oookJ_oonfX01Ooo0006oolX0003oa00oooonf[oT_l000?o
oo]Z0_oo00000ooonf[oo`00ool00003ool00004obH0oooo003oo`00ool000?ooo]Z00Go4P3ooook
J_oonf[ooo]Zo`3Lo`03oomi00gooo]Z1?l000000ooonf[oo`3fool0mP0EoookJP;oobP06?oonfX0
0ooo0?Kooo]ZoookJP0LoookJPOoolT01Ooo0004oookJP03oomi0?oonf[ooo]Z00[ooo]Z00?o9P3o
oookJ_oonfX03?oonfX01OooN@3ooo]ZoookJ_l0ok3o033o00Cooo]Z00CoobP0oi;o0?oonf[o403o
1OoonfX01?oo057oo`00ool00?oo07T6oookJP03o`3oDooonf[oogT000;oogT000?o0>7ooookJ_oo
nfX01ooonfX00ol0ocCo0?m>oookJP04oookJP05o`28ool0ZOoooo]ZoookJ_l01?l00_oonfX00ol0
e?oooo]ZoookJP08oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX0COoonfX00oni
o`3ooo]ZoookJP0=oookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01OoonfX00ooo
5P3ooi80oookJP03oookJP07ool0o?oonf[ooo]ZoookJ_lH0?oooo]Zool60002oookJP03on_o0?oo
0?Ko0:Ko00;ooo]Z00OoZ03ooookJ_oo0?Wooo]Zo`1goooonf[oof`000?ooo]Z00?o>ol0oookJ_l0
nol00ooonfX01ooo0`3ooo]Zool0gOoonf[o0:?ook?o0?nO0?l00ooonfX00ol0omkooo]Zool0K002
oookJP04odd0oooonf[oH@3oo`3oA@?ooo]Z00?o0?n@oookJ_l0oi801?oonfX02?mX0?oooo]Zoook
J_lH0?oo07CoonKo0?oonf[ooi001_oonfX00ooo_P3ooo]Zog00o`04oookJP05oomG0?oonf[ooo]Z
oookJ_oo02d02_oonfX01?l0e?oo00CooookJ_l0R?l2oookJP03o`3oC_oonf[ooo]Z00?ooo]Z00Go
0?lMoookJ_oonf[ooo]Zool0N@03oookJP03oa00oooonf[oT_l000Cooo]Z00?o0?mKoookJ_oonfX0
1?oonfX00olV0?oooo]ZoookJP04oookJP05oa80oooonf[ooo]ZoookJ_l0g?l00_oonfX00oooDP3o
oo]ZoookJP0;oookJPCo000000?ooo]Zool0m_oo0?H0;ooonfX00ooo0?Kooo]ZoookJP0OoookJP08
o`3o<oooDP3ooo]Zo`0Zoooonf[o0=cooookJ_l0oml5oookJP03oa80oooonf[ooo]Z00_ooo]Z00?o
9P3ooookJ_oonfX02ooonfX01Ol0oe_ooo]ZoookJ_l0ok3o033o00Cooo]Z00Go1P3ooi;o0?oonf[o
oo]Zoa00o`04oookJP04ool0DOoonf[o0:goool0N@Oooo]Z00Go0?mCoookJ_l0o`So0?lMo`3Qo`0:
oookJP03o`3o=?l0odkooo]Z00Cooo]Z00Oo08Soo`2Yoooonf[ooo]Zo`04oooonf[o0=Co00_ooo]Z
00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP0UoookJP00:ooonfX00onio`3ooo]Zoook
JP0=oookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01?oonfX00ooo5P3ooo]ZoonB
0002oookJP03ool0o?oonf[ooo]Z00?ooo]Z00Wo603ooomi0?oonf[ooo]Zon_o0?m4o`3ooo]Zo`2V
oonX0?l00ooonfX01?oo0?Wo07OooookJ_ooK002oookJP04oc_o0?oonf[ooo]Zo`3ko`Cooo]Z0ooo
00000ooUo`3oogT0oookJP04oookJP03o`3og_oonf[oo`1/00;ooo]Z00?oC@3oof40ool0odD00ooo
nfX00ol0oi3ooo]Zo`3oTP04oookJP06oolX0?oonf[ooo]ZoookJ_lH0?ooolT00ooo0006oookJP03
oonn0?l0o`GoL03o00?ooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@0:oookJP04o`3Dool01?oooo]Z
o`28o`;ooo]Z00Co0?m>o`3o=?oonf[ooo]Z1Ooo0006oolX0003oa00oonBo`3ooo]Z00;ooo]Z0ooo
0003oookJP;oo`0000Co9P3oool00?oo003oo`001?oonfX00olB0?oooo]ZoookJP05oomi00gooo]Z
1?l000000ooo0?Kooo]ZoookJP0>oookJPko/ol05?oonfX00ooo0?Kooo]ZoookJP0LoookJPKoolT0
1_oo0003oookJP03oomi0?oonf[ooo]Z00[ooo]Z00?o9P3oob3o0?oonfX03?oonfX01OooN@3ooo]Z
oookJ_l0ok3o033o00Cooo]Z00CoobP0oookJ_nBo`3o403o1OoonfX01?oo057oo`00ool00?oo07T6
oookJP03o`3oDooonf[ooo]Z00;oogT000?o0>7ooookJ_oonfX01ooonfX00ol0ocCo0?m>o`3o;P04
oookJP05o`28ool0ZOoooo]ZoookJ_l01?l00_oonfX00ol0e?oooo]ZoookJP08oookJP03oon10?oo
nf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX0COoonfX00onio`3ooo]ZoookJP0=oookJP03o`1coooo
nf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01OoonfX00ooo5P3ooi80oookJP02oookJP03ool0o?oo
nf[ooo]Z00;ooo]Z00?o603oool60?oonfX00_oonfX01Oo[o`3ooo]Zo`2Voooonf[oZ03o00;ooo]Z
00Coo`3io`1goooonf[oof`00ooonfX01?lko`3ooo]ZoookJ_l0nol3oookJP06ool30?oonf[oo`3M
o`2Soonco`3oW`3o1?oonfX00ol0omkooo]Zool0K002oookJP04odd0oooonf[oH@3oo`3oA@?ooo]Z
00?o0?n@o`3oT_oonfX00ooonfX02?mX0?oooo]ZoookJ_oonf[o603oonKo0?oonf[ooi001ooonfX0
0ooo_P3o0?l5og00o`03oookJP05oomG0?oonf[ooo]ZoookJ_oo02d02ooonfX01ol0e?oo00Cooook
J_l0R?oooo]Zo`3oC_l0oc@01?oonfX00ol0o`So0?lMoookJP02oookJP06ool0NOoonf[ooo]Zoook
J_l@0?ooT_l01?oonfX00ol0oe_ooo]ZoookJP04oookJP03ob3o0?lV0?oooo]Z00Gooo]Z00Oo4P3o
oookJ_oonf[ooo]Zo`3Loooonf[ooe8000kooo]Z1?l000000ooo0?Kooo]ZoookJP0>oookJPoo/ol0
4ooonfX00ooo0?Kooo]ZoookJP0OoookJP07oomB0?oonf[o02[ooookJ_l0g?oooo]Zo`3og`05oook
JP03oa80oooonf[ooo]Z00_ooo]Z00?o9P3ooookJ_oonfX02ooonfX01_l0oe_ooo]ZoookJ_l0ok3o
oo]Zo`0`o`?ooo]Z00Go1P3ooookJ_nBo`3ooo]Zoa00o`04oookJP04ool0DOoonf[ooo]Zool0N@Oo
oo]Z00Go0?mCoookJ_l0o`So0?lMo`3Qo`0:oookJP03o`3o=?l0odkooo]Z00Cooo]Z00Oo08Soo`2Y
oooonf[ooo]Zo`04oooonf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]Zoook
JP0UoookJP00:ooonfX00onio`3ooo]ZoookJP0=oookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3Z
oookJ_oonfX01?oonfX00ooo5P3ooo]ZoonB0002oookJP03ool0o?oonf[ooo]Z00?ooo]Z00Wo603o
oomi0?oonf[ojol0oookJ_m4o`3ooo]Zo`2VoonX0?l00_oonfX01Ooo0?Wooo]Zo`1gooooK03o0?nJ
00;ooo]Z00Co>ol0oookJ_oonf[o0?_o0ooonfX01_oo0`3oo`00ool00?oo003oiOl0oomi00Cooo]Z
00Co0?oNoookJ_oonf[oo`1/0_oonfX00om=0?ooH@3oo`3oA@02oookJP04o`3oT?oonf[ooo]Zo`3o
TPCooo]Z00KoJ03ooookJ_oonf[ooo]ZoaP0oooob@03ool000Kooo]Z00?ookh0og00oooonfX00_oo
nfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00Co0=CooookJ_oonf[o08So
0_oonfX00ol0odko0?ldoookJP06ool000GoobP000?o403ooookJ_nBo`000_oonfX4ool000Cooo]Z
00?o9P3oool00?oo00000_oo0003oookJP03oa80oooonf[ooo]Z00GoogT03_oonfX3o`000003ool0
m_oonf[ooo]Z00[ooo]Z1Onco`06oookJPGoobP00ooonfX3ok?o01;ooo]Z00?oo`3foookJ_oonfX0
6ooonfX6ooo90003oookJ_oo003oo`0000?oo`000ooonfX00oooN@3ooo]ZoookJP0;oookJP03obH0
oooonf[ooo]Z00_ooo]Z00GoogT0oookJ_oonf[o0?n`o`0`o`04oookJP05oolX0?oonf[oT_l0oook
J_l@0?l01?oonfX01?oo057oo`00ool00?oo07T6oookJP03o`3oDooonf[ooo]Z00;oogT000?o0>7o
oookJ_oonfX01ooonfX00ol0ocCo0?m>o`3o;P04oookJP03o`28ool0ZOoooo]Z00;ooo]Z00?o00Co
oookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z04gooo]Z00?o^Ol0
oookJ_oonfX03OoonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooaH0
oonB0?oonfX00_oonfX00ooo0?cooo]ZoookJP02oookJP0:oaP0oooo1P3ooo]ZoookJ_o[o`3oo`3f
oookJ_l0Y_oooo]ZojP0o`;ooo]Z00Coo`3io`1goooonf[oof`00ooonfX01?lko`3ooo]ZoookJ_l0
nol3oookJP06ool30?oonf[oo`3Mo`2Soonco`3oW`3o0ooonfX01?l0omkooo]ZoookJ_oo06`2oook
JP03odd0oooonf[oH@3o00?ooo]Z00?o0?n@oookJ_l0oi801?oonfX02?mX0?oooo]ZoookJ_oonf[o
603oonKo0?oonf[ooi001ooonfX00ooo_P3o0?l5og00o`03oookJP05oomG0?oonf[ooo]ZoookJ_oo
02d02_oonfX01?l0e?oo00CooookJ_l0R?l2oookJP03o`3oC_l0ocCooo]Z00?ooo]Z00Go0?lMoook
J_oonf[ooo]Zool0N@03oookJP03oa00oooonf[oT_l000Cooo]Z00?o0?mKoookJ_oonfX01?oonfX0
0olV0?oooo]ZoookJP04oookJP07oa80oooonf[ooo]ZoookJ_l0g?oooo]ZoomB000?oookJP?o0000
00?oo`3foookJ_oonfX02_oonfX5ok?o00oooo]Z0onco`0AoookJP03ool0m_oonf[ooo]Z01kooo]Z
00Oo0?lcoomB0?oonf[o02[ooookJ_l0g?oo0?oO00Kooo]Z00?o4P3ooookJ_oonfX02_oonfX00olV
0?oo8?l0oookJP0;oookJP06o`3oFooonf[ooo]Zo`3o/?oonf[o033o0ooonfX00ol60?oooo]Zoi;o
0002oookJP05oa00oooonf[ooo]ZoookJ_oo05400_oonfX00ol0[Oooo`1ioookJP05oookJP05o`3o
Dooonf[o0?l8oookJ_l0oad02_oonfX00ol0ocCo0?m>oookJP04oookJP03o`28ool0ZOoooo]Z00;o
oo]Z00?o00Coo`3DoooonfX02ooonfX00oooP@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z02Go
oo]Z000ZoookJP03okWo0?oonf[ooo]Z00gooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]Z
oookJP05oookJP03oolF0?ooTP3ooo]Z00;ooo]Z00?oo`3loookJ_oonfX00_oonfX02_lH0?oooo]Z
oomi0?oonf[ojol0oookJ_m4o`3ooo]Zo`2VoonX0?l2oookJP05ool0nOoonf[o07Oooom/0?l0oiX0
0_oonfX01?lko`3ooo]ZoookJ_l0nol3oookJPCoo`0000?oiOl0oomi0?oonfX00ooonfX02Ol0omko
oo]ZoookJ_oo06cooo]Zodd0oomQ0?oooo]Zo`3oA@02oookJP03o`3oT?oonf[o0?nB00Gooo]Z00Ko
J03ooookJ_oonf[o603oo`1doooob@03ool000Gooo]Z00?ookh0oookJ_m`0?l00ooonfX00oooE`3o
oo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00Co0=Coo`04oooonf[o08So0_oonfX00ol0
odko0?ldoookJP07ool000GoobP000Co403ooi;o0?oonf[ooo]Z1Ooo0003oookJP03obH0oooo003o
oo]Z00?oo`000_oonfX00olB0?oooo]ZoookJP06oomi00kooo]Z00Co0000ool0m_oo0?Ko00002?oo
nfX4ok?o00_ooo]Z1ooo:004oookJP?o/ol04?oonfX00ooo0?Kooo]ZoookJP0KoookJPGoolT00_oo
nfX4ool000Cooo]Z00?oogT0oookJ_oo00002_oonfX00olV0?oooo]ZoookJP0;oookJP05oomi0?oo
nf[ooo]ZoookJ_l0ok001?oonfX01Ooo:03ooo]Zoi;o0?oonf[o403o00Cooo]Z00Coo`1Aool00?oo
003oo`1i1_oonfX01_l0oe?ooo]ZoookJ_l0o`SoogT0o`3Qo`Wooo]Z00?o0?ldo`3oC_l0obh01?oo
nfX00ol0R?oo0:WooookJP02oookJP03o`04oooonf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02_oo
nfX00ooo02gooo]ZoookJP1;oookJP03okWo0?oonf[ooo]Z00gooo]Z00?o07?ooookJ_oonfX04_oo
nfX00ooo0>[ooo]ZoookJP06oookJP03oonB0?oonf[ooo]Z00;ooo]Z00?oo`3loookJ_oonfX00_oo
nfX02_lH0?ooo`H0oookJ_oonf[ojol0ool0m_oonf[o0:KooookJ_nX0?l2oookJP04ool0nOl0Mooo
oo]Zoom/00?ooo]Z00Co>ol0oookJ_oonf[o0?_o0_oonfX01ooo0`3ooo]Zool0gOoonf[o0:?ook?o
0?nO0?l00ooonfX02Ol0omkooo]ZoookJ_oo06cooo]Zodd0oooonf[oH@3oo`3oA@03oookJP03o`3o
T?l0oi;ooo]Z00Cooo]Z00SoJ03ooookJ_oonf[ooo]ZoaP0oooVo`3ooo]Zoon@00Kooo]Z00?ookh0
oookJ_m`0?l01?oonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00[ooo]Z00Oo0=Coo`04oooonf[o08So
oookJ_l0odko0?ld00Cooo]Z00?o0?l8o`3o7OoonfX00_oonfX01_oo07Wooo]ZoookJ_oonf[o403o
oi;o00Cooo]Z00?o0?mKoookJ_oonfX01?oonfX00olV0?oooo]ZoookJP04oookJP05oa80oooonf[o
oo]ZoookJ_l0g?l00_oonfX00oooDP3ooo]ZoookJP0=oookJP04o`000?oo0?Koo`3fo`0000Wooo]Z
0onco`0GoookJP?o/ol03ooonfX00ooo0?Kooo]ZoookJP0NoookJP07oomB0?oonf[o02[ooookJ_l0
g?oooo]Zo`3og`05oookJP03oa80oooonf[oolX000_ooo]Z00?o9P3ooookJ_oonfX02_oonfX01_l0
oe_ooo]ZoookJ_oonf[o0?n`o`0`o`?ooo]Z00?o1P3ooookJ_nBo`000_oonfX00ol@0?oooo]Zoook
JP02oookJP04ool0DOoonf[o0:goool0N@Kooo]Z00Go0?mCoookJ_l0o`Sooo]Zo`3o7@0:oookJP03
o`3o=?l0odkooo]Z00Cooo]Z00?o08Soo`2YoooonfX00_oonfX00ol01?oo0=CooookJP0;oookJP03
oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX09?oonfX002[ooo]Z00?o^Ol0oookJ_oonfX0
3OoonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Cooo]Z00?ooaH0oookJ_ooTP00
0_oonfX00ooo0?cooo]ZoookJP03oookJP09oaP0oooonf[oogT0oookJ_o[o`3oA?l0oookJ_l0Y_oo
Z03o00?ooo]Z00Goo`3io`1goooonf[oof`0o`3oVP02oookJP04oc_o0?oonf[ooo]Zo`3ko`?ooo]Z
0ooo00000ooUo`3oo`00oomi0004oookJP03o`3og_oonf[oo`1/00;ooo]Z00?oC@3oof40ool0odD0
0ooonfX00ol0oi3ooo]Zo`3oTP04oookJP06ofP0oooonf[ooo]ZoookJ_lH0?ooolT01?oo0005oook
JP03oonn0?l0o`GoL03o00;ooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP08oook
JP04o`3Doooonf[ooo]Zo`28o`;ooo]Z00?o0?m>o`3o=?oo00001ooo00002?oonf[oobP0oolX0?oo
:03o403ooookJ_nBo`3ooo]Z1Ooo0004oookJP05obH0oooonf[ooo]ZoookJ_oo00000ooonfX00olB
0?ooogT0oomi0006oomi00kooo]Z00Coo`3fo`000?l0003o00001?oonfX2ool000;o/ol01Ooo0009
oookJPWoobP01_oonfX2ok?o00oooo]Z00?oo`3foookJ_oonfX06ooonfX4ooo90003o`0Zoooonf[o
0=co00?oo`001?oonfX00oooN@3ooo]Zool0000:oookJP03obH0oolPo`3ooo]Z00cooo]Z00GoogT0
oookJ_oonf[o0?n`o`0`o`03oookJP05oolX0?oonf[ooo]Zoi;o0?l@0?l01OoonfX01?oo057oo`00
ool00?oo07T5oookJP06o`3oDooonf[ooo]Zo`3o2?l0oago0>7o2OoonfX00ol0ocCooo]Zo`3oCP04
oookJP03o`28oooonf[o0:Wo00;ooo]Z00?o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP0:
oookJP03ool0;Ooonf[ooo]Z04_ooo]Z00?o^Ol0oookJ_oonfX03OoonfX00ol0Looooo]ZoookJP0B
oookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooaH0oonB0?oonfX00_oonfX00ooo0?cooo]ZoookJP03
oookJP09oaP0oooo1P3ooo]ZoookJ_o[o`3ooo]Zo`2Voooonf[oZ03o00;ooo]Z00Goo`3io`1goooo
nf[oof`0o`3oVP03oookJP03oc_o0?oonf[o0?_o00?ooo]Z00Ooo`<0oookJ_oo0=gooo]Zok?o0?oo
nf[oW`3o00?ooo]Z00?o0?oNoookJ_oo06`00_oonfX00om=0?oooo]Zof40o`04oookJP03o`3oT?l0
oi;ooo]Z00?ooo]Z00SoJ03ooookJ_oonf[ooo]ZoaP0oooVo`3ooo]Zoon@00Oooo]Z00?ookh0o`3o
1Om`0?l00ooonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00_ooo]Z00Oo0=CooookJ_oonf[o08Sooook
J_l0odko0?ld00Cooo]Z00?o0?lMoookJ_oonfX00_oonfX01_oo07Wooo]ZoookJ_l@0?oooo]Zoi;o
00Cooo]Z00?o0?mKoookJ_oonfX00ooonfX00olPo`3o9P3ooookJP05oookJP04oa80oooonf[ooo]Z
o`3Lo`;ooo]Z00?ooe80oookJ_oonfX03_oonfX01?oo0?Ko0000o`000?l00007oookJP;o/ol07Ooo
nfX2ok?o00kooo]Z00?oo`3foookJ_oonfX07OoonfX01ol0oc?ooe80oookJ_l0:_oooo]Zo`3Lool0
oml01OoonfX00olB0?oooo]Zooo:000;oookJP03obH0oooonf[ooo]Z00_ooo]Z00Go0?mKoookJ_oo
nf[o0?n`o`0`o`03oookJP06o`H0oooonf[ooo]Zoi;o0?oonf[o403o1?oonfX01?oo057ooo]Zo`2]
oooo07T6oookJP06o`3oDooonf[o0?l8oookJ_l0oago0>7o2OoonfX00ol0ocCo0?l^o`3oCP04oook
JP03o`28oooonf[o0:Wo00;ooo]Z00?o00Coo`3DoooonfX02ooonfX00oooP@3ooo]ZoookJP0:oook
JP03ool0;Ooonf[ooo]Z02Cooo]Z000joookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oo
nfX01?oonfX00ooo5P3ooo]ZoonB0002oookJP03ool0o?oonf[ooo]Z00?ooo]Z00Wo603ooomi0?oo
nf[ooo]Zon_o0?m4o`3ooo]Zo`2VoonX0?l00ooonfX01?oo0?Wo07Oooom/0?l0oiX2oookJP04oc_o
0?oonf[ooo]Zo`3ko`?ooo]Z1?oo00000onco`3oo`00oomi0003oookJP04o`3og_oonf[ooo]Zool0
K0;ooo]Z00?oC@3oof40ool0odD00_oonfX01?oo:03ooo]ZoookJ_l0oi84oookJP06ofP0oooonf[o
oo]ZoookJ_lH0?ooolT01?oo0005oookJP03oonn0?m`0?oooo]Z00;ooo]Z00?ooeL0oookJ_oonfX0
0_oonfX00ooo02gooo]ZoookJP07oookJP08o`3Dool01?oooo]ZoookJ_l0R?oooo]Zo`3oC_l0oc@3
oookJPGoo`0000?ooo]ZoolX0?oonfX00_oonfX00ol@0?ooT_l0oookJP06ool000?ooo]Z00?o9P3o
ool00?oonfX01OoonfX00olB0?ooogT0oomi0006oomi00gooo]Z0_oob@04o`0000Cooo]Z0_nco`0?
ool00003of40oooo:03oobP000SoobP01ooonfX00onco`3ooo]ZoookJP0=oookJP03ool0m_oonf[o
oo]Z01_ooo]Z0ooob@000ol0:_oooo]ZoookJP03ool000Cooo]Z00?oogT0oookJ_oo00000_ooN@09
oookJP03obH0oooonf[ooo]Z00_ooo]Z00GoogT0oookJ_oonf[o0?n`o`0`o`03oookJP05oolX0?oo
nf[ooo]Zoi;o0?l@0?l01OoonfX01?oo057oo`00ool00?oo07T5oookJP07o`3oDooonf[ooo]Zo`3o
2?l0oagooo]Zo`3Qo`08oookJP03o`3o=?oonf[o0?m>00Cooo]Z00?o08SooookJ_l0ZOl00_oonfX0
1?l01?oooo]ZoookJ_l0e?l:oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX0Fooo
nfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooaH0oonB0?oonfX00_oo
nfX00ooo0?cooo]ZoookJP02oookJP03oaP0oooo1P3ooo]Z00;ooo]Z00Gojol0oookJ_l0Y_oooo]Z
ojP0o`02oookJP04ool0nOl0Mooooo]Zoom/00?ooo]Z00Co>ol0oookJ_oonf[o0?_o0ooonfX01_oo
0`3ooo]Zool0gOoonf[o/ol0oil0o`?ooo]Z00Co0?oNoookJ_oonf[oo`1/0_oonfX00om=0?oooo]Z
of40o`03oookJP03o`3oT?oonf[o0?nB00Cooo]Z00SoJ03ooookJ_oonf[ooo]ZoaP0oooVo`3ooo]Z
oon@00Oooo]Z00?ookh0o`3o1Om`0?l00ooonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00[ooo]Z00Oo
0=Coo`04oooonf[o08SooookJ_l0odko0?ld00Cooo]Z00?o0?l8o`3o7OoonfX00_oonfX01_oo07Wo
oo]ZoookJ_oonf[o403ooi;o00Cooo]Z00?o0?mKoookJ_oonfX01?oonfX00olV0?oooo]ZoookJP04
oookJP04oa80oooonf[ooo]Zo`3Lo`;ooo]Z00?ooe80oookJ_oonfX03_oonfX00ooo0?Ko0000o`00
0002o`0000Gooo]Z0_nco`0;oookJPSoH@3o3_oonfX00onco`3ooo]ZoookJP0<oookJP03ool0m_oo
nf[ooo]Z01cooo]Z00So0?lcoomB0?oonf[o02[ooookJ_l0g?oooo]Zo`3og`Cooo]Z00?o4P3ooook
J_oobP002ooonfX00olV0?oooo]ZoookJP0;oookJP06o`3oFooonf[ooo]Zo`3o/?oonf[o033o0_oo
nfX01_l60?oooo]ZoookJ_nBo`3ooo]Zoa00o`Cooo]Z00Coo`1AoookJ_oonf[oo`1i1_oonfX01_l0
oe?ooo]Zo`3o2?oonf[o0?lMo`3Qo`Wooo]Z00?o0?ldoookJ_l0odh01?oonfX00ol0R?oooo]Zo`2Y
o`02oookJP03o`04oooonf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]Zoook
JP0ToookJP00>_oonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Cooo]Z00?ooaH0
oookJ_ooTP000_oonfX00ooo0?cooo]ZoookJP03oookJP09oaP0ooooN@3ooo]Zon_o0?oonf[oA?l0
oookJ_l0Y_ooZ03o00;ooo]Z00Goo`3ioookJ_l0Moooof`0o`3oVP02oookJP04oc_o0?oonf[ooo]Z
o`3ko`?ooo]Z1?oo00000onco`3oo`00oomi0003oookJP09o`3og_oonf[ooo]Zool0K?oonf[oC@3o
oookJ_mQ0?oo0?m500;ooo]Z00?oobP0oookJ_l0oi801OoonfX01OmX0?oooo]ZoookJ_lH0?ooolT0
00Coo`001OoonfX00ooo_P3ooo]Zog00o`03oookJP05oomG0?oonf[ooo]ZoookJ_oo02d02_oonfX0
1?l0e?oo00CooookJ_l0R?l2oookJP03o`3oC_l0ocCooo]Z00?ooo]Z1?oo00001ooonf[oobP0oook
J_oonf[o403ooookJ_nBo`001ooo0002oookJP03obH0oooo003ooo]Z00Gooo]Z00?o4P3ooomi0?oo
N@001oooN@0<oookJP?oolT01?l00003oookJP03ok?o0?oo003oo`0000goo`000ooonfX<oolX00Ko
oo]Z00?o/ol0oookJ_oonfX03OoonfX00ooo0?Kooo]ZoookJP0JoookJPCoolT000?o02[ooookJ_l0
g?l00ooo0002oookJP?oogT000?oo`00oomi0?ooN@002OoonfX00olV0?oooo]ZoookJP0;oookJP03
oomi0?oonf[oogT000;oogT01?oonfX01?oo:03ooo]Zoi;o0?l@0?l5oookJP04ool0DOoonf[oo`00
ool0N@Gooo]Z00Oo0?mCoookJ_oonf[ooo]Zo`3o7Ooonf[o0>7o00Sooo]Z00Co0?ldoookJ_l0odko
0?l^0ooonfX00ol0R?oooo]Zo`2Yo`02oookJP04o`04oooonf[ooo]Zo`3Do`[ooo]Z00?ooh40oook
J_oonfX02_oonfX00ooo02gooo]ZoookJP1KoookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3Zoook
J_oonfX01OoonfX00ooo5P3ooi80oookJP02oookJP03ool0o?oonf[ooo]Z00;ooo]Z00[o603oool6
0?oonf[ooo]Zon_o0?oo0?Kooo]Zo`2Voooonf[oZ03o0_oonfX01?oo0?Wo07OooookJ_ooK003oook
JP04oc_o0?oonf[ooo]Zo`3ko`;ooo]Z00Ooo`<0oookJ_oonf[oo`3Mo`2Soonco`3oW`3o00?ooo]Z
00Ko0?oNoookJ_oonf[oo`1/oookJ_m=0?l2oookJP06of40oooonf[ooo]ZoookJ_l0oi3o0?nB1Ooo
nfX01OmX0?oooo]ZoookJ_oonf[o603o00;ooo]Z00?ooi00oookJ_oonfX01?oonfX00ooo_P3ooo]Z
og00o`03oookJP05oomG0?oonf[ooo]ZoookJ_oo02d02ooonfX01ol0e?oo00CooookJ_l0R?oooo]Z
o`3oC_l0oc@01?oonfX00ol0o`So0?lMoookJP02oookJP06ool0NOoonf[ooo]Zoa00oooonf[oT_l0
1?oonfX00ol0oe_ooo]ZoookJP03oookJP03obH0oooonf[ooo]Z00Cooo]Z00Oo4P3ooookJ_oonf[o
oo]Zo`3Loooonf[ooe80013ooo]Z00?oo`3foookJ_l000000ol00004oookJP03ok?o0?oonf[ooo]Z
00Kooo]Z1OmQ0?l8oookJPGoH@3o2_oonfX00onco`3ooo]ZoookJP0<oookJP03ool0m_oonf[ooo]Z
01cooo]Z00Oooe80oookJ_oonf[o02[oo`3Loooonf[o0?oO00Gooo]Z00?o4P3oooo:0?oonfX02_oo
nfX00olV0?oooo]ZoookJP0;oookJP06o`3oFooonf[ooo]Zo`3o/?oonf[o033o0ooonfX01Ol60?oo
oo]Zoi;o0?oonf[o403o00Cooo]Z00Coo`1AoookJ_oonf[oo`1i1_oonfX01_l0oe?ooo]ZoookJ_l0
o`So0?lMo`3Qo`Wooo]Z00?o0?ldoookJ_l0odh01?oonfX00ol0R?oooo]Zo`2Yo`02oookJP03o`04
oooonf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP0ToookJP00>Ooo
nfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Gooo]Z00GooaH0oookJ_ooTP3ooo]Z
ool0o005oookJP09oaP0oooonf[oogT0oookJ_o[o`3ooo]ZodCo0?oonf[oZ03o00?ooo]Z00Goo`3i
oookJ_l0Moooof`0o`3oVP02oookJP04oc_o0?oonf[ooo]Zo`3ko`;ooo]Z1Ooo00000onco`3oo`00
oomi0003oookJP08o`3og_oonf[ooo]Zool0K?oonf[oC@3oof40ool0odD2oookJP;oobP000?ooo]Z
o`3oT_oonfX01?oonfX01OmX0?oooo]ZoookJ_lH0?ooolT000Coo`001OoonfX00ooo_P3o0?l5og00
o`02oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX02?oonfX01ol0e?oooo]Zoook
J_l0R?oooo]Zo`3oC_l0oc@01?oonfX01_oo003ooo]ZoookJ_oonf[oo`00oolX00?ooo]Z00?o403o
oi;o0?oo00001_oo0003oookJP03obH0oooonf[ooo]Z00Gooo]Z2OooN@0;oookJPCoolT000?ooo]Z
o`000?l000000_l000000ooonf[o/ol0ok?o0002oookJPcoo`001?oonfX>oolX00Kooo]Z0_nco`0>
oookJP03ool0m_oonf[ooo]Z01[ooo]Z0ooob@001?l0:_oooo]Zo`3LoooonfX2ool000KoogT000?o
o`00oomi0?oonfX02?oonfX00olV0?oooo]ZoookJP09oookJPOoogT01?oonfX01Ooo:03ooo]Zoi;o
0?oonf[o403o00Cooo]Z00Coo`1AoookJ_l0[Oooo`1i1OoonfX01ol0oe?ooo]ZoookJ_oonf[o0?lM
oookJ_l0hOl02?oonfX01?l0ocCooo]Zo`3oC_l0obh3oookJP03o`28oooonf[o0:Wo00;ooo]Z00Co
00CooookJ_oonf[o0=Co2_oonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z05[ooo]Z
00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP06oookJP05oolF0?ooTP3ooo]ZoookJ_oo
0?`01OoonfX02OlH0?ooo`H0oookJ_oonf[ojol0ool0m_oonf[o0:KoojP0o`02oookJP05ool0nOoo
nf[o07OooookJ_ooK0000ooonfX01?lko`3ooo]ZoookJ_l0nol2oookJP07ool30?oonf[oo`3Moook
J_l0Xooo/ol0oil0o`03oookJP08o`3og_oonf[ooo]Zool0K?oonf[oC@3ooookJ_mQ0?l4oookJP03
o`3oT?l0oi;ooo]Z00Cooo]Z00GoJ03ooookJ_oonf[ooo]ZoaP0o`02oookJP03oon@0?oonf[ooo]Z
00Cooo]Z00?ookh0o`3o1Om`0?l00ooonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00[ooo]Z00Co0=Co
o`04oooonf[o08So0_oonfX00ol0odkooo]ZoookJP02oookJP03o`3o2?l0oagooo]Z00;ooo]Z00Oo
o`1ioookJ_oonf[ooo]Zoa00oooonf[oT_l000?ooo]Z00?o0?mKoookJ_oonfX00ooonfX00olPo`3o
9P3ooookJP05oookJP06oa80oooonf[ooo]Zo`3Loooonf[ooe804?oonfX00ooo0?Kooo]ZoookJP04
o`0000;ooo]Z0_nco`07oookJP;oH@3o4_oonfX3of40o`Sooo]Z00?o/ol0oookJ_oonfX03?oonfX0
0ooo0?Kooo]ZoookJP0KoookJP07o`3o<oooDP3ooo]Zo`0Zoooonf[o0=coo`3og`05oookJP03oa80
oooonf[oolX000[ooo]Z00?o9P3oob3o0?oonfX02ooonfX01_l0oe_ooo]ZoookJ_l0ok3ooo]Zo`0`
o`?ooo]Z00?o1P3ooookJ_nBo`000_oonfX01Ol@0?oooo]ZoookJ_oonf[oo`1A00;ooo]Z00?o0:go
ool0NOoonfX01?oonfX01_l0oe?ooo]ZoookJ_l0o`So0?lMo`3Qo`Wooo]Z00?o0?ldoookJ_l0odh0
1?oonfX00ol0R?oooo]Zo`2Yo`02oookJP03o`04oooonf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX0
2_oonfX00ooo02gooo]ZoookJP0ToookJP00>OoonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oo
nf[ooo]Z00Gooo]Z00GooaH0oonB0?oonf[ooo]Zool0o005oookJP06oaP0ooooN@3ooo]ZoookJ_o[
o`3oA?l00_oonfX02onX0?oooo]ZoookJ_oonf[oo`3io`1goooonf[oof`0o`3oV_oonf[o>ol000?o
oo]Z00?o0?_ooookJ_oonfX01?oo00001?nco`3oo`00ool00?ooN@02oookJP09o`3og_oonf[ooo]Z
oookJ_oo06cooo]Zodd0oomQ0?oo0?m500;ooo]Z0_oo:0000ooonf[o0?nBoookJP03oookJP06ofP0
oooonf[ooo]ZoookJ_lH0?ooolT01?oo0005oookJP03oonn0?m`0?oooo]Z00;ooo]Z00?ooeL0oook
J_oonfX00_oonfX00ooo02gooo]ZoookJP07oookJP04o`3Dool01?oooo]Zo`28o`;ooo]Z00?o0?m>
o`3o=?oonfX00ooonfX00ooo003ooo]ZoookJP02oookJP05oolX0?oonf[ooo]ZoookJ_l@0?l02?oo
0002oookJP03obH0oooonf[ooo]Z00Gooo]Z00?o4P3ooookJ_oonfX01oooN@09oookJPGoolT00_oo
nfX3o`0000;oobP01?oonfX>ool000Oooo]Z2_oo:007oookJP03ok?o0?oonf[ooo]Z00_ooo]Z00?o
o`3foookJ_oonfX06ooonfX2ooo90006o`0Zoooonf[ooo]Zo`3Loooonf[oo`001_ooN@000ooo003o
ogT0oookJP08oookJP03obH0oolPo`3ooo]Z00Oooo]Z2OooN@002Ol0<?oooo]ZoookJ_oonf[oobP0
oookJ_nBo`3ooo]Zoa00o`04oookJP05ool0DOoonf[o0:gooookJ_oo07T01?oonfX01ol0oe?ooo]Z
oookJ_oonf[o0?lMoookJ_l0hOl02?oonfX01?l0ocCooo]Zo`3oC_l0obh3oookJP03o`28oooonf[o
0:Wo00;ooo]Z00Co00CooookJ_oonf[o0=Co2_oonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooo
nf[ooo]Z05[ooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP06oookJP05oonB0?oo
nf[ooo]ZoookJ_oo0?`01OoonfX01Ooo1P3ooo]ZoookJ_oonf[ojol000;ooo]Z00Ko0:KoojP0oooo
nf[ooo]Zool0nOl0Mol2oookJP04oom/0?oonf[ooo]Zoc_o00;ooo]Z00[o0?_ooookJ_oonf[ooo]Z
ool30?oonf[oo`3MoookJ_nco`3oW`3o0ooonfX02Ol0omkooo]ZoookJ_oonf[oo`1/oookJ_m=0?oo
oo]Zof40o`03oookJP03o`3oT?oonf[o0?nB00Cooo]Z00SoJ03ooookJ_oonf[ooo]ZoaP0oooVo`3o
oo]Zoon@00Oooo]Z00?ookh0o`3o1Om`0?l00ooonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00[ooo]Z
00Oo0=Coo`04oooonf[o08SooookJ_l0odko0?ld00Cooo]Z00?o0?l8o`3o7OoonfX00_oonfX01_oo
07Wooo]ZoookJ_oonf[o403ooi;o00?ooo]Z00?o0?mKoookJ_oonfX01?oonfX00olV0?oooo]Zoook
JP04oookJP04oa80oooonf[ooo]Zo`3Lo`;ooo]Z00?ooe80oookJ_oonfX03OoonfX01?oo0?Kooo]Z
oookJ_oonfX4o`0000;o/ol08?oonfX3of40o`Kooo]Z00?o/ol0oookJ_oonfX02ooonfX00ooo0?Ko
oo]ZoookJP0KoookJP08o`3o<oooDP3ooo]Zo`0Zoooonf[o0=cooookJ_l0oml4oookJP03oa80oooo
nf[oolX000_ooo]Z00?o9P3ooookJ_oonfX02_oonfX01_l0oe_ooo]ZoookJ_l0ok3ooo]Zo`0`o`?o
oo]Z00?o1P3ooookJ_nBo`000_oonfX01Ol@0?oooo]ZoookJ_oonf[oo`1A00;ooo]Z00?o0:goool0
NOoonfX01?oonfX01_l0oe?ooo]ZoookJ_l0o`So0?lMo`3Qo`Wooo]Z00?o0?ldoookJ_l0odh01?oo
nfX00ol0R?oooo]Zo`2Yo`02oookJP03o`04oooonf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02_oo
nfX00ooo02gooo]ZoookJP0ToookJP00>OoonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[o
oo]Z00Gooo]Z00GooaH0oonB0?oonf[ooo]Zool0o005oookJP09oaP0ooooN@3ooo]ZoookJ_o[o`3o
A?l0oookJ_l0Y_ooZ03o00?ooo]Z00Coo`3io`1gooooK03o0?nJ0_oonfX01?lko`3ooo]ZoookJ_l0
nol2oookJPGoo`0000Co/ol0ool00?oo003oogT00_oonfX01?l0omkooo]ZoookJ_oo06`2oookJP04
odd0oomQ0?oo0?m5oookJP?oobP000?o0?nBoookJ_oonfX00ooonfX01OmX0?oooo]ZoookJ_oonf[o
603o00Goo`001?oonfX00ooo_P3ooo]Zog00o`02oookJP03oomi0?oonf[ooo]Z00;ooo]Z00?oo`0]
oookJ_oonfX02?oonfX01?l0e?oooo]ZoookJ_l0R?l2oookJP03o`3oC_oonf[ooo]Z00;ooo]Z00?o
o`00o`3o2?oonfX00_oonfX01Ooo:03ooo]ZoookJ_oonf[o403o00Woo`000_oonfX00olV0?oooo]Z
oookJP04oookJP05oa80oooonf[ooo]ZoookJ_l0g?l01OooN@09oookJPKoolT00_oonfX00ol0003o
obP0oolX0002oolX00Cooo]Z4?oo0008oookJP?oobP000?ooo]ZoolX0?oo:0000_oo:007oookJP03
ok?o0?oonf[ooo]Z00_ooo]Z00?oo`3foookJ_oonfX06ooonfX02?oob@3ooo]Zo`0Zoooonf[o0=co
oookJ_l0omoooo]Z1OooN@000ooo003oogT0oookJP09oookJP03obH0oooonf[ooo]Z00Kooo]Z2Ooo
N@002Ol0<?oooo]ZoookJ_oonf[oobP0oookJ_nBo`3ooo]Zoa00o`04oookJP05ool0DOoonf[o0:go
oookJ_oo07T01OoonfX01?l0oe?ooo]ZoookJ_l0oad2oookJP03o`3Qoooonf[ooo]Z00Gooo]Z00Co
0?ldoookJ_oonf[o0?m>0ooonfX01_l0R?oooo]ZoookJ_l0ZOoooo]Zo`04o`;ooo]Z00?o0=Cooook
J_oonfX02?oonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z05[ooo]Z00?o07?ooook
J_oonfX04_oonfX00ooo0>[ooo]ZoookJP06oookJP05oonB0?oonf[ooo]ZoookJ_oo0?`01?oonfX0
0olH0?ooo`H0oookJP02oookJP05on_o0?oonf[o0:KooookJ_nX0?l00_oonfX01?oo0?Wo07Oooook
J_ooK003oookJP04oc_o0?oonf[ooo]Zo`3ko`;ooo]Z00Ooo`<0oookJ_oonf[oo`3MoookJ_nco`3o
W`3o00?ooo]Z00Co0?oNoookJ_oonf[oo`1/0_oonfX00om=0?oooo]Zof40o`03oookJP03o`3oT?l0
oi;ooo]Z00Cooo]Z00SoJ03ooookJ_oonf[ooo]ZoaP0ool0M?oooo]Zoon@00Kooo]Z00?ookh0oook
J_m`0?l00ooonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00[ooo]Z00Co0=Coo`04oooonf[o08So0_oo
nfX00ol0odkooo]ZoookJP03oookJP05o`3o7Ooonf[ooo]ZoookJ_oo07T00ooonfX00ol@0?oooo]Z
oi;o0003oookJP03o`3oFooonf[ooo]Z00Cooo]Z00?o9P3ooookJ_oonfX00ooonfX01olB0?oooo]Z
oookJ_oonf[o0=cooookJ_ooDP003ooonfX00ooo0?Kooo]ZoookJP02oookJP?o000000?o/ol0o`00
0?oonfX08ooonfX00omQ0?oooo]ZoookJP04oookJP03ok?o0?oonf[ooo]Z00_ooo]Z00?oo`3foook
J_oonfX06ooonfX00ol0oc?ooe80o`0Zo`02oookJP03o`3Lool0omoooo]Z00Cooo]Z00?o4P3oooo:
0?oonfX02_oonfX00olV0?oooo]ZoookJP0:oookJP04o`3oFooonf[ooo]Zo`3o/0;ooo]Z00Ko033o
oookJ_oonf[o1P3ooookJ_nBo`02oookJP05oa00oooonf[ooo]ZoookJ_oo05400_oonfX00ol0[Ooo
o`1ioookJP04oookJP07o`3oDooonf[ooo]Zo`3o2?l0oagooo]Zo`3Qo`08oookJP04o`3o=?oonf[o
0?l^o`3oCP?ooo]Z00So08SooookJ_oonf[o0:WooookJ_l01?oooo]Zo`3Do`_ooo]Z00?ooh40oook
J_oonfX02_oonfX00ooo02gooo]ZoookJP0ToookJP00>?oonfX00ol0Looooo]ZoookJP0BoookJP03
ool0j_oonf[ooo]Z00Gooo]Z00?ooaH0oookJ_ooTP000_oonfX00ooo0?cooo]ZoookJP03oookJP08
oaP0ooooN@3ooo]ZoookJ_o[o`3oA?l0oookJ_nX0?l3oookJP05ool0nOoonf[o07Oooom/0?l0oiX0
0_oonfX01?lko`3ooo]ZoookJ_l0nol3oookJP05ool30?ooN@3oo`00ool00?nco`000_oo00001?oo
N@3ooo]ZoookJ_l0omh2oookJP05ool0K?oonf[oC@3ooookJ_mQ0?l00_oonfX3oolX0003o`3oT_oo
nf[ooo]Z00?ooo]Z00GoJ03ooookJ_oonf[o603oooo90005ool000Cooo]Z00?ookh0og00oooonfX0
0_oonfX00oooN@3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00So0=Coo`04oooonf[o
oo]Zo`28oooonf[o0?m>o`3o=0Cooo]Z00?oo`00oookJ_oonfX00_oonfX01ooo:03ooo]ZoookJ_oo
nf[o403ooi;o0?oonfX01ooo00000ooonf[o9P3ooookJP06oookJP05oa80oooonf[ooo]Zo`3Loooo
nfX01OooN@07oookJPOoolT00_oonfX5oolX00Kooo]Z0ooo0002oookJPCoo`001olH0?l2ool000Co
oo]Z1Ooo:004oookJP03of40oooonf[ooo]Z00Gooo]Z00?o/ol0oookJ_oonfX02_oonfX00ooo0?Ko
oo]ZoookJP0KoookJP08oomB0?oonf[o02[ooookJ_l0g?oooo]Zo`3ogooonfX5oomi0003ool00?oo
N@3ooo]Z00Wooo]Z00?o9P3ooookJ_oonfX01ooonfX8oomi0009o`0`oooonf[ooo]ZoookJ_oo:03o
oo]Zoi;o0?oonf[o403o00Cooo]Z00Goo`1AoookJ_l0[Ooooo]Zool0N@05oookJP04o`3oDooonf[o
oo]Zo`3o7@;ooo]Z00?o0>7ooookJ_oonfX01OoonfX01?l0ocCooo]ZoookJ_l0odh3oookJP06o`28
oooonf[ooo]Zo`2Yoooonf[o00Co0_oonfX00ol0e?oooo]ZoookJP08oookJP03oon10?oonf[ooo]Z
00_ooo]Z00?oo`0]oookJ_oonfX0F?oonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z
00Kooo]Z00?ooaH0oonB0?oonfX00_oonfX00ooo0?cooo]ZoookJP02oookJP03oaP0oooo1P3ooo]Z
00;ooo]Z00Cojol0oookJ_l0Y_ooZ03o0ooonfX01?oo0?Wo07OooookJ_ooK003oookJP04oc_o0?oo
nf[ooo]Zo`3ko`;ooo]Z00Ooo`<0oookJ_mi0?ooo`3MoookJ_nco`3oW`3o00?ooo]Z00Wo0?oNoook
J_oonf[oo`1/oookJ_m=0?oooo]Zo`3oAOmQ0?l00ooonfX00ol0oi3o0?nBoookJP04oookJP05ofP0
oooonf[ooo]ZoookJ_lH0?l00_oonfX00oooT03ooo]ZoookJP04oookJP03oonn0?l0o`GoL03o00?o
oo]Z00GooeL0oookJ_oonf[ooo]Zool0;@0:oookJP04o`3Dool01?oooo]Zo`28o`;ooo]Z00?o0?m>
oookJ_oonfX00_oonfX00ol0o`So0?lMoookJP02oookJP06ool0NOoonf[ooo]ZoookJ_l@0?ooT_l0
0ooonfX00ol0oe_ooo]ZoookJP04oookJP03obH0oooonf[ooo]Z00Cooo]Z00Ko4P3ooookJ_oonf[o
0=cooookJ_ooDP0?oookJP03ool0m_oonf[ooo]Z00?ooo]Z0_l000000onco`3o0000oookJP0>oook
JPOo603o3ooonfX00omQ0?oooo]ZoookJP05oookJP03ok?o0?oonf[ooo]Z00[ooo]Z00?oo`3foook
J_oonfX06ooonfX01ol0oc?ooe80oookJ_l0:_oooo]Zo`3Lool0oml01OoonfX00olB0?ooolX0oook
JP0:oookJP03obH0oooonf[ooo]Z00_ooo]Z00?o0?mKoookJ_l0ok000_oonfX01_l0<?oooo]Zoook
J_l60?oooo]Zoi;o00;ooo]Z00Go403ooookJ_oonf[ooo]Zool0D@02oookJP03o`2]oooo07Wooo]Z
00Cooo]Z00Oo0?mCoookJ_oonf[o0?l8o`3o7Ooonf[o0>7o00Sooo]Z00Co0?ldoookJ_l0obko0?m>
0ooonfX02?l0R?oooo]ZoookJ_l0ZOoooo]Zo`04oooonf[o0=Co2ooonfX00oooP@3ooo]ZoookJP0;
oookJP03ool0;Ooonf[ooo]Z02?ooo]Z000hoookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3Zoook
J_oonfX01OoonfX00ooo5P3ooo]ZoonB0002oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Wo603ooook
J_ooN@3ooo]Zon_o0?oonf[oA?l0oookJ_nX0?l00ooonfX01Ooo0?Wo07OooookJ_ooK03o0?nJ00;o
oo]Z00Co>ol0oookJ_oonf[o0?_o0ooonfX01Ooo0`3oogT0oomi0?oo003o/ol000;oo`0000?oogT0
oookJ_ooN@000ooonfX01_oo06cooo]Zodd0oomQ0?ooobP0oookJPCoobP000?o0?nBoookJ_oonfX0
0ooonfX01OmX0?oooo]Zool00?lH0?ooolT000Goo`000ooonfX00ooo_P3ooo]Zog00o`02oookJP;o
ogT01?oonfX00ooo02gooo]ZoookJP07oookJP04o`3Dool01?oooo]Zo`28o`;ooo]Z00?o0?m>oook
J_oonfX00_oonfX00ooo003o0?l8oookJP02oookJP06oolX0?oonf[ooo]ZoookJ_l@0?ooT_l01?oo
nfX4ool000;ooo]Z00?o9P3ooookJ_oonfX01?oonfX01_lB0?oooo]ZoookJ_l0g?oooo]Zoomi00;o
oo]Z0oooN@05oookJPWoolT01_oo:0000ol0003ooo]ZoookJP02oookJP;oobP000Coo`00oookJ_oo
nf[ooo]Z1OlH0?l7ool000?o603o00?oo`00oookJ_oo:0001Ooo:005oookJP03of40oooonf[ooo]Z
00Cooo]Z00?o/ol0oookJ_oonfX02ooonfX00ooo0?Kooo]ZoookJP0JoookJP03oomB0?oonf[o02[o
00;ooo]Z00Co0=coo`3ogooonf[ooo]Z1?ooN@000ooo003oogT0oookJP09oookJP03obH0oooonf[o
oo]Z00Oooo]Z2?ooN@001ol0<?oooo]ZoookJ_oonf[oobP0oookJ_nBo`000_oonfX02Ol@0?oooo]Z
oookJ_oonf[oo`1AoookJ_l0[Ooooo]Zool0N@05oookJP04o`3oDooonf[ooo]Zo`3o7@;ooo]Z00?o
0>7ooookJ_oonfX01_oonfX00ol0ocCooo]Zo`3oCP03oookJP06o`28oooonf[ooo]Zo`2Yoooonf[o
00Co0_oonfX00ol0e?oooo]ZoookJP08oookJP03oon10?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oo
nfX0F?oonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oonB0?oo
nfX00_oonfX00ooo0?cooo]ZoookJP02oookJP09oaP0oooo1P3ooo]ZoookJ_o[o`3oo`3foookJ_l0
Y_ooZ03o00;ooo]Z00Goo`3io`1goooonf[ooo]Zoom/0003oookJP04oc_o0?oonf[ooo]Zo`3ko`;o
oo]Z00Ooo`<0oookJ_mi0?ooo`3Mo`2Soonco`3oW`3o00;ooo]Z00Wo0?oNoookJ_oonf[ooo]Zool0
K?oonf[oC@3ooookJ_mQ0?l01?oonfX00ol0oi3o0?nBoookJP04oookJP07ofP0oooonf[ooo]ZoaP0
oooVo`3ooo]Zoon@0006oookJP04oonn0?oonf[o0?l5og00o`?ooo]Z00GooeL0oookJ_oonf[ooo]Z
ool0;@0:oookJP03o`3Dool01?oo08So00;ooo]Z00?o0?m>oookJ_oonfX00ooonfX01Ol0oagooo]Z
oookJ_oonf[oo`1i00?ooo]Z00?o403ooookJ_nBo`000ooonfX00ol0oe_ooo]ZoookJP04oookJP03
obH0oooonf[ooo]Z00?ooo]Z00Ko4P3ooookJ_oonf[o0=cooookJ_ooDP0?oookJP03ool0m_oonf[o
oo]Z00Cooo]Z00Co0000ok?o0?l0003o00002_oonfX5oaP0o`Cooo]Z0ol0M?l4oaP0o`cooo]Z00?o
H@3ooookJ_oonfX01?oonfX00onco`3ooo]ZoookJP0;oookJP03ool0m_oonf[ooo]Z01[ooo]Z00Oo
0?lcoomB0?oonf[o02[ooookJ_l0g?oo0?oO00Gooo]Z00?o4P3oooo:0?oonfX02_oonfX00olV0?oo
8?l0oookJP0;oookJP03o`3oFooonf[o0?n`00;ooo]Z00Ko033ooookJ_oonf[o1P3ooookJ_nBo`03
oookJP04oa00oooonf[ooo]Zool0D@;ooo]Z00?o0:goool0NOoonfX01?oonfX01ol0oe?ooo]Zoook
J_l0o`So0?lMoookJ_l0hOl02?oonfX01?l0ocCooo]Zo`3o;_l0odh3oookJP08o`28oooonf[ooo]Z
o`2Yoooonf[o00CooookJ_l0e?l;oookJP03oon10?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX0
8ooonfX003Sooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP05oookJP03oolF0?oo
nf[ooi8000;ooo]Z00?oo`3loookJ_oonfX00_oonfX01_lH0?ooogT0oookJ_oonf[ojol0odCo00;o
oo]Z00_oZ03ooookJ_oonf[ooo]Zool0nOl0Mooooo]Zoom/0?l0oi[ooo]Zoc_o0003oookJP04o`3k
oooonf[ooo]Zool300;oogT000?oo`00oomi0?nco`000oooN@000ooonf[oogT0oookJP02oookJP06
ool0K?oonf[oC@3oof40oooo:03ooo]Z1?oo:0000ol0oi;ooo]ZoookJP02oookJP06ofP0oooonf[o
oo]ZoookJ_lH0?oo07Co1Ooo0003oookJP03oonn0?oonf[oL03o00;ooo]Z0_ooN@03oookJP03ool0
;Ooonf[ooo]Z00Oooo]Z00Go0=Coo`04oooonf[ooo]Zo`28o`02oookJP03o`3oC_oonf[ooo]Z00;o
oo]Z00?oo`00oookJ_oonfX00_oonfX01_oo:03ooo]ZoookJ_oonf[o403ooi;o00?ooo]Z00Ooo`00
oookJ_oonf[ooo]Zool00?oonf[o9P3o00Kooo]Z00Ooo`00oookJ_oonf[ooo]Zo`3Loooonf[ooe80
00?ooo]Z00?oogT0oookJ_oonfX00ooonfX8ooo900SoobP000?o0000oookJ_oonfX00_oonfX3oolX
00?o603o00?oobP0ool00?oo00003?oo0003oaP0o`KoobP000?ooo]Zool00?oo00000_oonfX00omQ
0?oooo]ZoookJP04oookJP03ok?o0?oonf[ooo]Z00[ooo]Z00?oo`3foookJ_oonfX06_oonfX00ooo
DP3o0?lco`0Zo`02oookJP04o`3Loooonf[o0?oOoookJPCoogT000?oo`00oomi0?oonfX02OoonfX0
0olV0?oo8?l0oookJP08oookJPOoogT000Oo033ooookJ_oonf[ooo]ZoolX0?oonf[oT_l000;ooo]Z
00Wo403ooookJ_oonf[ooo]Zool0DOoonf[o0:gooookJ_oo07T01OoonfX01?l0oe?ooo]ZoookJ_l0
oad2oookJP03o`3Qoooonf[ooo]Z00Kooo]Z00?o0?ldoookJ_l0odh00ooonfX01_l0R?oooo]Zoook
J_l0ZOoooo]Zo`04o`;ooo]Z00?o0=CooookJ_oonfX02?oonfX00oooP@3ooo]ZoookJP0;oookJP03
ool0;Ooonf[ooo]Z05Sooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP06oookJP05
oolF0?ooTP3ooo]ZoookJ_oo0?`01OoonfX01Ooo1P3ooo]ZoookJ_oonf[ojol000;ooo]Z00Ko0:Ko
ojP0oooonf[ooo]Zool0nOl0Mol2oookJP04oom/0?oonf[ooo]Zoc_o00;ooo]Z00Co0?_ooookJ_oo
nf[oo`<00_oonfX01?oo0=gooo]Zo`2Soonco`03oookJP09o`3og_oonf[ooo]ZoookJ_oo06cooo]Z
odd0oooonf[oH@3o00?ooo]Z00?o0?n@oookJ_l0oi801?oonfX02?mX0?oooo]ZoookJ_oonf[o603o
o`1doooonf[ooi001_oonfX00ooo_P3ooo]Zog00o`03oookJP05oomG0?oonf[ooo]ZoookJ_oo02d0
2_oonfX01?l0e?oo00CooookJ_l0R?l2oookJP03o`3oC_oonf[ooo]Z00?ooo]Z00Go0?lMoookJ_oo
nf[ooo]Zool0N@03oookJP03oa00oonBo`3ooo]Z00;ooo]Z00?o0?mKoookJ_oonfX01?oonfX00olV
0?oooo]ZoookJP03oookJP07oa80oooonf[ooo]ZoookJ_l0g?oooo]ZoomB000>oookJP03ool0m_oo
nf[ooo]Z00Gooo]Z00Co/ol0o`000?l0003o00001ooonfX3oaP0o`kooo]Z0_l0M?l3oaP0o`[ooo]Z
00?oH@3ooookJ_oonfX01?oonfX00onco`3ooo]ZoookJP0:oookJP03ool0m_oonf[ooo]Z01_ooo]Z
00?ooe80oookJ_l0:_l00_oonfX00ol0g?oo0?oOoookJP04oookJP03oa80oooobP3ooo]Z00[ooo]Z
00?o9P3ooookJ_oonfX02_oonfX01_l0oe_ooo]ZoookJ_l0ok3ooo]Zo`0`o`;ooo]Z00?o1P3ooook
J_nBo`000ooonfX01?l@0?oooo]ZoookJ_oo0542oookJP03o`2]oooonf[oo`1i00Cooo]Z00Oo0?mC
oookJ_oonf[o0?l8o`3o7Ooonf[o0>7o00Sooo]Z00Co0?ldoookJ_l0obko0?m>0ooonfX02?l0R?oo
oo]ZoookJ_l0ZOoooo]Zo`04oooonf[o0=Co2ooonfX00oooP@3ooo]ZoookJP0;oookJP03ool0;Ooo
nf[ooo]Z02?ooo]Z000hoookJP03o`1coooonf[ooo]Z017ooo]Z00?oo`3ZoookJ_oonfX01_oonfX0
1Ooo5P3ooi80oookJ_oonf[oo`3l00Gooo]Z00Ko603ooomi0?oonf[ooo]Zon_o0?m4o`02oookJP0;
ojP0oooonf[ooo]ZoookJ_oo0?Wo07OooookJ_ooK03o0?nJoookJ_lko`000ooonfX01?l0nooooo]Z
oookJ_oo0`02oookJP03ool00?nco`3oogT000GoogT00_oonfX01Ooo06cooo]Zodd0oooonf[oH@3o
00OoobP01?oonfX01OmX0?oooo]ZoookJ_lH0?ooi_l000;ooo]Z00Coo`00oookJ_oo003oo`000ooo
nfX01?oo_P3oL03oo`3o1OoonfX3oomi00?ooo]Z00?oo`0]oookJ_oonfX01ooonfX01?l0e?oo00Co
oookJ_l0R?l2oookJP03o`3oC_oonf[ooo]Z00;ooo]Z00?oo`00o`3o2?oonfX00_oonfX01ooo:03o
oo]ZoookJ_oonf[o403ooookJ_nBo`000ooonfX00ooo003ooo]ZoookJP03oookJP03obH0oooonf[o
oo]Z00Cooo]Z00Koo`00oookJ_oonf[o0=cooookJ_ooDP09oookJPOoolT02Ooo:002o`0000Cooo]Z
00?oobP0oaP0oolH0?l01ooo:004ool000Oooo]Z0ooo:002oaP0o`CoobP00ooo0003oookJP03of40
oooonf[ooo]Z00Cooo]Z00?o/ol0oookJ_oonfX02_oonfX00ooo0?Kooo]ZoookJP0JoookJP07oomB
0?l0:_oooo]ZoookJ_l0g?oooo]Zo`3og`02oookJP?oogT000?oo`00oomi0?oonfX02_oonfX00olV
0?oooo]ZoookJP07oookJPOoogT000Oooo]Zo`0`oooonf[ooo]ZoolX0?oonf[oT_l000;ooo]Z00Oo
403ooookJ_oonf[ooo]Zool0DOoonf[o0:go00;ooo]Z00?oo`1ioookJ_oonfX00_oonfX01ol0oe?o
oo]ZoookJ_l0oago0?l8oookJ_l0hOl02?oonfX00ol0ocCooo]Zo`3oCP03oookJP06o`28oooonf[o
oo]Zo`2Yoooonf[o00Co0_oonfX00ol0e?oooo]ZoookJP08oookJP03oon10?oonf[ooo]Z00_ooo]Z
00?oo`0]oookJ_oonfX0F?oonfX00ol0Looooo]ZoookJP0AoookJP03ool0j_oonf[ooo]Z00Oooo]Z
00Gooi80oookJ_oonf[ooo]Zool0o005oookJP05ool60?oonf[ooo]ZoookJ_o[o`000_oonfX01_l0
Y_ooZ03ooookJ_oonf[oo`3io`1go`;ooo]Z00Coof`0oookJ_oonf[o>ol00_oonfX01?l0nooooo]Z
oookJ_oo0`02oookJP04ool0gOoonf[o/ol0oil0o`?ooo]Z00Ko0?oNoookJ_oonf[oo`1/oookJ_m=
0?l2oookJP07of40oooonf[ooo]ZoookJ_l0oi3ooo]Zo`3oTP04oookJP05ofP0oooonf[ooo]Zoook
J_lH0?l00_oonfX00oooT03ooo]ZoookJP04oookJP03oonn0?oonf[oL03o00?ooo]Z00GooeL0oook
J_oonf[ooo]Zool0;@0:oookJP07o`3Dool01?oooo]Zo`28oooonf[o0?ldo`3oCP04oookJP05o`3o
7Ooonf[ooo]ZoookJ_oo07T00ooonfX00ol@0?oooo]Zoi;o0003oookJP03o`3oFooonf[ooo]Z00Co
oo]Z00?o9P3ooookJ_oonfX00ooonfX01_lB0?oooo]ZoookJ_l0g?oooo]ZoomB00kooo]Z00?oo`3f
oookJ_oonfX01OoonfX00onco`3o0000o`000002o`0000Gooo]Z0_lH0?lEoookJP03o`1doolH0?oo
oo]Z00Wooo]Z00?oH@3ooookJ_oonfX01?oonfX00onco`3ooo]ZoookJP0:oookJP03ool0m_oonf[o
oo]Z01[ooo]Z00?o0?lcoomB0?l0:_l00_oonfX00ol0g?oo0?oOoookJP04oookJP03oa80oooobP3o
oo]Z00[ooo]Z00?o9P3ooookJ_oonfX02_oonfX01?l0oe_ooo]ZoookJ_l0ok02oookJP05o`0`oooo
nf[o1P3ooookJ_nBo`000ooonfX02Ol@0?oooo]ZoookJ_oonf[oo`1AoookJ_l0[Ooooo]Zool0N@04
oookJP07o`3oDooonf[ooo]ZoookJ_l0oagooo]Zo`3Qo`08oookJP04o`3o=?oonf[o0?l^o`3oCP?o
oo]Z00So08SooookJ_oonf[o0:WooookJ_l01?oooo]Zo`3Do`_ooo]Z00?ooh40oookJ_oonfX02ooo
nfX00ooo02gooo]ZoookJP0SoookJP00>?oonfX00ol0Looooo]ZoookJP0AoookJP03oomi0?oonf[o
oo]Z00Kooo]Z00GooaH0oonB0?oonf[ooo]Zool0o005oookJP09oaP0ooooN@3ooo]ZoookJ_o[o`3o
A?l0oookJ_l0Y_ooZ03o00;ooo]Z00Goo`3ioookJ_l0Mooooo]Zoom/0002oookJP04oc_o0?oonf[o
oo]Zo`3ko`?ooo]Z00Koo`<0oookJ_mi0?ooo`00ok?o0?nO0?l3oookJP;oogT00_oonfX01Ooo06co
oo]Zodd0oooo:03oH@3o00OoobP01?oonfX01OmX0?oooo]ZoookJ_lH0?ooi_l000;ooo]Z00?oo`00
oookJ_oonfX00ooonfX00ooo_P3ooo]Zog00o`02oookJP?oogT00ooonfX00ooo02gooo]ZoookJP07
oookJP04o`3Doooonf[ooo]Zo`28o`;ooo]Z00?o0?m>oookJ_oonfX00_oonfX00ooo003o0?l8oook
JP02oookJP06ool0NOoonf[ooo]ZoookJ_l@0?ooT_l00ooonfX00ooo003ooo]ZoookJP03oookJP03
obH0oooonf[ooo]Z00Cooo]Z0_oo0002oookJP03o`3Loooonf[ooe8000[ooo]Z1?oob@0:oolX00?o
00000ooonfX2oaP0o`goobP02OoonfX3oolX0003oaP0oooo:03oo`0000Goo`000ooonfX00omQ0?oo
oo]ZoookJP03oookJP03ok?o0?oonf[ooo]Z00[ooo]Z00?oo`3foookJ_oonfX06_oonfX00oooDP3o
oo]Zo`0Zo`02oookJP03o`3Lool0omoooo]Z00;ooo]Z0oooN@05ool000Oooo]Z00?o9P3ooookJ_oo
nfX02?oonfX6oomi0007oookJ_l0<?oooo]ZoookJ_oo:03ooo]Zoi;o0002oookJP07oa00oooonf[o
oo]ZoookJ_oo057ooo]Zo`2]o`02oookJP03ool0NOoonf[ooo]Z00;ooo]Z00Oo0?mCoookJ_oonf[o
0?lMo`3o2?oonf[o0>7o00Sooo]Z00?o0?ldoookJ_l0odh01?oonfX00ol0R?oooo]Zo`2Yo`02oook
JP03o`04oooonf[o0=Co00[ooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP1Hoook
JP03o`1coooonf[ooo]Z017ooo]Z00?oo`3ZoookJ_oonfX01ooonfX01OooTP3ooo]ZoookJ_oonf[o
o`3l00Cooo]Z00?o603oool60?oonfX00_oonfX03?o[o`3ooo]Zo`2Voooonf[oZ03ooookJ_oo0?Wo
oo]Zo`1goooonf[o0?nJoom/00;ooo]Z00Co>ol0oookJ_oonf[o0?_o0_oonfX01ooo0`3ooo]ZogT0
oooo0=gooo]Zok?o0?nO0?l00_oonfX02_oMo`3o0?oNoookJ_oonf[oo`1/oookJ_m=0?oooo]Zo`3o
AOmQ0?l3oookJP03o`3oT?l0oi;ooo]Z00Cooo]Z00GoJ03ooookJ_oonf[ooo]ZoaP0o`02oookJP03
oon@0?oonf[ooo]Z00?ooo]Z00Cookh0oookJ_l0o`GoL03o0ooonfX01OooE`3ooo]ZoookJ_oonf[o
o`0]00[ooo]Z00?o0=CooookJ_l0R?l00_oonfX00ol0odkooo]ZoookJP03oookJP05o`3o7Ooonf[o
oo]ZoookJ_oo07T00ooonfX00ol@0?oooo]Zoi;o0002oookJP03o`3oFooonf[ooo]Z00Cooo]Z00?o
9P3ooookJ_oonfX00ooonfX01olB0?oooo]ZoookJ_oonf[o0=cooookJ_ooDP003_oonfX00ooo0?Ko
oo]ZoookJP04oookJP03ok?o0?oonf[o000000?o00000ooonfX2oaP0oaWooo]Z0_lH0?l9oookJP03
of40oooonf[ooo]Z00?ooo]Z00?o/ol0oookJ_oonfX02_oonfX00ooo0?Kooo]ZoookJP0JoookJP03
o`3o<oooDP3o02[o00;ooo]Z00?o0=coo`3ogooonfX01?oonfX00olB0?ooolX0oookJP0:oookJP03
obH0oooonf[ooo]Z00[ooo]Z00Co0?mKoookJ_oonf[o0?n`0_oonfX01Ol0<?oooo]Zo`H0oooonf[o
T_l000?ooo]Z00Wo403ooookJ_oonf[ooo]Zool0DOoonf[o0:gooookJ_oo07T01OoonfX01_l0oe?o
oo]ZoookJ_l0oagooo]Zo`3Qo`Sooo]Z00Co0?ldoookJ_l0obko0?m>1?oonfX00ol0R?oooo]Zo`2Y
o`02oookJP03o`04ool0e?oooo]Z00[ooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02gooo]Zoook
JP0SoookJP00>?oonfX00ol0Looooo]ZoookJP0AoookJP03oomi0?oonf[ooo]Z00Gooo]Z00?ooaH0
oookJ_ooTP000_oonfX00ooo0?cooo]ZoookJP03oookJP08oomi0?oonf[ooo]Zon_o0?oonf[oA?l0
oookJ_nX0?l3oookJP07ool0nOl0Mooooo]Zoom/0?l0oi[ooo]Zoc_o0003oookJP04o`3koooonf[o
oo]Zool300;ooo]Z00?oN@3oool00?nco`000ooonfX3oomi00;ooo]Z00Coo`1/oookJ_m=0?ooH@3o
2?oo:004oookJP07ofP0oooonf[ooo]ZoaP0ool0M?oooo]Zool00006oookJP04oonn0?oonf[oL03o
oookJPCoogT00_oonfX00ooo02gooo]ZoookJP07oookJP05o`3Dool01?oooo]ZoookJ_l0R?l00_oo
nfX01_l0odkooo]ZoookJ_oonf[oo`00o`3o20?ooo]Z00Ooo`1ioookJ_oonf[ooo]Zoa00oooonf[o
T_l000?ooo]Z00?oo`00oookJ_oonfX00ooonfX00olV0?oooo]ZoookJP03oookJP;oo`000_oonfX0
0ol0g?oooo]ZoomB000<oookJP;oolT02_oo:004o`0000;ooo]Z00?o603ooookJ_oo:0003ooo:002
og00o`Kooo]Z0ooo:002oaP0o`Goo`001?oonfX00omQ0?oooo]ZoookJP03oookJP03ok?o0?oonf[o
oo]Z00Wooo]Z00?oo`3foookJ_oonfX06_oonfX00oooDP3ooo]Zo`0Zo`02oookJP04o`3Lool0omoo
oo]ZoookJPWoo`001ooonfX00olV0?oooo]ZoookJP08oookJPGoogT000?o0?n`oookJ_l0<?l00_oo
nfX01_oo:03ooo]ZoookJ_nBo`3ooo]Zoa00o`?ooo]Z00?oo`1AoookJ_l0[Ol00_oonfX00ooo07Wo
oo]ZoookJP02oookJP07o`3oDooonf[ooo]ZoookJ_l0oagooo]Zo`3Qo`08oookJP03o`3o=?oonf[o
0?m>00Cooo]Z00?o08SooookJ_l0ZOl00_oonfX00ol01?oooo]Zo`3Do`0;oookJP03oon10?oonf[o
oo]Z00[ooo]Z00?oo`0]oookJ_oonfX0F?oonfX00ol0Looooo]ZoookJP0AoookJP03ool0j_oonf[o
oo]Z00Kooo]Z00?ooaH0oonB0?oonfX00_oonfX00ooo0?cooo]ZoookJP02oookJP09ool60?oonf[o
oo]ZoookJ_o[o`3oo`3foookJ_l0Y_ooZ03o00;ooo]Z00Goo`3io`1goooonf[ooo]Zoom/0002oook
JP07oc_o0?oonf[ooo]ZoookJ_l0nooooo]Zool30002oookJP04ogT0oooo0=go01Oook?o00?ooo]Z
00Wo0?oNoookJ_oonf[ooo]Zool0K?oonf[oC@3ooookJ_mQ0?l01?oonfX00ol0oi3o0?nBoookJP04
oookJP07ofP0oooonf[ooo]ZoaP0ool0M?oooo]Zoon@0006oookJP03oonn0?oonf[oL03o00Cooo]Z
00CooeL0oookJ_oonf[oo`0]2_oonfX01?l0e?oo00CooookJ_l0R?l2oookJP03o`3oC_oonf[ooo]Z
00;ooo]Z00Go0?lMo`3o2?oonf[ooo]Zool0N@03oookJP03oa00oooonf[oT_l000?ooo]Z00?o0?mK
oookJ_oonfX00ooonfX00olV0?oooo]ZoookJP04oookJP06oa80oooonf[ooo]Zo`3Loooonf[ooe80
3_oonfX00ooo0?Kooo]ZoookJP04oookJP03ok?o0?oonf[ooo]Z00Co00000_oonfX00olH0?oooo]Z
oookJP06oookJPcoL03o2?oonfX00ol0M?oo603ooookJP08oookJP03of40oooonf[ooo]Z00?ooo]Z
00?o/ol0oookJ_oonfX02OoonfX00ooo0?Kooo]ZoookJP0JoookJP03o`3o<oooDP3o02[o00?ooo]Z
00?o0?oOoookJ_oonfX00ooonfX00olB0?ooolX0oookJP0:oookJP03obH0oooonf[ooo]Z00_ooo]Z
00?o0?mKoookJ_l0ok000_oonfX00ol0<?oooo]Zo`H0o`02oookJP04oi;o0?oonf[ooo]Zoa00o`?o
oo]Z00Goo`1AoookJ_l0[Ooooo]Zool0N@05oookJP06o`3oDooonf[ooo]Zo`3o7Ooonf[o0>7o2?oo
nfX01?l0ocCooo]Zo`3o;_l0odh4oookJP03o`28oooonf[o0:Wo00;ooo]Z00?o00Coo`3DoooonfX0
2ooonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z02?ooo]Z000goookJP03o`1coooo
nf[ooo]Z017ooo]Z0_ooN@07oookJP03oolF0?oonf[ooi8000;ooo]Z00?oo`3loookJ_oonfX00_oo
nfX01_lH0?ooogT0oookJ_oonf[ojol0odCo00;ooo]Z00_oZ03ooookJ_oonf[ooo]Zool0nOl0Mooo
oo]Zoom/0?l0oi[ooo]Zoc_o0003oookJP04o`3koooonf[ooo]Zool300;ooo]Z00?oo`00oookJ_nc
o`000ooonfX3oomi00;ooo]Z00Coo`1/oookJ_m=0?ooH@3o2?oo:003oookJP08ofP0oooonf[ooo]Z
oaP0oooVo`3o07CooookJ_oo0006oookJP04oonn0?m`0?oo0?l5oookJPCoogT00_oonfX00ooo02go
oo]ZoookJP07oookJP04o`3Dool01?oooo]Zo`28o`;ooo]Z00?o0?m>oookJ_oonfX00ooonfX01Ol0
o`Sooo]ZoookJ_oonf[oo`1i00?ooo]Z00?o403ooi;o0?oonfX00_oonfX00ooo003ooo]ZoookJP04
oookJP03obH0oooonf[ooo]Z00;ooo]Z0ooo00001?oonf[o0=cooookJ_ooDP0=oookJP03ool0m_oo
b@3oobP000WoobP01?l00002oaP0o`;ooo]Z3Ooo:002oookJP;oobP000Cooo]Zog00oom`0?ooL03o
1OoonfX3ool00003oaP0oooo003oo`0000;oo`0000?ooo]Zoomi0?ooN@000_oonfX00omQ0?oooo]Z
oookJP02oookJP03ok?o0?oonf[ooo]Z00[ooo]Z00?oo`3foookJ_oonfX06OoonfX00oooDP3ooo]Z
o`0Zo`02oookJP04o`3Lool0omoooo]ZoookJPWoo`001ooonfX00olV0?oo8?l0oookJP09oookJPCo
ogT000?o0?n`oookJ_l0<?l00_oonfX01_oo:03ooo]ZoookJ_nBo`3ooo]Zoa00o`?ooo]Z00?oo`1A
oookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP02oookJP07o`3oDooonf[ooo]ZoookJ_l0oagooo]Z
o`3Qo`08oookJP03o`3o=?oonf[o0?m>00Cooo]Z00?o08SooookJ_l0ZOl00_oonfX00ol01?oooo]Z
o`3Do`0;oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX0EooonfX00ol0Looooo]Z
oookJP0BoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oonB0?oonfX00_oonfX00ooo0?cooo]Z
oookJP02oookJP05ool60?oonf[ooo]ZoookJ_o[o`000_oonfX01_l0Y_ooZ03ooookJ_oonf[oo`3i
o`1go`;ooo]Z00Coof`0oookJ_oonf[o>ol00_oonfX01?l0nooooo]ZoookJ_oo0`02oookJP04ool0
gOoonf[o0:?ook?o00?ooo]Z00Wo0?oNoookJ_oonf[ooo]Zool0K?oonf[oC@3ooookJ_mQ0?l01?oo
nfX00ol0oi3o0?nBoookJP03oookJP08ofP0oooonf[ooo]ZoookJ_lH0?oo07CooookJ_ooT006oook
JP03oonn0?oonf[oL03o00?ooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@0:oookJP03o`3Dool01?oo
08So00;ooo]Z00?o0?ldo`3oC_oonfX00ooonfX01Ol0o`Sooo]ZoookJ_oonf[oo`1i00?ooo]Z00?o
403ooookJ_nBo`000_oonfX00ol0oe_ooo]ZoookJP04oookJP03obH0oooonf[ooo]Z00?ooo]Z00Co
4P3ooookJ_oonf[o0=co0_oonfX00oooDP3ooo]ZoookJP0;oookJP03ool0m_oonf[ooo]Z00Cooo]Z
00Co/ol0oookJ_oonf[ooo]Z1?l00002oaP0o`Kooo]Z0om`0?l<oookJP?oL03o1ooonfX00olH0?oo
oo]ZoookJP07oookJP03of40oooonf[ooo]Z00;ooo]Z00?o/ol0oookJ_oonfX02_oonfX00ooo0?Ko
oo]ZoookJP0JoookJP03oomB0?oonf[o02[o00;ooo]Z00?o0?oOoookJ_oonfX01?oonfX00ooobP3o
oo]ZoookJP09oookJP03obH0oolPo`3ooo]Z00_ooo]Z00?o0?mKoookJ_l0ok000_oonfX00ol0<?oo
oo]Zo`H0o`02oookJP04oi;o0?oonf[ooo]Zoa00o`?ooo]Z00Goo`1AoookJ_l0[Ooooo]Zool0N@05
oookJP06o`3oDooonf[ooo]Zo`3o7Ooonf[o0>7o2?oonfX01?l0ocCooo]Zo`3o;_l0odh4oookJP03
o`28oooonf[o0:Wo00;ooo]Z00?o00Coo`3DoooonfX02ooonfX00oooP@3ooo]ZoookJP0:oookJP03
ool0;Ooonf[ooo]Z02?ooo]Z000goookJP03o`1coooonf[ooo]Z017ooo]Z0_ooN@07oookJP03oolF
0?oonf[ooi8000;ooo]Z00?oo`3loookJ_oonfX00_oonfX01_lH0?ooogT0oookJ_oonf[ojol0odCo
00;ooo]Z00_oZ03ooookJ_oonf[oo`3ioookJ_l0Mooooo]Zoom/0?l0oi[ooo]Zoc_o0003oookJP09
o`3koooonf[ooo]Zool30?oonf[oN@3oool00?oonf[o/ol000;ooo]Z1?ooN@001_oonf[oo`1/oook
J_m=0?ooobP0of40o`SoobP00ooonfX01OmX0?oooo]ZoookJ_lH0?ooi_l000;ooo]Z00?oo`00oook
J_oonfX00ooonfX01?oo_P3ooo]Zog00oooonfX5oomi00;ooo]Z00?oo`0]oookJ_oonfX01ooonfX0
1?l0e?oooo]ZoookJ_l0R?l2oookJP03o`3oC_oonf[ooo]Z00;ooo]Z00?o0?l8oookJ_oonfX00_oo
nfX01_oo07Wooo]ZoookJ_l@0?oooo]Zoi;o00Wooo]Z00?o9P3ooookJ_oonfX00_oonfX4ool00004
oookJ_l0g?oooo]ZoomB00gooo]Z00?oo`3foookJ_oob@002?oo:0001Ooonf[o0000o`000?l0003o
603o00Cooo]Z0_oo0007oolX00Gooo]Z0ooo:004oookJP;oL03o1?oonfX3ool00003oaP0oooo003o
ogT000CoogT00_oonfX00omQ0?oooo]ZoookJP03oookJP03ok?o0?oonf[ooo]Z00Wooo]Z00?oo`3f
oookJ_oonfX06OoonfX00oooDP3o0?lco`0Zo`02oookJP03o`3Lool0omoooo]Z00;ooo]Z2?oo0008
oookJP03obH0oooonf[ooo]Z00Sooo]Z1?ooN@000ol0ok3ooo]Zo`0`o`02oookJP06oolX0?oonf[o
oo]Zoi;o0?oonf[o403o1?oonfX01Ooo057ooo]Zo`2]oooonf[oo`1i00Cooo]Z00Oo0?mCoookJ_oo
nf[ooo]Zo`3o7Ooonf[o0>7o00Sooo]Z00?o0?ldoookJ_l0odh01?oonfX00ol0R?oooo]Zo`2Yo`02
oookJP03o`04oooonf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP1G
oookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01_oonfX00ooo5P3ooi80oookJP02
oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Goo`H0oookJ_oonf[ooo]Zon_o0002oookJP06o`2VoonX
0?oooo]ZoookJ_oo0?Wo07Oo0_oonfX01?ooK03ooo]ZoookJ_lko`02oookJP0:o`3koooonf[ooo]Z
ool30?oonf[oN@3oool0gOoonf[o0:?ook?o00?ooo]Z00Ko0?oNoookJ_oonf[oo`1/oookJ_m=0?l2
oookJP07of40oooonf[ooo]ZoookJ_l0oi3ooo]Zo`3oTP04oookJP05ofP0oooonf[ooo]ZoookJ_lH
0?l00_oonfX00oooT03ooo]ZoookJP03oookJP04oonn0?oonf[o0?l5og00o`?ooo]Z00GooeL0oook
J_oonf[ooo]Zool0;@0:oookJP03o`3Doooonf[o08So00;ooo]Z00?o0?m>oookJ_oonfX00ooonfX0
1Ol0o`Sooo]ZoookJ_oonf[oo`1i00;ooo]Z00?o403ooookJ_nBo`002OoonfX00olV0?oooo]Zoook
JP04oookJP06oa80oooonf[ooo]Zo`3Loooonf[ooe803_oonfX00ooo0?Kooo]ZoookJP03oookJP03
ok?o0?oonf[ooo]Z00;ooo]Z0ol000000olH0?oooo]ZoookJP03oookJP?oL03o4_oonfX2og00o`Ko
oo]Z00?o603ooookJ_oonfX01_oonfX00omQ0?oooo]ZoookJP03oookJP03ok?o0?oonf[ooo]Z00Wo
oo]Z00?oo`3foookJ_oonfX06_oonfX00oooDP3ooo]Zo`0Zo`02oookJP03o`3ogooonf[ooo]Z00Co
oo]Z00?o4P3oooo:0?oonfX02_oonfX00olV0?oooo]ZoookJP0:oookJP03o`3oFooonf[o0?n`00;o
oo]Z00?o033ooookJ_l60?l00_oonfX01?nBo`3ooo]ZoookJ_l@0?l3oookJP05ool0DOoonf[o0:go
oookJ_oo07T01OoonfX01_l0oe?ooo]ZoookJ_l0oagooo]Zo`3Qo`Sooo]Z00Co0?ldoookJ_l0obko
0?m>1?oonfX00ol0R?oooo]Zo`2Yo`02oookJP03o`04ool0e?oooo]Z00_ooo]Z00?ooh40oookJ_oo
nfX02_oonfX00ooo02gooo]ZoookJP0SoookJP00=ooonfX00ol0Looooo]ZoookJP0AoookJP;oogT0
1ooonfX00ooo5P3ooi80oookJP02oookJP03ool0o?oonf[ooo]Z00;ooo]Z00KoogT0oookJ_oonf[o
oo]Zon_o0?m4o`02oookJP08ojP0oooonf[ooo]Zool0nOoonf[o07OooookJ_ooK002oookJP07oc_o
0?oonf[ooo]ZoookJ_l0nooooo]Zool30002oookJP04ogT0oooo003ooo]Zok?o00;ooo]Z1?ooN@00
1_oonf[oo`1/oookJ_m=0?ooobP0of40o`SoobP00ooonfX01omX0?oooo]ZoookJ_lH0?ooi_l0oook
J_oo00001_oonfX01?oo_P3ooo]Zog00oooonfX5oomi0003oookJ_oo02gooo]Z00Wooo]Z00Oo0=Co
oookJ_oonf[o08SooookJ_l0odko0?ld00Cooo]Z00Go0?l8oookJ_oonf[ooo]Zool0N@03oookJP03
oa00oonBo`3ooo]Z00Wooo]Z00Co9P3ooookJ_oonf[ooo]Z1Ooo00000ol0g?oooo]ZoomB000=oook
JP05ool0m_oonf[ooo]ZoookJ_oob@001_oo:002oookJP;o000000?o603oo`000?oo00002?oo0000
0ooo:03ooo]ZoookJP05oookJPGoobP01OoonfX00om`0?oooo]ZoookJP02oookJP;oo`001oooN@03
oookJP03of40oooonf[ooo]Z00?ooo]Z00?o/ol0oookJ_oonfX02OoonfX00ooo0?Kooo]ZoookJP0H
oookJP08oomB0?l0oc?ooo]Zo`0Zoooonf[o0=cooookJ_l0oml2oookJPSoo`001OoonfX01?oo003o
oo]ZoookJ_lV0?l;oookJP?oogT000?o0?n`oookJ_l0<?l00ooonfX01Ooo:03ooo]Zoi;o0?oonf[o
403o00Cooo]Z00Goo`1AoookJ_l0[Ooooo]Zool0N@04oookJP07o`3oDooonf[ooo]ZoookJ_l0oago
oo]Zo`3Qo`08oookJP03o`3o=?oonf[o0?m>00Cooo]Z00?o08SooookJ_l0ZOl00_oonfX00ol01?oo
oo]Zo`3Do`0;oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX0EooonfX00ol0Looo
oo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooi80oookJ_oonfX00_oonfX01Ooo0?co
oo]ZoookJ_oonf[oo`H000Cooo]Z00cojol0oookJ_oonf[o0:KoojP0oooonf[oo`3ioookJ_l0Mooo
oo]Zo`3oV_ooK002oookJP06oc_o0?oonf[ooo]Zo`3koooonf[oo`<00_oonfX01Omi0?ooo`3Moook
J_l0Xooo/ol000;ooo]Z00OogOl0o`3og_oonf[ooo]Zool0K?oonf[oC@3o00;ooo]Z00OoH@3ooook
J_oonf[ooo]Zo`3oT?oonf[o0?nB00Cooo]Z00OoJ03ooookJ_oonf[o603oonKo0?oonf[ooi0000Ko
oo]Z00?ookh0oookJ_m`0?l01?oonfX01?ooE`3ooo]ZoookJ_oo02d;oookJP03o`3Doooonf[o08So
00;ooo]Z00?o0?m>oookJ_oonfX00ooonfX01?l0o`Sooo]ZoookJ_oo07T3oookJP03oa00oooonf[o
T_l000Wooo]Z00?o9P3ooookJ_oonfX00ooonfX01?lB0?oooo]ZoookJ_l0g?l2oookJP03oomB0?oo
nf[ooo]Z00_ooo]Z00?oo`3foookJ_oonfX00ooonfX00onco`3ooo]ZoookJP03oookJP;o000000?o
603oo`000?oonfX00ooonfX00om`0?oooo]ZoookJP0EoookJP03og00oooonf[ooo]Z00Cooo]Z00?o
603ooookJ_oonfX01_oonfX00omQ0?oooo]ZoookJP03oookJP03ok?o0?oonf[ooo]Z00Wooo]Z00?o
o`3foookJ_oonfX06OoonfX00oooDP3ooo]Zo`0Zo`02oookJP03o`3Lool0omoooo]Z00Cooo]Z00?o
4P3oooo:0?oonfX01ooonfX01?oQo`3ooo]ZoookJ_lV0?l<oookJP03o`3oFooonf[o0?n`00;ooo]Z
00Ko033ooookJ_oonf[o1P3ooookJ_nBo`02oookJP09oa00oooonf[ooo]ZoookJ_oo057ooo]Zo`2]
oooonf[oo`1i00Gooo]Z00Ko0?mCoookJ_oonf[o0?lMoookJ_l0hOl8oookJP04o`3o=?oonf[o0?l^
o`3oCPCooo]Z00?o08SooookJ_l0ZOl00_oonfX00ol01?oo0=CooookJP0;oookJP03oon10?oonf[o
oo]Z00[ooo]Z00?oo`0]oookJ_oonfX08ooonfX003Oooo]Z00?o07?ooookJ_oonfX04?oonfX4oomi
00Kooo]Z00?ooaH0oonB0?oonfX00_oonfX00ooo0?cooo]ZoookJP02oookJP09oomi0?oonf[ooo]Z
on_o0?oonf[oA?l0oookJ_l0Y_ooZ03o00;ooo]Z00Ooo`3io`1goooonf[ooo]Zoom/0?oonf[o>ol0
00?ooo]Z00Co0?_ooookJ_oonf[oo`000_oonfX00omi0?ooo`00ok?o0002oookJPKoogT000Coo`1/
oookJ_m=0?ooH@3o2Ooo:003oookJP07ofP0oooonf[ooo]ZoaP0oooVo`3ooo]Zool00006oookJP03
oonn0?m`0?oo0?l500KoogT000?ooo]Zool0;OoonfX02?oonfX01?l0e?oo00CooookJ_l0R?l2oook
JP03o`3oC_oonf[ooo]Z00?ooo]Z00Go0?l8oookJ_oonf[ooo]Zool0N@03oookJP03oa00oonBo`3o
oo]Z00Sooo]Z00?o9P3ooookJ_oonfX00_oonfX5ool000;ooo]Z00?ooe80oookJ_oonfX02_oonfX0
0ooo0?Kooo]ZoookJP04oookJPGoobP00_oonfX00ol0003o603oool0000<ool000Gooo]Z1_oo:006
oookJP03og00oooonf[ooo]Z00;ooo]Z2?ooN@03oookJP03of40oooonf[ooo]Z00?ooo]Z00?o/ol0
oookJ_oonfX02OoonfX00ooo0?Kooo]ZoookJP0IoookJP07oomB0?oonf[o02[ooookJ_l0g?oooo]Z
o`3og`03oookJPKoo`001_oonfX01?oo003ooo]ZoookJ_lV0?l;oookJP?oogT000?o0?n`oookJ_l0
<?l00ooonfX01Ooo:03ooo]Zoi;o0?oonf[o403o00Cooo]Z00Goo`1AoookJ_l0[Ooooo]Zool0N@05
oookJP06o`3oDooonf[ooo]Zo`3o7Ooonf[o0>7o2?oonfX00ol0ocCooo]Zo`3oCP04oookJP03o`28
oooonf[o0:Wo00;ooo]Z00?o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP0:oookJP03ool0
;Ooonf[ooo]Z05Oooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP06oookJP05oonB
0?oonf[ooo]ZoookJ_oo0?`01?oonfX03Ooo1P3ooo]ZoookJ_oonf[ojol0ool0m_oonf[o0:Kooook
J_nX0?oooo]Zool0nOl0Mol00_oonfX01?l0oi[oof`0oookJ_lko`03oookJP03o`3koooonf[oo`<0
00;ooo]Z00CoN@3oool0gOl05ooo/ol00ooonfX02OoMo`3o0?oNoookJ_oonf[oo`1/oookJ_m=0?oo
oo]Zof40o`04oookJP03o`3oT?l0oi;ooo]Z00Cooo]Z00OoJ03ooookJ_oonf[o603oonKo0?oonf[o
oi0000Kooo]Z00?ookh0oookJ_m`0?l01?oonfX01?ooE`3ooo]ZoookJ_oo02d:oookJP03o`3Dool0
1?oo08So00?ooo]Z00?o0?m>oookJ_oonfX00_oonfX01Ol0o`Sooo]ZoookJ_oonf[oo`1i00?ooo]Z
00?o403ooi;o0?oonfX02?oonfX00olV0?oooo]ZoookJP04oookJP03oa80oooonf[o0=co00;ooo]Z
00?ooe80oookJ_oonfX02ooonfX00ooo0?Kooo]ZoookJP03oookJP03ok?o0?oonf[ooo]Z00Cooo]Z
00Co0000oaP0ool0003o00000_oonfX2og00oaWooo]Z00?oL03ooookJ_oonfX01?oonfX00olH0?oo
oo]ZoookJP05oookJP03of40oooonf[ooo]Z00?ooo]Z00?o/ol0oookJ_oonfX02OoonfX00ooo0?Ko
oo]ZoookJP0IoookJP03o`3o<oooDP3o02[o00;ooo]Z00?o0=coo`3ogooonfX01OoonfX00ooobP3o
oo]ZoookJP06oookJP04on7o0?oonf[ooo]ZobH0o`cooo]Z00?o0?mKoookJ_l0ok000_oonfX01_l0
<?oooo]ZoookJ_l60?oooo]Zoi;o00;ooo]Z00Wo403ooookJ_oonf[ooo]Zool0DOoonf[o0:gooook
J_oo07T01OoonfX01_l0oe?ooo]ZoookJ_l0oagooo]Zo`3Qo`Sooo]Z00Co0?ldoookJ_l0obko0?m>
1?oonfX00ol0R?oooo]Zo`2Yo`02oookJP03o`04ool0e?oooo]Z00_ooo]Z00?ooh40oookJ_oonfX0
2_oonfX00ooo02gooo]ZoookJP0SoookJP00=ooonfX00ol0Looooo]ZoookJP0@oookJPCoogT01_oo
nfX01Ooo5P3ooi80oookJ_oonf[oo`3l00Cooo]Z00Ko603oool60?oonf[ooo]Zon_o0?m4o`02oook
JP06o`2VoonX0?oooo]ZoookJ_oo0?Wo07Oo0_oonfX00oooK03ooo]Zoc_o0003oookJP04o`3koooo
nf[ooo]Zool000;ooo]Z00?oN@3oool00?nco`000_oonfX6oomi0004ool0K?m=0?ooobP0of40o`Wo
obP00_oonfX01OmX0?oooo]ZoookJ_lH0?ooi_l000;ooo]Z00?oo`00oookJ_oonfX00ooonfX01?oo
_P3ooo]Zog00oooonfX6oomi0003oookJ_oo02gooo]Z00Sooo]Z00Co0=CooookJ_oonf[o08So0_oo
nfX00ol0odkooo]ZoookJP02oookJP03o`3o2?oonf[ooo]Z00;ooo]Z00Goo`1ioookJ_oonf[o403o
oi;o000:oookJP04obH0oooonf[ooo]ZoookJPGoo`0000?o0=cooookJ_ooDP003?oonfX00ooo0?Ko
oo]ZoookJP04oookJP03ok?o0?oonf[oobP000;oobP00ooo00000olH0?ooo`00ool00004ool00003
oookJ_oo003oo`0000Ooo`000_oonfX8oolX00Kooo]Z00CoL03ooookJ_oonf[ooo]Z2?ooN@04oook
JP03of40oooonf[ooo]Z00?ooo]Z00?o/ol0oookJ_oonfX02OoonfX00ooUo`3ooo]ZoookJP0Hoook
JP03oomB0?oonf[o02[o00;ooo]Z00?o0=coo`3ogooonfX00_oonfX6ool000Kooo]Z00Coo`00oook
J_oonf[o9P3o3?oonfX2oomi0003oookJ_l0ok3oobP000GoobP000?oT_l0oolX0?l@0?l01?oonfX0
1Ooo057ooo]Zo`2]oooonf[oo`1i00Gooo]Z00Ko0?mCoookJ_oonf[o0?lMo`3o2?l0hOl8oookJP03
o`3o=?oonf[o0?m>00Cooo]Z00?o08SooookJ_l0ZOl00_oonfX00ol01?oooo]Zo`3Do`0;oookJP03
oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX0EooonfX00ol0Looooo]ZoookJP0AoookJP03
ool0j_oonf[ooo]Z00Oooo]Z00Gooi80oookJ_oonf[ooo]Zool0o004oookJP05ool60?oonf[ooo]Z
oookJ_o[o`000_oonfX01_l0Y_oooo]ZojP0oooonf[oo`3io`1go`;ooo]Z00Co0?nJoom/0?oonf[o
>ol00ooonfX00ol0nooooo]Zool30002oookJP04ogT0oooo0=go01Oook?o00?ooo]Z00KogOl0o`3o
g_oonf[ooo]Zool0K?m=0?l2oookJP03of40oooonf[ooo]Z00;ooo]Z00?o0?n@o`3oT_oonfX00ooo
nfX01OmX0?oooo]ZoookJ_oonf[o603o00;ooo]Z00?ooi00oookJ_oonfX00ooonfX01?oo_P3ooo]Z
o`3o1Om`0?l3oookJP05oomG0?oonf[ooo]ZoookJ_oo02d02_oonfX00ol0e?oooo]Zo`28o`02oook
JP03o`3oC_oonf[ooo]Z00?ooo]Z00Go0?l8oookJ_oonf[ooo]Zool0N@02oookJP03oa00oooonf[o
T_l000Wooo]Z00?o9P3ooookJ_oonfX00ooonfX01?lB0?oooo]ZoookJ_l0g?l2oookJP03oomB0?oo
nf[ooo]Z00[ooo]Z00?oo`3foookJ_oonfX00ooonfX00onco`3ooo]ZoookJP05oookJP06oaP0ool0
003o0000o`000?oonf[oL03o7?oonfX00om`0?oooo]ZoookJP03oookJP03onKo0?lH0?oooo]Z00Ko
oo]Z00?oH@3ooookJ_oonfX00ooonfX00onco`3ooo]ZoookJP09oookJP03ool0m_oonf[ooo]Z01So
oo]Z00?o0?lcoomB0?l0:_l00_oonfX00ol0g?oo0?oOoookJP05oookJP03ooo:0?oonf[ooo]Z00Ko
oo]Z00CohOl0oookJ_oonf[o9P3o3OoonfX01Ol0oe_ooo]Zo`3o/?oonf[o033o00;ooo]Z00?o1P3o
oookJ_nBo`000_oonfX02Ol@0?oooo]ZoookJ_oonf[oo`1AoookJ_l0[Ooooo]Zool0N@05oookJP06
o`3oDooonf[ooo]Zo`3o7Ol0o`So0>7o2?oonfX01?l0ocCooo]Zo`3o;_l0odh4oookJP03o`28oooo
nf[o0:Wo00;ooo]Z00?o00Coo`3DoooonfX02ooonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooo
nf[ooo]Z02?ooo]Z000goookJP03o`1coooonf[ooo]Z013ooo]Z1?ooN@05oookJP03oolF0?oonf[o
oi8000;ooo]Z00?oo`3loookJ_oonfX00_oonfX01_lH0?ooo`H0oookJ_oonf[ojol0odCo00;ooo]Z
00_o0:KoojP0oooonf[oo`3ioookJ_l0Mooooo]Zoom/0?l0oi[ooo]Zoc_o0003oookJP0:o`3koooo
nf[oo`00ool00?oonf[oN@3oool00?oonf[o/ol0oookJPKoogT000Goo`1/oookJ_m=0?ooobP0of40
o`05oolX0003oookJ_l0oi;ooo]Z00?ooo]Z00GoJ03ooookJ_oonf[o603oonKo0002oookJP03ool0
0?oonf[ooo]Z00?ooo]Z00?ookh0oookJ_m`0?l01oooN@000ooo02gooo]ZoookJP08oookJP07o`3D
oooonf[ooo]Zo`28oooonf[o0?m>o`3o=004oookJP05o`3o2?oonf[ooo]ZoookJ_oo07T00ooonfX0
0ol@0?ooT_l0oookJP08oookJP04obH0oooonf[ooo]ZoookJPKoo`000_oonfX00oooDP3ooo]Zoook
JP0:oookJP03ool0m_oonf[ooo]Z00?ooo]Z00Go/ol0oookJ_oonf[ooo]ZoolX0003ool00003oaP0
oooo003oo`0000Coo`0000?ooo]Zool00?oo00002Ooo0009oolX00Oooo]Z00CoL03ooookJ_oonf[o
oo]Z2?ooN@03oookJP03of40oooonf[ooo]Z00?ooo]Z00?o/ol0oookJ_oonfX02OoonfX5onGo01Ko
oo]Z00?ooe80oookJ_l0:_l00_oonfX00ol0g?oo0?oOoookJP02oookJPKoo`001_oonfX01?oo003o
oo]ZoookJ_lV0?l<oookJP;oogT000?ooo]Zo`3o/?oo:0001Ooo:0000onBo`3oobP0oa00o`04oook
JP05ool0DOoonf[o0:gooookJ_oo07T01OoonfX01_l0oe?ooo]ZoookJ_l0oago0?l8o`3Qo`Sooo]Z
00?o0?ldoookJ_l0odh01?oonfX00ol0R?oooo]Zo`2Yo`02oookJP03o`04oooonf[o0=Co00_ooo]Z
00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP1GoookJP03o`1coooonf[ooo]Z017ooo]Z
00?oo`3ZoookJ_oonfX01_oonfX00ooo5P3ooi80oookJP02oookJP03ool0o?oonf[ooo]Z00;ooo]Z
00Goo`H0oookJ_oonf[ooo]Zon_o0002oookJP06o`2Voooonf[oZ03ooookJ_oo0?Wo07Oo0_oonfX0
1?ooK03ooo]ZoookJ_lko`02oookJP0:o`3koooonf[ooo]Zool30?oonf[oN@3oool0gOoonf[o0:?o
ok?o00?ooo]Z00Ko0?oNoookJ_oonf[oo`1/oookJ_m=0?l2oookJP07of40oooonf[ooo]ZoookJ_l0
oi3ooo]Zo`3oTP04oookJP05ofP0oooonf[ooo]ZoookJ_lH0?l00_oonfX00oooT03ooo]ZoookJP03
oookJP04oonn0?oonf[o0?l5og00o`?ooo]Z00CooeL0oookJ_oonf[oo`0]2ooonfX00ol0e?oooo]Z
o`28o`02oookJP03o`3oC_oonf[ooo]Z00?ooo]Z00Co0?l8oookJ_oonf[oo`1i0ooonfX00ol@0?oo
oo]Zoi;o0008oookJP03obH0oooonf[ooo]Z00Cooo]Z00?o4P3ooookJ_l0g?l00_oonfX00oooDP3o
oo]ZoookJP0;oookJP03ool0m_oonf[ooo]Z00;ooo]Z00?o/ol0oookJ_oonfX01OoonfX00olH0?oo
0000o`000002o`000003og00oooonf[ooo]Z01cooo]Z00?oL03ooookJ_oonfX00ooonfX00ooVo`3o
603ooookJP05oookJP03of40oooonf[ooo]Z00?ooo]Z00?o/ol0oookJ_oonfX02OoonfX00ooo0?Ko
oo]ZoookJP0HoookJP07o`3o<oooDP3ooo]Zo`0Zoooonf[o0=coo`3og`06oookJP03ooo:0?oonf[o
oo]Z00Kooo]Z00CohOl0oookJ_oonf[o9P3o3OoonfX01Ol0oe_ooo]Zo`3o/?oonf[o033o00;ooo]Z
00?o1P3ooookJ_nBo`000_oonfX02Ol@0?oooo]ZoookJ_oonf[oo`1AoookJ_l0[Ooooo]Zool0N@05
oookJP06o`3oDooonf[ooo]Zo`3o7Ol0o`So0>7o2?oonfX01?l0ocCooo]Zo`3o;_l0odh4oookJP03
o`28oooonf[o0:Wo00;ooo]Z00?o00Coo`3DoooonfX02ooonfX00oooP@3ooo]ZoookJP09oookJP03
ool0;Ooonf[ooo]Z02Cooo]Z000goookJP03o`1coooonf[ooo]Z00oooo]Z1OooN@05oookJP03oolF
0?oonf[ooi8000;ooo]Z00?oo`3loookJ_oonfX00_oonfX01_lH0?ooo`H0oookJ_oonf[ojol0odCo
00;ooo]Z00GoZ03ooookJ_oonf[oo`3io`1go`02oookJP03oom/0?oonf[o>ol000Cooo]Z00[o0?_o
oookJ_oo003oo`00oookJ_mi0?ooo`00oil0oonco`3ooo]Z1_ooN@001Ooo06cooo]Zodd0oooo:03o
H@3o00GoobP000?ooo]Zo`3oT_oonfX00ooonfX01omX0?oooo]ZoookJ_lH0?ooi_l0oookJ_oo0000
1_oonfX00ooo_P3ooo]Zog00o`07oomi0003ool0;Ooonf[ooo]Z00Oooo]Z00So0=Coo`04oooonf[o
oo]Zo`28oooonf[o0?m>o`3o=0Cooo]Z00Go0?l8oookJ_oonf[ooo]Zool0N@03oookJP03oi;o0?oo
nf[ooo]Z00Sooo]Z00?o9P3ooookJ_oonfX01ooo00000ooonf[ooe80oookJP0;oookJP03ool0m_oo
nf[ooo]Z00;ooo]Z0_oo0004oookJP?oo`0000?o603oool00?oo00001?oo0002oookJPgoo`002?oo
:007oookJP04og00oooonf[ooo]ZoookJPOoogT01?oonfX00omQ0?oooo]ZoookJP02oookJP03ok?o
0?oonf[ooo]Z00Gooo]Z2OoUo`0FoookJP03oomB0?oonf[o02[o00;ooo]Z00?o0=coo`3ogooonfX0
0ooonfX5ool000Kooo]Z00Coo`00oookJ_oonf[o9P3o3OoonfX01?ooN@3ooo]Zo`3o/?l0<?l5oolX
0003oi;o0?oo:03o403o00Cooo]Z00Goo`1AoookJ_l0[Ooooo]Zool0N@05oookJP06o`3oDooonf[o
oo]Zo`3o7Ol0o`So0>7o2?oonfX00ol0ocCooo]Zo`3oCP04oookJP03o`28oooonf[o0:Wo00;ooo]Z
00?o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z05Oooo]Z
00?o07?ooookJ_oonfX04OoonfX00ooo0>[ooo]ZoookJP06oookJP03oolF0?ooTP3ooo]Z00;ooo]Z
00?oo`3loookJ_oonfX00_oonfX01Ooo1P3ooo]ZoookJ_oonf[ojol000;ooo]Z00Go0:KoojP0oooo
nf[oo`3io`1go`02oookJP04o`3oV_ooK03ooo]Zoc_o00?ooo]Z00[o0?_ooookJ_oonf[oo`<0oook
J_mi0?ooo`3Mo`0Gool0Xooo/ol00ooonfX01_l0omkooo]ZoookJ_oo06cooo]Zodd0o`;ooo]Z00Oo
H@3ooookJ_oonf[ooo]Zo`3oT?oonf[o0?nB00Cooo]Z00OoJ03ooookJ_oonf[o603oonKo0?oonf[o
oi0000Kooo]Z00Cookh0oookJ_l0o`GoL03o0ooonfX01?ooE`3ooo]ZoookJ_oo02d:oookJP04o`3D
ool01?oooo]Zo`28o`;ooo]Z00?o0?m>oookJ_oonfX00_oonfX01Ol0o`Sooo]ZoookJ_oonf[oo`1i
00?ooo]Z00?o403ooi;o0?oonfX02?oonfX00olV0?oooo]ZoookJP04oookJP03oa80oooonf[o0=co
00;ooo]Z00?ooe80oookJ_oonfX02_oonfX00ooo0?Kooo]ZoookJP02oookJP03ok?o0?oonf[ooo]Z
00Gooo]Z00?o603ooookJ_l000000ol00009oookJPCo00Co1?l0e?l?oookJP03og00oooonf[ooo]Z
00?ooo]Z00?oi_l0oaP0oooonfX01OoonfX00omQ0?oooo]ZoookJP02oookJP03ok?o0?oonf[ooo]Z
00Wooo]Z00?oo`3foookJ_oonfX06OoonfX00oooDP3ooo]Zo`0Zo`02oookJP03o`3ogooonf[ooo]Z
00Cooo]Z00?o4P3oooo:0?oonfX01_oonfX01?oQo`3ooo]ZoookJ_lV0?l=oookJP05o`3oFooonf[o
0?n`oookJ_l0<?l00_oonfX00ol60?oooo]Zoi;o0002oookJP03oa00oooonf[ooo]Z00;ooo]Z00Co
o`1Ao`2]oooonf[oo`1i1OoonfX01_l0oe?ooo]ZoookJ_l0oago0?l8o`3Qo`Wooo]Z00?o0?ldo`3o
;_l0odh01?oonfX00ol0R?oooo]Zo`2Yo`02oookJP03o`04ool0e?oooo]Z00_ooo]Z00?ooh40oook
J_oonfX02OoonfX00ooo02gooo]ZoookJP0ToookJP00=ooonfX00ol0Looooo]ZoookJP0?oookJPGo
ogT01OoonfX00ooo5P3ooi80oookJP02oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Go603oool60?oo
nf[ojol0odCo0003oookJP05ojP0oooonf[ooo]Zool0nOl0Mol00_oonfX00oooK03ooo]ZoolX0004
oookJP09o`3koooo003oo`00ool00?oonf[oN@3oool00?ooN@3o/ol000OoogT000Coo`1/oookJ_m=
0?ooH@3o1Ooo:002oookJP03o`3oT_oonf[ooo]Z00;ooo]Z00OoJ03ooookJ_lH0?oooo]ZonKo0?oo
nf[oo`0000Kooo]Z00?ookh0og00ooooN@001oooN@000ooo02gooo]ZoookJP07oookJP04o`3Dool0
1?oooo]Zo`28o`;ooo]Z00?o0?m>oookJ_oonfX00_oonfX00ol0o`Sooo]ZoookJP02oookJP05ool0
NOoonf[ooo]Zoa00oonBo`002OoonfX00ooo:03ooo]ZoookJP08ool00003oomB0?oonf[ooo]Z00[o
oo]Z00?oo`3foookJ_oonfX00_oonfX3ool000Gooo]Z00?oo`00oaP0oooo00001Ooo00000ol0003o
oo]ZoookJP0>ool000OoobP01ooonfX00om`0?oooo]ZoookJP02oookJPKoogT01?oonfX00omQ0?oo
oo]ZoookJP03oookJP03ok?o0?oonf[ooo]Z00Cooo]Z2OoUo`000ooo003ooo]ZoookJP0CoookJP07
oomB0?oonf[ooo]Zo`0Zoooonf[o0=coo`3og`04oookJPGoo`001_oonfX01?oo003ooo]ZoookJ_lV
0?l=oookJP04o`3oFooonf[o0?n`o`0`o`GoobP000?oT_l0oolX0?l@0?l01?oonfX01Ooo057ooo]Z
o`2]oooonf[oo`1i00Gooo]Z00Ko0?mCoookJ_oonf[o0?lMo`3o2?l0hOl8oookJP03o`3o=?oonf[o
0?m>00Cooo]Z00?o08SooookJ_l0ZOl00_oonfX00ol01?oooo]Zo`3Do`0;oookJP03oon10?oonf[o
oo]Z00Wooo]Z00?oo`0]oookJ_oonfX0F?oonfX00ol0Looooo]ZoookJP0AoookJP03ool0j_oonf[o
oo]Z00Kooo]Z00?ooi80oookJ_oonfX00_oonfX01_oo0?cooo]ZoookJ_oonf[o603oool600;ooo]Z
00Wojol0oookJ_oonf[ooo]Zo`2VoonX0?oooo]Zool0nOl0Mol00_oonfX01?l0oi[oof`0oookJ_lk
o`03oookJP0:o`3koooonf[ooo]Zool30?oonf[oN@3oool0gOl05ooo0:?ook?o00?ooo]Z00Wo0?oN
oookJ_oonf[oo`1/oookJ_m=0?oooo]Zof40ool0odD00ooonfX00ol0oi3ooo]Zo`3oTP04oookJP07
ofP0oooonf[ooo]ZoaP0oooVo`3ooo]Zoon@0006oookJP03oonn0?l0o`GoL03o00Cooo]Z00CooeL0
oookJ_oonf[oo`0]2_oonfX00ol0e?oo00Coo`28o`02oookJP03o`3oC_l0ocCooo]Z00?ooo]Z00Go
0?l8oookJ_oonf[ooo]Zool0N@02oookJP03oa00oooonf[oT_l000Sooo]Z00?o9P3ooookJ_oonfX0
1?oonfX01_lB0?oooo]ZoookJ_l0g?oooo]ZoomB00cooo]Z00?oo`3foookJ_oonfX00ooonfX00onc
o`3ooo]ZoookJP04oookJP03oaP0oooonf[ooo]Z00Go00001?oonfX4o`04o`Oooo]Z00?o00Coo`3D
ool0e?l00_l0e?l;oookJP03og00oooonf[ooo]Z00?ooo]Z00?oi_l0oaP0oooonfX01OoonfX00omQ
0?oooo]ZoookJP03oookJP03ok?o0?oonf[ooo]Z00Sooo]Z00?oo`3foookJ_oonfX00ooonfX00ooo
0?cooo]ZoookJP0CoookJP03oomB0?oonf[o02[o00;ooo]Z00?o0?oOoookJ_oonfX01?oonfX00olB
0?ooolX0oookJP06oookJP04on7o0?oonf[ooo]ZobH0o`gooo]Z00Go0?mKoookJ_l0ok3ooo]Zo`0`
o`02oookJP03o`H0oooonf[oT_l000;ooo]Z00?o403ooookJ_oonfX00_oonfX01?oo057o0:gooook
J_oo07T5oookJP06o`3oDooonf[ooo]Zo`3o7Ol0o`So0>7o2OoonfX00ol0ocCo0?l^o`3oCP04oook
JP03o`28oooonf[o0:Wo00;ooo]Z00?o00Coo`3DoooonfX02ooonfX00oooP@3ooo]ZoookJP09oook
JP03ool0;Ooonf[ooo]Z02Cooo]Z000goookJP03o`1coooonf[ooo]Z00oooo]Z1OooN@05oookJP03
oolF0?ooTP3ooo]Z00;ooo]Z00[oo`3loookJ_oonf[ooo]ZoaP0oooonf[oo`H0oookJ_o[o`3oA?l0
0_oonfX01_l0Y_ooZ03ooookJ_oonf[oo`3io`1go`;ooo]Z00?oof`0oookJ_oo:0000ooonfX00ol0
nooooo]Zool00002ool00005ogT0oooonf[oo`00ok?o0?oonfX01oooN@001?oo06coC@3ooolX0?mQ
0?l5oolX0003oookJ_l0oi;ooo]Z00Cooo]Z00OoJ03ooookJ_lH0?oo07CoonKo0?oonf[oo`0000Go
oo]Z00?ookh0oookJ_m`0?l00ooonfX5oomi00[ooo]Z00Oo0=CooookJ_oonf[o08SooookJ_l0odko
0?ld00Cooo]Z00Go0?l8oookJ_oonf[ooo]Zool0N@03oookJP03oa00oonBo`3ooo]Z00Sooo]Z00?o
obP0oookJ_oo00002?oo00000oooDP3ooo]ZoookJP0:oookJP04ool0m_oonf[ooo]ZoookJP?oo`00
1_oonfX00olH0?ooo`00ool00004ool000CoobP02?oo0008oookJPKoobP01ooonfX01?m`0?oooo]Z
oookJ_oonfX6oomi00Gooo]Z00?oH@3ooookJ_oonfX00_oonfX00onco`3ooo]ZoookJP05oookJPSo
iOl000?oo`00oookJ_oonfX05?oonfX01oooDP3ooo]Zo`0Zoooonf[o0=cooookJ_l0oml01?oonfX4
ool000Kooo]Z00Coo`00oookJ_oonf[o9P3o3OoonfX01?l0oe_ooo]Zo`3o/?l0<?l5oolX0003oi;o
0?oo:03o403o00Cooo]Z00Goo`1AoookJ_l0[Ooooo]Zool0N@05oookJP06o`3oDooonf[ooo]Zo`3o
7Ol0o`So0>7o2?oonfX00ol0ocCooo]Zo`3oCP04oookJP03o`28oooonf[o0:Wo00;ooo]Z00?o00Co
oookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z05Sooo]Z00?o07?o
oookJ_oonfX04OoonfX00ooo0>[ooo]ZoookJP06oookJP03oonB0?oonf[ooo]Z00;ooo]Z00Koo`3l
oookJ_oonf[ooo]ZoaP0oooo1P02oookJP09on_o0?oonf[ooo]Zo`2Voooonf[oZ03ooookJ_oo0?Wo
07Oo00;ooo]Z00Co0?nJoom/0?oonf[o>ol00ooonfX02Ol0nooooo]Zool30?oonf[oN@3ooookJ_oo
0=go01Oook?o0004oookJP05o`3og_oonf[ooo]Zool0K?m=0?l00_oonfX00omQ0?oo0?m5oookJP02
oookJP03o`3oT?l0oi;ooo]Z00Cooo]Z00OoJ03ooookJ_oonf[o603oonKo0?oonf[ooi0000Gooo]Z
00Cookh0oookJ_l0o`GoL03o0ooonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00[ooo]Z00?o0=Cooook
J_l0R?l00_oonfX00ol0odkooo]ZoookJP03oookJP04o`3o2?oonf[ooo]Zool0N@?ooo]Z00?o403o
oookJ_nBo`002?oonfX00olV0?oooo]ZoookJP04oookJP03oa80oooonf[o0=co00;ooo]Z00?ooe80
oookJ_oonfX02_oonfX00ooo0?Kooo]ZoookJP02oookJP03ok?o0?oonf[ooo]Z00Cooo]Z00Co603o
oookJ_oonf[ooo]Z1?l00003oookJP;o00Co3_oonfX2o`04o`;o0=Co2_oonfX00om`0?oooo]Zoook
JP03oookJP03onKo0?lH0?oooo]Z00Gooo]Z00?oH@3ooookJ_oonfX00_oonfX00onco`3ooo]Zoook
JP09oookJP03ool0m_oonf[ooo]Z00;ooo]Z00?oo`3loookJ_oonfX04ooonfX00ol0oc?ooe80o`0Z
o`02oookJP03o`3Lool0omoooo]Z00Cooo]Z00?o4P3oooo:0?oonfX01_oonfX01?oQo`3ooo]Zoook
J_lV0?l=oookJP05o`3oFooonf[o0?n`oookJ_l0<?l00_oonfX00ol60?oooo]Zoi;o0002oookJP03
oa00oooonf[ooo]Z00;ooo]Z00Coo`1Ao`2]oooonf[oo`1i1OoonfX01_l0oe?ooo]ZoookJ_l0oago
0?l8o`3Qo`Wooo]Z00?o0?ldo`3oC_oonfX01?oonfX00ol0R?oooo]Zo`2Yo`02oookJP03o`04ool0
e?oooo]Z00_ooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP0ToookJP00=_oonfX0
0ol0Looooo]ZoookJP0?oookJPKoogT01OoonfX00ooo5P3ooi80oookJP02oookJP06ool0o?oonf[o
oo]ZoookJ_lH0?ooo`H00_oonfX02_o[o`3oA?l0oookJ_oonf[o0:KoojP0oooonf[oo`3ioookJ_l0
Mol2oookJP03oom/0?oo:03oobP000?ooo]Z00?o0?_ooookJ_oo00000_oo00001?oo:03oo`00oook
J_nco`07oomi0007ool0K?ooN@3oC@3ooookJ_mQ0?ooobP0oookJP03oolX0003oookJ_l0oi;ooo]Z
00?ooo]Z00OoJ03ooookJ_oonf[o603oonKo0?oonf[oo`0000Kooo]Z00?ookh0oookJ_m`0?l00ooo
nfX00oooN@3ooo]ZoookJP02oomi00[ooo]Z00Oo0=CooookJ_oonf[o08SooookJ_l0odko0?ld00?o
oo]Z00?o0?l8oookJ_oonfX00_oonfX01Ooo07Wooo]ZoookJ_oonf[oT_l000Wooo]Z0_oo:003oook
JPKoo`0000?ooe80oookJ_oonfX02_oonfX01?oo0?Kooo]ZoookJ_oonfX4ool000Cooo]Z0_oo:000
0ooonf[oo`00ool00003ool000KoobP000?ooo]Zoomi0?ooN@001OooN@08oookJPGoobP02?oonfX0
1?m`0?oooo]ZoookJ_oonfX5oomi00Gooo]Z00?oH@3ooookJ_oonfX00_oonfX00onco`3ooo]Zoook
JP05oookJPSoiOl000?oo`00oookJ_oonfX05?oonfX01oooDP3ooo]Zo`0Zoooonf[o0=cooookJ_l0
oml01?oonfX4ool000Kooo]Z00Coo`00oookJ_oonf[o9P3o3OoonfX01Ol0oe_ooo]Zo`3o/?l0<?oo
oo]Z00CoobP000?oT_l0oookJ_l@0?l01?oonfX01Ooo057ooo]Zo`2]oooonf[oo`1i00Gooo]Z00Ko
0?mCoookJ_oonf[o0?lMo`3o2?l0hOl8oookJP03o`3o=?oonf[o0?m>00Cooo]Z00?o08SooookJ_l0
ZOl00_oonfX00ol01?oooo]Zo`3Do`0;oookJP03oon10?oonf[ooo]Z00Wooo]Z00?oo`0]oookJ_oo
nfX0EooonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooi80oookJ_oo
nfX00_oonfX01Ooo0?cooo]ZoookJ_oonf[oo`H000?ooo]Z00Wojol0oookJ_oonf[o0:KooookJ_nX
0?ooo`3ioookJ_l0Mol00_oonfX01?l0oi[oof`0oookJ_lko`02oookJP0:o`3koooonf[ooo]Zool3
0?oonf[oN@3oool0gOoonf[o01Oook?o00?ooo]Z00KogOl0o`3og_oonf[oo`1/oookJ_m=0?l2oook
JP07of40oooonf[ooo]ZoookJ_l0oi3ooo]Zo`3oTP04oookJP07ofP0oooonf[ooo]ZoookJ_lH0?oo
oo]Zoon@0006oookJP04oonn0?oonf[o0?l5og00o`?ooo]Z00CooeL0oookJ_oonf[oo`0]2ooonfX0
0ol0e?oooo]Zo`28o`02oookJP03o`3oC_oonf[ooo]Z00;ooo]Z00Go0?l8oookJ_oonf[ooo]Zool0
N@03oookJP03oa00oonBo`3ooo]Z00Sooo]Z00?o9P3ooookJ_oonfX00ooonfX01_lB0?oooo]Zoook
J_l0g?oooo]ZoomB00cooo]Z00?oo`3foookJ_oonfX00ooonfX00onco`3ooo]ZoookJP03oookJP03
oaP0oooonf[ooo]Z00;ooo]Z1?l00002oookJP03o`04oooonf[ooo]Z017ooo]Z00?o00Coo`3Doooo
nfX02OoonfX00om`0?oooo]ZoookJP02oookJP03onKo0?lH0?oooo]Z00Gooo]Z00?oH@3ooookJ_oo
nfX00_oonfX00onco`3ooo]ZoookJP09oookJP03ool0m_oonf[ooo]Z00;ooo]Z00?oo`3loookJ_oo
nfX04ooonfX00ol0oc?ooe80o`0Zo`02oookJP03o`3Lool0omoooo]Z00Cooo]Z00?o4P3oooo:0?oo
nfX01_oonfX01?oQo`3ooo]ZoookJ_lV0?l=oookJP05o`3oFooonf[o0?n`oookJ_l0<?l00_oonfX0
0ol60?oooo]Zoi;o0002oookJP03oa00oooonf[ooo]Z00;ooo]Z00Coo`1Ao`2]oooonf[oo`1i1Ooo
nfX01_l0oe?ooo]ZoookJ_l0oago0?l8o`3Qo`Wooo]Z00?o0?ldo`3oC_oonfX01?oonfX00ol0R?oo
0:WooookJP02oookJP03o`04ool0e?oooo]Z00_ooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02go
oo]ZoookJP0ToookJP00=_oonfX00ol0Looooo]ZoookJP0?oookJPOoogT00ooonfX00ooo5P3ooo]Z
oonB0003oookJP06ool0o?oonf[ooo]ZoookJ_lH0?ooo`H00_oonfX02_o[o`3oA?l0oookJ_oonf[o
0:KoojP0oooonf[oo`3ioookJ_l0Mol2oookJP03oom/0?oo:03oobP000?ooo]Z00?o0?_oool00?oo
00000_oo00001?oo:03oo`00o`0Goonco`04oookJP09omgo0?ooN@3oogT0ool0K?ooN@3oC@3ooook
J_mQ0?ooobP000?ooo]Z00?oobP0oookJ_l0oi801?oonfX01omX0?oooo]ZoaP0oooonf[oi_l0oook
J_oo00001_oonfX00ooo_P3o0?l5og00o`03oookJP05oomi0?oonf[ooo]ZoookJ_oo02d02OoonfX0
1ol0e?oo00CooookJ_oonf[o08SooookJ_l0odh01?oonfX00ol0o`Sooo]ZoookJP02oookJP05ool0
NOoonf[ooo]Zoa00oonBo`002OoonfX2oolX00Cooo]Z00?oo`00oookJ_oo00000_oo00000oooDP3o
oo]ZoookJP0:oookJP03ool0m_oonf[ooo]Z00Goo`000ooonfX4oolX00Coo`001_oo:0000ooonf[o
ogT0oomi0007oomi00Wooo]Z1?oo:008oookJP04og00oooonf[ooo]ZoookJPCoogT01_oonfX00omQ
0?oooo]ZoookJP02oookJP03ok?o0?oonf[ooo]Z00Gooo]Z1ooUo`05ool001;ooo]Z00Oooe80oook
J_l0:_oooo]Zo`3Loooonf[o0?oO00Cooo]Z00?o4P3oool00?oo00001ooonfX01?oo003ooo]Zoook
J_lV0?l=oookJP05o`3oFooonf[o0?n`o`0`oooonfX01?oo:0000onBo`3ooo]Zoa00o`04oookJP05
ool0DOoonf[o0:gooookJ_oo07T01OoonfX01_l0oe?ooo]ZoookJ_l0oago0?l8o`3Qo`Sooo]Z00?o
0?ldoookJ_l0odh01?oonfX00ol0R?oooo]Zo`2Yo`03oookJP03o`04ool0e?oooo]Z00[ooo]Z00?o
oh40oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP1GoookJP03o`1coooonf[ooo]Z01;ooo]Z00?o
o`3ZoookJ_oonfX01OoonfX00ooo5P3ooi80oookJP02oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Go
o`H0oookJ_oonf[ooo]Zon_o0002oookJP06o`2Voooonf[oZ03oool0nOoonf[o07Oo0_oonfX01?l0
oi[oof`0oookJ_lko`02oookJP0:o`3koooonf[ooo]Zool30?oonf[oN@3oool0gOl05ooo0:?ook?o
00?ooo]Z00KogOl0o`3og_oonf[oo`1/oookJ_m=0?l2oookJP07of40oooonf[ooo]ZoookJ_l0oi3o
oo]Zo`3oTP04oookJP07ofP0oooonf[ooo]ZoaP0oooVo`3ooo]Zoon@0006oookJP04oonn0?l0o`Go
oo]Zog00o`?ooo]Z00CooeL0oookJ_oonf[oo`0]2_oonfX01ol0e?oo00CooookJ_l0R?oooo]Zo`3o
C_l0oc@01?oonfX01Ol0o`Sooo]ZoookJ_oonf[oo`1i00;ooo]Z00?o403ooookJ_nBo`002?oonfX0
0olV0?oooo]ZoookJP04oookJP06oa80oooonf[ooo]Zo`3Loooonf[ooe802ooonfX00ooo0?Kooo]Z
oookJP03oookJP03ok?o0?oonf[ooo]Z00Cooo]Z00?o603ooookJ_oonfX00_oonfX4o`0000;o00Co
5_oonfX00ol0e?oooo]ZoookJP07oookJP03og00oooonf[ooo]Z00?ooo]Z00?oi_l0oaP0oooonfX0
1OoonfX00omQ0?oooo]ZoookJP02oookJP03ok?o0?oonf[ooo]Z00Sooo]Z00?oo`3foookJ_oonfX0
0_oonfX00ooo0?cooo]ZoookJP0CoookJP03o`3o<oooDP3o02[o00;ooo]Z00?o0=coo`3ogooonfX0
1?oonfX00olB0?ooolX0oookJP06oookJP04on7o0?oonf[ooo]ZobH0o`gooo]Z00Go0?mKoookJ_l0
ok3ooo]Zo`0`o`02oookJP03o`H0oooonf[oT_l000;ooo]Z00?o403ooookJ_oonfX00_oonfX01?oo
057o0:gooookJ_oo07T5oookJP06o`3oDooonf[ooo]ZoookJ_l0oago0>7o2OoonfX00ol0ocCo0?m>
oookJP04oookJP03o`28ool0ZOoooo]Z00?ooo]Z00?o0=CooookJ_oonfX02_oonfX00oooP@3ooo]Z
oookJP09oookJP03ool0;Ooonf[ooo]Z02Cooo]Z000foookJP03o`1coooonf[ooo]Z00oooo]Z1ooo
N@03oookJP03oolF0?oonf[ooi8000?ooo]Z00Woo`3loookJ_oonf[ooo]ZoaP0oooo1P3ooo]Zon_o
0?m4o`000ooonfX02Ol0Y_ooZ03ooookJ_oo0?Wooo]Zo`1goooonf[oof`0oookJP02oolX00?ooo]Z
00Co0?_oool00?oo003oo`000_oo:002ool00003ok?o0?oonf[ooo]Z00;ooo]Z00WoogT0oookJ_oo
nf[oo`1/odd0oooonf[oH@3ooookJ_oo:0000_oonfX01?oo:03ooo]ZoookJ_l0oi84oookJP07ofP0
oooonf[o603ooookJ_oVo`3ooo]Zool00006oookJP03oonn0?oo:03oL03o00?ooo]Z00GoogT0oook
J_oonf[ooo]Zool0;@09oookJP07o`3Dool01?oooo]Zo`28oooonf[o0?m>o`3o=004oookJP05o`3o
2?oonf[ooo]ZoookJ_oo07T00ooonfX00ol@0?ooT_l0oookJP07oookJP?oobP00ooonfX01ooo003o
oo]ZoookJ_oonf[o0=coool00?ooDP002ooonfX00ooo0?Kooo]ZoookJP05ool000?ooo]Z1Ooo:003
ool000KoobP000?ooo]Zoomi0?ooN@002OooN@09oookJP?oobP02OoonfX01?m`0?oooo]ZoookJ_oo
nfX3oomi00Kooo]Z00?oH@3ooookJ_oonfX00_oonfX00onco`3ooo]ZoookJP05oookJPCoiOl02?oo
000BoookJP07oomB0?oonf[o02[ooookJ_l0g?oooo]Zo`3og`04oookJP03oa80oooo003oo`0000Oo
oo]Z00Coo`00oookJ_oonf[o9P3o3OoonfX01Ol0oe_ooo]Zo`3o/?l0<?oooo]Z00CoobP000?oT_l0
oookJ_l@0?l01?oonfX01Ooo057ooo]Zo`2]oooonf[oo`1i00Gooo]Z00Ko0?mCoookJ_oonf[o0?lM
o`3o2?l0hOl8oookJP03o`3o=?oonf[o0?m>00Cooo]Z00?o08SooookJ_l0ZOl00ooonfX00ol01?oo
0=CooookJP0:oookJP03oon10?oonf[ooo]Z00Wooo]Z00?oo`0]oookJ_oonfX0EooonfX00ol0Looo
oo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooaH0oonB0?oonfX00_oonfX01_oo0?co
oo]ZoookJ_oonf[o603oool600;ooo]Z00gojol0oookJ_oonf[ooo]Zo`2Voooonf[oZ03oool0nOoo
nf[o07OooookJ_l0oi[oof`000;ooo]Z00Co>ol0oookJ_oonf[o0?_o0_oonfX01ooo0`3ooo]ZogT0
oooo0=go01Ooo`2Soonco`000ooonfX01Ol0omkooo]ZoookJ_oo06coC@3o00;ooo]Z00?oH@3oo`3o
AOoonfX00_oonfX00ol0oi3ooo]Zo`3oTP04oookJP07ofP0oooonf[ooo]ZoaP0oooVo`3ooo]Zoon@
0006oookJP04oonn0?l0o`Gooo]Zog00o`;ooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@0:oookJP03
o`3Dool01?oo08So00;ooo]Z00?o0?m>o`3o=?oonfX00ooonfX01?l0o`Sooo]ZoookJ_oo07T3oook
JP03oa00oooonf[oT_l000Sooo]Z00?o9P3ooookJ_oonfX00ooonfX01_lB0?oooo]ZoookJ_l0g?oo
oo]ZoomB00cooo]Z00?oo`3foookJ_oonfX00_oonfX00onco`3ooo]ZoookJP04oookJP03oaP0oooo
nf[ooo]Z00?ooo]Z0_l00002o`04oaWooo]Z00?o0=CooookJ_oonfX01ooonfX00om`0?oooo]Zoook
JP03oookJP03oaP0oooonf[ooo]Z00Cooo]Z00?oH@3ooookJ_oonfX00_oonfX00onco`3ooo]Zoook
JP08oookJP03ool0m_oonf[ooo]Z00;ooo]Z00?oo`3loookJ_oonfX05?oonfX01_ooDP3ooo]Zo`0Z
oooonf[o0=coo`3og`Gooo]Z00?o4P3ooookJ_oobP001_oonfX01?oQo`3ooo]ZoookJ_lV0?l=oook
JP05o`3oFooonf[o0?n`oookJ_l0<?l00_oonfX00ol60?oooo]Zoi;o0002oookJP03oa00oooonf[o
oo]Z00;ooo]Z00Coo`1AoookJ_l0[Oooo`1i1OoonfX01_l0oe?ooo]ZoookJ_oonf[o0?lMo`3Qo`Wo
oo]Z00?o0?ldo`3oC_oonfX01?oonfX00ol0R?oo0:WooookJP03oookJP03o`3Doooonf[ooo]Z00[o
oo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP0ToookJP00=_oonfX00ol0Looooo]Z
oookJP0>oookJPSoogT00ooonfX00ooo5P3ooi80oookJP02oookJP0:ool0o?oonf[ooo]ZoookJ_lH
0?oooo]Zool60?oonf[ojol0odCo00?ooo]Z00So0:KoojP0oooonf[oo`3ioookJ_l0Mooooo]Zoom/
00CoobP000?ooo]Zo`3koooo00000ooo0002oolX0003ool00?ooN@3o/ol000Cooo]Z00WoogT0oook
J_oonf[oo`1/oolX0?oonf[oH@3ooookJ_oo:0000_oonfX00ooo:03ooo]Zo`3oTP05oookJP07ofP0
oooonf[o603oo`1doooVo`3ooo]Zool00006oookJP03oonn0?oo:03oL03o00?ooo]Z00GoogT0oook
J_oonf[ooo]Zool0;@09oookJP07o`3Dool01?oooo]Zo`28oooonf[o0?m>o`3o=003oookJP03o`3o
2?oonf[ooo]Z00;ooo]Z00Koo`1ioookJ_oonf[ooo]Zoa00oonBo`07oookJPCoobP01_oonfX00ol0
g?oooo]ZoomB000<oookJP03ool0m_oonf[oo`0000Goo`0000?ooo]ZoolX0?oo:0000ooo:0001?oo
nf[oobP0oolX0?oo0006oolX00?ooo]Z0_oo0009oomi00Wooo]Z0ooo:009oookJP03og00oooonf[o
oo]Z00CoogT01OoonfX00omQ0?oooo]ZoookJP02oookJP03ok?o0?oonf[ooo]Z00Kooo]Z0ooUo`08
ool001;ooo]Z00Oooe80oookJ_oonf[o02[ooookJ_l0g?oo0?oO00Cooo]Z00?o4P3oool00?oo0000
1ooonfX01?oo003ooo]ZoookJ_lV0?l=oookJP04o`3oFooonf[o0?n`o`0`o`;ooo]Z0ooo:0000onB
o`3ooo]Zoa00o`04oookJP05ool0DOoonf[o0:gooookJ_oo07T01OoonfX01_l0oe?ooo]ZoookJ_l0
oago0?l8o`3Qo`Sooo]Z00?o0?ldoookJ_l0odh01?oonfX00ol0R?oooo]Zo`2Yo`03oookJP03o`04
ool0e?oooo]Z00_ooo]Z00?ooh40oookJ_oonfX02?oonfX00ooo02gooo]ZoookJP1GoookJP03o`1c
oooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01OoonfX00oooTP3ooo]ZoookJP02oookJP06ool0
o?oonf[ooo]ZoookJ_lH0?ooo`H00_oonfX03oo[o`3ooo]ZoookJ_oonf[o0:KooookJ_nX0?ooo`3i
oookJ_l0Mooooo]Zo`3oV_ooK03ooo]Zoc_o0003oookJP0:o`3koooonf[ooo]Zool30?oonf[oN@3o
ool0gOl05ooo0:?ook?o00?ooo]Z00Go0?oNoookJ_oonf[oo`1/odd0o`02oookJP03of40ool0odGo
oo]Z00;ooo]Z00?o0?n@o`3oT_oonfX01?oonfX01omX0?oooo]ZoookJ_lH0?ooi_l0oookJ_ooT000
1_oonfX00ooo_P3o0?l5og00o`03oookJP05oomG0?oonf[ooo]ZoookJ_oo02d02_oonfX00ol0e?oo
00Coo`28o`02oookJP03o`3oC_l0ocCooo]Z00;ooo]Z00Go0?l8oookJ_oonf[ooo]Zool0N@03oook
JP03oa00oonBo`3ooo]Z00Sooo]Z00?o9P3ooookJ_oonfX01_oonfX00ol0g?oooo]ZoomB000;oook
JP03ool0m_oonf[ooo]Z00?ooo]Z00?o/ol0oookJ_oonfX00ooonfX00olH0?oooo]ZoookJP04oook
JP04o`000?l01?oo0000o`0001[ooo]Z00?o0=CooookJ_oonfX01ooonfX00om`0?oooo]ZoookJP02
oookJP03oaP0oooonf[ooo]Z00Cooo]Z00?oH@3ooookJ_oonfX00_oonfX00onco`3ooo]ZoookJP08
oookJP03ool0m_oonf[ooo]Z00;ooo]Z00?oo`3loookJ_oonfX05?oonfX01_ooDP3ooo]Zo`0Zoooo
nf[o0=coo`3og`Gooo]Z00?o4P3ooookJ_oobP001_oonfX01?oQo`3ooo]ZoookJ_lV0?l=oookJP05
o`3oFooonf[o0?n`oookJ_l0<?l00_oonfX00ol60?oooo]Zoi;o0002oookJP03oa00oooonf[ooo]Z
00;ooo]Z00Coo`1AoookJ_l0[Oooo`1i1_oonfX01Ol0oe?ooo]ZoookJ_l0oago0>7o00Wooo]Z00?o
0?ldo`3oC_oonfX01?oonfX00ol0R?oo0:WooookJP03oookJP03o`3Doooonf[ooo]Z00_ooo]Z00?o
oh40oookJ_oonfX02?oonfX00ooo02gooo]ZoookJP0ToookJP00=_oonfX00ol0Looooo]ZoookJP0A
oookJP03oomi0?oonf[oogT000;oogT00ooonfX00ooo5P3ooi80oookJP02oookJP0:ool0o?oonf[o
oo]ZoookJ_lH0?oooo]Zool60?oonf[ojol0ool0mP;ooo]Z00Ko0:KoojP0oooonf[ooo]Zool0nOl0
Mol2oookJP03oom/0?oo:03oobP000;oobP000?ooo]Zo`3koooo00000ooo0002oolX0003ool00?oo
N@3o/ol000Cooo]Z00WoogT0oookJ_oonf[oo`1/oolX0?oonf[oH@3ooookJ_oo:0000_oonfX00ooo
:03ooo]Zo`3oTP04oookJP07ofP0oooonf[o603ooookJ_l0M?ooi_l0ool00007oookJP03oonn0?m`
0?oooo]Z00?ooo]Z00CoogT0oookJ_oonf[oo`0]2_oonfX01ol0e?oooo]ZoookJ_l0R?oooo]Zo`3o
C_l0oc@00ooonfX00ol0o`Sooo]ZoookJP02oookJP05ool0NOoonf[ooo]ZoookJ_nBo`002?oonfX4
oolX00Kooo]Z00?o0=cooookJ_ooDP002ooonfX00ooo0?Kooo]Zool00006ool000GoobP00_oonfX7
oolX0005o`000?oonf[ooo]ZoookJ_oo00001Ol@0?l7oomi00[ooo]Z00?oobP0oookJ_oonfX01ooo
nfX01?m`0?oooo]ZoookJ_oonfX3oomi00Gooo]Z00?oH@3ooookJ_oonfX00ooonfX00onco`3ooo]Z
oookJP04oookJP03ool00?oUo`3oiOl000;oiOl01ooo000BoookJP07oomB0?oonf[ooo]Zo`0Zoooo
nf[o0=coo`3og`04oookJP03oa80oooonf[oo`0000Cooo]Z00Coo`00oookJ_oonf[oo`000_oonfX0
0olV0?oooo]ZoookJP0;oookJP04o`3oFooonf[ooo]Zo`3o/0;ooo]Z0ooo:0000onBo`3ooo]Zoa00
o`04oookJP05ool0DOoonf[o0:gooookJ_oo07T01OoonfX01_l0oe?ooo]ZoookJ_l0oago0?l8o`3Q
o`Sooo]Z00?o0?ldoookJ_l0odh01?oonfX00ol0R?oooo]Zo`2Yo`03oookJP03o`04ool0e?oooo]Z
00_ooo]Z00?ooh40oookJ_oonfX02?oonfX00ooo02gooo]ZoookJP1GoookJP03o`1coooonf[ooo]Z
017ooo]Z00?oo`3ZoookJ_oonfX01_oonfX00oooTP3ooo]ZoookJP02oookJP06ool0o?oonf[ooo]Z
oookJ_lH0?ooo`H00_oonfX03oo[o`3ooo]ZoookJ_l0Y_oooo]ZojP0oooonf[oo`3ioookJ_l0Mooo
oo]Zo`3oV_ooK03ooo]Zoc_o0002oookJP0;o`3koooonf[ooo]ZoookJ_oo0`3ooo]ZogT0oooo0=go
01Ooo`2Soonco`000ooonfX01Ol0omkooo]ZoookJ_oo06coC@3o00;ooo]Z00OoH@3oo`3oAOoonf[o
oo]Zo`3oT?oonf[o0?nB00Cooo]Z00OoJ03ooookJ_oonf[o603oo`1doooVo`3ooi0000Oooo]Z00?o
okh0o`3o1Om`0?l00ooonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00[ooo]Z00Ko0=CooookJ_l0R?oo
oo]Zo`3oC_l0oc@4oookJP05o`3o2?oonf[ooo]ZoookJ_oo07T00ooonfX00ol@0?ooT_l0oookJP07
oookJP03obH0oooonf[ooo]Z00Oooo]Z00?o0=cooookJ_ooDP002ooonfX00ooo0?Kooo]ZoookJP02
oookJP03ok?o0?oonf[ooo]Z00?ooo]Z00?o603ooookJ_oonfX01OoonfX01?l01?oo0000o`000?l0
0004oookJPco403o2ooonfX00ol0e?oooo]ZoookJP06oookJP03og00oooonf[ooo]Z00;ooo]Z00?o
i_l0oaP0oooonfX01OoonfX00omQ0?oooo]ZoookJP02oookJP03ok?o0?oonf[ooo]Z00Cooo]Z00Go
of`0oookJ_oonf[ooo]Zool0mP04oookJP03ool0o?oonf[ooo]Z01?ooo]Z00Kooe80oookJ_l0:_oo
oo]Zo`3Lool0oml5oookJP03oa80oooonf[oolX000?ooo]Z00Coo`0CoookJ_oonf[ohOl00_oonfX0
0olV0?oooo]ZoookJP0;oookJP05o`3oFooonf[ooo]Zo`3o/?l0<?l00_oonfX00ol60?oooo]Zoi;o
0002oookJP03oa00oooonf[ooo]Z00;ooo]Z00Coo`1AoookJ_l0[Oooo`1i1_oonfX01Ol0oe?ooo]Z
oookJ_l0oago0>7o00Wooo]Z00?o0?ldo`3oC_oonfX01?oonfX00ol0R?oo0:WooookJP03oookJP03
o`3Doooonf[ooo]Z00_ooo]Z00?ooh40oookJ_oonfX02?oonfX00ooo02gooo]ZoookJP0ToookJP00
=_oonfX00ol0Looooo]ZoookJP0AoookJP03oomi0?oonf[ooo]Z00Gooo]Z00?ooaH0oonB0?oonfX0
0_oonfX02_oo0?cooo]ZoookJ_oonf[o603ooookJ_oo1P3ooo]Zon_o0?oo0?H2oookJP06o`2VoonX
0?oooo]ZoookJ_oo0?Wo07Oo0_oonfX00oooK03oobP0oolX0002oolX0003oookJ_l0noooo`0000;o
o`000_oo:0000ooo003oobP0ok?o0004oookJP04omgo0?ooN@3ooo]Zool0K0;oobP000?ooo]Zof40
oooo:0000ooonfX00ooo:03ooo]Zo`3oTP04oookJP07ofP0oooonf[oiOl0oookJ_oVo`3ooo]Zool0
0006oookJP03oonn0?oo:03oL03o00?ooo]Z00GoogT0oookJ_oonf[ooo]Zool0;@09oookJP07o`3D
ool01?oooo]ZoookJ_l0R?oo0?m>o`3o=004oookJP05o`3o2?oonf[ooo]ZoookJ_oo07T00ooonfX0
0ol@0?ooT_l0oookJP06oookJPGoobP01OoonfX01?l0g?oooo]ZoookJ_ooDP0;oookJP03ool0m_oo
003oo`0000Goo`001_oo:003oookJPGoobP00_l000001?oonf[o403ooa00ool@0?l4ool000Cooo]Z
1OooN@09oookJP03o`04oooo:03ooo]Z00Oooo]Z00?oL03ooookJ_oonfX00_oonfX2oomi00Kooo]Z
00?oH@3ooookJ_oonfX00_oonfX00onco`3ooo]ZoookJP04oookJPCoo`0000?oiOl0ool00?oo0000
1Ooo000BoookJP08o`3o<oooDP3ooo]Zo`0Zoooonf[o0=cooookJ_l0oml3oookJP03oa80oooonf[o
olX000Cooo]Z00Coo`00oookJ_oonf[oo`000_oonfX00olV0?oooo]ZoookJP0;oookJP04o`3oFooo
nf[ooo]Zo`3o/0;ooo]Z0ooo:0000onBo`3ooo]Zoa00o`05oookJP04ool0DOl0[Ooooo]Zool0N@Ko
oo]Z00Go0?mCoookJ_l0oago0?l8o`3Qo`08oookJP03o`3o=?oonf[o0?m>00Gooo]Z00?o08Soo`2Y
oooonfX00_oonfX00ol01?oooo]Zo`3Do`0;oookJP03oon10?oonf[ooo]Z00Sooo]Z00?oo`0]oook
J_oonfX0EooonfX00ol0Looooo]ZoookJP0AoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooi80oook
J_oonfX00_oonfX01_oo0?cooo]ZoookJ_oonf[o603oool600;ooo]Z00Wojol0oookJ_oonf[o0:Ko
oookJ_nX0?oooo]Zool0nOl0Mol00_oonfX01?l0oi[oof`0oookJ_lko`02oookJP0:o`3koooonf[o
oo]ZoookJ_oo0`3ooo]Zool0gOoonf[o01Oook?o00Cooo]Z00Go0?oNoookJ_oo06cooo]Zodd0o`02
oookJP07of40oooonf[ooo]ZoookJ_l0oi3ooo]Zo`3oTP04oookJP07ofP0oooonf[ooo]ZoaP0oooV
o`3ooo]Zoon@0006oookJP04oonn0?oonf[o0?l5og00o`?ooo]Z00CooeL0oookJ_oonf[oo`0]2_oo
nfX01ol0e?oo00CooookJ_l0R?oooo]Zo`3oC_l0oc@01?oonfX01?l0o`Sooo]ZoookJ_oo07T3oook
JP03oa00oooonf[oT_l000Sooo]Z00?o9P3ooookJ_oonfX01_oonfX00ol0g?oooo]ZoomB000;oook
JP03ool0m_oonf[ooo]Z00?ooo]Z00?o/ol0oookJ_oonfX00_oonfX00olH0?oooo]ZoookJP05oook
JP03o`04ool0003o000000;o000000Cooo]Zoa00ool@0?oo403o3?oonfX00ol@0?oooo]ZoookJP08
oookJP03o`04ool0e?oooo]Z00Oooo]Z00?oL03ooookJ_oonfX00_oonfX00olH0?oooo]ZoookJP04
oookJP03of40oooonf[ooo]Z00;ooo]Z00?o/ol0oookJ_oonfX01?oonfX01OooK03ooo]ZoookJ_oo
nf[oo`3f00Cooo]Z00?oo`3loookJ_oonfX04ooonfX01ol0oc?ooe80o`0Zoooonf[o0=cooookJ_l0
oml01?oonfX00olB0?oooo]Zooo:0003oookJP04ool04ooonf[ooo]Zon7o00;ooo]Z00?o9P3ooook
J_oonfX02ooonfX01Ol0oe_ooo]ZoookJ_l0ok3o033o00?ooo]Z00Go1P3ooi;o0?oonf[ooo]Zoa00
o`04oookJP04ool0DOoonf[o0:goool0N@Kooo]Z00Go0?mCoookJ_oonf[o0?lMo`3Qo`09oookJP03
o`3o=?l0odkooo]Z00Gooo]Z00?o0:WooookJ_oonfX00_oonfX00ol01?oo0=CooookJP0;oookJP03
oon10?oonf[ooo]Z00Sooo]Z00?oo`0]oookJ_oonfX09?oonfX003Kooo]Z00?o07?ooookJ_oonfX0
4OoonfX00oooN@3ooo]ZoookJP05oookJP03oolF0?ooTP3ooo]Z00;ooo]Z00[oo`3loookJ_oonf[o
oo]ZoaP0oooonf[oo`H0on_o0?oonf[oo`3f0_oonfX02?l0Y_ooZ03ooookJ_oonf[oo`3io`1goooo
nf[o0?nJ1Ooo:0000ooonf[o0?_oool00002ool000;oobP000?oo`00oolX0?nco`001?oonfX01?oM
o`3oogT0oookJ_oo06`2oolX0003of40oooonf[oobP000?ooo]Z00?oobP0oookJ_l0oi801?oonfX0
1omX0?oooo]ZonGo0?l0M?ooi_l0oookJ_oo00001_oonfX00ooo_P3oobP0og00o`03oookJP05oomi
0?oonf[ooo]ZoookJ_oo02d02OoonfX01ol0e?oo00CooookJ_l0R?oooo]Zo`3oC_l0oc@01?oonfX0
1Ol0o`Sooo]ZoookJ_oonf[oo`1i00?ooo]Z00?o403ooi;o0?oonfX01_oonfX5oolX00Gooo]Z00?o
0=cooookJ_ooDP002ooonfX00ooo0?Koo`00ool00006ool000KoobP00_oonfX00ooo003oobP0oolX
0002oolX00?o000000?o403oool00?oo00001_oo0005oookJP04oolX0?ooN@3oogT0oomi00Wooo]Z
00?o0=CooookJ_oonfX01ooonfX00om`0?oooo]ZoookJP02oookJP03oomi0?oonf[ooo]Z00Cooo]Z
00?oH@3ooookJ_oonfX00_oonfX00onco`3ooo]ZoookJP08ool00003onGo0?oo003oo`0000Coo`00
4ooonfX02?l0oc?ooe80oookJ_l0:_oooo]Zo`3Loooonf[o0?oO0ooonfX00olB0?oooo]Zooo:0004
oookJP04ool00?oonf[ooo]Zool000;ooo]Z00?o9P3ooookJ_oonfX02ooonfX01?l0oe_ooo]Zoook
J_l0ok03oookJP;oobP000?oT_l0oookJ_l@0?l01OoonfX01?oo057o0:gooookJ_oo07T6oookJP05
o`3oDooonf[o0?lMoookJ_l0hOl02?oonfX00ol0ocCooo]Zo`3oCP05oookJP03o`28ool0ZOoooo]Z
00;ooo]Z00?o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP08oookJP03ool0;Ooonf[ooo]Z
05Oooo]Z00?o07?ooookJ_oonfX04OoonfX00ooo0>[ooo]ZoookJP06oookJP03oonB0?oonf[ooo]Z
00;ooo]Z00Woo`3loookJ_oonf[o603ooookJ_oo1P3ooo]Zon_o0?oo0?H00_oonfX03?l0Y_oooo]Z
ojP0oooonf[oo`3io`1goooonf[o0?nJoookJ_ooK03ooo]Zoc_o00;ooo]Z00[o0?_ooookJ_oonf[o
oo]Zool30?mi0?ooo`3MoookJ_l0Xooo/ol01?oonfX02?l0omkooo]Zool0K?oonf[oC@3ooookJ_mQ
0?oo0?m50ooonfX00ol0oi3ooo]Zo`3oTP04oookJP07ofP0oooonf[ooo]ZoaP0oooVo`3ooo]Zoon@
0006oookJP04oonn0?oonf[o0?l5og00o`;ooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@0:oookJP03
o`3Dool01?oo08So00;ooo]Z00?o0?m>o`3o=?oonfX00ooonfX01?l0o`Sooo]ZoookJ_oo07T3oook
JP03oa00oonBo`3ooo]Z00Sooo]Z00?o9P3ooookJ_oonfX01_oonfX00ol0g?oooo]ZoomB000:oook
JP03ool0m_oonf[ooo]Z00?ooo]Z00?o/ol0oookJ_oonfX00_oonfX00olH0?oooo]ZoookJP05oook
JP03o`04oooonf[o000000?o000000?o403ooookJ_oonfX03_oonfX00ol@0?oooo]ZoookJP08oook
JP03o`3Doooonf[ooo]Z00Kooo]Z00?oL03ooookJ_oonfX00_oonfX00ooVo`3o603ooookJP04oook
JP03of40oooonf[ooo]Z00;ooo]Z00?o/ol0oookJ_oonfX01?oonfX01OooK03ooo]ZoookJ_oonf[o
o`3f00Cooo]Z00?oo`3loookJ_oonfX04ooonfX01ol0oc?ooe80o`0Zoooonf[o0=cooookJ_l0oml0
1?oonfX00olB0?oooo]Zooo:0003oookJP04ool04ooonf[ooo]Zon7o00;ooo]Z00?o9P3ooookJ_oo
nfX02ooonfX01Ol0oe_ooo]ZoookJ_l0ok3o033o00?ooo]Z00Go1P3ooi;o0?oonf[ooo]Zoa00o`04
oookJP04ool0DOoonf[o0:goool0N@Kooo]Z00Go0?mCoookJ_l0o`So0?lMo`3Qo`09oookJP03o`3o
=?l0odkooo]Z00Gooo]Z00?o0:WooookJ_oonfX00_oonfX00ol01?oo0=CooookJP0;oookJP03oon1
0?oonf[ooo]Z00Sooo]Z00?oo`0]oookJ_oonfX09?oonfX002[ooo]Z0ol007l5oookJPCo001o00?o
07?ooookJ_oonfX04OoonfX00oooN@3ooo]ZoookJP04oookJP03oolF0?oonf[ooi8000?ooo]Z00Co
o`3loookJ_oonf[o603o0_oonfX01?oo1P3ojol0oookJ_oo0?H2oookJP08o`2VoonX0?oooo]Zoook
J_oo0?Wo07OooookJ_l0oiX5oolX0003oookJ_l0noooo`0000;oo`000_oo:0001?oo003oogT0ok?o
0?oo0003o`00O`04oomi0?oonf[ooo]Zool0K0;oobP000?oH@3ooookJ_oo:0000_oonfX01?oo:03o
oo]ZoookJ_l0oi84oookJP06ofP0oooUo`3oiOl0o`1doooVo`3oo`001ooonfX00ooo_P3oobP0og00
o`03oookJP05oomi0?oonf[ooo]ZoookJ_oo02d02OoonfX02?l0e?oo00CooookJ_l0R?oooo]Zo`3o
C_l0ocCooo]Z0_l007l00ol0o`So001oo`00O`02oookJP05ool0NOoonf[ooo]ZoookJ_nBo`001ooo
nfX5oolX00Kooo]Z00?o0=cooookJ_ooDP002ooonfX9ool000GoobP000Cooo]Zool00?oo003oo`00
0ooo:003o`000003oa00oooo003oo`0000Ooo`000_oonfX6oolX0003oookJ_ooN@3ooo]Z00Oooo]Z
00?o00Coo`3DoooonfX01ooonfX00om`0?oooo]ZoookJP02oookJP03oaP0oooonf[ooo]Z00Cooo]Z
00?oH@3ooookJ_oonfX00ooonfX00onco`3ooo]Zool00007ool000;oiOl01Ooo000DoookJP07oomB
0?oonf[o02[ooookJ_l0g?oooo]ZoolX0003oookJP03oa80oooonf[oolX000Cooo]Z00Coo`00oook
J_oonf[oo`000_oonfX00olV0?oooo]ZoookJP0;oookJP04o`3oFooonf[ooo]ZoolX00?o001o0_oo
:0001?nBo`3ooo]ZoookJ_l@0?l4o`00O`04ool0DOl0[Ooooo]Zool0N@Kooo]Z00Go0?mCoookJ_l0
oagooo]Zo`3Qo`08oookJP03o`3o=?oonf[o0?m>00Gooo]Z00?o08Soo`2YoooonfX00_oonfX00ol0
1?oooo]Zo`3Do`0;oookJP03oon10?oonf[ooo]Z00Cooo]Z0ol007l00ooonf[oo`0]oookJP02oook
JPGo001oA_oonfX3o`00O`Gooo]Z0ol007l00ol0Looo001ooookJP0AoookJP03ool0j_oonf[ooo]Z
00Gooo]Z00?ooaH0oonB0?oonfX00_oonfX02_oo0?cooo]ZoookJ_oonf[o603ooookJ_oo1P3ooo]Z
on_o0?oo0?H2oookJP0<o`2Voooonf[oZ03ooookJ_oo0?Wo07OooookJ_l0oi[ooo]Zoom/0?oonf[o
>ol00_oonfX02_l0nooo001oo`00Oooonf[oo`<0ogT0oooo0=gooo]Zo`2Soonco`03o`00O`09o`3o
g_oonf[ooo]Zool0K?oonf[oC@3ooookJ_mQ0?oo0?m500?ooo]Z00?o0?n@oookJ_l0oi801?oonfX0
1_mX0?oooo]ZoookJ_lH0?ooi_l0oon@00Oooo]Z00Cookh0o`3o1Ooonf[oL03o0_oonfX01OooE`3o
oo]ZoookJ_oonf[oo`0]00[ooo]Z00?o0=Coo`04ool0R?l00_oonfX00ol0odko0?ldo`00O`02o`00
O`05o`3o2?l007oooo]ZoookJ_oo07T00ooonfX00ol@0?ooT_l0oookJP07oookJP03obH0oooonf[o
oo]Z00Oooo]Z00?o0=cooomB0?oonfX02_oonfX00ooo0?Kooo]ZoookJP08oookJP03oaP0oooonf[o
oo]Z00Cooo]Z00?o00CooookJ_oonfX00ol000000ol@0?oooo]ZoookJP0@oookJP03oa00oooonf[o
oo]Z00Oooo]Z00?o00Coo`3DoooonfX01_oonfX00om`0?oooo]ZoookJP02oookJP03onKo0?lH0?oo
oo]Z00Cooo]Z00?oH@3ooookJ_oonfX00ooonfX00onco`3ooo]ZoookJP03oookJP05oom/0?oonf[o
oo]ZoookJ_oo0?H00_l007l00olH0?oo001oool0o00EoookJP07o`3o<oooDP3o02[ooookJ_l0g?oo
oo]Zo`3og`04oookJP03oa80oooonf[oolX000?ooo]Z00Coo`0CoookJ_oonf[ohOl00_oonfX00olV
0?oooo]ZoookJP0;oookJP05o`3oFooonf[ooo]Zo`3o/?l0<?l00_l007l00ooonf[o1P3ooi;o0002
oookJP03oa00ool007oo001o00;o001o00Cooo]Zool0DOl0[Oooo`1i1_oonfX01Ol0oe?ooo]Zo`3o
2?l0oago0>7o00Wooo]Z00?o0?ldo`3oC_oonfX01OoonfX00ol0ZOoooo]ZoookJP02oookJP03o`04
ool0e?oooo]Z00_ooo]Z00?ooh40oookJ_oonfX01?oonfX3o`00O`03oookJ_oo02gooo]Z00;ooo]Z
1Ol007lNoookJP00:_oonfX3o`00O`Cooo]Z1Ol007l00ol0Looo001ooookJP0AoookJP03oomi0?oo
nf[ooo]Z00Cooo]Z00?ooaH0oonB0?oonfX00ooonfX01?oo0?cooo]ZoookJ_lH0?l2oookJP04ool6
0?o[o`3ooo]Zool0mP;ooo]Z00So0:KoojP0oooonf[oo`3ioookJ_l0Mooooo]Zoom/00GoobP000Co
0?_oool00?oo003oo`000ooo:0001?oo003oogT0ok?o0?oo0003o`00O`04oomi0?oonf[ooo]Zool0
K0;oobP000?oH@3ooookJ_oo:0000_oonfX00ooo:03ooo]Zo`3oTP04oookJP07ofP0oooonf[oiOl0
onGo0?l0M?ooi_l0ool00007oookJP03oonn0?oo:03oL03o00?ooo]Z00GoogT0oookJ_oonf[ooo]Z
ool0;@08oookJP08o`3Dool01?oooo]ZoookJ_l0R?oooo]Zo`3oC_l0oc@3o`00O`05o`3o2?l007oo
001oo`00Oooo07T00ooonfX00ol@0?ooT_l0oookJP06oookJPGoobP01OoonfX01?oob@3ooo]Zoook
J_ooDP0:oookJPWoo`001_oo:005ool00003oolX0?oonf[o000000;o403o00?o0000oookJ_oonfX0
1ooo0008oolX0003oookJ_l@0?oooo]Z00Sooo]Z00?o0=CooookJ_oonfX01_oonfX00om`0?oooo]Z
oookJP02oookJP03oaP0oooonf[ooo]Z00Cooo]Z00?oH@3ooookJ_ooN@002?ooN@05ool000;oiOl0
1Ooo000DoookJP07oomB0?oonf[o02[ooookJ_l0g?oooo]ZoolX0003oookJP03oa80oooonf[oolX0
00Cooo]Z00Coo`00oookJ_oonf[oo`000_oonfX00olV0?oooo]ZoookJP0;oookJP04o`3oFooonf[o
oo]ZoolX00?o001o0_oo:0001?nBo`3ooo]Zo`00Ool@0?l4o`00O`04ool0DOl0[Ooooo]Zool0N@Ko
oo]Z00Go0?mCoookJ_l0oagooo]Zo`3Qo`08oookJP03o`3o=?oonf[o0?m>00Gooo]Z00?o08Soo`2Y
oooonfX00_oonfX00ol01?oooo]Zo`3Do`0;oookJP03oon10?oonf[ooo]Z00Cooo]Z0ol007l01?oo
nf[oo`0]oookJ_oonfX7o`00OdGooo]Z0ol007l4oookJPCo001o00?o07?oo`00Ool007l04OoonfX0
0ooo0>[ooo]ZoookJP05oookJP03oonB0?oonf[ooo]Z00;ooo]Z00[oo`3loookJ_oonf[ooo]ZoaP0
oooonf[oo`H0oookJ_o[o`3oo`3f0_oonfX02Ol0Y_oooo]ZojP0oooo0?Wooo]Zo`1goooonf[o0?nJ
oom/0002oookJP04oc_o0?oonf[ooo]Zo`3ko`;o001o00Ooo`<0oookJ_mi0?ooo`3Mo`0Gool0Xooo
/ol000?o001o00Wo0?oNoookJ_oonf[oo`1/oookJ_m=0?oooo]Zof40ool0odD00_oonfX00ol0oi3o
oo]Zo`3oTP04oookJP07ofP0oooonf[ooo]ZoookJ_lH0?ooi_l0oon@0007oookJP03oonn0?l0o`Go
L03o00?ooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@09oookJP04o`3Dool01?oooo]Zo`28o`;ooo]Z
00?o0?m>o`00Ool007l00_l007l01?l0o`So001oo`00Oooo07T3oookJP03oa00oooonf[oT_l000So
oo]Z00?o9P3ooookJ_oonfX01_oonfX00ol0g?oooo]ZoomB000:oookJP03ool0m_oonf[ooo]Z00So
oo]Z00?o603ooookJ_oonfX01?oonfX01?l01?oooo]ZoookJ_oonfX2o`000003oa00ool0003ooo]Z
017ooo]Z00?o403ooookJ_oonfX02?oonfX00ol0e?oooo]ZoookJP06oookJP06og00oooonf[ooo]Z
oookJ_l0M?oo603o1_oonfX00omQ0?oooo]ZoookJP02oookJP03ok?o0?oonf[ooo]Z00?ooo]Z00Go
of`0oookJ_oonf[ooo]Zool0mP02o`00O`04oaP0ool007ooo`3lo`00OaGooo]Z00Kooe80o`0Zoooo
nf[o0=cooookJ_l0oml4oookJP03oa80oooonf[oolX000?ooo]Z00Coo`0CoookJ_oonf[ohOl00_oo
nfX00olV0?oooo]ZoookJP0;oookJP05o`3oFooonf[ooo]Zo`3o/?l0<?l00_l007l01_oonf[o1P3o
oi;o0?oonf[o001ooa00o`Go001o00?oo`1Ao`2]oooo07T01_oonfX01Ol0oe?ooo]Zo`3o2?l0oago
0>7o00Wooo]Z00?o0?ldo`3oC_oonfX01OoonfX00ol0ZOoooo]ZoookJP02oookJP03o`04ool0e?oo
oo]Z00_ooo]Z00?ooh40oookJ_oonfX01?oonfX3o`00O`04oookJ_oo02gooo]ZoookJPOo001o7Ooo
nfX002[ooo]Z0ol007l3oookJPCo001o00Cooo]Zo`1cool007oo001o4_oonfX00oooN@3ooo]Zoook
JP04oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00Coo`3loookJ_oonf[o603o0_oonfX03Ooo1P3ojol0
oookJ_oo0?Kooo]Zo`2Voooonf[oZ03ooookJ_oo0?Wooo]Zo`1goooonfX01_oo:0001?l0nooo001o
o`00Ool007l2oolX0006ool00?oo:03oogT0ok?o0?oo003ooo]Z0_l007l00oooN@3ooo]Zool0K003
oolX0003of40oooonf[oobP000;ooo]Z00?oobP0oookJ_l0oi801?oonfX00omX0?oooo]ZonGo0002
onGo0003onKo0?oonf[ooo]Z00Gooo]Z00CoobP0oonn0?oo:03oL03o0_oonfX01OooN@3ooo]Zoook
J_oonf[oo`0]00Wooo]Z00Oo0=Coo`04oooonf[ooo]Zo`28oooonf[o0?m>00Co001o00Go0?l8o`00
Ool007oo001oool00003oookJP03oa00oonBo`3ooo]Z00Gooo]Z1_oo:005oookJP03ooo90?oonf[o
oe8000_ooo]Z00?oo`3foookJ_oo00001_oo0005oolX00Koo`000_oonfX01?l@0?oo0000o`000?l0
0004oookJPGoo`002?oo:002oookJP03oa00oooonf[ooo]Z00Kooo]Z00?o00Coo`3DoooonfX01_oo
nfX00om`0?oooo]ZoookJP02oookJP03oaP0oooonf[ooo]Z00Cooo]Z00?oH@3ooookJ_ooN@002?oo
N@05ool000;oiOl01Ooo000DoookJP07oomB0?oonf[o02[ooookJ_l0g?oooo]ZoolX0003oookJP03
oa80oooonf[oolX000?ooo]Z1ooo00000olV0?ooogT0oomi0002oomi00Wooo]Z00Go0?mKoookJ_oo
nf[oobP0o`0`o`02o`00O`08oookJ_oo:03ooo]Zoi;o0?l007oo403oo`00OooonfX2o`00O`04ool0
DOl0[Ooooo]Zool0N@Kooo]Z00Co0?mCoookJ_l0oago0>7o2_oonfX00ol0ocCo0?m>oookJP04oook
JP03o`28ool0ZOoooo]Z00;ooo]Z00?o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP04oook
JP?o001o00?ooo]Zool0;OoonfX01?l007l01?oonf[o001oo`00Ool007m5oookJP?o001o0ooonfX4
o`00O`04o`1cool007oo001oo`00Oa7ooo]Z00?oo`3ZoookJ_oonfX01OoonfX00oooTP3ooo]Zoook
JP02oookJP0<ool0o?oonf[ooo]ZoookJ_lH0?oooo]Zool60?oonf[ojol0ool0m_oonf[o0:Ko0_oo
nfX01onX0?ooo`3ioookJ_l0Mooooo]Zo`3oV_ooK0000_oonfX00olko`3ooo]Zo`3ko`03o`00O`08
ool30?oonf[oo`3MoookJ_l05ooo0:?ook?o0?oonfX2o`00O`05o`3og_oonf[oo`1/oookJ_m=0?l0
0_oonfX01omQ0?oo0?m5oookJ_oonf[o0?n@oookJ_l0oi801?oonfX01_mX0?oooo]ZoookJ_oonf[o
603oonKo00Sooo]Z00?ookh0o`3o1Om`0?l00ooonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00Wooo]Z
00Oo0=Coo`04oooonf[o08SooookJ_l0odko0?ld00?o001o00Gooo]Zo`3o2?l007oo001oool0N@03
oookJP03oa00oonBo`3ooo]Z00Sooo]Z00?o9P3ooookJ_oonfX01_oonfX00ol0g?oooo]ZoomB000:
oookJP03ool0m_oonf[ooo]Z00Sooo]Z00?o603ooookJ_oonfX02?oonfX01?l0003o403oo`000?l0
000CoookJP03oa00oooonf[ooo]Z00Oooo]Z00?o0=CooookJ_oonfX01_oonfX01_m`0?oooo]Zoook
J_oonf[o07CooaP0o`Kooo]Z00?oH@3ooookJ_oonfX00_oonfX00onco`3ooo]ZoookJP03oookJP03
oom/0?oonf[ooo]Z00;o001o00Koo`3fo`00OolH0?oo001oool0o?l007lEoookJP06oomB0?l0:_oo
oo]Zo`3Loooonf[o0?oO1?oonfX00olB0?oooo]Zooo:0003oookJP08ool04ooonf[ooo]ZoookJ_oQ
o`3ooo]ZobH0oolPo`0<oookJP05o`3oFooonf[ooo]Zo`3o/?l0<?l00_l007l02?oonf[o1P3ooook
J_nBo`3o001ooa00ool007oooo]Z0ol007l00ooo057o0:goool0N@06oookJP05o`3oDooonf[o0?l8
o`3o7Ol0hOl02OoonfX00ol0ocCo0?m>oookJP05oookJP03o`2Yoooonf[ooo]Z00;ooo]Z00?o00Co
o`3DoooonfX02ooonfX00oooP@3ooo]ZoookJP04oookJP?o001o00?ooo]Zool0;OoonfX01?l007l0
1?oonf[o001oo`00Ool007lMoookJP006_oonfX:o`00O`Kooo]Z0ol007l3oookJP?o001o0_oonfX0
1?l0Looo001oo`00Ool007lAoookJP03oomi0?oonf[ooo]Z00Cooo]Z00?ooaH0oonB0?oonfX00_oo
nfX05?oo0?cooo]ZoookJ_oonf[o603ooookJ_oo1P3ooo]Zon_o0?oo0?Kooo]Zo`00Ool0Y_oo001o
ojP0ool007ooo`3io`00Ool0Mooo0?nJ1ooo:003o`00O`;oobP000Goo`00oolX0?nco`3oW`3oool0
0002oookJP04omgo0?ooN@3o001oool0K0;oobP000CoH@3ooolX0?oonf[oobP00_oonfX00ooo:03o
oo]Zo`3oTP04oookJP03ofP0oooUo`3oiOl000;oiOl02?oonfX01?oo:03ookh0og00oooo:002oook
JP05oomi0?oonf[ooo]ZoookJ_oo02d01?oonfX5o`00O`07o`3Dool01?oo001oo`28ool007oo0?m>
o`3o=003o`00O`03oookJ_l0o`Sooo]Z00;o001o00Koo`00oookJ_oonf[ooo]Zoa00oonBo`05oook
JPOoobP01?oonfX2ooo90003oookJ_ooDP3ooo]Z00[ooo]Z00Coo`3foookJ_oonf[ooo]Z1Ooo0005
oolX00Koo`0000?ooo]Zoa00ool000000ol00006oookJPCoo`001ooo:003oookJP03oa00oooonf[o
oo]Z00Kooo]Z00?o0=CooookJ_oonfX01OoonfX00om`0?oooo]ZoolX0003oolX0003oaP0oooo:03o
obP000;oobP000Cooo]Zof40oooonf[ooo]Z2?ooN@04ool00004o`00OooUo`3oiOl0oookJPCoo`00
5?oonfX01oooDP3ooo]Zo`0Zoooonf[o0=cooookJ_oo:0001?oonfX00olB0?ooolX0oookJP02oook
JPCoo`000oooN@000olV0?ooogT0oomi0002oomi00Wooo]Z00Go0?mKoookJ_oonf[oobP0o`0`o`02
o`00O`06oookJ_oo:03ooo]Zoi;o0?l007oo403o0ooonfX01Ol007ooo`1Ao`2]oooonf[oo`1i00Ko
oo]Z00Co0?mCoookJ_l0oago0>7o2_oonfX00ol0ocCo0?m>oookJP04oookJP03o`28ool0ZOoooo]Z
00;ooo]Z00?o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP04oookJP?o001o00?ooo]Zool0
;OoonfX00ol007l3oookJP?o001o=?oonfX:o`00O`Kooo]Z0ol007l3oookJP?o001o00?ooo]Zo`1c
oooonfX00ol007l@oookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooi80oookJ_oonfX00_oonfX01_oo
0?cooo]ZoookJ_oonf[o603oool600;ooo]Z00Cojol0ool0m_l007oo0:Ko0_l007l01onX0?ooo`3i
o`00Ool0Mooo0?nJo`00OoooK0000_oonfX00olko`3ooo]Zo`3ko`03o`00O`07ool30?oonf[oo`3M
o`00Ool05ooo/ol0oil0o`02oookJP0:o`00Ool0omko001oool0K?oonf[oC@3ooookJ_mQ0?oooo]Z
o`3oA@;ooo]Z00?o0?n@oookJ_l0oi801?oonfX01OmX0?oooo]ZoookJ_lH0?ooi_l000Wooo]Z00?o
okh0o`3o1Om`0?l00_oonfX00oooE`3ooo]ZoookJP02oookJP04ool0;Ooonf[ooo]ZoookJPKo001o
00Oo0=Coo`04ool0R?oo001ooookJ_l0odko0?ld00;o001o0_oonfX01?l0o`So001oo`00Oooo07T3
oookJP03oa00oonBo`3ooo]Z00Sooo]Z00?o9P3ooookJ_oonfX01_oonfX00ol0g?oooe80oookJP0:
oookJP03ool0m_oonf[ooo]Z00Oooo]Z00?o603ooookJ_oonfX02OoonfX01?l@0?oo0000o`000?l0
000DoookJP03oa00oooonf[ooo]Z00Oooo]Z00?o0=CooookJ_oonfX01OoonfX00om`0?oooo]Zoook
JP02oookJP03onKo0?lH0?oooo]Z00Cooo]Z00?oH@3ooookJ_oonfX00_oonfX00onco`3ooo]Zoook
JP03oookJP03oom/0?oonf[ooo]Z00;o001o00Goo`3foookJ_lH0?oooo]Zool0o002o`00OaCooo]Z
00Kooe80o`0Zoooonf[ooo]Zo`3Lool0oml4oookJP03oa80oooonf[oolX000?ooo]Z00Goo`0Coook
J_oonf[ooo]Zon7o0002oookJP03obH0oooonf[ooo]Z00[ooo]Z00Go0?mKoookJ_oonf[o0?n`o`0`
o`02o`00O`06oookJ_l60?oooo]Zoi;o0?l007oo403o0ooonfX2o`00O`03ool0DOl0[Oooo`1i00Ko
oo]Z00Go0?mCoookJ_l0o`So0?lMo`3Qo`09oookJP03o`3o=?l0odkooo]Z00Gooo]Z00?o0:Wooook
J_oonfX00_oonfX00ol01?oo0=CooookJP0;oookJP03oon10?oonf[ooo]Z00Cooo]Z0ol007l00ooo
nf[oo`0]oookJP03o`00O`?ooo]Z0ol007lLoookJP006_oonfX:o`00O`Kooo]Z0ol007l8oookJP04
o`1cool007oo001oo`00Oa7ooo]Z00?oogT0oookJ_oonfX01?oonfX00ooo5P3ooi80oookJP02oook
JP04ool0o?oonf[ooo]ZoaP0o`;ooo]Z00Soo`H0oookJ_o[o`3oo`3foookJ_l007oo0:KoojP0o`;o
001o00Coo`3io`00Ool0Mooo0?nJ1ooo:002o`00O`?oobP000?oo`00oomi0?nco`000_oo0002oook
JP04omgo0?ooN@3o001oool0K0;oobP000?oH@3ooolX0?oo:0000ooonfX00ooo:03ooo]Zo`3oTP04
oookJP03ofP0oooUo`3oiOl000;oiOl02?oonfX00ooo_P3oobP0og00o`02oolX0003oookJ_ooN@3o
oo]Z00;ooo]Z00?oo`0]oookJ_oonfX00_oonfX5o`00O`07o`3Dool01?oo001oo`28ool007oo0?m>
o`3o=004oookJP03o`3o2?oonf[o001o00;oo`000_oonfX00ol@0?ooT_l0oookJP05oookJPOoobP0
1?oonfX2ooo90003oookJ_ooDP3ooo]Z00Wooo]Z00?oo`3foookJ_oonfX00ooonfX3ool000GoobP0
1_oo00000ooonf[o403ooookJP04o`0000Sooo]Z0_oo0007oolX00Cooo]Z00?o403ooookJ_oonfX0
1OoonfX00ol01?oo0=CooookJP06oookJP03og00oooo:03oobP000;oobP000?o603ooolX0?oo:000
0_oo:002oookJP03of40oooonf[oogT000KoogT01Ooo0002oookJP03onGo0?oonf[oo`0000Coo`00
4ooonfX01oooDP3ooo]Zo`0Zoooonf[o0=cooookJ_oo:0001?oonfX00olB0?ooolX0oookJP03oook
JP?oo`000oooN@000olV0?ooogT0oomi0002oomi00Wooo]Z00Go0?mKoookJ_oonf[oobP0o`0`o`02
o`00O`06oookJ_l60?oooo]Zoi;o0?l007oo403o0ooonfX01?l007ooo`1Ao`2]oooo07T7oookJP04
o`3oDooonf[o0?lMo`3Qo`[ooo]Z00?o0?ldo`3oC_oonfX01?oonfX00ol0R?oo0:WooookJP02oook
JP03o`04oooonf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX01?oonfX3o`00O`03oookJ_oo02gooo]Z
00Kooo]Z0ol007ldoookJP[o001o1_oonfX3o`00O`Oooo]Z00?o07?ooookJ_l007l00_l007l@oook
JP03ool0j_oonf[ooo]Z00Gooo]Z00?ooi80oookJ_oonfX00_oonfX01_oo0?cooo]ZoookJ_lH0?oo
oo]Zool600;ooo]Z00gojol0ool0m_l007oo0:Koo`00OonX0?oo001oool0nOl007oo07Ooo`3oV_l0
07ooof`000;ooo]Z00?o>ol0oookJ_l0nol00ol007l01_oo0`3ooo]Zool0gOl007oo0:?ook?o00?o
oo]Z00Wo001oo`3og_l007ooo`1/oookJ_m=0?oooo]Zof40ool0odD00ooonfX00ol0oi3ooo]Zo`3o
TP04oookJP05ofP0oooonf[ooo]ZoaP0oooVo`002?oonfX01?oo_P3ooo]Zo`3o1Om`0?l2oookJP05
oomG0?oonf[ooo]ZoookJ_oo02d01?oonfX6o`00O`07o`3Dool01?oo08Soo`00Oooonf[o0?m>o`3o
=004oookJP04o`3o2?l007oo001oool0N@;ooo]Z00?o403ooookJ_nBo`002?oonfX00olV0?oooo]Z
oookJP06oookJP03o`3Loooonf[ooe8000[ooo]Z00?oo`3foookJ_oonfX02?oonfX00olH0?oooo]Z
oookJP08oookJP03oa00ool0003o000000;o00005OoonfX00ol@0?oooo]ZoookJP06oookJP03o`3D
oooonf[ooo]Z00Kooo]Z00KoL03ooookJ_oonf[ooo]Zo`1doolH0?l5oookJP03of40oooonf[ooo]Z
00;ooo]Z00?o/ol0oookJ_oonfX00ooonfX00oooK03ooo]ZoookJP02oookJP05ool0m_oonf[o603o
oookJ_oo0?`00_l007lDoookJP06oomB0?l0:_oooo]ZoookJ_l0g?oo0?oO1?oonfX00olB0?oooo]Z
ooo:0003oookJP05ool04ooonf[ooo]ZoookJ_oQo`000_oonfX00olV0?oooo]ZoookJP0:oookJP05
o`3oFooonf[ooo]Zo`3o/?l0<?l00_l007l01_oonf[o1P3ooookJ_nBo`3o001ooa00o`?ooo]Z0_l0
07l00ooo057o0:goool0N@06oookJP05o`3oDooonf[o0?l8o`3o7Ol0hOl02OoonfX00ol0ocCo0?m>
oookJP05oookJP03o`2Yoooonf[ooo]Z00;ooo]Z00?o00Coo`3DoooonfX02ooonfX00oooP@3ooo]Z
oookJP04oookJP?o001o00?oo`0]oookJ_oonfX01_oonfX3o`00Oacooo]Z000ZoookJP?o001o2?oo
nfX01?l0Looo001oo`00Ool007lAoookJP03oomi0?oonf[ooo]Z00?ooo]Z00?ooaH0oookJ_ooTP00
0ooonfX01?oo0?cooo]ZoookJ_lH0?l2oookJP04ool60?oonf[ojol0ool0mP;ooo]Z00Oo0:KoojP0
oooonf[ooo]Zool0nOoonf[o07Oo00SoobP00_l007l3oolX0003ool00?ooN@3o/ol000;oo`000_oo
nfX01?oMo`3oogT0o`00Oooo06`2oolX0003of40oooo:03oobP000;ooo]Z00CoobP0oookJ_oonf[o
0?nB0ooonfX00omX0?oooo]ZonGo0003onGo00Oooo]Z00CoobP0oonn0?oo:03oL03o0_oo:0000ooo
nf[oogT0oookJP02oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00Oo0=Coo`04oooonf[ooo]Zo`28oooo
nf[o0?m>00Cooo]Z00Co0?l8oookJ_oonf[o001o0_oo0002oookJP03oa00oonBo`3ooo]Z00Cooo]Z
2?oo:003oookJP?oolT000?ooe80oookJ_oonfX02OoonfX00ooo0?Kooo]ZoookJP05oookJP03ool0
0?oonf[oobP000?oobP01Ooo0002oookJP03oa00oooonf[o000000Co00002?oonfX2ool000KoobP0
1?oonfX00ol@0?oooo]ZoookJP05oookJP03o`04ool0e?oooo]Z00Kooo]Z00?oL03ooookJ_oo:000
0_oo:0000olH0?ooobP0oolX0002oolX00;ooo]Z00?oH@3ooookJ_ooN@001_ooN@0>ool001?ooo]Z
00?ooe80oookJ_l0:_l00_oonfX00ol0g?ooobP0oookJP03oookJP03oa80oooobP3ooo]Z00?ooo]Z
0ooo0003oomi0004obH0ooooN@3oogT0oomi00[ooo]Z00Go0?mKoookJ_oonf[oobP0o`0`o`02o`00
O`06oookJ_l60?oooo]Zoi;o0?l007oo403o0ooonfX01?l007ooo`1Ao`2]oooo07T7oookJP04o`3o
Dooonf[o0?l8o`3o7@[ooo]Z00?o0?m>o`3o;_oonfX01?oonfX01Ol0R?oo0:WooookJ_oonf[o00Co
00;ooo]Z00?o0=CooookJ_oonfX02OoonfX00oooP@3ooo]ZoookJP04oookJP?o001o00?ooo]Zool0
;OoonfX01_oonfX3o`00OdCooo]Z0ol007l7oookJP03o`1coooonf[o001o00;o001o4?oonfX00ooo
0>[ooo]ZoookJP04oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00Koo`3loookJ_oonf[o603ooookJ_oo
1P02oookJP0?on_o0?oonf[ooo]Zo`2Voooonf[oZ03ooookJ_oo0?Wooo]Zo`1gool0oi[ooo]Zoom/
0?oonf[o>ol000;ooo]Z00[o0?_oo`00Ool007oo001oool30?oonf[oo`3Mo`00Ool0Xooo/ol00ooo
nfX02Ol007oo0?oNo`00Oooo06cooo]Zodd0oooonf[oH@3oo`3oA@03oookJP03o`3oT?oonf[o0?nB
00?ooo]Z00KoJ03ooookJ_oonf[ooo]ZoaP0oooVo`08oookJP04oonn0?oonf[o0?l5og00o`;ooo]Z
00GooeL0oookJ_oonf[ooo]Zool0;@09oookJP04o`3Dool01?oooo]Zo`28o`;ooo]Z00?o0?m>oook
J_oonfX00_oonfX01Ol0o`Sooo]Zo`00Ool007ooo`1i00;ooo]Z00?o403ooi;o0?oonfX02?oonfX0
0olV0?oooo]ZoookJP06oookJP03o`3Loooonf[ooe8000[ooo]Z00?oo`3foookJ_oonfX02?oonfX0
0olH0?oooo]ZoookJP08oookJP03oa00ool0003o000000?o00002_oonfX00ol0g?oooo]ZoookJP07
oookJP03oa00oooonf[ooo]Z00Kooo]Z00?o0=CooookJ_oonfX01_oonfX01_m`0?oooo]ZoookJ_oo
nf[o07CooaP0o`Kooo]Z00GoH@3ooookJ_oonf[ooo]Zok?o0005oookJP03oom/0?oonf[ooo]Z00;o
oo]Z00Goo`3foookJ_lH0?oooo]Zool0o002o`00OaCooo]Z00Kooe80o`0Zoooonf[ooo]Zo`3Lool0
oml4oookJP03oa80oooonf[oolX000?ooo]Z00Goo`0CoookJ_oonf[ooo]Zon7o0002oookJP03obH0
oooonf[ooo]Z00[ooo]Z00Go0?mKoookJ_oonf[o0?n`o`0`o`02o`00O`06oookJ_l60?oooo]Zoi;o
0?l007oo403o0ooonfX2o`00O`03ool0DOl0[Oooo`1i00Kooo]Z00Go0?mCoookJ_l0o`So0?lMo`3Q
o`09oookJP03o`3o=?l0odkooo]Z00Gooo]Z00Oo0:WooookJ_oonf[ooo]Zo`04oooonf[o0=Co00co
oo]Z00?ooh40oookJ_oonfX01?oonfX3o`00O`03ool0;Ooonf[ooo]Z00Kooo]Z0ol007lLoookJP00
:_oonfX3o`00O`Cooo]Z0_l007l2oookJP04o`1cool007oo001oo`00Oa3ooo]Z00?oogT0oookJ_oo
nfX01?oonfX00ooo5P3ooi80oookJP03oookJP04ool0o?oonf[ooo]ZoaP0o`;ooo]Z00Coo`H0oook
J_o[o`3oo`3f0_oonfX01ol0Y_ooZ03ooookJ_oonf[oo`3io`1goooonfX02?oo:002o`00O`?oobP0
00Goo`00oomi0?nco`3oobP0ool00002oookJP04oomi0?l007oo001oool0K0;oobP000?oH@3ooolX
0?oo:0000_oonfX00ooo:03ooo]Zo`3oTP04oookJP03ool00?oUo`3oiOl000?oiOl01ooonfX01?oo
:03ookh0oolX0?m`0?l2oolX0005oookJ_ooN@3ooo]ZoookJ_oo02d02OoonfX01ol0e?oo00Cooook
J_oonf[o08SooookJ_l0odh00_oonfX2o`00O`03o`3o2?oonf[o001o00?oo`000_oonfX00ol@0?oo
T_l0oookJP07oookJPGoobP00ooonfX3ooo90003oomB0?oonf[ooo]Z00Wooo]Z00?oo`3foookJ_oo
nfX01_oonfX00ooo003ooo]ZoolX0002oolX00Goo`0000Cooo]Zoa00oooonf[ooo]Z1?l00008oook
JPGoo`001?oo:005oookJP03oa00oooonf[ooo]Z00Gooo]Z00?o0=CooookJ_oonfX01OoonfX00om`
0?oooo]ZoolX0002oolX0004oaP0oooo:03oobP0oolX00?ooo]Z00?oH@3ooookJ_oonfX01_ooN@0>
ool001?ooo]Z00?ooe80oookJ_l0:_l00_oonfX00ol0g?ooobP0oookJP03oookJP03oa80oooobP3o
oo]Z00;ooo]Z1Ooo0002oomi0004obH0ooooN@3oogT0oomi00[ooo]Z00Go0?mKoookJ_oonf[oo`00
o`0`o`02o`00O`06oookJ_l60?oooo]Zoi;o0?l007oo403o0ooonfX01?l007ooo`1Ao`00Oooo07T7
oookJP04o`3oDooonf[o0?l8o`3o7@[ooo]Z00?o0?m>o`3o;_oonfX01?oonfX01Ol0ZOoooo]Zoook
J_oonf[o00Co00;ooo]Z00?o0=CooookJ_oonfX02OoonfX00oooP@3ooo]ZoookJP04oookJP?o001o
00Cooo]Zool0;Ooonf[ooo]Z0_l007l2oookJPCo001oA?oonfX3o`00O`Cooo]Z0_l007l00ooonf[o
07?oo`00O`03o`00O`oooo]Z00?oo`3ZoookJ_oonfX01OoonfX00oooTP3ooo]ZoookJP03oookJP06
ool0o?oonf[ooo]ZoaP0oooonf[oo`H00_oonfX04_o[o`3ooo]ZoookJ_l0Y_oooo]ZojP0oooonf[o
o`3ioookJ_l0Mooo0?nJoookJ_ooK03ooo]Zoc_o0?oonf[o0?_ooookJP?o001o00Koo`<0oookJ_oo
0=go001oo`2Soonco`03oookJP09o`3og_oMo`3o001oool0K?oonf[oC@3ooookJ_mQ0?oo0?m500;o
oo]Z00?o0?n@oookJ_l0oi801?oonfX01_mX0?oooo]ZoookJ_oonf[o603oonKo00Sooo]Z00?ookh0
oookJ_m`0?l00ooonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00Wooo]Z00Co0=Coo`04oooonf[o08So
0_oonfX01_l0odkooo]Zo`00Ool007oooo]Zo`3o20;o001o00Koo`1io`00Oooonf[ooo]Zoa00oonB
o`09oookJP03obH0oooonf[ooo]Z00Kooo]Z00?o0=cooomB0?oonfX02_oonfX00ooo0?Kooo]Zoook
JP07oookJP03oaP0oooonf[ooo]Z00Sooo]Z00?o403ooookJ_l000000ol0000<oookJP03o`3Loooo
nf[ooo]Z00Oooo]Z00?o403ooookJ_oonfX01OoonfX00ol0e?oooo]ZoookJP06oookJP06og00oooo
nf[ooo]ZoookJ_l0M?oo603o1_oonfX01OmQ0?oooo]ZoookJ_oonf[o/ol000Kooo]Z00Ooof`0oook
J_oonf[o001oool0m_oonf[o603o00;o001o00?oo`3lo`00OooonfX04ooonfX01_ooDP3o02[ooook
J_oonf[o0=coo`3og`Cooo]Z00?o4P3ooookJ_oobP000ooonfX01Ooo01?ooo]ZoookJ_oonf[ohOl0
00;ooo]Z00?o9P3ooookJ_oonfX02_oonfX01Ol0oe_ooo]ZoookJ_n2o`3o033o00;o001o00Kooo]Z
o`H0oooonf[oT_l0o`00Ool@0?l3oookJP;o001o00?oo`1Ao`2]oooo07T01_oonfX01Ol0oe?ooo]Z
o`3o2?l0oago0>7o00Wooo]Z00?o0?ldo`3oC_oonfX01OoonfX01ol0ZOoooo]ZoookJ_oonf[o00Co
oookJ_l0e?l03?oonfX00oooP@3ooo]ZoookJP04oookJP?o001o00Coo`0]oookJ_oonf[ooo]Z0_l0
07l2oookJPCo001o7?oonfX002[ooo]Z0ol007l4oookJPCo001o00?o07?oo`00Ool007l04OoonfX0
0oooN@3ooo]ZoookJP04oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00Coo`3loookJ_oonf[o603o0_oo
nfX02?oo1P3ooo]Zon_o0?oo0?Kooo]Zo`2Voooonf[oZ03o0_oonfX01?oo0?Wo07OooookJ_ooK003
oookJP05oolX0?oonf[o0?_ooookJ_l007l00ooo:0001Ooo003oobP0oomi0?nco`3oobP000;oo`00
00Gooo]Zoomi0?l007ooobP0ool0K002oolX0003of40oooo:03oobP000;ooo]Z00?oobP0oookJ_l0
oi801?oonfX00ooo003oiOl0onGo0004onGo00Gooo]Z0_oo:0000ooo_P3oobP0og00o`02oolX0005
oomi0?oonf[ooo]ZoookJ_oo02d02OoonfX01?l0e?oo00CooookJ_l0R?l2oookJP03o`3oC_oonf[o
oo]Z00;o001o00?o0?l8o`00Ool007l00ooo0002oookJP03oa00oonBo`3ooo]Z00Oooo]Z00?oobP0
oookJ_oonfX00_oo:002oookJPCoolT000?ooe80oookJ_oonfX02?oonfX00ooo0?Kooo]ZoookJP07
oookJP04ool00?oonf[ooo]ZoolX00Goo`000_oonfX00ol@0?oooo]ZoookJP04o`0000Sooo]Z2?oo
00000ooo:03ooo]ZoookJP03oookJP03oa00oooonf[ooo]Z00Gooo]Z00?o0=CooookJ_oonfX01Ooo
nfX00om`0?oooo]ZoolX0002oolX0004oaP0oooo:03oobP0oolX00?ooo]Z00?oH@3ooookJ_oonfX0
1_ooN@000ooonf[oo`00ool0000:ool001Cooo]Z00?ooe80oookJ_l0:_l00_oonfX00ol0g?ooobP0
oookJP03oookJP03oa80oooobP3ooo]Z00;ooo]Z00?oo`00oookJ_oo00000_oo0002oomi0004obH0
ooooN@3oogT0oomi00[ooo]Z00Go0?mKoookJ_oonf[oo`00o`0`o`02o`00O`06oookJ_l60?oooo]Z
oi;o0?l007oo403o0ooonfX01?l007ooo`1Ao`00Oooo07T7oookJP04o`3oDooonf[o0?l8o`3o7@[o
oo]Z00?o0?m>o`3o;_oonfX01?oonfX01Ol0ZOoooo]ZoookJ_oonf[o00Co00;ooo]Z00?o0=Cooook
J_oonfX02?oonfX00oooP@3ooo]ZoookJP05oookJP?o001o00Cooo]Zool0;Ooonf[ooo]Z1ol007m5
oookJP?o001o1?oonfX3o`00O`04o`1cool007oo001oo`00Oa3ooo]Z00?oo`3ZoookJ_oonfX01Ooo
nfX00oooTP3ooo]ZoookJP02oookJP07ool0o?oonf[ooo]ZoookJ_lH0?oooo]Zool60002oookJP03
on_o0?oonf[o0:Ko00;ooo]Z00OoZ03ooookJ_oo0?Wooo]Zo`1gool0oi[oof`000;ooo]Z00Co>ol0
oookJ_l0nooooo]Z0ol007l01_oo0`3oo`3MogT0ool007oo0:?ook?o00?ooo]Z00Wo0?oNo`00Ool0
07ooo`1/oookJ_m=0?oooo]Zof40ool0odD00_oonfX00ol0oi3ooo]Zo`3oTP04oookJP06ofP0oooo
nf[ooo]ZoookJ_lH0?ooi_l02?oonfX00ooo_P3o0?l5og00o`02oookJP03oomG0?oonf[ooo]Z00;o
oo]Z00?oo`0]oookJ_oonfX01ooonfX00ol0e?oo00Coo`28o`03oookJP03o`3oC_oonf[o001o00;o
001o00Co0?l8o`00Ool007ooo`1i0ooonfX00ol@0?ooT_l0oookJP07oookJP03obH0oooonf[ooo]Z
00Kooo]Z00?o0=cooookJ_ooDP002_oonfX00ooo0?Kooo]ZoookJP08oookJP03oaP0oooonf[ooo]Z
00Oooo]Z00?o403ooookJ_oonfX01?l0000=oookJP03o`3Loooonf[ooo]Z00Kooo]Z00?o403ooook
J_oonfX01OoonfX00ol01?oo0=CooookJP06oookJP06og00oooonf[ooo]ZoookJ_l0M?oo603o1_oo
nfX01OmQ0?oooo]ZoookJ_oonf[o/ol000Kooo]Z00Ooof`0oookJ_oonf[o001oool0m_l007oo603o
00;o001o00?oo`3loookJ_oonfX04ooonfX01_ooDP3o02[ooookJ_oonf[o0=coo`3og`Cooo]Z00?o
4P3ooookJ_oobP000ooonfX01Ooo01?ooo]ZoookJ_oonf[ohOl000;ooo]Z00?o9P3ooookJ_oonfX0
2_oonfX01Ol0oe_ooo]ZoookJ_n2o`3o033o00;o001o00Kooo]Zo`H0oooonf[oT_l0o`00Ool@0?l3
oookJP;o001o00?oo`1Ao`2]oooo07T01_oonfX01Ol0oe?ooo]Zo`3o2?l0oago0>7o00Wooo]Z00?o
0?ldo`3oC_oonfX01OoonfX01ol0ZOoooo]ZoookJ_oonf[o00CooookJ_l0e?l02ooonfX00oooP@3o
oo]ZoookJP05oookJP?o001o00Coo`0]oookJ_oonf[ooo]Z1ol007lMoookJP00:_oonfX3o`00O`Co
oo]Z1?l007l00ol0Looo001ooookJP0AoookJP03oomi0?oonf[ooo]Z00Cooo]Z00?ooaH0oonB0?oo
nfX00ooonfX01?oo0?cooo]ZoookJ_lH0?l2oookJP08ool60?oonf[ojol0ool0m_oonf[o0:Kooook
J_nX0?l2oookJP04ool0nOl0Mooo0?nJoom/00?ooo]Z00GoobP0oookJ_l0nooooo]Zo`00O`03oolX
0005ool00?oo:03oogT0ok?o0?oo:0000_oo00001Ooonf[oogT0o`00Oooo:03oo`1/00;oobP000?o
H@3ooolX0?oo:0000_oonfX00ooo:03ooo]Zo`3oTP03oookJP;oo`001_oUo`05oookJP;oobP000?o
okh0oolX0?m`0?l00_oo:0001OooN@3ooo]ZoookJ_oonf[oo`0]00Wooo]Z00Oo0=Coo`04oooonf[o
08SooookJ_oo:03o0?m>00;ooo]Z0_l007l00ol0o`So001oo`00O`03ool000;ooo]Z00?oT_l0oook
J_oonfX01ooonfX00ooo:03ooo]ZoookJP04oookJPCoolT000?ooe80oookJ_oonfX02?oonfX00ooo
0?Kooo]ZoookJP06oookJP;oo`000ooonfX5ool00003oookJ_l@0?oooo]Z00;ooo]Z1?l00008oook
JPSoo`0000?oobP0oookJ_oonfX00ooonfX00ol@0?oooo]ZoookJP05oookJP03o`3Doooonf[ooo]Z
00Gooo]Z00?oL03ooookJ_oonfX00_oo:0001?lH0?ooobP0oolX0?oo:003oookJP03of40oooonf[o
oo]Z00KoogT000?ooo]Zool00?oo00000_oo00000ol007ooo`00ool00005ool001Cooo]Z00?ooe80
oookJ_l0:_l00_oonfX00ooo:03ooo]ZoookJP03oookJP03oa80oooobP3ooo]Z00;ooo]Z00?oo`00
oookJ_oo00000_oo0002oomi0004obH0ooooN@3oogT0oomi00[ooo]Z00Go0?mKoookJ_oo:03oo`00
o`0`o`02o`00O`06oookJ_l60?oooo]Zoi;o0?l007oo403o0ooonfX01?l007ooo`1Ao`00Oooo07T6
oookJP05o`3oDooonf[ooo]Zo`3o2?l0oad02_oonfX00ol0odko0?l^oookJP04oookJP05o`2Yoooo
nf[ooo]ZoookJ_l01?l00_oonfX00ol0e?oooo]ZoookJP08oookJP03oon10?oonf[ooo]Z00Gooo]Z
0ol007l01?oonf[oo`0]oookJ_oonfX6o`00OdKooo]Z0ol007l4oookJP?o001o00?o07?oo`00Ool0
07l04OoonfX00ooo0>[ooo]ZoookJP05oookJP03oonB0?oonf[ooo]Z00;ooo]Z00Ooo`3loookJ_oo
nf[ooo]ZoaP0oooonf[oo`H000;ooo]Z00?ojol0oookJ_l0Y_l00_oonfX01onX0?oooo]Zool0nOoo
nf[o07OooookJ_ooK0000_oonfX01?lko`3ooo]Zo`3koooonfX3o`00O`06ool30?oo0=goN@3oo`00
Ool0Xooo/ol00ooonfX02Ol0omko001oo`00Oooo06cooo]Zodd0oooonf[oH@3oo`3oA@02oookJP03
o`3oT?oonf[o0?nB00Cooo]Z00GoJ03ooookJ_oonf[ooo]ZoaP0o`09oookJP03oonn0?l0o`GoL03o
00;ooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP07oookJP03o`3Dool01?oo08So
00;ooo]Z00?o0?m>o`3o=?oonfX00ol007l01?l0o`So001oo`00Oooo07T3oookJP03oi;o0?oonf[o
oo]Z00Oooo]Z00?o9P3ooookJ_oonfX01_oonfX00ol0g?oooo]ZoomB000:oookJP03ool0m_oonf[o
oo]Z00Oooo]Z00?o603ooookJ_oonfX01ooonfX01?l@0?oooo]ZoookJ_oonfX4o`0000gooo]Z00?o
0=cooookJ_oonfX01_oonfX00ol@0?oooo]ZoookJP06oookJP03o`3Doooonf[ooo]Z00Gooo]Z00?o
L03ooookJ_oonfX00_oonfX00olH0?oooo]ZoookJP04oookJP05of40oooonf[ooo]ZoookJ_nco`00
1_oonfX01oooK03ooo]ZoookJ_l007ooo`3fo`00OolH0?l00_l007l00ooo0?cooo]ZoookJP0Boook
JP03oomB0?l0oc?o02[o00;ooo]Z00?o0=coo`3ogooonfX00ooonfX00olB0?oooo]Zooo:0003oook
JP05ool04ooonf[ooo]ZoookJ_oQo`000_oonfX00olV0?oooo]ZoookJP0:oookJP05o`3oFooonf[o
0?n`oh;o0?l0<?l00_l007l01_oonf[o1P3ooookJ_nBo`3o001ooa00o`?ooo]Z0_l007l00ooo057o
0:goool0N@05oookJP06o`3oDooonf[ooo]Zo`3o2?l0oago0>7o2OoonfX00ol0ocCo0?m>oookJP05
oookJP07o`2Yoooonf[ooo]ZoookJ_l01?oooo]Zo`3Do`0;oookJP03oon10?oonf[ooo]Z00Gooo]Z
0ol007l01?oo02gooo]ZoookJ_oonfX6o`00Oakooo]Z000WoookJPKo001o1?oonfX2o`00O`;ooo]Z
00?o07?ooookJ_oonfX04OoonfX00oooN@3ooo]ZoookJP04oookJP03oolF0?ooTP3ooo]Z00?ooo]Z
00Coo`3loookJ_oonf[o603o0_oonfX02?oo1P3ojol0oookJ_oo0?Kooo]Zo`2Voooonf[oZ03o0_oo
nfX01?oo0?Wo07Ooo`3oV_ooK002oookJP04oolX0?oonf[o001oo`3ko`?o001o0ooo00001?ooN@3o
/ol0oolX0?oo:002ool00005omgo0?ooN@3o001ooolX0?oo06`00_oo:0000omQ0?ooobP0oolX0002
oookJP03oolX0?oonf[o0?nB00?ooo]Z00?oo`00onGo0?oUo`001OoUo`05oookJP;oobP000?ookh0
oolX0?m`0?l00_oo:0001OooE`3ooo]ZoookJ_oonf[oo`0]00Wooo]Z00Oo0=Coo`04oooonf[o08So
oookJ_oo:03o0?m>00;ooo]Z0_l007l00ol0o`Sooo]Zool00003ool00003oookJ_l@0?ooT_l000Wo
oo]Z00?o9P3ooookJ_oonfX00ooonfX4ooo90003oomB0?oonf[ooo]Z00Wooo]Z00?oo`3foookJ_oo
nfX01OoonfX3ool000Cooo]Z0ooo00000ooonf[o403ooookJP03oookJPCo00002?oonfX7ool000;o
obP01_oonfX00ol@0?oooo]ZoookJP04oookJP03o`04ool0e?oooo]Z00Gooo]Z00?oL03ooookJ_oo
nfX00ooo:0000olH0?ooobP0oolX0003oookJP04of40oooonf[ooo]ZoookJPCoogT00_oonfX4ool0
0003o`00Oooo003oo`0000Goo`005?oonfX00oooDP3ooo]Zo`0Zo`02oookJP03oolX0?oonf[ooo]Z
00?ooo]Z00?o4P3oooo:0?oonfX00_oonfX00ooo003ooo]Zool00003ool00003oomi0?lV0?ooogT0
00;oogT02OoonfX01_l0oe_ooo]Zo`00Oooo:03oo`00o`0`o`;o001o00Ko1P3ooookJ_oonf[oT_l0
o`00Ool@0?l3oookJP04ool0DOl007oo001oool0N@Kooo]Z00Go0?mCoookJ_oonf[o0?l8o`3o7@0:
oookJP03o`3oC_l0obkooo]Z00Cooo]Z00Go0:WooookJ_oonf[ooo]Zo`04o`02oookJP03o`3Doooo
nf[ooo]Z00Sooo]Z00?ooh40oookJ_oonfX00_oonfX6o`00O`04oookJ_oo02gooo]ZoookJP;o001o
AooonfX6o`00O`Cooo]Z0_l007l00ooonf[o07?ooookJP0BoookJP03ool0j_oonf[ooo]Z00Gooo]Z
00?ooi80oookJ_oonfX00_oonfX03?oo0?cooo]ZoookJ_oonf[o603ooookJ_oo1P3ooo]Zon_o0?oo
0?Kooo]Zo`2Vo`;ooo]Z00OoZ03ooookJ_oo0?Wo07Ooo`3oV_oonf[oof`000;ooo]Z00?o>ol0o`00
Ool0nol00ol007l01ooo0`3ooo]ZoookJ_mi0?oo0:?ook?o0?nO0?l00ooonfX02Ol0omko001oo`00
Oooo06cooo]Zodd0oooonf[oH@3oo`3oA@02oookJP03o`3oT?oonf[o0?nB00Cooo]Z00GoJ03ooook
J_oonf[ooo]ZoaP0o`09oookJP03oonn0?l0o`GoL03o00;ooo]Z00?ooeL0oookJ_oonfX00_oonfX0
0ooo02gooo]ZoookJP07oookJP03o`3Dool01?oo08So00;ooo]Z00?o0?m>o`3o=?oonfX00_l007l0
1Ooonf[o0?l8oookJ_oonf[oo`1i00?ooo]Z00?oT_l0oookJ_oonfX01ooonfX00olV0?oooo]Zoook
JP06oookJP03o`3Loooonf[ooe8000[ooo]Z00?oo`3foookJ_oonfX01ooonfX00olH0?oooo]Zoook
JP07oookJP04oa00oooonf[ooo]ZoookJPCo00003_oonfX00ol0g?oooo]ZoookJP06oookJP03oa00
oooonf[ooo]Z00Gooo]Z00?o0=CooookJ_oonfX01OoonfX00om`0?oooo]ZoookJP02oookJP03onKo
0?lH0?oooo]Z00Cooo]Z00?oH@3ooookJ_oonfX00_oonfX00onco`3ooo]ZoookJP03oookJP07oom/
0?oonf[ooo]Zo`00Oooo0?Kooo]ZoaP0o`02oookJP03ool0o?oonf[ooo]Z01;ooo]Z00?ooe80o`3o
<ol0:_l00_oonfX00ol0g?oo0?oOoookJP03oookJP03oa80oooonf[oolX000?ooo]Z00Goo`0Coook
J_oonf[ooo]Zon7o0002oookJP03obH0oooonf[ooo]Z00Wooo]Z00Ko0?mKoookJ_l007oo0?n`oh;o
0?l0<?l2o`00O`06o`H0oooonf[ooo]Zoi;o0?l007oo403o0ooonfX01Ol007ooo`1Ao`00Ool0[Ooo
o`1i00Gooo]Z00Ko0?mCoookJ_oonf[o0?l8o`3o7Ol0hOl9oookJP03o`3o=?l0odkooo]Z00Gooo]Z
00Oo0:WooookJ_oonf[ooo]Zo`04oooonf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX00_oonfX6o`00
O`04ool0;Ooonf[ooo]ZoookJP;o001o8_oonfX002Oooo]Z1_l007l4oookJP;o001o0_oonfX00ol0
Looooo]ZoookJP0AoookJP03oomi0?oonf[ooo]Z00Cooo]Z00?ooaH0oonB0?oonfX00ooonfX01?oo
0?cooo]ZoookJ_lH0?l2oookJP08ool60?o[o`3ooo]Zool0m_oonf[o0:KooookJ_nX0?l2oookJP04
ool0nOl0Mooo0?nJoom/00;ooo]Z00CoobP0oookJ_l007oo0?_o0ol007l2ool00004oolX0?ooN@3o
/ol0oil0o`?oo`0000CogOl0oomi0?oo:03oo`1/0ooo:0001OmQ0?ooobP0oolX0?oonf[oobP000;o
oo]Z00Go0?nBoookJ_oonf[ooo]Zool00007onGo00Cooo]Z0ooo:0000ooo_P3oL03ooolX0002oolX
0005oomG0?oonf[ooo]ZoookJ_oo02d02OoonfX01ol0e?oooo]ZoookJ_l0R?oooo]Zo`3oC_oo:000
0_oonfX01?l007oo0?l8oookJ_oonfX4ool00003oookJ_l@0?ooT_l000Wooo]Z00?o9P3ooookJ_oo
nfX00ooonfX4ooo90003oomB0?oonf[ooo]Z00Sooo]Z00?oo`3foookJ_oonfX01_oonfX3ool000Go
oo]Z00?oo`00oookJ_l@0?l01OoonfX4o`0000Sooo]Z1ooo0002oolX00Kooo]Z00?o403ooookJ_oo
nfX01OoonfX00ol0e?oooo]ZoookJP04oookJP03og00oooonf[ooo]Z00?oobP000?o603ooolX0?oo
:0000ooonfX01?mQ0?oooo]ZoookJ_oonfX4oomi00?ooo]Z0ooo00000ol007ooo`00ool00005ool0
01Cooo]Z00?ooe80oookJ_l0:_l00_oonfX00ooo:03ooo]ZoookJP03oookJP03oa80oooobP3ooo]Z
00;ooo]Z00?oo`00oookJ_oonfX00ooo00001?ooN@3o9P3ooomi0?ooN@0:oookJP06o`3oFooonf[o
001ooolX0?oo003o033o0_l007l03Ol60?oooo]ZoookJ_nBo`3o001ooa00ool007oooo]Zo`00Oooo
057o001ooookJ_oo07T01_oonfX01Ol0oe?ooo]ZoookJ_l0o`So0?lM00[ooo]Z00?o0?m>o`3o;_oo
nfX01?oonfX01Ol0ZOoooo]ZoookJ_oonf[o00Co00;ooo]Z00?o0=CooookJ_oonfX02?oonfX00ooo
P@3ooo]ZoookJP02oookJPKo001o00Cooo]Zool0;Ooonf[ooo]Z0_l007m7oookJPKo001o1?oonfX2
o`00O`03oookJ_l0Looooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01OoonfX00oooTP3ooo]ZoookJP02
oookJP0<ool0o?oonf[ooo]ZoookJ_lH0?oooo]Zool60?oonf[ojol0ool0m_oonf[o0:Ko0_oonfX0
1onX0?oooo]Zool0nOl0Mooo0?nJoookJ_ooK0000_oonfX00olko`3o001oo`3ko`03o`00O`0=ool3
0?oonf[oN@3ooookJ_l0Xooo/ol0oil0ool007oooo]Zo`00Ool0omko001oool0K002oookJP03odd0
oooonf[oH@3o00;ooo]Z00Co0?n@oookJ_oonf[o0?nB1?oonfX01OmX0?oooo]ZoookJ_oonf[o603o
00Wooo]Z00?ookh0o`3o1Om`0?l00_oonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00[ooo]Z00?o0=Co
oookJ_l0R?l00_oonfX00ol0odko0?ldoookJP02o`00O`05o`3o2?oonf[ooo]ZoookJ_oo07T00ooo
nfX00onBo`3ooo]ZoookJP07oookJP03obH0oooonf[ooo]Z00Kooo]Z00?o0=cooomB0?oonfX02Ooo
nfX00ooo0?Kooo]ZoookJP07oookJP03oaP0oooonf[ooo]Z00Oooo]Z00?o403ooookJ_oonfX00_oo
nfX4o`0000kooo]Z00?o0=cooookJ_oonfX01_oonfX00ol@0?oooo]ZoookJP05oookJP03o`3Doooo
nf[ooo]Z00Gooo]Z00?oL03ooookJ_oonfX00_oonfX00ooVo`3o603ooookJP04oookJP03of40oooo
nf[ooo]Z00;ooo]Z00?o/ol0oookJ_oonfX00ooonfX01oooK03ooo]ZoookJ_l007ooo`3foookJ_lH
0?l00_oonfX00ooo0?cooo]ZoookJP0BoookJP03oomB0?l0oc?o02[o00;ooo]Z00?o0=coo`3ogooo
nfX00ooonfX00olB0?oooo]Zooo:0003oookJP05ool04ooonf[ooo]ZoookJ_oQo`000_oonfX00olV
0?oooo]ZoookJP09oookJP06o`3oFooonf[o001oo`3o/?n2o`3o033o0_l007l02?l60?oooo]Zoook
J_nBo`3o001ooa00ool007oooo]Z0_l007l01?oo057ooo]Zo`2]oooo07T5oookJP06o`3oDooonf[o
oo]Zo`3o2?l0oago0>7o2OoonfX00ol0ocCo0?m>oookJP04oookJP03o`28ool0ZOoooo]Z00;ooo]Z
00?o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP02oookJPKo001o00Coo`0]oookJ_oonf[o
oo]Z0_l007lRoookJP00:OoonfX4o`00O`Gooo]Z0_l007l00ol0Looo001oo`00O`02o`00Oa3ooo]Z
00?oogT0oookJ_oonfX00ooonfX00ooo5P3ooi80oookJP03oookJP05ool0o?oonf[ooo]ZoookJ_lH
0?l00_oonfX01ooo1P3ojol0oookJ_oo0?Kooo]Zo`2VoonX0?l00ooonfX01?oo0?Wo07Ooo`3oV_oo
K002oookJP04oolX0?oonf[ooo]Zo`3ko`?o001o00Koo`00oookJ_oo:03o0:?ook?o0?nO0?l3o`00
O`08omgo0?ooN@3o001oool0K?oonf[oobP0oookJ_mQ0?l2oolX0004oookJ_oo:03ooo]Zo`3oTP?o
oo]Z0_oo0007onGo00Kooo]Z00?ookh0oolX0?m`0?l00ooo:0001?ooE`3ooo]ZoookJ_oo02d:oook
JP06o`3Doooonf[ooo]Zo`28oooo:03o0?m>0_oo:002oookJP03o`3o2?l007ooo`0000Goo`0000?o
403ooi;o0?oonfX02?oonfX00olV0?oooo]ZoookJP02oookJPGoolT000?ooe80oookJ_oonfX02?oo
nfX00ooo0?Kooo]ZoookJP05oookJPCoo`001_oonfX00ooo:03ooo]ZoookJP04oookJPCo00002Ooo
nfX6ool000;oobP01_oonfX00ol@0?oooo]ZoookJP05oookJP03o`3Doooonf[ooo]Z00Cooo]Z00Co
L03ooookJ_oonf[ooo]Z0_oo:0000olH0?ooobP0oookJP03oookJP04of40oooonf[ooo]ZoookJPCo
ogT00ooonfX2ool000;ooo]Z00?o001oool00?oo00000_oo00000ooo0?co001ooookJP0CoookJP03
oomB0?l0:_oooo]Z00;ooo]Z00?oobP0oookJ_oonfX00ooonfX00olB0?ooolX0oookJP02oookJP03
ool00?oonf[ooo]Z00?oo`0000CoogT0obH0ooooN@3oogT02_oonfX01_l0oe_ooo]ZoookJ_oo003o
001oo`0`o`;o001o00Ko1P3ooookJ_oonf[oT_l0o`00Ool@0?l3o`00O`04ool0DOl007oooo]Zool0
N@Kooo]Z00Go0?mCoookJ_oonf[o0?l8o`3o7@0:oookJP03o`3oC_l0obkooo]Z00?ooo]Z00?o08So
o`2YoooonfX00_oonfX01?l01?oooo]ZoookJ_l0e?l:oookJP03oon10?oonf[ooo]Z00Cooo]Z1?l0
07l00ooonf[oo`0]oookJP02oookJPOo001o@ooonfX4o`00O`Gooo]Z00?o001oo`1cool007l01?l0
07l?oookJP03ool0j_oonf[ooo]Z00Cooo]Z00?ooi80oookJ_oonfX00ooonfX03_oo0?cooo]Zoook
J_oonf[o603ooookJ_oo1P3ooo]Zon_o0?oo0?Kooo]Zo`2Voooonf[oZ03o0_oonfX01Ooo0?Wo07Oo
o`3oV_oonf[oof`000;ooo]Z00?o>ol0oookJ_l0nol00ol007l01ooo0`3ooo]ZogT0oooonf[o0:?o
ok?o0?nO0?l00ol007l02?l0omko001oool0K?oonf[oC@3ooookJ_mQ0?oo0?m50_oonfX00ol0oi3o
oo]Zo`3oTP05oookJP05ofP0oooonf[ooo]ZoaP0oooVo`002?oonfX00ooo_P3ooo]Zog00o`03oook
JP05oomG0?oonf[ooo]ZoookJ_oo02d02OoonfX01?l0e?oo00CooookJ_l0R?l2oookJP06o`3oC_oo
nf[ooo]ZoookJ_l007oo0?l80ol007l01Ooo07Wo001ooookJ_l@0?ooT_l000Wooo]Z00?o9P3ooook
J_oonfX01OoonfX00ol0g?oooo]ZoomB000:oookJP03ool0m_oonf[ooo]Z00Oooo]Z00?o603ooook
J_oonfX01_oonfX00ol@0?oooo]ZoookJP03oookJPCo00003ooonfX00ol0g?oooo]ZoookJP05oook
JP03oa00oooonf[ooo]Z00Gooo]Z00?o00Coo`3DoooonfX01OoonfX00om`0?oooo]ZoookJP02oook
JP03onKo0?lH0?oooo]Z00Cooo]Z00?oH@3ooookJ_oonfX00_oonfX00onco`3ooo]ZoookJP03oook
JP07oom/0?oonf[ooo]ZoookJ_oo0?Ko001ooaP0o`02o`00O`03ool0o?l007oooo]Z01;ooo]Z00?o
oe80o`0ZoooonfX00_oonfX00ol0g?oo0?oOoookJP03oookJP03oa80oooonf[oolX000?ooo]Z00Go
o`0CoookJ_oonf[ooo]Zon7o0002oookJP03obH0oooonf[ooo]Z00Wooo]Z00Ko0?mKoookJ_oonf[o
0?n`oh;o0?l0<?l2o`00O`06o`H0oooonf[ooo]Zoi;o0?l007oo403o1?l007l01?oo057ooo]Zo`2]
oooo07T5oookJP06o`3oDooonf[ooo]Zo`3o2?l0oago0>7o2OoonfX00ol0ocCo0?m>oookJP04oook
JP03o`28ool0ZOoooo]Z00;ooo]Z00?o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP04oook
JPCo001o00?oo`0]oookJ_oonfX00_oonfX7o`00Oacooo]Z000ZoookJP?o001o1OoonfX2o`00O`03
o`1cool007oo001o00;o001o4?oonfX00oooN@3ooo]ZoookJP03oookJP03oolF0?ooTP3ooo]Z00?o
oo]Z00Goo`3loookJ_oonf[ooo]ZoaP0o`02oookJP07ool60?o[o`3ooo]Zool0m_l0Y_oooo]ZojP0
o`03oookJP04ool0nOl0Mooo0?nJoom/00;ooo]Z00GoobP0oookJ_oonf[o0?_ooookJP02o`00O`06
ool00?oonf[oobP0o`2Soonco`3ooo]Z0ol007l02OooN@3o001ooookJ_oo06cooo]ZoolX0?oonf[o
H@3ooolX0002oookJP03o`3oT?oonf[o0?nB00?ooo]Z00?oo`00onGo0?oUo`001ooUo`05oookJP03
oonn0?oo:03oL03o00?ooo]Z00CooeL0oookJ_oonf[oo`0]2_oonfX01_l0e?oooo]ZoookJ_l0R?oo
obP0o`3oCP;oobP00_oonfX00ol0o`So001oool00005ool00003oa00oonBo`3ooo]Z00Sooo]Z00?o
9P3ooookJ_oonfX00_oonfX5ooo90003oomB0?oonf[ooo]Z00Sooo]Z00?oo`3foookJ_oonfX01?oo
nfX5ool000Kooo]Z00?oobP0oookJ_oonfX01?oonfX4o`0000Wooo]Z1Ooo0003oolX00Kooo]Z00?o
403ooookJ_oonfX01OoonfX00ol0e?oooo]ZoookJP05oookJP03og00oooonf[ooo]Z00;oobP000?o
603ooolX0?oonfX00ooonfX00omQ0?oooo]ZoookJP02oookJP?oogT00ooonfX2ool000;ooo]Z00?o
001oool00?oo00000_oo00000ooo0?co001ooookJP0CoookJP03oomB0?l0:_oooo]Z00;ooo]Z00?o
obP0oookJ_oonfX00ooonfX00olB0?ooolX0oookJP02oookJP03ool00?oonf[ooo]Z00?oo`0000Co
ogT0obH0ooooN@3oogT02_oonfX01_l0oe_ooo]ZoookJ_oo003ooo]Zo`0`o`;o001o00Ko1P3ooook
J_oonf[oT_l0oookJ_l@0?l3o`00O`04ool0DOoonf[ooo]Zool0N@Kooo]Z00Go0?mCoookJ_oonf[o
0?l8o`3o7@0:oookJP03o`3oC_l0obkooo]Z00?ooo]Z00?o08Soo`2YoooonfX00_oonfX01?l01?oo
oo]ZoookJ_l0e?l:oookJP03oon10?oonf[ooo]Z00Gooo]Z0ol007l00ooo02gooo]ZoookJP02oook
JPOo001oA?oonfX3o`00O`Gooo]Z00?o001oo`1cool007l01?l007l?oookJP03ool0j_oonf[ooo]Z
00Cooo]Z00?ooi80oookJ_oonfX00ooonfX02ooo0?cooo]ZoookJ_oonf[o603ooookJ_oo1P3ooo]Z
on_o0?oo0?Ko0:Ko00;ooo]Z00SoZ03ooookJ_oonf[oo`3io`1gool0oi[ooo]Zoom/00;ooo]Z00Co
>ol0oookJ_l0nooooo]Z0_l007l01_oo0`3ooo]ZogT0oooonf[o0:?ook?o00?o001o00Wo0?oNomgo
0?oonf[oo`1/oookJ_m=0?oooo]Zof40ool0odD00_oonfX00ol0oi3ooo]Zo`3oTP05oookJP05ofP0
oooonf[ooo]ZoaP0oooVo`002?oonfX00ooo_P3ooo]Zog00o`03oookJP05oomG0?oonf[ooo]Zoook
J_oo02d02OoonfX01?l0e?oo00CooookJ_l0R?l2oookJP06o`3oC_oonf[ooo]ZoookJ_l007oo0?l8
0ol007l01Ooo07Wo001ooookJ_l@0?ooT_l000Wooo]Z00?o9P3ooookJ_oonfX01OoonfX00ol0g?oo
oo]ZoomB000:oookJP03ool0m_oonf[ooo]Z00Oooo]Z00?o603ooookJ_oonfX01_oonfX00ol@0?oo
oo]ZoookJP03oookJPCo00003ooonfX00ol0g?oooo]ZoookJP05oookJP03oa00oooonf[ooo]Z00Go
oo]Z00?o00Coo`3DoooonfX01OoonfX00om`0?oooo]ZoookJP02oookJP03onKo0?lH0?oooo]Z00Co
oo]Z00?oH@3ooookJ_oonfX00_oonfX00onco`3ooo]ZoookJP03oookJP07oom/0?oonf[ooo]Zoook
J_oo0?Ko001ooaP0o`02o`00O`03ool0o?l007oooo]Z01;ooo]Z00?ooe80o`0ZoooonfX00_oonfX0
0ol0g?oo0?oOoookJP03oookJP03oa80oooonf[oolX000?ooo]Z00Goo`0CoookJ_oonf[ooo]Zon7o
0002oookJP03obH0oooonf[ooo]Z00Wooo]Z00Ko0?mKoookJ_oonf[oP_l0oookJ_l0<?l2o`00O`06
o`H0oooonf[ooo]Zoi;o0?oonf[o403o1?l007l01?oo057ooo]Zo`2]oooo07T5oookJP06o`3oDooo
nf[ooo]Zo`3o2?l0oago0>7o2OoonfX00ol0ocCo0?m>oookJP04oookJP03o`28ool0ZOoooo]Z00;o
oo]Z00?o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP05oookJP?o001o00?oo`0]oookJ_oo
nfX00_oonfX7o`00Oacooo]Z000doookJP03o`1coooonf[ooo]Z01;ooo]Z00?oogT0oookJ_oonfX0
0ooonfX00ooo5P3ooi80oookJP03oookJP0>ool0o?oonf[ooo]ZoookJ_lH0?oooo]Zool60?oonf[o
jol0oookJ_oo0?Ko0:KooookJ_nX0?l2oookJP04ool0nOoonf[o07Oooom/00?ooo]Z00CoobP0oook
J_oonf[o0?_o0_oonfX01_oo003ooo]ZoookJ_oo:03o0:?ook?o00Cooo]Z00WoogT0oookJ_oonf[o
o`1/oookJ_oo:03ooo]Zof40oooo:0000_oonfX00ol0oi3ooo]Zo`3oTP03oookJP03ool00?oUo`3o
iOl000OoiOl01OoonfX00ooo_P3oobP0og00o`03oookJP04oomG0?oonf[ooo]Zool0;@Wooo]Z00Oo
0=Coo`04oooonf[ooo]Zo`28oooo:03o0?m>00;oobP00_oonfX00ol0o`Soo`00ool00005ool00003
oa00oonBo`3ooo]Z00Oooo]Z00?o9P3ooookJ_oonfX00_oonfX5ooo90003oomB0?oob@3ooo]Z00Wo
oo]Z00?oo`3foookJ_oonfX00ooonfX6ool000Gooo]Z0_oo:006oookJPCo00002OoonfX5ool00003
oookJ_oo:03oobP000Oooo]Z00?o403ooookJ_oonfX01?oonfX00ol0e?oooo]ZoookJP05oookJP03
og00oooonf[ooo]Z00;oobP000?o603ooolX0?oonfX00ooonfX00omQ0?oooo]ZoookJP02oookJP?o
ogT01?oonfX01?oo003ooo]ZoookJ_oonfX4ool00003ool0o?oonf[ooo]Z01?ooo]Z00Kooe80o`0Z
oooonf[ooo]Zo`3Loooo:005oookJP03ooo:0?oonf[ooo]Z00;ooo]Z00Coo`00oookJ_oonf[ooo]Z
0ooo00000olV0?ooogT0oomi000:oookJP06o`3oFooonf[ooo]Zool00?oonf[o033o0_oonfX01_l6
0?oooo]ZoookJ_nBo`3ooo]Zoa00o`?ooo]Z00Coo`1AoookJ_oonf[oo`1i1_oonfX01Ol0oe?ooo]Z
oookJ_l0o`So0?lM00[ooo]Z00?o0?m>o`3o;_oonfX00ooonfX00ol0R?oo0:WooookJP02oookJP04
o`04oooonf[ooo]Zo`3Do`[ooo]Z00?ooh40oookJ_oonfX02?oonfX00ooo02gooo]ZoookJP1Foook
JP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01?oonfX00oooTP3ooo]ZoookJP02oook
JP03ool0o?oonf[ooo]Z00;ooo]Z00Oo603oool60?oonf[ooo]Zon_o0?oo0?Ko0:Ko00;ooo]Z00Oo
Z03ooookJ_oo0?Wooo]Zo`1gool0oi[oof`000?ooo]Z00?o>ol0oookJ_l0nol00ooonfX01_oo0`3o
oo]ZogT0oooonf[o0:?ook?o00?ooo]Z00Wo0?oNomgo0?oonf[oo`1/oookJ_m=0?oooo]Zof40ool0
odD00_oonfX00ol0oi3ooo]Zo`3oTP05oookJP05ofP0oooonf[ooo]ZoaP0ool0M?l02?oonfX00ooo
_P3ooo]Zog00o`03oookJP05oomG0?oonf[ooo]ZoookJ_oo02d02OoonfX01ol0e?oo00CooookJ_l0
R?oooo]Zo`3oC_l0oc@01?oonfX01?l0o`Sooo]ZoookJ_oo07T3oookJP03oa00oonBo`3ooo]Z00Oo
oo]Z00?o9P3ooookJ_oonfX01_oonfX00ol0g?oooo]ZoomB000:oookJP03ool0m_oonf[ooo]Z00Ko
oo]Z00?o603ooookJ_oonfX01_oonfX00ol@0?oooo]ZoookJP04oookJPCo00003ooonfX00ol0g?oo
oo]ZoookJP06oookJP03oa00oooonf[ooo]Z00Cooo]Z00?o00Coo`3DoooonfX01OoonfX00om`0?oo
oo]ZoookJP02oookJP03onKo0?lH0?oooo]Z00Cooo]Z00?oH@3ooookJ_oonfX00_oonfX00onco`3o
oo]ZoookJP03oookJP07oom/0?oonf[ooo]ZoookJ_oo0?Kooo]ZoaP0o`02oookJP03ool0o?oonf[o
oo]Z01;ooo]Z00?ooe80o`0ZoooonfX00_oonfX00ol0g?oo0?oOoookJP03oookJP03oa80oooobP3o
oo]Z00?ooo]Z00Goo`0CoookJ_oonf[ooo]Zon7o0002oookJP03obH0oooonf[ooo]Z00Wooo]Z00Ko
0?mKoookJ_oonf[oP_l0oookJ_l0<?l2oookJP06o`H0oooonf[ooo]Zoi;o0?oonf[o403o1?oonfX0
1?oo057ooo]Zo`2]oooo07T5oookJP06o`3oDooonf[ooo]Zo`3o2?l0oago0>7o2OoonfX00ol0ocCo
0?m>oookJP04oookJP03o`28ool0ZOoooo]Z00;ooo]Z00?o00CooookJ_l0e?l02ooonfX00oooP@3o
oo]ZoookJP08oookJP03ool0;Ooonf[ooo]Z02Gooo]Z000doookJP03o`1coooonf[ooo]Z01;ooo]Z
00?oogT0oookJ_oonfX00ooonfX00ooo5P3ooi80oookJP03oookJP0>ool0o?oonf[ooo]ZoookJ_lH
0?oooo]Zool60?oonf[ojol0oookJ_oo0?Ko0:KooookJ_nX0?l2oookJP04ool0nOoonf[o07Oooom/
00?ooo]Z00CoobP0oookJ_oonf[o0?_o0_oonfX01_oo003ooo]ZoookJ_oo:03o/ol0oil0o`Cooo]Z
00WoogT0oookJ_oonf[oo`1/oookJ_oo:03oH@3ooookJ_oo:0000_oonfX00ol0oi3ooo]Zo`3oTP02
oookJPKoo`001OoUo`05oookJP03oonn0?oo:03oL03o00?ooo]Z00CooeL0oookJ_oonf[oo`0]2Ooo
nfX01?l0e?oo00CooookJ_oonfX2oolX0003o`3oC_oo:03oobP000;ooo]Z00?o0?l8ool00?oo0000
1Ooo00000onBo`3ooo]ZoookJP07oookJP03obH0oooonf[ooo]Z00;ooo]Z1Ooob@000oooDP3oolT0
oookJP08oookJP03ool0m_oonf[ooo]Z00Cooo]Z1Ooo0005oookJP?oobP01_oonfX4o`0000Wooo]Z
1Ooo00000ooonf[oobP0oolX0007oookJP03oa00oooonf[ooo]Z00Cooo]Z00?o0=CooookJ_oonfX0
1OoonfX01om`0?oooo]ZoookJ_oonf[oobP0oaP0oooo:0001?oonfX00omQ0?oooo]ZoookJP02oook
JP;oogT01OoonfX01?oo003ooo]ZoookJ_oo0?H4ool00003ool0o?oonf[ooo]Z01?ooo]Z00?ooe80
o`0Zoooo:0000ooo:005oookJP03ooo:0?oo003oo`0000Woo`0000?o9P3ooomi0?ooN@002_oonfX0
1_l0oe_ooo]ZoookJ_oo003ooo]Zo`0`o`;ooo]Z00Ko1P3ooookJ_oonf[oT_l0oookJ_l@0?l3oook
JP04ool0DOoonf[ooo]Zool0N@Kooo]Z00Go0?mCoookJ_l0o`Sooo]Zo`3o7@0:oookJP03o`3oC_l0
obkooo]Z00?ooo]Z00Go08Soo`2Yoooonf[ooo]Zo`04o`03oookJP03o`3Doooonf[ooo]Z00Sooo]Z
00?ooh40oookJ_oonfX02?oonfX00ooo02gooo]ZoookJP1FoookJP03o`1coooonf[ooo]Z01;ooo]Z
00?oo`3ZoookJ_oonfX01?oonfX00oooTP3ooo]ZoookJP02oookJP03ool0o?oonf[ooo]Z00;ooo]Z
00Oo603oool60?oonf[ooo]Zon_o0?oo0?Ko0:Ko00;ooo]Z00OoZ03ooookJ_oo0?Wooo]Zo`1gool0
oi[oof`000;ooo]Z00Co>ol0oookJ_oonf[o0?_o0ooonfX01_oo0`3ooo]ZogT0oooonf[o/ol0oil0
o`?ooo]Z00Wo0?oNoookJ_oonf[oo`1/oookJ_m=0?oooo]Zof40ool0odD00_oonfX00ol0oi3ooo]Z
o`3oTP05oookJP05ofP0oooonf[ooo]ZoaP0ool0M?l02?oonfX00ooo_P3ooo]Zog00o`03oookJP05
oomG0?oonf[ooo]ZoookJ_oo02d02OoonfX01ol0e?oo00CooookJ_l0R?oooo]Zo`3oC_l0oc@01?oo
nfX01?l0o`Sooo]ZoookJ_oo07T3oookJP03oa00oonBo`3ooo]Z00Oooo]Z00?o9P3ooookJ_oonfX0
1OoonfX01?l0g?oooo]ZoookJ_ooDP0:oookJP03ool0m_oonf[ooo]Z00oooo]Z00?o403ooookJ_oo
nfX01?oonfX4o`00013ooo]Z00?o0=cooookJ_oonfX01OoonfX00ol@0?oooo]ZoookJP04oookJP03
o`04ool0e?oooo]Z00Gooo]Z00?oL03ooookJ_oonfX00_oonfX00ooVo`3o603ooookJP04oookJP03
of40oooonf[ooo]Z00;ooo]Z00?o/ol0oookJ_oonfX00ooonfX01oooK03ooo]ZoookJ_oonf[oo`3f
oookJ_lH0?l00_oonfX00ooo0?cooo]ZoookJP0BoookJP07oomB0?l0:_oooo]ZoookJ_l0g?oooo]Z
o`3og`04oookJP03oa80oooobP3ooo]Z00;ooo]Z00?oo`0CoookJ_oonfX00_oonfX01?oQo`3ooo]Z
oookJ_lV0?l;oookJP06o`3oFooonf[ooo]Zoh;o0?oonf[o033o0_oonfX01_l60?oooo]ZoookJ_nB
o`3ooo]Zoa00o`Cooo]Z00Coo`1AoookJ_l0[Oooo`1i1OoonfX01_l0oe?ooo]Zo`3o2?oonf[o0?lM
o`3Qo`Wooo]Z00?o0?ldo`3oC_oonfX01?oonfX01Ol0R?oo0:WooookJ_oonf[o00Co00;ooo]Z00?o
0=CooookJ_oonfX02?oonfX00oooP@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z02Gooo]Z000d
oookJP03o`1coooonf[ooo]Z017ooo]Z00?oogT0oookJ_oonfX01?oonfX00ooo5P3ooi80oookJP03
oookJP0>ool0o?oonf[ooo]ZoookJ_lH0?oooo]Zool60?oonf[ojol0ool0m_oonf[o0:KooookJ_nX
0?l2oookJP04ool0nOl0Mooooo]Zoom/00?ooo]Z00CoobP0oookJ_oonf[o0?_o0_oonfX01_oo003o
oo]ZoookJ_oo:03o/ol0oil0o`?ooo]Z00WogOl0oomi0?oonf[ooo]Zool0K?oonf[oobP0of40oooo
:0000ooonfX00ol0oi3ooo]Zo`3oTP02oookJPGoo`0000?oiOl0onKo0?l0M?l02?oonfX00ooo_P3o
obP0og00o`03oookJP04oomG0?oonf[ooo]Zool0;@Wooo]Z00Co0=Coo`04oooonf[o08So0_oo:000
1_l0odkoobP0oolX0?oonf[o0?l8oookJPKoo`0000?o403ooi;o0?oonfX02?oonfX01?lV0?oooo]Z
oookJ_oonfX6ooo90003oomB0?oob@3ooo]Z00Sooo]Z00?oo`3foookJ_oonfX00ooonfX6ool000Go
oo]Z0ooo:006oookJPCo00002OoonfX01?oo003oobP0oolX0?oo0003oookJP03oolX0?oonf[ooo]Z
00Gooo]Z00Co403ooookJ_oonf[ooo]Z0oooN@000ol0e?oooo]ZoookJP05oookJP07og00oooonf[o
oo]ZoookJ_oo:03o603ooolX0004oookJP03of40oooonf[ooo]Z00?ooo]Z00?oogT0oookJ_oonfX0
0ooonfX01OooK03ooo]ZoookJ_oo0?Kooo]Z00?oo`0000?oo`3loookJ_oonfX04_oonfX00oooDP3o
0?lco`0Zo`08oolX0003oookJ_oobP3oo`0000Woo`0000?ooo]ZobH0ooooN@002ooonfX01_l0oe_o
oo]ZoookJ_oo003ooo]Zo`0`o`;ooo]Z00?o1P3ooookJ_nBo`000_oonfX01Ol@0?oooo]ZoookJ_oo
nf[oo`1A00;ooo]Z00?oo`1ioookJ_oonfX01?oonfX01Ol0oe?ooo]Zo`3o2?oonf[o0?lM00[ooo]Z
00?o0?m>o`3o;_oonfX00ooonfX01Ol0R?oo0:WooookJ_oonf[o00Co00;ooo]Z00?o0=CooookJ_oo
nfX02OoonfX00oooP@3ooo]ZoookJP08oookJP03ool0;Ooonf[ooo]Z05Kooo]Z00?o07?ooookJ_oo
nfX04OoonfX00ooo0>[ooo]ZoookJP05oookJP03oonB0?oonf[ooo]Z00;ooo]Z00?oo`3loookJ_oo
nfX00_oonfX01olH0?ooo`H0oookJ_oonf[ojol0ool0m_l0Y_l00_oonfX01onX0?oooo]Zool0nOoo
nf[o07Ooo`3oV_ooK0000_oonfX01?lko`3ooo]ZoookJ_l0nol3oookJP06ool30?oonf[oN@3ooook
J_nco`3oW`3o0ooonfX02?l0omkooo]ZoookJ_oo06cooo]Zodd0oooonf[oH@3o0ooonfX00ol0oi3o
oo]Zo`3oTP04oookJP06ofP0oooonf[ooo]ZoookJ_lH0?oo07Co2?oonfX00ooo_P3o0?l5og00o`03
oookJP04oomG0?oonf[ooo]Zool0;@[ooo]Z00?o0=Coo`04ool0R?l00_oonfX00ol0odko0?ldoook
JP02oookJP05o`3o2?oonf[ooo]ZoookJ_oo07T00ooonfX00ol@0?ooT_l0oookJP07oookJP03obH0
oooonf[ooo]Z00Gooo]Z00Co0=cooookJ_oonf[ooe802_oonfX00ooo0?Kooo]ZoookJP0>oookJP03
oa00oooonf[ooo]Z00Gooo]Z1?l0000@oookJP03o`3Loooonf[ooo]Z00Gooo]Z00?o403ooookJ_oo
nfX01?oonfX00ol01?oo0=CooookJP05oookJP03og00oooonf[ooo]Z00;ooo]Z00?oi_l0oaP0oooo
nfX01?oonfX00omQ0?oooo]ZoookJP02oookJP03ok?o0?oonf[ooo]Z00?ooo]Z00Ooof`0oookJ_oo
nf[ooo]Zool0m_oonf[o603o00;ooo]Z00?oo`3loookJ_oonfX04_oonfX01_ooDP3o02[ooookJ_oo
nf[o0=coo`3og`Gooo]Z00?o4P3oooo:0?oonfX00_oonfX00ooo01?ooo]ZoookJP02oookJP04on7o
0?oonf[ooo]ZobH0o`_ooo]Z00Ko0?mKoookJ_oonf[oP_l0oookJ_l0<?l2oookJP06o`H0oooonf[o
oo]Zoi;o0?oonf[o403o1?oonfX01?oo057ooo]Zo`2]oooo07T5oookJP06o`3oDooonf[o0?l8oook
J_l0oago0>7o2OoonfX00ol0ocCo0?m>oookJP04oookJP07o`28ool0ZOoooo]ZoookJ_l01?oooo]Z
o`3Do`0;oookJP03oon10?oonf[ooo]Z00Wooo]Z00?oo`0]oookJ_oonfX09OoonfX003Cooo]Z00?o
07?ooookJ_oonfX04OoonfX00oooN@3ooo]ZoookJP03oookJP03oolF0?oonf[ooi8000Cooo]Z00ko
o`3loookJ_oonf[ooo]ZoaP0oooonf[oo`H0oookJ_o[o`3oo`3foookJ_l0Y_oooo]ZojP0o`;ooo]Z
00Coo`3io`1goooonf[oof`00ooonfX01?oo:03ooo]ZoookJ_l0nol2oookJP06ool00?oonf[ooo]Z
oolX0?nco`3oW`3o0ooonfX02OoMo`3oogT0oookJ_oonf[oo`1/oookJ_oo:03oH@3ooolX0003oook
JP03o`3oT?oonf[o0?nB00;ooo]Z1Ooo00000ooUo`3oi_l0o`1do`08oookJP03oonn0?m`0?oooo]Z
00;ooo]Z00CooeL0oookJ_oonf[oo`0]2_oonfX01?l0e?oo00CooookJ_l0R?l2oolX0005o`3oC_oo
:03oobP0oookJ_l0o`P01ooo00000ol@0?ooT_l0oookJP08oookJP03obH0oooonf[ooo]Z00Cooo]Z
0ooob@000oooDP3oolT0oookJP08oookJP03ool0m_oonf[ooo]Z00;ooo]Z1ooo0004oookJP?oobP0
1ooonfX4o`0000Wooo]Z00?oo`00oolX0?oo:0000_oo:002oookJP03o`3Loooonf[ooo]Z00Gooo]Z
00Co403ooookJ_oonf[ooo]Z0oooN@000ol0e?ooogT0oomi0005oookJP06og00oooonf[ooo]Zoook
J_oo:03o603o1OoonfX00omQ0?oooo]ZoookJP03oookJP03oomi0?oonf[ooo]Z00?ooo]Z00Goof`0
oookJ_oonf[oo`3foookJP02ool00003ool0o?oonf[ooo]Z01?ooo]Z00?ooe80o`3o<ol0:_l02?oo
:0000ooonf[oolX0ool00007ool00005oookJ_oo003ooo]ZobH0ooooN@002ooonfX01_l0oe_ooo]Z
oookJ_oo003ooo]Zo`0`o`;ooo]Z00?o1P3ooookJ_nBo`000_oonfX01Ol@0?oooo]ZoookJ_oonf[o
o`1A00;ooo]Z00?oo`1ioookJ_oonfX01?oonfX01Ol0oe?ooo]Zo`3o2?oonf[o0?lM00[ooo]Z00?o
0?m>o`3o;_oonfX00ooonfX01Ol0R?oo0:WooookJ_oonf[o00Co00;ooo]Z00?o0=CooookJ_oonfX0
2?oonfX00oooP@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z05Kooo]Z00?o07?ooookJ_oonfX0
4OoonfX00ooo0>[ooo]ZoookJP04oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00?oo`3loookJ_oonfX0
0_oonfX01olH0?ooo`H0oookJ_oonf[ojol0ool0m_l0Y_l00_oonfX01onX0?oooo]Zool0nOoonf[o
07Ooo`3oV_ooK0000_oonfX01?lko`3ooo]ZoookJ_l0nol3oookJP06ool30?oonf[oN@3ooookJ_nc
o`3oW`3o0ooonfX02?l0omkooo]ZoookJ_oo06cooo]Zodd0oooonf[oH@3o0ooonfX00ol0oi3ooo]Z
o`3oTP04oookJP06ofP0oooonf[ooo]ZoookJ_lH0?oo07Co2?oonfX00ooo_P3oL03ooookJP03oook
JP04oomG0?oonf[ooo]Zool0;@[ooo]Z00?o0=Coo`04ool0R?l00_oonfX00ol0odko0?ldoookJP02
oookJP05o`3o2?oonf[ooo]ZoookJ_oo07T00ooonfX00ol@0?ooT_l0oookJP07oookJP03obH0oooo
nf[ooo]Z00Gooo]Z00Co0=cooookJ_oonf[ooe802OoonfX00ooo0?Kooo]ZoookJP0?oookJP03oa00
oooonf[ooo]Z00Gooo]Z1?l0000@oookJP03o`3Loooonf[ooo]Z00Gooo]Z00?o403ooookJ_oonfX0
1?oonfX00ol01?oo0=CooookJP05oookJP03og00oooonf[ooo]Z00;ooo]Z00?oi_l0oaP0oooonfX0
1?oonfX00omQ0?oooo]ZoookJP02oookJP03ok?o0?oonf[ooo]Z00?ooo]Z00Woof`0oookJ_oonf[o
oo]Zool0m_oonf[o603ooookJ_oo0?`05OoonfX01_ooDP3o02[ooookJ_oonf[o0=coo`3og`Gooo]Z
00?o4P3oooo:0?oonfX00_oonfX00ooo01?ooo]ZoookJP02oookJP04on7o0?oonf[ooo]ZobH0o`_o
oo]Z00Ko0?mKoookJ_oonf[oP_l0oookJ_l0<?l2oookJP03o`H0oooonf[oT_l000;ooo]Z00?o403o
oookJ_oonfX00_oonfX01?oo057ooo]Zo`2]oooo07T5oookJP06o`3oDooonf[o0?l8oookJ_l0oago
0>7o2OoonfX00ol0ocCo0?m>oookJP04oookJP07o`28ool0ZOoooo]ZoookJ_l01?oooo]Zo`3Do`0;
oookJP03oon10?oonf[ooo]Z00Wooo]Z00?oo`0]oookJ_oonfX09OoonfX003Cooo]Z00?o07?ooook
J_oonfX04OoonfX00oooN@3ooo]ZoookJP03oookJP03oolF0?oonf[ooi8000Cooo]Z00koo`3loook
J_oonf[ooo]ZoaP0oooonf[oo`H0oookJ_o[o`3oo`3foookJ_l0Y_oooo]ZojP0o`;ooo]Z00Coo`3i
o`1goooonf[oof`00ooonfX01?oo:03ooo]ZoookJ_l0nol2oookJP06ool00?oonf[ooo]ZoolX0?nc
o`3oW`3o0ooonfX02OoMo`3oogT0oookJ_oonf[oo`1/oookJ_oo:03oH@3ooolX0003oookJP04o`3o
T?oonf[o0?nBoookJPKoo`0000?oiOl0onKo0?oonfX01ooonfX00ooo_P3oobP0og00o`03oookJP04
oomG0?oonf[ooo]Zool0;@[ooo]Z00?o0=Coo`04oooonfX00ooo:0001Ol0odkoobP0oolX0?oonf[o
0?l800?ooo]Z1?oo00000ol@0?ooT_l0oookJP08oookJP03obH0oooonf[ooo]Z00Gooo]Z00Co0=co
oookJ_ooDP3oolT02OoonfX00ooo0?Kooo]ZoookJP02oookJPOoo`000ooonfX4oolX00Oooo]Z1?l0
0009oookJP03ool00?oo:03oobP000CoobP000?o0=cooookJ_oonfX01OoonfX01?l@0?oooo]Zoook
J_oonfX3oomi0003o`3DooooN@3oogT000;oogT00ooonfX00om`0?oooo]ZoookJP02oookJP03oaP0
oooonf[ooo]Z00?ooo]Z00?oH@3ooookJ_oonfX00ooonfX00onco`3ooo]ZoookJP03oookJP05oom/
0?oonf[ooo]Zool0m_oonfX00_oo00000ooo0?cooo]ZoookJP0CoookJP03oomB0?l0oc?o02[o00Oo
obP00_oonfX00ooobP3ooo]Zool00006ool00005oookJ_oo003ooo]ZobH0ooooN@002ooonfX01_l0
oe_ooo]ZoookJ_oo003ooo]Zo`0`o`;ooo]Z00?o1P3ooookJ_nBo`000_oonfX01Ol@0?oooo]Zoook
J_oonf[oo`1A00;ooo]Z00?oo`1ioookJ_oonfX00ooonfX01_l0oe?ooo]ZoookJ_l0o`Sooo]Zo`3o
7@Wooo]Z00?o0?ldo`3oC_l0obh01?oonfX01Ol0R?oo0:WooookJ_oonf[o00Co00;ooo]Z00?o0=Co
oookJ_oonfX02?oonfX00oooP@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z05Kooo]Z00?o07?o
oookJ_oonfX04OoonfX00ooo0>[ooo]ZoookJP04oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00?oo`3l
oookJ_oonfX00_oonfX01olH0?ooo`H0oookJ_oonf[ojol0ool0m_l0Y_l00_oonfX01onX0?oooo]Z
ool0nOoonf[o07Ooo`3oV_ooK0000_oonfX01?lko`3ooo]ZoookJ_l0nol3oookJP06ool30?oonf[o
N@3ooookJ_nco`3oW`3o0ooonfX02?l0omkooo]ZoookJ_oo06cooo]Zodd0oooonf[oH@3o0ooonfX0
0ol0oi3ooo]Zo`3oTP04oookJP05ofP0oooonf[ooo]ZoookJ_lH0?l02?oonfX00ooo_P3ooo]Zog00
o`04oookJP04oomG0?oonf[ooo]Zool0;@[ooo]Z00?o0=CooookJ_l0R?l00_oonfX00ol0odko0?ld
oookJP02oookJP05o`3o2?oonf[ooo]ZoookJ_oo07T00ooonfX00ol@0?ooT_l0oookJP07oookJP03
obH0oooonf[ooo]Z00Gooo]Z00?o0=cooookJ_ooDP002_oonfX00ooo0?Kooo]ZoookJP0?oookJP03
oa00oooonf[ooo]Z00Gooo]Z1?l0000@oookJP03o`3Loooonf[ooo]Z00Gooo]Z00?o403ooookJ_oo
nfX01?oonfX00ol01?oo0=CooookJP05oookJP03og00oooonf[ooo]Z00;ooo]Z00?oi_l0oaP0oooo
nfX01?oonfX00omQ0?oooo]ZoookJP02oookJP03ok?o0?oonf[ooo]Z00?ooo]Z00Woof`0oookJ_oo
nf[ooo]Zool0m_oonf[o603ooookJ_oo0?`05OoonfX01_ooDP3o02[ooookJ_oonf[o0=coo`3og`Go
oo]Z00?o4P3oooo:0?oonfX00_oonfX00ooo01?ooo]ZoookJP02oookJP04on7o0?oonf[ooo]ZobH0
o`_ooo]Z00Ko0?mKoookJ_oonf[oP_l0oookJ_l0<?l2oookJP03o`H0oooonf[oT_l000;ooo]Z00?o
403ooookJ_oonfX00_oonfX01?oo057ooo]Zo`2]oooo07T4oookJP07o`3oDooonf[ooo]Zo`3o2?oo
nf[o0?lMo`3Qo`08oookJP03o`3o=?l0odko0?l^00Gooo]Z00Oo08Soo`2Yoooonf[ooo]Zo`04oooo
nf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP0UoookJP00:?oonfX<
o`000003o`1cool0003o0000017o000000?oogT0o`000?l000000ol000000ooo5P3o0000oonB0004
o`000004ool0o?l0003o0000oaP0o`;o000000Ooo`H0o`000?o[o`3oo`3fo`000?l0Y_ooZ03o00?o
000000Coo`3io`1gool0003oof`00ol000000ooo:03o0000o`3ko`03o`000006ool00?l0003o0000
oolX0?nco`3oW`3o0ol000002OooN@3o0000o`000?l0003oo`1/o`000?oo:03oH@3oo`3oA@03o`00
0004o`3oT?l0003o0?nBo`0000Koo`0000?oiOl0onKo0?l000001ol000000ooo_P3oobP0og00o`03
o`000004oomG0?l0003o0000ool0;@[o000000?o0=Coo`04ool000000_oo:0000ol0odkoobP0oolX
0002oolX0003o`3o2?l0003o000000;o000000Goo`00o`000?oo003o403ooi;o0009o`000003obH0
ool0003o000000Go000000?o0=cooomB0?l000002_l000001?oo0?Ko0000o`000?l00008ool000;o
00001Ooo:00Do`0000SoobP01ol000001?l@0?oo0000o`000?l00003oomi0003o`3DooooN@3oogT0
00;oogT00ol000001_m`0?oo0000o`000?l0003o603ooolX00Go000000?oH@3oo`000?l000000ol0
00000onco`3o0000o`000002o`000005oom/0?l0003o0000o`000?oo0?H00_l000000ooo003oo`3l
o`00000Do`000003oomB0?l0003o02[o00OoobP00_l000000ooobP3o0000ool00006ool00005o`00
0?oQo`3o0000obH0oolPo`002ol000001_l0oe_o0000o`000?oo003o0000o`0`o`;o000000?o1P3o
o`000?nBo`000_l000001?l@0?oo0000o`000?oo0543o`000003ool0NOl0003o000000?o000000Ko
0?mCo`000?l0003o0?l8o`000?l0oad9o`000003o`3o=?l0odko0?l^00Co000000Go08Soo`2Yool0
003o0000o`04o`02o`000003o`3Dool0003o000000So000000?ooh40o`000?l000002Ol000000ooo
02go0000o`000002o`0004Sooo]Z3?l000000ol0Looo0000o`00000Ao`000003ool0j_l0003o0000
00Co000000?ooaH0oonB0?l000000ol000001ooo0?co0000o`000?l0003o603oo`000?oo1P000_l0
00001Oo[o`3oo`3fo`2Vool0003oZ03o00;o000000Goo`3io`000?l0Mooo0?nJoom/0002o`000003
oc_o0?l0003o0?_o00?o000000Ooo`<0o`000?l0003oN@3oo`000?nco`3oW`3o00;o000000Wo0?oN
omgo0?l0003o0000ool0K?l0003oC@3oo`000?mQ0?l00ol000000ol0oi3o0000o`3oTP04o`000005
ofP0ool0003o0000o`000?lH0?l02?l000000ooo_P3o0000og00o`04o`000004oomG0?l0003o0000
ool0;@Wo000000Co0=Coo`04ool0003o08So0_l000000ol0odko0000o`000002o`000005o`3o2?l0
003o0000o`000?oo07T00ol000000ol@0?ooT_l0o`000007o`000003obH0ool0003o000000Go0000
00?o0=coo`000?ooDP002_l000000ooo0?Ko0000o`00000?o`000003oa00ool0003o000001Co0000
00?oo`3fo`000?l000000_l000000ol0g?oo0000o`000005o`000003oa00ool0003o000000Co0000
00?o0=Coo`000?l000001Ol000000om`0?oo0000o`000002o`000003oaP0ool0003o000000Co0000
00?oH@3oo`000?l000000_l000000onco`3o0000o`000003o`000009oom/0?l0003o0000o`000?oo
0?Ko0000oaP0ool0003oo`3l01Go000000Kooe80o`0Zool0003o0000o`3Lool0oml5o`000003oa80
oooobP3o000000;o000000?oo`0Co`000?l000000_l000001?oQo`3o0000o`000?lV0?l;o`000006
o`3oFol0003o0000oh;o0?l0003o033o0_l000000ol60?oo0000oi;o0002o`000005oa00ool0003o
0000o`000?oo05400_l000000ol0[Oooo`1io`000003o`000007o`3oDol0003o0000o`3o2?l0003o
0?lMo`3Qo`08o`000003o`3o=?l0odko0?l^00Co000000?o08Soo`000?l0ZOl00_l000000ol01?oo
0000o`3Do`0;o`000003oon10?l0003o000000Wo000000?oo`0]o`000?l000000_l0000SoookJP00
:?oonfX<o`000003o`1cool0003o0000017o000000?oogT0o`000?l000000ol000000ooo5P3o0000
oonB0003o`000005ool0o?l0003o0000o`000?lH0?l00_l000001ooo1P3o0000on_o0?oo0?Ko0000
o`2VoonX0?l00ol000001?oo0?Wo07Oooom/0?l0oiX3o`000003oolX0?l0003o0?_o00?o000000Ko
o`00o`000?l0003oobP0ok?o0?nO0?l3o`000009oomi0?l0003o0000o`000?oo06co0000oolX0?mQ
0?oo0?m500?o000000Co0?n@o`000?l0oi;o00001_oo00000ooUo`3oo`00o`000007o`0000;oobP0
00GoL03oo`000?l0003o0000oomG0002o`000003ool0;Ol0003o000000So000000?o0=Coo`04ool0
00000_oo:0000ol0odkoobP0oolX0002oolX0003o`3o2?l0003o000000;o000000Goo`00o`000?l0
003o403ooi;o0009o`000003obH0ool0003o000000Go000000?o0=cooomB0?l000002Ol000001?oo
0?Ko0000o`000?l00009ool000;o00001Ooo:00Do`0000SoobP01ol000001?l@0?oo0000o`000?l0
0003oomi0004o`3DooooN@3oogT0oomi00Co000000KoL03oo`000?l0003o0000oaP0oooVo`05o`00
0003of40ool0003o000000?o000000?o/ol0o`000?l000000_l000001OooK03o0000o`000?l0003o
o`3f00;o000000?oo`00ool0o?l000005?l000000oooDP3o0000o`0Zo`07oolX00;o000000?oolX0
o`000?oo00001Ooo0002o`000004on7o0?l0003o9P3oob3o00_o000000Ko0?mKo`000?oo003oobP0
o`000?l0<?l2o`000003o`H0ool0003oT_l000;o000000CoA?l0o`000?l0003oo`1A0_l000000ooo
:03oo`1io`000004o`000006o`3oDol0003o0000o`3o2?l0oago0>7o2Ol000000ol0ocCo0?m>o`3o
;P04o`000005o`28ool0ZOoo0000o`000?l01?l00_l000000ol0e?oo0000o`000008o`000003oon1
0?l0003o000000Wo000000?oo`0]o`000?l000000_l00018oookJPco000000?o07?oo`000?l00000
4Ol000000ooo0>[o0000o`000004o`000003oolF0?ooTP3o000000?o000000Ooo`3lo`000?l0003o
0000oaP0ool0003oo`H000;o000000Gojol0ool0m_l0Y_oo0000ojP0o`02o`000004ool0nOl0003o
07Oooom/00?o000000?o>ol0o`000?l0nol00ol000001ooo0`3o0000o`000?mi0?oo0000ok?o0?nO
0?l00_l000002Ol0omkogOl0o`000?l0003oo`1/o`000?m=0?oo0000of40o`03o`000003o`3oT?l0
003o0?nB00Co000000GoJ03oo`000?l0003o0000oaP0o`08o`000003oonn0?l0003oL03o00Co0000
00CooeL0o`000?l0003oo`0]2Ol000001ol0e?oo00Coo`000?l0R?oo0000o`3oC_l0oc@01?l00000
1Ol0o`So0000o`000?l0003oo`1i00?o000000?oT_l0o`000?l000001ol000000olV0?oo0000o`00
0005o`000003o`3Lool0003ooe8000[o000000?oo`3fo`000?l000003ol000000ol@0?oo0000o`00
000Do`000003ool0m_l0003o000000;o000000?o0=coo`000?l000001Ol000000ol@0?oo0000o`00
0004o`000003o`3Dool0003o000000Go000000?oL03oo`000?l000000_l000000olH0?oo0000o`00
0004o`000003of40ool0003o000000;o000000?o/ol0o`000?l000000ol000002OooK03o0000o`00
0?l0003oo`3fo`000?lH0?oo0000ool0o00Eo`000006oomB0?l0:_oo0000o`000?l0g?oo0?oO1Ol0
00000olB0?ooolX0o`000002o`000003ool04ol0003o000000;o000000CohOl0o`000?l0003o9P3o
2ol000001_l0oe_o0000o`000?n2o`3o0000o`0`o`;o000000?o1P3oo`000?nBo`000_l000002Ol@
0?oo0000o`000?l0003oo`1Ao`000?l0[Ooo0000ool0N@04o`000007o`3oDol0003o0000o`3o2?l0
oago0000o`3Qo`08o`000003o`3o=?l0odko0?l^00Co000000?o08Soo`2Yool000000_l000000ol0
1?oo0000o`3Do`0;o`000003oon10?l0003o000000Wo000000?oo`0]o`000?l000000_l0000Soook
JP00:?oonfX;o`000003o`1cool0003o000001;o000000?oogT0o`000?l000000ol000000ooo5P3o
0000oonB0003o`000005ool0o?l0003o0000o`000?lH0?l00_l000001ooo1P3o0000on_o0?oo0?Ko
0000o`2VoonX0?l00ol000001?oo0?Wo07Oooom/0?l0oiX2o`000004oolX0?l0003o0000o`3ko`;o
000000Ooo`00o`000?l0003oobP0o`000?nco`3oW`3o00?o000000WoogT0o`000?l0003o0000ool0
K?l0003oobP0of40ool0odD00ol000000ol0oi3o0000o`3oTP07ool00003onGo0?oo003o000000Oo
00000_oo:0001Om`0?oo0000o`000?l0003ooeL000;o000000?oo`0]o`000?l000002?l000000ol0
e?oo00CooolX0002oolX0003o`3oC_oo:03oobP000;oobP000Go0?l8o`000?l0003o0000ool00003
o`000003oa00oonBo`3o000000Oo000000?o9P3oo`000?l000001_l000000ol0g?oooe80o`000009
o`000003ool0m_l0003o000000Co00001_oo00000ol0003oobP0oolX0004oolX01Co00001ooo:000
0ol0g?oo0000o`000004o`000003oa00ool0003o000000;o00000oooN@001?l0e?ooogT0oomi0?oo
N@04o`000006og00ool0003o0000o`000?lH0?ooi_l01Ol000000omQ0?oo0000o`000002o`000003
ok?o0?l0003o000000?o000000Goof`0o`000?l0003o0000ool0mP02o`000003oaP0oooo0?co0000
01Co000000?ooe80o`000?l0:_l01_oo:003o`000003ooo:0?l0003oo`0000Goo`000_l000001?oQ
o`3o0000obH0oolPo`0;o`000008o`3oFol0003oo`00oolX0?l0003o033oo`000?l60?l2o`000004
oi;o0?l0003o0000odCo00;o000000Goo`1Ao`000?l0003oobP0ool0N@05o`000006o`3oDol0003o
0000o`3o2?l0oago0>7o2Ol000000ol0ocCo0?m>o`3o;P03o`000003o`28ool0003o0:Wo00;o0000
00Co00Coo`000?l0003o0=Co2_l000000oooP@3o0000o`000009o`000003ool0;Ol0003o000000;o
0000B?oonfX;o`000003o`1cool0003o000001;o000000?oo`3Zo`000?l000001?l000000ooo5P3o
oi80o`000002o`000003ool0o?l0003o000000;o000000?o603oo`000?oo1P000_l000001Oo[o`3o
0000o`2Vool0003oZ03o00;o000000Coo`3io`000?l0Moooof`00ol000000olko`3o0000o`3ko`03
o`000003ool30?l0003oN@3o00;o000000Ko/ol0oil0ool0003o0000o`3og_oMo`02o`000005ool0
K?l0003oC@3oo`000?mQ0?l00ol000000ol0oi3o0000o`3oTP04o`000005ofP0ool0003o0000oaP0
oooVo`002?l000000ooo_P3o0000og00o`04o`000004oomG0?l0003o0000ool0;@Wo000000Oo0=Co
o`04ool0003o08Soo`000?l0odko0?ld00Co000000Co0?l8o`000?l0003oo`1i0ol000000ol@0?oo
T_l0o`000007o`000003obH0ool0003o000000Ko000000?o0=coo`000?ooDP002_l000000ooo0?Ko
0000o`00000?o`000003oa00ool0003o000001Co000000?oo`3fo`000?l000000_l000000ol0g?oo
0000o`000005o`000003oa00ool0003o000000Co000000?o0=Coo`000?l000001Ol000000om`0?oo
0000o`000002o`000003oaP0ool0003o000000Co000000GoH@3oo`000?l0003o0000ok?o0005o`00
0003oom/0?l0003o000000;o000000Goo`3fo`000?lH0?oo0000ool0o00Eo`000006oomB0?l0:_oo
0000o`000?l0g?oo0?oO1Ol000000olB0?ooolX0o`000002o`000003ool04ol0003o000000;o0000
00CohOl0o`000?l0003o9P3o2ol000002?l0oe_o0000o`000?n2o`3o0000o`0`ool0003o1P3o0_l0
00001?nBo`3o0000o`000?l@0?l3o`000005ool0DOl0003o0:goo`000?oo07T01?l000001ol0oe?o
0000o`000?l0o`So0?lMo`000?l0hOl02?l000000ol0ocCo0?m>o`3o;P04o`000003o`28ool0ZOoo
000000;o000000?o00Coo`000?l0e?l02ol000000oooP@3o0000o`000008o`000003ool0;Ol0003o
000000?o00008ooonfX002Sooo]Z2ol000000ol0Looo0000o`00000Bo`000003oomi0?l0003o0000
00?o000000?ooaH0o`000?ooTP000ol000001Ooo0?co0000o`000?l0003o603o00;o000000Ooo`H0
o`000?o[o`3oo`3fo`000?l0Y_ooZ03o00?o000000Coo`3io`1gooooK03o0?nJ0_l000001?oo:03o
0000o`000?l0nol2o`000007ool00?l0003o0000oolX0?l0003o/ol0ool00002o`000003omgo0?l0
omko000000;o000000Goo`1/oolX0?l0003oH@3oo`3oA@03o`000003o`3oT?l0003o0?nB00Ooo`00
00?oiOl0ool00?l000001ol00002oolX0005og00ool0003o0000o`000?ooE`000_l000000ooo02go
0000o`000008o`000006o`3Dool01?oo0000o`28ool0003o0?m>1?oo:0001Ol0o`So0000o`000?l0
003oo`0000?o000000?o403ooi;o0?l000001ol000000olV0?oo0000o`000006o`000003o`3Loooo
DP3o000000Wo000000?oo`3fo`000?l000002?l00002ool000OoobP05?l00006oolX0003o`000?l0
g?oo000000Go000000?o403oo`000?l000000_l00003oomi0003o`3DooooN@3oogT000Co000000?o
L03oo`000?l000000_l000000olH0?ooi_l0o`000004o`000003of40ool0003o000000;o000000?o
/ol0o`000?l000000ol000001OooK03o0000o`000?l0003oo`3f00;o000000?o603oool0o?l00000
5?l000000oooDP3o0000o`0Zo`06oolX00;o000000?o4P3oooo:0?l000001_oo00001Ol0003ohOl0
o`000?l0003o9P3o00co000000?o0?mKo`000?oo00000_l000001Ol0<?oo0000o`H0ool0003oT_l0
00?o000000CoA?l0o`000?l0003oo`1A0_l000000ooo:03oo`1io`000004o`000006o`3oDol0003o
0000o`3o2?l0oago0>7o2Ol000000ol0ocCo0?m>o`3o;P03o`000003o`28ool0003o0:Wo00;o0000
00Co00Coo`000?l0003o0=Co2_l000000oooP@3o0000o`000009o`000003ool0;Ol0003o000000;o
0000B?oonfX;o`000003o`1cool0003o000001;o000000?oo`3Zo`000?l000001?l000000ooo5P3o
oi80o`000002o`000003ool0o?l0003o000000;o000000?o603oo`000?oo1P000_l000001Oo[o`3o
0000o`2Vool0003oZ03o00;o000000Coo`3io`1gool0003oof`00ol000000olko`3o0000o`3ko`03
o`000006ool30?l0003oN@3oo`000?l0Xooo/ol00ol000001_l0omko0000o`000?l0003oo`1/odd0
o`;o000000OoH@3oo`000?l0003o0000o`3oT?l0003o0?nB00Co000000GoJ03oo`000?l0003o603o
onKo0008o`000003oonn0?l0003oL03o00Co000000CooeL0o`000?l0003oo`0]2Ol000001ol0e?oo
00Coo`000?l0R?oo0000o`3oC_l0oc@01?l000001?l0o`So0000o`000?oo07T3o`000003oa00oonB
o`3o000000Oo000000?o9P3oo`000?l000001_l000000ol0g?oo0000oomB000:o`000003ool0m_l0
003o000000ko000000?o403oo`000?l000005?l000000ooo0?Ko0000o`000003o`000003o`3Lool0
003o000000Go000000?o403oo`000?l000001?l000000ol0e?oo0000o`000005o`000003og00ool0
003o000000;o000000?o603oo`000?l000001?l000001OmQ0?oo0000o`000?l0003o/ol000Go0000
00?oof`0o`000?l000000_l000001Ooo0?Ko0000oaP0ool0003oo`3l01Go000000Kooe80o`0Zool0
003o0000o`3Lool0oml4o`000003oa80ool0003oolX000?o000000Goo`0Co`000?l0003o0000on7o
0002o`000003ob3o0?lV0?oo000000[o000000So0?mKo`000?l0ok3oP_l0o`000?l0<?oo0000o`H0
o`;o000000CoT_l0o`000?l0003o403o0ol000001Ooo057o0000o`2]ool0003oo`1i00Co000000Oo
0?mCo`000?l0003o0?l8o`3o7Ol0003o0>7o00So000000?o0?ldo`3oC_l0obh01?l000000ol0R?oo
0:Woo`000002o`000003o`04ool0003o0=Co00_o000000?ooh40o`000?l000002?l000000ooo02go
0000o`000003o`0002?ooo]Z000ZoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o07?ooookJ_oonfX0
4_oonfX00oooN@3ooo]ZoookJP03oookJP03oolF0?oonf[ooi8000?ooo]Z00Goo`3loookJ_oonf[o
oo]ZoaP0o`02oookJP07ool60?oonf[ojol0ool0m_oonf[o0:KoojP0o`03oookJP04ool0nOl0Mooo
of`0o`3oVP;ooo]Z00OoobP0oookJ_oonf[o0?_ooookJ_l0003oo`0000;ooo]Z00?oobP0oookJ_nc
o`000ooonfX00ooMo`3o0?oNoookJP02oookJP05ool0K?oo:03ooo]Zof40ool0odD00ooonfX00ol0
oi3ooo]Zo`3oTP04oookJP05ool00?oonf[ooo]ZonGo0?oVo`001ooonfX3oolX0005og00oooonf[o
oo]ZoookJ_ooE`000_oonfX00ooo02gooo]ZoookJP08oookJP0;o`3Dool01?oooo]Zo`28oooonf[o
0?m>oolX0?oonf[o0000oookJ_l0o`P00ooonfX01_oo003ooo]ZoookJ_l@0?oooo]Zoi;o00Sooo]Z
00?o9P3ooookJ_oonfX01OoonfX00ol0g?oooo]ZoomB000:oookJP03ool0m_oonf[ooo]Z00[ooo]Z
1ooo:007oookJPCo00002OoonfX5oolX00;ooo]Z00?o0=cooookJ_oonfX01?oonfX00ol@0?oooo]Z
oookJP02oookJP?oogT000?o0=Cooomi0?ooN@001?oonfX00om`0?oooo]ZoookJP02oookJP03oaP0
oooonf[ooo]Z00Cooo]Z00?oH@3ooookJ_oonfX00_oonfX00onco`3ooo]ZoookJP03oookJP05oom/
0?oonf[ooo]ZoookJ_oo0?H00_oonfX00olH0?ooo`3loookJP0DoookJP04oomB0?oonf[o02[ooook
JPGoobP00_oonfX01?lB0?ooolX0oookJ_oonfX4ool000;ooo]Z00CohOl0oookJ_oonf[o9P3o3?oo
nfX00ol0oe_ooo]Zool00002oookJP09o`0`oooonf[o1P3ooookJ_nBo`3ooo]Zo`000?oonf[oA?l0
00;ooo]Z00Goo`1AoookJ_oonf[oobP0ool0N@05oookJP06o`3oDooonf[ooo]Zo`3o2?l0oago0>7o
2OoonfX00ol0ocCo0?m>o`3o;P03oookJP03o`28oooonf[o0:Wo00;ooo]Z00?o00CooookJ_l0e?l0
2ooonfX00oooP@3ooo]ZoookJP09oookJP04ool0;Ooonf[ooo]Zo`0004_ooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Cooo]Z00?ooaH0oonB0?oo
nfX00_oonfX00ooo0?cooo]ZoookJP02oookJP03oaP0oooonf[oo`H000;ooo]Z00Gojol0oookJ_l0
Y_oooo]ZojP0o`02oookJP04ool0nOl0Mooooo]Zoom/00?ooo]Z00?o>ol0oookJ_l0nol00_oonfX0
1ol0003oo`<0oookJ_mi0?oooo]Zo`2Soonco`000ooonfX01_l0omkooo]ZoookJ_oonf[oo`1/odd0
o`;ooo]Z00OoH@3ooookJ_oonf[ooo]Zo`3oT?oonf[o0?nB00Cooo]Z00GoJ03ooookJ_oonf[o603o
onKo0008oookJP03oonn0?l0o`GoL03o00?ooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@09oookJP09
o`3Dool01?oooo]Zo`28oooonf[o0?m>o`3o=?oonf[o000000;ooo]Z00Co0?l8oookJ_oonf[oo`1i
0ooonfX00ol@0?ooT_l0oookJP07oookJP03obH0oooonf[ooo]Z00Kooo]Z00?o0=cooookJ_ooDP00
2_oonfX00ooo0?Kooo]ZoookJP0>oookJP03oa00oooonf[ooo]Z00Kooo]Z1?l0000:oookJP03ool0
m_oonf[ooo]Z00?ooo]Z00?o0=cooookJ_oonfX01OoonfX00ol@0?oooo]ZoookJP04oookJP03o`3D
oooonf[ooo]Z00Gooo]Z00KoL03ooookJ_oonf[ooo]ZonKo0?lH0?l6oookJP05of40oooonf[ooo]Z
oookJ_nco`001OoonfX00oooK03ooo]ZoookJP02oookJP05ool0m_oonf[o603oo`000?oo0?`05?oo
nfX00oooDP3o0?lco`0Zo`02oookJP03o`3Lool0omoooo]Z00?ooo]Z00?o4P3ooookJ_oobP000ooo
nfX01Ooo01?ooo]ZoookJ_oonf[ohOl000;ooo]Z00?o8?l0obH0oooonfX02_oonfX00ol0oe_ooo]Z
oh;o0002oookJP03o`0`oooonf[o1P3o00;ooo]Z00CoT_l0o`000?oonf[o403o0ooonfX01Ooo057o
oo]Zo`2]oooonf[oo`1i00Cooo]Z00Oo0?mCoookJ_oonf[o0?l8o`3o7Ooonf[o0>7o00Sooo]Z00?o
0?ldo`3oC_l0obh01?oonfX00ol0R?oo0:WooookJP02oookJP03o`04ool0e?oooo]Z00[ooo]Z00?o
oh40oookJ_oonfX02OoonfX01Ooo02gooo]ZoookJ_oonf[o000002Cooo]Z000coookJP03o`1coooo
nf[ooo]Z01;ooo]Z00?oogT0oookJ_oonfX00ooonfX00ooo5P3ooo]ZoonB0003oookJP07ool0o?oo
nf[ooo]ZoookJ_lH0?oooo]Zool60002oookJP05on_o0?oo0?Kooo]Zo`2VoonX0?l00ooonfX01?oo
0?Wo07Oooom/0?l0oiX2oookJP04oolX0?oonf[ooo]Zo`3ko`;ooo]Z00Koo`00oookJ_oonf[oobP0
oookJ_nco`03oookJP0:omgo0?l0omkooo]ZoookJ_oo06cooo]ZoolX0?oonf[oH@3oo`3oA@?ooo]Z
00?o0?n@oookJ_l0oi801?oonfX01Ooo003ooo]ZoookJ_oUo`3oi_l000Oooo]Z0ooo:0001Om`0?oo
oo]ZoookJ_oonf[ooeL000;ooo]Z00?oo`0]oookJ_oonfX02?oonfX01_l0e?oooo]ZoookJ_l0R?oo
oo]Zo`3oCPCooo]Z00?o0?l8oookJ_oonfX01?oonfX00ol@0?ooT_l0oookJP08oookJP03ool00?oo
nf[ooo]Z00Gooo]Z00?o0=cooookJ_ooDP002_oonfX00ooo0?Kooo]ZoookJP09oookJPSoobP01ooo
nfX4o`0000Sooo]Z1_oo:0000ooonf[o0=cooookJP06oookJP03oa00oooonf[ooo]Z00;ooo]Z0ooo
N@000ol0e?ooogT0oomi0004oookJP03og00oooonf[ooo]Z00;ooo]Z00?o603ooookJ_oonfX01?oo
nfX00omQ0?oooo]ZoookJP02oookJP03ok?o0?oonf[ooo]Z00?ooo]Z00Woof`0oookJ_oonf[ooo]Z
ool0m_oonf[o603ooookJ_oo0?`05OoonfX01?ooDP3ooo]Zo`0ZoooonfX4oolX00?ooo]Z00Co4P3o
ooo:0?oonf[ooo]Z1?oo0002oookJP04on7o0?oonf[o9P3oob3o00cooo]Z00?o0?mKoookJ_oo0000
0_oonfX01Ol0<?oooo]Zo`H0oooonf[oT_l000;ooo]Z00GoA?l0oookJ_oonf[ooo]Zool0D@02oook
JP03oolX0?oo07Wooo]Z00Cooo]Z00Ko0?mCoookJ_oonf[o0?l8o`3o7Ol0hOl9oookJP03o`3o=?l0
odko0?l^00?ooo]Z00Go08SooookJ_l0ZOoooo]Zo`04o`02oookJP03o`3Doooonf[ooo]Z00Wooo]Z
00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP1EoookJP03o`1coooonf[ooo]Z01;ooo]Z
00?oo`3ZoookJ_oonfX01?oonfX00ooo5P3ooi80oookJP02oookJP03ool0o?oonf[ooo]Z00;ooo]Z
00?o603oool60?oonfX00_oonfX01Oo[o`3ooo]Zo`2Voooonf[oZ03o00;ooo]Z00Coo`3io`1goooo
nf[oof`00_oonfX01?lko`3ooo]ZoookJ_l0nol3oookJP06ool30?oonf[oN@3ooookJ_l0Xooo/ol0
0ooonfX02Ol0omkooo]ZoookJ_oo06cooo]Zodd0oooonf[oH@3oo`3oA@03oookJP03o`3oT?oonf[o
0?nB00Cooo]Z00GoJ03ooookJ_oonf[o603oonKo0008oookJP03oonn0?l0o`GoL03o00?ooo]Z00Go
oeL0oookJ_oonf[ooo]Zool0;@09oookJP07o`3Dool01?oooo]Zo`28oooonf[o0?m>o`3o=004oook
JP03o`3o2?oonf[ooo]Z00Cooo]Z00?o403ooi;o0?oonfX01ooonfX00olV0?oooo]ZoookJP06oook
JP03o`3Loooonf[ooe8000[ooo]Z00?oo`3foookJ_oonfX05ooonfX4o`0000[ooo]Z00?oo`3foook
J_oonfX00_oonfX00ol0g?oooo]ZoookJP06oookJP03oa00oooonf[ooo]Z00Cooo]Z00?o0=Cooook
J_oonfX01OoonfX01_m`0?oooo]ZoookJ_oonf[oi_l0oaP0o`Kooo]Z00GoH@3ooookJ_oonf[ooo]Z
ok?o0005oookJP03oom/0?oonf[ooo]Z00;ooo]Z00Goo`3foaP0oooonf[ooo]Zool0o00DoookJP03
oomB0?l0oc?o02[o00;ooo]Z00?o0=coo`3ogooonfX00ooonfX00olB0?oooo]Zooo:0003oookJP05
ool04ooonf[ooo]ZoookJ_oQo`000_oonfX00olV0?oooo]ZoookJP0:oookJP03o`3oFooonf[oP_l0
00;ooo]Z00Go033ooookJ_l60?oooo]Zoi;o0002oookJP03oa00oooonf[ooo]Z00;ooo]Z00Goo`1A
oookJ_l0[Ooooo]Zool0N@04oookJP07o`3oDooonf[ooo]Zo`3o2?l0oagooo]Zo`3Qo`08oookJP03
o`3o=?l0odko0?l^00Cooo]Z00Oo08Soo`2Yoooonf[ooo]Zo`04oooonf[o0=Co00_ooo]Z00?ooh40
oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP0VoookJP00<ooonfX00ol0Looooo]ZoookJP0Aoook
JP03oomi0?oonf[ooo]Z00Cooo]Z00?ooaH0oookJ_ooTP000ooonfX03_oo0?cooo]ZoookJ_oonf[o
603ooookJ_oo1P3ooo]Zon_o0?oonf[oo`3foookJ_l0Y_ooZ03o0_oonfX01Ooo0?Wo07OooookJ_oo
K03o0?nJ00;ooo]Z00CoobP0oookJ_oonf[o0?_o0_oonfX01_oo003ooo]ZoookJ_oo:03ooo]Zok?o
00?ooo]Z00[ogOl0o`3og_oonf[ooo]Zool0K?oonf[oobP0oookJ_mQ0?oo0?m50ooonfX00ol0oi3o
oo]Zo`3oTP04oookJP05ool00?oonf[ooo]ZonGo0?oVo`001ooonfX3oolX0005og00oooonf[ooo]Z
oookJ_ooE`000_oonfX00ooo02gooo]ZoookJP07oookJP07o`3Dool01?oooo]ZoookJ_l0R?oooo]Z
o`3oCP04oookJP03o`3o2?oonf[ooo]Z00Cooo]Z00?o403ooi;o0?oonfX02?oonfX00ooo003ooo]Z
oookJP05oookJP03o`3Loooonf[ooe8000[ooo]Z00?oo`3foookJ_oonfX02?oonfX8oolX0003ool0
0?oonf[ooo]Z00Gooo]Z1?l00008oookJPGoobP00_oonfX00ol0g?oooo]ZoookJP05oookJP03oa00
oooonf[ooo]Z00?ooo]Z0_ooN@000ol0e?ooogT0oookJP04oookJP03og00oooonf[ooo]Z00;ooo]Z
00?o603ooookJ_oonfX01?oonfX00omQ0?oooo]ZoookJP02oookJP03ok?o0?oonf[ooo]Z00;ooo]Z
00?oof`0oookJ_oonfX00_oonfX01Ooo0?Kooo]ZoaP0oooonf[oo`3l01Gooo]Z00Cooe80oookJ_l0
:_oooo]Z1?oo:003oookJP04oa80oooobP3ooo]ZoookJPCoo`000_oonfX01?oQo`3ooo]ZobH0oolP
o`0:oookJP;oobP000Go0?mKoolX0?oo003ooo]Zo`0`o`02oookJP03o`H0oooonf[oT_l000;ooo]Z
00GoA?l0oookJ_oonf[ooo]Zool0D@02oookJP03oolX0?oo07Wooo]Z00Cooo]Z00Ko0?mCoookJ_oo
nf[o0?l8o`3o7Ol0hOl8oookJP04o`3o=?oonf[o0?m>o`3o;P?ooo]Z00Go08SooookJ_l0ZOoooo]Z
o`04o`02oookJP03o`3Doooonf[ooo]Z00Wooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]Z
oookJP1EoookJP03o`1coooonf[ooo]Z017ooo]Z00?oo`3ZoookJ_oonfX01OoonfX00ooo5P3ooi80
oookJP02oookJP03ool0o?oonf[ooo]Z00;ooo]Z013o603oool60?oonf[ooo]Zon_o0?oo0?Kooo]Z
o`2Voooonf[oZ03ooookJ_oo0?Wooo]Zo`1goooonf[oof`00_oonfX01?lko`3ooo]ZoookJ_l0nol3
oookJP06ool30?oonf[oN@3ooookJ_l0Xooo/ol00ooonfX02Ol0omkooo]ZoookJ_oo06cooo]Zodd0
oooonf[oH@3oo`3oA@03oookJP03o`3oT?oonf[o0?nB00Cooo]Z00GoJ03ooookJ_oonf[o603oonKo
0008oookJP03oonn0?l0o`GoL03o00?ooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@09oookJP07o`3D
ool01?oooo]Zo`28oooonf[o0?m>o`3o=004oookJP03o`3o2?oonf[ooo]Z00Cooo]Z00?o403ooi;o
0?oonfX01ooonfX00olV0?oooo]ZoookJP06oookJP03o`3Loooonf[ooe8000[ooo]Z00?oo`3foook
J_oonfX05ooonfX4o`0000[ooo]Z00?oo`3foookJ_oonfX00_oonfX00ol0g?oooo]ZoookJP06oook
JP03oa00oooonf[ooo]Z00?ooo]Z00?o00Coo`3DoooonfX01OoonfX00om`0?oooo]ZoookJP02oook
JP03onKo0?lH0?oooo]Z00Cooo]Z00?oH@3ooookJ_oonfX00_oonfX00onco`3ooo]ZoookJP03oook
JP03oom/0?oonf[ooo]Z00;ooo]Z00Goo`3foaP0oooonf[ooo]Zool0o00DoookJP07oomB0?l0oc?o
02[ooookJ_l0g?oooo]Zo`3og`04oookJP03oa80oooonf[oolX000?ooo]Z00Goo`0CoookJ_oonf[o
oo]Zon7o0002oookJP03obH0oooonf[ooo]Z00[ooo]Z00Go0?mKoookJ_n2o`3ooo]Zo`0`o`02oook
JP03o`H0oooonf[oT_l000;ooo]Z00?o403ooookJ_oonfX00_oonfX01Ooo057ooo]Zo`2]oooonf[o
o`1i00Cooo]Z00Oo0?mCoookJ_oonf[o0?l8o`3o7Ooonf[o0>7o00Oooo]Z00Co0?ldoookJ_l0odko
0?l^1?oonfX01ol0R?oo0:WooookJ_oonf[o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP09
oookJP03ool0;Ooonf[ooo]Z02Kooo]Z000coookJP03o`1coooonf[ooo]Z017ooo]Z00?oogT0oook
J_oonfX01?oonfX00ooo5P3ooo]ZoonB0003oookJP0=ool0o?oonf[ooo]ZoookJ_lH0?oooo]Zool6
0?oonf[ojol0oookJ_oo0?Kooo]ZojP0o`03oookJP05ool0nOl0Mooooo]Zoom/0?l0oiX00_oonfX0
1?oo:03ooo]ZoookJ_l0nol2oookJP06ool00?oonf[ooo]ZoolX0?oonf[o/ol00ooonfX02_oMo`3o
0?oNoookJ_oonf[oo`1/oookJ_oo:03ooo]Zof40ool0odD3oookJP03o`3oT?oonf[o0?nB00Cooo]Z
00Goo`00oookJ_oonf[oiOl0onKo0007oookJP?oobP000GoL03ooookJ_oonf[ooo]ZoomG0002oook
JP03ool0;Ooonf[ooo]Z00Oooo]Z00Oo0=Coo`04oooonf[ooo]Zo`28oooonf[o0?m>00Cooo]Z00?o
0?l8oookJ_oonfX01?oonfX00ol@0?ooT_l0oookJP08oookJP;oo`001_oonfX00ol0g?oooo]ZoomB
000:oookJP03ool0m_oonf[ooo]Z00[ooo]Z1_oo:0000ooo003ooo]ZoookJP05oookJPCo00002?oo
nfX4oolX00?ooo]Z00?o0=cooookJ_oonfX01OoonfX00ol@0?oooo]ZoookJP03oookJP;oogT000?o
0=Cooomi0?oonfX01?oonfX00om`0?oooo]ZoookJP02oookJP03oaP0oooonf[ooo]Z00?ooo]Z00?o
H@3ooookJ_oonfX00ooonfX00onco`3ooo]ZoookJP02oookJP03oom/0?oonf[ooo]Z00;ooo]Z00Go
o`3foookJ_lH0?oooo]Zool0o00EoookJP04oomB0?oonf[o02[ooookJPCoobP00ooonfX01?lB0?oo
olX0oookJ_oonfX3ool000?ooo]Z00CohOl0oookJ_lV0?oo8?l02_oonfX2oolX0003o`3oFooo:03o
o`0000CoobP000?o1P3ooookJ_nBo`000_oonfX02Om4o`3ooo]ZoookJ_oonf[oo`1AoookJ_oo:03o
oo]Zool0N@05oookJP06o`3oDooonf[ooo]Zo`3o7Ooonf[o0>7o2?oonfX01?l0ocCooo]Zo`3oC_l0
obh3oookJP05o`28oooonf[o0:WooookJ_l01?l00_oonfX00ol0e?oooo]ZoookJP08oookJP03oon1
0?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX0EOoonfX00ol0Looooo]ZoookJP0AoookJP03ool0
j_oonf[ooo]Z00Gooo]Z00?ooaH0oonB0?oonfX00_oonfX00ooo0?cooo]ZoookJP02oookJP09oaP0
oooo1P3ooo]ZoookJ_o[o`3oo`3foookJ_l0Y_ooZ03o00;ooo]Z00Goo`3ioookJ_l0Mooooo]Zoom/
0002oookJP04oc_o0?oonf[ooo]Zo`3ko`?ooo]Z00Koo`<0oookJ_mi0?oooo]Zo`2Soonco`03oook
JP09o`3og_oonf[ooo]Zool0K?oonf[oC@3ooookJ_mQ0?oo0?m500?ooo]Z00?o0?n@oookJ_l0oi80
1?oonfX01OmX0?oooo]ZoookJ_lH0?ooi_l000Sooo]Z00?ookh0o`3o1Om`0?l00ooonfX01OooE`3o
oo]ZoookJ_oonf[oo`0]00Wooo]Z00Ko0=Coo`04oooonf[o08SooookJ_l0odh5oookJP03o`3o2?oo
nf[ooo]Z00Cooo]Z00?o403ooi;o0?oonfX01ooonfX00olV0?oooo]ZoookJP06oookJP03o`3Loooo
nf[ooe8000[ooo]Z00?oo`3foookJ_oonfX05ooonfX4o`0000Wooo]Z00?oo`3foookJ_oonfX00ooo
nfX00ol0g?oooo]ZoookJP05oookJP03oa00oooonf[ooo]Z00Cooo]Z00?o00Coo`3DoooonfX01Ooo
nfX00om`0?oooo]ZoookJP02oookJP03onKo0?lH0?oooo]Z00Cooo]Z00?oH@3ooookJ_oonfX00_oo
nfX00onco`3ooo]ZoookJP03oookJP03oom/0?oonf[ooo]Z00;ooo]Z00Goo`3foaP0oooonf[ooo]Z
ool0o00DoookJP07oomB0?oonf[o02[ooookJ_l0g?oooo]Zo`3og`04oookJP03oa80oooonf[oolX0
00?ooo]Z00Goo`0CoookJ_oonf[ooo]Zon7o0002oookJP03obH0oooonf[ooo]Z00[ooo]Z00Go0?mK
oookJ_n2o`3ooo]Zo`0`o`02oookJP03o`H0oooonf[oT_l000;ooo]Z00?o403ooookJ_oonfX00_oo
nfX01Ooo057ooo]Zo`2]oooonf[oo`1i00Cooo]Z00Co0?mCoookJ_oonf[o0?lM0_oonfX00ol0hOoo
oo]ZoookJP05oookJP04o`3o=?oonf[o0?m>o`3o;PCooo]Z00Oo08Soo`2Yoooonf[ooo]Zo`04oooo
nf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP0VoookJP00<ooonfX0
0ol0Looooo]ZoookJP0AoookJP03oomi0?oonf[ooo]Z00Cooo]Z00?ooaH0oookJ_ooTP000_oonfX0
0ooo0?cooo]ZoookJP02oookJP06oaP0oooonf[oo`H0oookJ_o[o`3oo`3f0_oonfX02OnX0?oooo]Z
oookJ_oonf[oo`3io`1goooonf[oof`0o`3oVP02oookJP04oolX0?oonf[ooo]Zo`3ko`;ooo]Z00Ko
o`00oookJ_oonf[oobP0oookJ_nco`03oookJP0:omgo0?l0omkooo]ZoookJ_oo06cooo]ZoolX0?oo
nf[oH@3oo`3oA@?ooo]Z00?o0?n@oookJ_l0oi801?oonfX01Ooo003ooo]ZonGo0?oonf[oi_l000Ko
oo]Z1Ooo:003oookJP04oomG0?oonf[ooo]Zool0;@Wooo]Z00Co0=Coo`04oooonf[o08So0_oonfX0
0ol0odkooo]ZoookJP02oookJP03o`3o2?oonf[ooo]Z00Cooo]Z00?o403ooi;o0?oonfX02?oonfX2
ool000Kooo]Z00?o0=cooookJ_ooDP002_oonfX00ooo0?Kooo]ZoookJP0=oookJP?oobP00_oo0006
oookJPCo00002?oonfX3oolX00Cooo]Z00?o0=cooookJ_oonfX01?oonfX00ol@0?oooo]ZoookJP04
oookJP03oomi0?l0e?ooogT000Kooo]Z00?oL03ooookJ_oonfX00_oonfX00olH0?oooo]ZoookJP03
oookJP03of40oooonf[ooo]Z00;ooo]Z00?o/ol0oookJ_oonfX00ooonfX00oooK03ooo]ZoookJP02
oookJP05ool0m_oonf[o603ooookJ_oo0?`05OoonfX01?ooDP3ooo]Zo`0ZoooonfX3oolX00?ooo]Z
00?o4P3ooookJ_oobP000_oonfX3ool000?ooo]Z00CohOl0oookJ_lV0?oo8?l02_oonfX2oolX0003
o`3oFooo:03oo`0000CoobP000?o1P3ooookJ_nBo`000_oonfX02Om4o`3ooo]ZoookJ_oonf[oo`1A
oookJ_oo:03ooo]Zool0N@04oookJP07o`3oDooonf[ooo]ZoookJ_l0oagooo]Zo`3Qo`08oookJP04
o`3o=?oonf[o0?m>o`3o;P?ooo]Z00Go08SooookJ_l0ZOoooo]Zo`04o`02oookJP03o`3Doooonf[o
oo]Z00Sooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP1EoookJP03o`1coooonf[o
oo]Z017ooo]Z00?oo`3ZoookJ_oonfX01OoonfX00ooo5P3ooi80oookJP02oookJP03ool0o?oonf[o
oo]Z00;ooo]Z00Wo603oool60?oonf[ooo]Zon_o0?oo0?Kooo]Zo`2VoonX0?l00_oonfX01Ooo0?Wo
oo]Zo`1goooonf[oof`000;ooo]Z00Co>ol0oookJ_oonf[o0?_o0ooonfX01_oo0`3ooo]ZogT0oooo
nf[o0:?ook?o00?ooo]Z00Wo0?oNoookJ_oonf[oo`1/oookJ_m=0?oooo]Zof40ool0odD00ooonfX0
0ol0oi3ooo]Zo`3oTP04oookJP05ofP0oooonf[ooo]ZoaP0oooVo`002?oonfX00ooo_P3o0?l5og00
o`03oookJP05oomG0?oonf[ooo]ZoookJ_oo02d02?oonfX01?l0e?oooo]Zo`04ool0R?l2oookJP03
o`3oC_oonf[ooo]Z00?ooo]Z00?o0?l8oookJ_oonfX01?oonfX00ol@0?ooT_l0oookJP07oookJP03
obH0oooonf[ooo]Z00Kooo]Z00?o0=cooookJ_ooDP002_oonfX00ooo0?Kooo]ZoookJP0GoookJPCo
00002OoonfX00ooo0?Kooo]ZoookJP03oookJP03o`3Loooonf[ooo]Z00Gooo]Z00?o403ooookJ_oo
nfX01?oonfX00ol0e?oooo]ZoookJP05oookJP03og00oooonf[ooo]Z00;ooo]Z00?oi_l0oaP0oooo
nfX01?oonfX01OmQ0?oooo]ZoookJ_oonf[o/ol000Kooo]Z00Ooof`0oookJ_oonf[ooo]Zool0m_oo
nf[o603o00;ooo]Z00?oo`3loookJ_oonfX04_oonfX01oooDP3ooo]Zo`0Zoooonf[o0=cooookJ_l0
oml01?oonfX00olB0?oooo]Zooo:0003oookJP05ool04ooonf[ooo]ZoookJ_oQo`000_oonfX00olV
0?oooo]ZoookJP0:oookJP05o`3oFooonf[oP_l0oookJ_l0<?l00_oonfX00ol60?oooo]Zoi;o0002
oookJP03oa00oooonf[ooo]Z00;ooo]Z00Goo`1Ao`2]oooonf[ooo]Zool0N@03oookJP05o`3oDooo
nf[ooo]ZoookJ_l0oad00_oonfX00ol0hOoooo]ZoookJP05oookJP04o`3o=?oonf[o0?m>o`3o;P?o
oo]Z00?o08SooookJ_l0ZOl00_oonfX00ol01?oooo]Zo`3Do`0;oookJP03oon10?oonf[ooo]Z00Wo
oo]Z00?oo`0]oookJ_oonfX09_oonfX003?ooo]Z00?o07?ooookJ_oonfX04OoonfX00oooN@3ooo]Z
oookJP04oookJP03oolF0?oonf[ooi8000;ooo]Z00?oo`3loookJ_oonfX00_oonfX01_lH0?oooo]Z
ool60?oonf[ojol0ool0mP;ooo]Z00WoZ03ooookJ_oonf[ooo]Zool0nOl0Mooooo]Zoom/0?l0oiX0
0_oonfX01_oo:03ooo]ZoookJ_l0nooooo]Zool000?ooo]Z00?oobP0oookJ_nco`000ooonfX02_oM
o`3o0?oNoookJ_oonf[oo`1/oookJ_oo:03ooo]Zof40ool0odD3oookJP03o`3oT?oonf[o0?nB00Co
oo]Z00Goo`00oookJ_oUo`3ooo]ZonKo0006oookJPGoobP00ooonfX01?ooE`3ooo]ZoookJ_oo02d9
oookJP04o`3Dool01?oooo]Zo`28o`;ooo]Z00?o0?m>oookJ_oonfX00_oonfX00ol0o`Sooo]Zoook
JP04oookJP03oa00oooo:03ooo]Z00Oooo]Z0ooo0006oookJP03o`3Loooonf[ooe8000[ooo]Z00?o
o`3foookJ_oonfX03OoonfX2ool00003oolX0?oo003oo`0000Kooo]Z1?l00008oookJP?oobP00ooo
nfX00ol0g?oooo]ZoookJP05oookJP03oa00oooonf[ooo]Z00Cooo]Z00?oogT0o`3DooooN@001Ooo
nfX00om`0?oooo]ZoookJP02oookJP03oaP0oooVo`3ooo]Z00Cooo]Z00?oH@3ooookJ_oonfX00_oo
nfX00onco`3ooo]ZoookJP03oookJP05oom/0?oonf[ooo]ZoookJ_oo0?H00_oonfX00olH0?ooo`3l
oookJP0EoookJP05oomB0?oonf[o02[ooookJ_l0g?l00_oo:003oookJP03oa80oooonf[oolX000?o
oo]Z0_oo0002oookJP04on7o0?oonf[ooo]ZobH0o`_ooo]Z0_oo:0000ol0oe_oo`00oolX0003oolX
0004oookJ_l60?oooo]Zoi;o00;ooo]Z00CoA?l0oookJ_oonf[oo`1A0_oonfX00ooo:03ooo]Zool0
N@04oookJP07o`3oDooonf[ooo]ZoookJ_l0oagooo]Zo`3Qo`08oookJP03o`3o=?oonf[o0?m>00Co
oo]Z00Go08SooookJ_l0ZOoooo]Zo`04o`02oookJP03o`3Doooonf[ooo]Z00Sooo]Z00?ooh40oook
J_oonfX02_oonfX00ooo02gooo]ZoookJP1EoookJP03o`1coooonf[ooo]Z017ooo]Z00?oo`3Zoook
J_oonfX01OoonfX01Ooo5P3ooi80oookJ_oonf[oo`3l00Gooo]Z00Wo603oool60?oonf[ooo]Zon_o
0?oo0?Kooo]Zo`2VoonX0?l00_oonfX01Ooo0?Wooo]Zo`1goooonf[oof`000;ooo]Z00Co>ol0oook
J_oonf[o0?_o0_oonfX01ooo0`3ooo]ZoookJ_mi0?oooo]Zo`2Soonco`000ooonfX02Ol0omkooo]Z
oookJ_oo06cooo]Zodd0oooonf[oH@3oo`3oA@03oookJP03o`3oT?oonf[o0?nB00Cooo]Z00GoJ03o
oookJ_oonf[o603oonKo0008oookJP03oonn0?l0o`GoL03o00?ooo]Z00GooeL0oookJ_oonf[ooo]Z
ool0;@08oookJP04o`3Doooonf[o00Coo`28o`;ooo]Z00?o0?m>oookJ_oonfX00ooonfX00ol0o`So
oo]ZoookJP04oookJP03oa00oonBo`3ooo]Z00Oooo]Z00?o9P3ooookJ_oonfX01_oonfX00ol0g?oo
oo]ZoomB000:oookJP03ool0m_oonf[ooo]Z01Oooo]Z1?l00009oookJP03ool0m_oonf[ooo]Z00;o
oo]Z00?o0=cooookJ_oonfX01_oonfX00ol@0?oooo]ZoookJP04oookJP03o`3Doooonf[ooo]Z00Go
oo]Z00?oL03ooookJ_oonfX00_oonfX00olH0?oooo]ZoookJP04oookJP05of40oooonf[ooo]Zoook
J_nco`001_oonfX02OooK03ooo]ZoookJ_oonf[oo`3foookJ_lH0?oooo]Zool0o00EoookJP07oomB
0?oonf[o02[ooookJ_l0g?oooo]Zo`3og`04oookJP03oa80oooonf[oolX000?ooo]Z00Coo`0Coook
J_oonf[ohOl00_oonfX00olPo`3o9P3ooookJP0;oookJP05o`3oFooonf[oP_l0oookJ_l0<?l00_oo
nfX00ol60?oooo]Zoi;o0002oookJP07oa00oooonf[ooo]ZoookJ_oo057ooo]Zo`2]o`02oookJP05
ool0NOoonf[ooo]ZoookJ_l0oe<00ooonfX01?l0oagooo]ZoookJ_l0hOl7oookJP04o`3o=?oonf[o
0?m>o`3o;P?ooo]Z00?o08SooookJ_l0ZOl00_oonfX00ol01?oooo]Zo`3Do`0;oookJP03oon10?oo
nf[ooo]Z00Wooo]Z00?oo`0]oookJ_oonfX09_oonfX003?ooo]Z00?o07?ooookJ_oonfX04OoonfX0
0oooN@3ooo]ZoookJP04oookJP03oolF0?oonf[ooi8000;ooo]Z00?oo`3loookJ_oonfX00_oonfX0
1_lH0?oooo]Zool60?oonf[ojol0ool0mP;ooo]Z00WoZ03ooookJ_oonf[ooo]Zool0nOl0Mooooo]Z
oom/0?l0oiX00_oonfX01_oo:03ooo]ZoookJ_l0nooooo]Zool000?ooo]Z00?oobP0oookJ_nco`00
0ooonfX02_oMo`3o0?oNoookJ_oonf[oo`1/oookJ_oo:03ooo]Zof40ool0odD3oookJP03o`3oT?oo
nf[o0?nB00Cooo]Z00Goo`00oookJ_oUo`3o07CoonKo0006oookJPGoobP00ooonfX01?ooE`3ooo]Z
oookJ_oo02d9oookJP04o`3Dool01?oooo]Zo`28o`;ooo]Z00?o0?m>oookJ_oonfX00_oonfX00ol0
o`Sooo]ZoookJP04oookJP03oa00oooo:03ooo]Z00Oooo]Z1?oo0005oookJP03o`3Loooonf[ooe80
00[ooo]Z00?oo`3foookJ_oonfX03OoonfX5ool000Kooo]Z1?l00007oookJP?oobP01?oonfX00ol0
g?oooo]ZoookJP05oookJP03oa00oooonf[ooo]Z00Cooo]Z00?oogT0o`3DoooonfX01OoonfX00om`
0?oooo]ZoookJP02oookJP03oaP0oooVo`3ooo]Z00Cooo]Z00?oH@3ooookJ_oonfX00_oonfX00onc
o`3ooo]ZoookJP03oookJP05oom/0?oonf[ooo]ZoookJ_oo0?H00_oonfX00olH0?ooo`3loookJP0E
oookJP05oomB0?l0:_oooo]Zo`3LoooonfX00_oo:003oookJP03oa80oooonf[oobP000?ooo]Z00Go
o`00oookJ_oonf[ooo]Zon7o0002oookJP03obH0oooonf[ooo]Z00[ooo]Z00?oobP0o`3oFooo0000
1?oo:0000ooonf[o1P3ooi;o0003oookJP04odCo0?oonf[ooo]Zool0D@;ooo]Z00?oobP0oookJ_oo
07T01?oonfX01_l0oe?ooo]ZoookJ_oonf[o0?lMo`3Qo`Wooo]Z00?o0?ldoookJ_l0odh01?oonfX0
1Ol0R?oooo]Zo`2Yoooonf[o00Co00;ooo]Z00?o0=CooookJ_oonfX02?oonfX00oooP@3ooo]Zoook
JP0:oookJP03ool0;Ooonf[ooo]Z05Gooo]Z00?o07?ooookJ_oonfX04OoonfX00ooo0>[ooo]Zoook
JP05oookJP05oolF0?ooTP3ooo]ZoookJ_oo0?`01OoonfX02OlH0?ooo`H0oookJ_oonf[ojol0ool0
m_oonf[o0:KoojP0o`02oookJP05ool0nOoonf[o07OooookJ_ooK0000_oonfX01?lko`3ooo]Zoook
J_l0nol2oookJP07ool30?oonf[ooo]ZogT0oooonf[o0:?ook?o0003oookJP09o`3og_oonf[ooo]Z
ool0K?oonf[oC@3ooookJ_mQ0?oo0?m500?ooo]Z00?o0?n@oookJ_l0oi801?oonfX01OmX0?oooo]Z
oaP0ool0M?ooi_l000Sooo]Z00?ookh0o`3o1Om`0?l00ooonfX01OooE`3ooo]ZoookJ_oonf[oo`0]
00Sooo]Z00Co0=Coo`04oooonf[o08So0_oonfX00ol0odkooo]ZoookJP03oookJP03o`3o2?oonf[o
oo]Z00Cooo]Z00?o403ooi;o0?oonfX01ooonfX00olV0?oooo]ZoookJP06oookJP03o`3Loooonf[o
oe8000[ooo]Z00?oo`3foookJ_oonfX05ooonfX4o`0000Sooo]Z00?oo`3foookJ_oonfX00ooonfX0
0ol0g?oooo]ZoookJP05oookJP03oa00oooonf[ooo]Z00Gooo]Z00?o0=CooookJ_oonfX01OoonfX0
0om`0?oooo]ZoookJP02oookJP03oaP0oooonf[ooo]Z00?ooo]Z00?oH@3ooookJ_oonfX00_oonfX0
0onco`3ooo]ZoookJP04oookJP09oom/0?oonf[ooo]ZoookJ_oo0?Kooo]ZoaP0oooonf[oo`3l01Go
oo]Z00Oooe80o`0Zoooonf[ooo]Zo`3Loooonf[o0?oO00?ooo]Z00Co4P3ooookJ_oonf[oolX00ooo
nfX01?oo01?ooo]ZoookJ_oQo`02oookJP03obH0oooonf[ooo]Z00_ooo]Z00Go0?mKoookJ_n2o`3o
oo]Zo`0`o`02oookJP03o`H0oooonf[oT_l000;ooo]Z00Wo403ooookJ_oonf[ooo]Zool0DOoonf[o
0:gooookJ_oo07T01?oonfX01ol0oe?ooo]ZoookJ_oonf[o0?lMoookJ_l0hOl02?oonfX00ol0ocCo
oo]Zo`3oCP04oookJP03o`28oooonf[o0:Wo00;ooo]Z00?o00CooookJ_l0e?l02ooonfX00oooP@3o
oo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z02Kooo]Z000boookJP03o`1coooonf[ooo]Z01;ooo]Z
00?oogT0oookJ_oonfX01?oonfX00ooo5P3ooo]ZoonB0002oookJP03ool0o?oonf[ooo]Z00;ooo]Z
00Ko603ooookJ_oo1P3ooo]Zon_o0?oo0?H2oookJP09ojP0oooonf[ooo]ZoookJ_oo0?Wo07Oooook
J_ooK03o0?nJ00;ooo]Z00KoobP0oookJ_oonf[o0?_ooookJ_oo0003oookJP03oolX0?nO0?oo/ol0
00?ooo]Z00[ogOl0o`3og_oonf[ooo]Zool0K?oonf[oobP0oookJ_mQ0?oo0?m50_oonfX01?l0oi3o
oo]ZoookJ_l0oi84oookJP05ool00?oonf[oiOl0o`1doooVo`001OoonfX7oolX0003oookJ_ooE`3o
oo]Z00;ooo]Z00?oo`0]oookJ_oonfX01ooonfX01?oob@3o00CooookJ_l0R?l2oookJP03o`3oC_oo
nf[ooo]Z00;ooo]Z00?o0?l8oookJ_oonfX01?oonfX00ol@0?ooobP0oolX0007oookJPCoo`001Ooo
nfX00ol0g?oooo]ZoomB000:oookJP03ool0m_oonf[ooo]Z00cooo]Z1ooo0005oookJPCo00001ooo
nfX2oolX00Cooo]Z00?o0=cooookJ_oonfX01_oonfX00ol@0?oooo]ZoookJP04oookJP03oomi0?l0
e?oooo]Z00Gooo]Z00?oL03ooookJ_oonfX00_oonfX00olH0?oooo]ZoookJP04oookJP03of40oooo
nf[ooo]Z00;ooo]Z00?o/ol0oookJ_oonfX00ooonfX02OooK03ooo]ZoookJ_oonf[oo`3foookJ_lH
0?oooo]Zool0o00FoookJP06oomB0?l0:_oooo]Zo`3Loooonf[oobP01?oonfX00olB0?oooo]ZoolX
0003oookJP08ool00?oonf[ooo]ZoookJ_oQo`3ooo]ZobH0oolPo`0<oookJP03oolX0?l0oe_oo`00
00CoobP000?ooo]Zo`H0oonBo`000_oonfX01Om4o`3ooo]ZoookJ_oonf[oo`1A00;ooo]Z00?oobP0
ool0NOoonfX01?oonfX01_l0oe?ooo]ZoookJ_oonf[o0?lMo`3Qo`Wooo]Z00?o0?ldoookJ_oUo`00
0ooonfX02?l0R?oooo]ZoookJ_l0ZOoooo]Zo`04oooonf[o0=Co2ooonfX00oooP@3ooo]ZoookJP0:
oookJP03ool0;Ooonf[ooo]Z05Cooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP05
oookJP05oolF0?ooTP3ooo]ZoookJ_oo0?`01OoonfX02OlH0?ooo`H0oookJ_oonf[ojol0ool0m_oo
nf[o0:KoojP0o`02oookJP05ool0nOoonf[o07OooookJ_ooK0000_oonfX01?lko`3ooo]ZoookJ_l0
nol2oookJP07ool30?oonf[ooo]ZogT0oooonf[o0:?ook?o0003oookJP09o`3og_oonf[ooo]Zool0
K?oonf[oC@3ooookJ_mQ0?oo0?m500;ooo]Z00Co0?n@oookJ_oonf[o0?nB1?oonfX01OmX0?oooo]Z
oaP0ool0M?ooi_l000Sooo]Z00?ookh0o`3o1Om`0?l00ooonfX01OooE`3ooo]ZoookJ_oonf[oo`0]
00Sooo]Z00Co0=Coo`04oooonf[o08So0_oonfX00ol0odkooo]ZoookJP03oookJP03o`3o2?oonf[o
oo]Z00Cooo]Z00?o403ooi;o0?oonfX01ooonfX00olV0?oooo]ZoookJP06oookJP03o`3Loooonf[o
oe8000[ooo]Z00?oo`3foookJ_oonfX05ooonfX4o`0000Sooo]Z00?oo`3foookJ_oonfX00ooonfX0
0ol0g?oooo]ZoookJP05oookJP03oa00oooonf[ooo]Z00Cooo]Z00?o00Coo`3DoooonfX01_oonfX0
1_m`0?oooo]ZoookJ_oonf[oi_l0oaP0o`Gooo]Z00?oH@3ooookJ_oonfX00_oonfX00onco`3ooo]Z
oookJP03oookJP03oom/0?oonf[ooo]Z00;ooo]Z00Goo`3foaP0oooonf[ooo]Zool0o00EoookJP07
oomB0?l0:_oooo]ZoookJ_l0g?oooo]Zo`3og`03oookJP04oa80oooonf[ooo]Zooo:00?ooo]Z00Co
o`0CoookJ_oonf[ohOl00_oonfX00olV0?oooo]ZoookJP0;oookJP05o`3oFooonf[oP_l0oookJ_l0
<?l00_oonfX01Ol60?oooo]Zoi;o0?oonf[o403o00Cooo]Z00Goo`1AoookJ_l0[Ooooo]Zool0N@04
oookJP07o`3oDooonf[ooo]ZoookJ_l0oagooo]Zo`3Qo`08oookJP03o`3o=?oonf[o0?m>00Cooo]Z
00?o08SooookJ_l0ZOl00_oonfX00ol01?oo0=CooookJP0;oookJP03oon10?oonf[ooo]Z00Wooo]Z
00?oo`0]oookJ_oonfX09_oonfX003;ooo]Z00?o07?ooookJ_oonfX04_oonfX00oooN@3ooo]Zoook
JP04oookJP03oolF0?oonf[ooi8000;ooo]Z00?oo`3loookJ_oonfX00_oonfX01_lH0?oooo]Zool6
0?oonf[ojol0ool0mP;ooo]Z00WoZ03ooookJ_oonf[ooo]Zool0nOl0Mooooo]Zoom/0?l0oiX00_oo
nfX01_oo:03ooo]ZoookJ_l0nooooo]Zool000?ooo]Z00?oobP0o`2Soonco`000ooonfX01_oMo`3o
0?oNoookJ_oonf[oo`1/oolX00;ooo]Z00OoH@3oo`3oAOoonf[ooo]Zo`3oT?oonf[o0?nB00Gooo]Z
00Coo`00oookJ_oUo`3oi_l01_oonfX7oolX0003oookJ_ooE`3ooo]Z00;ooo]Z00?oo`0]oookJ_oo
nfX01ooonfX01?oob@3o00CooookJ_l0R?l2oookJP03o`3oC_oonf[ooo]Z00;ooo]Z00?o0?l8oook
J_oonfX01?oonfX00ol@0?ooobP0oolX0007oookJPCoo`001_oonfX00ol0g?oooe80oookJP0:oook
JP03ool0m_oonf[ooo]Z00_ooo]Z1ooo0005oookJPCo00001ooonfX00ooo:03ooo]ZoookJP03oook
JP03o`3Loooonf[ooo]Z00Gooo]Z00?o403ooookJ_oonfX01OoonfX00oooN@3o0=CooookJP05oook
JP03og00oooonf[ooo]Z00;ooo]Z00?o603ooookJ_oonfX00ooonfX00omQ0?oooo]ZoookJP03oook
JP03ok?o0?oonf[ooo]Z00?ooo]Z00Woof`0oookJ_oonf[ooo]Zool0m_oonf[o603ooookJ_oo0?`0
5_oonfX01_ooDP3o02[ooookJ_l0g?oooo]Zo`3og`Cooo]Z00?o4P3ooookJ_oo:0000ooonfX02?oo
01?ooo]ZoookJ_oonf[ohOl0oookJ_lV0?oo8?l03?oonfX00ol0oe_oobP0ool00003oolX0004oook
J_l60?oooo]Zoi;o00;ooo]Z00GoA?l0oookJ_oonf[ooo]Zool0D@02oookJP03oolX0?oo07Wooo]Z
00Cooo]Z00Ko0?mCoookJ_oonf[o0?l8o`3o7Ol0hOl9oookJP03o`3o=?oonf[oiOl000?ooo]Z00So
08SooookJ_oonf[o0:WooookJ_l01?oooo]Zo`3Do`_ooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo
02gooo]ZoookJP1DoookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01OoonfX01Ooo
5P3ooi80oookJ_oonf[oo`3l00Gooo]Z00Wo603oool60?oonf[ooo]Zon_o0?oo0?Kooo]Zo`2VoonX
0?l00_oonfX01Ooo0?Wooo]Zo`1goooonf[oof`000;ooo]Z00Co>ol0oookJ_oonf[o0?_o0_oonfX0
1ooo0`3ooo]ZoookJ_mi0?oooo]Zo`2Soonco`000ooonfX01Ol0omkooo]ZoookJ_oo06coC@3o00;o
oo]Z00OoH@3oo`3oAOoonf[ooo]Zo`3oT?oonf[o0?nB00Gooo]Z00GoJ03ooookJ_lH0?oo07CoonKo
0008oookJP03oonn0?l0o`GoL03o00?ooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@08oookJP04o`3D
ool01?oooo]Zo`28o`;ooo]Z00?o0?m>oookJ_oonfX00ooonfX00ol0o`Sooo]ZoookJP04oookJP03
oa00oonBo`3ooo]Z00Oooo]Z00?o9P3ooookJ_oonfX01_oonfX00ol0g?oooo]ZoomB000:oookJP03
ool0m_oonf[ooo]Z01Oooo]Z1?l00007oookJP03ool0m_oonf[ooo]Z00?ooo]Z00?o0=cooookJ_oo
nfX01_oonfX00ol@0?oooo]ZoookJP04oookJP03o`04ool0e?oooo]Z00Kooo]Z00KoL03ooookJ_oo
nf[ooo]ZonKo0?lH0?l5oookJP03of40oooonf[ooo]Z00;ooo]Z00?o/ol0oookJ_oonfX00ooonfX0
0oooK03ooo]ZoookJP02oookJP05ool0m_lH0?oooo]ZoookJ_oo0?`05OoonfX01oooDP3o02[ooook
J_oonf[o0=cooookJ_l0oml00ooonfX01?lB0?oooo]ZoookJ_oobP03oookJP04ool04ooonf[ooo]Z
on7o00;ooo]Z00?o9P3ooookJ_oonfX02_oonfX01Ol0oe_ooo]ZoookJ_n2o`3o033o00;ooo]Z00?o
1P3ooookJ_nBo`000_oonfX00ol@0?oooo]ZoookJP02oookJP05ool0DOoonf[o0:gooookJ_oo07T0
1?oonfX01ol0oe?ooo]ZoookJ_l0o`So0?lMoookJ_l0hOl02?oonfX00ol0ocCooo]Zo`3oCP04oook
JP03o`28oooonf[o0:Wo00;ooo]Z00?o00Coo`3DoooonfX02_oonfX00oooP@3ooo]ZoookJP0:oook
JP03ool0;Ooonf[ooo]Z02Kooo]Z000boookJP03o`1coooonf[ooo]Z01;ooo]Z00?oogT0oookJ_oo
nfX01?oonfX00ooo5P3ooo]ZoonB0002oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Ko603ooookJ_oo
1P3ooo]Zon_o0?oo0?H2oookJP0;ojP0oooonf[ooo]ZoookJ_oo0?Wo07OooookJ_ooK03o0?nJoook
J_oo:0000ooonfX00ol0nooooo]ZoookJP02oookJP04oolX0?oonf[o0:?ook?o00?ooo]Z00KogOl0
o`3og_oonf[ooo]Zool0K?oo:002oookJP07of40ool0odGooo]ZoookJ_l0oi3ooo]Zo`3oTP05oook
JP04ool00?oonf[oiOl0onKo00Kooo]Z1ooo:0000ooonf[ooeL0oookJP02oookJP03ool0;Ooonf[o
oo]Z00Oooo]Z0_oob@001Ooonf[oobP0oookJ_oonf[o0?m>00Cooo]Z00?o0?l8oookJ_oonfX01?oo
nfX00ol@0?ooobP0oolX0007oookJPGoo`001OoonfX00ol0g?oooe80oookJP0:oookJP03ool0m_oo
nf[ooo]Z00_ooo]Z1ooo0005oookJPCo00001ooonfX00ooo0?Kooo]ZoookJP02oookJP03o`3Loooo
nf[ooo]Z00Kooo]Z00Co403ooookJ_oo003oo`001?oonfX00ol0e?oooo]ZoookJP05oookJP03og00
oooonf[ooo]Z00;ooo]Z00?o603ooookJ_oonfX00ooonfX00omQ0?oooo]ZoookJP03oookJP03ok?o
0?oonf[ooo]Z00;ooo]Z00?oof`0oookJ_oonfX00_oonfX01Ooo0?Kooo]ZoaP0oooonf[oobP001Go
oo]Z00Oooe80o`3o<ol0:_oooo]Zo`3Loooonf[o0?oO00Cooo]Z00?o4P3ooolX0?oonfX00ooonfX0
2?oo01?ooo]ZoookJ_oonf[ohOl0oookJ_lV0?oo8?l03?oonfX00ol0oe_oobP0ool00003oolX0004
oookJ_l60?oooo]Zoi;o00;ooo]Z00WoA?l0oookJ_oonf[ooo]Zool0DOoonf[oobP0oookJ_oo07T0
1OoonfX01_l0oe?ooo]ZoookJ_l0o`So0?lMo`3Qo`Sooo]Z00Co0?ldoookJ_oonf[oiOl00ooonfX0
2?l0R?oooo]ZoookJ_l0ZOoooo]Zo`04oooonf[o0=Co2ooonfX00oooP@3ooo]ZoookJP0:oookJP03
ool0;Ooonf[ooo]Z05Cooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP05oookJP05
oolF0?ooTP3ooo]ZoookJ_oo0?`01OoonfX02OlH0?ooo`H0oookJ_oonf[ojol0ool0m_oonf[o0:Ko
ojP0o`02oookJP05ool0nOoonf[o07OooookJ_ooK0000_oonfX01?lko`3ooo]ZoookJ_l0nol4oook
JP05ogT0oooonf[ooo]Zo`2Soonco`000ooonfX01Ol0omkooo]ZoookJ_oo06coC@3o00;ooo]Z00Oo
H@3oo`3oAOoonf[ooo]Zo`3oT?oonf[o0?nB00Gooo]Z00GoJ03ooookJ_lH0?oo07CoonKo0008oook
JP03oonn0?l0o`GoL03o00?ooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@08oookJP04o`3Dool01?oo
oo]Zo`28o`;ooo]Z00?o0?m>oookJ_oonfX00ooonfX00ol0o`Sooo]ZoookJP04oookJP03oa00oonB
o`3ooo]Z00Sooo]Z00?o9P3ooookJ_oonfX01OoonfX00ol0g?oooo]ZoomB000:oookJP03ool0m_oo
nf[ooo]Z01Oooo]Z1?l00007oookJP03ool0m_oonf[ooo]Z00?ooo]Z00?o0=cooookJ_oonfX01Ooo
nfX00ol@0?oooo]ZoookJP05oookJP03o`3Doooonf[ooo]Z00Gooo]Z00?oL03ooookJ_oonfX00_oo
nfX00olH0?oooo]ZoookJP04oookJP03of40oooonf[ooo]Z00;ooo]Z00?o/ol0oookJ_oonfX00ooo
nfX01oooK03ooo]ZoookJ_oonf[oo`3foookJ_lH0?l00_oonfX00ooo0?cooo]ZoookJP0BoookJP03
oomB0?l0oc?o02[o00;ooo]Z00?o0=cooookJ_l0oml00ooonfX00olB0?oooo]Zooo:0004oookJP04
ool04ooonf[ooo]Zon7o00;ooo]Z00?o9P3ooookJ_oonfX02_oonfX01Ol0oe_ooo]ZoookJ_n2o`3o
033o00;ooo]Z00?o1P3ooookJ_nBo`000_oonfX00ol@0?oooo]ZoookJP02oookJP05ool0DOoonf[o
0:gooookJ_oo07T01?oonfX01ol0oe?ooo]ZoookJ_l0o`So0?lMoookJ_l0hOl01ooonfX01?l0ocCo
oo]ZoookJ_l0odh4oookJP03o`28oooonf[o0:Wo00;ooo]Z00?o00Coo`3DoooonfX02_oonfX00ooo
P@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z02Kooo]Z000boookJP03o`1coooonf[ooo]Z01;o
oo]Z00?oogT0oookJ_oonfX01?oonfX00ooo5P3ooo]ZoonB0002oookJP03ool0o?oonf[ooo]Z00;o
oo]Z00Ko603ooookJ_oo1P3ooo]Zon_o0?oo0?H2oookJP08ojP0oooonf[ooo]ZoookJ_oo0?Wo07Oo
oookJ_ooK002oookJP05oolX0?oonf[ooo]ZoookJ_l0nol01?oonfX01?oo:03ooo]Zo`2Soonco`03
oookJP06omgo0?l0omkooo]ZoookJ_oo06coobP00_oonfX01omQ0?oo0?m5oookJ_oonf[o0?n@oook
J_l0oi801?oonfX01Ooo003ooo]ZoookJ_lH0?ooi_l000Kooo]Z1ooo:0000ooonf[ooeL0oookJP02
oookJP03ool0;Ooonf[ooo]Z00Oooo]Z0_oob@001Ooonf[oobP0oookJ_oonf[o0?m>00Cooo]Z00?o
0?l8oookJ_oonfX01?oonfX4oolX00Gooo]Z1_oo0005oookJP03o`3LooooDP3ooo]Z00[ooo]Z00?o
o`3foookJ_oonfX02_oonfX8ool000Gooo]Z1?l00006oookJP03ool0m_oonf[ooo]Z00?ooo]Z00?o
0=cooookJ_oonfX01_oonfX00ol@0?oooo]Zool00003ool000;ooo]Z00?o0=CooookJ_oonfX01?oo
nfX00om`0?oooo]ZoookJP02oookJP03oaP0oooVo`3ooo]Z00Cooo]Z00?oH@3ooookJ_oonfX00_oo
nfX00onco`3ooo]ZoookJP03oookJP05oom/0?oonf[ooo]ZoookJ_oo0?H00_oonfX00olH0?oooo]Z
oolX000EoookJP06oomB0?l0oc?o02[ooookJ_l0g?oo0?oO1?oonfX00olB0?oooo]ZoolX0003oook
JP03ool04ooonf[ooo]Z00;ooo]Z00CohOl0oookJ_lV0?oo8?l02_oonfX2ool00003o`3oFooo003o
o`0000?oobP000Cooo]Zo`H0oooonf[oT_l00_oonfX02Om4o`3ooo]ZoookJ_oonf[oo`1AoookJ_oo
:03ooo]Zool0N@05oookJP06o`3oDooonf[ooo]Zo`3o7Ooonf[o0>7o2?oonfX00ol0ocCooo]ZonGo
0004oookJP08o`28oooonf[ooo]Zo`2Yoooonf[o00CooookJ_l0e?l;oookJP03oon10?oonf[ooo]Z
00[ooo]Z00?oo`0]oookJ_oonfX0E?oonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z
00Gooo]Z00GooaH0oonB0?oonf[ooo]Zool0o005oookJP09oaP0oooo1P3ooo]ZoookJ_o[o`3oo`3f
oookJ_l0Y_ooZ03o00;ooo]Z00Ooo`3io`1goooonf[o0?nJoom/0?oonf[o>ol000?ooo]Z00?o0?_o
oookJ_oonfX00_oonfX01Omi0?oooo]Zo`0Gool0Xooo/ol000?ooo]Z00Go0?oNoookJ_oonf[oo`1/
odd0o`02oookJP07of40ool0odGooo]ZoookJ_l0oi3ooo]Zo`3oTP04oookJP06ofP0oooonf[ooo]Z
oaP0ool0M?ooi_l02?oonfX00ooo_P3o0?l5og00o`03oookJP05oomG0?oonf[ooo]ZoookJ_oo02d0
2?oonfX01?l0e?oo00CooookJ_l0R?l2oookJP03o`3o=?l0odkooo]Z00?ooo]Z00?o0?l8oookJ_oo
nfX01?oonfX00ol@0?ooT_l0oookJP08oookJP03obH0oooonf[ooo]Z00Gooo]Z00?o0=cooookJ_oo
DP002ooonfX00ooo0?Kooo]ZoookJP0FoookJPCo00001_oonfX00ooo0?Kooo]ZoookJP04oookJP03
o`3Loooonf[ooo]Z00Gooo]Z00?o403ooookJ_oonfX01OoonfX00ol0e?oooo]ZoookJP05oookJP03
og00oooonf[ooo]Z00;ooo]Z00?o603ooookJ_oonfX01?oonfX01OmQ0?oooo]ZoookJ_oonf[o/ol0
00Kooo]Z00Ooof`0oookJ_oonf[ooo]Zool0m_oonf[o603o00;ooo]Z00?oo`3loookJ_oonfX04_oo
nfX00oooDP3o0?lco`0Zo`02oookJP03o`3Lool0omoooo]Z00?ooo]Z00?o4P3ooookJ_oobP000ooo
nfX01Ooo01?ooo]ZoookJ_oonf[ohOl000;ooo]Z00?o9P3ooookJ_oonfX02_oonfX01Ol0oe_ooo]Z
oookJ_n2o`3o033o00;ooo]Z00?o1P3ooookJ_nBo`000_oonfX00ol@0?oooo]ZoookJP02oookJP05
ool0DOoonf[o0:gooookJ_oo07T01?oonfX01?l0oe?ooo]ZoookJ_l0oad2oookJP03o`3Qoooonf[o
oo]Z00Gooo]Z00Co0?ldoookJ_oonf[o0?m>1?oonfX00ol0R?oooo]Zo`2Yo`02oookJP03o`04ool0
e?oooo]Z00[ooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP0VoookJP00<_oonfX0
0ol0Looooo]ZoookJP0AoookJP03oomi0?oonf[ooo]Z00Gooo]Z00?ooaH0oookJ_ooTP000_oonfX0
0ooo0?cooo]ZoookJP02oookJP06oaP0oooo1P3ooo]ZoookJ_o[o`3oo`3f0_oonfX01OnX0?oooo]Z
oookJ_oonf[o07Oo00;ooo]Z00Coof`0oookJ_oonf[oobP00ooonfX00ol0nooooo]ZoookJP02oook
JP04oolX0?oonf[o0:?ook?o00Cooo]Z00Wo0?oNoookJ_oonf[oo`1/oolX0?oonf[oH@3ooookJ_l0
odD00_oonfX00ol0oi3ooo]Zo`3oTP04oookJP05ool00?oonf[ooo]ZoaP0oooVo`001OoonfX9oolX
0005oomG0?oonf[ooo]ZoookJ_oo02d02OoonfX2ooo90005oookJ_oo:03oobP0oookJ_l0odh01?oo
nfX00ol0o`Sooo]ZoookJP04oookJPCoobP01OoonfX6ool000Gooo]Z00?o0=cooookJ_ooDP002ooo
nfX00ooo0?Kooo]ZoookJP09oookJPWoo`001?oonfX5o`0000Cooo]Z00?oo`3foookJ_oonfX00ooo
nfX00ol0g?oooo]ZoookJP06oookJP03oa00oooonf[ooo]Z00Goo`0000?o00Coo`3DoooonfX01Ooo
nfX00om`0?oooo]ZoookJP02oookJP03oaP0oooVo`3ooo]Z00Cooo]Z00?oH@3ooookJ_oonfX00_oo
nfX00onco`3ooo]ZoookJP03oookJP05oolX0?oonf[ooo]ZoookJ_oo0?H00_oonfX00olH0?oooo]Z
oolX000EoookJP06oomB0?l0:_oooo]ZoookJ_l0g?oo0?oO1?oonfX00olB0?ooo`00oolX0003oook
JP05ool04ooonf[ooo]ZoookJ_oQo`000_oonfX00olV0?oooo]ZoookJP09oookJP;oo`0000?o0?mK
ool00?oo00001?oo00000ol60?oooo]Zoi;o0002oookJP09odCo0?oonf[ooo]ZoookJ_oo057ooo]Z
oolX0?oonf[oo`1i00Gooo]Z00Go0?mCoookJ_oonf[o0?lMo`3Qo`09oookJP03o`3o=?oonf[oiOl0
00Cooo]Z00Go08SooookJ_oonf[o0:Woo`04o`02oookJP03o`3Doooonf[ooo]Z00Sooo]Z00?ooh40
oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP1EoookJP03o`1coooonf[ooo]Z017ooo]Z00?oo`3Z
oookJ_oonfX01_oonfX01Ooo5P3ooi80oookJ_oonf[oo`3l00Gooo]Z00Woo`H0oookJ_oonf[ooo]Z
on_o0?oo0?Kooo]Zo`2VoonX0?l00_oonfX01ooo0?Wo07OooookJ_l0oi[oof`0oookJ_lko`000ooo
nfX00ol0nooooo]ZoookJP02oookJP05ogT0oooonf[o01Ooo`2Soonco`000ooonfX01Ol0omkooo]Z
oookJ_oo06coC@3o00;ooo]Z00OoH@3oo`3oAOoonf[ooo]Zo`3oT?oonf[o0?nB00Cooo]Z00KoJ03o
oookJ_oonf[o603oo`1doooVo`08oookJP03oonn0?l0o`GoL03o00?ooo]Z00GooeL0oookJ_oonf[o
oo]Zool0;@09oookJP03o`3Doooonf[o08So00;ooo]Z00?o0?ldo`3oC_oonfX00ooonfX00ol0o`So
oo]ZoookJP05oookJP03oi;o0?oonf[ooo]Z00Oooo]Z00?o9P3ooookJ_oonfX01_oonfX00ol0g?oo
oo]ZoomB000:oookJP03ool0m_oonf[ooo]Z01Kooo]Z1Ol00004oookJP03ool0m_oonf[ooo]Z00Co
oo]Z00?o0=cooookJ_oonfX01OoonfX00ol@0?oooo]ZoookJP05oookJP03o`04ool0e?oooo]Z00Ko
oo]Z00?oL03ooookJ_oonfX00_oonfX00olH0?oooo]ZoookJP03oookJP03of40oooonf[ooo]Z00;o
oo]Z00?o/ol0oookJ_oonfX01?oonfX01oooK03ooo]ZoookJ_oonf[oo`3foookJ_lH0?l00_oonfX0
0ooo0?cooo]ZoookJP0BoookJP03oomB0?l0:_oooo]Z00;ooo]Z00?o0=coo`3ogooonfX00ooonfX0
0ol0oa_ooo]Zooo:0003oookJP04ool04ooonf[ooo]Zon7o00;ooo]Z00?o9P3ooookJ_oonfX02ooo
nfX01Ol0oe_ooo]Zoh;o0?l0ok3o033o00;ooo]Z00?o1P3ooookJ_nBo`000_oonfX00ol@0?oooo]Z
oookJP02oookJP04ool0DOl0[Ooooo]Zool0N@Gooo]Z00Ko0?mCoookJ_oonf[o0?lMoookJ_l0hOl8
oookJP03o`3o=?oonf[o0?m>00Cooo]Z00So08SooookJ_oonf[o0:WooookJ_l01?oooo]Zo`3Do`_o
oo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP0VoookJP00<_oonfX00ol0Looooo]Z
oookJP0AoookJP03oomi0?oonf[ooo]Z00Gooo]Z00?ooaH0oookJ_ooTP000_oonfX00ooo0?cooo]Z
oookJP02oookJP06oaP0oooo1P3ooo]ZoookJ_o[o`3oo`3f0_oonfX01OnX0?oooo]ZoookJ_oonf[o
07Oo00;ooo]Z00Coof`0oookJ_oonf[oobP00ooonfX00ol0nooooo]ZoookJP02oookJP04oolX0?oo
nf[o0:?ook?o00Cooo]Z00Wo0?oNoookJ_oonf[oo`1/oolX0?oonf[oH@3ooookJ_l0odD00_oonfX0
0ol0oi3ooo]Zo`3oTP04oookJP05ool00?oonf[ooo]ZoaP0oooVo`001OoonfX9oolX0005oomG0?oo
nf[ooo]ZoookJ_oo02d02?oonfX4ooo900;oobP000?ooo]Zo`3oC_l0oc@00ooonfX00ol0o`Sooo]Z
oookJP04oookJPGoobP01?oonfX7ool000Cooo]Z00?o0=cooookJ_ooDP002ooonfX00ooo0?Kooo]Z
oookJP0>oookJPCoo`001?oonfX4o`0000Cooo]Z00?oo`3foookJ_oonfX01?oonfX00ol0g?oooo]Z
oookJP06oookJP03oa00oooonf[ooo]Z00Ooo`001_oonfX00om`0?oooo]ZoookJP02oookJP05oaP0
oooonf[ooo]ZoookJ_oo00000_oonfX00omQ0?oooo]ZoookJP02oookJP03ok?o0?oonf[ooo]Z00?o
oo]Z00WoobP0oookJ_oonf[ooo]Zool0m_oonf[o603ooookJ_oo:0005_oonfX01_ooDP3o02[ooook
J_oonf[o0=coo`3og`Cooo]Z00?o4P3oool00?oo:0000ooonfX01Ooo01?ooo]ZoookJ_oonf[ohOl0
00;ooo]Z00?o9P3ooookJ_oonfX02OoonfX2ool00003o`3oFooo003oo`0000Coo`0000Go1P3ooi;o
0?oonf[ooo]ZodCo0004oookJP04ool0DOoonf[oobP0ool0N@Kooo]Z00Go0?mCoookJ_oonf[o0?lM
o`3Qo`09oookJP03o`3o=?oonf[oiOl000Cooo]Z00Go08SooookJ_l0ZOoooo]Zo`04o`02oookJP03
o`3Doooonf[ooo]Z00Sooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP1EoookJP03
o`1coooonf[ooo]Z017ooo]Z00?oo`3ZoookJ_oonfX01_oonfX01Ooo5P3ooi80oookJ_oonf[oo`3l
00Gooo]Z00Woo`H0oookJ_oonf[ooo]Zon_o0?oo0?Kooo]Zo`2VoonX0?l00_oonfX01ooo0?Wo07Oo
oookJ_l0oi[oof`0oookJ_lko`000ooonfX00ol0nooooo]ZoookJP02oookJP05ogT0oooonf[o01Oo
o`2Soonco`000ooonfX01Ol0omkooo]ZoookJ_oo06coC@3o00;ooo]Z00OoH@3oo`3oAOoonf[ooo]Z
o`3oT?oonf[o0?nB00Cooo]Z00KoJ03ooookJ_oonf[o603oo`1doooVo`08oookJP03oonn0?l0o`Go
L03o00?ooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@09oookJP03o`3Doooonf[o08So00?ooo]Z00?o
0?m>oookJ_oonfX00_oonfX00ol0o`Sooo]ZoookJP05oookJP03oi;o0?oonf[ooo]Z00Oooo]Z00?o
9P3ooookJ_oonfX01_oonfX00ol0g?oooo]ZoomB000:oookJP03ool0m_oonf[ooo]Z01Kooo]Z1?l0
0004oookJP03ool0m_oonf[ooo]Z00Cooo]Z00?o0=cooookJ_oonfX01_oonfX00ol@0?oooo]Zoook
JP05oookJP03o`04ool0e?oooo]Z00Gooo]Z00?oL03ooookJ_oonfX00_oonfX01OlH0?oooo]Zoook
J_oonf[o0?nB00;ooo]Z00?oH@3ooookJ_oonfX00_oonfX00onco`3ooo]ZoookJP04oookJP06oom/
0?oonf[ooo]ZoookJ_oo0?Ko603o0_oonfX00ooo0?cooo]ZoookJP0CoookJP07oomB0?l0:_oooo]Z
oookJ_l0g?oooo]Zo`3og`03oookJP04oa80ool0oa_ooo]Zooo:00?ooo]Z00Coo`0CoookJ_oonf[o
hOl00_oonfX00olV0?oooo]ZoookJP0;oookJP05o`3oFooonf[oP_l0oookJ_l0<?l00_oonfX01Ol6
0?oooo]Zoi;o0?oonf[o403o00Gooo]Z00Coo`1Ao`2]oooonf[oo`1i1OoonfX01_l0oe?ooo]Zoook
J_l0oagooo]Zo`3Qo`Sooo]Z00?o0?ldoookJ_l0odh01?oonfX00ol0R?oooo]Zo`2Yo`02oookJP03
o`04oooonf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP0VoookJP00
<_oonfX00ol0Looooo]ZoookJP0AoookJP03oomi0?oonf[ooo]Z00Gooo]Z00?ooaH0oookJ_ooTP00
0_oonfX00ooo0?cooo]ZoookJP02oookJP06oaP0oooo1P3ooo]ZoookJ_o[o`3oo`3f0_oonfX01OnX
0?oooo]ZoookJ_oonf[o07Oo00;ooo]Z00Coof`0oookJ_oonf[oobP00ooonfX00ol0nooooo]Zoook
JP02oookJP04oolX0?oonf[o0:?ook?o00Cooo]Z00Wo0?oNoookJ_oonf[oo`1/odd0oooonf[oH@3o
oookJ_l0odD00_oonfX00ol0oi3ooo]Zo`3oTP04oookJP06ool00?oonf[ooo]ZoaP0oooVo`3oolT0
2?oonfX00ooo:03o0?l5og00o`02oookJP05oomG0?oonf[ooo]ZoookJ_oo02d02?oonfX4ooo900;o
obP000?ooo]Zo`3oC_l0oc@00ooonfX00ol0o`Sooo]ZoookJP04oookJPGoobP01?oonfX7ool000Go
oo]Z00?o0=cooomB0?oonfX02_oonfX00ooo0?Kooo]ZoookJP0FoookJPCo00000ooonfX00ooo0?Ko
oo]ZoookJP04oookJP03o`3Loooonf[ooo]Z00Kooo]Z00?o403ooookJ_oonfX02Ooo0004oookJP03
og00oooonf[ooo]Z00?ooo]Z00Go603oool00?oonf[ooo]Zool00002oookJP03of40oooonf[ooo]Z
00;ooo]Z00?o/ol0oookJ_oonfX00ooonfX02Ooo:03ooo]ZoookJ_oonf[oo`3foookJ_lH0?oooo]Z
oolX000EoookJP07oomB0?l0oc?o02[ooookJ_l0g?oooo]Zo`3og`04oookJP03oa80oooo003oobP0
00?ooo]Z00Soo`0CoookJ_oonf[ooo]Zon7o0?oonf[o9P3oob3o00_ooo]Z00?oo`00o`3oFooo0000
1Ooo00000ooonf[o1P3ooi;o0002oookJP03odCo0?oonf[ooo]Z00;ooo]Z00Coo`1AoookJ_oo:03o
o`1i1_oonfX01Ol0oe?ooo]ZoookJ_l0oago0>7o00Wooo]Z00?o0?ldoookJ_oUo`001?oonfX01Ol0
R?oooo]Zo`2Yoooonf[o00Co00;ooo]Z00?o0=CooookJ_oonfX02?oonfX00oooP@3ooo]ZoookJP0:
oookJP03ool0;Ooonf[ooo]Z05Gooo]Z00?o07?ooookJ_oonfX04OoonfX00ooo0>[ooo]ZoookJP06
oookJP05oolF0?ooTP3ooo]ZoookJ_oo0?`01OoonfX02Ooo1P3ooo]ZoookJ_oonf[ojol0ool0m_oo
nf[o0:KoojP0o`02oookJP07ool0nOl0Mooooo]Zo`3oV_ooK03ooo]Zoc_o0003oookJP03o`3koooo
nf[ooo]Z00;ooo]Z00GoN@3ooookJ_l05ooo0:?ook?o0003oookJP05o`3og_oonf[ooo]Zool0K?m=
0?l00_oonfX01omQ0?oo0?m5oookJ_oonf[o0?n@oookJ_l0oi801?oonfX01_mX0?oooo]ZoookJ_lH
0?oo07CoonKo00Sooo]Z00?ookh0o`3o1Om`0?l00ooonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00Wo
oo]Z00Co0=CooookJ_oonf[o08So0_oonfX00ol0odkooo]ZoookJP02oookJP03o`3o2?oonf[ooo]Z
00Gooo]Z00?o403ooi;o0?oonfX01ooonfX00olV0?oooo]ZoookJP06oookJP03o`3Loooonf[ooe80
00[ooo]Z00?oo`3foookJ_oonfX05_oonfX4o`0000Cooo]Z00?oo`3foookJ_oonfX01?oonfX00ol0
g?oooo]ZoookJP06oookJP03oa00oooonf[ooo]Z00Gooo]Z00?o0=CooookJ_oonfX01OoonfX00om`
0?oooo]ZoookJP02oookJP05oaP0oooonf[ooo]ZoookJ_l0oi800_oonfX00omQ0?oooo]ZoookJP02
oookJP03ok?o0?oonf[ooo]Z00?ooo]Z00Ooof`0oookJ_oonf[ooo]Zool0m_oonf[o603o00;ooo]Z
00?oo`3loookJ_oonfX04_oonfX00oooDP3o0?lco`0Zo`02oookJP03o`3Loooonf[o0?oO00?ooo]Z
00Co4P3oo`3o6ooonf[oolX00ooonfX01?oo01?ooo]ZoookJ_oQo`02oookJP03obH0oooonf[ooo]Z
00[ooo]Z00Ko0?mKoookJ_oonf[oP_l0oookJ_l0<?l2oookJP05o`H0oooonf[oT_l0oookJ_l@0?l0
1OoonfX01?oo057o0:gooookJ_oo07T5oookJP06o`3oDooonf[ooo]Zo`3o7Ooonf[o0>7o2?oonfX0
0ol0ocCooo]Zo`3oCP04oookJP03o`28oooonf[o0:Wo00;ooo]Z00?o00CooookJ_l0e?l02ooonfX0
0oooP@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z02Oooo]Z000boookJP03o`1coooonf[ooo]Z
017ooo]Z00?oogT0oookJ_oonfX01OoonfX00ooo5P3ooo]ZoonB0002oookJP03ool0o?oonf[ooo]Z
00;ooo]Z00Ko603oool60?oonf[ooo]Zon_o0?oo0?H2oookJP05o`2VoonX0?oooo]Zool0nOl0Mol0
0_oonfX01?ooK03ooo]ZoookJ_oo:003oookJP03o`3koooonf[ooo]Z00;ooo]Z00CoN@3ooookJ_l0
Xooo/ol01?oonfX02Ol0omkooo]Zool0K?oonf[oC@3ooookJ_mQ0?oooo]Zo`3oA@02oookJP03o`3o
T?oonf[o0?nB00Cooo]Z00Koo`00oookJ_oonf[o603oonKo0?oob@08oookJP03oolX0?l0o`GoL03o
00;ooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@08oookJPCoolT00ooo:0000ol0odko0?ldoookJP02
oookJP03o`3o2?oonf[ooo]Z00Cooo]Z1Ooo:004oookJPOoo`001OoonfX00ol0g?oooe80oookJP0;
oookJP03ool0m_oonf[ooo]Z01Gooo]Z1?l00002oookJP03ool0m_oonf[ooo]Z00Gooo]Z00?o0=co
oookJ_oonfX01_oonfX00ol@0?oooo]ZoookJP09ool000Cooo]Z00?oL03ooookJ_oonfX00ooonfX0
0olH0?ooo`00ool00002ool00003oookJ_mQ0?oooo]Z00Cooo]Z00?o/ol0oookJ_oonfX00_oonfX0
0ooo:03ooo]ZoookJP02oookJP05ool0m_oonf[o603ooookJ_oo:0005OoonfX01oooDP3o0?lco`0Z
oooonf[o0=cooookJ_l0oml01?oonfX00ooo003oobP0oookJP03oookJP08ool04ooonf[ooo]Zoook
J_oQo`3ooo]ZobH0oolPo`0;oookJP03ool00?l0oe_oo`0000Goo`0000?ooo]Zo`H0oonBo`000_oo
nfX01Om4o`3ooo]ZoookJ_oonf[oo`1A00;ooo]Z00?oobP0ool0NOoonfX01?oonfX01_l0oe?ooo]Z
oookJ_oonf[o0?lMo`3Qo`Wooo]Z00?o0?ldoookJ_oUo`001?oonfX01ol0R?oooo]Zo`2Yoooonf[o
00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z05Gooo]Z00?o
07?ooookJ_oonfX04OoonfX00ooo0>[ooo]ZoookJP06oookJP05oolF0?ooTP3ooo]ZoookJ_oo0?`0
1OoonfX01Ooo1P3ooo]ZoookJ_oonf[ojol000;ooo]Z00_o0:KoojP0oooonf[oo`3ioookJ_l0Mooo
oo]Zo`3oV_ooK03ooo]Zoc_o0003oookJP03o`3koooonf[ooo]Z00;ooo]Z00CoN@3ooookJ_l05ooo
/ol01?oonfX02Ol0omkooo]Zool0K?oonf[oC@3ooookJ_mQ0?oooo]Zo`3oA@02oookJP03o`3oT?oo
nf[o0?nB00Cooo]Z00KoJ03ooookJ_oonf[o603oo`1doooVo`08oookJP03oonn0?l0o`GoL03o00?o
oo]Z00GooeL0oookJ_oonf[ooo]Zool0;@09oookJP04o`3Doooonf[ooo]Zo`28o`;ooo]Z00?o0?m>
oookJ_oonfX00_oonfX00ol0o`Sooo]ZoookJP05oookJP03oa00oonBo`3ooo]Z00Oooo]Z00?o9P3o
oookJ_oonfX01_oonfX00ol0g?oooo]ZoomB000;oookJP03ool0m_oonf[ooo]Z01Gooo]Z1?l00003
oookJP03ool0m_oonf[ooo]Z00Cooo]Z00?o0=cooookJ_oonfX01_oonfX00ol@0?oooo]ZoookJP04
oookJP03o`3oC_l01?oo0=Co00Oooo]Z00?oL03ooookJ_oonfX00_oonfX01OlH0?oooo]ZoookJ_oo
nf[o0?nB00;ooo]Z00?oH@3ooookJ_oonfX00_oonfX00onco`3ooo]ZoookJP03oookJP07oom/0?oo
nf[ooo]ZoookJ_oo0?Kooo]ZoaP0o`02oookJP03ool0o?oonf[ooo]Z01;ooo]Z00?ooe80o`3o<ol0
:_l00_oonfX00ol0g?oo0?oOoookJP03oookJP03o`3o6ooonf[oolX000Cooo]Z00Coo`0CoookJ_oo
nf[ohOl00_oonfX00olV0?oooo]ZoookJP0:oookJP05o`3oFooonf[ooo]Zoh;o0?l0<?l00ooonfX0
1Ol60?oooo]Zoi;o0?oonf[o403o00Cooo]Z00Goo`1AoookJ_l0[Ooooo]Zool0N@04oookJP07o`3o
Dooonf[ooo]ZoookJ_l0oagooo]Zo`3Qo`08oookJP03o`3o=?oonf[o0?m>00Cooo]Z00?o08Sooook
J_l0ZOl00_oonfX00ol01?oo0=CooookJP0;oookJP03oon10?oonf[ooo]Z00Wooo]Z00?oo`0]oook
J_oonfX09ooonfX003;ooo]Z00?o07?ooookJ_oonfX04OoonfX00oooN@3ooo]ZoookJP05oookJP03
oolF0?oonf[ooi8000;ooo]Z00?oo`3loookJ_oonfX00_oonfX01_lH0?ooo`H0oookJ_oonf[ojol0
ool0mP;ooo]Z00Go0:KoojP0oooonf[oo`3io`1go`02oookJP04oom/0?oonf[ooo]Zoc_o00?ooo]Z
00?o0?_ooookJ_oonfX00_oonfX01Omi0?ooobP0o`2Soonco`3oobP000?ooo]Z00Wo0?oNoookJ_oo
06cooo]Zodd0oooonf[oH@3ooookJ_l0odD00_oonfX00ol0oi3ooo]Zo`3oTP04oookJP06ool00?oo
nf[ooo]Zooo90?lH0?ooolT02?oonfX00ooo:03o0?l5og00o`02oookJP05oomG0?oonf[ooo]Zoook
J_oo02d02?oonfX5ooo900;oobP000?o0?m>o`3o=?oonfX00_oonfX00ooo:03ooo]ZoookJP04oook
JPKoobP00_oonfX9ool000Cooo]Z00?o0=cooomB0?oonfX03?oonfX00ooo0?Kooo]ZoookJP0Doook
JPCo000000?ooo]Zool0m_oonfX01_oonfX00ol0g?oooo]ZoookJP07oookJP03oa00oooonf[ooo]Z
00Soo`001OoonfX00om`0?oooo]ZoookJP02oookJP03oaP0oooo003oo`0000Coo`0000?oH@3ooook
J_oonfX00_oonfX00onco`3ooo]ZoookJP03oookJP03oolX0?oonf[ooo]Z00;ooo]Z00Goo`3foook
J_lH0?oooo]ZoolX000EoookJP06oomB0?l0oc?o02[ooookJ_l0g?oo0?oO1?oonfX00olB0?ooo`00
oolX0003oookJP03ool04ooonf[ooo]Z00;ooo]Z00CohOl0oookJ_lV0?oo8?l03?oonfX00ol0oe_o
o`00ool00003ool000;ooo]Z00Go1P3ooi;o0?oonf[ooo]ZodCo0003oookJP05ool0DOoonf[oobP0
oookJ_oo07T01OoonfX01_l0oe?ooo]ZoookJ_oonf[o0?lMo`3Qo`Sooo]Z00?o0?ldoookJ_oUo`00
1OoonfX01ol0R?oooo]Zo`2Yoooonf[o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP0:oook
JP03ool0;Ooonf[ooo]Z05Gooo]Z00?o07?ooookJ_oonfX04OoonfX00ooo0>[ooo]ZoookJP06oook
JP05oolF0?ooTP3ooo]ZoookJ_oo0?`01OoonfX01Ooo1P3ooo]ZoookJ_oonf[ojol000;ooo]Z00_o
0:KoojP0oooonf[oo`3ioookJ_l0Mooooo]Zo`3oV_ooK03ooo]Zoc_o0003oookJP03o`3koooonf[o
oo]Z00;ooo]Z00CoN@3ooookJ_oonf[o/ol01?oonfX02Ol0omkooo]Zool0K?oonf[oC@3ooookJ_mQ
0?oooo]Zo`3oA@02oookJP03o`3oT?oonf[o0?nB00Cooo]Z00KoJ03ooookJ_oonf[ooo]ZoaP0oooV
o`08oookJP03oonn0?l0o`GoL03o00?ooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@09oookJP04o`3D
ool01?oooo]Zo`28o`;ooo]Z00?o0?m>oookJ_oonfX00_oonfX00ol0o`Sooo]ZoookJP05oookJP03
oa00oonBo`3ooo]Z00Oooo]Z00?o9P3ooookJ_oonfX01_oonfX00ol0g?oooo]ZoomB000<oookJP03
ool0m_oonf[ooo]Z01Cooo]Z1?l00002oookJP03ool0m_oonf[ooo]Z00Cooo]Z00?o0=cooookJ_oo
nfX01ooonfX00ol@0?oooo]ZoookJP04oookJP03o`3oC_l0e?oooo]Z00Kooo]Z00?oL03ooookJ_oo
nfX00_oonfX01OoVo`3o603ooookJ_oonf[o0?nB00;ooo]Z00?oH@3ooookJ_oonfX00_oonfX00onc
o`3ooo]ZoookJP04oookJP09oom/0?oonf[ooo]ZoookJ_oo0?Kooo]ZoaP0oooonf[oo`3l01Gooo]Z
00?ooe80o`3o<ol0:_l00_oonfX00ol0g?oo0?oOoookJP03oookJP03o`3o6ooonf[oolX000?ooo]Z
00Goo`0CoookJ_oonf[ooo]Zon7o0002oookJP03obH0oooonf[ooo]Z00[ooo]Z00Go0?mKoookJ_oo
nf[oP_l0o`0`o`03oookJP05o`H0oooonf[oT_l0oookJ_l@0?l01?oonfX01Ooo057ooo]Zo`2]oooo
nf[oo`1i00Cooo]Z00Oo0?mCoookJ_oonf[ooo]Zo`3o7Ooonf[o0>7o00Oooo]Z00Co0?ldoookJ_oo
nf[o0?m>1?oonfX00ol0R?oooo]Zo`2Yo`02oookJP03o`04ool0e?oooo]Z00[ooo]Z00?ooh40oook
J_oonfX02_oonfX00ooo02gooo]ZoookJP0WoookJP00<OoonfX00ol0Looooo]ZoookJP0BoookJP03
ool0j_oonf[ooo]Z00Gooo]Z00?ooaH0oookJ_ooTP000_oonfX00ooo0?cooo]ZoookJP02oookJP05
oaP0oooo1P3ooo]ZoookJ_o[o`000ooonfX01Ol0Y_ooZ03ooookJ_oo0?Wo07Oo00;ooo]Z00Coof`0
oookJ_oonf[o>ol00ooonfX00ol0nooooo]ZoookJP02oookJP05ogT0oooo:03o0:?ook?o0?oo:000
0ooonfX02Ol0omkooo]Zool0K?oonf[oC@3ooookJ_mQ0?oooo]Zo`3oA@02oookJP03o`3oT?oonf[o
0?nB00Cooo]Z00Goo`00oookJ_oonf[oolT0oaP0o`02ooo900Oooo]Z00?oobP0o`3o1Om`0?l00_oo
nfX01OooE`3ooo]ZoookJ_oonf[oo`0]00Sooo]Z1Ooob@02oolX0003o`3oC_l0ocCooo]Z00;ooo]Z
00?oobP0oookJ_oonfX01?oonfX6oolX00;ooo]Z2Ooo0004oookJP03o`3Loooonf[ooe8000cooo]Z
00?oo`3foookJ_oonfX05?oonfX3o`0000;oo`3f2?oonfX00ol0g?oooo]ZoookJP06oookJP04oa00
oooonf[ooo]ZoookJPOoo`001_oonfX00om`0?oooo]ZoookJP02oookJP03oaP0oooo003oo`0000Co
o`0000?oH@3oool00?oonfX00_oonfX00onco`3ooo]ZoookJP03oookJP05oolX0?oonf[ooo]Zoook
J_oo0?H00_oonfX00olH0?ooobP0oookJP0EoookJP06oomB0?l0:_oooo]ZoookJ_l0g?oo0?oO1?oo
nfX00olB0?ooo`00oolX0002oookJP03ool00?oo01?ooo]Z00?ooo]Z00CohOl0oookJ_lV0?oo8?l0
3?oonfX00ol0oe_oo`00ool00003ool000;ooo]Z00Go1P3ooi;o0?oonf[ooo]ZodCo0003oookJP05
ool0DOoonf[oobP0oookJ_oo07T01OoonfX01Ol0oe?ooo]ZoookJ_l0oago0>7o00Wooo]Z00?o0?ld
oookJ_oUo`001?oonfX02?l0R?oooo]ZoookJ_l0ZOoooo]Zo`04oooonf[o0=Co2ooonfX00oooP@3o
oo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z05Cooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[o
oo]ZoookJP06oookJP03oolF0?ooTP3ooo]Z00;ooo]Z00?oo`3loookJ_oonfX00_oonfX01Ooo1P3o
oo]ZoookJ_oonf[ojol000;ooo]Z00_o0:KoojP0oooonf[oo`3ioookJ_l0Mooooo]Zo`3oV_ooK03o
oo]Zoc_o0003oookJP03o`3koooonf[ooo]Z00;ooo]Z00CoN@3ooookJ_oonf[o/ol01?oonfX02Ol0
omkooo]Zool0K?oonf[oC@3ooookJ_mQ0?oooo]Zo`3oA@02oookJP03o`3oT?oonf[o0?nB00Cooo]Z
00KoJ03ooookJ_oonf[ooo]ZoaP0oooVo`08oookJP03oonn0?l0o`GoL03o00?ooo]Z00GooeL0oook
J_oonf[ooo]Zool0;@09oookJP04o`3Dool01?oooo]Zo`28o`;ooo]Z00?o0?m>oookJ_oonfX00_oo
nfX00ol0o`Sooo]ZoookJP05oookJP03oa00oonBo`3ooo]Z013ooo]Z00Co0=cooookJ_oonf[ooe80
2ooonfX00ooo0?Kooo]ZoookJP0DoookJPCo00000_oo0?H7oookJP03o`3Loooonf[ooo]Z00Oooo]Z
00?o403ooookJ_oonfX00ooonfX00ol0odkooo]Zo`3Do`07oookJP03og00oooonf[ooo]Z00;ooo]Z
00Go603ooookJ_oonf[ooo]Zo`3oTP02oookJP03of40oooonf[ooo]Z00;ooo]Z00?o/ol0oookJ_oo
nfX00ooonfX00oooK03ooo]ZoookJP02oookJP05ool0m_oonf[o603ooookJ_oo0?`05OoonfX00ooo
DP3o02[ooookJP02oookJP03o`3Lool0omoooo]Z00?ooo]Z00?o0?lKoookJ_oobP000_oonfX00ol0
nOooo`0CoookJP02oookJP04on7o0?oonf[o9P3oob3o00cooo]Z00Go0?mKoookJ_oonf[oP_l0o`0`
o`03oookJP05o`H0oonBo`3ooo]ZoookJ_l@0?l01?oonfX01?oo057ooo]Zo`2]oooo07T5oookJP06
o`3oDooonf[ooo]Zo`3o7Ol0o`So0>7o2?oonfX01?l0ocCooo]Zo`3oC_l0obh4oookJP03o`28oooo
nf[o0:Wo00;ooo]Z00?o00Coo`3DoooonfX02_oonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooo
nf[ooo]Z02Oooo]Z000aoookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01OoonfX0
0ooo5P3ooi80oookJP02oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Go603oool60?oonf[ooo]Zon_o
0003oookJP05o`2VoonX0?oooo]Zool0nOl0Mol00_oonfX01?ooK03ooo]ZoookJ_lko`02oookJP03
o`3koooonf[ooo]Z00?ooo]Z00GoN@3ooolX0?l0Xooo/ol0oolX0003oookJP09o`3og_oonf[oo`1/
oookJ_m=0?oooo]Zof40oooonf[o0?m500;ooo]Z00?o0?n@oookJ_l0oi801?oonfX01Ooo003ooo]Z
oookJ_oob@3o603o00;oolT01ooonfX00ooo:03o0?l5og00o`02oookJP05oomG0?oonf[ooo]Zoook
J_oo02d02?oonfX5ooo900;oobP000?o0?m>o`3o=?oonfX00_oonfX2oolX00Cooo]Z2?oo:0000ooo
nf[oo`00ool00002ool000[ooo]Z00?o0=cooomB0?oonfX03?oonfX2oomi01Cooo]Z0_l000000ooo
0?Ko0000oookJP07oookJP03o`3Loooonf[ooo]Z00Oooo]Z00Co403ooookJ_oonf[ooo]Z1_oo0006
oookJP03og00oooonf[ooo]Z00;ooo]Z00?oi_l0oaP0oooo00001Ooo00000omQ0?ooo`00oookJP02
oookJP03ok?o0?oonf[oobP000?oobP01?oonfX01Ooo0?Kooo]ZoookJ_lH0?ooobP001Kooo]Z00Ko
oe80o`0Zoooonf[ooo]Zo`3Lool0oml4oookJP03oa80oooo003oobP000;ooo]Z00?oo`00ool04ooo
nfX00_oonfX01OoQo`3ooo]ZoookJ_lV0?oo8?l000cooo]Z00?o0?mKool00?oo00000ooo0002oook
JP05o`H0oonBo`3ooo]ZoookJ_m4o`000ooonfX01?oo057ooo]ZoolX0?oo07T6oookJP05o`3oDooo
nf[ooo]Zo`3o7Ol0hOl02OoonfX00ol0ocCooo]ZonGo0004oookJP03o`28oooonf[o0:Wo00;ooo]Z
00?o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z05Cooo]Z
00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP06oookJP03oolF0?ooTP3ooo]Z00;ooo]Z
00?oo`3loookJ_oonfX00_oonfX01Ooo1P3ooo]ZoookJ_oonf[ojol000;ooo]Z00_o0:KooookJ_nX
0?ooo`3ioookJ_l0Mooooo]Zo`3oV_ooK03ooo]Zoc_o0002oookJP03o`3koooonf[ooo]Z00?ooo]Z
00GoN@3ooookJ_oonf[o/ol0oil0o`03oookJP09omgo0?l0omkoo`1/oookJ_m=0?oooo]Zof40oooo
nf[o0?m500;ooo]Z00?o0?n@oookJ_l0oi801?oonfX01_mX0?oooo]ZoookJ_oonf[o603oonKo00So
oo]Z00?ookh0oookJ_m`0?l00ooonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00Wooo]Z00Co0=Coo`04
oooonf[o08So0_oonfX00ol0odkooo]ZoookJP02oookJP03o`3o2?oonf[ooo]Z00Gooo]Z00?o403o
oi;o0?oonfX04OoonfX00ol0g?oooo]ZoomB000<oookJP03ool0m_oonf[ooo]Z01?ooo]Z0ol00000
0ooo0?Kooo]ZoookJP06oookJP03o`3Loooonf[ooo]Z00Oooo]Z00?o403ooookJ_oonfX01?oonfX0
0ol0odko0=CooookJP07oookJP03og00oooonf[ooo]Z00;ooo]Z00Go603ooookJ_oonf[ooo]Zo`3o
TP02oookJP03of40oooonf[ooo]Z00;ooo]Z00?o/ol0oookJ_oonfX00ooonfX01OooK03ooo]Zoook
J_oonf[oo`3f00;ooo]Z00?o603ooookJ_oo0?`05OoonfX00oooDP3o02[ooookJP02oookJP03o`3L
ool0omoooo]Z00?ooo]Z00?o0?lKoookJ_oobP000_oonfX01Ol0nOooo`0CoookJ_oonf[ohOl000;o
oo]Z00?o9P3oob3o0?oonfX02ooonfX01Ol0oe_ooo]ZoookJ_n2o`3o033o00?ooo]Z00Go1P3ooi;o
0?oonf[ooo]Zoa00o`04oookJP04ool0DOl0[Ooooo]Zool0N@Gooo]Z00Ko0?mCoookJ_oonf[o0?lM
o`3o2?l0hOl8oookJP03o`3o=?oonf[o0?m>00Gooo]Z00?o08Soo`2YoooonfX00_oonfX00ol01?oo
0=CooookJP0:oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX09ooonfX0037ooo]Z
00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP05oookJP03oolF0?ooTP3ooo]Z00;ooo]Z
00?oo`3loookJ_oonfX00_oonfX01OlH0?ooo`H0oookJ_o[o`3oo`3f00?ooo]Z00Go0:KoojP0oooo
nf[oo`3io`1go`02oookJP04oom/0?oonf[ooo]Zoc_o00;ooo]Z00?o0?_ooookJ_oonfX00ooonfX0
1?mi0?ooobP0o`2Soonco`02oolX00;ooo]Z00?o0?oNoookJ_oo06`00_oonfX01?m=0?ooH@3ooook
J_l0odD2oookJP03o`3oT?oonf[o0?nB00Oooo]Z00CoolT0oaP0oooob@3oolT01ooonfX00ooo:03o
0?l5og00o`03oookJP04oomG0?oonf[ooo]Zool0;@Sooo]Z1_oob@000ooo:03o0?m>o`3o=003oook
JP;oobP01?oonfX8oolX00oooo]Z00?o0=cooomB0?oonfX03?oonfX4oomi01;ooo]Z00Co0000ool0
m_l0003o00001ooonfX00ol0g?oooo]ZoookJP07oookJP04oa00oooonf[ooo]ZoookJPKoo`001ooo
nfX00om`0?oooo]ZoookJP02oookJP03onKo0?lH0?ooo`0000Coo`0000?oH@3oool00?oonfX00_oo
nfX00onco`3ooo]ZoookJP06oolX00;ooo]Z0ooo:0000ooonf[oobP0oookJP0DoookJP03oomB0?l0
oc?o02[o00;ooo]Z00?o0=coo`3ogooonfX00ooonfX00ooo003oobP0oookJP02oookJP03ool00?oo
01?ooo]Z00;ooo]Z00CohOl0oookJ_oonf[o9P3o3?oonfX00ol0oe_oo`00ool00003ool000?ooo]Z
00CoT_l0oookJ_oonf[oA?l01?oonfX01?oo057ooo]ZoolX0?oo07T6oookJP05o`3oDooonf[ooo]Z
o`3o7Ol0hOl02OoonfX00ol0ocCooo]ZonGo0004oookJP03o`28oooonf[o0:Wo00;ooo]Z00?o00Co
oookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z05Cooo]Z00?o07?o
oookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP06oookJP03oolF0?ooTP3ooo]Z00;ooo]Z00?oo`3l
oookJ_oonfX00_oonfX01Ooo1P3ooo]ZoookJ_o[o`3oo`3f00;ooo]Z00_o0:KooookJ_nX0?ooo`3i
oookJ_l0Mooooo]Zo`3oV_ooK03ooo]Zoc_o0002oookJP03o`3koooonf[ooo]Z00Cooo]Z00CoN@3o
o`2Soonco`3oW`3o0ooonfX00ooMo`3o0?oNool0K002oookJP04odd0oomQ0?oooo]Zo`3oA@;ooo]Z
00?o0?n@oookJ_l0oi802?oonfX00olH0?ooi_l0oookJP07oookJP03oonn0?oonf[oL03o00Cooo]Z
00CooeL0oookJ_oonf[oo`0]2_oonfX00ol0e?oooo]Zo`28o`02oookJP03o`3oC_oonf[ooo]Z00;o
oo]Z00?o0?l8oookJ_oonfX01OoonfX00ol@0?ooT_l0oookJP0AoookJP03o`3Loooonf[ooe8000go
oo]Z00?oo`3foookJ_oonfX04_oonfX2o`000003ool0m_l0003ooo]Z00Kooo]Z00?o0=cooookJ_oo
nfX02?oonfX00ol@0?oooo]ZoookJP03oookJP03o`3oC_oonf[o0=Co00Oooo]Z00?oL03ooookJ_oo
nfX00_oonfX01OoVo`3o603ooookJ_oonf[o0?nB00;ooo]Z00?oH@3ooookJ_oonfX00_oonfX00onc
o`3ooo]ZoookJP04oookJP07oom/0?oonf[ooo]ZoookJ_oo0?Kooo]ZoaP0o`02oookJP03ool0o?oo
nf[ooo]Z01;ooo]Z00?ooe80o`3o<ol0:_l00ooonfX00ol0omoooo]ZoookJP02oookJP03o`3o6olB
0?ooolX000?ooo]Z00Go0?Woool04ooonf[ooo]Zon7o0002oookJP03obH0oooonf[ooo]Z00[ooo]Z
00Ko0?mKoookJ_oonf[ooo]Zoh;o0?l0<?l3oookJP04o`H0oonBo`3ooo]Zoa00o`Gooo]Z00Coo`1A
o`2]oooonf[oo`1i1OoonfX01_l0oe?ooo]ZoookJ_l0oagooo]Zo`3Qo`Sooo]Z00?o0?ldoookJ_l0
odh01OoonfX00ol0R?oo0:WooookJP02oookJP03o`04ool0e?oooo]Z00[ooo]Z00?ooh40oookJ_oo
nfX02_oonfX00ooo02gooo]ZoookJP0WoookJP00<OoonfX00ol0Looooo]ZoookJP0BoookJP03ool0
j_oonf[ooo]Z00Gooo]Z00?ooaH0oonB0?oonfX00ooonfX02Ooo0?cooo]ZoookJ_oonf[o603oool6
0?oonf[ojol0ool0mP03oookJP05o`2VoonX0?oooo]Zool0nOl0Mol00_oonfX01?ooK03ooo]Zoook
J_lko`02oookJP03o`3koooonf[ooo]Z00?ooo]Z00CoN@3ooolX0?l0Xooo/ol00_oo:002oookJP03
o`3og_oonf[oo`1/00;ooo]Z00CoC@3oof40oooonf[o0?m50_oonfX00ol0oi3ooo]Zo`3oTP06oook
JP;oolT000Co603oooo90?oob@3oolT01_oonfX00ooo:03o0?l5og00o`03oookJP04oomG0?oonf[o
oo]Zool0;@Sooo]Z1_oob@000ooo:03oogT0o`3o=003oookJP?oobP00ooonfX8oolX00oooo]Z00?o
0=cooookJ_ooDP003OoonfX5oomi00oooo]Z0_oo0?H3o`0000Oooo]Z00?o0=cooookJ_oonfX01ooo
nfX01?l@0?oooo]ZoookJ_oonfX5ool00003o`3Doooonf[ooo]Z00Gooo]Z00?oL03ooookJ_oonfX0
0_oonfX00olH0?ooo`00ool00004ool00003of40oooonf[ooo]Z00;ooo]Z00?o/ol0oookJ_oonfX0
3_oo:00DoookJP07oomB0?l0oc?o02[ooookJ_l0g?oooo]Zo`3og`04oookJP06ool00?oo:03ooo]Z
oookJ_oo003oo`0C1?oonfX01?oQo`3ooo]ZoookJ_lV0?l<oookJP03o`3oFooo003oo`0000?oo`00
0_oonfX01Ol60?ooT_l0oookJ_oonf[oA?l000Cooo]Z00Coo`1AoookJ_oo:03oo`1i1_oonfX01Ol0
oe?ooo]ZoookJ_l0oago0>7o00Wooo]Z00?o0?ldoookJ_oUo`001?oonfX00ol0R?oooo]Zo`2Yo`02
oookJP03o`04oooonf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP1D
oookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01_oonfX00ooo5P3ooi80oookJP02
oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Goo`H0oookJ_oonf[ojol0ool0mP02oookJP0;o`2Voooo
nf[oZ03oool0nOoonf[o07OooookJ_l0oi[oof`0oookJ_lko`000_oonfX00ol0nooooo]ZoookJP04
oookJP04ogT0ool0Xooo/ol0oil0o`?ooo]Z00?ogOl0o`3og_oo06`00_oonfX01?m=0?ooH@3ooook
J_l0odD2oookJP03o`3oT?oonf[o0?nB00Sooo]Z00?o603oonKo0?oonfX01ooonfX00ooo_P3ooo]Z
og00o`04oookJP04oomG0?oonf[ooo]Zool0;@[ooo]Z00Ko0=CooookJ_oonf[o08SooookJ_l0odh5
oookJP03o`3o2?oonf[ooo]Z00Cooo]Z00?o403ooi;o0?oonfX04_oonfX00ol0g?oooo]ZoomB000=
oookJP03ool0m_oonf[ooo]Z017ooo]Z0_oo0?H2o`0000Oooo]Z00?o0=cooookJ_oonfX02?oonfX0
0ol@0?oooo]ZoookJP03oookJP03o`3oC_oonf[o0=Co00Oooo]Z00?oL03ooookJ_oonfX00_oonfX0
1OlH0?oooo]ZoookJ_oonf[o0?nB00;ooo]Z00?oH@3ooookJ_oonfX00_oonfX00onco`3ooo]Zoook
JP03oookJP03oom/0?oonf[ooo]Z00;ooo]Z00Goo`3foookJ_lH0?oooo]Zool0o00EoookJP03oomB
0?l0oc?o02[o00;ooo]Z00?o0=coo`3ogooonfX00ooonfX00ol0oa_ooo]Zooo:0002oookJP03o`3i
oooo01?ooo]Z00;ooo]Z00CohOl0oookJ_oonf[o9P3o3?oonfX01_l0oe_ooo]ZoookJ_oonf[oP_l0
o`0`o`;ooo]Z00Go1P3ooookJ_nBo`3ooo]Zoa00o`05oookJP04ool0DOl0[Ooooo]Zool0N@Gooo]Z
00Ko0?mCoookJ_oonf[o0?lMoookJ_l0hOl8oookJP03o`3o=?oonf[o0?m>00Cooo]Z00?o08Sooook
J_l0ZOl00ooonfX00ol01?oo0=CooookJP0:oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oook
J_oonfX09ooonfX0037ooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP05oookJP03
oolF0?ooTP3ooo]Z00?ooo]Z00Woo`3loookJ_oonf[o603ooookJ_oo1P3ooo]Zon_o0?oo0?H00ooo
nfX01Ol0Y_ooZ03ooookJ_oo0?Wo07Oo00;ooo]Z00Co0?nJoom/0?oonf[o>ol00_oonfX00ol0nooo
oo]ZoookJP04oookJP03ogT0ool0Xooo/ol000;oobP00_oonfX00ol0omkooo]Zool0K002oookJP04
odd0oomQ0?oooo]Zo`3oA@;ooo]Z00?o0?n@oookJ_l0oi801_oonfX2ooo90004oaP0oooob@3oolT0
ooo900Kooo]Z00?oobP0o`3o1Om`0?l00ooonfX01?ooE`3ooo]ZoookJ_oo02d7oookJPOoolT000?o
obP0oomi0?l0oc@00ooonfX3oolX00?ooo]Z2Ooo:00?oookJP03o`3LooooDP3ooo]Z00gooo]Z1_oo
N@0;oookJP;oo`3f00?ooo]Zo`000?l000000_l00006oookJP03o`3Loooonf[ooo]Z00Oooo]Z00?o
403ooookJ_oonfX00_oonfX5ool000?ooo]Z0_ooN@02oookJP03og00oooonf[ooo]Z00;ooo]Z00?o
i_l0oaP0oooo00001Ooo00000omQ0?oooo]ZoookJP02oookJP03ok?o0?oonf[ooo]Z013oobP04_oo
nfX01_ooDP3ooo]Zo`0Zoooonf[o0=coo`3og`Gooo]Z00Koo`00oolX0?oonf[ooo]Zool00?oo01<4
oookJP05on7o0?oonf[o9P3oob3o0?oo00002ooonfX00ol0oe_oo`00ool00002ool000?ooo]Z00Go
1P3ooi;o0?oonf[ooo]ZodCo0004oookJP04ool0DOoo:03ooo]Zool0N@Kooo]Z00Go0?mCoookJ_oo
nf[o0?lMo`3Qo`09oookJP03o`3o=?oUo`3ooo]Z00Cooo]Z00Go08SooookJ_l0ZOoooo]Zo`04o`02
oookJP03o`3Doooonf[ooo]Z00Sooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP1D
oookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01_oonfX00ooo5P3ooi80oookJP02
oookJP06ool0o?oonf[ooo]ZoookJ_lH0?ooo`H00_oonfX03oo[o`3oo`3foookJ_oonf[o0:Kooook
J_nX0?ooo`3ioookJ_l0Mooooo]Zo`3oV_ooK03ooo]Zoc_o0002oookJP03o`3koooonf[ooo]Z00Co
oo]Z00CoN@3oo`2Soonco`3oW`3o1?oonfX02?l0omkoo`1/oookJ_oonf[oC@3oof40oooonf[o0?m5
0_oonfX00ol0oi3ooo]Zo`3oTP08oookJP03oaP0oooVo`3ooo]Z00Oooo]Z00?ookh0oookJ_m`0?l0
1?oonfX01?ooE`3ooo]ZoookJ_oo02d:oookJP06o`3Doooonf[ooo]Zo`28oooonf[o0?m>1OoonfX0
0ol0o`Sooo]ZoookJP04oookJP03oa00oonBo`3ooo]Z01;ooo]Z00?o0=cooookJ_ooDP003_oonfX0
0ooo0?Kooo]ZoookJP0=oookJP?oo`3f1?l00006oookJP03o`3Loooonf[ooo]Z00Sooo]Z00?o403o
oookJ_oonfX00ooonfX00ol0odkooo]Zo`3Do`08oookJP03og00oooonf[ooo]Z00;ooo]Z00Go603o
oookJ_oonf[ooo]Zo`3oTP02oookJP03of40oooonf[ooo]Z00;ooo]Z00?o/ol0oookJ_oonfX00ooo
nfX00oooK03ooo]ZoookJP02oookJP05ool0m_oonf[o603ooookJ_oo0?`05OoonfX00oooDP3ooo]Z
o`0Zo`02oookJP03o`3Lool0omoooo]Z00?ooo]Z00?o0?lKoookJ_oobP000_oonfX00ol0nOooo`0C
oookJP02oookJP05on7o0?oonf[ooo]ZobH0oon40?l02ooonfX01Ol0oe_ooo]ZoookJ_oonf[oP_l0
00?ooo]Z00Go1P3ooookJ_nBo`3ooo]Zoa00o`05oookJP04ool0DOl0[Ooooo]Zool0N@Gooo]Z00Ko
0?mCoookJ_oonf[o0?lMoookJ_l0hOl8oookJP03o`3o=?oonf[o0?m>00Cooo]Z00?o08SooookJ_l0
ZOl00_oonfX00ol01?oooo]Zo`3Do`0;oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oo
nfX09ooonfX0037ooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP06oookJP03oonB
0?oonf[ooo]Z00;ooo]Z00Coo`3loookJ_oonf[o603o0_oonfX00ooo1P3ojol0ool0mP03oookJP09
o`2VoonX0?oooo]Zool0nOoonf[o07OooookJ_l0oi[oof`000;ooo]Z00?o>ol0oookJ_l0nol01_oo
nfX00omi0?oo0:?ook?o0003oolX0004oookJ_l0omkooo]Zool0K0;ooo]Z00CoC@3oof40oooonf[o
0?m50_oonfX00ol0oi3ooo]Zo`3oTP06oookJP;oolT000Co603oooo90?oob@3oolT01_oonfX00ooo
:03o0?l5og00o`03oookJP04oomG0?oonf[ooo]Zool0;@Oooo]Z2?oob@02oomi0003o`3o=?oonf[o
oo]Z00CoobP01?oonfX2onGo0003oi;o0?oonf[ooo]Z017ooo]Z00?o0=cooookJ_ooDP003OoonfX8
oomi00Oooo]Z0_oo0?H3oookJPCo00001?oonfX2o`3Lo`Kooo]Z00GoolT0oookJ_oonf[ooo]Zoa00
o`04oookJPCoo`0000Co0=CooookJ_oonf[ooo]Z1OooN@04oookJP03oaP0oooonf[oo`0000Coo`00
00?oH@3ooookJ_oonfX00_oonfX01?nco`3ooo]ZoookJ_oonfX7oolX0003ool0m_oo:03oobP000Ko
obP04_oonfX01_ooDP3o02[ooookJ_oonf[o0=coo`3og`Cooo]Z00?o4P3oool00?oo:0000_oonfX0
0ooo003oo`0CoookJP03oookJP05on7o0?oonf[o9P3oob3o0?oo00002ooonfX00ol0oe_oo`00ool0
0002ool000?ooo]Z00Go1P3ooi;o0?oonf[ooo]ZodCo0004oookJP04ool0DOoo:03ooo]Zool0N@Ko
oo]Z00Co0?mCoookJ_oonf[o0?lM2_oonfX00ol0ocCoiOl0oookJP04oookJP07o`28ool0ZOoooo]Z
oookJ_l01?oooo]Zo`3Do`0;oookJP03oon10?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX0E?oo
nfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oonB0?oonfX00_oo
nfX02_oo0?cooo]ZoookJ_oonf[o603ooookJ_oo1P3ooo]Zon_o0?oo0?H2oookJP09o`2Voooonf[o
Z03oool0nOoonf[o07OooookJ_l0oi[oof`000;ooo]Z00?o>ol0oookJ_l0nol01_oonfX01?mi0?oo
0:?ook?o0?nO0?l4oookJP08o`3og_oo06cooo]ZoookJ_m=0?ooH@3ooookJ_l0odD2oookJP03o`3o
T?oonf[o0?nB00Sooo]Z00?o603oonKo0?oonfX01ooonfX00ooo_P3ooo]Zog00o`04oookJP04oomG
0?oonf[ooo]Zool0;@[ooo]Z00Oo0=CooookJ_oonf[o08SooookJ_l0odko0?ld00Cooo]Z00?o0?l8
oookJ_oonfX01OoonfX00onBo`3ooo]ZoookJP0AoookJP04o`3Loooonf[ooo]ZoomB00kooo]Z1?oo
0?H9oookJP;oo`3f0ooonfX4o`0000Gooo]Z00?o0=cooookJ_oonfX02?oonfX00ol@0?oooo]Zoook
JP04oookJP03o`3oC_oonf[o0=Co00Oooo]Z00?oL03ooookJ_oonfX00_oonfX01OoVo`3o603ooook
J_oonf[o0?nB00;ooo]Z00?oH@3ooookJ_oonfX00_oonfX00onco`3ooo]ZoookJP04oookJP03oom/
0?oonf[ooo]Z00;ooo]Z00Goo`3foookJ_lH0?oooo]Zool0o00EoookJP03oomB0?l0:_oooo]Z00;o
oo]Z00?o0=coo`3ogooonfX00ooonfX00ol0oa_ooo]Zooo:0002oookJP03o`3ioooo01?ooo]Z00;o
oo]Z00GohOl0oookJ_oonf[o9P3ooh@0o`0;oookJP05o`3oFooonf[ooo]Zoh;o0?l0<?l00ooonfX0
1Ol60?oooo]Zoi;o0?oonf[o403o00Gooo]Z00?oo`1Ao`2]oooo07T01_oonfX01Ol0oe?ooo]Zoook
J_l0oago0>7o00Wooo]Z00?o0?ldo`3oC_l0obh01?oonfX00ol0R?oooo]Zo`2Yo`02oookJP03o`04
ool0e?oooo]Z00_ooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP0WoookJP00<Ooo
nfX00ol0Looooo]ZoookJP0CoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooi80oookJ_oonfX00_oo
nfX01?oo0?cooo]ZoookJ_lH0?l2oookJP03ool60?o[o`3oo`3f00?ooo]Z00Wo0:KoojP0oooonf[o
o`3ioookJ_l0Mooooo]Zo`3oV_ooK0000_oonfX00olko`3ooo]Zo`3ko`05oookJP04oolX0?mi0?oo
0:?ook?o00?oobP000Cooo]Zo`3og_oonf[oo`1/0_oonfX01?m=0?ooH@3ooookJ_l0odD2oookJP03
o`3oT?oonf[o0?nB00Kooo]Z0_oob@000olH0?ooolT0ooo90002ooo900Gooo]Z00?oobP0o`3o1Om`
0?l00ooonfX01?ooE`3ooo]ZoookJ_oo02d7oookJPSoolT00_ooN@000ol0ocCooo]ZoookJP04oolX
00Cooo]Z0ooUo`000onBo`3ooo]ZoookJP0@oookJP04o`3Loooonf[ooo]ZoomB00gooo]Z2OooN@02
oookJP?oo`3f1OoonfX4o`0000?ooo]Z00?o0=cooookJ_oonfX01_oonfX2ooo90003oookJ_l@0?oo
oo]Z00Cooo]Z0ooo00000ol0e?oooo]ZoookJP02oookJPOoogT000Cooo]ZonKo0?lH0?oooo]Z1Ooo
00000omQ0?oooo]ZoookJP02oookJP04ok?o0?oonf[ooo]ZoookJPKoobP000?ooo]Zool0m_oo:000
1_oo:00BoookJP07oomB0?l0oc?o02[ooookJ_l0g?oooo]Zo`3og`04oookJP03ool00?oo:03ooo]Z
00;ooo]Z00?oo`00ool04ooonfX00ooonfX01OoQo`3ooo]ZobH0oolPo`3oo`0000[ooo]Z00?o0?mK
oookJ_oonfX00_oo00001_l0<?oooo]ZoookJ_oonf[o1P3ooi;o00;ooo]Z00?oA?l0oookJ_oonfX0
0_oonfX01?oo057oobP0oookJ_oo07T6oookJP04o`3oDooonf[o0?lMo`3Qo`Wooo]Z00?o0?ldoook
J_oUo`001OoonfX01ol0R?oo0:WooookJ_oonf[o00CooookJ_l0e?l02ooonfX00oooP@3ooo]Zoook
JP0;oookJP03ool0;Ooonf[ooo]Z05Cooo]Z00?o07?ooookJ_oonfX04ooonfX00ooo0>[ooo]Zoook
JP05oookJP03oolF0?ooTP3ooo]Z00;ooo]Z00[oo`3loookJ_oonf[ooo]ZoaP0oooonf[oo`H0oook
J_o[o`3oo`3f0_oonfX02Ol0Y_oooo]ZojP0oooo0?Wooo]Zo`1goooonf[o0?nJoom/0002oookJP03
oc_o0?oonf[o0?_o00Kooo]Z00CoN@3oo`2Soonco`3oW`3o1?oonfX02?l0omkoo`1/oookJ_oonf[o
C@3oof40oooonf[o0?m50_oonfX00ol0oi3ooo]Zo`3oTP08oookJP03oaP0oooVo`3ooo]Z00Oooo]Z
00?ookh0oookJ_m`0?l01?oonfX01?ooE`3ooo]ZoookJ_oo02d:oookJP04o`3Dool01?oooo]Zo`28
o`;ooo]Z00?o0?m>oookJ_oonfX00_oonfX00ol0o`Sooo]ZoookJP05oookJP03oa00oonBo`3ooo]Z
01;ooo]Z00Co0=cooookJ_oonf[ooe804OoonfX4ool0mP;ooo]Z0ooo0?H5oookJPCo00001?oonfX0
0ol0g?oooo]ZoookJP09oookJP03oa00oooonf[ooo]Z00Cooo]Z00?o0?m>o`3DoooonfX01ooonfX0
0om`0?oooo]ZoookJP02oookJP05oaP0oooonf[ooo]ZoookJ_l0oi800_oonfX00omQ0?oooo]Zoook
JP02oookJP03ok?o0?oonf[ooo]Z00?ooo]Z00?oof`0oookJ_oonfX00_oonfX01Ooo0?Kooo]ZoaP0
oooonf[oo`3l01Gooo]Z00?ooe80o`3o<ol0:_l00_oonfX00ol0g?oo0?oOoookJP03oookJP03o`3o
6olB0?ooolX000;ooo]Z00?o0?WooookJ_oo01<00ooonfX01OoQo`3ooo]ZobH0oolPo`3oQ03o00[o
oo]Z00Ko0?mKoookJ_oonf[ooo]Zoh;o0?l0<?l3oookJP05o`H0oooonf[oT_l0oookJ_l@0?l01Ooo
nfX00ooo057o0:goool0N@06oookJP05o`3oDooonf[o0?lMoookJ_l0hOl02?oonfX00ol0ocCooo]Z
o`3oCP05oookJP03o`28ool0ZOoooo]Z00;ooo]Z00?o00Coo`3DoooonfX02ooonfX00oooP@3ooo]Z
oookJP0:oookJP03ool0;Ooonf[ooo]Z02Oooo]Z000aoookJP03o`1coooonf[ooo]Z01?ooo]Z00?o
o`3ZoookJ_oonfX01OoonfX00oooTP3ooo]ZoookJP02oookJP04ool0o?oonf[ooo]ZoaP0o`;ooo]Z
00?oo`H0on_o0?oo0?H00ooonfX02Ol0Y_ooZ03ooookJ_oo0?Wooo]Zo`1goooonf[o0?nJoom/0002
oookJP03oc_o0?oonf[o0?_o00Gooo]Z00CoobP0ogT0ool0Xooo/ol00ooo:0001?oonf[o0?oNoook
J_oo06`2oookJP04odd0oooonf[oH@3oo`3oA@;ooo]Z00?o0?n@oookJ_l0oi801_oonfX2ooo90003
oaP0oooob@3oolT000;oolT01OoonfX00ooo:03o0?l5og00o`03oookJP05oomG0?oonf[ooo]Zoook
J_oo02d01_oonfX4ooo90004oolX0?l01?ooobP0oolX00?oogT00_oonfX5oolX00?ooo]Z0ooUo`00
0onBo`3ooo]ZoookJP0AoookJP03o`3Loooonf[ooe8000kooo]Z2_ooN@08oookJPCo00000_oonfX0
0ol0g?oooo]ZoookJP06oookJPCoolT01OoonfX3ool00003o`04ool0e?oooo]Z00;ooo]Z2OooN@00
0ooVo`3o603ooookJP04ool00003of40oooonf[ooo]Z00?ooo]Z00Co/ol0oookJ_oonf[ooo]Z1_oo
:0000ooonf[oo`3foolX0006oolX01;ooo]Z00Oooe80o`3o<ol0:_oooo]Zo`3Loooonf[o0?oO00Co
oo]Z00Ooo`00oolX0?oonf[ooo]Zool00?oonf[oo`0C00?ooo]Z00GohOl0oookJ_oonf[o9P3oob3o
000;oookJP03o`3oFooonf[ooo]Z00;oo`001?oonfX01Ol60?ooT_l0oookJ_oonf[oA?l000?ooo]Z
00Coo`1AoookJ_oo:03oo`1i1_oonfX01Ol0oe?ooo]ZoookJ_l0oago0>7o00Wooo]Z00?o0?ldoook
J_oUo`001OoonfX01ol0R?oo0:WooookJ_oonf[o00CooookJ_l0e?l02ooonfX00oooP@3ooo]Zoook
JP0:oookJP03ool0;Ooonf[ooo]Z05Gooo]Z00?o07?ooookJ_oonfX04ooonfX00ooo0>[ooo]Zoook
JP05oookJP03oolF0?ooTP3ooo]Z00;ooo]Z00[oo`3loookJ_oonf[ooo]ZoaP0oooonf[oo`H0oook
J_o[o`3oo`3f0_oonfX01?l0Y_oooo]ZojP0oooo0?T2oookJP03o`1gool0oi[oof`000;ooo]Z00?o
>ol0oookJ_l0nol01_oonfX01?mi0?oo0:?ook?o0?nO0?l4oookJP08o`3og_oonf[oo`1/oookJ_m=
0?oooo]Zof40ool0odD2oookJP03o`3oT?oonf[o0?nB00Sooo]Z00?o603oonKo0?oonfX01ooonfX0
0ooo_P3ooo]Zog00o`04oookJP04oomG0?oonf[ooo]Zool0;@[ooo]Z00Co0=Coo`04oooonf[o08So
0_oonfX00ol0odkooo]ZoookJP02oookJP03o`3o2?oonf[ooo]Z00Gooo]Z00?o403ooi;o0?oonfX0
4_oonfX01?l0g?oooo]ZoookJ_ooDP0EoookJP;oo`3f2?oonfX4o`0000?ooo]Z00?o0=cooookJ_oo
nfX02OoonfX00ol@0?oooo]ZoookJP04oookJP03o`3oC_oonf[o0=Co00Oooo]Z00?oL03ooookJ_oo
nfX00ooonfX01OlH0?oooo]ZoookJ_oonf[o0?nB00;ooo]Z00?oH@3ooookJ_oonfX00_oonfX00onc
o`3ooo]ZoookJP03oookJP03oom/0?oonf[ooo]Z00;ooo]Z00Goo`3foookJ_lH0?oooo]Zool0o00E
oookJP03oomB0?l0oc?o02[o00;ooo]Z00?o0=coo`3ogooonfX00ooonfX00ol0oa_o4P3oooo:0002
oookJP03o`3ioooonf[oo`0C00;ooo]Z00GohOl0oookJ_oonf[o9P3oob3o000;oookJP06o`3oFooo
nf[ooo]ZoookJ_n2o`3o033o0ooonfX01Ol60?ooT_l0oookJ_oonf[o403o00Cooo]Z00Coo`1Aoook
J_l0[Oooo`1i1OoonfX01_l0oe?ooo]ZoookJ_l0oagooo]Zo`3Qo`Sooo]Z00?o0?ldoookJ_l0odh0
1OoonfX00ol0R?oo0:WooookJP02oookJP03o`04ool0e?oooo]Z00[ooo]Z00?ooh40oookJ_oonfX0
2_oonfX00ooo02gooo]ZoookJP0XoookJP00<OoonfX00ol0Looooo]ZoookJP0CoookJP03ool0j_oo
nf[ooo]Z00Gooo]Z00?ooi80oookJ_oonfX00_oonfX01?oo0?cooo]ZoookJ_lH0?l2oookJP03ool6
0?o[o`3oo`3f00?ooo]Z00Wo0:KoojP0oooonf[oo`3ioookJ_l0Mooooo]Zo`3oV_ooK0000_oonfX0
0olko`3ooo]Zo`3ko`05oookJP04oolX0?mi0?oo0:?ook?o00CoobP000Wo0?oNoookJ_oonf[oo`1/
oookJ_m=0?oooo]Zof40ool0odD00_oonfX00ooo003ooo]Zo`3oTP05oookJP?oolT000?oi_l0oaP0
oooob@000_oob@05oookJP03oolX0?oonf[oL03o00?ooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@09
oookJP03oolX0?oob@3o00Co00;oobP01?ooN@000ooonf[oobP0oolX0003oolX00?ooo]Z0ooUo`00
0onBo`3ooo]ZoookJP0AoookJP03o`3Loooonf[ooo]Z00;ooe803OoonfX:oomi00Oooo]Z0_l00002
oomi0003oookJ_l0g?oooo]Z00Sooo]Z1Ooob@04oookJP;oo`0000?ooo]Zo`3DoooonfX00ooonfX9
oomi0003oaP0oooonf[ooo]Z00Coo`0000?oH@3ooookJ_oonfX00_oonfX00onco`3ooo]ZoookJP02
oookJPGoobP00_oonfX00ooo0?KoobP0oolX0004oolX01?ooo]Z00Kooe80oookJ_l0:_oooo]Zo`3L
ool0oml5oookJP06ool00?oo:03ooo]ZoookJ_oo003oo`0C1?oonfX01OoQo`3ooo]ZoookJ_lV0?oo
o`0000_ooo]Z00?o0?mKoookJ_oonfX00_oo0004oookJP04o`H0oonBo`3ooo]ZodCo00Cooo]Z00Co
o`1AoookJ_oo:03oo`1i1_oonfX01Ol0oe?ooo]ZoookJ_l0oago0>7o00Wooo]Z00?o0?ldonGo0?l0
obh01OoonfX01ol0R?oo0:WooookJ_oonf[o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP0:
oookJP03ool0;Ooonf[ooo]Z05Gooo]Z00?o07?ooookJ_oonfX04ooonfX00ooo0>[ooo]ZoookJP05
oookJP03oolF0?ooTP3ooo]Z00;ooo]Z00[oo`3loookJ_oonf[ooo]ZoaP0oooonf[oo`H0oookJ_o[
o`3oo`3f0_oonfX02Ol0Y_oooo]ZojP0oooonf[oo`3ioookJ_l0Mooo0?nJoom/0002oookJP03oc_o
0?oonf[o0?_o00Kooo]Z00CoN@3oo`2Soonco`3oW`3o1?oonfX02?l0omkooo]Zool0K?oonf[oC@3o
oookJ_mQ0?oo0?m50_oonfX00ol0oi3ooo]Zo`3oTP09oookJP03oaP0oooonf[ooo]Z00Kooo]Z00?o
okh0oookJ_m`0?l01?oonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00Wooo]Z00Co0=Coo`04oooonf[o
08So0_oonfX00ol0odkooo]ZoookJP03oookJP03o`3o2?oonf[ooo]Z00Gooo]Z00?oT_l0oookJ_oo
nfX04_oonfX01?l0g?oooo]ZoookJ_ooDP0NoookJPCo00000_oonfX00ol0g?oooo]ZoookJP09oook
JP03oa00oooonf[ooo]Z00Gooo]Z00?o0?m>o`3DoooonfX01ooonfX00om`0?oooo]ZoookJP02oook
JP03onKo0?lH0?oooo]Z00;ooo]Z00?o0?nBoookJ_mQ0?l01?oonfX00onco`3ooo]ZoookJP04oook
JP03oom/0?oonf[ooo]Z00;ooo]Z00Goo`3foookJ_lH0?oooo]Zool0o00EoookJP03oomB0?oonf[o
02[o00;ooo]Z00?o0=coo`3ogooonfX00ooonfX00ol0oa_o4P3oooo:0002oookJP03o`3ioooo01?o
oo]Z00;ooo]Z00GohOl0oookJ_oonf[o9P3ooh@0o`0;oookJP06o`3oFooonf[ooo]Zo`3o/?n2o`3o
033o0ooonfX01?l60?ooT_l0oookJ_l@0?l5oookJP04ool0DOl0[Ooooo]Zool0N@Gooo]Z00Ko0?mC
oookJ_oonf[o0?lMoookJ_l0hOl8oookJP03o`3o=?oonf[o0?m>00Gooo]Z00?o08Soo`2YoooonfX0
0_oonfX00ol01?oo0=CooookJP0:oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX0
:?oonfX003;ooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP05oookJP03oonB0?oo
nf[ooo]Z00;ooo]Z00Coo`3loookJ_oonf[o603o0_oonfX00ooo1P3ojol0ool0mP03oookJP09o`2V
oonX0?oooo]ZoookJ_oo0?Wo07OooookJ_l0oi[oof`000;ooo]Z00?o>ol0oookJ_l0nol01OoonfX0
1?oo:03oN@3oo`2Soonco`04oolX0009o`3og_oonf[ooo]Zool0K?oonf[oC@3ooookJ_mQ0?oo0?m5
00;ooo]Z00?oo`00oookJ_l0oi801OoonfX3ooo90003onKo0?lH0?ooolT000?oolT01?oonfX00ooo
:03ooo]Zog00o`04oookJP04oomG0?oonf[ooo]Zool0;@[ooo]Z00CoolT0o`04oooonf[oobP01?oo
N@000ooonf[oobP0oolX0004oolX00;ooo]Z1?oUo`000onBo`3ooo]ZoookJP0AoookJP05o`3Loooo
nf[ooo]ZoookJ_ooDP003?oonfX:oomi00Oooo]Z00Go0000oomi0?ooN@3oogT0o`3Lo`09oookJPOo
olT00ooonfX01?oo003ooo]Zo`04ool0e?l4oookJPSoogT000Coi_l0oaP0oooonf[ooo]Z0ooo0000
0ooonf[oH@3ooookJP03oookJP04ok?o0?oonf[ooo]ZoookJPKoobP000?ooo]Zool0m_oonfX01_oo
:00CoookJP06oomB0?oonf[o02[ooookJ_l0g?oo0?oO0_oonfX3oolX0006ool00?oo:03ooo]Zoook
J_oo003oo`0C1?oonfX01OoQo`3ooo]ZoookJ_lV0?ooo`0000_ooo]Z00Go0?mKoookJ_oonf[oo`00
o`0`o`04oookJP04oi;o0?oonf[ooo]ZodCo00;ooo]Z0_oo:0001?oo057oobP0oolX0?oo07T6oook
JP05o`3oDooonf[ooo]Zo`3o7Ol0hOl02OoonfX00ol0ocCoiOl0oookJP04oookJP03o`28oooonf[o
0:Wo00;ooo]Z00?o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[o
oo]Z05Kooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP05oookJP03oolF0?ooTP3o
oo]Z00;ooo]Z00[oo`3loookJ_oonf[ooo]ZoaP0oooonf[oo`H0oookJ_o[o`3oo`3f0_oonfX02Ol0
Y_oooo]ZojP0oooonf[oo`3ioookJ_l0Mooo0?nJoom/0002oookJP03oc_o0?oonf[o0?_o00Kooo]Z
00CoN@3oo`2Soonco`3oW`3o1?oonfX02?l0omkooo]Zool0K?oonf[oC@3ooookJ_mQ0?oo0?m50_oo
nfX00ol0oi3ooo]Zo`3oTP09oookJP03oaP0oooonf[ooo]Z00Kooo]Z00?ookh0oookJ_m`0?l01Ooo
nfX01?ooE`3ooo]ZoookJ_oo02d:oookJP03o`3Doooonf[o08So00;ooo]Z00?o0?m>oookJ_oonfX0
0ooonfX00ol0o`Sooo]ZoookJP05oookJP03oa00oonBo`3ooo]Z01?ooo]Z00Co0=cooookJ_oonf[o
oe807OoonfX5o`000003o`3Loooonf[ooo]Z00[ooo]Z00?o403ooookJ_oonfX01?oonfX00ol0odko
oo]Zo`3Do`07oookJP03og00oooonf[ooo]Z00?ooo]Z00Go603ooookJ_oonf[ooo]Zo`3oTP02oook
JP03of40oooonf[ooo]Z00;ooo]Z00?o/ol0oookJ_oonfX00ooonfX00oooK03ooo]ZoookJP02oook
JP05ool0m_oonf[o603ooookJ_oo0?`05_oonfX00oooDP3ooo]Zo`0Zo`02oookJP03o`3Lool0omoo
oo]Z00?ooo]Z00?o0?lKoa80oooobP000_oonfX00ol0nOooo`0CoookJP02oookJP05on7o0?oonf[o
oo]ZobH0oon40?l02ooonfX01_l0oe_ooo]ZoookJ_l0ok3oP_l0o`0`o`?ooo]Z00Co1P3ooi;o0?oo
nf[o403o1OoonfX01?oo057o0:gooookJ_oo07T5oookJP06o`3oDooonf[ooo]Zo`3o7Ooonf[o0>7o
2?oonfX00ol0ocCooo]Zo`3oCP05oookJP03o`28ool0ZOoooo]Z00;ooo]Z00?o00Coo`3DoooonfX0
2_oonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z02Sooo]Z000boookJP03o`1coooo
nf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01OoonfX00oooTP3ooo]ZoookJP02oookJP04ool0o?oo
nf[ooo]ZoaP0o`;ooo]Z00Coo`H0on_o0?oonf[oo`3f0_oonfX02Ol0Y_ooZ03ooookJ_oonf[oo`3i
o`1goooonf[o0?nJoom/0002oookJP03oc_o0?oonf[o0?_o00Kooo]Z00?oN@3oo`2Soonco`001?oo
nfX02Ol0omkooo]ZoookJ_oo06cooo]Zodd0oooonf[oH@3oo`3oA@02oookJP;oo`0000?o0?nBoook
J_oonfX00ooonfX3ooo90003onKo0?lH0?oooo]Z00Oooo]Z00Cookh0oookJ_l0o`GoL03o0ooonfX0
1?ooE`3ooo]ZoookJ_oo02d:oookJP04ooo90?l01?oooo]ZoolX00GoogT01_oo:002oookJPCoiOl0
00?oT_l0onGo0?oonfX04_oonfX01Ol0g?oooo]ZoookJ_oonf[ooe8000cooo]Z2?ooN@07oookJP;o
o`000oooN@0:oookJPSoolT00_oonfX00ol0odko00Coo`3Do`05oookJPOoogT000Cooo]ZoaP0oooo
nf[ooo]Z0ooo00000ooonf[oH@3ooookJP04oookJP04ok?o0?oonf[ooo]ZoookJPGoobP00_oonfX0
0ooo0?Kooo]ZoolX0004oolX01?ooo]Z00Oooe80o`3o<ol0:_oooo]Zo`3Loooonf[o0?oO00;ooo]Z
0_oo:0001ooo003oobP0oolX0?oo:03ooo]Zool00?oo01<01?oonfX01?oQo`3ooo]ZobH0oolPo`0<
oookJP05o`3oFooonf[ooo]Zoh;o0?l0<?l00ooonfX01Ol60?ooT_l0oookJ_oonf[oA?l000;ooo]Z
0_oo:0001?oo057oobP0oolX0?oo07T2oolX00Cooo]Z00Co0?mCoookJ_oonf[o0?lM2_oonfX00ol0
ocCoiOl0oookJP04oookJP03o`28ool0ZOoooo]Z00;ooo]Z00?o00CooookJ_l0e?l02ooonfX00ooo
P@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z05Kooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo
0>[ooo]ZoookJP05oookJP03oolF0?ooTP3ooo]Z00;ooo]Z01Goo`3loookJ_oonf[ooo]ZoaP0oooo
nf[oo`H0oookJ_o[o`3ooo]Zool0m_oonf[o0:KooookJ_nX0?oooo]Zool0nOoonf[o07Ooo`3oV_oo
K0000_oonfX00olko`3ooo]Zo`3ko`06oookJP04ogT0ool0Xooo/ol0oil0o`Cooo]Z00So0?oNoook
J_oo06cooo]Zodd0oooonf[oH@3oo`3oA@;ooo]Z00?o0?n@oookJ_l0oi802OoonfX00olH0?oo07Co
oookJP06oookJP04oonn0?oonf[o0?l5og00o`Cooo]Z00CooeL0oookJ_oonf[oo`0]2_oonfX01ol0
e?oooo]ZoookJ_l0R?oooo]Zo`3o=?l0odh01?oonfX00ol0o`Sooo]ZoookJP05oookJP03oa00oonB
o`3ooo]Z01Cooo]Z00Co0=cooookJ_oonf[ooe807?oonfX3o`0000;o0=co3?oonfX00ol@0?oooo]Z
oookJP05oookJP03o`3oC_l0e?oooo]Z00Oooo]Z00?oL03ooookJ_oonfX00_oonfX00ol0M?oo603o
oookJP02oookJP04o`3oT_oonf[ooo]Zof40o`Cooo]Z00?o/ol0oookJ_oonfX00ooonfX00oooK03o
oo]ZoookJP02oookJP05ool0m_oonf[o603ooookJ_oo0?`05OoonfX00oooDP3o0?lco`0Zo`02oook
JP03o`3Loooonf[o0?oO00?ooo]Z00So0?lKoa80oooonf[oolX0oookJ_l0nOoooo]Zool04`?ooo]Z
00CohOl0oookJ_oonf[o9P3o3?oonfX01Ol0oe_ooo]ZoookJ_l0ok3oP_l000?ooo]Z00Go1P3ooook
J_nBo`3ooo]Zoa00o`05oookJP03ool0DOl0[Oooo`1i00Kooo]Z00Go0?mCoookJ_oonf[o0?lMo`3Q
o`09oookJP03o`3o=?l0odko0?l^00Gooo]Z00?o08Soo`2YoooonfX00_oonfX00ol01?oo0=Cooook
JP0:oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX0:?oonfX003;ooo]Z00?o07?o
oookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP05oookJP03oonB0?oonf[ooo]Z00;ooo]Z00Coo`3l
oookJ_oonf[o603o0_oonfX01?oo1P3ojol0oookJ_oo0?H2oookJP09o`2VoonX0?oooo]ZoookJ_oo
0?Wo07OooookJ_l0oi[oof`000;ooo]Z00?o>ol0oookJ_l0nol01_oonfX00omi0?oo0:?ook?o0004
oookJP09o`3og_oonf[ooo]Zool0K?oonf[oC@3ooookJ_mQ0?oo0?m500;ooo]Z0_oo00000ol0oi;o
oo]ZoookJP07oookJP03oaP0oooonf[ooo]Z00Kooo]Z00Cookh0oookJ_l0o`GoL03o0ooonfX01Ooo
E`3ooo]ZoookJ_oonf[oo`0]00Wooo]Z00CoolT0o`04oooonf[oobP01OooN@07oolX00;ooo]Z1?oU
o`000onBo`3ooo]ZoookJP0BoookJP05o`3Loooonf[ooo]ZoookJ_ooDP003?oonfX6oomi00Gooo]Z
1Ooo0004oomi00Sooo]Z1ooob@03oookJP03o`3oC_oonf[o0=Co00Kooo]Z1_ooN@000ooonf[oi_l0
oaP0o`02oookJP?oo`0000?ooo]Zof40oooonfX00ooonfX00onco`3ooo]ZoookJP02oookJPCoobP0
0ooonfX00ooo0?Kooo]ZoolX0003oolX01Cooo]Z00Oooe80oookJ_l0:_oooo]Zo`3Loooonf[o0?oO
00;ooo]Z0_oo:0000ooo003oobP0oolX0003oolX0003ool04ooonf[ooo]Z00;ooo]Z00CohOl0oook
J_lV0?oo8?l02ooonfX01_l0oe_ooo]ZoookJ_oonf[oP_l0o`0`o`?ooo]Z00Go1P3ooi;o0?m4o`3o
oo]ZodCo0002oookJP;oobP000Coo`1AoolX0?oo:03oo`1i0_oo:004oookJP04o`3oDooonf[oolT0
o`3o7@[ooo]Z00?o0?ldonGo0?oonfX01?oonfX00ol0R?oo0:WooookJP02oookJP03o`04oooonf[o
0=Co00_ooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP1GoookJP03o`1coooonf[o
oo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01OoonfX00ooo5P3ooi80oookJP02oookJP0Eool0o?oonf[o
oo]ZoookJ_lH0?oooo]Zool60?oonf[ojol0oookJ_oo0?Kooo]Zo`2Voooonf[oZ03ooookJ_oo0?Wo
oo]Zo`1gool0oi[oof`000;ooo]Z00?o>ol0oookJ_l0nol01ooonfX00ol0Xooo/ol0oil0o`04oook
JP08o`3og_oonf[oo`1/oookJ_m=0?oooo]Zof40ool0odD2oookJP04o`3oT?oonf[ooo]Zo`3oTPSo
oo]Z00?o603oonKo0?oonfX01_oonfX01?oo_P3ooo]Zo`3o1Om`0?l4oookJP04oomG0?oonf[ooo]Z
ool0;@[ooo]Z00Co0=CooookJ_oonf[o08So0_oonfX00ol0odkooo]ZoookJP02oookJP03o`3o2?oo
nf[ooo]Z00Kooo]Z00?o403ooi;o0?oonfX05?oonfX01?l0g?oooo]ZoookJ_ooDP0KoookJP04o`00
0?l0g?oo0=coo`0000cooo]Z00?o403ooookJ_oonfX01OoonfX00ol0odko00Coo`3Do`08oookJP03
og00oooonf[ooo]Z00;ooo]Z00?o603ooookJ_oonfX00_oonfX00ol0oi;ooo]Zof40o`04oookJP03
ok?o0?oonf[ooo]Z00Cooo]Z00?oof`0oookJ_oonfX00_oonfX01Ooo0?Kooo]ZoaP0oooonf[oo`3l
01Gooo]Z00?ooe80oookJ_l0:_l00_oonfX00ol0g?oo0?oOoookJP03oookJP03o`3o6olB0?ooolX0
00;ooo]Z00?o0?WooookJ_oo01<00ooonfX01?oQo`3ooo]ZobH0oolPo`0;oookJP06o`3oFooonf[o
oo]ZoookJ_l0ok3oP_l00ooonfX01Ol60?oooo]Zoi;o0?oonf[o403o00Gooo]Z00?oo`1Ao`2]oooo
07T01_oonfX01Ol0oe?ooo]Zo`3o2?l0oago0>7o00Wooo]Z00?o0?ldo`3oC_l0obh01?oonfX00ol0
R?oo0:WooookJP03oookJP03o`04ool0e?oooo]Z00[ooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo
02gooo]ZoookJP0YoookJP00<_oonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Go
oo]Z00?ooi80oookJ_oonfX00_oonfX01?oo0?cooo]ZoookJ_lH0?l2oookJP04ool60?o[o`3ooo]Z
ool0mP;ooo]Z00Wo0:KooookJ_nX0?oooo]Zool0nOl0Mooooo]Zo`3oV_ooK0000_oonfX00olko`3o
oo]Zo`3ko`06oookJP03ogT0ool0Xooo/ol000Cooo]Z00Wo0?oNoookJ_oonf[oo`1/oookJ_m=0?oo
oo]Zof40ool0odD00_oonfX3ool00003o`3oT_oonf[ooo]Z00Kooo]Z00?o603ooookJ_oonfX01ooo
nfX00ooo_P3o0?l5og00o`03oookJP05oomG0?oonf[ooo]ZoookJ_oo02d02OoonfX01?oob@3o00Co
oookJ_oo:006oomi00KoobP00_oonfX4onGo0003oi;o0?oUo`3ooo]Z01?ooo]Z00Go0=cooookJ_oo
nf[ooo]ZoomB000;oookJPGoogT01?oonfX7ool000CoogT02?oonfX6ooo900?ooo]Z00Co0?m>oook
J_l01?oo0=Co1OoonfX6oomi00;ooo]Z00Co603ooookJ_oonf[ooo]Z0_oo0002oookJP03of40oooo
nf[ooo]Z00;ooo]Z00?o/ol0oookJ_oonfX00_oonfX6oolX0003ool0m_oonf[oobP000CoobP05?oo
nfX01oooDP3ooo]Zo`0Zoooonf[o0=cooookJ_l0oml00_oonfX2oolX0003ool00?oo:03oobP000?o
obP01OoonfX01?oQo`3ooo]ZobH0oolPo`0;oookJP05o`3oFooonf[ooo]Zoh;o0?l0<?l01?oonfX0
0ol60?ooT_l0odCo0003odCo0006oookJ_oo:03oobP0ool0DOoo:03oo`1i0_oo:005oookJP04o`3o
Dooonf[o0?lMo`3Qo`Wooo]Z00?o0?ldoookJ_oUo`001OoonfX00ol0R?oo0:WooookJP02oookJP03
o`04ool0e?oooo]Z00_ooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP1GoookJP03
o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01OoonfX00ooo5P3ooi80oookJP02oookJP0E
ool0o?oonf[ooo]ZoookJ_lH0?oooo]Zool60?oonf[ojol0oookJ_oo0?Kooo]Zo`2Voooonf[oZ03o
oookJ_oo0?Wooo]Zo`1gool0oi[oof`000;ooo]Z00?o>ol0oookJ_l0nol01ooonfX00ol0Xooo/ol0
oil0o`04oookJP08o`3og_oonf[oo`1/oookJ_m=0?oooo]Zof40ool0odD3oookJP03o`3oT?oonf[o
0?nB00Sooo]Z00?o603oonKo0?oonfX01ooonfX00ooo_P3o0?l5og00o`04oookJP04oomG0?oonf[o
oo]Zool0;@[ooo]Z00Co0=CooookJ_oonf[o08So0_oonfX00ol0odkooo]ZoookJP02oookJP03o`3o
2?oonf[ooo]Z00Kooo]Z00?o403ooi;o0?oonfX05OoonfX01?l0g?oooo]ZoookJ_ooDP0JoookJP04
o`3Lool0003o0000o`0000cooo]Z00?o403ooookJ_oonfX01?oonfX00ol0odkooo]Zo`3Do`08oook
JP03og00oooonf[ooo]Z00?ooo]Z00Go603ooookJ_oonf[ooo]Zo`3oTP02oookJP03of40oooonf[o
oo]Z00;ooo]Z00?o/ol0oookJ_oonfX00ooonfX00oooK03ooo]ZoookJP02oookJP03ool0m_oonf[o
603o00;ooo]Z00?oo`3loookJ_oonfX04ooonfX00oooDP3ooo]Zo`0Zo`02oookJP03o`3Lool0omoo
oo]Z00?ooo]Z00?o0?lKoa80oooobP000_oonfX00ol0nOooo`0CoookJP03oookJP04on7o0?oonf[o
9P3oob3o00_ooo]Z00Ko0?mKoookJ_oonf[o0?n`oh;o0?l0<?l3oookJP05o`H0oooonf[oT_l0oook
J_l@0?l01OoonfX00ooo057o0:goool0N@06oookJP05o`3oDooonf[o0?lMoookJ_l0hOl02?oonfX0
0ol0ocCooo]Zo`3oCP05oookJP03o`28ool0ZOoooo]Z00?ooo]Z00?o0=CooookJ_oonfX02_oonfX0
0oooP@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z02Wooo]Z000boookJP03o`1coooonf[ooo]Z
01;ooo]Z00?oo`3ZoookJ_oonfX01OoonfX00oooTP3ooo]ZoookJP02oookJP04ool0o?oonf[ooo]Z
oaP0o`;ooo]Z00Coo`H0oookJ_o[o`3oo`3f0_oonfX02Ol0Y_oooo]ZojP0oooonf[oo`3io`1goooo
nf[o0?nJoom/0002oookJP03oc_o0?oonf[o0?_o00Kooo]Z00CoN@3oo`2Soonco`3oobP00ooonfX0
1?l0omkogOl0oookJ_oo06`2oookJP03odd0oooonf[oH@3o00;ooo]Z0ooo00000ol0oi;ooo]Zoook
JP06oookJP03oaP0oooonf[ooo]Z00Oooo]Z00?ookh0o`3o1Om`0?l00ooonfX01OooE`3ooo]Zoook
J_oonf[oo`0]00Wooo]Z00Co0=CooookJ_l01?oo08So1_ooN@07oolX0003oookJ_oUo`3oiOl000;o
iOl000?oT_l0onGo0?oonfX05?oonfX2o`3Lo`;ooo]Z1?oo:008oookJP?oogT00ooonfX:ool000?o
ogT01ooonfX6ooo900Cooo]Z00?o0?m>oookJ_l0e?l01_oonfX5oomi00;ooo]Z00?oi_l0oaP0oooo
nfX00_oonfX01?oo003ooo]ZoookJ_mQ0?l5oookJP03ok?o0?oonf[ooo]Z00;ooo]Z0ooo:0000ooo
nf[oobP0oolX0006oolX01Gooo]Z00Kooe80oookJ_l0:_oooo]Zo`3Lool0oml3oookJP03oolX0?oo
003oobP000CoobP000?oo`0CoookJ_oonfX00_oonfX01OoQo`3ooo]ZoookJ_lV0?oo8?l000_ooo]Z
00Go0?mKoookJ_oonf[oP_l0o`0`o`03oookJP03o`H0oom4o`3oT_l000KoA?l000CoobP0ool0DOoo
:03oo`1i0_oo:005oookJP04o`3oDooonf[o0?lMo`3Qo`Wooo]Z00?o0?ldonGo0?l0obh01OoonfX0
1ol0R?oo0:WooookJ_oonf[o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP0:oookJP03ool0
;Ooonf[ooo]Z05Oooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP05oookJP03oolF
0?ooTP3ooo]Z00;ooo]Z01Goo`3loookJ_oonf[ooo]ZoaP0oooonf[oo`H0oookJ_o[o`3ooo]Zool0
m_oonf[o0:KooookJ_nX0?oooo]Zool0nOoonf[o07Ooo`3oV_ooK0000_oonfX00olko`3ooo]Zo`3k
o`07oookJP04o`2Soonco`3ooo]Zoil0o`?ooo]Z00?o0?oNoookJ_oo06`00_oonfX00om=0?oooo]Z
of40o`03oookJP03o`3oT?oonf[o0?nB00Sooo]Z00?o603oonKo0?oonfX01ooonfX00ooo_P3o0?l5
og00o`04oookJP05oomG0?oonf[ooo]ZoookJ_oo02d02OoonfX01?l0e?oo00CooookJ_l0R?l2oook
JP03o`3oC_oonf[ooo]Z00?ooo]Z00?o0?l8oookJ_oonfX01OoonfX00ol@0?ooT_l0oookJP0Foook
JP;o0=co00?ooo]ZoomB0?ooDP005_oonfX2o`3Lo`Co00002ooonfX00ol@0?oooo]ZoookJP05oook
JP03o`3oC_l01?oo0=Co00Sooo]Z00?oL03ooookJ_oonfX00_oonfX00ooVo`3o603ooookJP02oook
JP04o`3oT_oonf[ooo]Zof40o`Cooo]Z00?o/ol0oookJ_oonfX00ooonfX00oooK03ooo]ZoookJP02
oookJP05ool0m_oonf[o603ooookJ_oo0?`05_oonfX00oooDP3ooo]Zo`0Zo`02oookJP03o`3Lool0
omoooo]Z00;ooo]Z00Co0?lKoookJ_lB0?ooolX00_oonfX00ol0nOooo`0CoookJP02oookJP05on7o
0?oonf[ooo]ZobH0oolPo`002ooonfX01_l0oe_ooo]ZoookJ_l0ok3oP_l0o`0`o`;ooo]Z00Ko1P3o
oookJ_oonf[oT_l0oookJ_l@0?l5oookJP03ool0DOl0[Oooo`1i00Kooo]Z00Go0?mCoookJ_l0oago
oo]Zo`3Qo`08oookJP03o`3o=?oonf[o0?m>00Gooo]Z00?o08Soo`2YoooonfX00_oonfX00ol01?oo
0=CooookJP0;oookJP03oon10?oonf[ooo]Z00Wooo]Z00?oo`0]oookJ_oonfX0:OoonfX003;ooo]Z
00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP05oookJP03oonB0?oonf[ooo]Z00;ooo]Z
00Coo`3loookJ_oonf[o603o0_oonfX01?oo1P3ooo]Zon_o0?oo0?H2oookJP09o`2Voooonf[oZ03o
oookJ_oo0?Wo07OooookJ_l0oi[oof`000;ooo]Z00Co>ol0oookJ_oonf[o0?_o1OoonfX01?mi0?oo
0:?ook?o0?oo:003oookJP04o`3og_oMo`3ooo]Zool0K0;ooo]Z00?oC@3ooookJ_mQ0?l00_oonfX3
ool00003o`3oT_oonf[ooo]Z00Kooo]Z00?o603ooookJ_oonfX01ooonfX00ooo_P3oo`00og00o`03
oookJP05oomG0?oonf[ooo]ZoookJ_oo02d02_oonfX00ol0e?oo00CooookJP07oomi00?oobP01?oo
nfX5onGo0003oi;o0?oUo`3ooo]Z01Gooo]Z0_l0g?l2oookJPOoobP01?oonfX00oooN@3ooo]Zool0
000<ool000CoogT01_oonfX4ooo900Gooo]Z00Co0?m>oookJ_l01?oo0=Co1_oonfX5oomi00;ooo]Z
00?oi_l0oaP0oooonfX00_oonfX01?l0oi;ooo]ZoookJ_mQ0?l4oookJP03ok?o0?oonf[ooo]Z00?o
oo]Z0ooo:0000ooonf[oobP0oolX0006oolX01Gooo]Z00Kooe80oookJ_l0:_oo0=cooookJ_l0oml3
ool00003oolX0?oo003oobP000CoobP000?oo`0CoookJ_oonfX00_oonfX01?oQo`3ooo]ZoookJ_lV
0?l<oookJP05o`3oFooonf[ooo]Zoh;o0?l0<?l00ooonfX00ol60?ooA?l0oi;o0006odCo0005ool0
DOoo:03oobP0ool0NOoo:0001OoonfX01Ol0oe?ooo]ZoookJ_l0oago0>7o00Wooo]Z00?o0?ldonGo
0?oonfX01OoonfX01ol0ZOoooo]ZoookJ_oonf[o00CooookJ_l0e?l02ooonfX00oooP@3ooo]Zoook
JP0:oookJP03ool0;Ooonf[ooo]Z05Oooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]Zoook
JP05oookJP03oolF0?ooTP3ooo]Z00;ooo]Z00Ooo`3loookJ_oonf[ooo]ZoaP0oooonf[oo`H000;o
oo]Z00cojol0ool0m_oonf[o0:KooookJ_nX0?oooo]Zool0nOoonf[o07Ooo`3oV_ooK002oookJP04
oc_o0?oonf[ooo]Zo`3ko`Kooo]Z00Co0:?ook?o0?oonf[oW`3o0ooonfX02?l0omkooo]ZoookJ_oo
06cooo]Zodd0oooonf[oH@3o0ooonfX00ol0oi3ooo]Zo`3oTP08oookJP03oaP0oooVo`3ooo]Z00Oo
oo]Z00?ookh0o`3o1Om`0?l01?oonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00[ooo]Z00Oo0=Cooook
J_oonf[o08SooookJ_l0odko0?ld00Cooo]Z00?o0?l8oookJ_oonfX01_oonfX00ol@0?ooT_l0oook
JP0GoookJP03o`3Loooonf[ooo]Z00;ooe804_oonfX2o`3Lo`;ooo]Z1?l0000:oookJP03oa00oooo
nf[ooo]Z00Gooo]Z00?o0?m>oookJ_l0e?l02?oonfX00om`0?oooo]ZoookJP03oookJP03oaP0oooo
nf[ooo]Z00;ooo]Z00?o0?nBoookJ_mQ0?l01?oonfX00onco`3ooo]ZoookJP04oookJP03oom/0?oo
nf[ooo]Z00;ooo]Z00Goo`3foookJ_lH0?oooo]Zool0o00FoookJP07oomB0?oonf[o02[ooookJ_l0
g?oooo]Zo`3og`03oookJP08o`3o6olB0?oooo]Zooo:0?oonf[o0?WooookJ_oo01<3oookJP04on7o
0?oonf[ooo]ZobH0o`cooo]Z00Ko0?mKoookJ_oonf[o0?n`oh;o0?l0<?l2oookJP05o`H0oooonf[o
T_l0ool0mOl@0?l01OoonfX00ooo057ooo]Zool0N@06oookJP06o`3oDooonf[ooo]Zo`3o7Ooonf[o
0>7o2?oonfX00ol0ocCooo]Zo`3oCP05oookJP03o`28ool0ZOoooo]Z00;ooo]Z00?o00Coo`3Doooo
nfX02ooonfX00oooP@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z02Wooo]Z000boookJP03o`1c
oooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01OoonfX00oooTP3ooo]ZoookJP02oookJP04ool0
o?oonf[ooo]ZoaP0o`;ooo]Z00Coo`H0oookJ_o[o`3oo`3f0_oonfX02Ol0Y_oooo]ZojP0oooonf[o
o`3ioookJ_l0Mooo0?nJoom/0002oookJP04oc_o0?oonf[ooo]Zo`3ko`Gooo]Z00CoN@3ooookJ_nc
o`3oobP00ooonfX01?l0omkogOl0oookJ_oo06`2oookJP05odd0oooonf[oH@3oool00?oonfX01?oo
0008oookJP03oaP0oooonf[ooo]Z00Oooo]Z00Cookh0ool00?oonf[oL03o0_oonfX00oooE`3ooo]Z
oookJP02oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?o0=Coo`04oooonfX02?ooN@000ooonf[oobP0
oookJP03oookJPGoiOl000?oT_l0onGo0?oUo`005ooonfX00ol0g?oooo]ZoookJP0;oolX00koo`00
1?ooN@05oookJPCoolT000?ooo]ZoolX0?oonfX00_oonfX01?l0odkooo]Zo`04ool0e?l7oookJPCo
ogT00_oonfX00ooVo`3o603ooookJP02oookJP04o`3oT_oonf[ooo]Zof40o`Gooo]Z00?o/ol0oook
J_oonfX00ooonfX2oolX00;ooo]Z2?oo:00DoookJP07oomB0?oonf[o02[ooookJ_l0g?oooo]Zo`3o
g`06ool000?oobP000?ooo]Zool04ooonfX00ooonfX01?oo:03ooo]ZoookJ_lV0?l<oookJP05o`3o
Fooonf[oP_l0o`3o/?l0<?l00ooonfX00ol60?ooT_l0odCo0005odCo0006oolX0?oo057oobP0oolX
0?oo07WoobP01OoonfX01Ol0oe?ooo]Zooo90?l0oago0>7o00Wooo]Z00?o0?ldonGo0?oonfX01Ooo
nfX01ol0ZOoooo]ZoookJ_oonf[o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP0:oookJP03
ool0;Ooonf[ooo]Z05Oooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP05oookJP03
oolF0?ooTP3ooo]Z00?ooo]Z00Koo`3loookJ_oonf[o603ooookJ_oo1P02oookJP0<on_o0?oo0?Ko
oo]Zo`2Voooonf[oZ03ooookJ_oo0?Wooo]Zo`1gool0oi[oof`00_oonfX01?lko`3ooo]ZoookJ_l0
nol6oookJP04ogT0oonco`3ooo]Zoil0o`?ooo]Z00So0?oNoookJ_oonf[oo`1/oookJ_m=0?oooo]Z
of40o`?ooo]Z00?o0?n@oookJ_l0oi802?oonfX00olH0?ooi_l0oookJP07oookJP04oonn0?l0o`Go
oo]Zog00o`?ooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@0:oookJP04o`3Doooonf[ooo]Zo`28o`;o
oo]Z00?o0?m>oookJ_oonfX00_oonfX00ol0o`Sooo]ZoookJP06oookJP03oa00oonBo`3ooo]Z01So
oo]Z0_l0g?l2oookJP;ooe802_oonfX4oomB00;o0=co1?oonfX4o`0000Wooo]Z00?o403ooookJ_oo
nfX01OoonfX01?l0odkooo]Zo`04ool0e?l8oookJP03og00oooonf[ooo]Z00;ooo]Z00?oi_l0oaP0
oooonfX00_oonfX01?l0oi;ooo]ZoookJ_mQ0?l4oookJP03ok?o0?oonf[ooo]Z00?ooo]Z00?oof`0
oookJ_oonfX00_oonfX00ooo0?Kooo]ZoaP0o`02oookJP03ool0o?oonf[ooo]Z01?ooo]Z00?ooe80
oookJ_l0:_l00_oonfX00ol0g?oo0?oOoookJP03oookJP03o`3o6olB0?ooolX000;ooo]Z00?o0?Wo
oookJ_oo01<00ooonfX01?oQo`3ooo]ZoookJ_lV0?l<oookJP06o`3oFooonf[ooo]Zoh;o0?oonf[o
033o0_oonfX01Ol60?oooo]Zoi;o0?oo0?Go403o00Gooo]Z00?oo`1Ao`2]oooo07T01_oonfX01_l0
oe?ooo]Zo`3o2?l0oagooo]Zo`3Qo`Sooo]Z00?o0?ldo`3oC_l0obh01OoonfX00ol0R?oo0:Wooook
JP02oookJP03o`04ool0e?oooo]Z00[ooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]Zoook
JP0YoookJP00<_oonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooi80
oookJ_oonfX00_oonfX01?oo0?cooo]ZoookJ_lH0?l3oookJP03ool60?o[o`3oo`3f00;ooo]Z00Wo
0:KooookJ_nX0?oooo]Zool0nOoonf[o07Ooo`3oV_ooK0000_oonfX01?lko`3ooo]ZoookJ_l0nol6
oookJP03ogT0oonco`3oobP000?ooo]Z00Wo0?oNomgo0?oonf[ooo]Zool0K?oonf[oC@3ooookJ_mQ
0?l01_oo0008oookJP03oaP0oooVo`3ooo]Z00Oooo]Z00Cookh0ool00?oo003oL03o0_oonfX00ooo
E`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?o0=Coo`04oooonfX02?ooN@000ooo
nf[o0?l8oookJP03oookJPGoiOl000?oT_l0oookJ_oonfX06?oonfX2o`3Lo`03oookJ_oo:03oobP0
00[oobP03Ooo00000ol0003ooo]ZoookJP05oookJP?oolT00_oonfX2oolX0005oookJ_l0odkooo]Z
oookJ_l0e?l02?oonfX3oomi00?ooo]Z00?oi_l0oaP0oooonfX00_oonfX01?l0oi;ooo]ZoookJ_mQ
0?l5oookJP03ok?o0?oonf[ooo]Z00?ooo]Z00CoobP0oookJ_oonf[ooo]Z2?oo:00DoookJP07oomB
0?oonf[o02[ooookJ_l0g?oooo]Zo`3og`08ool00003oolX0?oonf[oo`0C00Cooo]Z00CoobP0oook
J_lV0?oo8?l02ooonfX01_l0oe_ooo]ZoookJ_n2o`3ooo]Zo`0`o`?ooo]Z00?o1P3ooi;o0?m4o`00
1Om4o`001_oo:03oo`1AoolX0?oo:03oo`1ioolX00Gooo]Z00Co0?mCoookJ_oob@3o0?lM2_oonfX0
0ol0ocCoiOl0oookJP05oookJP07o`2Yoooonf[ooo]ZoookJ_l01?oooo]Zo`3Do`0;oookJP03oon1
0?oonf[ooo]Z00Wooo]Z00?oo`0]oookJ_oonfX0F?oonfX00ol0Looooo]ZoookJP0BoookJP03ool0
j_oonf[ooo]Z00Gooo]Z00?ooaH0oonB0?oonfX00ooonfX01?oo0?cooo]ZoookJ_lH0?l2oookJP08
ool60?oonf[ojol0ool0m_oonf[o0:KooookJ_nX0?l2oookJP04ool0nOl0Mooo0?nJoom/00;ooo]Z
00Co>ol0oookJ_oonf[o0?_o1_oonfX01?mi0?oo/ol0oookJ_nO0?l3oookJP09o`3og_oonf[ooo]Z
ool0K?oonf[oC@3ooookJ_mQ0?oo0?m500;ooo]Z00Co0?n@oookJ_oonf[o0?nB1ooonfX00olH0?oo
07CoonKo0008oookJP03oonn0?l0o`GoL03o00?ooo]Z00GooeL0oookJ_oonf[ooo]Zool0;@0:oook
JP04o`3Doooonf[ooo]Zo`28o`;ooo]Z00?o0?m>oookJ_oonfX00_oonfX00ol0o`Sooo]ZoookJP06
oookJP03oa00oonBo`3ooo]Z01[ooo]Z00Co0=cooookJ_oonf[ooo]Z2_ooDP02oookJP;o0=co1_oo
nfX4o`0000Sooo]Z00?o403ooookJ_oonfX01OoonfX01?l0odkooo]ZoookJ_l0e?l8oookJP03og00
oooonf[ooo]Z00?ooo]Z00?oi_l0oaP0oooonfX00_oonfX01?l0oi;ooo]ZoookJ_mQ0?l4oookJP03
ok?o0?oonf[ooo]Z00?ooo]Z00?oof`0oookJ_oonfX00_oonfX01Ooo0?Kooo]ZoaP0oooonf[oo`3l
01Kooo]Z00?ooe80oookJ_l0:_l00_oonfX00ol0g?oo0?oOoookJP03oookJP03o`3o6olB0?ooolX0
00;ooo]Z00?o0?WooookJ_oo01<00ooonfX01?oQo`3ooo]ZobH0oolPo`0;oookJP06o`3oFooonf[o
oo]Zo`3o/?n2o`3o033o0ooonfX01Ol60?oooo]Zoi;o0?oonf[o403o00Gooo]Z00?oo`1Ao`2]oooo
07T01_oonfX01Ol0oe?ooo]Zo`3o2?l0oago0>7o00Wooo]Z00?o0?ldo`3oC_l0obh01OoonfX00ol0
ZOoooo]ZoookJP02oookJP03o`04ool0e?oooo]Z00[ooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo
02gooo]ZoookJP0ZoookJP00<_oonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Go
oo]Z00?ooi80oookJ_oonfX00_oonfX01?oo0?cooo]ZoookJ_lH0?l3oookJP03ool60?o[o`3oo`3f
00;ooo]Z00Wo0:KooookJ_nX0?oooo]Zool0nOoonf[o07Ooo`3oV_ooK0000_oonfX01?lko`3ooo]Z
oookJ_l0nol6oookJP03ogT0oonco`3oobP000?ooo]Z00Wo0?oNomgo0?oonf[ooo]Zool0K?oonf[o
C@3ooookJ_mQ0?l01ooo0007oookJP03oaP0oooVo`3ooo]Z00Sooo]Z00?ookh0ool00?m`0?l00ooo
nfX01OooE`3ooo]ZoookJ_oonf[oo`0]00[ooo]Z00?o0=Coo`04ooooN@002?ooN@000ooonf[o0?l8
oookJP02oookJP?oiOl000?ooo]Zoa00oooonfX00_oo000JoookJP;o0=co2ooo:004oomi0003oook
J_oo003oo`0000Koo`0000?o0000oookJ_oonfX01?oonfX2ooo900?ooo]Z1?oo:0001?l0odkooo]Z
o`04ool0e?l7oookJP?oogT00ooonfX00ooVo`3o603ooookJP02oookJP05o`3oT_oonf[ooo]Zoook
J_mQ0?l01?oonfX00onco`3ooo]ZoookJP04oookJP04oom/0?oonf[ooo]ZoookJPOoobP05OoonfX0
1?ooDP3ooo]Zo`0Zool0g?l2oookJP03o`3ogooo003oo`0000Ooo`0000?oo`0CoookJ_oonfX00_oo
nfX01Ooo:03ooo]ZoookJ_lV0?oo8?l000_ooo]Z00Go0?mKoookJ_oonf[oP_l0o`0`o`03oookJP03
o`H0oooonf[oolT000GoA?l000Kooo]Zool0DOoo:03oobP0ool0NOoo:005oookJP05o`3oDooonf[o
oo]Zooo90?l0oad02_oonfX00ol0ocCoiOl0oookJP05oookJP07o`2Yoooonf[ooo]ZoookJ_l01?oo
oo]Zo`3Do`0;oookJP03oon10?oonf[ooo]Z00Wooo]Z00?oo`0]oookJ_oonfX0F?oonfX00ol0Looo
oo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooaH0oonB0?oonfX00ooonfX01?oo0?co
oo]ZoookJ_lH0?l2oookJP08ool60?oonf[ojol0ool0m_oonf[o0:KooookJ_nX0?l2oookJP04ool0
nOl0Mooo0?nJoom/00;ooo]Z00Co>ol0oookJ_oonf[o0?_o1_oonfX01?mi0?oo/ol0oookJ_nO0?l3
oookJP09o`3og_oonf[ooo]Zool0K?oonf[oC@3ooookJ_mQ0?oo0?m500?ooo]Z00?o0?n@oookJ_l0
oi801ooonfX00olH0?oo07CoonKo0008oookJP03oonn0?l0o`GoL03o00Cooo]Z00CooeL0oookJ_oo
nf[oo`0]2ooonfX01ol0e?oooo]ZoookJ_l0R?oooo]Zo`3oC_l0oc@01?oonfX00ol0o`Sooo]Zoook
JP06oookJP03oa00oonBo`3ooo]Z01[ooo]Z1Ol0g?l6oookJPCo0=co2?oonfX4o`0000Oooo]Z00?o
403ooookJ_oonfX01_oonfX01?l0odkooo]Zo`04ool0e?l8oookJP03og00oooonf[ooo]Z00;ooo]Z
00?oi_l0oaP0oooonfX00_oonfX01?l0oi;ooo]ZoookJ_mQ0?l4oookJP03ok?o0?oonf[ooo]Z00Co
oo]Z00Goof`0oookJ_oonf[ooo]Zool0mP02oookJP03oaP0oooonf[oo`3l01Kooo]Z00Oooe80oook
J_l0:_oooo]Zo`3Loooonf[o0?oO00?ooo]Z00So0?lKoa80oooonf[oolX0oookJ_l0nOoooo]Zool0
4`?ooo]Z00GohOl0oookJ_oonf[o9P3oob3o000;oookJP06o`3oFooonf[ooo]Zo`3o/?n2o`3o033o
0_oonfX01_l60?oooo]ZoookJ_nBo`3ooo]Zoa00o`Cooo]Z00Coo`1AoookJ_l0[Oooo`1i1OoonfX0
1_l0oe?ooo]ZoookJ_l0o`So0?lMo`3Qo`Wooo]Z00?o0?ldo`3oC_oonfX01OoonfX00ol0ZOoooo]Z
oookJP02oookJP03o`04ool0e?oooo]Z00[ooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]Z
oookJP0ZoookJP00<_oonfX00ol0Looooo]ZoookJP0CoookJP03ool0j_oonf[ooo]Z00Cooo]Z00?o
oi80oookJ_oonfX00_oonfX01?oo0?cooo]ZoookJ_lH0?l3oookJP0>ool60?o[o`3ooo]Zool0m_oo
nf[o0:KooookJ_nX0?oooo]Zool0nOoonf[o07Ooo`3oV_ooK003oookJP03oc_o0?oonf[o0?_o00Ko
oo]Z00?oN@3ook?o0?oo:0000ooonfX02Ol0omkogOl0oookJ_oonf[oo`1/oookJ_m=0?oooo]Zof40
o`07ool000Sooo]Z00?o603ooookJ_oonfX01ooonfX00ooo_P3oo`00og00o`03oookJP05oomG0?oo
nf[ooo]ZoookJ_oo02d02_oonfX00ol0e?oo00Cooomi0005oomi00;oo`000_oonfX01Ol0o`Sooo]Z
oookJ_oonf[oiOl000Cooo]Z00Co403oool00?oo003oo`007?oonfX9oolX00_ooo]Z1?l00006oook
JP03ooo90?oonf[ooo]Z00;ooo]Z1Ooo:0000ol01?oo0=CooookJP07oookJP;oogT01?oonfX00ooV
o`3o603ooookJP02oookJP04o`3oT_oonf[ooo]Zof40o`Gooo]Z00?o/ol0oookJ_oonfX00ooonfX0
0oooK03ooo]ZoookJP02oookJPGoobP000?oo`3loookJ_oonfX05?oonfX01oooDP3ooo]Zo`0Zool0
g?oooo]Zo`3ogooonfX01ooo00000ooo:03oo`00ool04`04oookJP04oolX0?oonf[ooo]ZobH0o`co
oo]Z00Go0?mKoookJ_oonf[oP_l0o`0`o`03oookJP03o`H0oooonf[oolT000GoA?l000Kooo]Zool0
DOoo:03oobP0ool0NOoo:005oookJP05o`3oDooonf[ooo]Zooo90?l0oad02_oonfX00ooUo`3o0?l^
oookJP04oookJP03o`28ool0ZOoooo]Z00;ooo]Z00?o00CooookJ_l0e?l02ooonfX00oooP@3ooo]Z
oookJP09oookJP03ool0;Ooonf[ooo]Z05Sooo]Z00?o07?ooookJ_oonfX04ooonfX00ooo0>[ooo]Z
oookJP04oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00Coo`3loookJ_oonf[o603o0_oonfX02?oo1P3o
oo]Zon_o0?oonf[oo`3fo`2Voooonf[oZ03o0_oonfX01?oo0?Wo07Ooo`3oV_ooK003oookJP03oc_o
0?oonf[o0?_o00Kooo]Z00CoN@3ook?o0?oonf[oW`3o0ooonfX02Ol0omkooo]ZoookJ_oo06cooo]Z
odd0oooonf[oH@3oo`3oA@03oookJP03o`3oT?oonf[o0?nB00Sooo]Z00?o603oonKo0?oonfX01ooo
nfX00ooo_P3o0?l5og00o`04oookJP05oomG0?oonf[ooo]ZoookJ_oo02d02_oonfX01ol0e?oooo]Z
oookJ_l0R?oooo]Zo`3oC_l0oc@01?oonfX00ol0o`Sooo]ZoookJP07oookJP03oi;o0?oonf[ooo]Z
01kooo]Z1_l0g?l<oookJPCo00001_oonfX00ol@0?oooo]ZoookJP06oookJP04o`3oC_oonf[o00Co
o`3Do`Wooo]Z00?oL03ooookJ_oonfX00_oonfX00ooVo`3o603ooookJP02oookJP04o`3oT_oonf[o
oo]Zof40o`Cooo]Z00?o/ol0oookJ_oonfX00ooonfX00oooK03ooo]ZoookJP02oookJP03ool0m_oo
nf[o603o00;ooo]Z00?oo`3loookJ_oonfX05?oonfX01oooDP3ooo]Zo`0Zoooonf[o0=cooookJ_l0
oml00ooonfX02?l0oa_o4P3ooookJ_oobP3ooo]Zo`3ioooonf[oo`0C0ooonfX01?oQo`3ooo]Zoook
J_lV0?l<oookJP06o`3oFooonf[ooo]Zo`3o/?n2o`3o033o0_oonfX01_l60?oooo]ZoookJ_nBo`3o
oo]Zoa00o`Cooo]Z00Coo`1AoookJ_l0[Oooo`1i1OoonfX01_l0oe?ooo]ZoookJ_l0o`So0?lMo`3Q
o`Wooo]Z00?o0?ldo`3oC_oonfX01OoonfX00ol0ZOoooo]ZoookJP02oookJP03o`04ool0e?oooo]Z
00[ooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP0ZoookJP00<_oonfX00ol0Looo
oo]ZoookJP0CoookJP03ool0j_oonf[ooo]Z00Cooo]Z00?ooi80oookJ_oonfX00_oonfX01Ooo0?co
oo]ZoookJ_oonf[o603o00;ooo]Z00Soo`H0on_o0?oonf[oo`3foookJ_l0Y_oooo]ZojP0o`;ooo]Z
00Coo`3io`1goooonf[oof`00ooonfX00olko`3ooo]Zo`3ko`06oookJP03ogT0ool0Xooo/ol000?o
oo]Z00[o0?oNomgo0?oonf[ooo]Zool0K?oonf[oC@3ooookJ_oo003oH@3o1ooo0007oookJP03oaP0
oooonf[ooo]Z00Oooo]Z00Cookh0ool00?oo003oL03o0_oonfX01OooE`3ooo]ZoookJ_oonf[oo`0]
00[ooo]Z00Go0=Coo`04ooooN@3oogT0oookJP02ool00004oomi0?oo003oo`00ool000;ooo]Z00?o
0?l8oookJ_oonfX01OoonfX00ol@0?oooo]Zool00002ool001gooo]Z1ooo:00;oookJPCo00001?oo
nfX00ol@0?ooolT0oookJP03oookJPOoobP000?o0=CooookJ_oonfX01_oonfX00oooN@3ooo]Zoook
JP02oookJP03onKo0?lH0?oooo]Z00;ooo]Z00Go0?nBoookJ_oonf[ooo]Zof40o`04oookJP03ok?o
0?oonf[ooo]Z00Cooo]Z00?oof`0oookJ_oonfX00_oonfX4oolX0003ool0o?oo:03ooo]Z00cooo]Z
00?oo`00oookJ_oonfX01OoonfX02?ooDP3ooo]Zo`0Zoooonf[o0=cooookJ_l0omoooo]Z2?oo0000
0ooonf[oo`0CoookJP03oookJP04oolX0?oonf[ooo]ZobH0o`cooo]Z00Go0?mKoookJ_n2o`3ooo]Z
o`0`o`03oookJP03o`H0oooo003oolT000GoA?l000Gooo]Zool0DOoo:03oobP0ool0N@06oookJP05
o`3oDooonf[oolT0o`3o7Ol0hOl02OoonfX00ol0ocCoiOl0oookJP05oookJP03o`2Yoooonf[ooo]Z
00;ooo]Z00?o00Coo`3DoooonfX02ooonfX00oooP@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z
05Sooo]Z00?o07?ooookJ_oonfX04ooonfX00ooo0>[ooo]ZoookJP04oookJP03oolF0?ooTP3ooo]Z
00?ooo]Z00koo`3loookJ_oonf[ooo]ZoaP0oooonf[oo`H0oookJ_o[o`3ooo]Zool0m_l0Y_oooo]Z
ojP0o`;ooo]Z00Coo`3io`1goooonf[oof`00ooonfX00olko`3ooo]Zo`3ko`06oookJP04ogT0ool0
Xooo/ol0oil0o`?ooo]Z00Ko0?oNoookJ_oonf[oo`1/oookJ_m=0?l2oookJP07of40oooonf[ooo]Z
oookJ_l0oi3ooo]Zo`3oTP08oookJP03oaP0oooVo`3ooo]Z00Oooo]Z00Cookh0oookJ_l0o`GoL03o
0ooonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00[ooo]Z00Co0=Coo`04oooonf[o08So0_oonfX00ol0
odkooo]ZoookJP03oookJP03o`3o2?oonf[ooo]Z00Kooo]Z00?o403ooi;o0?oonfX0<?oonfX4o`00
00Cooo]Z0_l@0?l8oookJP05o`3oC_oonf[o00CooookJ_l0e?l02?oonfX00om`0?oooo]ZoookJP02
oookJP03onKo0?lH0?oooo]Z00;ooo]Z00Go0?nBoookJ_oonf[ooo]Zof40o`03oookJP03ok?o0?oo
nf[ooo]Z00Cooo]Z00?oof`0oookJ_oonfX00_oonfX01Ooo0?Kooo]ZoaP0oooonf[oo`3l00oooo]Z
00?o07?ooookJ_oonfX01?oonfX00oooDP3ooo]Zo`0Zo`02oookJP03o`3Lool0omoooo]Z00?ooo]Z
00?o0?lKoa80oooobP000_oonfX00ol0nOoooo]Zool04`03oookJP04on7o0?oonf[ooo]ZobH0o`co
oo]Z00Ko0?mKoookJ_l0ok3oP_l0oookJ_l0<?l2oookJP05o`H0oooonf[oo`3eoi;o0?l@0?l01Ooo
nfX00ooo057ooo]Zool0N@06oookJP06o`3oDooonf[o0?l8o`3o7Ooonf[o0>7o2?oonfX00ol0ocCo
oo]Zo`3oCP05oookJP03o`28ool0ZOoooo]Z00?ooo]Z00?o0=CooookJ_oonfX02_oonfX00oooP@3o
oo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z02[ooo]Z000coookJP03o`1coooonf[ooo]Z01;ooo]Z
00?oo`3ZoookJ_oonfX01?oonfX00oooTP3ooo]ZoookJP02oookJP05ool0o?oonf[ooo]ZoookJ_lH
0?l00_oonfX02?oo1P3ooo]Zon_o0?oo0?Kooo]Zo`2Voooonf[oZ03o0_oonfX01?oo0?Wo07Oooook
J_ooK003oookJP04oc_o0?oonf[ooo]Zo`3ko`Gooo]Z00?oN@3ooookJ_nco`000ooonfX02_l0omko
gOl0oookJ_oonf[oo`1/oookJ_m=0?oooo]Zool00?mQ0?l7ool000Oooo]Z00?o603ooookJ_oonfX0
1ooonfX01?oo_P3oo`00ool00?m`0?l2oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oo
nfX02?oonfX01?l0e?oo00CooookJ_l0R?l2ool00004oomi0?oo003oo`00ool000;ooo]Z00?o0?l8
oookJ_oonfX01_oonfX00ol@0?ooo`00ool00002ool001gooo]Z1Ooo:00<oookJPCo00000ooonfX0
0ol@0?oooo]ZoookJP03oookJPWoobP02?oonfX00om`0?oooo]ZoookJP02oookJP03onKo0?lH0?oo
oo]Z00;ooo]Z00Co0?nBoookJ_oonf[oH@3o1OoonfX00onco`3ooo]ZoookJP03oookJP03oom/0?oo
nf[ooo]Z00;ooo]Z1Ooo:0000ooo0?cooo]ZoookJP0<oookJP03ool00?oonf[ooo]Z00Gooo]Z00So
oe80oookJ_l0:_oooo]Zo`3Loooonf[o0?oOoookJPKoo`0000CoobP0ool00?oonf[oo`0C0ooonfX0
1Ooo:03ooo]ZoookJ_lV0?oo8?l000_ooo]Z00Ko0?mKoookJ_oonf[oP_l0oookJ_l0<?l2oookJP04
o`H0oooonf[oolT0oookJPCoA?l00_oonfX01?oo057oobP0oolX0?oo07T6oookJP05o`3oDooonf[o
olT0o`3o7Ol0hOl02OoonfX00ol0ocCoiOl0oookJP05oookJP07o`2Yoooonf[ooo]ZoookJ_l01?oo
oo]Zo`3Do`0<oookJP03oon10?oonf[ooo]Z00Sooo]Z00?oo`0]oookJ_oonfX0F_oonfX00ol0Looo
oo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Cooo]Z00?ooaH0oonB0?oonfX00ooonfX03_oo0?co
oo]ZoookJ_oonf[o603ooookJ_oo1P3ooo]Zon_o0?oonf[oo`3fo`2Voooonf[oZ03o0_oonfX01?oo
0?Wooo]Zo`1gooooK003oookJP04oc_o0?oonf[ooo]Zo`3ko`Kooo]Z00?oN@3ook?o0?nO0?l00ooo
nfX01_l0omkooo]ZoookJ_oonf[oo`1/odd0o`;ooo]Z00OoH@3oo`3oAOoonf[ooo]Zo`3oT?oonf[o
0?nB00Sooo]Z00?o603oonKo0?oonfX02?oonfX00ooo_P3o0?l5og00o`03oookJP05oomG0?oonf[o
oo]ZoookJ_oo02d02ooonfX01ol0e?oooo]ZoookJ_l0R?oooo]Zo`3oC_l0oc@01OoonfX00ol0o`So
oo]ZoookJP06oookJP03oa00oonBo`3ooo]Z02oooo]Z1?l00003oookJP03oa00oooonf[ooo]Z00So
oo]Z00Co0?m>o`04oooonf[o0=Co2OoonfX00om`0?oooo]ZoookJP02oookJP03oaP0oooonf[ooo]Z
00;ooo]Z00Co0?nBoookJ_oonf[oH@3o1?oonfX00onco`3ooo]ZoookJP03oookJP03oom/0?oonf[o
oo]Z00;ooo]Z00Koo`3foookJ_oonf[o603ooookJ_oo0?`?oookJP03o`1coooonf[ooo]Z00Cooo]Z
00?ooe80oookJ_l0:_l00_oonfX00ol0g?oo0?oOoookJP03oookJP03o`3o6ooonf[oolX000;ooo]Z
00?o0?WooookJ_oo01<00_oonfX01OoQo`3ooo]ZoookJ_lV0?oo8?l000_ooo]Z00Wo0?mKoookJ_oo
nf[o0?n`oh;o0?oonf[o033ooookJ_l60?l00_oonfX00onBo`3ooo]Zoa00o`05oookJP03ool0DOoo
nf[oo`1i00Kooo]Z00Ko0?mCoookJ_l0o`So0?lMoookJ_l0hOl8oookJP03o`3o=?l0odko0?l^00Go
oo]Z00?o08Soo`2YoooonfX00_oonfX00ol01?oo0=CooookJP0;oookJP03oon10?oonf[ooo]Z00So
oo]Z00?oo`0]oookJ_oonfX0:ooonfX003?ooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]Z
oookJP04oookJP03oonB0?oonf[ooo]Z00;ooo]Z00Goo`3loookJ_oonf[ooo]ZoaP0o`02oookJP08
ool60?oonf[ojol0ool0m_oonf[o0:KooookJ_nX0?l2oookJP04ool0nOl0Mooooo]Zoom/00?ooo]Z
00Co>ol0oookJ_oonf[o0?_o1OoonfX00omi0?oooo]Zok?o0004oookJP09o`3og_oonf[ooo]Zool0
K?oonf[oC@3ooookJ_oo003oH@3o00Ooo`001ooonfX00olH0?ooi_l0oookJP07oookJP07ool00?oo
_P3oo`00og00oooo003ooo]ZoomG0004oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00Co0=Coo`04oooo
nf[o08So0_oo00000ol0odkoo`00ool00002ool000;ooo]Z00?o0?l8oookJ_oonfX01_oonfX00ol@
0?ooo`00ool00002ool001gooo]Z1?oo:00<oookJPCo00000_oonfX00ol@0?oooo]ZoookJP04oook
JPOoobP02OoonfX00om`0?oooo]ZoookJP02oookJP03onKo0?lH0?oooo]Z00;ooo]Z00Go0?nBoook
J_oonf[ooo]Zof40o`04oookJP03ok?o0?oonf[ooo]Z00Cooo]Z00?oof`0oookJ_oonfX00_oonfX4
oolX0003ool0o?oonf[ooo]Z00cooo]Z00?oo`00oookJ_oonfX01_oonfX01?ooDP3ooo]Zo`0Zool0
g?l2oookJP03o`3ogooonf[oo`0000Goo`0000?ooo]Zool00?oo01<01?oonfX01?oo:03ooo]Zoook
J_lV0?l<oookJP06o`3oFooonf[ooo]Zoh;o0?oonf[o033o0_oonfX01?l60?oooo]Zooo90?oonfX4
odCo0003oookJ_oo057ooo]Z00;oobP000?oo`1ioookJ_oonfX00ooonfX01Ol0oe?ooo]ZoookJ_oo
b@3o0?lM00[ooo]Z00?o0?ldonGo0?oonfX01OoonfX01ol0ZOoooo]ZoookJ_oonf[o00CooookJ_l0
e?l03?oonfX00oooP@3ooo]ZoookJP08oookJP03ool0;Ooonf[ooo]Z05[ooo]Z00?o07?ooookJ_oo
nfX04_oonfX00ooo0>[ooo]ZoookJP04oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00koo`3loookJ_oo
nf[ooo]ZoaP0oooonf[oo`H0oookJ_o[o`3ooo]Zool0m_l0Y_oooo]ZojP0o`;ooo]Z00Coo`3ioook
J_l0Moooof`00ooonfX01?lko`3ooo]ZoookJ_l0nol6oookJP03ogT0oonco`3oW`3o00?ooo]Z00Ko
gOl0o`3og_oonf[ooo]Zool0K?m=0?l2oookJP05of40ool0odGooo]ZoookJ_l0oi000_oonfX00ol0
oi;ooo]ZoookJP05oookJP03oaP0ool0M?ooi_l000Sooo]Z00?ookh0o`3o1Om`0?l00ooonfX01Ooo
E`3ooo]ZoookJ_oonf[oo`0]00_ooo]Z00Oo0=Coo`04oooonf[o08SooookJ_l0odko0?ld00Gooo]Z
00?o0?l8oookJ_oonfX01_oonfX00ol@0?oooo]Zoi;o000_oookJPCo00000_oonfX00ol@0?oooo]Z
oookJP08oookJP04o`3oC_l01?oooo]Zo`3Do`Wooo]Z00?oL03ooookJ_oonfX00_oonfX00ooVo`3o
603ooookJP02oookJP05o`3oT_oonf[ooo]ZoookJ_mQ0?l00ooonfX00onco`3ooo]ZoookJP04oook
JP03oom/0?oonf[ooo]Z00;ooo]Z00Goo`3foookJ_lH0?oooo]Zool0o00?oookJP03o`1coooonf[o
oo]Z00Gooo]Z00Oooe80oookJ_l0:_oooo]Zo`3Loooonf[o0?oO00?ooo]Z00So0?lKoa80oooonf[o
olX0oookJ_l0nOoooo]Zool04`?ooo]Z00CohOl0oookJ_oonf[o9P3o3?oonfX02Ol0oe_ooo]Zoook
J_l0ok3oP_l0oookJ_l0<?oooo]Zo`H0o`02oookJP03oi;o0?oonf[o403o00Cooo]Z00Coo`1Aoook
J_oonf[oo`1i1OoonfX01_l0oe?ooo]ZoookJ_l0o`So0?lMo`3Qo`Wooo]Z00?o0?ldo`3oC_l0obh0
1OoonfX00ol0ZOoooo]ZoookJP02oookJP03o`04ool0e?oooo]Z00_ooo]Z00?ooh40oookJ_oonfX0
2?oonfX00ooo02gooo]ZoookJP0[oookJP00<ooonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oo
nf[ooo]Z00Cooo]Z00?ooi80oookJ_oonfX00_oonfX01Ooo0?cooo]ZoookJ_oonf[o603o00;ooo]Z
00Soo`H0oookJ_o[o`3oo`3foookJ_l0Y_oooo]ZojP0o`;ooo]Z00Coo`3io`1goooonf[oof`00ooo
nfX01?lko`3ooo]ZoookJ_l0nol5oookJP03ogT0oooonf[o/ol000Cooo]Z00Ko0?oNoookJ_oonf[o
o`1/oookJ_m=0?l2ool00003of40oooo003oo`0000Koo`001_oonfX00olH0?ooi_l0oookJP08oook
JP03oonn0?oo003oL03o00;oo`0000?ooo]ZoomG0?oonfX00_oonfX00ooo02gooo]ZoookJP09oook
JP03o`3Dool01?oooo]Z00?oo`0000?o0?m>ool00?oo00000_oo00000ooonf[o0?l8oookJP08oook
JPKoo`007?oonfX3oolX00cooo]Z1?l00002oa00o`Kooo]Z1ooo:009oookJP03og00oooonf[ooo]Z
00?ooo]Z00Go603ooookJ_oonf[ooo]Zo`3oTP03oookJP03of40oooonf[ooo]Z00?ooo]Z00?o/ol0
oookJ_oonfX00ooonfX00oooK03ooo]ZoookJP03oookJPCoobP000?oo`3loookJ_oonfX03?oonfX0
0ooo003ooo]ZoookJP05oookJP05oomB0?l0oc?o02[ooookJ_l0g?l00_oonfX00ol0omoooo]Zool0
0004ool00004oolX0?oo003oo`00ool04`Cooo]Z00CoobP0oookJ_oonf[o9P3o3?oonfX01Ol0oe_o
oo]Zoh;o0?l0ok3o033o00?ooo]Z00Co1P3oool00?oob@3ooo]Z0om4o`02oookJP05ool0DOoonf[o
obP0oolX0?oo07T01OoonfX01Ol0oe?ooo]ZoookJ_oob@3o0?lM00[ooo]Z00?oiOl0o`3o;_oonfX0
1OoonfX01ol0ZOoooo]ZoookJ_oonf[o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP09oook
JP03ool0;Ooonf[ooo]Z05[ooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP04oook
JP03oolF0?ooTP3ooo]Z00?ooo]Z00Ooo`3loookJ_oonf[ooo]ZoaP0oooonf[oo`H000;ooo]Z00?o
jol0ool0m_l0Y_l00_oonfX01_nX0?oooo]Zool0nOoonf[o07Oooom/00?ooo]Z00Co>ol0oookJ_oo
nf[o0?_o1_oonfX00omi0?oo/ol0oil0o`03oookJP06omgo0?l0omkooo]ZoookJ_oo06coC@3o0_oo
nfX01OmQ0?oo0?m5oookJ_oonf[o0?n@00;ooo]Z00?o0?nBoookJ_oonfX01OoonfX00olH0?oo07Co
onKo0008oookJP03oonn0?oonf[oL03o00Cooo]Z00CooeL0oookJ_oonf[oo`0]3?oonfX01_l0e?oo
oo]ZoookJ_l0R?oooo]Zo`3oCPKooo]Z00?o0?l8oookJ_oonfX01_oonfX00ol@0?oooo]Zoi;o000^
oookJPCo000000?ooo]Zoa00oooonfX02OoonfX01?l0odkooo]Zo`04ool0e?l9oookJP03og00oooo
nf[ooo]Z00?ooo]Z00Go603ooookJ_oonf[ooo]Zo`3oTP03oookJP03of40oooonf[ooo]Z00;ooo]Z
00?o/ol0oookJ_oonfX00ooonfX00oooK03ooo]ZoookJP03oookJP05ool0m_oonf[o603ooookJ_oo
0?`03ooonfX00ol0Looooo]ZoookJP04oookJP03oomB0?l0oc?o02[o00;ooo]Z00?o0=cooookJ_l0
oml00ooonfX02?l0oa_o4P3ooookJ_oobP3ooo]Zo`3ioooonf[oo`0C0ooonfX01?oQo`3ooo]Zoook
J_lV0?l<oookJP06o`3oFooonf[ooo]Zoh;o0?oonf[o033o0_oonfX01_l60?oooo]Zool0mOnBo`3o
oo]Zoa00o`Cooo]Z00Coo`1AoookJ_l0[Oooo`1i1OoonfX01_l0oe?ooo]ZoookJ_l0o`So0?lMo`3Q
o`Wooo]Z00?o0?ldo`3oC_l0obh01OoonfX00ol0ZOoooo]ZoookJP02oookJP03o`04ool0e?oooo]Z
00[ooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP0[oookJP00<ooonfX00ol0Looo
oo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Cooo]Z00?ooi80oookJ_oonfX00_oonfX01Ooo0?co
oo]ZoookJ_oonf[o603o00;ooo]Z00Soo`H0oookJ_o[o`3oo`3foookJ_l0Y_oooo]ZojP0o`;ooo]Z
00Coo`3io`1goooonf[oof`00ooonfX01?lko`3ooo]ZoookJ_l0nol5oookJP03ogT0oooonf[o/ol0
00Cooo]Z00Ko0?oNoookJ_oonf[oo`1/oookJ_m=0?l2ool00003of40oooo003oo`0000?oo`0000?o
oo]Zo`3oT_oonfX01_oonfX00olH0?ooi_l0oookJP08oookJP03oonn0?oo003oL03o00;oo`0000?o
oo]ZoomG0?oonfX00_oonfX00ooo02gooo]ZoookJP09oookJP03o`3Dool01?oooo]Z00?oo`0000?o
0?m>ool00?oonfX01?oonfX00ol0o`Sooo]ZoookJP06oookJPOoo`007?oonfX00ooo:03ooo]Zoook
JP0;oookJP?o000000?o403oo`000?oonfX01_oonfX5oolX0003o`3Doooonf[ooo]Z00Sooo]Z00?o
L03ooookJ_oonfX00_oonfX00ooVo`3o603ooookJP02oookJP04o`3oT_oonf[ooo]Zof40o`Gooo]Z
00?o/ol0oookJ_oonfX01?oonfX00oooK03ooo]ZoookJP02oookJP03ool0m_oo:03oobP000;oobP0
00?oo`3loookJ_oonfX03?oonfX00ooo003ooo]ZoookJP05oookJP07oomB0?oonf[o02[ooookJ_l0
g?oooo]Zo`3og`02oookJPSoo`0000Goo`0Cool00?oo003ooo]ZoolX0002oookJP03obH0oolPo`3o
oo]Z00_ooo]Z00Go0?mKoookJ_n2o`3ooo]Zo`0`o`03oookJP04o`H0oooob@3ooo]ZoookJP?oA?l0
0_oonfX01?oo057ooo]ZoolX0?oo07T6oookJP05o`3oDooonf[ooo]Zooo90?l0oad02_oonfX00ooU
o`3o0?l^oookJP04oookJP05o`2Yoooob@3ooo]ZoookJ_l01?l00_oonfX00ol0e?oooo]ZoookJP09
oookJP03oon10?oonf[ooo]Z00Wooo]Z00?oo`0]oookJ_oonfX0F_oonfX00ol0Looooo]ZoookJP0B
oookJP03ool0j_oonf[ooo]Z00Cooo]Z00?ooaH0oonB0?oonfX00ooonfX01ooo0?cooo]ZoookJ_oo
nf[o603ooookJ_oo1P000_oonfX01_o[o`3oo`3foookJ_l0Y_oooo]ZojP0o`;ooo]Z00?oo`3io`1g
ooooK0000ooonfX01?lko`3ooo]ZoookJ_l0nol6oookJP03ogT0oonco`3oW`3o00?ooo]Z00KogOl0
o`3og_oonf[ooo]Zool0K?m=0?l2oookJP03of40ool0odGooo]Z00;ooo]Z00?o0?n@oookJ_l0oi80
1ooonfX00olH0?oo07CoonKo0009oookJP03oonn0?m`0?oooo]Z00?ooo]Z00GooeL0oookJ_oonf[o
oo]Zool0;@0;oookJP07o`3Dool01?oooo]Zo`28oooonf[o0?m>o`3o=005oookJP03o`3o2?oonf[o
oo]Z00Oooo]Z00?o403ooi;o0?oonfX0;OoonfX4o`000003oa00oooonf[ooo]Z00Sooo]Z00Co0?m>
oookJ_l01?oo0=Co2OoonfX00om`0?oooo]ZoookJP03oookJP03onKo0?lH0?oooo]Z00;ooo]Z00Co
0?nBoookJ_oonf[oH@3o1?oonfX00onco`3ooo]ZoookJP04oookJP03oom/0?oonf[ooo]Z00;ooo]Z
00Koo`3foookJ_oonf[o603ooookJ_oo0?`>oookJP03o`1coooonf[ooo]Z00Gooo]Z00?ooe80oook
J_l0:_l00_oonfX00ol0g?oo0?oOoookJP03oookJP08o`3o6ooonf[ooo]Zooo:0?oonf[o0?Wooook
J_oo01<2oookJP05on7o0?oonf[ooo]ZobH0oolPo`003?oonfX01_l0oe_ooo]Zo`3o/?n2o`3ooo]Z
o`0`o`;ooo]Z00?o1P3ooookJ_nBo`000_oonfX00ol@0?oooo]ZoookJP02oookJP04ool0DOoonf[o
0:goool0N@Gooo]Z00Ko0?mCoookJ_oonf[o0?l8o`3o7Ol0hOl9oookJP03o`3o=?l0odkooo]Z00Go
oo]Z00Oo0:WooookJ_oonf[ooo]Zo`04oooonf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02OoonfX0
0ooo02gooo]ZoookJP0[oookJP00<ooonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z
00Cooo]Z00?ooi80oookJ_oonfX00_oonfX01Ooo0?cooo]ZoookJ_oonf[o603o00;ooo]Z00Coo`H0
oookJ_o[o`3oo`3f0_oonfX02Ol0Y_ooZ03ooookJ_oonf[oo`3io`1goooonf[oof`0o`3oVP02oook
JP04oc_o0?oonf[ooo]Zo`3ko`Gooo]Z00CoN@3ooookJ_l0Xooo/ol00ooonfX02Ol0omkogOl0oook
J_oonf[oo`1/oookJ_m=0?ooo`00of40o`05ool00003oookJ_l0oi;ooo]Z00Kooo]Z00?o07CooaP0
oooonfX02?oonfX01?oo_P3oo`00ool00?m`0?l2ool00003oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]
oookJ_oonfX02?oonfX00ol0e?oo00CooookJP02ool000;ooo]Z00?o0?m>oookJ_oonfX00ooonfX0
0ol0o`Sooo]ZoookJP07oookJPOoo`00:OoonfX2o`000003oa00ool0003ooo]Z00Kooo]Z1Ooo:000
0ol0e?oooo]ZoookJP08oookJP03og00oooonf[ooo]Z00?ooo]Z00Go603ooookJ_oonf[ooo]Zo`3o
TP03oookJP03of40oooonf[ooo]Z00?ooo]Z00?o/ol0oookJ_oonfX01?oonfX00oooK03ooo]Zoook
JP02oookJP05ool0m_oo:03oobP0oolX0?oo0?`03_oonfX00ooo003ooo]ZoookJP06oookJP07oomB
0?l0:_oooo]ZoookJ_l0g?oooo]Zo`3og`02oookJPCoo`0000GoobP0ool00?oo003oo`00ool04`02
ool00005oookJ_oo:03ooo]ZoookJ_lV0?l03OoonfX01Ol0oe_ooo]Zoh;o0?oonf[o033o00;ooo]Z
00?o1P3ooookJ_oob@000_oonfX2odCo00;ooo]Z00Goo`1AoookJ_oonf[oobP0ool0N@05oookJP06
o`3oDooonf[ooo]Zooo90?oonf[o0?lM2_oonfX00ooUo`3ooo]ZoookJP04oookJP05o`2Yoooob@3o
oo]ZoookJ_l01?l00_oonfX00ol0e?oooo]ZoookJP09oookJP03oon10?oonf[ooo]Z00Sooo]Z00?o
o`0]oookJ_oonfX0FooonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Cooo]Z00?o
oaH0oonB0?oonfX00ooonfX01ooo0?cooo]ZoookJ_oonf[o603ooookJ_oo1P000_oonfX01_o[o`3o
o`3foookJ_l0Y_oooo]ZojP0o`;ooo]Z00Coo`3io`1gooooK03o0?nJ0_oonfX01?lko`3ooo]Zoook
J_l0nol6oookJP03ogT0ool0Xooo/ol000Cooo]Z00[o0?oNoookJ_oonf[oo`1/oookJ_m=0?oooo]Z
of40oooonf[o0?m50_oonfX00ol0oi3ooo]Zo`3oTP08oookJP03oaP0oooVo`3ooo]Z00Sooo]Z00?o
okh0o`3o1Om`0?l00ooonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00_ooo]Z00Co0=Coo`04oooonf[o
08So0_oonfX00ol0odkooo]ZoookJP04oookJP03o`3o2?oonf[ooo]Z00Kooo]Z00?o403ooookJ_nB
o`00;OoonfX3o`000003oa00oooonf[ooo]Z00Sooo]Z00Co0?m>oookJ_l01?oo0=Co2_oonfX00om`
0?oooo]ZoookJP03oookJP05oaP0oooonf[ooo]ZoookJ_l0oi800ooonfX00omQ0?oooo]ZoookJP02
oookJP03ok?o0?oonf[ooo]Z00Cooo]Z00?oof`0oookJ_oonfX00_oonfX01Ooo0?Kooo]ZoaP0oooo
nf[oo`3l00oooo]Z00?o07?ooookJ_oonfX01OoonfX00oooDP3ooo]Zo`0Zo`02oookJP03o`3Lool0
omoooo]Z00?ooo]Z00Go0?lKoookJ_oobP3ooo]Zo`3io`02oookJP04ool04ooonf[ooo]Zon7o00;o
oo]Z00?o9P3ooookJ_oonfX02ooonfX02?l0oe_ooo]Zo`3o/?n2o`3ooo]Zo`0`oooonf[o1P3o0_oo
nfX01?nBo`3ooo]ZoookJ_l@0?l3oookJP04ool0DOoonf[ooo]Zool0N@Gooo]Z00Oo0?mCoookJ_oo
nf[o0?l8oookJ_l0oago0>7o00Wooo]Z00?o0?ldo`3oC_oonfX01OoonfX01ol0ZOoooo]ZoookJ_oo
nf[o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP08oookJP03ool0;Ooonf[ooo]Z02cooo]Z
000coookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01?oonfX00oooTP3ooo]Zoook
JP02oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Ko603ooookJ_oo1P3ooo]Zon_o0?oo0?H2oookJP09
o`2VoonX0?oooo]ZoookJ_oo0?Wooo]Zo`1gooooK03o0?nJ00;ooo]Z00Co>ol0oookJ_oonf[o0?_o
1OoonfX01?mi0?oooo]Zo`2Soonco`04oookJP08o`3og_oonf[ooo]Zool0K?oonf[oC@3oool00?mQ
0?l5ool00003oookJ_l0oi;ooo]Z00Oooo]Z00?o603ooookJ_oonfX01ooonfX01?oo_P3oo`00ool0
0?m`0?l2ool00003oookJ_ooE`3ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX02OoonfX01?l0e?oo00Co
oookJ_l0R?l2oookJP03o`3oC_oonf[ooo]Z00Cooo]Z00?o0?l8oookJ_oonfX01_oonfX8ool002So
oo]Z00Co0000oa00ool0003o00001_oonfX01oooN@3oobP0oolX0?oo:03ooo]Zo`04ool0e?l02Ooo
nfX00om`0?oooo]ZoookJP03oookJP03onKo0?lH0?oooo]Z00;ooo]Z00Co0?nBoookJ_oonf[oH@3o
1OoonfX00onco`3ooo]ZoookJP04oookJP03oom/0?oonf[ooo]Z00;ooo]Z00?oo`3foookJ_oo:000
0_oo:0000ooo0?cooo]ZoookJP0<oookJP03ool00?oonf[ooo]Z00Gooo]Z00Gooe80o`3o<ol0:_oo
oo]Zo`3Lo`02oookJP03o`3ogooonf[ooo]Z00Soo`0000Goo`0Cool00?oonf[ooo]ZoolX0002oook
JP03obH0oooonf[ooo]Z00[ooo]Z00Ko0?mKoookJ_oonf[oP_l0oookJ_l0<?l2oookJP03o`H0oooo
nf[oolT000;ooo]Z0_m4o`02oookJP05ool0DOoonf[ooo]Zo`2]oooo07T01OoonfX01_l0oe?ooo]Z
oookJ_oob@3o0?lMo`3Qo`[ooo]Z00?oiOl0oookJ_oonfX01?oonfX01Ol0ZOoooo]ZoookJ_oonf[o
00Co00;ooo]Z00?o0=CooookJ_oonfX02OoonfX00oooN@3ooo]ZoookJP08oookJP03ool0;Ooonf[o
oo]Z05_ooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP04oookJP03oolF0?ooTP3o
oo]Z00?ooo]Z00?oo`3loookJ_oonfX00_oonfX02_lH0?ooo`H0oookJ_oonf[ojol0ool0m_oonf[o
0:KooookJ_nX0?l2oookJP04ool0nOl0Moooof`0o`3oVP;ooo]Z00Co>ol0oookJ_oonf[o0?_o1_oo
nfX01?mi0?oo0:?ook?o0?nO0?l3oookJP0:omgo0?l0omkooo]Zool0K?oonf[oC@3ooookJ_mQ0?oo
oo]Zo`3oA@;ooo]Z00Co0?n@oookJ_oonf[o0?nB1ooonfX00olH0?ooi_l0oookJP08oookJP03oonn
0?oonf[oL03o00Cooo]Z00CooeL0oookJ_oonf[oo`0]3?oonfX01_l0e?oooo]ZoookJ_l0R?oooo]Z
o`3oCPOooo]Z00?o0?l8oookJ_oonfX01_oonfX2oa00o`03oi;o0?oonf[ooo]Z02[ooo]Z0_l00000
0ol@0?oo0000oookJP08oookJP05o`3oC_oonf[o00CooookJ_l0e?l02OoonfX00om`0?oooo]Zoook
JP03oookJP03oaP0oooonf[ooo]Z00;ooo]Z00Co0?nBoookJ_oonf[oH@3o1?oonfX00onco`3ooo]Z
oookJP04oookJP03oom/0?oonf[ooo]Z00;ooo]Z00Koo`3foookJ_oonf[o603ooookJ_oo0?`?oook
JP03o`1coooonf[ooo]Z00Cooo]Z00?ooe80o`3o<ol0:_l00_oonfX00ol0g?oooo]Zo`3og`03oook
JP06o`3o6olB0?oooo]Zooo:0?oonf[o0?Wo0_oonfX01?oo01?ooo]ZoookJ_oQo`02oookJP03obH0
oooonf[ooo]Z00[ooo]Z00ko0?mKoookJ_oonf[o0?n`oh;o0?oonf[o033ooookJ_l60?oooo]Zool0
mOnBo`3ooo]Zoa00o`Cooo]Z00Coo`1AoookJ_oonf[oo`1i1OoonfX01ol0oe?ooo]ZoookJ_l0o`So
0?lMoookJ_l0hOl02OoonfX00ol0odko0?l^oookJP04oookJP03o`2Yoooonf[ooo]Z00;ooo]Z00?o
00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP08oookJP03ool0;Ooonf[ooo]Z02cooo]Z000c
oookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01?oonfX00oooTP3ooo]ZoookJP03
oookJP0Eool0o?oonf[ooo]ZoookJ_lH0?oooo]Zool60?oonf[ojol0oookJ_oo0?Kooo]Zo`2Voooo
nf[oZ03ooookJ_oo0?Wooo]Zo`1gooooK03o0?nJ00;ooo]Z00Go>ol0oookJ_oonf[ooo]Zo`3ko`04
oookJP04ogT0oooonf[ooo]Zok?o00Cooo]Z00Ko0?oNoookJ_oonf[oo`1/oookJ_m=0?l2ool00003
of40oooo003oo`0000;oo`0000?ooo]Zo`3oT_oonfX01ooonfX00olH0?ooi_l0oookJP07oookJP04
ool00?oo_P3oo`00og00o`?oo`0000GooeL0oookJ_oonf[ooo]Zool0;@0;oookJP04o`3Dool01?oo
oo]Zo`28o`?ooo]Z00?o0?m>oookJ_oonfX00ooonfX00ol0o`Sooo]ZoookJP07oookJPSoo`009_oo
nfX2oa00o`?o00001_oonfX3oolX0003oookJ_l01?oo0=Co00[ooo]Z00?oL03ooookJ_oonfX00ooo
nfX01OlH0?oooo]ZoookJ_oonf[o0?nB00?ooo]Z00?oH@3ooookJ_oonfX00ooonfX00onco`3ooo]Z
oookJP04oookJP03oom/0?oonf[ooo]Z00;ooo]Z00Goo`3foookJ_oo:03oobP0ool0o00>oookJP03
ool00?oonf[ooo]Z00Kooo]Z00Oooe80oookJ_l0:_oooo]Zo`3Loooonf[o0?oO00?ooo]Z0ooo0000
1OoobP3oo`00ool00?oo003oo`0C00;oo`0000Kooo]ZoolX0?oonf[ooo]ZobH0oolPo`0<oookJP05
o`3oFooonf[oP_l0o`3o/?l0<?l00ooonfX00ol60?ooolT0oookJP02oookJP;oA?l00_oonfX01Ooo
057ooo]Zo`2]oooonf[oo`1i00Gooo]Z00Go0?mCoookJ_oonf[oolT0o`3o7@0:oookJP03o`3o=?oU
o`3ooo]Z00Gooo]Z00Oo0:WooookJ_oonf[ooo]Zo`04oooonf[o0=Co00cooo]Z00?oogT0oookJ_oo
nfX02?oonfX00ooo02gooo]ZoookJP1KoookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oo
nfX01?oonfX00ooo5P3ooi80oookJP03oookJP03ool0o?oonf[ooo]Z00;ooo]Z00[o603oool60?oo
nf[ooo]Zon_o0?oonf[oo`3fo`2Voooonf[oZ03o0_oonfX01?oo0?Wo07Oooom/0?l0oiX2oookJP05
oc_o0?oonf[ooo]ZoookJ_l0nol01OoonfX01?mi0?oooo]Zok?o0?nO0?l3oookJP06omgo0?l0omko
oo]ZoookJ_oo06coC@3o0_oonfX01OmQ0?oo0?m5oookJ_oonf[o0?n@00;ooo]Z00?o0?nBoookJ_oo
nfX01OoonfX00olH0?oo07CoonKo0008oookJP03oonn0?oonf[oL03o00Cooo]Z00CooeL0oookJ_oo
nf[oo`0]3?oonfX01?l0e?oo00CooookJ_l0R?l2oookJP03o`3oC_oonf[ooo]Z00Cooo]Z00?o0?l8
oookJ_oonfX02?oonfX00ol@0?ooT_l0oookJP0ZoookJP;o403o0_l00008oookJP05o`3oC_oonf[o
00CooookJ_l0e?l02OoonfX00om`0?oooo]ZoookJP04oookJP05oaP0oooonf[ooo]ZoookJ_l0oi80
0ooonfX00omQ0?oooo]ZoookJP02oookJP03ok?o0?oonf[ooo]Z00Cooo]Z00?oof`0oookJ_oonfX0
0_oonfX01Ooo0?Kooo]ZoookJ_lH0?ooo`3l00oooo]Z00?o07?ooookJ_oonfX01OoonfX00oooDP3o
oo]Zo`0Zo`02oookJP03o`3Lool0omoooo]Z00?ooo]Z00So0?lKoookJ_oonf[oolX0oookJ_l0nOoo
oo]Zool04`;ooo]Z00GohOl0oookJ_oonf[o9P3oob3o000<oookJP06o`3oFooonf[ooo]Zoh;o0?oo
nf[o033o0_oonfX00ol60?oooo]Zoi;o0002oookJP03oa00oooonf[ooo]Z00;ooo]Z00Coo`1Aoook
J_l0[Oooo`1i1OoonfX01_l0oe?ooo]ZoookJ_l0o`So0?lMo`3Qo`Wooo]Z00?o0?ldo`3oC_l0obh0
1OoonfX01ol0ZOoooo]ZoookJ_oonf[o00CooookJ_l0e?l03?oonfX00oooP@3ooo]ZoookJP08oook
JP03ool0;Ooonf[ooo]Z02cooo]Z000coookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oo
nfX01?oonfX00oooTP3ooo]ZoookJP03oookJP05ool0o?oonf[ooo]ZoookJ_lH0?l00_oonfX03_oo
1P3ooo]Zon_o0?oo0?Kooo]Zo`2Voooonf[oZ03ooookJ_oo0?Wooo]Zo`1goooonf[oof`00_oonfX0
1Olko`3ooo]ZoookJ_oonf[o0?_o00Cooo]Z00CoN@3ooookJ_oonf[o/ol01?oonfX01_l0omkooo]Z
oookJ_oo06cooo]Zodd0o`;oo`0000?oH@3oool00?oo00000ooo00000ol0oi;ooo]ZoookJP06oook
JP03o`1doolH0?oooo]Z00Oooo]Z00Coo`00oonn0?oo003oL03o1?oo00001OooE`3ooo]ZoookJ_oo
nf[oo`0]00[ooo]Z00Co0=CooookJ_l01?oo08So1?oonfX00ol0odkooo]ZoookJP03oookJP;oo`00
1ooonfX9ool002?ooo]Z0_l@0?l00ooonf[o0000o`000002o`0000Gooo]Z0ooo:0000ooonf[o00Co
o`3Do`0:oookJP03og00oooonf[ooo]Z00?ooo]Z00?oi_l0oaP0oooonfX00_oonfX01?l0oi;ooo]Z
oookJ_mQ0?l5oookJP03ok?o0?oonf[ooo]Z00Cooo]Z00?oof`0oookJ_oonfX00ooonfX01Ooo0?Ko
oo]ZoolX0?oonf[oo`3l00kooo]Z00?oo`00oookJ_oonfX01OoonfX00oooDP3o0?lco`0Zo`02oook
JP03o`3Loooonf[o0?oO00?ooo]Z1ooo00001Ooo:03oo`00oookJ_oonf[oobP000;ooo]Z00?o9P3o
oookJ_oonfX02ooonfX01Ol0oe_ooo]Zoh;o0?oonf[o033o00;ooo]Z00?o1P3ooookJ_oob@000ooo
nfX02Om4o`3ooo]ZoookJ_oonf[oo`1AoookJ_l0[Ooooo]Zool0N@05oookJP05o`3oDooonf[ooo]Z
ooo90?l0oad02_oonfX00ooUo`3o0?l^oookJP04oookJP05o`2Yoooob@3ooo]ZoookJ_l01?l00_oo
nfX00ol0e?oooo]ZoookJP0:oookJP03oomi0?oonf[ooo]Z00Sooo]Z00?oo`0]oookJ_oonfX01_oo
nfX00oooE`3ooo]ZoookJP1BoookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01?oo
nfX00ooo5P3ooi80oookJP03oookJP03ool0o?oonf[ooo]Z00;ooo]Z00[o603ooookJ_oo1P3ooo]Z
on_o0?oonf[oo`3fo`2Voooonf[oZ03o0_oonfX01?oo0?Wo07OooookJ_ooK002oookJP05oc_o0?oo
nf[ooo]ZoookJ_l0nol01OoonfX01?mi0?oooo]Zok?o0?nO0?l3oookJP06omgo0?l0omkooo]Zoook
J_oo06coC@3o0_oonfX01OmQ0?oo0?m5oookJ_oonf[o0?n@00;ooo]Z00?o0?nBoookJ_oonfX01_oo
nfX00olH0?ooi_l0oookJP08oookJP03oonn0?m`0?oooo]Z00?ooo]Z00GooeL0oookJ_oonf[ooo]Z
ool0;@0;oookJP04o`3Dool01?oooo]Zo`28o`?ooo]Z00?o0?m>oookJ_oonfX01?oonfX00ol0o`So
oo]ZoookJP08oookJP03oa00oooonf[ooo]Z02Oooo]Z0_l@0?l4o`0000Oooo]Z00Go0?m>oookJ_l0
1?oooo]Zo`3Do`0:oookJP03og00oooonf[ooo]Z00?ooo]Z00?o603ooookJ_oonfX00_oonfX01?l0
oi;ooo]ZoookJ_mQ0?l4oookJP03ok?o0?oonf[ooo]Z00Cooo]Z00?oof`0oookJ_oonfX00ooonfX0
1Ooo0?Kooo]ZoaP0oooonf[oo`3l00oooo]Z00?o07?ooookJ_oonfX01?oonfX01?ooDP3o0?lcoook
J_l0:_l2oookJP03o`3Lool0omoooo]Z00?ooo]Z00?o0?lKoookJ_oobP000_oonfX00ol0nOoooo]Z
ool04`02oookJP05on7o0?oonf[ooo]ZobH0oon40?l03?oonfX02?l0oe_ooo]Zo`3o/?n2o`3ooo]Z
o`0`oooonf[o1P3o0_oonfX01?nBo`3ooo]ZoookJ_l@0?l4oookJP04ool0DOoonf[o0:goool0N@Go
oo]Z00Ko0?mCoookJ_oonf[o0?l8o`3o7Ol0hOl9oookJP03o`3o=?l0odko0?l^00Gooo]Z00Oo0:Wo
oookJ_oonf[ooo]Zo`04oooonf[o0=Co00cooo]Z00?ooh40oookJ_oonfX02?oonfX00ooo02gooo]Z
oookJP07oookJP03oomG0?oonf[ooo]Z02;ooo]Z000coookJP03o`1coooonf[ooo]Z01;ooo]Z00?o
o`3ZoookJ_oonfX01?oonfX00ooo5P3ooi80oookJP03oookJP05ool0o?oonf[ooo]ZoookJ_lH0?l0
0_oonfX02?oo1P3ooo]Zon_o0?oo0?Kooo]Zo`2Voooonf[oZ03o0_oonfX01?oo0?Wo07OooookJ_oo
K002oookJP05oc_o0?oonf[ooo]ZoookJ_l0nol01OoonfX01?mi0?oooo]Zo`2Soonco`04oookJP05
o`3og_oonf[oo`1/oookJ_m=0?l00_oo00001omQ0?ooo`00ool00?oonf[oo`00oookJ_l0oi802Ooo
nfX00olH0?oooo]ZoookJP06oookJP05ool00?oo_P3oo`00og00oooo00000ooonfX01OooE`3ooo]Z
oookJ_oonf[oo`0]00_ooo]Z00?o0=Coo`04oooonfX00_oo0002oookJP03o`3oC_oonf[ooo]Z00?o
oo]Z1?oo0006oookJPKoo`008ooonfX2oa00o`?ooo]Z1?l00004oookJP03oomi0?oo:03oogT000;o
ogT000?o0=CooookJ_oonfX02OoonfX00om`0?oooo]ZoookJP02oookJP03onKo0?lH0?oooo]Z00;o
oo]Z00Go0?nBoookJ_oonf[ooo]Zof40o`05oookJP03ok?o0?oonf[ooo]Z00Cooo]Z00?oof`0oook
J_oonfX00_oonfX01Ooo0?Kooo]ZoookJ_lH0?ooo`3l00oooo]Z00?oo`00oookJ_oonfX01OoonfX0
1OooDP3ooo]Zo`0Zoooonf[o0=co00;ooo]Z00Co0?oOoookJ_oonf[ooo]Z0_oo00000ooobP3oo`00
ool00002ool00003oolX0?oo003ooo]Z00?oo`0000?ooo]ZobH0oooonfX03?oonfX01Ol0oe_ooo]Z
oh;o0?oonf[o033o00;ooo]Z00?o1P3ooookJ_oob@000ooonfX01?l@0?oooo]ZoookJ_oo0542oook
JP03o`2]oooo07Wooo]Z00Cooo]Z00Ko0?mCoookJ_oonf[oolT0oookJ_l0oad:oookJP03onGo0?l0
obkooo]Z00Cooo]Z00Go0:WooookJ_oonf[ooo]Zo`04o`02oookJP03o`3Doooonf[ooo]Z00Wooo]Z
00?oogT0oookJ_oonfX02?oonfX00ooo02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z05;ooo]Z
00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP04oookJP03oolF0?oonf[ooi8000?ooo]Z
00?oo`3loookJ_oonfX00_oonfX02_lH0?oooo]Zool60?oonf[ojol0oookJ_oo0?Kooo]Zo`2VoonX
0?l2oookJP04ool0nOl0Mooooo]Zoom/00;ooo]Z00Go>ol0oookJ_oonf[ooo]Zo`3ko`05oookJP04
ogT0oooonf[o0:?ook?o00Cooo]Z00Go0?oNoookJ_oonf[oo`1/odd0o`02oookJP05of40oooonf[o
0?m5oookJ_l0oi000_oonfX00ol0oi;ooo]ZoookJP06oookJP03oaP0oooVo`3ooo]Z00Sooo]Z00?o
okh0og00ool0o`D01?oonfX01?ooE`3ooo]ZoookJ_oo02d<oookJP04o`3Dool01?oooo]Zo`28o`;o
oo]Z00?o0?m>oookJ_oonfX01?oonfX00ol0o`Sooo]ZoookJP09oookJP;o403o9OoonfX2oa00o`;o
oo]Z1?l00006oookJP05o`3oC_oonf[o00CooookJ_l0e?l02_oonfX00om`0?oooo]ZoookJP03oook
JP03oaP0ool0M?oooo]Z00;ooo]Z00Go0?nBoookJ_oonf[ooo]Zof40o`04oookJP03ok?o0?oonf[o
oo]Z00Cooo]Z00?oof`0oookJ_oonfX00_oonfX01Ooo0?Kooo]ZoookJ_lH0?ooo`3l00oooo]Z00?o
07?ooookJ_oonfX01OoonfX00oooDP3o0?lco`0Zo`02oookJP03o`3Loooonf[o0?oO00Cooo]Z00Go
0?lKoookJ_oobP3ooo]Zo`3io`02oookJP04ool04ooonf[ooo]Zon7o00;ooo]Z00?o9P3ooookJ_oo
nfX02ooonfX02ol0oe_ooo]Zo`3o/?n2o`3ooo]Zo`0`oooonf[o1P3ooookJ_oo0?GoT_l000;ooo]Z
00Go403ooookJ_oonf[ooo]Zool0D@02oookJP03o`2]oooo07Wooo]Z00?ooo]Z00Oo0?mCoookJ_oo
nf[o0?l8oookJ_l0oago0>7o00Wooo]Z00?o0?ldo`3oC_oonfX01?oonfX00ol0R?oo0:WooookJP02
oookJP03o`04oooonf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02?oonfX00ooo02gooo]ZoookJP08
oookJP03oomG0?oonf[ooo]Z02;ooo]Z000coookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3Zoook
J_oonfX01?oonfX00ooo5P3ooi80oookJP03oookJP05ool0o?oonf[ooo]ZoookJ_lH0?l00_oonfX0
1?oo1P3ooo]Zon_o0?oo0?H2oookJP0;o`2VoonX0?oooo]ZoookJ_oo0?Wo07OooookJ_ooK03o0?nJ
oookJ_lko`000ooonfX00ol0nooooo]ZoookJP03oookJP04ogT0oooonf[o0:?ook?o00Cooo]Z00Co
0?oNoookJ_oo06cooo]Z0_oo00000ooonf[oH@3oool00003oookJP03ool00?oonf[o0?nB00Sooo]Z
00?o603ooookJ_oonfX01_oonfX01Ooo003ookh0oookJ_oo003oL03o00Cooo]Z00GooeL0oookJ_oo
nf[ooo]Zool0;@0:oookJP03o`3Dool01?oooo]Z00?oo`000_oonfX00ol0odkooo]ZoookJP03oook
JPCoo`001OoonfX5ool002?ooo]Z00?o403ooookJ_oonfX00ooonfX4o`0000?ooo]Z00?o0?m>oolX
0?ooN@001?ooN@0:oookJP03og00oooonf[ooo]Z00;ooo]Z00?oi_l0o`1doolH0?l00ooonfX01?l0
oi;ooo]ZoookJ_mQ0?l5oookJP03ok?o0?oonf[ooo]Z00Cooo]Z00?oof`0oookJ_oonfX00ooonfX0
1Ooo0?Kooo]ZoaP0oooonf[oo`3l00kooo]Z00?oo`00oookJ_oonfX01_oonfX01oooDP3o02[ooook
J_oonf[o0=cooookJ_l0oml00ooonfX01?lB0?ooo`00ool00?oobP03ool00004oolX0?oo003ooo]Z
oookJP?oo`0000?o9P3oob3o0?oo00003?oonfX01?l0oe_oP_l0o`3o/?l0<?l3oookJP03o`H0oooo
b@3ooo]Z00;ooo]Z00Wo403ooookJ_oonf[ooo]Zool0DOoonf[o0:gooookJ_oo07T01OoonfX01_l0
oe?ooo]ZoookJ_oob@3o0?lMo`3Qo`[ooo]Z00?oiOl0oookJ_oonfX01?oonfX01Ol0ZOoooo]Zoook
J_oonf[o00Co00;ooo]Z00?oU?l0oookJ_oonfX02OoonfX00oooN@3ooo]ZoookJP08oookJP03ool0
;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX0D_oonfX00ol0Looooo]ZoookJP0BoookJP03ool0
j_oonf[ooo]Z00Cooo]Z00?ooaH0oookJ_ooTP000ooonfX00ooo0?cooo]ZoookJP02oookJP0:oaP0
oooonf[oo`H0oookJ_o[o`3ooo]Zool0m_oonf[o0:KoojP0o`;ooo]Z00Ooo`3io`1goooonf[oof`0
o`3oV_oonf[o>ol000?ooo]Z00?o0?_ooookJ_oonfX01?oonfX00omi0?oo0:?ook?o0004oookJP05
o`3og_oonf[ooo]Zool0K?m=0?l00_oonfX00omQ0?oooo]Zo`3oA@02oookJP03o`3oT?oonf[o0?nB
00Sooo]Z00?o603oonKo0?oonfX02?oonfX00ooo_P3ooo]Zog00o`04oookJP05oomG0?oonf[ooo]Z
oookJ_oo02d02ooonfX01?l0e?oo00CooookJ_l0R?l3oookJP03o`3oC_oonf[ooo]Z00Cooo]Z00?o
0?l8oookJ_oonfX02_oonfX00ol@0?oooo]ZoookJP0PoookJP;o403o1?oonfX4o`0000Cooo]Z0_l0
odh01?oonf[o00Coo`3Dool0e?l:oookJP03og00oooonf[ooo]Z00?ooo]Z00?oi_l0oaP0oooonfX0
0ooonfX01?l0oi;ooo]ZoookJ_mQ0?l4oookJP03ok?o0?oonf[ooo]Z00Cooo]Z00?oof`0oookJ_oo
nfX00ooonfX01Ooo0?Kooo]ZoaP0oooonf[oo`3l00oooo]Z00?o07?ooookJ_oonfX01OoonfX00ooo
DP3ooo]Zo`0Zo`02oookJP03o`3Lool0omoooo]Z00?ooo]Z00So0?lKoookJ_oonf[oolX0oookJ_l0
nOoooo]Zool04`;ooo]Z00GohOl0oookJ_oonf[o9P3oob3o000=oookJP05o`3oFooonf[oP_l0oook
J_l0<?l00_oonfX00ol60?oooo]Zoi;o0002oookJP03oa00oooonf[ooo]Z00;ooo]Z00Coo`1Aoook
J_l0[Oooo`1i1OoonfX01ol0oe?ooo]ZoookJ_l0o`So0?lMoookJ_l0hOl02OoonfX00ol0ocCo0?m>
oookJP04oookJP03o`28ool0ZOoooo]Z00;ooo]Z00?o00CooookJ_l0e?l02ooonfX00oooP@3ooo]Z
oookJP08oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00?ooeL0oookJ_oonfX08_oonfX003Cooo]Z00?o
07?ooookJ_oonfX04OoonfX00ooo0>[ooo]ZoookJP04oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00Go
o`3loookJ_oonf[ooo]ZoaP0o`02oookJP04ool60?oonf[ojol0ool0mP;ooo]Z00_o0:KoojP0oooo
nf[ooo]Zool0nOl0Mooooo]Zoom/0?l0oi[ooo]Zoc_o0003oookJP03o`3koooonf[ooo]Z00?ooo]Z
00CoN@3ooookJ_l0Xooo/ol01?oonfX01Ol0omkooo]Zool0K?oonf[oo`0000;ooo]Z00?oH@3oool0
0?oonfX00_oonfX00ooo003ooo]Zo`3oTP08oookJP03onKo0?lH0?oooo]Z00Oooo]Z00Cookh0oook
J_oo003oL03o1?oonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00_ooo]Z00?o0=Coo`04oooonfX01?oo
00000ol0odkooo]ZoookJP04oookJPGoo`000ooonfX3ool000;ooo]Z00?o403ooookJ_oonfX07_oo
nfX2oa00o`Kooo]Z1?l00002oookJP03o`3oC_ooN@3oogT000KoogT02?oonfX00om`0?oooo]Zoook
JP03oookJP03onKo0?lH0?oooo]Z00;ooo]Z00GoobP0oookJ_oonf[ooo]Zof40o`05oookJP03ok?o
0?oonf[ooo]Z00Cooo]Z00?oof`0oookJ_oonfX00ooonfX01?oo0?Kooo]ZoaP0oooo0?`?oookJP03
ool00?oonf[ooo]Z00Gooo]Z00?ooe80o`3o<ol0:_l00_oonfX00ol0g?oooo]Zo`3og`03oookJP04
oa80oooo003oolX0oookJP?oo`0000CoobP0oookJ_oonf[ooo]Z0ooo00000olV0?ooo`00ool00002
ool000Wooo]Z00Go0?mKoookJ_n2o`3ooo]Zo`0`o`03oookJP03o`H0oooob@3ooo]Z00;ooo]Z00Wo
403ooookJ_oonf[ooo]Zool0DOoonf[o0:gooookJ_oo07T01OoonfX01_l0oe?ooo]ZoookJ_oob@3o
0?lMo`3Qo`[ooo]Z00?oiOl0oookJ_oonfX01?oonfX01Ol0ZOoooo]ZoookJ_oonf[o00Co00;ooo]Z
00?oU?l0oookJ_oonfX02OoonfX00oooN@3ooo]ZoookJP08oookJP03ool0;Ooonf[ooo]Z00Kooo]Z
00?ooeL0oookJ_oonfX0E?oonfX00ol0Looooo]ZoookJP0AoookJP03ool0j_oonf[ooo]Z00Cooo]Z
00?ooaH0oookJ_ooTP001?oonfX01ooo0?cooo]ZoookJ_oonf[o603ooookJ_oo1P000_oonfX01Oo[
o`3oo`3foookJ_l0Y_ooZ03o00;ooo]Z00Ooo`3io`1goooonf[oof`0o`3oV_oonf[o>ol000?ooo]Z
00?o0?_ooookJ_oonfX01?oonfX00omi0?oo0:?ook?o0004oookJP05omgo0?l0omkooo]Zool0K?m=
0?l00_oonfX00omQ0?oooo]Zo`3oA@02oookJP04o`3oT?oonf[ooo]Zo`3oTPSooo]Z00?o603ooook
J_oonfX01ooonfX00ooo_P3ooo]Zog00o`05oookJP05oomG0?oonf[ooo]ZoookJ_oo02d02ooonfX0
1?l0e?oo00CooookJ_l0R?l2oookJP03o`3oC_oonf[ooo]Z00Gooo]Z00?o0?l8oookJ_oonfX02_oo
nfX00ol@0?oooo]ZoookJP0MoookJP;o403o1_oonfX4o`0000?ooo]Z00Go0?m>oookJ_oonf[o00Co
o`3Do`0;oookJP03og00oooonf[ooo]Z00Cooo]Z00?o603ooookJ_oonfX00_oonfX01Ol0oi;ooo]Z
oookJ_oonf[oH@3o00Cooo]Z00?o/ol0oookJ_oonfX01?oonfX00oooK03ooo]ZoookJP03oookJP04
ool0m_oonf[o603oool0o0oooo]Z00?o07?ooookJ_oonfX01OoonfX00oooDP3o0?lco`0Zo`03oook
JP03o`3Lool0omoooo]Z00?ooo]Z00?o0?lKoookJ_oobP000_oonfX00ol0nOoooo]Zool04`02oook
JP05on7o0?oonf[ooo]ZobH0oon40?l03?oonfX01_l0oe_ooo]Zo`3o/?n2o`3ooo]Zo`0`o`;ooo]Z
00?o1P3ooookJ_nBo`000_oonfX00ol@0?oooo]ZoookJP02oookJP04ool0DOoonf[o0:goool0N@Go
oo]Z00Oo0?mCoookJ_oonf[o0?l8o`3o7Ooonf[o0>7o00Wooo]Z00?o0?m>o`3o;_oonfX01?oonfX0
1Ol0ZOoooo]ZoookJ_oonf[o00Co00;ooo]Z00?o0=CooookJ_oonfX02OoonfX00oooP@3ooo]Zoook
JP08oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX08ooonfX003Cooo]Z00?o07?o
oookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP03oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00?oo`3l
oookJ_oonfX00_oonfX01_lH0?oooo]Zool60?oonf[ojol0ool0mP;ooo]Z00Ko0:KoojP0oooonf[o
oo]Zool0nOl0Mol2oookJP04oom/0?oonf[ooo]Zoc_o00;ooo]Z00?o0?_ooookJ_oonfX00ooonfX0
1?mi0?oooo]Zoil0oonco`04oookJP04o`3og_oonf[oo`1/oookJP;oo`0000Cooo]Zof40oooonf[o
o`000_oonfX00ooo003ooo]Zo`3oTP09oookJP03oaP0oooonf[ooo]Z00Oooo]Z00?ookh0oookJ_m`
0?l01?oonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00Wooo]Z00?o0=CooookJ_oo
00001?oo00000ol0odkooo]ZoookJP03oookJPOoo`000_oonfX00ooo003ooo]ZoookJP02oookJP03
oa00oooonf[ooo]Z01[ooo]Z0ol@0?l8oookJPCo000000?ooo]Zo`3oC_oonfX02OooN@07oookJP03
og00oooonf[ooo]Z00;ooo]Z00?oi_l0oaP0oooonfX00ooonfX01?oo:03ooo]ZoookJ_mQ0?l5oook
JP03ok?o0?oonf[ooo]Z00Cooo]Z00?oof`0oookJ_oonfX00ooonfX01Ooo0?Kooo]ZoaP0oooonf[o
o`3l00kooo]Z00?oo`00oookJ_oonfX01_oonfX00oooDP3ooo]Zo`0Zo`02oookJP03o`3Lool0omoo
oo]Z00?ooo]Z00Co4P3oo`3o6ooobP3ooo]Z0ooo00001?oo:03ooo]ZoookJ_oo:003ool00003obH0
oooo003oo`0000;oo`002OoonfX01Ol0oe_ooo]Zoh;o0?oonf[o033o00;ooo]Z00?o1P3ooookJ_oo
b@000ooonfX01?l@0?oooo]ZoookJ_oo0542oookJP03o`2]oooonf[oo`1i00Cooo]Z00Ko0?mCoook
J_oonf[ooo]Zooo90?l0oad7oookJP?oiOl000?o0?ldonGo0?oonfX01?oonfX01Ooob@3o0:Wooook
J_oonf[o00Co00?ooo]Z00?oU?l0oookJ_oonfX02?oonfX00oooN@3ooo]ZoookJP09oookJP03ool0
;Ooonf[ooo]Z00Kooo]Z00?ooeL0oookJ_oonfX0E?oonfX00ol0Looooo]ZoookJP0BoookJP03ool0
j_oonf[ooo]Z00?ooo]Z00?ooaH0oookJ_ooTP001?oonfX00ooo0?cooo]ZoookJP02oookJP09oaP0
oooo1P3ooo]ZoookJ_o[o`3oo`3foookJ_l0Y_ooZ03o00?ooo]Z00Co07OooookJ_oonf[oof`00_oo
nfX01?lko`3ooo]ZoookJ_l0nol6oookJP03ogT0oooonf[o/ol000Gooo]Z00Wo0?oNoookJ_oo06co
oo]Zodd0oooonf[oH@3ooookJ_l0odD00_oonfX01?l0oi3ooo]ZoookJ_l0oi88oookJP03oaP0oooV
o`3ooo]Z00Sooo]Z00?ookh0og00ool0o`D01?oonfX01OooE`3ooo]ZoookJ_oonf[oo`0]00cooo]Z
00Co0=CooookJ_oonf[o08So0_oonfX00ol0odkooo]ZoookJP05oookJP03o`3o2?oonf[ooo]Z00[o
oo]Z00?o403ooookJ_oonfX06OoonfX3oa00o`Sooo]Z1?l00002oookJP05o`3oC_oonf[ooo]Zo`04
ool0e?l03?oonfX00om`0?oooo]ZoookJP03oookJP03onKo0?lH0?oooo]Z00?ooo]Z00Co0?nBoook
J_oonf[oH@3o1?oonfX00onco`3ooo]ZoookJP04oookJP03oom/0?oonf[ooo]Z00?ooo]Z00Goo`3f
oookJ_lH0?oooo]Zool0o00?oookJP03o`1coooonf[ooo]Z00Gooo]Z00?ooe80oookJ_l0:_l00ooo
nfX00ol0omoooo]ZoookJP03oookJP03o`3o6ooonf[oolX000;ooo]Z00?o0?Woool04ooonfX00_oo
nfX01OoQo`3ooo]ZoookJ_lV0?ooQ03o00cooo]Z00_o0?mKoookJ_l0ok3oP_l0oookJ_l0<?oooo]Z
o`H0oooonf[oo`3eoi;o0002oookJP05oa00oooonf[ooo]ZoookJ_oo05400_oonfX00ol0[Oooo`1i
oookJP03oookJP07o`3oDooonf[ooo]ZoookJ_l0o`So0?lMo`3Qo`09oookJP03o`3o=?l0odko0?l^
00Cooo]Z00?o08Soo`2YoooonfX00_oonfX01?l01?oooo]ZoookJ_l0e?l:oookJP03oon10?oonf[o
oo]Z00Wooo]Z00?oo`0]oookJ_oonfX01ooonfX00oooE`3ooo]ZoookJP0SoookJP00=?oonfX00ol0
Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Cooo]Z00?ooi80oookJ_oonfX00_oonfX00ooo
0?cooo]ZoookJP02oookJP06oaP0oooonf[oo`H0oookJ_o[o`3oo`3f0_oonfX01_l0Y_ooobP0oook
J_oonf[oo`3io`1go`;ooo]Z00Coof`0oookJ_oonf[o>ol00ooonfX00ol0nooooo]ZoookJP02oook
JP04ogT0oooonf[ooo]Zok?o00Cooo]Z00CogOl0o`3og_oonf[oo`1/0ooo00000ooonf[oH@3oool0
0002oookJP03ool00?oonf[o0?nB00Wooo]Z00?o603ooookJ_oonfX01ooonfX01?oo003ooo]Zool0
0?m`0?l4oookJP05oomG0?oonf[ooo]ZoookJ_oo02d03?oonfX00ol0e?oooo]Zool00003ool00003
o`3oC_oo003ooo]Z00Cooo]Z2?oo0006oookJP?o403o5_oonfX3oa00o`_ooo]Z1?l000000ol0odko
oo]Zoomi0007oomi00Sooo]Z00?oL03ooookJ_oonfX00_oonfX00ooVo`3oobP0oaP0o`03oookJP04
oolX0?oonf[ooo]Zof40o`Kooo]Z00?o/ol0oookJ_oonfX01?oonfX00oooK03ooo]ZoookJP03oook
JP05ool0m_oonf[o603ooookJ_oo0?`03_oonfX00ooo003ooo]ZoookJP05oookJP03oomB0?l0oc?o
02[o00;ooo]Z00?o0=cooookJ_l0oml00ooonfX00olB0?oo0?lKooo:0002oookJP;oo`0000GoobP0
oookJ_oonf[ooo]ZoolX0002ool00003obH0oolPo`3oo`0000;oo`002_oonfX01?l0oe_oP_l0o`3o
/?l0<?l3oookJP03o`H0oooob@3ooo]Z00;ooo]Z00Oo403ooookJ_oonf[ooo]Zool0DOoonf[o0:go
00;ooo]Z00?oo`1ioookJ_oonfX00_oonfX01_l0oe?ooo]ZoookJ_oob@3o0?lMo`3Qo`Oooo]Z1_oU
o`04oookJP05o`2Yoooonf[ooo]ZoookJ_l01?l00_oonfX00onDo`3ooo]ZoookJP09oookJP03oomi
0?oonf[ooo]Z00Wooo]Z00?oo`0]oookJ_oonfX01_oonfX00oooE`3ooo]ZoookJP1DoookJP03o`1c
oooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01?oonfX00ooo5P3ooi80oookJP03oookJP03ool0
o?oonf[ooo]Z00;ooo]Z00Wo603oool60?oonf[ooo]Zon_o0?oo0?Kooo]Zo`2VoonX0?l00ooonfX0
1?l0Mooooo]ZoookJ_ooK002oookJP05oc_o0?oonf[ooo]ZoookJ_l0nol01OoonfX00omi0?oooo]Z
ok?o0005oookJP05o`3og_oonf[oo`1/oookJ_m=0?l00_oonfX01OmQ0?oo0?m5oookJ_oonf[o0?n@
00;ooo]Z00?o0?nBoookJ_oonfX01_oonfX00olH0?ooi_l0oookJP08oookJP03oonn0?oonf[oL03o
00Cooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP0:oookJP06o`3Doooonf[ooo]Z
o`28oooonf[o0?m>2?oonfX00ol0o`Sooo]ZoookJP0:oookJP?o403o5OoonfX3oa00o`_ooo]Z1?l0
0002o`3oCP;ooo]Z00?o00Coo`3DoooonfX02ooonfX00om`0?oooo]ZoookJP03oookJP03onKo0?lH
0?oooo]Z00?ooo]Z00Co0?nBoookJ_oonf[oH@3o1OoonfX00onco`3ooo]ZoookJP04oookJP03oom/
0?oonf[ooo]Z00?ooo]Z00Goo`3foookJ_lH0?oooo]Zool0o00?oookJP03o`1coooonf[ooo]Z00Co
oo]Z00Cooe80o`3o<ooonf[o02[o0_oonfX00ol0g?oo0?oOoookJP03oookJP03o`3o6ooonf[oolX0
00;ooo]Z00?o0?WooookJ_oo01<00_oonfX01OoQo`3ooo]ZoookJ_lV0?oo8?l000gooo]Z00Go0?mK
oookJ_n2o`3ooo]Zo`0`o`02oookJP03o`H0oooonf[oT_l000;ooo]Z00?o403ooookJ_oonfX00_oo
nfX01Ooo057ooo]Zo`2]oooonf[oo`1i00Cooo]Z00Oo0?mCoookJ_oonf[o0?l8o`3o7Ooonf[o0>7o
00Wooo]Z00?o0?ldo`3oC_l0obh01?oonfX00ol0R?oo0:WooookJP02oookJP03o`04oooonf[o0=Co
00_ooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z
02?ooo]Z000doookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01?oonfX00ooo5P3o
oi80oookJP02oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Ko603ooookJ_oo1P3ooo]Zon_o0?oo0?H2
oookJP06o`2Voooo:03ooo]ZoookJ_oo0?Wo07Oo0_oonfX01?ooK03ooo]ZoookJ_lko`03oookJP03
o`3koooonf[ooo]Z00;ooo]Z00Goo`00oookJ_oonf[o0:?ook?o0004oookJP03o`3og_oonf[oo`1/
00?oo`0000?ooo]Zof40oooo00000_oonfX00ooo003ooo]Zo`3oTP09oookJP03onKo0?lH0?oooo]Z
00Oooo]Z0ooo00000om`0?oooo]ZoookJP02oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oook
J_oonfX02OoonfX00ol0e?oo00Coool00004ool000;o0?m>1?oonfX9ool000Sooo]Z0ol@0?l@oook
JP?o403o3_oonfX2o`0000;o0?m>00?ooo]Zoomi0?ooN@001OooN@09oookJP03og00oooonf[ooo]Z
00;ooo]Z00?oi_l0oookJ_lH0?l00_oo:0000ooonf[oobP0oookJP02oookJP03of40oooonf[ooo]Z
00?ooo]Z00?o/ol0oookJ_oonfX01?oonfX00oooK03ooo]ZoookJP03oookJP05ool0m_oonf[o603o
oookJ_oo0?`02_oonfX2ool000?ooo]Z00?oo`00oookJ_oonfX01OoonfX00oooDP3ooo]Zo`0Zo`02
oookJP03o`3Lool0omoooo]Z00?ooo]Z00?o4P3oo`3o6ooobP000_oonfX2ool00005oolX0?oonf[o
oo]ZoookJ_oo:0000_oo00001?lV0?ooo`00ool00?oo000:oookJP05o`3oFooonf[oP_l0o`3o/?l0
<?l00ooonfX00ol60?ooolT0oookJP02oookJP09oa00oooonf[ooo]ZoookJ_oo057ooo]Zo`2]oooo
nf[oo`1i00Gooo]Z00Ko0?mCoookJ_oonf[oolT0o`3o7Ol0hOl7oookJPSoiOl00_oonfX01Ol0ZOoo
oo]ZoookJ_oonf[o00Co00;ooo]Z00?oU?l0oookJ_oonfX02OoonfX00oooN@3ooo]ZoookJP08oook
JP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0oookJ_oonfX0EOoonfX00ol0Looooo]ZoookJP0Boook
JP03ool0j_oonf[ooo]Z00Cooo]Z00?ooaH0oookJ_ooTP000ooonfX00ooo0?cooo]ZoookJP02oook
JP06oaP0oooo1P3ooo]ZoookJ_o[o`3oo`3f0_oonfX02?nX0?oooo]ZoookJ_oonf[oo`3io`1goooo
nf[oof`00_oonfX01Olko`3ooo]ZoookJ_oonf[o0?_o00Gooo]Z00CoN@3ooookJ_l0Xooo/ol01?oo
nfX01Ol0omkooo]ZoookJ_oo06coC@3o00;ooo]Z00GoH@3ooookJ_l0odGooo]Zo`3oT002oookJP03
o`3oT_oonf[ooo]Z00Oooo]Z00?o603ooookJ_oonfX01ooonfX00ooo_P3ooo]Zog00o`05oookJP05
oomG0?oonf[ooo]ZoookJ_oo02d03?oonfX01_l0e?oo00CooookJ_oonf[o08SooookJP;o0?m>1ooo
nfX00ol0o`Sooo]ZoookJP0<oookJP?o403o3ooonfX3oa00o`kooo]Z0ol000001?l0odkooo]Zoook
J_oonfX2o`3Do`cooo]Z00?oL03ooookJ_oonfX00ooonfX00ooVo`3o603oo`1do`03oookJP05o`3o
T_oonf[ooo]ZoookJ_mQ0?l01?oonfX00onco`3ooo]ZoookJP04oookJP03oom/0?oonf[ooo]Z00?o
oo]Z00Goo`3foookJ_lH0?oooo]Zool0o00?oookJP03o`1coooonf[ooo]Z00Gooo]Z00?ooe80o`3o
<ol0:_l00ooonfX00ol0omoooo]ZoookJP03oookJP03o`3o6ooonf[oolX000;ooo]Z00?o0?Wooook
J_oo01<00_oonfX01OoQo`3ooo]ZoookJ_lV0?ooQ03o00cooo]Z00Ko0?mKoookJ_oonf[oP_l0oook
J_l0<?l2oookJP03o`H0oooonf[oT_l000;ooo]Z00?o403ooookJ_oonfX00_oonfX01Ooo057ooo]Z
o`2]oooonf[oo`1i00Cooo]Z00Oo0?mCoookJ_oonf[o0?l8o`3o7Ooonf[o0>7o00Wooo]Z00?o0?ld
o`3oC_l0obh01?oonfX01Ol0R?oo0:WooookJ_oonf[o00Co00;ooo]Z00?o0=CooookJ_oonfX02Ooo
nfX00oooP@3ooo]ZoookJP08oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX09?oo
nfX003Cooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP04oookJP03oolF0?ooTP3o
oo]Z00;ooo]Z00?oo`3loookJ_oonfX00_oonfX00olH0?oooo]Zool60002oookJP04on_o0?oonf[o
oo]Zo`2Vo`;oobP000?ooo]Zool0nOl0Mol00_oonfX01?ooK03o0?nJoookJ_lko`03oookJP03o`3k
oooonf[ooo]Z00;ooo]Z00Goo`00oookJ_oonf[o0:?ook?o0004oookJP04o`3og_oonf[oo`1/oook
JP?oo`0000?oolT0ool00?oonfX00_oonfX00ooo003ooo]Zo`3oTP08oookJP03onKo0?lH0?oooo]Z
00Oooo]Z1?oo00000om`0?oooo]ZoookJP02oookJP05oomG0?oonf[ooo]ZoookJ_oo02d03?oonfX0
0ol0e?oo00Coool00005ool00003o`3oC_oonf[ooo]Z00;ooo]Z2_oo0009oookJP?o403o1_oonfX7
oa00oa7ooo]Z00Go0000o`3oC_l0003o0000oookJP05oomi00;ooo]Z00?oo`00oookJ_oonfX01Ooo
nfX00om`0?oooo]ZoookJP03oookJP03onKo0?oo:03o603o00CoobP00_oonfX00omQ0?oooo]Zoook
JP04oookJP03ok?o0?oonf[ooo]Z00Cooo]Z00?oof`0oookJ_oonfX00_oonfX01_oo0?Kooo]Zoook
J_lH0?oooo]Zool0o0[ooo]Z1Ooo0008oookJP03oomB0?l0:_oooo]Z00;ooo]Z00?o0=coo`3ogooo
nfX00ooonfX00olB0?oo0?lKooo:0002oookJP03ool00?oo:03ooo]Z00;ooo]Z00GoobP0oookJ_oo
003oo`00obH0o`03ool000[ooo]Z00Go0?mKoookJ_n2o`3ooo]Zo`0`o`03oookJP03o`H0oooob@3o
oo]Z00;ooo]Z00Wo403ooookJ_oonf[ooo]Zool0DOoonf[o0:gooookJ_oo07T01OoonfX01_l0oe?o
oo]ZoookJ_oob@3o0?lMo`3Qo`Oooo]Z2?oUo`000ooonf[oolT0o`2Yo`02oookJP05o`04oooonf[o
oo]ZoookJ_nDo`002_oonfX00oooN@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?o
oeL0oookJ_oonfX0EOoonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Cooo]Z00?o
oaH0oookJ_ooTP000ooonfX00ooo0?cooo]ZoookJP02oookJP06oaP0oooo1P3ooo]ZoookJ_o[o`3o
o`3f0_oonfX02onX0?oooo]ZoookJ_oonf[oo`3io`1goooonf[oof`0o`3oV_oonf[o>ol000?ooo]Z
00?o0?_ooookJ_oonfX00ooonfX01?mi0?oooo]Zo`2Soonco`04oookJP0:omgo0?l0omkooo]Zool0
K?oonf[oC@3ooookJ_mQ0?oooo]Zo`3oA@;ooo]Z00?o0?n@oookJ_l0oi802OoonfX00olH0?oo07Co
oookJP08oookJP03oonn0?oonf[oL03o00Cooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]Z
oookJP0:oookJP05o`3Dool01?oooo]ZoookJ_l0R?l00_oonfX00ol0odkooo]ZoookJP05oookJP03
o`3o2?oonf[ooo]Z00kooo]Z0ol@0?l5oookJPOo403o4OoonfX01?l0003o0?m>o`3oC_l00002oook
JP03o`3Doooonf[ooo]Z00_ooo]Z00?oL03ooookJ_oonfX01?oonfX00ooVo`3o603ooookJP02oook
JP05o`3oT_oonf[ooo]ZoookJ_mQ0?l01OoonfX00onco`3ooo]ZoookJP04oookJP03oom/0?oonf[o
oo]Z00?ooo]Z00Goo`3foookJ_lH0?oooo]Zool0o00?oookJP03o`1coooonf[ooo]Z00Gooo]Z00?o
oe80oookJ_l0:_l00ooonfX00ol0omoooo]ZoookJP03oookJP03o`3o6ooobP3ooo]Z00;ooo]Z00?o
0?Woool04ooonfX00_oonfX01OoQo`3ooo]ZoookJ_lV0?ooQ03o00cooo]Z00Go0?mKoookJ_l0ok3o
P_l0o`0`o`03oookJP03o`H0oooo0?GoT_l000;ooo]Z00?o403ooookJ_oonfX00_oonfX01?oo057o
oo]Zo`2]oooo07T5oookJP07o`3oDooonf[ooo]Zo`3o2?l0oagooo]Zo`3Qo`08oookJP03o`3o=?oo
nf[o0?m>00Gooo]Z00Go08Soo`2Yoooonf[ooo]Zo`04o`02oookJP03o`3Doooonf[ooo]Z00Sooo]Z
00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z02Cooo]Z
000doookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01?oonfX00ooo5P3ooi80oook
JP02oookJP03ool0o?oonf[ooo]Z00;ooo]Z00?o603ooookJ_oo1P000_oonfX01?o[o`3oo`3foook
J_oonfX2oolX0004oookJ_oo0?Wooo]Zo`1go`;ooo]Z00?oof`0oookJ_lko`000ooonfX00ol0nooo
oo]ZoookJP02oookJP;oo`0000?ooo]Zo`2Soonco`001?oonfX01?l0omkooo]Zool0K?oonfX3ool0
0003ooo90?oo003ooo]Z00;ooo]Z00?oo`00oookJ_l0oi802OoonfX00olH0?oooo]ZoookJP07oook
JP?oo`0000?oL03ooookJ_oonfX00_oonfX00oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z
00[ooo]Z00?o0=Coo`04oooo00001Ooo00000ol0odkoo`00oookJP02oookJP[oo`002ooonfX6oa00
oaSooo]Z00Co0?m>o`000?l0003o00001?ooN@04oookJP;oo`000_oonfX01?oo003ooo]ZoookJ_m`
0?l5oookJP03onKo0?l0M?oo603o00KoobP000?ooo]Zof40oooonfX01?oonfX00onco`3ooo]Zoook
JP05oookJP03oom/0?oonf[ooo]Z00;ooo]Z00Goo`3foookJ_lH0?oooo]Zool0o00;oookJPOoo`00
1OoonfX00oooDP3ooo]Zo`0Zo`02oookJP03o`3Loooonf[o0?oO00?ooo]Z00?o4P3oo`3o6ooobP00
0ooonfX00ooo003oobP0oookJP02oookJP05oolX0?oonf[oo`00obH0oolPo`000_oo000;oookJP04
o`3oFooonf[oP_l0o`0`o`?ooo]Z00?o1P3oooo90?oo00000_oonfX01ol@0?oooo]ZoookJ_oonf[o
o`1AoookJ_l0[Ol00_oonfX01ooo07Wooo]ZoookJ_oonf[oolT0o`3oDooob@000_oonfX00ol0oago
oo]Zo`3Qo`07oookJPOoiOl00_oonfX01Ooob@3o0:WooookJ_oonf[o00Co00;ooo]Z00?oU?l0oook
J_oonfX02OoonfX00oooN@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0oook
J_oonfX0EOoonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Cooo]Z00?ooaH0oook
J_ooTP000ooonfX00ooo0?cooo]ZoookJP02oookJP0:oaP0oooo1P3ooo]ZoookJ_o[o`3ooo]Zool0
m_oonf[o0:KoojP0o`;ooo]Z00Ooo`3io`1goooonf[ooo]Zoom/0?oonf[o>ol000?ooo]Z00?o0?_o
oookJ_oonfX01?oonfX00omi0?oo0:?ook?o0005oookJP09o`3og_oonf[oo`1/oookJ_m=0?oooo]Z
of40oooonf[o0?m500;ooo]Z00Co0?n@oookJ_oonf[o0?nB2?oonfX00olH0?ooi_l0oookJP08oook
JP04oonn0?oonf[o0?l5og00o`?ooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP0;
oookJP04o`3Dool01?oooo]Zo`28o`?ooo]Z00?o0?m>oookJ_oonfX01OoonfX00ol0o`Sooo]Zoook
JP0@oookJPGo403o6?oonfX01_l0odko0000o`000?l0003ooo]Zo`3Do`[ooo]Z00CooeL0oookJ_oo
nf[oL03o1_oonfX00ooVo`3o603ooookJP03oookJP05o`3oT_oonf[ooo]ZoookJ_mQ0?l01?oonfX0
0onco`3ooo]ZoookJP05oookJP03oom/0?oonf[ooo]Z00;ooo]Z00Goo`3foookJ_lH0?oooo]Zool0
o00?oookJP03o`1coooonf[ooo]Z00Gooo]Z00Cooe80o`3o<ooonf[o02[o0_oonfX00ol0g?oo0?oO
oookJP03oookJP03o`3o6ooonf[oolX000;ooo]Z00?o0?WooookJ_oo01<00_oonfX01OoQo`3ooo]Z
oookJ_lV0?oo8?l000gooo]Z00Go0?mKoookJ_l0ok3oP_l0o`0`o`02oookJP03o`H0oooonf[oT_l0
00;ooo]Z00?o403ooookJ_oonfX00_oonfX01Ooo057ooo]Zo`2]oooonf[oo`1i00Cooo]Z00Go0?mC
oookJ_oonf[ooo]Zo`3o7@02oookJP03o`3Qoooonf[ooo]Z00Kooo]Z00?o0?ldo`3oC_l0obh01?oo
nfX00ol0R?oo0:WooookJP02oookJP03o`04oooonf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02Ooo
nfX00ooo02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z02Cooo]Z000doookJP03o`1coooonf[o
oo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01?oonfX00ooo5P3ooi80oookJP02oookJP03ool0o?oonf[o
oo]Z00?ooo]Z00Ko603oool60?oonf[ooo]Zon_o0?oo0?H2oookJP?oobP000?oo`3ioookJ_l0Mol0
0_oonfX00oooK03ooo]Zool00003oookJP03o`3koooonf[ooo]Z00;ooo]Z0ooo00000ol0Xooo/ol0
oookJP03oookJP04omgo0?l0omkoo`1/oookJP?oo`000_oob@001_oo003ooo]ZoookJ_oo003ooo]Z
oomi00Wooo]Z00?oi_l0oaP0oooonfX01ooonfX4ool00003og00oooonf[ooo]Z00;ooo]Z00GooeL0
oookJ_oonf[ooo]Zool0;@0=oookJP03o`3Dool01?ooo`0000Goo`0000Co0?m>ool00?oonf[ooo]Z
2?oo000ZoookJP05o`3oC_l0003o0000o`000?l01?l00oooN@04oookJPGoo`000_oonfX00om`0?oo
oo]ZoookJP03oookJP03onKo0?l0M?oo603o00OoobP000?oogT0oookJ_oonfX01?oonfX00onco`3o
oo]ZoookJP04oookJP03oom/0?oonf[ooo]Z00;ooo]Z00Koo`3foookJ_oonf[o603ooookJ_oo0?`;
oookJPSoo`001?oonfX00oooDP3ooo]Zo`0Zo`02oookJP03o`3Lool0omoooo]Z00?ooo]Z00?o4P3o
o`3o6ooobP000ooonfX00ooo003oobP0oookJP02oookJP04oolX0?oo003oo`00obH0o`?oo`002_oo
nfX01Ol0oe_ooo]Zoh;o0?l0ok3o033o00?ooo]Z00?o1P3oooo90?oonfX00_oonfX01ol@0?oooo]Z
oookJ_oonf[oo`1AoookJ_l0[Ol00_oonfX01_oo07Wooo]ZoookJ_oonf[oolT0o`3oD`?oolT000?o
0?lMo`3QoooonfX01ooonfX7onGo00;ooo]Z00Go0:WooookJ_oonf[ooo]Zo`04o`02oookJP03oiCo
0?oonf[ooo]Z00Wooo]Z00?oogT0oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP06oookJP03oomG
0?oonf[ooo]Z05Gooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP05oookJP03oolF
0?ooTP3ooo]Z00;ooo]Z00?oo`3loookJ_oonfX00ooonfX02Ooo1P3ooo]ZoookJ_o[o`3ooo]Zool0
m_oonf[o0:KoojP0o`02oookJP07ool0nOl0Mooooo]ZoookJ_ooK03ooo]Zoc_o0003oookJP03o`3k
oooonf[ooo]Z00Cooo]Z00CoN@3oo`2Soonco`3oW`3o1?oonfX00ol0omkooo]Zool0K002oookJP04
odd0oooonf[oH@3oo`3oA@;ooo]Z00Co0?n@oookJ_oonf[o0?nB2OoonfX00olH0?oo07CooookJP08
oookJP03oonn0?oonf[oL03o00Cooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP0;
oookJP04o`3Dool01?oooo]Zo`28o`?ooo]Z00?o0?m>oookJ_oonfX01OoonfX00ol0o`Sooo]Zoook
JP0[oookJP06o`3oC_l0003o0000o`000?l01?oo0=Co2_oonfX01?ooE`3ooo]ZoookJ_m`0?l6oook
JP03onKo0?lH0?oooo]Z00?ooo]Z00Go0?nBoookJ_oonf[ooo]Zof40o`05oookJP03ok?o0?oonf[o
oo]Z00Cooo]Z00?oof`0oookJ_oonfX00_oonfX01_oo0?Kooo]ZoookJ_lH0?oooo]Zool0o0oooo]Z
00?o07?ooookJ_oonfX01OoonfX00oooDP3ooo]Zo`0Zo`03oookJP03o`3ogooonf[ooo]Z00?ooo]Z
00?o0?lKoookJ_oobP000_oonfX00ol0nOooo`0CoookJP02oookJP05on7o0?oonf[ooo]ZobH0oon4
0?l03?oonfX01_l0oe_ooo]ZoookJ_n2o`3ooo]Zo`0`o`;ooo]Z00?o1P3ooookJ_nBo`000_oonfX0
0ol@0?oooo]ZoookJP02oookJP05ool0DOoonf[o0:gooookJ_oo07T01?oonfX01ol0oe?ooo]Zoook
J_oonf[o0?lMoookJ_l0hOl02OoonfX00ol0ocCo0?m>o`3o;P04oookJP03o`28ool0ZOoooo]Z00;o
oo]Z00?o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z00Ko
oo]Z00?ooeL0oookJ_oonfX09OoonfX003Cooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]Z
oookJP05oookJP05oolF0?ooTP3ooo]ZoookJ_oo0?`01OoonfX01_lH0?ooo`H0oookJ_oonf[ojol0
ool0mP;ooo]Z0ooo:0000ooo0?Wooo]Zo`1go`02oookJP03oom/0?oonf[oo`0000?ooo]Z00?o0?_o
oookJ_oonfX00_oonfX3ool00003oookJ_nco`3ooo]Z00Cooo]Z00?o0?oNoookJ_oo06`00ooo0003
ooo900Cooo]Z00?oogT0oookJ_oonfX02?oonfX00olH0?oooo]ZoookJP06oookJPGoo`001?oonfX0
0oooE`3ooo]ZoookJP02oookJP03ool0;Ooonf[ooo]Z00[ooo]Z00?o0=Coool00?l01?l01_oo0002
o`3oCP;ooo]Z1_oo000YoookJP;o0?m>00Cooo]Zo`000?l0003o00Co0_ooN@05oookJPKoo`0000?o
oo]Zog00oooonfX01OoonfX00ooVo`3o603ooolX0006oolX0003oookJ_ooN@3ooo]Z00Cooo]Z00?o
/ol0oookJ_oonfX01OoonfX00oooK03ooo]ZoookJP02oookJP05ool0m_oonf[o603ooookJ_oo0?`0
3?oonfX8ool000?ooo]Z00?ooe80o`3o<ol0:_l00_oonfX00ol0g?oooo]Zo`3og`04oookJP03o`3o
6ooonf[oolX000?ooo]Z00KoobP0oookJ_oonf[ooo]ZoolX0?oonfX2ool00003obH0oooo003oo`00
00_ooo]Z00Go0?mKoookJ_n2o`3o0?n`o`0`o`03oookJP03o`H0oooob@3ooo]Z00;ooo]Z00Wo403o
oookJ_oonf[ooo]Zool0DOoonf[o0:gooookJ_oo07T01?oonfX00ooob@3o0?mCooo90002ooo90004
o`3o7Ol0hOooolT0ooo900Kooo]Z1_oUo`02oookJP03ooo90?l0ZOoooo]Z00;ooo]Z00Co00Cooook
J_oonf[oU?l02ooonfX00oooN@3ooo]ZoookJP08oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0
oookJ_oonfX0E_oonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooaH0
oookJ_ooTP000_oonfX00ooo0?cooo]ZoookJP03oookJP09ool60?oonf[ooo]Zon_o0?oonf[oo`3f
oookJ_l0Y_ooZ03o00;ooo]Z00Ooo`3io`1goooonf[ooo]Zoom/0?oonf[o>ol000?ooo]Z00?o0?_o
oookJ_oonfX01?oonfX01?mi0?oooo]Zok?o0?nO0?l4oookJP0:o`3og_oonf[ooo]Zool0K?oonf[o
C@3ooookJ_mQ0?oooo]Zo`3oA@Cooo]Z00?o0?nBoookJ_oonfX01ooonfX00olH0?ooi_l0oookJP09
oookJP03oonn0?oonf[oL03o00?ooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]ZoookJP0;
oookJP05o`3Dool01?oooo]ZoookJ_l0R?l00ooonfX2o`3oCS7ooo]Z0_l0odh01Ooonf[o0000o`00
0?l01?oo0=Co00[ooo]Z00CooeL0oookJ_oonf[oL03o1ooonfX00olH0?oooo]ZoookJP02oookJP03
o`3oT_oonf[ooo]Z00;ooo]Z00?oH@3ooookJ_oonfX00_oonfX00onco`3ooo]ZoookJP05oookJP03
oom/0?oonf[ooo]Z00;ooo]Z00Goo`3foookJ_lH0?oooo]Zool0o00?oookJP03o`1coooonf[ooo]Z
00Gooo]Z00Cooe80o`3o<ooonf[o02[o0_oonfX00ol0g?oo0?oOoookJP03oookJP03o`3o6olB0?oo
olX000?ooo]Z00?o0?Woool04ooonfX00_oonfX01OoQo`3ooo]ZoookJ_lV0?ooQ03o00cooo]Z00Go
0?mKoookJ_oonf[oP_l0o`0`o`03oookJP03o`H0oooo0?GoT_l000;ooo]Z00?o403ooookJ_oonfX0
0_oonfX01?oo057ooo]Zo`2]oooo07T5oookJP07o`3oDooonf[ooo]Zo`3o2?l0oagooo]Zo`3Qo`08
oookJP04o`3o=?oonf[o0?m>o`3o;PCooo]Z00Go08Soo`2Yoooonf[ooo]Zo`04o`02oookJP03o`3D
oooonf[ooo]Z00Wooo]Z00?ooh40oookJ_oonfX02?oonfX00ooo02gooo]ZoookJP07oookJP03oomG
0?oonf[ooo]Z02Gooo]Z000doookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01Ooo
nfX01Ooo5P3ooi80oookJ_oonf[oo`3l00Gooo]Z00Ko603ooookJ_oo1P3ooo]Zon_o0?oo0?H2oook
JPCoobP000Koo`3io`1goooonf[ooo]Zoom/0?oonfX2ool000?ooo]Z00?o0?_ooookJ_oonfX00_oo
nfX3ool00003o`2Soonco`3ooo]Z00?ooo]Z00?o0?oNoookJ_oo06`00ooo0004ooo900?ooo]Z0_oo
N@09oookJP03oaP0oooonf[ooo]Z00Kooo]Z1_oo0003oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?o
o`0]oookJ_oonfX02ooonfX00ol0e?ooo`00o`04o`05ool000;ooo]Z00?o0?m>oookJ_oo00001?oo
000XoookJP;o0?m>0ooonfX00ol01?oo0=Cooomi0002o`0000Gooo]Z1_oo00000om`0?oooo]Zoook
JP04oookJP03onKo0?lH0?oooo]Z00KoobP000?ooo]Zoomi0?oonfX01?oonfX00onco`3ooo]Zoook
JP05oookJP03oom/0?oonf[ooo]Z00;ooo]Z00Koo`3foookJ_oonf[o603ooookJ_oo0?`;oookJPSo
o`001?oonfX00oooDP3ooo]Zo`0Zo`02oookJP03o`3Lool0omoooo]Z00?ooo]Z00?o4P3oo`3o6ooo
bP000ooonfX00ol0nOooobP0oookJP02oookJP04oolX0?oonf[oo`00obH0o`;oo`003?oonfX01?l0
oe_ooo]Zoh;o0?l0<?l3oookJP03o`H0oooob@3oo`0000;ooo]Z00Oo403ooookJ_oonf[ooo]Zool0
DOoonf[o0:go00;ooo]Z00?oo`1ioookJ_oonfX00_oonfX01ol0oe?oolT0ooo90?oob@3o0?lMooo9
0?l0hOl00_oob@06oookJPKoiOl00_oonfX01Ooob@3o0:WooookJ_oonf[o00Co00;ooo]Z00?oU?l0
oookJ_oonfX02OoonfX00oooN@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0
oookJ_oonfX0E_oonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooaH0
oookJ_ooTP000_oonfX00ooo0?cooo]ZoookJP03oookJP06oaP0oooo1P3ooo]Zon_o0?oonf[oo`3f
0_oonfX01Ol0Y_ooZ03ooookJ_oo0?Wo07Oo00;ooo]Z00Coof`0oookJ_oonf[o>ol00ooonfX00ol0
nooooo]ZoookJP04oookJP03ogT0ool0Xooo/ol000Cooo]Z00[ogOl0o`3og_oonf[oo`1/oookJ_m=
0?oooo]Zof40oooonf[o0?m51OoonfX00ol0oi;ooo]ZoookJP06oookJP03oaP0oooVo`3ooo]Z00Wo
oo]Z00?ookh0oookJ_m`0?l00ooonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00_o
oo]Z00Go0=Coo`04oooonf[ooo]Zo`28o`04oookJP03o`3oC_oonf[ooo]Z02cooo]Z0_l0odh3oook
JP03o`000?l0e?oo0=Co00;o00002?oonfX01?ooE`3ooo]ZoookJ_m`0?l7oookJP03oaP0oooonf[o
oo]Z00;ooo]Z00?o0?nBoookJ_oonfX00_oonfX00omQ0?oooo]ZoookJP02oookJP03ok?o0?oonf[o
oo]Z00Gooo]Z00?oof`0oookJ_oonfX00_oonfX01_oo0?Kooo]ZoookJ_lH0?oooo]Zool0o0oooo]Z
00?o07?ooookJ_oonfX01OoonfX01?ooDP3o0?lcoookJ_l0:_l2oookJP03o`3ogooonf[ooo]Z00?o
oo]Z00?o0?lKoookJ_oobP000_oonfX00ol0nOooo`0CoookJP02oookJP06on7o0?oonf[ooo]ZobH0
oooonf[oQ03o3?oonfX01Ol0oe_ooo]Zo`3o/?n2o`3o033o00;ooo]Z00?o1P3ooookJ_nBo`000_oo
nfX00ol@0?oooo]ZoookJP02oookJP05ool0DOoonf[o0:gooookJ_oo07T01?oonfX01Ol0oe?ooo]Z
oookJ_oonf[o0?lM00;ooo]Z00?o0>7ooookJ_oonfX01_oonfX01?l0ocCooo]Zo`3oC_l0obh3oook
JP03o`28oooonf[o0:Wo00;ooo]Z00?o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP09oook
JP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX09OoonfX003Cooo]Z00?o07?ooookJ_oo
nfX04_oonfX00ooo0>[ooo]ZoookJP05oookJP05oolF0?ooTP3ooo]ZoookJ_oo0?`01OoonfX01_lH
0?oooo]Zool60?oonf[ojol0ool0mP;ooo]Z1?oo:0000ooo0?WoobP0oookJP02oookJP04oom/0?oo
003oo`00ool000;ooo]Z00?o0?_ooookJ_oonfX00_oonfX3ool00003o`2Soonco`3ooo]Z00?ooo]Z
00Co0?oNoookJ_oonf[oo`1/0ooo0003ooo900Cooo]Z0_ooN@09oookJP03oaP0oooonf[ooo]Z00Ko
oo]Z1_oo0003oookJP03oomG0?oonf[ooo]Z00;ooo]Z00?oo`0]oookJ_oonfX02ooonfX00ol0e?oo
o`00o`04o`03ool000Cooo]Z00?o0?m>oookJ_oo00000_oo000WoookJP;o0?m>1?oonfX2o`3Do`?o
00001OoonfX6ool00003og00oooo003oo`0000Cooo]Z00?oi_l0o`1doolH0?l00_oo:002oomi00;o
obP000?ooo]Zoomi0?oonfX01?oonfX00onco`3ooo]ZoookJP06oookJP05oom/0?oonf[ooo]Zoook
J_oo0?H00_oonfX01?lH0?oooo]ZoookJ_oo0?`;oookJPOoo`001OoonfX01oooDP3ooo]Zo`0Zoooo
nf[o0=cooookJ_l0oml01?oonfX00ol0oa_ooo]Zooo:0003oookJPCoobP000Gooo]ZoolX0?oonf[o
o`00obH0o`02ool000_ooo]Z00Go0?mKoookJ_n2o`3o0?n`o`0`o`03oookJP03o`H0oooob@3ooo]Z
00;ooo]Z00Oo403ooookJ_oonf[ooo]Zool0DOoonf[o0:go00;ooo]Z00?oo`1ioookJ_oonfX00_oo
nfX02?l0oe?oolT0ooo90?oob@3o0?lMooo90?l0hOooolT01ooonfX5onGo00?ooo]Z00GoolT0o`2Y
oooonf[ooo]Zo`04o`02oookJP03oiCo0?oonf[ooo]Z00Wooo]Z00?oogT0oookJ_oonfX02OoonfX0
0ooo02gooo]ZoookJP06oookJP03oomG0?oonf[ooo]Z05Kooo]Z00?o07?ooookJ_oonfX04_oonfX0
0ooo0>[ooo]ZoookJP05oookJP03oolF0?oonf[ooi8000;ooo]Z00?oo`3loookJ_oonfX00ooonfX0
1_lH0?ooo`H0oookJ_oonf[ojol0ool0mP;ooo]Z00Go0:KoojP0oooonf[ooo]Zo`1go`03oookJP03
oom/0?oonf[o>ol000?ooo]Z00?o0?_ooookJ_oonfX01?oonfX01?mi0?oo0:?ook?o0?nO0?l4oook
JP03o`3og_oonf[oo`1/00;ooo]Z00CoC@3ooookJ_mQ0?oo0?m51OoonfX00ol0oi;ooo]ZoookJP07
oookJP03oaP0oooVo`3ooo]Z00Wooo]Z00?ookh0oookJ_m`0?l00ooonfX00oooE`3ooo]ZoookJP03
oookJP03ool0;Ooonf[ooo]Z00_ooo]Z00Go0=Coo`04oooonf[ooo]Zo`28o`04oookJP03o`3oC_oo
nf[ooo]Z02Wooo]Z0_l0odh4oookJP;o0=Co0ol00008oookJP04oomG0?oonf[ooo]Zog00o`Oooo]Z
00?oi_l0oaP0oooonfX00ooonfX01Ol0oi;ooo]ZoookJ_oonf[oH@3o00Gooo]Z00?o/ol0oookJ_oo
nfX01OoonfX00oooK03ooo]ZoookJP02oookJP03ool0m_oonf[o603o00;ooo]Z00?oo`3loookJ_oo
nfX03OoonfX00ol0Looooo]ZoookJP05oookJP03oomB0?oonf[o02[o00;ooo]Z00?o0=coo`3ogooo
nfX00ooonfX00ol0oa_o4P3oooo:0003oookJP03o`3ioooo01?ooo]Z00;ooo]Z00GohOl0oookJ_oo
nf[o9P3ooh@0o`0<oookJP06o`3oFooonf[ooo]Zoh;o0?oonf[o033o0_oonfX00ol60?oooo]Zoi;o
0002oookJP03oa00oooonf[ooo]Z00;ooo]Z00Goo`1AoookJ_l0[Ooooo]Zool0N@04oookJP05o`3o
Dooonf[ooo]ZoookJ_l0oad00_oonfX00ol0hOoooo]ZoookJP06oookJP03o`3o=?oonf[o0?m>00Co
oo]Z00?o08SooookJ_l0ZOl00_oonfX00ol01?oooo]Zo`3Do`0;oookJP03oon10?oonf[ooo]Z00Wo
oo]Z00?oo`0]oookJ_oonfX01ooonfX00oooE`3ooo]ZoookJP0UoookJP00=?oonfX00ol0Looooo]Z
oookJP0BoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooaH0oonB0?oonfX00_oonfX00ooo0?cooo]Z
oookJP02oookJP06oaP0oooonf[oo`H0oookJ_o[o`3oo`3f0_oonfX4oolX0003ool0nOoo:03ooo]Z
00;ooo]Z00Coof`0ool00?oo003oo`000_oonfX00ol0nooooo]ZoookJP02oookJP?oo`0000?o0:?o
ok?o0?oonfX00ooonfX01?oMo`3o0?oNoookJ_oo06`3ool000CoolT00ooonfX3oomi00Sooo]Z00?o
603ooookJ_oonfX01_oonfX7ool000;ooo]Z00?ooeL0oookJ_oonfX00_oonfX00ooo02gooo]Zoook
JP0<oookJP;o0=Co00?o00Coool00?oonfX01OoonfX00ol0odkooo]Zool0000VoookJP;o0?m>1?oo
nfX00ol01?oo0=CooookJP04o`0000Gooo]Z1Ooo00000om`0?ooo`00oookJP04oookJP04onKo0?l0
M?oo603ooookJP;oobP00oooN@000ooonf[oogT0oookJP05oookJP03ok?o0?oonf[ooo]Z00Gooo]Z
00?oof`0oookJ_oonfX00_oonfX00ooo0?Kooo]ZoaP0o`02oookJP03ool0o?oonf[ooo]Z00[ooo]Z
1ooo0004oookJP03oomB0?oonf[o02[o00;ooo]Z00?o0=cooookJ_l0oml01?oonfX00ol0oa_oolX0
oookJP02oookJP03o`3ioooo:03oobP000GoobP000?o9P3oob3o0?oo00003?oonfX01Ol0oe_ooo]Z
oh;o0?l0ok3o033o00?ooo]Z00?o1P3oooo90?oonfX00_oonfX02Ol@0?oooo]ZoookJ_oonf[oo`1A
oookJ_l0[Ooooo]Zool0N@05oookJP06o`3oDooob@3oolT0ooo90?l0oago0>7o0_oob@07oookJPGo
iOl00_oonfX00ooob@3ooo]Zo`2Yo`02oookJP04o`04oooonf[ooo]ZoiCo00_ooo]Z00?oogT0oook
J_oonfX02OoonfX00ooo02gooo]ZoookJP05oookJP03oomG0?oonf[ooo]Z05Oooo]Z00?o07?ooook
J_oonfX04_oonfX00ooo0>[ooo]ZoookJP06oookJP03oolF0?ooTP3ooo]Z00;ooo]Z00?oo`3loook
J_oonfX00_oonfX01_lH0?ooo`H0oookJ_oonf[ojol0ool0mP;ooo]Z00Go0:KoojP0oooonf[ooo]Z
o`1go`03oookJP03oom/0?oonf[o>ol000?ooo]Z00?o0?_ooookJ_oonfX01?oonfX01?mi0?oo0:?o
ok?o0?nO0?l4oookJP09o`3og_oonf[ooo]Zool0K?oonf[oC@3ooookJ_mQ0?oo0?m500Kooo]Z00?o
0?nBoookJ_oonfX01_oonfX00olH0?ooi_l0oookJP09oookJP04oonn0?oonf[ooo]Zog00o`;ooo]Z
00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP0<oookJP;o0=Co1ooonfX00ol0odkooo]Z
oookJP0WoookJP03o`3oC_oonf[ooo]Z00?ooo]Z00?o0=CooookJ_l000000ol00007oookJP04oomG
0?oonf[ooo]Zog00o`Oooo]Z00?oi_l0oaP0oooonfX00ooonfX01Ol0oi;ooo]ZoookJ_oonf[oH@3o
00Gooo]Z00?o/ol0oookJ_oonfX01OoonfX00oooK03ooo]ZoookJP02oookJP03ool0m_oonf[o603o
00;ooo]Z00?oo`3loookJ_oonfX03OoonfX00ol0Looooo]ZoookJP05oookJP04oomB0?l0oc?ooo]Z
o`0Zo`;ooo]Z00?o0=coo`3ogooonfX00ooonfX00ol0oa_o4P3oooo:0002oookJP03o`3ioooonf[o
o`0C00?ooo]Z00GohOl0oookJ_lV0?oo8?l0oh@0o`0<oookJP05o`3oFooonf[ooo]Zoh;o0?l0<?l0
0ooonfX00ol60?oooo]Zoi;o0002oookJP03oa00oooonf[ooo]Z00;ooo]Z00Coo`1AoookJ_l0[Ooo
o`1i1OoonfX01ol0oe?ooo]ZoookJ_oonf[o0?lMoookJ_l0hOl02?oonfX01?l0ocCooo]Zo`3oC_l0
obh4oookJP05o`28ool0ZOoooo]ZoookJ_l01?l00_oonfX00ol0e?oooo]ZoookJP09oookJP03oon1
0?oonf[ooo]Z00Wooo]Z00?oo`0]oookJ_oonfX01_oonfX00oooE`3ooo]ZoookJP0VoookJP00=Ooo
nfX00ol0Looooo]ZoookJP0AoookJP03ool0j_oonf[ooo]Z00Kooo]Z00Gooi80oookJ_oonf[ooo]Z
ool0o004oookJP03oaP0oooonf[oo`H000;ooo]Z00?ojol0oookJ_oonfX01?oo:0000ooo0?WoobP0
oolX0002oookJP03oom/0?oo003oo`0000;oo`0000?ooo]Zo`3koooonfX00ooonfX3ool00003o`2S
oonco`3oW`3o00Cooo]Z00?o0?oNoookJ_oo06`00ooo0005ooo900;ooo]Z1?ooN@07oookJP03oaP0
oooVo`3ooo]Z00Kooo]Z2?oo0002oookJP03oomG0?oonf[ooo]Z00;ooo]Z0_oo02d<oookJP;oo`00
00?o0=Coo`04ool01?l01_oonfX2o`3oCRCooo]Z0_l0odh5oookJP;o0=Co0_oonfX4o`0000Cooo]Z
1Ooo00000om`0?ooo`00oookJP05oookJP03onKo0?lH0?oooo]Z00;oobP01_ooN@05oookJP03ok?o
0?oonf[ooo]Z00Gooo]Z00?oof`0oookJ_oonfX00_oonfX01?oo0?Kooo]ZoookJ_lH0?l2oookJP03
ool0o?oonf[ooo]Z00[ooo]Z1_oo0005oookJP07oomB0?oonf[o02[ooookJ_l0g?oooo]Zo`3og`04
oookJP03oa80ool0oa_oolX000?ooo]Z00?o0?WooolX0?oo:0001Ooo:0000olV0?ooo`00ool0000;
oookJP05o`3oFooonf[ooo]Zoh;o0?l0<?l01?oonfX01Ooob@3oo`00oookJ_oonf[o403o00Cooo]Z
00Goo`1Ao`2]oooonf[ooo]Zool0N@05oookJP07o`3oDooob@3oolT0o`3o7Ooob@3o0>7oooo90008
oookJPCoiOl00ooonfX01Ooob@3o0:WooookJ_oonf[o00Co00;ooo]Z00?oU?l0oookJ_oonfX02Ooo
nfX00oooN@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0oookJ_oonfX0F?oo
nfX00ol0Looooo]ZoookJP0AoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oonB0?oonfX00_oo
nfX00ooo0?cooo]ZoookJP02oookJP06oaP0oooo1P3ooo]ZoookJ_o[o`3oo`3f0_oonfX01_l0Y_oo
Z03ooookJ_oonf[oo`3io`1go`;ooo]Z00Coof`0oookJ_oonf[o>ol00_oonfX00ol0nooooo]Zoook
JP05oookJP03o`2Soonco`3oW`3o00Cooo]Z00Ko0?oNoookJ_oonf[oo`1/oookJ_m=0?l2oookJP03
of40ool0odGooo]Z00Cooo]Z00?o0?nBoookJ_oonfX01_oonfX00olH0?oo07CoonKo000:oookJP03
oonn0?oonf[oL03o00?ooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP0=oookJP03
o`3Dool01?oooo]Z00Gooo]Z0ol0odhToookJP;o0?m>1?oonfX2o`3Do`;ooo]Z1?l00006oookJP04
oomG0?oonf[ooo]Zog00o`Oooo]Z00?oi_l0oaP0oooonfX00ooonfX01Ol0oi;ooo]ZoookJ_oonf[o
H@3o00Gooo]Z00?o/ol0oookJ_oonfX01OoonfX00oooK03ooo]ZoookJP03oookJP03ool0m_oonf[o
603o00;ooo]Z00?oo`3loookJ_oonfX03OoonfX00ol0Looooo]ZoookJP05oookJP03oomB0?oonf[o
02[o00;ooo]Z00?o0=coo`3ogooonfX01?oonfX00ol0oa_ooo]Zooo:0002oookJP03o`3ioooo01?o
oo]Z00;ooo]Z00KohOl0oookJ_oonf[o9P3ooookJ_n40?l;oookJP06o`3oFooonf[ooo]Zo`3o/?n2
o`3o033o0ooonfX01Ol60?ooT_l0oookJ_oonf[o403o00Gooo]Z00Coo`1Ao`2]oooonf[oo`1i1Ooo
nfX01?l0oe?ooo]ZoookJ_l0oad2oookJP03o`3Qoooonf[ooo]Z00Kooo]Z00Co0?ldoookJ_l0odko
0?l^0ooonfX00ol0R?oooo]Zo`2Yo`02oookJP03o`04oooonf[o0=Co00_ooo]Z00?ooh40oookJ_oo
nfX02OoonfX00ooo02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z02Kooo]Z000eoookJP03o`1c
oooonf[ooo]Z017ooo]Z00?oo`3ZoookJ_oonfX01_oonfX01Ooo5P3ooi80oookJ_oonf[oo`3l00Go
oo]Z00Go603oool60?oonf[ooo]Zon_o0002oookJPCoobP000Koo`3ioolX0?oo:03oobP0oookJ_l0
oiX5ool00003o`3koooonf[ooo]Z00;ooo]Z1?oo00000ol0Xooo/ol0oookJP03oookJP04o`3og_oo
nf[ooo]Zool0K0;oo`001_oob@000ooonf[oogT0oomi0003oomi00Oooo]Z00?o603ooookJ_oonfX0
1_oonfX8ool000;ooo]Z00?ooeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP0:oookJP05ool0
0?oonf[o0=CooookJ_l01?l01ooonfX3o`3oCQoooo]Z0_l0odh5oookJP;o0=Co1?oonfX4o`0000?o
oo]Z1Ooo00000om`0?oooo]ZoookJP05oookJP04onKo0?lH0?oooo]ZoookJP;oobP01_ooN@04oook
JP03ok?o0?oonf[ooo]Z00Kooo]Z00?oof`0oookJ_oonfX00_oonfX00ooo0?Kooo]ZoaP0o`02oook
JP03ool0o?oonf[ooo]Z00_ooo]Z1Ooo0005oookJP03o`3o<oooDP3o02[o00;ooo]Z00?o0=cooook
J_l0oml01?oonfX00ol0oa_ooo]Zooo:0003oookJP03oolX0?oonf[oobP000GoobP000?o9P3oool0
0?oonfX02ooonfX01Ol0oe_ooo]ZoookJ_n2o`3o033o00?ooo]Z00?o1P3oooo90?oo00000_oonfX0
1ol@0?oooo]ZoookJ_oonf[oo`1AoookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP02oookJP08o`3o
Dooob@3oolT0ooo90?l0oagoolT0o`3Qoooob@08oookJPCoiOl00ooonfX01Ooob@3o0:WooookJ_oo
nf[o00Co00;ooo]Z00?oU?l0oookJ_oonfX02OoonfX00oooN@3ooo]ZoookJP09oookJP03ool0;Ooo
nf[ooo]Z00Kooo]Z00?ooeL0oookJ_oonfX0F?oonfX00ol0Looooo]ZoookJP0AoookJP03ool0j_oo
nf[ooo]Z00Kooo]Z00?ooaH0oookJ_ooTP000_oonfX00ooo0?cooo]ZoookJP03oookJP05ool60?oo
nf[ooo]Zon_o0?oo0?H00ooonfX01Ol0Y_ooZ03ooookJ_oo0?Wo07Oo00;ooo]Z00Co0?nJoom/0?oo
nf[o>ol00_oonfX00ol0nooooo]ZoookJP05oookJP04ogT0ool0Xooo/ol0oil0o`?ooo]Z00[o0?oN
oookJ_oonf[ooo]Zool0K?oonf[oC@3ooookJ_mQ0?oo0?m51_oonfX00ol0oi;ooo]ZoookJP06oook
JP03oaP0oooVo`3ooo]Z00[ooo]Z00?ookh0oookJ_m`0?l00ooonfX00oooE`3ooo]ZoookJP03oook
JP03ool0;Ooonf[ooo]Z00gooo]Z00?o0=Coo`04ool01?l01ooonfX3o`3oCQoooo]Z0_l0odh4oook
JP;o0=Co1?oonfX4o`0000Gooo]Z00CooeL0oookJ_oonf[oL03o1ooonfX00ooVo`3o603ooookJP03
oookJP05o`3oT_oonf[ooo]ZoookJ_mQ0?l01_oonfX00onco`3ooo]ZoookJP05oookJP03oom/0?oo
nf[ooo]Z00;ooo]Z00?oo`3foookJ_lH0?l00_oonfX00ooo0?cooo]ZoookJP0=oookJP03o`1coooo
nf[ooo]Z00Kooo]Z00?ooe80oookJ_l0:_l00_oonfX00ol0g?oo0?oOoookJP03oookJP03o`3o6olB
0?ooolX000?ooo]Z00?o0?Woool04ooonfX00_oonfX01OoQo`3ooo]ZoookJ_lV0?ooQ03o00cooo]Z
00Ko0?mKoookJ_oonf[o0?n`oh;o0?l0<?l2oookJP03o`H0oooonf[oT_l000;ooo]Z00?o403ooook
J_oonfX00_oonfX01Ooo057ooo]Zo`2]oooonf[oo`1i00Cooo]Z00Go0?mCoookJ_oonf[ooo]Zo`3o
7@02oookJP03o`3Qoooonf[ooo]Z00Kooo]Z00Co0?ldoookJ_l0odko0?l^0ooonfX00ol0R?oooo]Z
o`2Yo`02oookJP03o`04oooonf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]Z
oookJP07oookJP03oomG0?oonf[ooo]Z02Kooo]Z000eoookJP03o`1coooonf[ooo]Z01;ooo]Z00?o
o`3ZoookJ_oonfX01OoonfX00ooo5P3ooi80oookJP02oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Oo
603oool60?oonf[ooo]Zon_o0?oo0?Kooo]Z00CoobP000Koo`3ioolX0?oo:03oobP0oookJ_l0oiX6
ool000Cooo]Z1?oo00000ol0Xooo/ol0ool00003oookJP04omgo0?l0omkooo]Zool0K0;oo`001_oo
b@000ooonf[oogT0oomi0003oomi00Oooo]Z00?o603oonKo0?oonfX01_oonfX9ool000;ooo]Z00?o
oeL0oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP0<oookJP;o0=Co0_l01?l8oookJP?o0?m>6Ooo
nfX3o`3oCPKooo]Z00?o0=CooookJ_oonfX01?oonfX4o`0000?ooo]Z1?oo00000om`0?oooo]Zoook
JP05oookJP04onKo0?lH0?oooo]ZoookJP;oobP02?ooN@02oookJP03ok?o0?oonf[ooo]Z00Kooo]Z
00?oof`0oookJ_oonfX00_oonfX01?oo0?Kooo]ZoookJ_lH0?l2oookJP03ool0o?oonf[ooo]Z00_o
oo]Z1?oo0006oookJP03oomB0?oonf[o02[o00;ooo]Z00?o0=coo`3ogooonfX01?oonfX00ol0oa_o
olX0oookJP02oookJP03o`3ioooo:03ooo]Z00GoobP000?o9P3oob3o0?oonfX03?oonfX01Ol0oe_o
oo]Zoh;o0?l0ok3o033o00?ooo]Z00?o1P3oooo90?oonfX00_oonfX02Ol@0?oooo]ZoookJ_oonf[o
o`1AoookJ_l0[Ooooo]Zool0N@05oookJP07o`3oDooob@3oolT0ooo90?l0oago0>7oooo90008oook
JP04o`3o=?oUo`3oiOl0onGo00Cooo]Z00GoolT0o`2Yoooonf[ooo]Zo`04o`02oookJP03oiCo0?oo
nf[ooo]Z00Wooo]Z00?oogT0oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP06oookJP03oomG0?oo
nf[ooo]Z05Sooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP05oookJP03oolF0?oo
nf[ooi8000?ooo]Z00?oo`3loookJ_oonfX00_oonfX01_oo1P3ooo]ZoookJ_o[o`3ooo]Zool0mP;o
oo]Z00Go0:KoojP0oooonf[oo`3io`1go`02oookJP04o`3oV_ooK03ooo]Zoc_o00;ooo]Z00?o0?_o
oookJ_oonfX01OoonfX01?mi0?oo0:?ook?o0?nO0?l4oookJP08o`3og_oonf[ooo]Zool0K?oonf[o
C@3ooookJ_mQ0?l7oookJP03o`3oT_oonf[ooo]Z00Kooo]Z00?o603oo`1doooVo`002_oonfX00ooo
_P3ooo]Zog00o`04oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX03OoonfX2o`3D
o`03o`04oooonf[ooo]Z00Oooo]Z0ol0odhIoookJP?o0?m>1OoonfX00ol0e?oo00CooookJP04oook
JPCo00001?oonfX01?ooE`3ooo]ZoookJ_m`0?l7oookJP03onKo0?lH0?oooo]Z00Cooo]Z00Go0?nB
oookJ_oonf[ooo]Zof40o`05oookJP03ok?o0?oonf[ooo]Z00Gooo]Z00?oof`0oookJ_oonfX00_oo
nfX01?oo0?Kooo]ZoookJ_lH0?l2oookJP03ool0o?oonf[ooo]Z00gooo]Z00?o07?ooookJ_oonfX0
1OoonfX01?ooDP3ooo]ZoookJ_l0:_l2oookJP03o`3ogooonf[ooo]Z00?ooo]Z00?o0?lKoa80oooo
bP000_oonfX00ol0nOooo`0CoookJP03oookJP05on7o0?oonf[o9P3oob3o0?n40?l03?oonfX01Ol0
oe_ooo]ZoookJ_n2o`3o033o00?ooo]Z00?o1P3ooookJ_nBo`000_oonfX00ol@0?oooo]ZoookJP02
oookJP04ool0DOoonf[o0:goool0N@Gooo]Z00Oo0?mCoookJ_oonf[ooo]Zo`3o7Ooonf[o0>7o00So
oo]Z00Co0?ldoookJ_oonf[o0?m>1?oonfX01Ol0R?oooo]Zo`2Yoooonf[o00Co00;ooo]Z00?o0=Co
oookJ_oonfX02OoonfX00oooP@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0
oookJ_oonfX09ooonfX003Gooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP05oook
JP03oolF0?ooTP3ooo]Z00;ooo]Z00?oo`3loookJ_oonfX00_oonfX01olH0?ooo`H0oookJ_oonf[o
jol0ool0m_oonfX01Ooo:0001Ooo0?WoobP0oolX0?oo:03ooo]Z00Koo`0000Co0?_ooookJ_oonf[o
oo]Z1?oo00000ol0Xooo/ol0ool00003oookJP06omgo0?l0omkooo]Zool00?oo06cooo]Z1ooob@00
0ooonf[oogT0oomi0003oomi00Kooo]Z00?o603oonKo0?oonfX01_oonfX7ool000Gooo]Z00?ooeL0
oookJ_oonfX00ooonfX00ooo02gooo]ZoookJP0=oookJP04o`3Doooonf[o00Coo`04o`Wooo]Z0ol0
odhBoookJPCo0?m>1ooonfX2o`3Do`Oooo]Z1?l00002oookJPCoo`0000?oL03ooookJ_oonfX01Ooo
nfX00ooVo`3o07CooaP0o`02oookJP;oobP02OooN@000ooonf[o/ol0oookJP06oookJP03oom/0?oo
nf[ooo]Z00;ooo]Z00Coo`3foookJ_oonf[o603o0_oonfX00ooo0?cooo]ZoookJP0<oookJPCoo`00
1OoonfX02?l0oc?ooe80oookJ_l0:_oooo]Zo`3Loooonf[o0?oO1?oonfX00ol0oa_ooo]Zooo:0003
oookJP03oolX0?oonf[oobP000GoobP000?o9P3ooh@0oooonfX02ooonfX01_l0oe_ooo]ZoookJ_n2
o`3o0?n`oookJP;oo`0000?ooo]Zo`H0oooob@000_oonfX00ol@0?oooo]ZoookJP02oookJP05ool0
DOl0[Ooooo]ZoookJ_oo07T01OoonfX01ol0oe?ooo]Zooo90?l0oagoolT0o`3Qoooob@002?oonfX0
1?l0ocCoiOl0onGo0?oUo`03oookJP03ooo90?oonf[o0:Wo00;ooo]Z00?o00CooookJ_nDo`002ooo
nfX00oooN@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooeL0oookJ_oonfX0FOoo
nfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oonB0?oonfX00_oo
nfX00ooo0?cooo]ZoookJP02oookJP06oaP0oooo1P3ooo]Zon_o0?oonf[oo`3f0_oonfX01_l0Y_oo
Z03ooookJ_oonf[oo`3io`1go`;ooo]Z00Coof`0oookJ_oonf[o>ol00_oonfX00ol0nooooo]Zoook
JP05oookJP03o`2Soonco`3oW`3o00Cooo]Z00Co0?oNoookJ_oonf[oo`1/0_oonfX00om=0?oooo]Z
of40o`06oookJP03o`3oT_oonf[ooo]Z00Kooo]Z00?o603oo`1doooVo`002ooonfX00ooo_P3ooo]Z
og00o`04oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX03_oonfX00ol0e?oo00Co
o`04o`0:oookJP?o0?m>4_oonfX4o`3oCPKooo]Z0_l0e?l00ol01?oooo]ZoookJP04oookJPCo0000
0ooonfX01?ooE`3ooo]ZoookJ_m`0?l7oookJP03onKo0?l0M?oo603o00Cooo]Z00Go0?nBoookJ_oo
nf[ooo]Zof40o`05oookJP03ok?o0?oonf[ooo]Z00Gooo]Z00?oof`0oookJ_oonfX00ooonfX00ooo
0?Kooo]ZoaP0o`02oookJP03ool0o?oonf[ooo]Z00gooo]Z00?o07?ooookJ_oonfX01_oonfX00ooo
DP3ooo]Zo`0Zo`02oookJP03o`3Lool0omoooo]Z00?ooo]Z00?o0?lKoa80oooobP000ooonfX00ol0
nOooo`0CoookJP02oookJP06on7o0?oonf[ooo]ZobH0oooonf[oQ03o2ooonfX01_l0oe_ooo]Zoook
J_oonf[oP_l0o`0`o`?ooo]Z00Go1P3oool0mOnBo`3ooo]Zoa00o`05oookJP04ool0DOl0[Ooooo]Z
ool0N@Gooo]Z00Oo0?mCoookJ_oonf[o0?lMo`3o2?oonf[o0>7o00Sooo]Z00Co0?ldoookJ_oonf[o
0?m>1?oonfX01ol0R?oooo]Zo`2Yoooonf[o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP0:
oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0oookJ_oonfX09ooonfX003Gooo]Z00?o07?ooook
J_oonfX04_oonfX00ooo0>[ooo]ZoookJP05oookJP03oolF0?ooTP3ooo]Z00;ooo]Z00?oo`3loook
J_oonfX00_oonfX01olH0?oooo]Zool60?oonf[ojol0ool0m_oonfX01Ooo:0000ooo0?WoobP0oolX
0002oolX0003oom/0?oo003oo`0000Coo`001?oonfX3ool00004o`2Soonco`3oo`00ool000;ooo]Z
00KogOl0o`3og_oonf[ooo]Zool0K?oonfX8ooo900KoogT01_oonfX00olH0?ooi_l0oookJP05oook
JPGoo`000_oonfX00om`0?oooo]ZoookJP03oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oook
J_oonfX03OoonfX2o`3Do`03oookJ_l01?oooo]Z00[ooo]Z1ol0odh7oookJPCo0?m>2?oonfX00ol0
1?oo0=Coo`3Do`09oookJPCo00000_oonfX2ool000;oL03o1ooonfX00ooVo`3o07CooaP0o`03oook
JP03oolX0?oonf[oogT000KoogT00_oonfX00onco`3ooo]ZoookJP06oookJP03oom/0?oonf[ooo]Z
00;ooo]Z00Koo`3foookJ_oonf[o603ooookJ_oo0?`?oookJP?oo`001_oonfX00oooDP3ooo]Zo`0Z
o`02oookJP03o`3Loooonf[o0?oO00Cooo]Z00?o0?lKooo:0?oonfX00_oonfX00ol0nOooobP0oook
JP06oolX0003obH0oooonf[ooo]Z00_ooo]Z00Ko0?mKoookJ_oonf[oP_l0o`0`oooonfX2ool00003
o`H0oooob@3oo`0000;ooo]Z00Oo403ooookJ_oonf[ooo]Zool0DOoonf[o0:go00;ooo]Z00?oo`1i
oookJ_oonfX00ooonfX01_l0oe?ooo]Zooo90?l0oagoolT0o`3Qo`Wooo]Z00?o0?ldonGo0?oUo`00
1?oonfX01Ooob@3o0:WooookJ_oonf[o00Co00;ooo]Z00?oU?l0oookJ_oonfX02OoonfX00oooN@3o
oo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0oookJ_oonfX0FOoonfX00ol0Looo
oo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oonB0?oonfX00_oonfX00ooo0?co
oo]ZoookJP02oookJP06oaP0oooo1P3ooo]Zon_o0?oonf[oo`3f0_oonfX01_l0Y_oooo]ZojP0oooo
nf[oo`3io`1go`;ooo]Z00Coof`0oookJ_oonf[o>ol00_oonfX00ol0nooooo]ZoookJP05oookJP04
o`2Soonco`3ooo]Zoil0o`?ooo]Z00Wo0?oNoookJ_oonf[ooo]Zool0K?oonf[oC@3ooookJ_mQ0?l0
1ooonfX00ol0oi;ooo]ZoookJP06oookJP03oaP0ool0M?ooi_l000[ooo]Z00Cookh0oookJ_oonf[o
L03o1?oonfX00oooE`3ooo]ZoookJP03oookJP03ool0;Ooonf[ooo]Z00kooo]Z0_l0e?l2o`04o`_o
oo]Z1ol0odh7oookJPCo0?m>2?oonfX2o`3Do`03o`04oooonf[ooo]Z00Kooo]Z1?l00002oookJP04
oomG0?oonf[oL03oog00o`Oooo]Z00?oi_l0o`1doolH0?l01?oonfX01Ol0oi;ooo]ZoookJ_oonf[o
H@3o00Gooo]Z00?o/ol0oookJ_oonfX01_oonfX00oooK03ooo]ZoookJP02oookJP06ool0m_oonf[o
oo]ZoaP0oooonf[oo`3l4?oonfX00ol0Looooo]ZoookJP05oookJP04oomB0?l0oc?ooo]Zo`0Zo`;o
oo]Z00?o0=coo`3ogooonfX00ooonfX00ol0oa_o4P3oooo:0002oookJP03o`3ioooo01?ooo]Z00?o
oo]Z00GohOl0oookJ_oonf[o9P3ooh@0o`0<oookJP05o`3oFooonf[ooo]Zo`3o/?n2o`000ooonfX0
0ol60?oooo]Zoi;o0002oookJP03oa00oooonf[ooo]Z00;ooo]Z00Goo`1AoookJ_l0[Ooooo]Zool0
N@05oookJP04o`3oDooonf[ooo]Zo`3o7@;ooo]Z00?o0>7ooookJ_oonfX01_oonfX01?l0ocCooo]Z
o`3oC_l0obh3oookJP03o`28oooonf[o0:Wo00;ooo]Z00?o00CooookJ_l0e?l02ooonfX00oooP@3o
oo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX09ooonfX003Gooo]Z
00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP06oookJP03oolF0?ooTP3ooo]Z00;ooo]Z
00_oo`3loookJ_oonf[ooo]ZoaP0oooonf[oo`H0oookJ_o[o`3oo`3foookJP05oolX0003ool0nOoo
:03oobP000?oobP01ooo0003oookJPCoo`0000Co/ol0ool00?oo003oo`000_oonfX01_l0omkooo]Z
oookJ_oonf[oo`1/oookJPSoolT01_ooN@05oookJP03oaP0oooVo`3ooo]Z00Kooo]Z0ooo00001?oo
nf[oo`00oookJ_m`0?l6oookJP03oomG0?oonf[ooo]Z00?ooo]Z00?oo`0]oookJ_oonfX03_oonfX0
1?l0e?oooo]Zo`04ool01?l@oookJPOo0?m>2_oonfX3o`3Do`_ooo]Z1?l000001?oonf[oo`00oook
J_m`0?l8oookJP03onKo0?l0M?oo603o00?ooo]Z00?oobP0oookJ_ooN@001_ooN@02oookJP03ok?o
0?oonf[ooo]Z00Kooo]Z00?oof`0oookJ_oonfX00_oonfX01?oo0?Kooo]ZoookJ_lH0?l2oookJP03
ool0o?oonf[ooo]Z00cooo]Z0ooo0007oookJP07oomB0?oonf[o02[ooookJ_l0g?oooo]Zo`3og`05
oookJP03o`3o6ooobP3ooo]Z00;ooo]Z00?oobP0oookJ_oonfX01Ooo:0000olV0?oo8?l0oookJP0<
oookJP06o`3oFooonf[oP_l0o`3o/?l0<?oooo]Z0_oo00001Ol60?ooolT0ool00?oo003o403o00Co
oo]Z00Goo`1AoookJ_l0[Ooooo]Zool0N@05oookJP07o`3oDooonf[ooo]Zooo90?l0oago0>7oooo9
0008oookJP04o`3o=?oonf[oiOl0onGo00Cooo]Z00GoolT0o`2Yoooonf[ooo]Zo`04o`02oookJP03
oiCo0?oonf[ooo]Z00Wooo]Z00?oogT0oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP06oookJP03
oomG0?oonf[ooo]Z05Wooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP06oookJP03
oolF0?oonf[ooi8000?ooo]Z00[oo`3loookJ_oonf[ooo]ZoaP0oooo1P3ooo]Zon_o0?oonf[oo`3f
0_oonfX01_l0Y_oooo]ZojP0oooonf[oo`3io`1go`;ooo]Z00Co0?nJoom/0?oonf[o>ol00_oonfX0
0ol0nooooo]ZoookJP05oookJP04ogT0oonco`3ooo]Zoil0o`?ooo]Z00Oo0?oNomgo0?oonf[ooo]Z
ool0K?oonf[oC@3o00;ooo]Z00?oH@3ooookJ_oonfX01?oonfX00ol0oi;ooo]ZoookJP06oookJP03
oaP0ool0M?ooi_l000_ooo]Z00?ookh0oookJ_m`0?l01OoonfX00oooE`3ooo]ZoookJP03oookJP03
ool0;Ooonf[ooo]Z00oooo]Z00?o0=CooookJ_l01?l04OoonfX7o`3oCPWooo]Z0ol0e?l;oookJPCo
000000Cooo]ZoomG0?oonf[oL03o2?oonfX00ooVo`3o07CooaP0o`04oookJP05o`3oT_oonf[ooo]Z
oookJ_mQ0?l01_oonfX00onco`3ooo]ZoookJP05oookJP03oom/0?oonf[ooo]Z00?ooo]Z00?oo`3f
oookJ_lH0?l00_oonfX00ooo0?cooo]ZoookJP0>oookJP03o`1coooonf[ooo]Z00Gooo]Z00Oooe80
oookJ_oonf[o02[ooookJ_l0g?oo0?oO00Gooo]Z00?o0?lKooo:0?oonfX00_oonfX00ol0nOooo`0C
oookJP03oookJP05on7o0?oonf[o9P3oob3o0?n40?l03?oonfX01Ol0oe_ooo]ZoookJ_n2o`3o033o
00?ooo]Z00Go1P3ooookJ_nBo`3ooo]Zoa00o`05oookJP04ool0DOoonf[o0:goool0N@Gooo]Z00Oo
0?mCoookJ_oonf[ooo]Zo`3o7Ooonf[o0>7o00Sooo]Z00Co0?ldoookJ_oonf[o0?m>1?oonfX00ol0
R?oooo]Zo`2Yo`02oookJP03o`04oooonf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo
02gooo]ZoookJP06oookJP03oomG0?oonf[ooo]Z02Sooo]Z000eoookJP03o`1coooonf[ooo]Z01;o
oo]Z00?oo`3ZoookJ_oonfX01_oonfX00ooo5P3ooi80oookJP02oookJP0;ool0o?oonf[ooo]Zoook
J_lH0?oooo]Zool60?oonf[ojol0ool0m_oonfX00ooo:0000ooonf[oobP0oookJP05oolX00Ooo`00
0ooonfX4ool00003o`2Soonco`3oW`3o00?ooo]Z00KogOl0o`3og_oonf[ooo]Zool0K?oonfX6ooo9
0003oookJ_ooN@3oogT000KoogT01OoonfX00olH0?ooi_l0oookJP05oookJP03ool00?oonf[ooo]Z
00;ooo]Z00Coo`00oookJ_oob@3oolT01?oonfX00oooE`3ooo]ZoookJP04oookJP03ool0;Ooonf[o
oo]Z00kooo]Z00Co0=CooookJ_oonf[o00Co2?oonfX9ooo900cooo]Z0ol0e?l6oookJP;oo`001_oo
nfX3o`000004oomG0?oo003ooo]Zog00o`?ooo]Z00?oogT0oookJ_oonfX00_oonfX00ooVo`3oogT0
oaP0o`04oookJP03o`3oT_oonf[oogT000GoogT00ooonfX00onco`3ooo]ZoookJP05oookJP03oom/
0?oonf[ooo]Z00?ooo]Z00Koo`3foookJ_oonf[o603ooookJ_oo0?`?oookJP?oo`001_oonfX00ol0
oc?ooe80o`0Zo`02oookJP03o`3Loooonf[o0?oO00Cooo]Z00?o0?lKoookJ_oobP000_oonfX01?l0
nOooobP0oookJ_oonfX5oolX0003obH0oooonf[ooo]Z00_ooo]Z00Go0?mKoookJ_oonf[oP_l0o`3o
/002oookJP;oo`0000Ko1P3oooo90?oo003oo`00oa00oooo0003oookJP05ool0DOl0[Ooooo]Zoook
J_oo07T01OoonfX01_l0oe?ooo]ZoookJ_l0oagoolT0o`3Qo`Wooo]Z00?o0?ldoookJ_oUo`001?oo
nfX00ooob@3ooo]Zo`2Yo`02oookJP03o`04oooonf[oU?l000_ooo]Z00?oogT0oookJ_oonfX02_oo
nfX00ooo02gooo]ZoookJP05oookJP03oomG0?oonf[ooo]Z05[ooo]Z00?o07?ooookJ_oonfX04_oo
nfX00ooo0>[ooo]ZoookJP06oookJP03oolF0?oonf[ooi8000?ooo]Z00[oo`3loookJ_oonf[ooo]Z
oaP0oooonf[oo`H0oookJ_o[o`3oo`3f0ooonfX02Ol0Y_ooZ03ooookJ_oonf[oo`3io`1goooonf[o
0?nJoom/0002oookJP03oc_o0?oonf[o0?_o00Sooo]Z00?o0:?ook?o0?nO0?l01?oonfX02Ol0omko
oo]ZoookJ_oonf[oo`1/oookJ_m=0?oooo]Zof40o`07oookJP03o`3oT_oonf[ooo]Z00Kooo]Z00?o
603oo`1doooVo`002ooonfX00ooo_P3ooo]Zog00o`04oookJP03oomG0?oonf[ooo]Z00Cooo]Z00?o
o`0]oookJ_oonfX03ooonfX01?l0e?oooo]Zo`04ool01?lLoookJP?o0=Co3_oonfX3o`0000;ooeL0
00?ooo]Zog00oooonfX01ooonfX00ooVo`3o07CooaP0o`04oookJP05o`3oT_oonf[ooo]ZoookJ_mQ
0?l01_oonfX00onco`3ooo]ZoookJP05oookJP03oom/0?oonf[ooo]Z00?ooo]Z00Koo`3foookJ_oo
nf[o603ooookJ_oo0?`@oookJP03o`1coooonf[ooo]Z00Kooo]Z00?ooe80oookJ_l0:_l00_oonfX0
0ol0g?oo0?oOoookJP03oookJP03o`3o6olB0?ooolX000;ooo]Z00?o0?WooookJ_oo01<00ooonfX0
1OoQo`3ooo]ZoookJ_lV0?ooQ03o00cooo]Z00Ko0?mKoookJ_oonf[ooo]Zoh;o0?l0<?l3oookJP05
o`H0oooo0?GoT_l0oookJ_l@0?l01OoonfX01?oo057o0:gooookJ_oo07T5oookJP07o`3oDooonf[o
oo]Zo`3o7Ol0o`Sooo]Zo`3Qo`08oookJP04o`3o=?oonf[ooo]Zo`3oCPCooo]Z00Oo08SooookJ_l0
ZOoooo]Zo`04oooonf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP06
oookJP03oomG0?oonf[ooo]Z02Sooo]Z000eoookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3Zoook
J_oonfX01_oonfX00ooo5P3ooi80oookJP02oookJP03ool0o?oonf[ooo]Z00;ooo]Z00co603ooook
J_oo1P3ooo]Zon_o0?oo0?KoobP0oookJ_l0Y_oooo]ZoolX0?oonfX5oolX00Soo`000_oonfX2ool0
0005oookJ_oo003ooo]Zok?o0?nO0?l00ooonfX00ooMo`3o0?oNoookJP02oookJP03ool0K?oob@3o
olT000;oolT00ooonfX9oomi00Gooo]Z00?o603ooookJ_oonfX02OoonfX00ooo003ooo]Zooo90003
ooo900?ooo]Z00?ooeL0oookJ_oonfX01?oonfX00ooo02gooo]ZoookJP0>oookJP?o0=Co4Ooob@0:
oookJP;o0=Co00Co00CooookJ_oonf[ooo]Z1?l007l3ool000Kooo]Z0_l000001?ooE`3o0000oook
J_m`0?l4oookJP;oogT00_oonfX00ooVo`3o603ooaP0o`04oookJP03o`3oT_oonf[oogT000CoogT0
1?oonfX00onco`3ooo]ZoookJP06oookJP03oom/0?oonf[ooo]Z00;ooo]Z00Koo`3foookJ_oonf[o
603ooookJ_oo0?`@oookJP;oo`001ooonfX01oooDP3ooo]Zo`0Zoooonf[o0=cooookJ_l0oml01Ooo
nfX00ol0oa_oolX0oookJP02oookJP04o`3ioooo:03ooo]ZoookJPCoobP000?ooo]ZobH0oooonfX0
3?oonfX01Ol0oe_ooo]ZoookJ_n2o`3o033o00;ooo]Z0_oo00001_oob@3oo`00ool00?oo003o403o
ool000?ooo]Z00Coo`1Ao`2]oooonf[oo`1i1_oonfX01_l0oe?ooo]ZoookJ_l0oagoolT0o`3Qo`Wo
oo]Z00?o0?ldoookJ_l0odh01?oonfX01Ooob@3ooo]Zo`2Yoooonf[o00Co00;ooo]Z00?oU?l0oook
J_oonfX02OoonfX00oooN@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooeL0oook
J_oonfX0F_oonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Oooo]Z00?ooaH0oonB
0?oonfX00_oonfX00ooo0?cooo]ZoookJP02oookJP06oaP0oooo1P3ooo]Zon_o0?oonf[oo`3f0_oo
nfX02Ol0Y_ooZ03ooookJ_oonf[oo`3io`1goooonf[o0?nJoom/0002oookJP04oc_o0?oonf[ooo]Z
o`3ko`Oooo]Z00?oN@3ook?o0?nO0?l01?oonfX02Ol0omkooo]ZoookJ_oonf[oo`1/oookJ_m=0?oo
oo]Zof40o`07oookJP03o`3oT_oonf[ooo]Z00Oooo]Z00?o603oonKo0?oonfX02_oonfX01?oo_P3o
oo]ZoookJ_m`0?l4oookJP03oomG0?oonf[ooo]Z00Cooo]Z00?oo`0]oookJ_oonfX03ooonfX3o`3D
o`Co00Co5_oonfX2o`3Do`04o`04oooonf[ooo]ZoookJPGo001o2?oonfX2o`000004oomG0?l0003o
oo]Zog00o`Sooo]Z00?oi_l0oaP0oolH0?l01?oonfX00ol0oi;ooo]ZoookJP02oookJP03of40oooo
nf[ooo]Z00?ooo]Z00?o/ol0oookJ_oonfX01_oonfX00oooK03ooo]ZoookJP03oookJP05ool0m_oo
nf[o603ooookJ_oo0?`04OoonfX00ol0Looooo]ZoookJP05oookJP07oomB0?oonf[ooo]Zo`0Zoooo
nf[o0=coo`3og`05oookJP03o`3o6olB0?ooolX000;ooo]Z00?o0?Woool04ooonfX00ooonfX01OoQ
o`3ooo]ZoookJ_lV0?ooQ03o00cooo]Z00Go0?mKoookJ_oonf[o0?n`oh;o0004oookJP05o`H0oonB
o`3ooo]ZoookJ_l@0?l01OoonfX00ooo057o0:goool0N@06oookJP07o`3oDooonf[ooo]Zo`3o7Ol0
o`Sooo]Zo`3Qo`08oookJP04o`3o=?oonf[ooo]Zo`3oCP?ooo]Z00So08SooookJ_oonf[o0:Wooook
J_l01?oooo]Zo`3Do`_ooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP06oookJP03
oomG0?oonf[ooo]Z02Sooo]Z000eoookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX0
1_oonfX00ooo5P3ooi80oookJP02oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Ko603ooookJ_oo1P3o
oo]Zon_o0?oo0?H2oookJP03o`2Voooonf[ooo]Z00KoobP02Ooo0004oookJP04ool00?oonf[o/ol0
oil0o`?ooo]Z00?ogOl0o`3og_oonfX00_oonfX00ooo06coolT0ool00002oookJP04ooo90?oonf[o
oo]ZoookJPKoogT01ooonfX00olH0?ooi_l0oookJP0:oookJP03ool00?oonf[oolT000?oolT00ooo
nfX00oooE`3ooo]ZoookJP04oookJP03ool0;Ooonf[ooo]Z013ooo]Z1Ol0e?l<ooo900?ooo]Z1?l0
1?l3o`3Do`Gooo]Z1?l007l5ool000Gooo]Z0_ooE`000ol0003oL03oog00o`04oookJPCoogT000?o
i_l0oaP0oooonfX01?oonfX00ol0oi;ooo]ZoookJP04oomi00Cooo]Z00?o/ol0oookJ_oonfX01_oo
nfX00oooK03ooo]ZoookJP02oookJP07ool0m_oonf[ooo]ZoookJ_lH0?oooo]Zool0o00@oookJP03
ool00?oonf[ooo]Z00Gooo]Z00So0?lcoomB0?oonf[o02[ooookJ_l0g?oooo]Zo`3og`Cooo]Z00Oo
0?lKoa80oooobP3oobP0oookJ_l0nOooobP000?ooo]Z1?oo:0000olV0?oo8?l0oookJP0;oookJP06
o`3oFooonf[ooo]ZoookJ_n2o`3ooo]Z0ooob@001_l60?ooolT0ool00?oo003o403oool000?ooo]Z
00Goo`1AoookJ_l0[Ooooo]Zool0N@05oookJP06o`3oDooonf[ooo]ZoookJ_l0oago0>7o2OoonfX0
0ol0ocCooo]Zo`3oCP05oookJP05ooo90?oonf[o0:WooookJ_l01?l00_oonfX00onDo`3ooo]Zoook
JP09oookJP03oomi0?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooE`3ooo]Zoook
JP1JoookJP03o`1coooonf[ooo]Z01;ooo]Z00?oo`3ZoookJ_oonfX01ooonfX00ooo5P3ooi80oook
JP02oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Ko603oool60?oonf[ojol0oookJ_oo0?H2oookJP09
o`2Voooonf[oZ03ooookJ_oo0?Wooo]Zo`1goooonf[oof`000;ooo]Z00Co>ol0oookJ_oonf[o0?_o
1ooonfX01?mi0?oo/ol0oookJ_nO0?l3oookJP05o`3og_oonf[ooo]ZoookJ_oo06`00_oonfX00om=
0?oooo]Zof40o`07oookJP03o`3oT_oonf[ooo]Z00Kooo]Z00?o603oo`1doooVo`002ooonfX01?oo
_P3ooo]ZoookJ_m`0?l4oookJP03oomG0?oonf[ooo]Z00Cooo]Z00?oo`0]oookJ_oonfX04OoonfX4
o`3Do`Ko00Co2OoonfX4o`04o`?o0=Co1OoonfX7o`00O`Oooo]Z0_ooE`000ol0003oL03oog00o`08
oookJP03onKo0?lH0?oooo]Z00Cooo]Z00?o0?nBoookJ_oonfX00_oonfX00omQ0?oooo]ZoookJP04
oookJP03ok?o0?oonf[ooo]Z00Gooo]Z00?oof`0oookJ_oonfX00ooonfX01_oo0?Kooo]ZoookJ_lH
0?oooo]Zool0o13ooo]Z00?o07?ooookJ_oonfX01_oonfX01oooDP3ooo]ZoookJ_l0:_oooo]Zo`3L
ool0oml01?oonfX00ol0oa_ooo]Zooo:0002oookJP03o`3ioooonf[oo`0C00Cooo]Z00CohOl0oook
J_lV0?oo8?l03?oonfX01_l0oe_ooo]ZoookJ_oonf[o0?n`oh;o00?ooo]Z00Go1P3ooookJ_nBo`3o
oo]Zoa00o`05oookJP04ool0DOoonf[o0:goool0N@Gooo]Z00Oo0?mCoookJ_oonf[ooo]Zo`3o7Ol0
o`So0>7o00Sooo]Z00Co0?ldoookJ_oonf[o0?m>1?oonfX02?l0R?oooo]ZoookJ_l0ZOoooo]Zo`04
oooonf[o0=Co2ooonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0
oookJ_oonfX0:?oonfX003Gooo]Z00?o07?ooookJ_oonfX04ooonfX00ooo0>[ooo]ZoookJP06oook
JP03oonB0?oonf[ooo]Z00;ooo]Z00[oo`3loookJ_oonf[ooo]ZoaP0oooonf[oo`H0oookJ_oo:03o
o`3f0_oonfX00ol0Y_oooo]ZoookJP06oolX00Ooo`0000?o0?_ooookJ_oonfX01?oonfX01?oo003o
oo]Zok?o0?nO0?l3oookJP07omgo0?l0omkooo]ZoookJ_oo06cooo]Zool00002oookJP04ooo90?oo
nf[ooo]ZoookJP?oogT000?ooo]Zoomi0?oonfX02?oonfX00olH0?oooo]ZoookJP0<oookJPGoolT0
0_oonfX00oooE`3ooo]ZoookJP04oookJP03ool0;Ooonf[ooo]Z01Cooo]Z1?l0e?l7ooo90003o`04
ool0e?oo0=Co00Go0=Co1ooonfX4o`00O`Ooo`000ooonfX01OooE`3o0000o`000?m`0?oo000000Co
oo]Z1?ooN@000ooVo`3o603ooookJP04oookJP03o`3oT_oonf[ooo]Z00CoogT00_oonfX00ooo003o
oo]Zok?o0008oookJP03oom/0?oonf[ooo]Z00?ooo]Z00Koo`3foookJ_oonf[o603ooookJ_oo0?`A
oookJP03o`1coooonf[ooo]Z00Gooo]Z00Oooe80oookJ_l0:_oooo]Zo`3Loooonf[o0?oO00Gooo]Z
00?o0?lKooo:0?oo:0001?oo:003oookJP?oobP000?ooo]ZobH0oooonfX03?oonfX01_l0oe_ooo]Z
oookJ_n2o`3o033ooookJPOoolT000?o403ooookJ_oonfX00_oonfX01Ooo057o0:gooookJ_oonf[o
o`1i00Gooo]Z00Ko0?mCoookJ_oonf[o0?lMooo90?l0hOl9oookJP03o`3o=?oonf[o0?m>00Cooo]Z
00?oolT0oookJ_l0ZOl00_oonfX00ol01?oooo]ZoiCo000<oookJP03oomi0?oonf[ooo]Z00Wooo]Z
00?oo`0]oookJ_oonfX01_oonfX00oooE`3ooo]ZoookJP1JoookJP03o`1coooonf[ooo]Z01?ooo]Z
00?oo`3ZoookJ_oonfX01_oonfX00ooo5P3ooi80oookJP03oookJP0:ool0o?oonf[ooo]ZoookJ_lH
0?oooo]Zool60?o[o`3ooo]Zool0mP;ooo]Z00?o0:KooookJ_nX0?l00_oonfX01Ooo0?Wo07Oooook
J_l0oi[oof`000;ooo]Z00Co>ol0oookJ_oonf[o0?_o1ooonfX00omi0?oo/ol0oil0o`04oookJP09
o`3og_oonf[ooo]ZoookJ_oo06cooo]Zodd0oooonf[oH@3o00Oooo]Z00?o0?nBoookJ_oonfX01ooo
nfX00olH0?ooi_l0oookJP0>oookJP03og00oooonf[ooo]Z00;ooo]Z00?ooeL0oookJ_oonfX01?oo
nfX00ooo02gooo]ZoookJP0DoookJPCo0=Co0_oonfX6o`04o`Oo0=Co1ooonfX4o`00O`05oookJ_l0
07oo001oo`00OooonfX00_oo02d3oookJP05oomG0?l0003o0000og00ool000002?oonfX00ooVo`3o
603ooookJP04oookJP03o`3oT_oonf[ooo]Z00;ooo]Z00GoH@3ooookJ_oonf[ooo]Zo`3ogP02oook
JP03ok?o0?oonf[ooo]Z00Gooo]Z00?oof`0oookJ_oonfX01?oonfX01Ooo0?Kooo]ZoaP0oooonf[o
o`3l017ooo]Z00?o07?ooookJ_oonfX01OoonfX01oooDP3o0?lcoookJ_l0:_oooo]Zo`3Lool0oml0
1OoonfX00ol0oa_o4P3oooo:0002oookJP03o`3ioooo01?ooo]Z00?ooo]Z00GohOl0oookJ_oonf[o
9P3ooh@0o`0<oookJP06o`3oFooonf[ooo]Zo`3o/?n2o`3o033o0ooonfX01Ol60?ooo`3eoi;o0?oo
nf[o403o00Gooo]Z00Coo`1Ao`2]oooonf[oo`1i1OoonfX01ol0oe?ooo]ZoookJ_l0oago0?l8oook
J_l0hOl02?oonfX01?l0ocCooo]ZoookJ_l0odh4oookJP07o`28oooonf[o0:WooookJ_l01?oooo]Z
o`3Do`0<oookJP03oon10?oonf[ooo]Z00Wooo]Z00?oo`0]oookJ_oonfX01_oonfX00oooE`3ooo]Z
oookJP0YoookJP00=OoonfX00ol0Looooo]ZoookJP0CoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?o
oaH0oonB0?oonfX00_oonfX01Ooo0?cooo]ZoookJ_oonf[o603o00;ooo]Z00Coo`H0oolX0?oonf[o
o`3f0_oonfX01?l0Y_oooo]ZoolX0?oonfX4oolX00Goo`000_oonfX00ol0nooooo]ZoookJP04oook
JP04ool00?oonf[o/ol0oil0o`?ooo]Z00?oobP0o`3og_oonfX00_oonfX00ooo06coo`00oookJP02
oookJP04ooo90?oonf[ooo]Zoomi00?ooo]Z00?oogT0oookJ_oonfX02?oonfX00olH0?oooo]Zoook
JP0;oookJPOoolT000?ooo]ZoomG0?oonfX01OoonfX00ooo02gooo]ZoookJP0EoookJP;oolT02?l0
e?l>oookJP?o001o2?oo00001_oonf[ooeL0oomG0?oonf[o0000og00o`;o00001?oonfX3oomi0004
onKo0?lH0?ooogT0oomi00?ooo]Z00Co0?nBoookJ_oonf[ooo]Z0_ooN@04oookJP03ool00?oonf[o
/ol000Oooo]Z00?oof`0oookJ_oonfX00ooonfX01_oo0?Kooo]ZoookJ_oonf[o603oool0o17ooo]Z
00?o07?ooookJ_oonfX01OoonfX02?l0oc?ooe80oookJ_l0:_oooo]Zo`3Loooonf[o0?oO1?oonfX0
0ol0oa_o4P3oooo:000:oolX00;ooo]Z00?o9P3ooookJ_oonfX02ooonfX01_l0oe_ooo]ZoookJ_n2
o`3o033ooookJPWoolT00ooonfX01?oo057o0:gooookJ_oo07T6oookJP05o`3oDooonf[ooo]Zo`3o
7Ol0hOl02_oonfX00ol0ocCooo]Zo`3oCP04oookJP03ooo90?oonf[oogT000;ooo]Z00?o00Cooook
J_nDo`002ooonfX00oooN@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooeL0oook
J_oonfX0FooonfX00ol0Looooo]ZoookJP0CoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oook
J_ooTP000ooonfX02?oo0?cooo]ZoookJ_oonf[o603ooookJ_oo1P3ojol00_oonfX01Ooo0?Kooo]Z
o`2Voooonf[oZ03o00;ooo]Z00Goo`3io`1goooonf[o0?nJoom/0002oookJP04oc_o0?oonf[ooo]Z
o`3ko`Oooo]Z00?oN@3ook?o0?nO0?l01?oonfX01ol0omkooo]ZoookJ_oonf[oo`1/oookJ_m=0?l0
0_oonfX00omQ0?oooo]ZoookJP05oookJP03o`3oT_oonf[ooo]Z00Oooo]Z00?o603oonKo0?oonfX0
3_oonfX00om`0?oooo]ZoookJP02oookJP03oomG0?oonf[ooo]Z00Cooo]Z00?oo`0]oookJ_oonfX0
5ooonfX8o`3Do`kooo]Z0ol007l3oookJP03o`00Oooo02goo`0]00?ooo]Z0_ooE`000ooonf[o0000
og00o`02o`0000Oooo]Z00?oi_l0oaP0oooonfX01?oonfX00ol0oi;ooo]ZoookJP02oookJP03of40
oooonf[ooo]Z00;ooo]Z00?o0?oNoookJ_nco`001ooonfX00oooK03ooo]ZoookJP04oookJP05ool0
m_oonf[ooo]ZoaP0oooo0?`04OoonfX00ol0Looooo]ZoookJP06oookJP07oomB0?oonf[ooo]Zo`0Z
oooonf[o0=coo`3og`04oookJP03o`3o6ooonf[oolX000?ooo]Z00?o0?Woool04ooonfX00ooonfX0
1OoQo`3ooo]ZoookJ_lV0?ooQ03o00cooo]Z00Go0?mKoookJ_oonf[o0?n`oh;o0004oookJP05o`H0
oonBo`3ooo]ZoookJ_l@0?l01OoonfX00ooo057o0:goool0N@06oookJP06o`3oDooonf[ooo]Zo`3o
7Ol0o`So0>7o2OoonfX01?l0ocCooo]Zo`3o;_l0odh3oookJP08o`28oooonf[ooo]Zo`2Yoooonf[o
00CooookJ_l0e?l;oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX01_oonfX00ooo
E`3ooo]ZoookJP0YoookJP00=_oonfX00ol0Looooo]ZoookJP0BoookJP03ool0j_oonf[ooo]Z00Ko
oo]Z00?ooaH0oonB0?oonfX00_oonfX01Ooo0?cooo]ZoookJ_oonf[o603o00;ooo]Z00Coo`H0oolX
0?oo:03oo`3f0_oonfX00ol0Y_oooo]ZoookJP05oolX0008ool00?oo:03oobP0oolX0?oonf[oo`00
oookJ_l0nol6oookJP04ool00?oonf[o0:?ook?o00?ooo]Z0_oo:0001_l0omkooo]ZoookJ_oo06co
oo]Zool000;ooo]Z00?oolT0oookJ_oonfX01OoonfX00oooN@3ooo]ZoookJP07oookJP03onKo0?lH
0?oooo]Z00cooo]Z2?oob@02oomG00Gooo]Z0_oo02dGoookJPOoolT04?oonfX9ool000;ooeL00_oo
nfX2og00o`Go000000Cooo]Zoomi0?ooN@3oogT00_lH0?l4oomi0003oookJ_l0oi;ooo]Z00?ooo]Z
00?oogT0oookJ_oonfX00_oonfX00ooo003ooo]Zok?o0008oookJP03oom/0?oonf[ooo]Z00?ooo]Z
00Koo`3foookJ_oonf[o603ooookJ_oo0?`@oookJP03o`1coooonf[ooo]Z00Kooo]Z00Go0?lcoomB
0?l0:_oooo]Zo`3Lo`02oookJP03o`3ogooonf[ooo]Z00;ooo]Z00?o0?lKoookJ_oobP000ooo:000
0ooo003oobP0oolX0004oolX0003oookJ_lV0?oo8?l000cooo]Z00Go0?mKoookJ_oonf[ooo]Zoh;o
0002oookJPWoolT00_oonfX01Ooo057ooo]Zo`2]oooonf[oo`1i00Kooo]Z00Go0?mCoookJ_oonf[o
0?lMo`3Qo`09oookJP03o`3o=?oonf[o0?m>00Gooo]Z00GoolT0oookJ_ooN@3ooo]Zo`04o`02oook
JP03oiCo0?oonf[ooo]Z00Wooo]Z00?oogT0oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP05oook
JP03oomG0?oonf[ooo]Z05cooo]Z00?o07?ooookJ_oonfX04_oonfX00ooo0>[ooo]ZoookJP06oook
JP03oolF0?oonf[ooi8000?ooo]Z00_oo`3loookJ_oonf[ooo]ZoaP0oooonf[oo`H0oookJ_o[o`3o
oo]Zool0mP02oookJP03o`2Voooonf[oZ03o00;ooo]Z00Coo`3io`1gool0oi[oof`00ooonfX01?lk
o`3ooo]ZoookJ_l0nol6oookJP04ogT0oooonf[o/ol0oil0o`?ooo]Z00?ogOl0o`3og_oonfX00_oo
nfX01Ooo06cooo]Zodd0oooonf[oH@3o00Oooo]Z00?o0?nBoookJ_oonfX02?oonfX00olH0?oo07Co
oookJP0>oookJP03og00oooonf[ooo]Z00;ooo]Z0_ooE`05oookJP;oo`0]<_oonfX2ool0;@;o001o
00?ooo]ZoomG0?ooE`000_oonfX2og00o`Go00001?oonfX2oaP0o`Gooo]Z00?o0?nBoookJ_oonfX0
0_oonfX00omQ0?oooo]ZoookJP02oookJP04o`3og_oonf[ooo]Zok?o00Oooo]Z00?oof`0oookJ_oo
nfX00ooonfX01_oo0?Kooo]ZoookJ_lH0?oooo]Zool0o13ooo]Z00?o07?ooookJ_oonfX01ooonfX0
1oooDP3ooo]Zo`0Zoooonf[o0=cooookJ_l0oml01?oonfX00ol0oa_o4P3oooo:0002oookJP03o`3i
oooo09?ooo]Z00Cooo]Z00CohOl0oookJ_lV0?oo8?l03?oonfX01_l0oe_ooo]ZoookJ_oonf[o0?n`
oh;o00?ooo]Z00Ko1P3ooookJ_nBo`3ooo]Zoa00oooo06X4oookJP04ool0DOoonf[o0:goool0N@Ko
oo]Z00Ko0?mCoookJ_oonf[o0?lMo`3o2?l0hOl8oookJP04o`3o=?oonf[ooo]Zo`3oCPCooo]Z00So
08SooookJ_oonf[o0:WooookJ_l01?oooo]Zo`3Do`_ooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo
02gooo]ZoookJP06oookJP03oomG0?oonf[ooo]Z02Wooo]Z000foookJP03o`1coooonf[ooo]Z01?o
oo]Z00?oo`3ZoookJ_oonfX01OoonfX00ooo5P3ooi80oookJP03oookJP04ool0o?oonf[ooo]ZoaP0
o`;ooo]Z00Ooo`H0oolX0?oo:03oobP0ool0m_oonf[o0:Ko00;ooo]Z1_oo:0001OooK03ooo]Zoook
J_oonf[oo`0000;ooo]Z00?o0?_ooookJ_oonfX01?oonfX01?oo003ooo]Zok?o0?nO0?l3oookJP;o
obP000Go0?oNoookJ_oonf[oo`1/ool00002oookJP03ooo90?oonf[ooo]Z00Gooo]Z00?oogT0oook
J_oonfX02?oonfX00olH0?oo07CooookJP0;oookJPWoolT000?ooo]ZoomG0?ooE`001OoonfX2ool0
;ASooo]Z0ooob@0@oookJP03ool00?oo:03oobP000Koo`0000KooeL0ool00?oonf[ooo]Zog00oooo
nfX4o`0000;ooo]Z0oooN@000olH0?ooogT0oomi0002oomi00;ooo]Z00Ko0?nBoookJ_oonf[ooo]Z
of40ooooN@04oookJP03ool00?oonf[o/ol000Sooo]Z00?oof`0oookJ_oonfX00ooonfX01_oo0?Ko
oo]ZoookJ_oonf[o603oool0o17ooo]Z00?o07?ooookJ_oonfX01_oonfX01oooDP3ooo]Zo`0Zoooo
nf[o0=cooookJ_l0oml01OoonfX00ol0oa_oolX0oookJP03oolX0003ool00?oo:03oobP000?oobP0
0_oonfX00olV0?oooo]ZoookJP0;oookJP05o`3oFooonf[ooo]Zoh;o0?l0<?l00_oonfX8ooo900?o
oo]Z00Goo`1Ao`2]oooonf[ooo]Zool0N@05oookJP06o`3oDooonf[ooo]Zo`3o7Ol0o`So0>7o2Ooo
nfX00ol0ocCooo]Zo`3oCP04oookJP03ooo90?oonf[oogT000;ooo]Z00Co00CooookJ_oonf[oU?l0
2ooonfX00oooN@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooeL0oookJ_oonfX0
G?oonfX00ol0Looooo]ZoookJP0CoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oonB0?oonfX0
0ooonfX01?oo0?cooo]ZoookJ_lH0?l2oookJP04ool60?o[o`3ooo]Zool0mP;ooo]Z00?o0:Kooook
J_nX0?l00_oonfX01?oo0?Wo07OooookJ_ooK003oookJP04oc_o0?oonf[ooo]Zo`3ko`Oooo]Z00?o
N@3ook?o0?nO0?l01?oonfX02OoMo`3o0?oNoookJ_oonf[oo`1/oookJ_m=0?oooo]Zof40o`08oook
JP03o`3oT_oonf[ooo]Z00Oooo]Z00?o603oonKo0?oonfX03ooonfX00om`0?oooo]ZoookJP03oook
JP;ooeL01OoonfX3ool0;Bgooo]Z0_oo02d01Ooonf[o001oo`00Ool007oooeL000?ooo]Z00?oL03o
oookJ_l000000ol00005oookJP03oaP0oooonf[ooo]Z00Cooo]Z00Co0?nBoookJ_oonf[ooo]Z0_mQ
0?l4oookJP04o`3og_oonf[ooo]Zok?o00Oooo]Z00?oof`0oookJ_oonfX01?oonfX01Ooo0?Kooo]Z
oookJ_lH0?ooo`3l017ooo]Z00?o07?ooookJ_oonfX01_oonfX01oooDP3ooo]ZoookJ_l0:_oooo]Z
o`3Lool0oml01OoonfX00ol0oa_o4P3oooo:0002oookJP03o`3ioooo09?ooo]Z00?ooo]Z00GohOl0
oookJ_oonf[o9P3ooh@0o`0<oookJP05o`3oFooonf[ooo]Zo`3o/?n2o`001?oonfX01_l60?ooo`3e
oi;o0?oonf[o403oool0JPCooo]Z00Coo`1Ao`2]oooonf[oo`1i1OoonfX01ol0oe?ooo]ZoookJ_l0
oago0?l8oookJ_l0hOl02?oonfX01?l0ocCooo]ZoookJ_l0odh4oookJP03o`28oooonf[o0:Wo00;o
oo]Z00?o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z00Go
oo]Z00?ooeL0oookJ_oonfX0:_oonfX003Kooo]Z00?o07?ooookJ_oonfX04ooonfX00ooo0>[ooo]Z
oookJP05oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00Goo`3loookJ_oonf[ooo]ZoaP0o`02oookJP06
ool60?oo:03oobP0oolX0?oonf[o0:Ko0_oonfX3oolX0005oookJ_oo:03ooo]Zo`3oV_ooK0000_oo
nfX01?oo003ooo]ZoookJ_l0nol6oookJP04ool00?oonf[o0:?ook?o00?ooo]Z0_oo:0001Ol0omko
oo]ZoookJ_oo06coo`0000?ooo]Z00?oolT0oookJ_oonfX01OoonfX00oooN@3ooo]ZoookJP08oook
JP03oaP0ool0M?oooo]Z00_ooo]Z2_oob@000ooonf[ooeL0oookJP05oookJP;oo`0]6?oonfX00ooo
b@3ooo]ZoookJP0=oookJP04ool00?oo:03oobP0oolX00Coo`000_ooE`03ool00003og00oooonf[o
oo]Z00Co000000Gooo]Zoomi0?ooN@3oi_l0oaP0o`03oomi00?ooo]Z00Go0?nBoookJ_oonf[ooo]Z
of40o`02ool000?ooo]Z00?oo`00oookJ_nco`002?oonfX00oooK03ooo]ZoookJP03oookJP06ool0
m_oonf[ooo]ZoookJ_lH0?ooo`3l4OoonfX00ol0Looooo]ZoookJP06oookJP05o`3o<oooDP3o02[o
oookJ_l0g?l00_oonfX00ol0omoooo]ZoookJP02oookJP03o`3o6ooonf[oolX000?oobP000?oo`00
oolX0?oo:0000ooo:002oookJP03oh@0oolV0?oooo]Z00_ooo]Z00Ko0?mKoookJ_oonf[ooo]ZoolX
0?l0<?l2oookJPOoolT01?oonfX01?oo057o0:gooookJ_oo07T6oookJP05o`3oDooonf[ooo]Zo`3o
7Ol0hOl02_oonfX00ol0ocCooo]Zo`3oCP04oookJP03ooo90?oonf[oogT000;ooo]Z00?o00Cooook
J_nDo`002ooonfX00oooN@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooeL0oook
J_oonfX0GOoonfX00ol0Looooo]ZoookJP0CoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oonB
0?oonfX00ooonfX03ooo0?cooo]ZoookJ_oonf[o603ooookJ_oo1P3ooo]Zon_o0?oonf[oo`3foook
J_l0Y_oooo]ZojP0o`02oookJP05ool0nOl0Mooooo]Zo`3oV_ooK0000_oonfX01?lko`3ooo]Zoook
J_l0nol7oookJP03ogT0oooonf[o/ol000Cooo]Z00OogOl0o`3og_oonf[ooo]Zool0K?oonf[oC@3o
00;ooo]Z00?oH@3ooookJ_oonfX01OoonfX00ol0oi;ooo]ZoookJP08oookJP03oaP0oooVo`3ooo]Z
00oooo]Z00?oL03ooookJ_oonfX01?oonfX00oooE`3ooo]ZoookJP05oookJP;oo`0]:OoonfX2ool0
;@;ooo]Z0_l007l2oomG00?ooo]Z00?oL03ooookJ_oonfX01?l00003oookJP03onKo0?lH0?oooo]Z
00Gooo]Z00Go0?nBoookJ_oonf[ooo]Zof40o`05oookJP04o`3og_oonf[ooo]Zok?o00Oooo]Z00?o
of`0oookJ_oonfX01?oonfX01Ooo0?Kooo]ZoookJ_lH0?ooo`3l017ooo]Z00?o07?ooookJ_oonfX0
1ooonfX01oooDP3ooo]Zo`0Zoooonf[o0=cooookJ_l0oml01?oonfX00ol0oa_o4P3oooo:0002oook
JP03o`3ioooo09?oo`0C00Cooo]Z00CohOl0oookJ_oonf[o9P3o3?oonfX01_l0oe_ooo]ZoookJ_oo
nf[o0?n`oh;o00Cooo]Z00Go1P3ooi;o0?oonf[ooo]Zoa00o`05oookJP03ool0DOl0[Oooo`1i00Ko
oo]Z00Ko0?mCoookJ_oonf[o0?lMo`3o2?l0hOl9oookJP03o`3o=?oonf[o0?m>00Gooo]Z00Oo08So
oookJ_l0ZOoooo]Zo`04oooonf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]Z
oookJP06oookJP03oomG0?oonf[ooo]Z02[ooo]Z000foookJP03o`1coooonf[ooo]Z01?ooo]Z00?o
o`3ZoookJ_oonfX01_oonfX00oooTP3ooo]ZoookJP02oookJP05ool0o?oonf[ooo]ZoookJ_lH0?l0
0_oonfX01_oo1P3oobP0oolX0?oo:03ooo]Zo`2Vo`;ooo]Z00GoobP0oookJ_oonf[oo`3ioolX0002
oookJP05oom/0?oonf[ooo]ZoookJ_oo00000_oonfX00ol0nooooo]ZoookJP03oookJP05ool00?oo
nf[ooo]Zo`2Soonco`000_oonfX3oolX0005o`3og_oonf[ooo]Zool0K?oo00000_oonfX00ooob@3o
oo]ZoookJP05oookJP03oomi0?oonf[ooo]Z00Wooo]Z00?o603ooookJ_oonfX02ooonfX:ooo90003
oookJ_ooE`3ooeL000Kooo]Z0ooo02dToookJPKoobP00_oo00000oooE`3oo`00ool00002oookJP04
og00oooonf[ooo]ZoookJPCo000000Cooo]Zoomi0?oVo`3o603o0oooN@03oookJP05o`3oT_oonf[o
oo]ZoookJ_mQ0?l01?oo00001Ooonf[oo`00oookJ_oonf[o/ol000Sooo]Z00?oof`0oookJ_oonfX0
0ooonfX01_oo0?Kooo]ZoookJ_lH0?oooo]Zool0o17ooo]Z00?o07?ooookJ_oonfX01_oonfX01ooo
DP3ooo]Zo`0Zoooonf[o0=cooookJ_l0oml01OoonfX00ol0oa_ooo]Zooo:0003oolX0006ool00?oo
:03oobP0oolX0?oonf[ohOl00_oonfX00olV0?oo8?l0oookJP0;oookJP05o`3oFooonf[ooo]Zo`3o
/?oo:0000ooonfX7ooo900Cooo]Z00Coo`1Ao`2]oooonf[oo`1i1_oonfX01Ol0oe?ooo]ZoookJ_l0
oago0>7o00Wooo]Z00?o0?ldoookJ_l0odh01OoonfX00ooob@3ooo]Zoomi0002oookJP03o`04oooo
nf[oU?l000_ooo]Z00?oogT0oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP05oookJP03oomG0?oo
nf[ooo]Z05gooo]Z00?o07?ooookJ_oonfX04ooonfX00ooo0>[ooo]ZoookJP06oookJP03oolF0?oo
TP3ooo]Z00?ooo]Z00ooo`3loookJ_oonf[ooo]ZoaP0oooonf[oo`H0oookJ_o[o`3ooo]Zool0m_oo
nf[o0:KooookJ_nX0?l00ooonfX01?oo0?Wo07OooookJ_ooK003oookJP04oc_o0?oonf[ooo]Zo`3k
o`Kooo]Z00CoN@3ooookJ_l0Xooo/ol01?oonfX02OoMo`3o0?oNoookJ_oonf[oo`1/oookJ_m=0?oo
oo]Zof40o`07oookJP03o`3oT_oonf[ooo]Z00Wooo]Z00?o603oonKo0?oonfX03ooonfX00om`0?oo
oo]ZoookJP04oookJP;ooeL01ooonfX2ool0;BGooo]Z0_oo02d5o`00O`03oomG0?l007oooo]Z00;o
oo]Z00CoL03ooookJ_oonf[ooo]Z1?l00002oookJP03onKo0?lH0?oooo]Z00Gooo]Z00Go0?nBoook
J_oonf[ooo]Zof40o`05oookJP05o`3og_oonf[ooo]ZoookJ_nco`001ooonfX00oooK03ooo]Zoook
JP04oookJP05ool0m_oonf[o603ooookJ_oo0?`04OoonfX00ol0Looooo]ZoookJP06oookJP03oomB
0?l0oc?o02[o00;ooo]Z00?o0=coo`3ogooonfX01?oonfX00ol0oa_o4P3oooo:0002oookJP03o`3i
oooo09?ooo]Z00Cooo]Z00CohOl0oookJ_lV0?oo8?l03?oonfX01_l0oe_ooo]ZoookJ_l0ok3ooo]Z
oh;o00?ooo]Z00Ko1P3ooookJ_nBo`3ooo]Zoa00oooo06X5oookJP03ool0DOl0[Oooo`1i00Kooo]Z
00Ko0?mCoookJ_oonf[o0?lMo`3o2?l0hOl8oookJP04o`3o=?oonf[ooo]Zo`3oCPCooo]Z00So08So
oookJ_oonf[o0:WooookJ_l01?oooo]Zo`3Do`_ooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02go
oo]ZoookJP06oookJP03oomG0?oonf[ooo]Z02[ooo]Z000foookJP03oomi0?oonf[ooo]Z01Cooo]Z
00?oo`3ZoookJ_oonfX01OoonfX00ooo5P3ooi80oookJP03oookJP04ool0o?oonf[ooo]ZoaP0o`;o
oo]Z00?oo`H0oolX0?oo:0000_oo:0002ooonf[o0:KooookJ_oonf[oobP0oookJ_oo0?Wooo]ZoolX
0?oonf[oof`000?ooo]Z00Coo`00oookJ_oonf[o0?_o1_oonfX01?oo003ooo]Zo`2Soonco`03oook
JP;oobP000Co0?oNoolX0?oonf[oo`1/1?oonfX00ooob@3ooo]ZoookJP05oookJP03oomi0?oonf[o
oo]Z00Sooo]Z00?o603oonKo0?oonfX02ooonfX8ooo900Gooo]Z0_ooE`07oookJP;oo`0]3_oonfX5
oolX00kooo]Z2Ooo:0000ol007oooo]ZoookJP02og00o`Cooo]Z1?l000000ooVo`3o603ooaP0o`02
oomi00Cooo]Z00Ko0?nBoookJ_oonf[ooo]Zof40oooonfX5ool000;ooo]Z00?o/ol0oookJ_oonfX0
1_oonfX00oooK03ooo]ZoookJP03oookJP06ool0m_oonf[ooo]ZoaP0oooonf[oo`3l4OoonfX00ol0
Looooo]ZoookJP06oookJP05oomi0?ooDP3o02[ooookJ_l0g?l00_oonfX00ol0omoooo]ZoookJP02
oookJP04o`3o6ooonf[oolX0oookJP;oobP000Koo`00oolX0?oo:03oobP0oookJ_oQo`03oookJP03
obH0oooonf[ooo]Z00_ooo]Z00Go0?mKoookJ_oonf[oobP0o`0`o`02oookJP03ool00?oob@3oolT0
00CoolT01?oonfX01Ooo057o0:gooookJ_oonf[oo`1i00Gooo]Z00Ko0?mCoookJ_oonf[o0?lMo`3o
2?l0hOl9oookJP03o`3o=?oonf[o0?m>00Cooo]Z00?oolT0oookJ_ooN@000_oonfX01?l01?oooo]Z
oookJ_nDo`0;oookJP03oomi0?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooE`3o
oo]ZoookJP1MoookJP03o`1coooonf[ooo]Z01Cooo]Z00?oo`3ZoookJ_oonfX01OoonfX00ooo5P3o
oo]ZoonB0004oookJP04ool0o?oonf[ooo]ZoaP0o`;ooo]Z00Koo`H0on_o0?oonf[oo`3foookJ_l0
Y_l2oookJP07ojP0oooonf[ooo]Zool0nOl0Mooooo]Zoom/0003oookJP04oc_o0?oonf[ooo]Zo`3k
o`Oooo]Z00?oN@3ooookJ_nco`001OoonfX01?l0omkooo]ZoookJ_oo06`4oookJP03of40oooonf[o
oo]Z00Gooo]Z00?o0?nBoookJ_oonfX02?oonfX00olH0?oo07CoonKo000@oookJP03og00oooonf[o
oo]Z00Gooo]Z0_ooE`07oookJP?oo`0]8?oonfX2ool0;@;ooo]Z0ol007l2oomG0003o`00Oooonf[o
oo]Z00;oL03o1?oonfX4o`000003oookJ_lH0?oo603o00Kooo]Z00Go0?nBoookJ_oonf[ooo]Zof40
o`05oookJP05o`3og_oonf[ooo]ZoookJ_nco`001ooonfX00oooK03ooo]ZoookJP04oookJP05ool0
m_oonf[o603ooookJ_oo0?`04OoonfX00ol0Looooo]ZoookJP07oookJP07oomB0?oonf[o02[ooook
J_l0g?oooo]Zo`3og`04oookJP03o`3o6olB0?ooolX000;ooo]Z00?o0?Woool0Tooo01<01?oonfX0
1?oQo`3ooo]ZoookJ_lV0?l=oookJP05o`3oFooonf[ooo]Zo`3o/?n2o`000_oonfX01ol0odgooo]Z
o`H0oooo0?GoT_l0oookJ_l@0?l01OoonfX01?oo057o0:gooookJ_oo07T5oookJP07o`3oDooonf[o
oo]Zo`3o7Ol0o`Sooo]Zo`3Qo`08oookJP04o`3o=?oonf[ooo]Zo`3oCPCooo]Z00?o08SooookJ_l0
ZOl00_oonfX00ol01?oooo]Zo`3Do`0;oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oo
nfX01OoonfX00oooE`3ooo]ZoookJP0[oookJP00=_oonfX00oooN@3ooo]ZoookJP0DoookJP03ool0
j_oonf[ooo]Z00Gooo]Z00?ooaH0oonB0?oonfX00ooonfX01?oo0?cooo]ZoookJ_lH0?l3oookJP03
ool60?oo:03oobP000;oobP000_o0:KooookJ_oonf[oobP0oookJ_oo0?Wooo]ZoolX0?oonf[oof`0
o`3oVP02oookJP05ool00?oonf[ooo]ZoookJ_l0nol01OoonfX01Ooo003ooo]ZoookJ_l0Xooo/ol0
00;ooo]Z0ooo:0000ol0omkoobP0ool0K004oookJP03ooo90?oonf[ooo]Z00Gooo]Z00?oogT0oook
J_oonfX02OoonfX00olH0?ooi_l0oookJP0;oookJPKoolT02?oonfX2oomG00Oooo]Z0_oo02d4oook
JPgoobP02ooonfX00ooo02goobP0oolX0008oolX00;ooo]Z0_m`0?l6oookJP?o000000Coi_l0oaP0
ooooN@3oogT01OoonfX01_l0oi;ooo]ZoookJ_oonf[oH@3ooookJPOoo`0000?o/ol0oookJ_oonfX0
1_oonfX00oooK03ooo]ZoookJP03oookJP06ool0m_oonf[ooo]ZoaP0oooonf[oo`3l4OoonfX00ol0
Looooo]ZoookJP07oookJP05oomB0?l0:_oooo]ZoookJ_l0g?l00_oonfX00ol0omoooo]ZoookJP02
oookJP04o`3o6ooonf[oolX0oookJP;oobP000Koo`00oolX0?oo:03oobP0oookJ_oQo`02oookJP03
oh@0oolV0?oooo]Z00_ooo]Z00Ko0?mKoookJ_oonf[o0?n`oolX0?l0<?l2oookJP03ool00?oob@3o
olT000?oolT000?o403ooookJ_oonfX00_oonfX01?oo057o0:gooookJ_oo07T6oookJP05o`3oDooo
nf[ooo]Zo`3o7Ol0hOl02_oonfX00ol0ocCo0?m>oookJP04oookJP03ooo90?oonf[oogT000;ooo]Z
00?o00CooookJ_nDo`002ooonfX00oooN@3ooo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z00Gooo]Z
00?ooeL0oookJ_oonfX0GOoonfX00ol0Looooo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z00Kooo]Z
00?ooaH0oonB0?oonfX00ooonfX01?oo0?cooo]ZoookJ_lH0?l2oookJP09ool60?oonf[ojol0oook
J_oo0?Kooo]Zo`2Voooonf[oZ03o00;ooo]Z00Goo`3ioookJ_l0Moooof`0o`3oVP02oookJP05oc_o
0?oonf[ooo]ZoookJ_l0nol01_oonfX01?mi0?oooo]Zo`2Soonco`04oookJP05omgo0?l0omkooo]Z
oookJ_oo06`00ooonfX00omQ0?oooo]ZoookJP05oookJP03o`3oT_oonf[ooo]Z00Wooo]Z00?o603o
o`1doooVo`004?oonfX00om`0?oooo]ZoookJP06oookJP;ooeL02?oonfX2ool0;A_ooo]Z0ooo02d4
oookJP?ooeL00ooonfX2og00o`Kooo]Z0ol000000ooVo`3o603oo`1do`06oookJP05o`3oT_oonf[o
oo]ZoookJ_mQ0?l01OoonfX01Ol0omkooo]ZoookJ_l0Xooo/ol000Oooo]Z00?oof`0oookJ_oonfX0
1?oonfX01Ooo0?Kooo]ZoookJ_lH0?ooo`3l017ooo]Z00?o07?ooookJ_oonfX01ooonfX00oooDP3o
0?lco`0Zo`02oookJP03o`3Loooonf[o0?oO00Cooo]Z00?o0?lKoa80oooobP000_oonfX00ol0nOoo
o`2CoookJP04oookJP04on7o0?oonf[ooo]ZobH0o`cooo]Z00Ko0?mKoookJ_oonf[o0?n`oookJ_n2
o`02oookJP04o`3oCOl60?oooo]Zoi;o00;ooo]Z00?o403ooookJ_oonfX00ooonfX00ooo057o0:go
ool0N@06oookJP06o`3oDooonf[ooo]Zo`3o7Ol0o`So0>7o2OoonfX00ol0ocCooo]Zo`3oCP05oook
JP07o`28oooonf[o0:WooookJ_l01?oooo]Zo`3Do`0;oookJP03oon10?oonf[ooo]Z00_ooo]Z00?o
o`0]oookJ_oonfX01OoonfX00oooE`3ooo]ZoookJP0[oookJP00=_oonfX2oomi01Gooo]Z00?oo`3Z
oookJ_oonfX01OoonfX00ooo5P3ooi80oookJP03oookJP05ool0o?oonf[ooo]ZoookJ_lH0?l00_oo
nfX00ooo1P3oobP0oolX0003oolX00;ooo]Z00GoobP0oookJ_oonf[oo`3ioolX0002oookJP05oom/
0?oonf[ooo]ZoookJ_oo00000_oonfX00ol0nooooo]ZoookJP03oookJP05ool00?oonf[ooo]Zo`2S
oonco`000_oonfX3oolX0004o`3og_oo:03oobP0ool0K0?ooo]Z00?oolT0oookJ_oonfX01_oonfX0
0oooN@3ooo]ZoookJP09oookJP03oaP0oooVo`3ooo]Z00[ooo]Z1Ooob@000ooonf[oolT0oookJP08
oookJP03oomG0?oonf[ooo]Z00Kooo]Z4Ooo:006oookJPGoo`0]2_oo:003og00o`Sooo]Z00Go0000
onKo0?oVo`3o603ooomi0006oookJP06o`3oT_oonf[ooo]ZoookJ_mQ0?oooo]Z1ooo00000onco`3o
o`00oookJP07oookJP03oom/0?oonf[ooo]Z00;ooo]Z00Ooo`3foookJ_oonf[ooo]ZoaP0oooonf[o
o`3l017ooo]Z00?o07?ooookJ_oonfX01_oonfX01OooDP3ooo]Zo`0Zoooonf[o0=co00;ooo]Z00?o
0?oOoookJ_oonfX00_oonfX00olB0?oo0?lKooo:0002oookJP03oolX0?oo003oobP000;oobP000?o
oo]Zon7o0?oonfX00_oonfX00olV0?oooo]ZoookJP0;oookJP05o`3oFooonf[ooo]ZoolX0?l0<?l0
0_oonfX00ooo003oolT0ooo90003ooo90003oa00oooo003ooo]Z00?ooo]Z00Coo`1Ao`2]oooonf[o
o`1i1_oonfX01Ol0oe?ooo]ZoookJ_l0oago0>7o00Wooo]Z00?o0?ldoookJ_l0odh01OoonfX00ooo
b@3ooo]Zoomi0002oookJP03o`04oooonf[oU?l000_ooo]Z00?oogT0oookJ_oonfX02_oonfX00ooo
02gooo]ZoookJP05oookJP03oomG0?oonf[ooo]Z05oooo]Z00?o07?ooookJ_oonfX04ooonfX00ooo
0>[ooo]ZoookJP06oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00ooo`3loookJ_oonf[ooo]ZoaP0oooo
nf[oo`H0oookJ_o[o`3ooo]Zool0m_oonf[o0:KooookJ_nX0?l00ooonfX01?oo0?Wo07OooookJ_oo
K003oookJP04oc_o0?oonf[ooo]Zo`3ko`Kooo]Z00CoN@3ooookJ_oonf[o/ol01OoonfX01?l0omko
oo]ZoookJ_oo06`3oookJP03of40oooonf[ooo]Z00Kooo]Z00?o0?nBoookJ_oonfX02OoonfX00olH
0?oo07CoonKo000@oookJP03og00oooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX01ooonfX5ool0
;A7ooo]Z1Ooo02d4oookJP?ooeL00_l007l2oookJP;oL03o2?oonfX2o`000003onKo0?lH0?oo07Co
00Kooo]Z00Go0?nBoookJ_oonf[ooo]Zof40o`05oookJP05o`3og_oonf[ooo]Zo`2Soonco`002?oo
nfX00oooK03ooo]ZoookJP03oookJP06ool0m_oonf[ooo]ZoaP0oooonf[oo`3l4OoonfX00ol0Looo
oo]ZoookJP06oookJP08oomB0?l0oc?ooo]Zo`0Zoooonf[o0=cooookJ_l0oml5oookJP07o`3o6ooo
bP3ooo]ZoookJ_l0nOooo`2Cool04`04oookJP04on7o0?oonf[ooo]ZobH0o`gooo]Z00oo0?mKoook
J_oonf[o0?n`oh;o0?l0<?oooo]Zo`3oCOoonf[o1P3ooookJ_nBo`3ooo]Zoa00oooo06X01OoonfX0
0ooo057o0:goool0N@06oookJP06o`3oDooonf[ooo]Zo`3o7Ooonf[o0>7o2?oonfX01?l0ocCooo]Z
oookJ_l0odh4oookJP03o`28oooonf[o0:Wo00;ooo]Z00?o00CooookJ_l0e?l02ooonfX00oooP@3o
oo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0oookJ_oonfX0:ooonfX003Kooo]Z
0oooN@0EoookJP03ool0j_oonf[ooo]Z00Cooo]Z00?ooaH0oonB0?oonfX00ooonfX01Ooo0?cooo]Z
oookJ_oonf[o603o00;ooo]Z00?oo`H0oolX0?oo:0000ooo:003oookJP07oolX0?oonf[oo`3ioook
J_oo:03ooo]Zoom/0003oookJP04ool00?oonf[ooo]Zo`3ko`Kooo]Z00Goo`00oookJ_oonf[o0:?o
ok?o0002oookJP?oobP000?o0?oNoolX0?oo06`01?oonfX00ooob@3ooo]ZoookJP06oookJP03o`3o
T_oonf[ooo]Z00Wooo]Z00?o603oonKo0?oonfX02_oonfX3ooo900?ooo]Z00?oolT0og00oooonfX0
1ooonfX2oomG00Sooo]Z3ooo:0000ooonf[oo`0]ool0;@03ool0;@?ooo]Z2_oo:002og00o`03oolX
0?l007oo001o00;o001o00?ooo]Zooo90?oonfX00ooonfX01?oVo`3o0000oaP0ooooN@06oookJP05
o`3oT_oonf[ooo]ZoookJ_mQ0?l00_oonfX6ool00003ok?o0?oonf[ooo]Z00Oooo]Z00?oof`0oook
J_oonfX00ooonfX01_oo0?Kooo]ZoookJ_lH0?oooo]Zool0o17ooo]Z00?o07?ooookJ_oonfX01_oo
nfX00oooN@3ooe80o`0Zo`02oookJP04o`3Loooonf[ooo]Zo`3og`?ooo]Z00Co4P3oo`3o6ooonf[o
olX00_oonfX01?oo:03oo`00oolX0?oo:002oookJP05on7o0?oonf[ooo]Zoh@0oolV0?l03OoonfX0
1Ol0oe_ooo]ZoookJ_oo:03o033o00;ooo]Z00?oo`00ooo90?oob@000ooob@000ol@0?oooo]Zoook
JP02oookJP04ool0DOl0[Ooooo]Zool0N@Oooo]Z00Go0?mCoookJ_l0oago0?l8o`3Qo`09oookJP03
o`3o=?oonf[o0?m>00Cooo]Z00?oolT0oookJ_ooN@000_oonfX01?l01?oooo]ZoookJ_nDo`0;oook
JP03oomi0?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooE`3ooo]ZoookJP1Ooook
JP03o`1coooonf[ooo]Z01Cooo]Z00?oo`3ZoookJ_oonfX01OoonfX00ooo5P3ooi80oookJP03oook
JP05ool0o?oonf[ooo]ZoookJ_lH0?l00_oonfX01_oo1P3ooo]Zon_o0?oonf[oo`3fo`2Vo`;ooo]Z
00OoZ03ooookJ_oonf[oo`3io`1goooonf[oof`000?ooo]Z00Go>ol0oookJ_oonf[ooo]Zo`3ko`06
oookJP04ogT0oooonf[o0:?ook?o00Cooo]Z00CogOl0o`3og_oonf[oo`1/1?oonfX00omQ0?oooo]Z
oookJP06oookJP03o`3oT_oonf[ooo]Z00Wooo]Z00?o603oo`1doooVo`004?oonfX2og00o`Sooo]Z
0_ooE`0<oookJPOoo`0]1OoonfX5ool0;@Kooo]Z0oooE`04oookJP?oL03o1?l007l6oookJP;oi_l0
00?o603oo`1doooonfX01OoonfX01Ol0oi;ooo]ZoookJ_oonf[oH@3o00Gooo]Z00Go0?oNoookJ_oo
nf[o0:?ook?o0008oookJP03oom/0?oonf[ooo]Z00?ooo]Z00Koo`3foookJ_oonf[o603ooookJ_oo
0?`AoookJP03o`1coooonf[ooo]Z00Oooo]Z00?ooe80oookJ_l0:_l00_oonfX00ol0g?oooo]Zo`3o
g`04oookJP03o`3o6ooonf[oolX000;ooo]Z00?o0?Woool0TooonfX01?oonfX01?oQo`3ooo]Zoook
J_lV0?l=oookJP05o`3oFooonf[ooo]Zo`3o/?n2o`000_oonfX01ol0odgo1P3ooookJ_oo0?GoT_l0
oookJ_l@0?l01OoonfX00ooo057o0:goool0N@07oookJP06o`3oDooonf[o0?lMo`3o2?oonf[o0>7o
2?oonfX01?l0ocCooo]Zo`3o;_l0odh4oookJP03o`28oooonf[o0:Wo00;ooo]Z00?o00CooookJ_l0
e?l02ooonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0oookJ_oo
nfX0:ooonfX003Kooo]Z0oooN@0EoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooaH0oonB0?oonfX0
0ooonfX02?oo0?cooo]ZoookJ_oonf[o603ooookJ_oo:03oo`H01Ooo:002oookJP08oolX0?oonf[o
oo]Zool0nOoo:03ooo]Zoom/0?l0oiX2oookJP05ool00?oonf[ooo]ZoookJ_l0nol01OoonfX01ooo
003ooo]ZoookJ_l0Xooo/ol0ool00?oonfX01?oo:0000ol0omkoobP0ool0K003oookJP03of40oooo
nf[ooo]Z00Oooo]Z00?o0?nBoookJ_oonfX02?oonfX00olH0?oo07CoonKo000;oookJP03ooo90?oo
nf[ooo]Z00Cooo]Z0om`0?l7oookJP?ooeL02?oonfX<oolX0003ool0;Ooonf[ooo]Z00Gooo]Z2Ooo
:002og00o`CoobP00ol007l2ooo900?ooo]Z00?oi_l0ooo90?oob@000_l00005oookJP05o`3oT_oo
nf[ooo]ZoookJ_mQ0?l00_oonfX6ool00003ok?o0?oonf[ooo]Z00Oooo]Z00?oof`0oookJ_oonfX0
0ooonfX01_oo0?Kooo]ZoookJ_lH0?oooo]Zool0o17ooo]Z00?o07?ooookJ_oonfX01ooonfX00ooo
DP3ooo]Zo`0Zo`02oookJP03o`3Loooonf[o0?oO00Cooo]Z00Oo4P3oo`3o6ooonf[oolX0oookJ_l0
nOooo`0000;oobP00_oonfX01OoQo`3ooo]ZoookJ_oonf[o9P3o00gooo]Z00Wo0?mKoookJ_oonf[o
obP0oookJ_l0<?oooo]Zool00?oonfX01?oob@000ol@0?ooo`00oookJP03oookJP04ool0DOl0[Ooo
oo]Zool0N@Kooo]Z00Go0?mCoookJ_oonf[o0?lMo`3Qo`0:oookJP03o`3o=?l0odkooo]Z00Cooo]Z
00?oolT0oookJ_ooN@000_oonfX00ol01?oooo]ZoiCo000<oookJP03oomi0?oonf[ooo]Z00[ooo]Z
00?oo`0]oookJ_oonfX01OoonfX00oooE`3ooo]ZoookJP1OoookJP03o`1coooonf[ooo]Z01Cooo]Z
00?oo`3ZoookJ_oonfX01OoonfX00ooo5P3ooo]ZoonB0004oookJP0?ool0o?oonf[ooo]ZoookJ_lH
0?oooo]Zool60?oonf[ojol0oookJ_oo0?Kooo]Zo`2Voooonf[oZ03o00?ooo]Z00Coo`3io`1goooo
K03o0?nJ0_oonfX01Olko`3ooo]ZoookJ_oonf[o0?_o00Kooo]Z00CoN@3ooookJ_nO0?oo/ol01Ooo
nfX01?oMo`3o0?oNoookJ_oo06`3oookJP03of40oooonf[ooo]Z00Oooo]Z00?o0?nBoookJ_oonfX0
2?oonfX01?lH0?oo07CooookJ_oVo`0AoookJP?oL03o1ooonfX4oomG00oooo]Z1Ooo02d8oookJP?o
oeL01OoonfX2og00o`Oo001o1OoonfX01OoVo`3o603ooaP0ool0M?oo000000Gooo]Z00Go0?nBoook
J_oonf[ooo]Zof40o`06oookJP04o`3og_oonf[o0:?ook?o00Sooo]Z00?oof`0oookJ_oonfX00ooo
nfX01_oo0?Kooo]ZoookJ_lH0?oooo]Zool0o17ooo]Z00?o07?ooookJ_oonfX01ooonfX01?ooDP3o
0?lcoookJ_l0:_l2oookJP03o`3Lool0omoooo]Z00Cooo]Z00Oo0?lKoookJ_oobP3ooo]Zo`3ioooo
09?oo`0C00Cooo]Z00CohOl0oookJ_oonf[o9P3o3OoonfX03ol0oe_ooo]ZoookJ_l0ok3oP_l0o`0`
oooonf[o0?m=oookJ_l60?oooo]Zoi;o0?oonf[o403oool0JP05oookJP03ool0DOl0[Oooo`1i00Ko
oo]Z00Ko0?mCoookJ_oonf[o0?lMoookJ_l0hOl9oookJP03o`3o=?oonf[o0?m>00Gooo]Z00Oo08So
oookJ_l0ZOoooo]Zo`04oooonf[o0=Co00cooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]Z
oookJP05oookJP03oomG0?oonf[ooo]Z02cooo]Z000foookJPCoogT05?oonfX00ooo0>[ooo]Zoook
JP05oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00Soo`3loookJ_oonf[ooo]ZoaP0oooonf[oobP0ool6
00KoobP000Kooo]ZoolX0?oonf[ooo]Zool0nOoo:002oookJP05oom/0?oonf[ooo]ZoookJ_oo0000
0_oonfX00ol0nooooo]ZoookJP03oookJP07ool00?oonf[ooo]ZoookJ_l0Xooo/ol0ool00004oolX
0004o`3og_oo:03oo`1/oolX00?ooo]Z00?oH@3ooookJ_oonfX01ooonfX00ol0oi;ooo]ZoookJP08
oookJP03oaP0ool0M?ooi_l001Cooo]Z0_m`0?l8oookJPGooeL01OoonfX9oolX00Cooo]Z1?ooE`07
oolX00?oL03o2?oonfX4ooo90003onKo0?oob@3oolT000Co00000ooonfX2o`3oTP?ooo]Z00CoH@3o
oookJ_oonf[ooo]Z1Ooo00000onco`3ooo]ZoookJP08oookJP03oom/0?oonf[ooo]Z00;ooo]Z00Co
o`3foookJ_oonf[o603o0_oonfX00ooo0?cooo]ZoookJP0?oookJP03o`1coooonf[ooo]Z00Kooo]Z
00?oogT0oomB0?l0:_l00_oonfX00ol0g?oooo]Zo`3og`04oookJP04oa80ool0oa_ooo]Zooo:00;o
oo]Z00CoobP0ool00?oo:03oobP00_oonfX01OoQo`3ooo]ZoookJ_n40?oo9P3o00gooo]Z00Go0?mK
oookJ_oonf[oobP0o`0`o`02oookJP03ool00?oonf[oolT000;oolT000?ooo]Zoa00oooonfX01?oo
nfX01?oo057o0:gooookJ_oo07T6oookJP05o`3oDooonf[ooo]Zo`3o7Ol0hOl02OoonfX00ol0ocCo
oo]Zo`3oCP05oookJP03ooo90?ooN@3ooo]Z00;ooo]Z00?o00CooookJ_nDo`002ooonfX00oooN@3o
oo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z00Cooo]Z00?ooeL0oookJ_oonfX0HOoonfX00ol0Looo
oo]ZoookJP0CoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oonB0?oonfX00ooonfX01ooo0?co
oo]ZoookJ_oonf[o603ooookJ_oo1P000_oonfX01_o[o`3oo`3foookJ_l0Y_oooo]ZojP0o`?ooo]Z
00Coo`3io`1goooonf[oof`00ooonfX01Olko`3ooo]ZoookJ_oonf[o0?_o00Gooo]Z00GoN@3ooook
J_oonf[o0:?ook?o0005oookJP03o`3og_oonf[oo`1/00Cooo]Z00?oH@3ooookJ_oonfX01ooonfX0
0ol0oi;ooo]ZoookJP08oookJP04oaP0ool0M?oooo]ZonKo01?ooo]Z0_m`0?l9oookJPGooeL04Ooo
nfX6oomG00Kooo]Z0_m`0?l=oookJP;o603o00Co07Coo`000?l0003o00000ooonfX2o`3oTP?ooo]Z
00?oH@3ooookJ_oonfX01?oonfX01?l0omkooo]Zo`2Soonco`09oookJP03oom/0?oonf[ooo]Z00?o
oo]Z00Koo`3foookJ_oonf[o603ooookJ_oo0?`AoookJP03o`1coooonf[ooo]Z00Oooo]Z00?ooe80
oookJ_l0:_l00_oonfX00ol0g?oo0?oOoookJP04oookJP03o`3o6ol0S_ooolX000;ooo]Z00?o0?Wo
ool0Tooo01<01?oonfX01?oQo`3ooo]ZoookJ_lV0?l=oookJP0>o`3oFooonf[ooo]Zo`3o/?n2o`3o
033ooookJ_l0odgooo]Zo`H0oooonf[oT_l0oookJ_l@0?l6oookJP03ool0DOl0[Oooo`1i00Kooo]Z
00Ko0?mCoookJ_oonf[o0?lMoookJ_l0hOl8oookJP04o`3o=?oonf[ooo]Zo`3oCPCooo]Z00?o08So
oookJ_l0ZOl00_oonfX00ol01?oooo]Zo`3Do`0;oookJP03oon10?oonf[ooo]Z00_ooo]Z00?oo`0]
oookJ_oonfX01OoonfX00oooE`3ooo]ZoookJP0/oookJP00=_oonfX4oomi01Gooo]Z00?oo`3Zoook
J_oonfX01?oonfX00ooo5P3ooi80oookJP03oookJP03ool0o?oonf[ooo]Z00;ooo]Z00?o603ooook
J_oo1P002?oo:002oookJP06ool0nOoonf[oobP0oookJ_ooK03o0?nJ0_oonfX01Ooo003ooo]Zoook
J_oonf[o0?_o00Gooo]Z00Goo`00oookJ_oonf[o0:?ook?o0002ool000CoobP000Co0?oNoolX0?oo
06coobP00ooonfX00omQ0?oooo]ZoookJP07oookJP03o`3oT_oonf[ooo]Z00Sooo]Z0_lH0?l00ooV
o`3ooo]ZoookJP0CoookJP;oL03o2ooonfX5oomG00?ooo]Z0_oo:008oomG00Wooo]Z0_m`0?l:oook
JPKoolT00_oonfX4o`0000;ooo]Z00?o0?nBoookJ_oonfX00_oonfX01?mQ0?oooo]ZoookJ_oonfX5
ool00003ok?o0?oonf[ooo]Z00Sooo]Z00?oof`0oookJ_oonfX00_oonfX01ooo0?Kooo]ZoookJ_oo
nf[o603ooookJ_oo0?`04OoonfX00ol0Looooo]ZoookJP07oookJP03oomB0?oonf[o02[o00;ooo]Z
00?o0=cooookJ_l0oml01?oonfX01?lB0?oo0?lKoookJ_oobP02oookJP03ool00?oo:03oobP000;o
oo]Z00GohOl0oookJ_oonf[ooo]ZobH0o`0=oookJP0:o`3oFooonf[ooo]ZoolX0?oonf[o033ooook
J_oo003ooo]Zo`H0o`?oolT000?ooo]Zoa00oooonfX00ooonfX01?oo057o0:gooookJ_oo07T7oook
JP04o`3oDooonf[o0?lMo`3Qo`[ooo]Z00?o0?ldoookJ_l0odh01?oonfX00ooob@3ooo]Zoomi0003
oookJP03o`04oooonf[oU?l000_ooo]Z00?oogT0oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP05
oookJP03oomG0?oonf[ooo]Z067ooo]Z00?o07?ooookJ_oonfX05?oonfX00ooo0>[ooo]ZoookJP05
oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00Goo`3loookJ_oonf[ooo]ZoaP0o`02oookJP08ool60?oo
nf[ojol0oookJ_oo0?Kooo]Zo`2VoonX0?l3oookJP05ool0nOl0Mooooo]Zoom/0?l0oiX00_oonfX0
1Olko`3ooo]ZoookJ_oonf[o0?_o00Kooo]Z00CoN@3ooookJ_oonf[o/ol01OoonfX01?oMo`3o0?oN
oookJ_oo06`4oookJP03of40oooonf[ooo]Z00Oooo]Z00?o0?nBoookJ_oonfX02?oonfX2oaP0o`03
o`1doooVo`3ooo]Z01?ooo]Z0om`0?l;oookJPGooeL01OoonfX7oomG00[ooo]Z0_m`0?l=oookJP04
onKo0?lH0?oo07CooookJPCo00000_oonfX00ol0oi;ooo]ZoookJP02oookJP03of40oooonf[ooo]Z
00Cooo]Z00Co0?oNoookJ_l0Xooo/ol02OoonfX00oooK03ooo]ZoookJP03oookJP06ool0m_oonf[o
oo]ZoaP0oooonf[oo`3l4OoonfX00ol0Looooo]ZoookJP07oookJP03oomB0?l0oc?o02[o00?ooo]Z
00?o0=coo`3ogooonfX01?oonfX00ol0oa_ooo]Zooo:0002oookJP03ool0Tooo01?ooo]Z00?ooo]Z
00CohOl0oookJ_oonf[o9P3o3OoonfX03ol0oe_ooo]ZoookJ_l0ok3oP_l0o`0`oooonf[o0?m=oook
J_l60?oooo]Zool0mOnBo`3ooo]Zoa00o`05oookJP03ool0DOl0[Oooo`1i00Oooo]Z00Go0?mCoook
J_l0oago0?l8o`3Qo`09oookJP03o`3o=?oonf[o0?m>00Gooo]Z00?o08SooookJ_l0ZOl00_oonfX0
0ol01?oooo]Zo`3Do`0;oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX01_oonfX0
0oooE`3ooo]ZoookJP0/oookJP00=_oonfX5oomi01Cooo]Z00?oo`3ZoookJ_oonfX01?oonfX00ooo
5P3ooi80oookJP04oookJP07ool0o?oonf[ooo]ZoookJ_lH0?oooo]Zool60005oolX0004o`2Voooo
nf[ooo]ZoolX00;ooo]Z00Goo`3ioolX0?oonf[ooo]Zoom/0002oookJP05ool00?oonf[ooo]Zoook
J_l0nol02?oonfX00ooo003o0:?ook?o0002ool000?oobP000Co0?oNoolX0?oonf[oo`1/1?oonfX0
0omQ0?oooo]ZoookJP07oookJP03o`3oT_oonf[ooo]Z00Wooo]Z00?o603oonKo0?oonfX05OoonfX3
og00o`gooo]Z1OooE`04oolX00[ooo]Z0om`0?l;oookJPOoolT00_oonfX4o`0000;o0?nB1?oonfX0
0omQ0?oooo]ZoookJP02oookJP?oo`0000?ooo]Zok?o0?oonfX02OoonfX00oooK03ooo]ZoookJP02
oookJP07ool0m_oonf[ooo]ZoookJ_lH0?oooo]Zool0o00BoookJP03o`1coooonf[ooo]Z00Kooo]Z
00?ooe80oookJ_l0:_l00_oonfX00ol0g?oooo]Zo`3og`04oookJP04oa80ool0oa_ooo]Zooo:00;o
oo]Z00?oo`00oolX0?oo:0000ooonfX01OoQo`3ooo]ZoookJ_n40?oo9P3o00gooo]Z00[o0?mKoook
J_oonf[oobP0oookJ_l0<?oooo]Zool00?oonf[o1P3o0_oob@000ooonf[o403ooookJP04oookJP04
ool0DOl0[Ooooo]Zool0N@Kooo]Z00Go0?mCoookJ_oonf[o0?lMo`3Qo`0:oookJP03o`3o=?l0odko
oo]Z00Cooo]Z00?oolT0oookJ_ooN@000_oonfX00ol01?oooo]ZoiCo000<oookJP03oomi0?oonf[o
oo]Z00[ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooE`3ooo]ZoookJP07oookJP03oomi0?oonf[o
oo]Z05Oooo]Z00?o07?ooookJ_oonfX05?oonfX00ooo0>[ooo]ZoookJP05oookJP03oolF0?ooTP3o
oo]Z00Cooo]Z00ooo`3loookJ_oonf[ooo]ZoaP0oooonf[oo`H0oookJ_o[o`3ooo]Zool0m_oonf[o
0:KooookJ_nX0?l00ooonfX01?oo0?Wo07OooookJ_ooK002oookJP03oc_o0?oonf[ooo]Z00;ooo]Z
00?o0?_ooookJ_oonfX01_oonfX00ol0Xooo/ol0oookJP04oookJP04o`3og_oonf[ooo]Zool0K0Co
oo]Z00?oH@3ooookJ_oonfX01ooonfX00ol0oi;ooo]ZoookJP09oookJP03oaP0ool0M?ooi_l001Ko
oo]Z0_m`0?l>oookJPGooeL03_oonfX3og00o`kooo]Z0_lH0?l3oookJPCo00000_l0oi84oookJP03
of40oooonf[ooo]Z00Cooo]Z00Co0?oNoookJ_l0Xooo/ol02OoonfX00oooK03ooo]ZoookJP03oook
JP06ool0m_oonf[ooo]ZoaP0oooonf[oo`3l4_oonfX00ol0Looooo]ZoookJP06oookJP04oomB0?l0
oc?ooo]Zo`0Zo`;ooo]Z00?o0=coo`3ogooonfX01?oonfX00ol0oa_ooo]Zooo:0002oookJP03ool0
Tooonf[oo`0C00Cooo]Z00CohOl0oookJ_oonf[o9P3o3OoonfX03_l0oe_ooo]ZoookJ_l0ok3oP_l0
o`0`oooonf[o0?m=oookJ_l60?oooo]Zoi;o0?oonf[o403o1_oonfX00ooo057o0:goool0N@06oook
JP06o`3oDooonf[ooo]Zo`3o7Ooonf[o0>7o2OoonfX00ol0ocCooo]Zo`3oCP05oookJP03o`28ool0
ZOoooo]Z00;ooo]Z00?o00Coo`3DoooonfX02ooonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooo
nf[ooo]Z00Gooo]Z00?ooeL0oookJ_oonfX02?oonfX00oo[0?oooo]ZoookJP0RoookJP00=_oonfX6
oomi01?ooo]Z00?oo`3ZoookJ_oonfX01OoonfX00oooTP3ooo]ZoookJP03oookJP03ool0o?oonf[o
oo]Z00;ooo]Z00?o603ooolX0?oo1P000_oo:0001_oonf[oo`3foookJ_l0Y_oooo]ZoolX00;ooo]Z
00Koo`3ioolX0?oonf[ooo]Zoom/0?l0oiX2oookJP05ool00?oonf[ooo]ZoookJ_l0nol02?oonfX0
0ol0Xooo/ol0ool00002ool000?oobP000Co0?oNoookJ_oonf[oo`1/1?oonfX00omQ0?oooo]Zoook
JP07oookJP03o`3oT_oonf[ooo]Z00Wooo]Z0_lH0?l00ol0M?oooo]ZoookJP0EoookJP;oL03o4ooo
nfX00ooo:03ooo]ZoookJP04oookJPCoL03o3OoonfX9ooo90005oookJ_l0003o0000o`000?l0oi80
1OoonfX00omQ0?oooo]ZoookJP02oookJPCoo`0000?o/ol0oookJ_oonfX02?oonfX00oooK03ooo]Z
oookJP03oookJP04ool0m_oonf[ooo]ZoaP0o`;ooo]Z00?oo`3loookJ_oonfX03ooonfX00ol0Looo
oo]ZoookJP06oookJP04oomi0?ooDP3ooo]Zo`0Zo`;ooo]Z00?o0=cooookJ_l0oml01?oonfX01?lB
0?oo0?lKoookJ_oobP02oookJP03ool00?oo:03ooo]Z00;ooo]Z00GohOl0oookJ_oonf[ooo]ZobH0
o`0>oookJP0;o`3oFooonf[oobP0oookJ_l0<?oooo]Zool00?oonf[o1P3ooookJ_oob@000_oonfX0
0ol@0?oooo]ZoookJP02oookJP05ool0DOoonf[o0:gooookJ_oo07T01_oonfX01Ol0oe?ooo]Zoook
J_l0oago0>7o00Wooo]Z00?o0?ldoookJ_l0odh01OoonfX00ooob@3oogT0oookJP02oookJP03o`04
oooonf[oU?l000_ooo]Z00?oogT0oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP04oookJP03oomG
0?oonf[ooo]Z00Sooo]Z00?oogT0oookJ_oonfX0F?oonfX00ol0Looooo]ZoookJP0CoookJP03ool0
j_oonf[ooo]Z00Gooo]Z00?ooaH0oonB0?oonfX01?oonfX01ooo0?cooo]ZoookJ_oonf[o603ooook
J_oo1P000_oonfX01_o[o`3oo`3foookJ_oonf[o0:KoojP0o`?ooo]Z00Goo`3io`1goooonf[ooo]Z
oom/0002oookJP05oc_o0?oonf[ooo]ZoookJ_l0nol02OoonfX00onco`3ooo]ZoookJP03oookJP05
omgo0?l0omkooo]ZoookJ_oo06`01?oonfX00omQ0?oooo]ZoookJP07oookJP03o`3oT_oonf[ooo]Z
00Wooo]Z0_lH0?l00ooVo`3ooo]ZoookJP0EoookJP?oL03o6_oonfX4og00o`oooo]Z0_lH0?l5oook
JP?o000000?o0?nBoookJ_oonfX00ooonfX00omQ0?oooo]ZoookJP04oookJP04o`3og_oonf[o0:?o
ok?o00Wooo]Z00?oof`0oookJ_oonfX00ooonfX01?oo0?Kooo]ZoookJ_lH0?l2oookJP03ool0o?oo
nf[ooo]Z00oooo]Z00?o07?ooookJ_oonfX01ooonfX00oooDP3ooo]Zo`0Zo`03oookJP03o`3Lool0
omoooo]Z00Cooo]Z00?o0?lKoookJ_oobP000_oonfX00ooo09?oo`0CoookJP03oookJP04on7o0?oo
nf[ooo]ZobH0o`kooo]Z00ko0?mKoookJ_l0ok3oP_l0o`0`oooonf[o0?m=oookJ_l60?oooo]Zool0
mOnBo`3ooo]Zoa00o`Gooo]Z00Coo`1AoookJ_l0[Oooo`1i1_oonfX01_l0oe?ooo]ZoookJ_l0oago
oo]Zo`3Qo`Sooo]Z00Co0?ldoookJ_oonf[o0?m>1OoonfX01ol0R?oo0:WooookJ_oonf[o00Cooook
J_l0e?l02ooonfX00oooP@3ooo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooeL0oook
J_oonfX02?oonfX00oo[0?oooo]ZoookJP0RoookJP00=ooonfX5oomi01Cooo]Z00?oo`3ZoookJ_oo
nfX01?oonfX00ooo5P3ooi80oookJP03oookJP03ool0o?oonf[ooo]Z00;ooo]Z00?o603ooolX0?oo
1P000_oonfX01_oo:03oo`3foookJ_l0Y_oooo]ZoolX00;ooo]Z00?oo`3ioookJ_oo:0000_oonfX0
1?ooK03ooo]ZoookJ_oo0003oookJP03o`3koooonf[ooo]Z00Kooo]Z00?o0:?oool00?nco`000ooo
0002oookJP05o`3og_oonf[ooo]ZoookJ_oo06`01?oonfX00omQ0?oooo]ZoookJP07oookJP03o`3o
T_oonf[ooo]Z00[ooo]Z00?o603oo`1doooonfX05ooonfX5og00oa7ooo]Z1?m`0?l@oookJP[oolT0
00Gooo]Zo`000?l0oi;o0?nBo`000004oookJP03of40oooonf[ooo]Z00;ooo]Z1?oo00000onco`3o
o`00ool00008oookJP03oom/0?oonf[ooo]Z00?ooo]Z00Coo`3foookJ_oonf[o603o0_oonfX00ooo
0?cooo]ZoookJP0?oookJP03o`1coooonf[ooo]Z00Oooo]Z00?ooe80oookJ_l0:_l00_oonfX00ol0
g?oooo]Zo`3og`04oookJP04oa80oooonf[o0?lKooo:00;ooo]Z00?oo`00oookJ_oo01<00ooonfX0
1OoQo`3ooo]ZoookJ_lV0?oo8?l000gooo]Z00oo0?mKoookJ_oonf[oobP0oookJ_l0<?oooo]Zool0
0?oonf[o1P3ooookJ_nBo`3ooo]Zool00?l@0?l01?oonfX01?oo057o0:gooookJ_oo07T7oookJP04
o`3oDooonf[o0?lMo`3Qo`[ooo]Z00?o0?ldo`3oC_ooN@001OoonfX00ooob@3oogT0oookJP02oook
JP03o`04oooonf[oU?l000_ooo]Z00?oogT0oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP04oook
JP03oomG0?oonf[ooo]Z00Sooo]Z00?oogT0oookJ_oonfX0F?oonfX00ol0Looooo]ZoookJP0Doook
JP03ool0j_oonf[ooo]Z00Gooo]Z00?ooaH0oonB0?oonfX00ooonfX00ooo0?cooo]ZoookJP02oook
JP0:oaP0oooonf[oo`H0oookJ_o[o`3ooo]Zool0m_oonf[o0:KoojP0o`?ooo]Z00Goo`3ioookJ_l0
Mooooo]Zoom/0002oookJP03oc_o0?oonf[ooo]Z00;ooo]Z00?o0?_ooookJ_oonfX01_oonfX00ol0
Xooo/ol0oookJP04oookJP05o`3og_oonf[ooo]ZoookJ_oo06`01?oonfX00omQ0?oooo]ZoookJP07
oookJP03o`3oT_oonf[ooo]Z00[ooo]Z00?o603oonKo0?oonfX06?oonfX5og00oa7ooo]Z1?m`0?lB
oookJP03oaP0oooVo`3ooo]Z00Gooo]Z0_l000000ol0oi;o0000oookJP03oookJP03of40oooonf[o
oo]Z00Cooo]Z00Co0?oNoookJ_l0Xooo/ol02OoonfX00oooK03ooo]ZoookJP03oookJP07ool0m_oo
nf[ooo]ZoookJ_lH0?oooo]Zool0o00AoookJP03o`1coooonf[ooo]Z00Oooo]Z00Cooe80o`3o<ooo
nf[o02[o0_oonfX00ol0g?oo0?oOoookJP04oookJP03oa80ool0oa_oolX000;ooo]Z00?oo`2Coook
J_oo01<00ooonfX01OoQo`3ooo]ZoookJ_oonf[o9P3o00gooo]Z00oo0?mKoookJ_oonf[o0?n`oh;o
0?l0<?oooo]Zo`3oCOoonf[o1P3ooookJ_oo0?GoT_l0ool0J_l@0?l01OoonfX00ooo057o0:goool0
N@07oookJP05o`3oDooonf[o0?lMoookJ_l0hOl02OoonfX00ol0ocCooo]Zo`3oCP05oookJP03o`28
oooonf[o0:Wo00;ooo]Z00?o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP0;oookJP03ool0
;Ooonf[ooo]Z00Gooo]Z00?ooeL0oookJ_oonfX02?oonfX00oo[0?oooo]ZoookJP0RoookJP00=ooo
nfX6oomi01?ooo]Z00?oo`3ZoookJ_oonfX01?oonfX00ooo5P3ooi80oookJP03oookJP03ool0o?oo
nf[ooo]Z00;ooo]Z00?o603ooookJ_oo1P000_oonfX01ooo:03ooo]Zool0m_oonf[o0:KooookJ_oo
:0000_oonfX00ooo0?WoobP0oookJP02oookJP03oom/0?oonf[oo`0000?ooo]Z00?o0?_ooookJ_oo
nfX01_oonfX00ooo003o0:?ook?o0004ool00003oookJ_oo:03o0?oN00;ooo]Z00?oo`1/oookJ_oo
nfX00ooonfX00omQ0?oooo]ZoookJP07oookJP03o`3oT_oonf[ooo]Z00[ooo]Z0_lH0?l00ol0M?oo
oo]ZoookJP0IoookJPSoL03o1OoonfX4og00oa?ooo]Z3?oob@000ol0oi;o0000o`000002o`0000;o
oo]Z00?oH@3ooookJ_oonfX00ooonfX3ool00003ok?o0?oo003oo`0000;oo`001_oonfX00oooK03o
oo]ZoookJP03oookJP04ool0m_oonf[ooo]ZoaP0o`;ooo]Z00?oo`3loookJ_oonfX04?oonfX00ol0
Looooo]ZoookJP06oookJP04oomi0?ooDP3ooo]Zo`0Zo`;ooo]Z00?o0=coo`3ogooonfX01?oonfX0
0olB0?ooobP0ooo:0003oookJP03ool00?oo01?ooo]Z00;ooo]Z00GohOl0oookJ_oonf[ooo]ZobH0
o`0>oookJP0;o`3oFooonf[oobP0o`3o/?oonf[o033oool00?oonf[o1P3ooookJ_nBo`000_oonfX0
0ol@0?oooo]ZoookJP02oookJP05ool0DOoonf[o0:gooookJ_oo07T01_oonfX01Ol0oe?ooo]Zoook
J_l0oago0>7o00[ooo]Z00?o0?ldo`3oC_oonfX00ooob@001?oonf[oolT0oookJ_ooN@02oookJP03
o`04oooonf[oU?l000cooo]Z00?oogT0oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP04oookJP03
oomG0?oonf[ooo]Z00Oooo]Z00?oogT0og00oooonfX0FOoonfX00ol0Looooo]ZoookJP0DoookJP03
ool0j_oonf[ooo]Z00Gooo]Z00?ooaH0oonB0?oonfX00ooonfX00ooo0?cooo]ZoookJP02oookJP03
oaP0oooonf[oo`H000;ooo]Z00Kojol0ool0m_oonf[ooo]Zo`2VoonX0?l3oookJP07ool0nOl0Mooo
oo]ZoookJ_ooK03ooo]Zoc_o0004oookJP03o`3koooonf[ooo]Z00Oooo]Z00?o/ol0oil0oooonfX0
1?oonfX01?l0omkooo]ZoookJ_oo06`5oookJP03of40oooonf[ooo]Z00Oooo]Z00?o0?nBoookJ_oo
nfX02_oonfX2oaP0o`03o`1doooonf[ooo]Z01[ooo]Z2?m`0?l5oookJPCoL03o5?oonfX2oaP0o`So
oo]Z0_l0oi83o`0000;ooo]Z00?oH@3ooookJ_oonfX01?oonfX01?l0omkooo]Zo`2Soonco`09oook
JP03oom/0?oonf[ooo]Z00Cooo]Z00Koo`3foookJ_oonf[o603ooookJ_oo0?`BoookJP03o`1coooo
nf[ooo]Z00Oooo]Z00?ooe80oookJ_l0:_l00ooonfX00ol0omoooo]ZoookJP04oookJP03o`3o6ooo
bP3ooo]Z00;ooo]Z00?oo`2Cool04ooonfX00ooonfX01OoQo`3ooo]ZoookJ_lV0?ooQ03o00gooo]Z
00ko0?mKoookJ_oonf[oP_l0oookJ_l0<?oooo]Zo`3oCOl60?oooo]Zool0mOnBo`3ooo]Zoa00o`Go
oo]Z00Coo`1AoookJ_l0[Oooo`1i1_oonfX01_l0oe?ooo]ZoookJ_l0oagooo]Zo`3Qo`Wooo]Z00?o
0?ldoookJ_l0odh01OoonfX00ol0R?oo0:WooookJP02oookJP03o`04ool0e?oooo]Z00_ooo]Z00?o
oh40oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP04oookJP03oomG0?oonf[ooo]Z00Sooo]Z00?o
j`3oog00oooonfX08ooonfX003Oooo]Z1_ooN@0CoookJP03ool0j_oonf[ooo]Z00Cooo]Z00?ooaH0
oonB0?oonfX01?oonfX00ooo0?cooo]ZoookJP02oookJP03oaP0oooonf[oo`H000;ooo]Z00KoobP0
ool0m_oonf[o0:KooookJ_oo:002oookJP03ool0nOoo:03ooo]Z00;ooo]Z00Coof`0oookJ_oonf[o
o`000ooonfX00ol0nooooo]ZoookJP06oookJP03o`2Soooo003o/ol000Coo`0000?ooo]Zo`3og_oo
nfX00_oonfX00ooo06cooo]ZoookJP03oookJP03of40oooonf[ooo]Z00Oooo]Z00?o0?nBoookJ_oo
nfX02_oonfX00ooVo`3o603oo`1do`0RoookJPGoL03o5_oonfX:ooo90003oookJ_l0oi;o0?nB00Co
00000_oonfX00omQ0?oooo]ZoookJP02oookJP05o`3og_oo003oo`00ool00?nco`001_oo0004oook
JP03oom/0?oonf[ooo]Z00?ooo]Z00Goo`3foookJ_oonf[ooo]ZoaP0o`02oookJP03ool0o?oonf[o
oo]Z00oooo]Z00?o07?ooookJ_oonfX01_oonfX01?ooN@3ooe80oookJ_l0:_l2oookJP03oiCo0?oo
nf[o0?oO00Cooo]Z00Co4P3ooookJ_oo:03oolX00_oonfX00ooo003ooo]Zool04`03oookJP05on7o
0?oonf[ooo]ZobH0oolPo`003_oonfX02ol0oe_ooo]ZoolX0?oonf[o033ooookJ_oo003ooo]Zo`H0
oooonf[oT_l000;ooo]Z00?o403ooookJ_oonfX00_oonfX01?oo057ooo]Zo`2]oooo07T7oookJP05
o`3oDooonf[ooo]Zo`3o7Ol0hOl02OoonfX01?l0ocCooo]Zo`3oC_oonfX5ooo90007oomi0?oonf[o
oo]ZoookJ_l01?oooo]ZoiCo000;oookJP03oomi0?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX0
1OoonfX00oooE`3ooo]ZoookJP07oookJP03oomi0?oonf[ooo]Z05[ooo]Z00?o07?ooookJ_oonfX0
4ooonfX00ooo0>[ooo]ZoookJP05oookJP03oolF0?ooTP3ooo]Z00Cooo]Z00?oo`3loookJ_oonfX0
0_oonfX01_lH0?ooo`H0oookJ_oonf[ojol0ool0mP;ooo]Z00?o0:KoojP0oooonfX00_oonfX01Ooo
0?Wo07OooookJ_oonf[oof`000;ooo]Z00?o>ol0oookJ_oonfX00_oonfX00ol0nooooo]ZoookJP06
oookJP03o`2Soonco`3ooo]Z00Cooo]Z00Go0?oNoookJ_oonf[ooo]Zool0K005oookJP03of40oooo
nf[ooo]Z00Oooo]Z00?o0?nBoookJ_oonfX02ooonfX00olH0?ooi_l0oookJP0RoookJPGoL03o5Ooo
nfX00ooVo`3o603ooaP0o`09oookJP03o`3oT_l0003o000000;o00000_oonfX00omQ0?oooo]Zoook
JP03oookJP;o0?oN00?ooo]Zo`2Soonco`002OoonfX00oooK03ooo]ZoookJP04oookJP04ool0m_oo
nf[ooo]ZoaP0o`;ooo]Z00?oo`3loookJ_oonfX03ooonfX00ol0Looooo]ZoookJP07oookJP03oomB
0?oonf[o02[o00?ooo]Z00?o0=coo`3ogooonfX01?oonfX00olB0?oo0?lKooo:0002oookJP03ool0
Tooonf[oo`0C00?ooo]Z00GohOl0oookJ_oonf[ooo]ZobH0o`0>oookJP0>o`3oFooonf[o0?n`oh;o
0?l0<?oooo]Zo`3oCOoonf[o1P3ooookJ_oo0?GoT_l0oookJ_l@0?l5oookJP03ool0DOoonf[oo`1i
00Oooo]Z00Ko0?mCoookJ_oonf[o0?lMoookJ_l0hOl8oookJP03o`3o=?oonf[o0?m>00Kooo]Z00Oo
08Soo`2Yoooonf[ooo]Zo`04oooonf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02go
oo]ZoookJP05oookJP03oomG0?oonf[ooo]Z00Sooo]Z00?oj`3ooookJ_oonfX08ooonfX003Oooo]Z
1oooN@0CoookJP03ool0j_oonf[ooo]Z00?ooo]Z00?ooaH0oookJ_ooTP001?oonfX00ooo0?cooo]Z
oookJP02oookJP03oaP0oooonf[oo`H000;ooo]Z00KoobP0ool0m_oonf[ooo]Zo`2VoonX0?l3oook
JP03ool0nOoo:03ooo]Z00;ooo]Z00?oof`0oookJ_oonfX00ooonfX00ol0nooooo]ZoookJP06oook
JP04ool00?l0Xoooo`00ok?o00Coo`0000?ooo]Zo`3og_oonfX00_oonfX00ooo06cooo]ZoookJP03
oookJP03of40oooonf[ooo]Z00Oooo]Z00?o0?nBoookJ_oonfX02ooonfX2oaP0o`03o`1doooonf[o
oo]Z03Oooo]Z00?oi_l0ooo90?oob@001Ooob@04oookJP03o`3oT_oonf[ooo]Z00Co00000_mQ0?l4
oookJP05o`3og_oonf[oo`00ool00?nco`001Ooo0005oookJP03oom/0?oonf[ooo]Z00Cooo]Z00Co
o`3foookJ_oonf[o603o0_oonfX00ooo0?cooo]ZoookJP0@oookJP03o`1coooonf[ooo]Z00Kooo]Z
00?ooe80oookJ_l0:_l00ooonfX00onDo`3o0?oOoookJP03oookJP04ool00?lB0?ooobP0ooo:00?o
oo]Z00?oo`00ool04ooonfX00_oonfX01OoQo`3ooo]ZoookJ_oonf[o9P3o00kooo]Z00_o0?mKoook
J_oonf[oobP0oookJ_l0<?ooo`00oookJ_l60?oooo]Zoi;o0002oookJP03ool00?l@0?oooo]Z00;o
oo]Z00Goo`1AoookJ_l0[Ooooo]Zool0N@06oookJP05o`3oDooonf[ooo]Zo`3o7Ol0hOl02_oonfX0
1?l0ocCo0?m>oomi0?oonfX5ooo90007oomi0?oob@3oolT0oookJ_l01?oooo]ZoiCo000;oookJP03
oomi0?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooE`3ooo]ZoookJP04oookJP?o
ogT000?ooo]Zoomi0?oonfX0FooonfX00ol0Looooo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z00Co
oo]Z00?ooaH0oookJ_ooTP001?oonfX00ooo0?cooo]ZoookJP02oookJP03oaP0oooonf[oo`H000;o
oo]Z00Gojol0ool0m_oonf[ooo]ZojP0o`04oookJP05ool0nOl0Mooooo]ZoookJ_ooK0001_oonfX0
0ol0nooooo]ZoookJP07oookJP03o`2Soonco`3ooo]Z00Cooo]Z00Go0?oNoookJ_oonf[ooo]Zool0
K005oookJP03of40oooonf[ooo]Z00Oooo]Z00?o0?nBoookJ_oonfX02ooonfX2oaP0o`03onKo0?oo
nf[ooo]Z03Oooo]Z0_oVo`000olH0?oooo]ZoookJP07oookJP;o0?nB00?ooo]Zo`000?l000000_l0
0002of40o`Gooo]Z00Go0?oNoookJ_oonf[o0:?ook?o0009oookJP03oom/0?oonf[ooo]Z00Cooo]Z
00Ooo`3foookJ_oonf[ooo]ZoaP0oooonf[oo`3l01;ooo]Z00?o07?ooookJ_oonfX01_oonfX01?oo
DP3o0?lcoookJ_l0:_l3oookJP03o`3ogooonf[ooo]Z00?ooo]Z00?o08koo`3o6ooobP000ooonfX0
0ooo09?oo`0CoookJP03oookJP05on7o0?oonf[ooo]ZobH0oon40?l03OoonfX03ol0oe_ooo]Zoook
J_l0ok3oP_l0o`0`oooonf[o0?m=o`H0oooonf[oo`3eoi;o0?oonf[oo`1Zoa00o`04oookJP04ool0
DOoonf[o0:goool0N@Kooo]Z00Ko0?mCoookJ_oonf[o0?lMoookJ_l0hOl9oookJP03o`3o=?oonf[o
0?m>00Gooo]Z00?o08SooookJ_l0ZOl00_oonfX00ol01?oooo]Zo`3Do`0;oookJP03oon10?oonf[o
oo]Z00_ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooE`3ooo]ZoookJP08oookJP03on/0oooonf[o
oo]Z02?ooo]Z000goookJPSoogT04_oonfX00ooo0>[ooo]ZoookJP04oookJP03oolF0?ooTP3ooo]Z
00?ooo]Z00?oo`3loookJ_oonfX00ooonfX00olH0?ooo`H0oookJP02oookJP06oolX0?oo0?Kooo]Z
o`2Voooonf[oZ03o0_oonfX00ooo0?WoobP0oookJP02oookJP03oom/0?oonf[ooo]Z00Cooo]Z00?o
0?_ooookJ_oonfX01OoonfX01?oo003o0:?oool00?nco`05ool00003oolX0?l0omkooo]Z00;ooo]Z
00?oo`1/oookJ_oonfX00_oonfX00omQ0?oooo]ZoookJP08oookJP03o`3oT_oonf[ooo]Z00cooo]Z
00?o603oonKo0?oonfX0=?oonfX3onKo00GoolT01OoonfX2o`3oTP?ooo]Z0ol000000omQ0?oooo]Z
oookJP03oookJP05o`3og_oonf[oo`00ool00?nco`001?oo0006oookJP03oom/0?oonf[ooo]Z00Co
oo]Z00Coo`3foookJ_oonf[o603o0_oonfX00ooo0?cooo]ZoookJP05oookJP03ool00?oonf[ooo]Z
00Sooo]Z00?o07?ooookJ_oonfX01_oonfX01?ooN@3ooe80oookJ_l0:_l2oookJP03oiCo0?oonf[o
0?oO00Cooo]Z00Co4P3ooolX0?oonf[oolX00_oonfX00ooo003oo`0CoookJP03oookJP05on7o0?oo
nf[ooo]ZobH0oolPo`003_oonfX00ol0oe_ooo]ZoolX0002oookJP06o`0`oooo003ooo]Zo`H0oooo
nf[oT_l00_oonfX00ol@0?oooo]ZoookJP02oookJP05ool0DOoonf[o0:gooookJ_oo07T01_oonfX0
1Ol0oe?ooo]ZoookJ_l0oago0>7o00[ooo]Z00Co0?ldo`3oC_oonf[ooo]Z1?oob@001oooN@3oolT0
ooo90?oob@3ooo]Zo`04oonDo`003?oonfX00oooN@3ooo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z
00Cooo]Z00?ooeL0oookJ_oonfX01?oonfX6oomi05_ooo]Z00?o07?ooookJ_oonfX05?oonfX00ooo
0>[ooo]ZoookJP05oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00?oo`3loookJ_oonfX00_oonfX00olH
0?oooo]Zool60002oookJP06on_o0?oo0?Kooo]ZoookJ_l0Y_ooZ03o0ooonfX01Ooo0?Wo07Oooook
J_oonf[oof`000Kooo]Z00?o0?_ooookJ_oonfX01ooonfX00ol0Xooo/ol0oil0o`04oookJP03omgo
0?l0omkooo]Z00;ooo]Z00?oo`1/oookJ_oonfX00_oonfX00omQ0?oooo]ZoookJP08oookJP03o`3o
T_oonf[ooo]Z00cooo]Z00?o603oonKo0?oVo`00=OoonfX2onKo00;o603o2OoonfX01?l0oi;ooo]Z
oookJ_oonfX3o`000003of40oooonf[ooo]Z00Cooo]Z00Go0?oNoookJ_oonf[o0:?ook?o0009oook
JP03oom/0?oonf[ooo]Z00Cooo]Z00Ooo`3foookJ_oonf[ooo]ZoaP0oooonf[oo`3l00Oooo]Z00?o
o`3ZoookJ_oonfX02?oonfX00ol0Looooo]ZoookJP07oookJP03oomB0?oonf[o02[o00?ooo]Z00?o
0=coo`3ogooonfX01?oonfX00ol0oa_ooo]Zooo:0002oookJP03ool0Tooo01?ooo]Z00?ooo]Z00Go
hOl0oookJ_oonf[o9P3oob3o000>oookJP0>o`3oFooonf[o0?n`oh;o0?oonf[o033oo`3oCOoonf[o
1P3ooookJ_oo0?GoT_l0oookJ_l@0?l5oookJP04ool0DOoonf[o0:goool0N@Kooo]Z00Ko0?mCoook
J_oonf[o0?lMoookJ_l0hOl9oookJP03o`3o=?oonf[o0?m>00Gooo]Z00?o08Soo`2YoooonfX00_oo
nfX00ol01?oo0=CooookJP0;oookJP03oon10?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX01?oo
nfX00oooE`3ooo]ZoookJP09oookJP03on/0ool0o`Gooo]Z02?ooo]Z000goookJPKoogT05?oonfX0
0ooo0>[ooo]ZoookJP04oookJP03oolF0?oonf[ooi8000Cooo]Z00?oo`3loookJ_oonfX00_oonfX0
0olH0?oooo]Zool60002oookJP0:oolX0?oo0?Kooo]ZoookJ_l0Y_oooo]ZojP0oooonf[oo`3ioolX
00Cooo]Z00?oof`0oookJ_oonfX00ooonfX00ol0nooooo]ZoookJP06oookJP04ool00?l0Xoooo`00
ok?o00;oo`000ooonfX00ol0omkooo]ZoookJP02oookJP03ool0K?oonf[ooo]Z00;ooo]Z00?oH@3o
oookJ_oonfX02?oonfX00ol0oi;ooo]ZoookJP0<oookJP;o603o00?oi_l0oookJ_oonfX09OoonfX2
oomi00Sooo]Z0_oVo`001?l0M?oo603oooo90?oob@08oookJP03o`3oT_oonf[ooo]Z00?ooo]Z00Co
0000of40oomQ0?oo00000ooonfX2o`3ogP;ooo]Z00?oo`00ok?o0?oo00000_oo0007oookJP03oom/
0?oonf[ooo]Z00Cooo]Z00Coo`3foookJ_oonf[o603o0_oonfX00ooo0?cooo]ZoookJP06oookJP03
ool00?oonf[ooo]Z00Oooo]Z00?o07?ooookJ_oonfX01ooonfX00oooDP3ooo]Zo`0Zo`02oookJP03
oiCo0?oonf[o0?oO00Cooo]Z00Coo`00oa80oooo:03oolX00ooonfX00ooo003oo`0CoookJP02oook
JP05on7o0?oonf[ooo]ZoookJ_lV0?l03_oonfX02ol0oe_ooo]ZoookJ_oo:03ooo]Zoomi0?oo003o
oo]Zo`H0oooonf[oT_l000;ooo]Z00?oo`00oa00oooonfX00ooonfX01?oo057ooo]Zo`2]oooo07T6
oookJP06o`3oDooonf[ooo]Zo`3o2?l0oago0>7o2OoonfX00ol0ocCooo]Zo`3oCP02oookJPCoolT0
00OoogT0ooo90?oob@3ooo]Zo`04oooonf[oU?l000cooo]Z00?oogT0oookJ_oonfX02ooonfX00ooo
02gooo]ZoookJP04oookJP03oomG0?oonf[ooo]Z00Cooo]Z1_ooN@1LoookJP03o`1coooonf[ooo]Z
01?ooo]Z00?oo`3ZoookJ_oonfX01OoonfX00ooo5P3ooo]ZoonB0004oookJP03ool0o?oonf[ooo]Z
00;ooo]Z00?o603oool60?oonfX00_oonfX01_o[o`3oo`3foookJ_oonf[o0:KoojP0o`;ooo]Z00?o
o`3io`1goooonfX00_oonfX00oooK03ooo]ZoookJP04oookJP03o`3koooonf[ooo]Z00Oooo]Z00?o
0:?ook?o0?nO0?l01?oonfX00ol0omkooo]ZoookJP02oookJP03ool0K?oonf[ooo]Z00;ooo]Z00?o
H@3ooookJ_oonfX02?oonfX00ol0oi;ooo]ZoookJP0<oookJP;o603o0_oVo`0aoookJP;oi_l00_lH
0?l:oookJP03o`3oT_oonf[ooo]Z00;ooo]Z00Co0000of40oomQ0?oo00001?oonfX2o`3ogP;ooo]Z
00?o0:?ook?o0?oonfX02?oonfX00oooK03ooo]ZoookJP04oookJP07ool0m_oonf[ooo]ZoookJ_lH
0?oooo]Zool0o008oookJP03ool0j_oonf[ooo]Z00Oooo]Z00?o07?ooookJ_oonfX01ooonfX01?oo
DP3o0?lcoookJ_l0:_l2oookJP03o`3Lool0omoooo]Z00Cooo]Z00?o08koo`3o6ooobP000ooonfX0
0ooo09?oo`0CoookJP03oookJP05on7o0?oonf[ooo]ZobH0oon40?l03OoonfX04?l0oe_ooo]Zoook
J_l0ok3oP_l0o`0`oooonf[o0?m=o`H0oooonf[oo`3eoi;o0?oonf[oo`1Zoa00ool0GOl4oookJP03
ool0DOoonf[oo`1i00Kooo]Z00Oo0?mCoookJ_oonf[o0?l8o`3o7Ooonf[o0>7o00Sooo]Z00?o0?ld
oookJ_l0odh01_oonfX00ol0R?oo0:WooookJP02oookJP03o`04ool0e?oooo]Z00_ooo]Z00?ooh40
oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP04oookJP03oomG0?oonf[ooo]Z00Sooo]Z00?oj`3o
og00ool0o`D09?oonfX003Oooo]Z0oooN@000ooonf[oogT0oookJP0EoookJP03ool0j_oonf[ooo]Z
00?ooo]Z00?ooaH0oookJ_ooTP001?oonfX00ooo0?cooo]ZoookJP03oookJP0;oaP0oooo1P3ooo]Z
oookJ_oo:03ooo]Zool0m_oonf[o0:KooookJ_nX0?l00_oonfX00ooo0?WoobP0oookJP02oookJP03
oom/0?oonf[ooo]Z00Cooo]Z00?o0?_ooookJ_oonfX01OoonfX01Ooo003o0:?oool00?nco`3oo`00
00Cooo]Z00?oobP0o`3og_l0omh00_oonfX00ooo06cooo]ZoookJP03oookJP03of40oooonf[ooo]Z
00Sooo]Z00?o0?nBoookJ_oonfX03OoonfX00olH0?ooi_l0onKo000SoookJPCoogT01_oonfX2onKo
00?o603o2OoonfX2o`3oTPGooo]Z0_mQ0?l3o`0000;ooo]Z00Ko0?oNoookJ_oonf[ooo]Zool00?nc
o`02ool000Sooo]Z00?oof`0oookJ_oonfX01?oonfX01ooo0?Kooo]ZoookJ_oonf[o603ooookJ_oo
0?`02?oonfX00ooo003ooo]ZoookJP08oookJP03o`1coooonf[ooo]Z00Kooo]Z00CoogT0oomB0?oo
nf[o02[o0_oonfX00onDo`3o0?oOoookJP04oookJP03oa80oooo:03oolX000?ooo]Z00?oo`00ool0
4ooonfX00ooonfX01Ooo003ooo]ZoookJ_lV0?oo8?l000kooo]Z00?o0?mKoookJ_oo:0000_oonfX0
1_ooN@3oo`00oookJ_l60?oooo]Zoi;o00;ooo]Z00?oo`00oa00oooonfX00_oonfX01Ooo057ooo]Z
o`2]oooonf[oo`1i00Kooo]Z00Go0?mCoookJ_oonf[o0?lMo`3Qo`0:oookJP03o`3o=?l0odkooo]Z
00;ooo]Z1?oob@001oooN@3oolT0ooo90?oonf[o00CooookJ_nDo`002ooonfX00oooN@3ooo]Zoook
JP0;oookJP03ool0;Ooonf[ooo]Z00Cooo]Z00?ooeL0oookJ_oonfX01OoonfX6oomi05cooo]Z00?o
07?ooookJ_oonfX05?oonfX00ooo0>[ooo]ZoookJP04oookJP03oolF0?oonf[ooi8000Cooo]Z00?o
o`3loookJ_oonfX00_oonfX00olH0?oooo]Zool60002oookJP06on_o0?oo0?Kooo]ZoookJ_l0Y_oo
Z03o0ooonfX01_oo0?Wo07OooookJ_oonf[o0?nJoom/00Gooo]Z00?o0?_ooookJ_oonfX01ooonfX0
0ol0Xooo/ol0oil0o`05oookJP;o0?oN0_oonfX00ooo06cooo]ZoookJP03oookJP03of40oooonf[o
oo]Z00Sooo]Z00?o0?nBoookJ_oonfX03OoonfX01?lH0?oo07CoonKo0?oVo`0/oookJP;oi_l00olH
0?l:oookJP;o0?nB1?oonfX2of40o`?o00000ooonfX01_l0omkooo]ZoookJ_oonf[o0:?ook?o00Wo
oo]Z00?oof`0oookJ_oonfX01?oonfX01ooo0?Kooo]ZoookJ_oonf[o603ooookJ_oo0?`02?oonfX0
0ooo0>[ooo]ZoookJP08oookJP03o`1coooonf[ooo]Z00Oooo]Z00?ooe80oookJ_l0:_l00ooonfX0
0ol0omoooo]ZoookJP04oookJP03o`3o6ooonf[oolX000;ooo]Z00?oo`2Cool04ooonfX00ooonfX0
1OoQo`3of_l0oookJ_lV0?oo8?l000kooo]Z013o0?mKoookJ_l0ok3oP_l0oookJ_l0<?oo0?m=oook
J_l60?oooo]Zool0mOnBo`3ooo]Zool0J_l@0?oo05go0ooonfX01?oo057ooo]Zo`2]oooo07T6oook
JP06o`3oDooonf[ooo]Zo`3o7Ooonf[o0>7o2OoonfX00ol0ocCooo]Zo`3oCP05oookJP03o`28ool0
ZOoooo]Z00;ooo]Z00?o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP0;oookJP03ool0;Ooo
nf[ooo]Z00Gooo]Z00?ooeL0oookJ_oonfX02?oonfX00oo[0?oo0?l5oookJP0ToookJP00=ooonfX0
1OooN@3ooo]ZoookJ_oonf[oogT001Kooo]Z00?oo`3ZoookJ_oonfX01?oonfX00ooo5P3ooo]ZoonB
0003oookJP03ool0o?oonf[ooo]Z00?ooo]Z00?o603oool60?oonfX00_oonfX02_oo:03oo`3foook
J_oonf[o0:KooookJ_nX0?oooo]Zool0nOl0Mol4oookJP03oom/0?oonf[ooo]Z00?ooo]Z00?o0?_o
oookJ_oonfX01OoonfX2ool00004o`2Soooonf[o/ol0ool000Cooo]Z00?oobP0oookJ_l0omh00_oo
nfX00ooo06cooo]ZoookJP03oookJP03of40oooonf[ooo]Z00Sooo]Z00?o0?nBoookJ_oonfX03Ooo
nfX3oaP0o`03onKo0?oonf[ooo]Z01gooo]Z1_ooN@03oookJP03o`1doooVo`3o603o00;o603o2ooo
nfX00ol0oi;ooo]ZoookJP04oookJP03of40oooonf[o000000;o00000_oo00001?l0omkooo]Zoook
J_oonfX2ok?o00;oo`002?oonfX00oooK03ooo]ZoookJP04oookJP07ool0m_oonf[ooo]ZoookJ_lH
0?oooo]Zool0o008oookJP03ool00?oonf[ooo]Z00Sooo]Z00?o07?ooookJ_oonfX01_oonfX01?oo
N@3ooe80oookJ_l0:_l2oookJP03oiCo0?oonf[o0?oO00Cooo]Z00Coo`00oolX0?oonf[oolX00ooo
nfX00ooo003oo`0CoookJP02oookJP05on7o0?oo003ooo]ZoookJ_lV0?l03ooonfX01_l0oe_ooo]Z
oolX0?oonf[oogT0ool000;ooo]Z00Ko1P3ooi;o0?oonf[ooo]Zool00?l@0?l4oookJP05ool0DOoo
nf[o0:gooookJ_oo07T01_oonfX01Ol0oe?ooo]Zo`3o2?l0oago0>7o00[ooo]Z00?o0?ldo`3oC_oo
nfX00_oonfX3ooo90003oomi0?oob@3oolT000;ooo]Z00?o00CooookJ_nDo`002ooonfX00oooN@3o
oo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z00Cooo]Z00?ooeL0oookJ_oonfX01OoonfX6oomi05co
oo]Z00?o07?ooookJ_oonfX05?oonfX00ooo0>[ooo]ZoookJP05oookJP03oolF0?oonf[ooi8000?o
oo]Z00?oo`3loookJ_oonfX00ooonfX01_lH0?ooo`H0oookJ_oonf[ojol0ool0mP?ooo]Z00Ko0:Ko
ojP0oooonf[ooo]Zool0nOl0Mol3oookJP03oom/0?oonf[ooo]Z00Cooo]Z00?o0?_ooookJ_oonfX0
1ooonfX00ol0Xooo/ol0ok?o0004oookJP03omgo0?oonf[o0?oN00;ooo]Z00?oo`1/oookJ_oonfX0
0ooonfX00omQ0?oooo]ZoookJP08oookJP03o`3oT_oonf[ooo]Z00gooo]Z0olH0?l2onKo02Oooo]Z
00?o07CoonKo0?lH0?l00_lH0?l<oookJP03o`3oT_oonf[ooo]Z00?ooo]Z00?oH@3ooookJ_l00000
0ol00002ool0K004o`3og_oonf[ooo]ZoookJP;o/ol02OoonfX00oooK03ooo]ZoookJP05oookJP06
ool0m_oonf[ooo]ZoookJ_lH0?ooo`3l2?oonfX00ooo0>[ooo]ZoookJP08oookJP03o`1coooonf[o
oo]Z00Oooo]Z00Cooe80oookJ_oonf[o02[o0_oonfX00ol0g?oo0?oOoookJP04oookJP03o`2>ool0
oa_oolX000?ooo]Z00?oo`2Cool04ooonfX00ooonfX01OoQo`3of_l0oookJ_lV0?ooQ03o00kooo]Z
00oo0?mKoookJ_l0ok3oP_l0o`0`oooonf[o0?m=oookJ_l60?ooo`3eoi;o0?oonf[oo`1Zoa00ool0
GOl01?oonfX01?oo057ooo]Zo`2]oooo07T6oookJP06o`3oDooonf[o0?l8o`3o7Ooonf[o0>7o2Ooo
nfX00ol0ocCo0?m>o`3o;P05oookJP03o`28ool0ZOoooo]Z00;ooo]Z00?o00CooookJ_l0e?l02ooo
nfX00oooP@3ooo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooeL0oookJ_oonfX02?oo
nfX00oo[0?oo0?l5oookJP0ToookJP00>ooonfX00oooN@3ooo]ZoookJP0DoookJP03ool0j_oonf[o
oo]Z00Cooo]Z00?ooaH0oookJ_ooTP001?oonfX00ooo0?cooo]ZoookJP03oookJP06oaP0oooo1P3o
oo]ZoookJ_oo:03oo`3f0ooonfX01_l0Y_ooZ03ooookJ_oo0?Wooo]Zo`1go`?ooo]Z00?oof`0oook
J_oonfX00ooonfX00ol0nooooo]ZoookJP06oookJP06ool00?oonf[o0:?ooookJ_nco`3oo`001?oo
nfX00ooo:03ogOl0o`3ogP02oookJP03ool0K?oonf[ooo]Z00?ooo]Z00?oH@3ooookJ_oonfX02?oo
nfX2o`3oTQ3ooo]Z0olH0?l00ol0M?oooo]ZoookJP0HoookJPSoogT000?o07Cooomi0?lH0?l00_lH
0?l<oookJP;o0?nB1OoonfX01?oo003oH@3ooookJ_oonfX2o`000003ool00?l0omko0?oN00?ooo]Z
00?o/ol0ool00?oo00002OoonfX00oooK03ooo]ZoookJP05oookJP06ool0m_oonf[ooo]ZoaP0oooo
nf[oo`3l2?oonfX00ooo003ooo]ZoookJP08oookJP03o`1coooonf[ooo]Z00Oooo]Z00Sooe80oook
J_oonf[o02[ooookJ_nDo`3ooo]Zo`3og`Cooo]Z00Coo`00oa80oooo:03oolX00ooonfX00ooo003o
o`0CoookJP03oookJP05ool00?oonf[ooo]ZobH0oolPo`003_oonfX00ol0oe_ooo]ZoolX0002oook
JP06oomi0?oo003ooo]Zo`H0oooonf[oT_l00_oonfX00ooo003o403ooookJP02oookJP05ool0DOoo
nf[ooo]Zo`2]oooo07T01_oonfX01Ol0oe?ooo]ZoookJ_l0o`So0?lM00[ooo]Z00?o0?ldo`3oC_oo
N@000ooonfX3ooo90003oomi0?oob@3ooo]Z00;ooo]Z00?o00CooiCo0?oonfX02ooonfX00oooN@3o
oo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z00Cooo]Z00?ooeL0oookJ_oonfX01OoonfX6oomi05go
oo]Z00?o07?ooookJ_oonfX04ooonfX00ooo0>[ooo]ZoookJP05oookJP03oolF0?oonf[ooi8000Co
oo]Z00?oo`3loookJ_oonfX00_oonfX00olH0?ooo`H0oookJP02oookJP03on_o0?oo0?Kooo]Z00;o
oo]Z00KoZ03ooookJ_oonf[oo`3ioookJ_l0Mol2oookJP03o`3oV_ooK03ooo]Z00Cooo]Z00?o0?_o
oookJ_oonfX02?oonfX00ol0Xooooo]Zok?o0004oookJP;ogOl000Co0?oNoookJ_oonf[oo`1/1Ooo
nfX00omQ0?oooo]ZoookJP08oookJP;o0?nB4?oonfX3oaP0o`03onKo0?oonf[ooo]Z023ooo]Z00?o
07CoonKo0?lH0?l00_lH0?l=oookJP;o0?nB1?oonfX2of40o`;ooo]Z0_l00002ool0K0;o0?oN0ooo
nfX00onco`3ooo]ZoookJP08oookJP03oom/0?oonf[ooo]Z00Gooo]Z00Koo`3foookJ_oonf[ooo]Z
oaP0oooo0?`8oookJP03ool0j_oonf[ooo]Z00Sooo]Z00?o07?ooookJ_oonfX01ooonfX01?ooDP3o
0?lcoookJ_l0:_l2oookJP03o`3Lool0omoooo]Z00Cooo]Z00?o08koo`3o6ooobP000ooonfX00ooo
09?oo`0CoookJP03oookJP05on7o0?oJo`3ooo]ZobH0oolPo`003_oonfX04?l0oe_ooo]Zo`3o/?n2
o`3ooo]Zo`0`ool0odgooo]Zo`H0oooonf[oo`3eoi;o0?oonf[oo`1Zoa00ool0GOl3oookJP04ool0
DOoonf[ooo]Zool0N@Kooo]Z00Ko0?mCoookJ_oonf[o0?l8o`3o7Ol0hOl9oookJP03o`3o=?oonf[o
0?m>00Kooo]Z00?o08Soo`2YoooonfX00_oonfX00ol01?oo0=CooookJP0;oookJP03oon10?oonf[o
oo]Z00_ooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooE`3ooo]ZoookJP09oookJP03on/0ool0o`Go
oo]Z02Cooo]Z000loookJP03oomi0?oonf[ooo]Z01Cooo]Z00?oo`3ZoookJ_oonfX01?oonfX00ooo
5P3ooo]ZoonB0003oookJP03ool0o?oonf[ooo]Z00?ooo]Z00?o603oool60?oonfX00_oonfX02?oo
:03oo`3foookJ_oonf[o0:KooookJ_nX0?oooo]Z0_oo:0001Ol0Mooooo]ZoookJ_l0oi[oof`000Go
oo]Z00?o0?_ooookJ_oonfX02?oonfX00ol0Xooooo]Zok?o0006oookJP05omgo0?l0omkooo]Zoook
J_oo06`01OoonfX00omQ0?oooo]ZoookJP09oookJP;o0?nB4OoonfX4oaP0o`03o`1doooonf[ooo]Z
01;ooo]Z2OooN@03oaP0o`gooo]Z0_l0oi86oookJP;oo`000ooonfX2ool00003o`3og_l0003ooo]Z
00;ooo]Z00?o/ol0ool00?oonfX02OoonfX00oooK03ooo]ZoookJP05oookJP06ool0m_oonf[ooo]Z
oaP0oooonf[oo`3l2?oonfX00ooo003ooo]ZoookJP09oookJP03o`1coooonf[ooo]Z00;ooo]Z0_oo
N@02oookJP04oomi0?ooDP3ooo]Zo`0Zo`;ooo]Z00?oU?l0o`3ogooonfX01?oonfX01?oo003oobP0
oookJ_oobP03oookJP03ool00?oonf[ooo]Z00;ooo]Z00KohOl0ool00?oonf[o9P3oob3o0?n40?l>
oookJP06o`3oFooonf[oobP0oookJ_ooN@3oo`000_oonfX00ol60?ooT_l0ool0m@02oookJP03ool0
0?l@0?oooo]Z00;ooo]Z00Goo`1AoookJ_l0[Ooooo]Zool0N@06oookJP05o`3oDooonf[ooo]Zo`3o
7Ol0hOl02_oonfX00ol0ocCo0?m>oookJP03oookJP?oolT000OoogT0ooo90?oonf[ooo]Zo`04oooo
nf[oU?l000_ooo]Z00?oogT0oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP05oookJP03oomG0?oo
nf[ooo]Z00Gooo]Z1_ooN@1MoookJP03o`1coooonf[ooo]Z01Cooo]Z00?oo`3ZoookJ_oonfX01Ooo
nfX00ooo5P3ooo]ZoonB0003oookJP03ool0o?oonf[ooo]Z00?ooo]Z00Ko603oool60?oonf[ooo]Z
on_o0?oo0?H3oookJP0:o`2VoonX0?oooo]ZoookJ_oo0?Wooo]Zo`1goooonf[o0?nJoom/00Kooo]Z
00?o0?_ooookJ_oonfX02?oonfX00ol0XoooW`3ook?o0005oookJP05omgo0?l0omkooo]ZoookJ_oo
06`01OoonfX00omQ0?oooo]ZoookJP09oookJP;o0?nB4OoonfX4oaP0o`03o`1doooonf[ooo]Z01So
oo]Z0ooVo`03oaP0o`gooo]Z0ol0oi85oookJP03of40oooonf[ooo]Z00;ooo]Z00Co0000ool0K?l0
003o0?oN0ooonfX2ok?o00[ooo]Z00?oof`0oookJ_oonfX01OoonfX01_oo0?Kooo]ZoookJ_oonf[o
603oool0o0Sooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ol0Looooo]ZoookJP07oookJP03oomB0?oo
nf[o02[o00?ooo]Z00?o0?oOoookJ_oonfX01?oonfX00ol0oa_o4P3oooo:0003oookJP03ool0Tooo
nf[ooo]Z00?ooo]Z00Gof_l0oookJ_oonf[o9P3ooh@0o`0>oookJP0;o`3oFooonf[o0?n`oh;o0?l0
<?oooo]Zo`3oCOoonf[o1P3ooookJ_nBo`000_oonfX00ooo06[o403ooookJP03oookJP04ool0DOoo
nf[o0:goool0N@Kooo]Z00Ko0?mCoookJ_oonf[o0?lMoookJ_l0hOl9oookJP03o`3o=?oonf[o0?m>
00Kooo]Z00Oo0:WooookJ_oonf[ooo]Zo`04oooonf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02ooo
nfX00ooo02gooo]ZoookJP05oookJP03oomG0?oonf[ooo]Z00Sooo]Z00?oj`3oog00oooonfX09Ooo
nfX003cooo]Z00?oogT0oookJ_oonfX05?oonfX00ooo0>[ooo]ZoookJP04oookJP03oolF0?oonf[o
oi8000?ooo]Z00?oo`3loookJ_oonfX01?oonfX01_oo1P3ooo]ZoookJ_oonf[oobP0ool0mP?ooo]Z
00?o0:KooookJ_nX0?l00ooo:0001?l0Mooooo]ZoookJ_ooK005oookJP03o`3koooonf[ooo]Z00Wo
oo]Z00?o0:?ooookJ_nco`001_oonfX01?oMo`3o0?oNoookJ_oo06`6oookJP03of40oooonf[ooo]Z
00[ooo]Z0_l0oi8AoookJP;oi_l00olH0?l00ooVo`3ooo]ZoookJP0=oookJPSoogT00olH0?l2oomi
00_ooo]Z0ol0oi86oookJP03of40oooo003oo`0000Coo`000_l0omh2o`000003oookJ_nco`3o/ol0
00_ooo]Z00?oof`0oookJ_oonfX01OoonfX01?oo0?Kooo]ZoookJ_lH0?l2oookJP03ool0o?oonf[o
oo]Z00Gooo]Z00?oo`00oookJ_oonfX02OoonfX00ol0Looooo]ZoookJP03oookJPCoogT000Sooe80
oookJ_oonf[o02[ooookJ_nDo`3ooo]Zo`3og`Cooo]Z00Coo`00oa80oooo:03oolX00ooonfX00ooo
003oo`0CoookJP03oookJP05ool00?oonf[ooo]ZobH0oolPo`003ooonfX02_l0oe_oobP0o`3o/?oo
nf[oogT0ool00?oonf[o1P3ooookJ_nBo`02oookJP03ool00?l@0?oooo]Z00;ooo]Z00Koo`1Aoook
J_oonf[o0:gooookJ_oo07T5oookJP06o`3oDooonf[ooo]Zo`3o2?l0oago0>7o2_oonfX00ol0ocCo
0?m>oookJP02oookJP?oolT000?oogT0ooo90?oonfX00_oonfX00ol01?oooo]ZoiCo000;oookJP03
oomi0?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooE`3ooo]ZoookJP06oookJPKo
ogT0GOoonfX00ol0Looooo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooaH0oookJ_oo
TP000ooonfX00ooo0?cooo]ZoookJP03oookJP03oaP0oooo1P3ooo]Z00;ooo]Z00?ojol0oookJ_oo
nfX00_oonfX01?l0Y_ooZ03ooookJ_oo0?T2oookJP04o`1goooonf[o0?nJoom/00Gooo]Z00?o0?_o
oookJ_oonfX02OoonfX00ol0XoooW`3ook?o0005oookJP04omgo0?l0omkooo]Zool0K0Kooo]Z00?o
H@3ooookJ_oonfX02_oonfX2o`3oTQ;ooo]Z00?oi_l0oaP0oolH0?l00_lH0?l00ol0M?oooo]Zoook
JP0@oookJPCoi_l00olH0?l>oookJP;o0?nB1_oonfX2of40o`Cooo]Z0_oo06`2o`3ogP04o`000?oo
nf[ooo]Zok?o00_ooo]Z00?oof`0oookJ_oonfX01OoonfX00ooo0?Kooo]ZoookJP02oaP0o`03oook
J_oo0?cooo]Z00Kooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ol0Looooo]ZoookJP07oookJP04oomB
0?oonf[ooo]Zo`0Zo`;ooo]Z00?o0=coo`3ogooonfX01?oonfX00ol0S_oo0?lKooo:0003oookJP03
ool0Tooo01?ooo]Z00?ooo]Z00GohOl0om[o0?oonf[o9P3oob3o000?oookJP0?o`3oFooonf[oP_l0
oookJ_l0<?oo0?m=oookJ_l60?oooo]Zool0mOnBo`3ooo]Zool0J_l@0?oo05go00?ooo]Z00Goo`1A
oookJ_oonf[o0:goool0N@05oookJP07o`3oDooonf[ooo]Zo`3o2?l0oagooo]Zo`3Qo`09oookJP03
o`3o=?l0odko0?l^00Gooo]Z00?o08Soo`2YoooonfX00_oonfX00ol01?oooo]Zo`3Do`0;oookJP03
oon10?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooE`3ooo]ZoookJP08oookJP03
on/0oom`0?oooo]Z02Gooo]Z000loookJP03oomi0?oonf[ooo]Z01Cooo]Z00?oo`3ZoookJ_oonfX0
1OoonfX00ooo5P3ooo]ZoonB0003oookJP03ool0o?oonf[ooo]Z00?ooo]Z00Oo603oool60?oonf[o
oo]ZoolX0?oonf[oo`3f00;ooo]Z00Co0:KooookJ_nX0?oooo]Z0ooo:0001?l0Mooooo]Zo`3oV_oo
K005oookJP03o`3koooonf[ooo]Z00Wooo]Z00?o0:?ooookJ_nco`001_oonfX01?oMo`3o0?oNoook
J_oo06`6oookJP;oH@3o3?oonfX2o`3oTQCooo]Z0olH0?l7onKo00?o07Co2olH0?l5oomi00Wooo]Z
0_l0oi88oookJP03of40oooo003oo`0000Coo`0000?o0?oNo`000?l000000_l000000onco`3o0:?o
oookJP0:oookJP03oom/0?oonf[ooo]Z00Cooo]Z0_oo0?H2oookJP04oaP0oooonf[ooo]Zool0o0So
oo]Z00?oo`00oookJ_oonfX02OoonfX00ol0Looooo]ZoookJP02oookJPGoogT000?ooe80oookJ_l0
:_l00_oonfX00onDo`3o0?oOoookJP04oookJP03oa80oooo:03oolX000?oo`0000?ooo]Zool00?oo
nfX00ooonfX01_oo003ooo]ZoookJ_lV0?oo8?l0oh@0o`kooo]Z00Ko0?mKoookJ_oo:03ooo]Zoomi
0?oo0002oookJP03o`H0oonBo`3oo`3e00;ooo]Z00?oo`00oa00oooonfX00_oonfX01Ooo057ooo]Z
oookJ_l0[Oooo`1i00Kooo]Z00Go0?mCoookJ_oonf[o0?l8o`3o7@0:oookJP03o`3o=?l0odkoogT0
00?ooo]Z0ooob@001oooN@3oolT0oiCo0?nDo`3ooo]Zo`04oonDo`002?oonfX3oomi0003oookJ_oo
N@3ooo]Z00cooo]Z00?oo`0]oookJ_oonfX01?oonfX00oooE`3ooo]ZoookJP06oookJPKoogT0G_oo
nfX00ol0Looooo]ZoookJP0CoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oookJ_ooTP000ooo
nfX00ooo0?cooo]ZoookJP03oookJP06ool60?oonf[ooo]ZoookJ_o[o`3oo`3f0ooonfX02ol0Y_oo
Z03ooookJ_oonf[oo`3ioookJ_l0Mooooo]Zo`3oV_oonf[oof`000Gooo]Z00?o0?_ooookJ_oonfX0
2OoonfX00ol0XoooW`3ook?o0005oookJP04omgo0?l0omkooo]Zool0K0Kooo]Z0_mQ0?l<oookJP;o
0?nB5OoonfX3oaP0o`Koi_l000Cooo]Zo`1dool0M?oo07Co2_lH0?l?oookJP;o0?nB1ooonfX00omQ
0?oooo]ZoookJP02oookJP;oo`1/00?ooo]Zo`3og_l000000_l000000ol0Xooo/ol0oookJP0:oook
JP03oom/0?oonf[ooo]Z00Cooo]Z0_oo0?H2oookJP04oaP0oooonf[ooo]Zool0o0Sooo]Z00?oo`3Z
oookJ_oonfX02OoonfX00ol0Looooo]ZoookJP07oookJP03oomB0?oonf[o02[o00;ooo]Z00?o0=co
o`3ogooonfX01OoonfX00ol0oa_ooo]Zooo:0003oookJP03ool0Tooonf[ooo]Z00?ooo]Z00Gof_l0
oookJ_oonf[o9P3ooh@0o`0>oookJP0;o`3oFooonf[o0?n`oh;o0?l0<?oooo]Zo`3oCOoonf[o1P3o
oookJ_nBo`000_oonfX00ooo06[o403ooookJP03oookJP04ool0DOoonf[ooo]Zool0N@Kooo]Z00Ko
0?mCoookJ_oonf[o0?l8o`3o7Ol0hOl9oookJP03o`3o=?oonf[o0?m>00Kooo]Z00?o0:WooookJ_oo
nfX00_oonfX00ol01?oo0=CooookJP0;oookJP03oon10?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oo
nfX01?oonfX00oooE`3ooo]ZoookJP09oookJP03on/0ool0o`Gooo]Z02Gooo]Z000moookJP03oomi
0?oonf[ooo]Z01Cooo]Z00?oo`3ZoookJ_oonfX01OoonfX00ooo5P3ooi80oookJP03oookJP03ool0
o?oonf[ooo]Z00?ooo]Z00Koo`H0oookJ_oonf[ooo]ZoolX0?oo0?H3oookJP03o`2Voooonf[oZ03o
00?oobP000Co07OooolX0?oonf[oof`01_oonfX00ol0nooooo]ZoookJP09oookJP03o`2Soooonf[o
/ol000Kooo]Z00CogOl0o`3og_oonf[oo`1/1ooonfX00omQ0?oooo]ZoookJP0;oookJP;o0?nB5Ooo
nfX:oaP0oa3oogT01ooonfX2o`3oTPSooo]Z0_mQ0?l7ool00005oookJ_l0003o0000o`000?nco`00
3?oonfX00oooK03ooo]ZoookJP04oookJP05ool0m_oonf[ooo]ZoookJ_lH0?l00_oonfX00ooo0?co
oo]ZoookJP06oookJP03ool00?oonf[ooo]Z00Wooo]Z00?o07?ooookJ_oonfX00ooonfX4oomi0008
oomB0?ooN@3oogT0o`0Zoooonf[oU?l0oookJ_l0oml4oookJP04ool00?oo:03ooo]Zooo:00Coo`00
00?oo`0CoookJ_oonfX00_oonfX01Ooo003ooo]ZoookJ_lV0?ooQ03o00oooo]Z00[o0?mKoolX0?l0
ok3ooo]Zoomi0?oo003ooo]Zo`H0oooonf[oT_l00_oonfX00ooo003o403ooookJP02oookJP06ool0
DOoonf[ooo]Zo`2]oooonf[oo`1i1OoonfX01_l0oe?ooo]ZoookJ_l0o`So0?lMo`3Qo`[ooo]Z00?o
0?ldo`3oC_oonfX00ooonfX2ooo90003oomi0?oob@3ooo]Z00GoU?l02?oonfX6oomi00_ooo]Z00?o
o`0]oookJ_oonfX01OoonfX00oooE`3ooo]ZoookJP06oookJPGoogT0GooonfX00ol0Looooo]Zoook
JP0DoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oonB0?oonfX00_oonfX00ooo0?cooo]Zoook
JP03oookJP03oaP0oooo1P3ooo]Z00;ooo]Z00?ojol0oookJ_oonfX00_oonfX02_l0Y_ooZ03ooook
J_oonf[oo`3ioookJ_l0Mooooo]Zo`3oV_ooK006oookJP03o`3koooonf[ooo]Z00Wooo]Z00?o0:?o
oil0oonco`001OoonfX01?oMo`3o0?oNoookJ_oo06`7oookJP03of40oooonf[ooo]Z00_ooo]Z0_l0
oi8FoookJP[o603o00?oi_l0oookJ_oonfX04ooonfX3o`3oTPOooo]Z0_mQ0?l4oookJP04ool0K?oo
nf[ooo]Zo`3ogP?o00000_nco`0;oookJP03oom/0?oonf[ooo]Z00Cooo]Z00Goo`3foookJ_oonf[o
oo]ZoaP0o`02oookJP03ool0o?oonf[ooo]Z00Kooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ol0Looo
oo]ZoookJP07oookJP04oomB0?oonf[ooo]Zo`0Zo`;ooo]Z00?o0=coo`3ogooonfX01?oonfX00ol0
S_oo0?lKooo:0003oookJP03ool0Tooo01?ooo]Z00?ooo]Z00GohOl0om[o0?oonf[o9P3ooh@0o`0?
oookJP0?o`3oFooonf[oP_l0oookJ_l0<?oo0?m=oookJ_l60?oooo]Zool0mOnBo`3ooo]Zool0J_l@
0?oo05go00?ooo]Z00Goo`1AoookJ_oonf[o0:goool0N@05oookJP07o`3oDooonf[ooo]Zo`3o2?l0
oagooo]Zo`3Qo`09oookJP03o`3o=?l0odko0?l^00Kooo]Z00Oo0:WooookJ_oonf[ooo]Zo`04oooo
nf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP05oookJP03oomG0?oo
nf[ooo]Z00Wooo]Z00?oj`3ooookJ_oonfX09OoonfX002[ooo]Z00?o^Ol0oookJ_oonfX04?oonfX0
0oooN@3ooo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z00Gooo]Z00?ooaH0oookJ_ooTP000ooonfX0
0ooo0?cooo]ZoookJP03oookJP06ool60?oonf[ooo]ZoookJ_oo:03oo`3f0ooonfX01?l0Y_oooo]Z
ojP0oooonfX3oolX0004o`1goooo:03o0?nJoom/00Kooo]Z00?o0?_ooookJ_oonfX02OoonfX00ol0
Xoooo`00ok?o0006oookJP04omgo0?l0omkooo]Zool0K0Oooo]Z0_mQ0?l=oookJP03o`3oT_oonf[o
oo]Z02Gooo]Z1oooN@05oookJP;o0?nB2?oonfX2of40o`03oookJ_oo003oo`0000Ooo`0000Co0000
ok?o0?nco`3o00002ooonfX00oooK03ooo]ZoookJP04oookJP05ool0m_oonf[ooo]ZoookJ_lH0?l0
0_oonfX00ooo0?cooo]ZoookJP06oookJP03ool00?oonf[ooo]Z00Wooo]Z00?oobP0oookJ_oonfX0
1?oonfX3oomi0008oomB0?ooN@3oogT0o`0ZooooN@3oU?l0oookJ_l0oml4oookJP04ool00?lB0?oo
obP0ooo:00Ooo`000_oonfX01_oo003ooo]ZoookJ_lV0?oo8?l0oh@0o`kooo]Z00Ko0?mKoookJ_oo
:03ooo]Zoomi0?oo0002oookJP03o`H0oonBo`3oo`3e00;ooo]Z00?oo`00oa00oooonfX00_oonfX0
1Ooo057ooo]ZoookJ_l0[Oooo`1i00Kooo]Z00Ko0?mCoookJ_oonf[o0?l8o`3o7Ol0hOl:oookJP03
o`3o=?l0odkooo]Z00?ooo]Z0_oob@000oooN@3oolT0oookJP07oiCo00Kooo]Z2?ooN@09oookJP03
ool0;Ooonf[ooo]Z00Cooo]Z00?ooeL0oookJ_oonfX01ooonfX4oomi04gooo]Z00?o^Ol0oookJ_oo
nfX04?oonfX00ol0Looooo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oookJ_oo
TP000ooonfX00ooo0?cooo]ZoookJP02oookJP03oaP0oooo1P3ooo]Z00;ooo]Z00?ojol0oookJ_oo
nfX00_oonfX00ol0Y_ooZ03ooookJP02oookJP06ool0nOoonf[o07Ooo`3oV_oonf[oof`01_oonfX0
0ol0nooooo]ZoookJP09oookJP03o`2Soooonf[o/ol000Gooo]Z00CogOl0o`3og_oonf[oo`1/1ooo
nfX2of40o`gooo]Z00?o0?nBoookJ_oonfX0<OoonfX2o`3oTPSooo]Z0_mQ0?l4oookJP;oo`1/00Co
oo]Zo`3og_l0omkooo]Z0_l000000onco`3o0000oookJP0:oookJP03oom/0?oonf[ooo]Z00Cooo]Z
00Goo`3foookJ_oonf[ooo]ZoaP0o`02oookJP03ool0o?oonf[ooo]Z00Kooo]Z00?oo`3ZoookJ_oo
nfX02OoonfX00ol0Looooo]ZoookJP07oookJP04oomB0?l0oc?ooo]Zo`0Zo`;ooo]Z00?o0=coo`3o
gooonfX01?oonfX01?l0S_oo0?lKoookJ_oobP03oookJP03ool0Tooonf[ooo]Z00?ooo]Z00Gof_l0
oookJ_oonf[o9P3ooh@0o`0>oookJP0;o`3oFooonf[o0?n`oh;o0?l0<?oooo]Zo`3oCOoonf[o1P3o
oookJ_nBo`000_oonfX00ooo06[o403ooookJP03oookJP04ool0DOoonf[ooo]Zool0N@Kooo]Z00Oo
0?mCoookJ_oonf[o0?l8o`3o7Ooonf[o0>7o00Wooo]Z00?o0?ldo`3oC_oonfX01OoonfX00ol0R?oo
0:WooookJP02oookJP03o`04oooonf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02go
oo]ZoookJP05oookJP03oomG0?oonf[ooo]Z00Sooo]Z00?oj`3oog00oooonfX09_oonfX002[ooo]Z
00?o^Ol0oookJ_oonfX04?oonfX00oooN@3ooo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z00Kooo]Z
00?ooaH0oonB0?oonfX00ooonfX00ooo0?cooo]ZoookJP03oookJP06ool60?oonf[ooo]ZoookJ_oo
:03oo`3f0ooonfX00ol0Y_oooo]ZojP0o`04oolX0004o`1goooo:03oobP0oom/00Kooo]Z00?o0?_o
oookJ_oonfX02OoonfX00ol0Xoooo`00ok?o0006oookJP03omgo0?l0omkooo]Z00;oo`1/1ooonfX2
of40o`cooo]Z0_l0oi8^oookJP?o0?nB2OoonfX00omQ0?oooo]ZoookJP0:ool00004ok?o0?l0Xooo
0000o`0000Wooo]Z0_ooK006oookJP05ool0m_oonf[ooo]ZoookJ_lH0?l00_oonfX00ooo0?cooo]Z
oookJP06oookJP03ool00?oonf[ooo]Z00[ooo]Z00?oobP0oookJ_oonfX00ooonfX4oomi0003oomB
0?ooN@3o02[o00;ooo]Z00?oU?l0o`3ogooonfX01?oonfX01?oo003oobP0oookJ_oobP08ool00006
oookJ_oo003ooo]ZoookJ_lV0?ooQ03o3ooonfX02_l0oe_oobP0o`3o/?ooN@3ooo]Zool00?oonf[o
1P3ooookJ_nBo`02oookJP03ool00?l@0?oooo]Z00;ooo]Z00Koo`1AoookJ_oonf[o0:gooookJ_oo
07T5oookJP06o`3oDooonf[ooo]Zo`3o2?oonf[o0?lM2_oonfX00ol0ocCo0?m>oomi0004oookJP;o
olT000?oogT0oookJ_oonfX02?nDo`05oookJPSoogT02?oonfX00ooo02gooo]ZoookJP05oookJP03
oomG0?oonf[ooo]Z00Oooo]Z1?ooN@1=oookJP03okWo0?oonf[ooo]Z017ooo]Z00?o07?ooookJ_oo
nfX04ooonfX00ooo0>[ooo]ZoookJP07oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00?oo`3loookJ_oo
nfX00_oonfX01_lH0?ooo`H0oookJ_oonf[ojol0ool0mPCooo]Z00Go0:KoojP0oooonf[ooo]Zool0
n@02oookJP03o`1gool0oi[oof`000Oooo]Z00?o0?_ooookJ_oonfX02OoonfX00ol0Xooooo]Zok?o
0006oookJP04o`3og_oonf[oo`1/ool0K0Oooo]Z0_mQ0?l<oookJP;o0?nB;ooonfX2o`3oTPWooo]Z
00?oH@3ooookJ_oonfX00_oonfX2ool0K0;ooo]Z00Co0?oNoookJ_oonf[ooo]Z0_nco`02o`0000Wo
oo]Z0_ooK006oookJP05ool0m_oonf[ooo]ZoookJ_lH0?l00_oonfX00ooo0?cooo]ZoookJP06oook
JP03ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX01_oonfX02?nio`3ooe80oookJ_oonf[o
02[ooookJ_l0g?oo0?oO1_oonfX00ol0oa_o4P3oooo:0003oookJP03ool0Tooo01?ooo]Z00?ooo]Z
00Kof_l0oookJ_oonf[o9P3ooookJ_n40?l>oookJP0>o`3oFooonf[oP_l0o`0`oooonf[o0?m=oook
J_l60?oooo]Zool0mOnBo`3ooo]Zool0J_l@0?l4oookJP05ool0DOoonf[ooo]Zo`2]oooo07T01Ooo
nfX01ol0oe?ooo]ZoookJ_l0o`Sooo]Zo`3o7Ol0hOl02OoonfX00ol0ocCooo]Zo`3oCP06oookJP03
o`2Yoooonf[ooo]Z00;ooo]Z00?o00Coo`3DoooonfX02ooonfX00oooP@3ooo]ZoookJP0:oookJP03
ool0;Ooonf[ooo]Z00Gooo]Z00?ooeL0oookJ_oonfX02OoonfX00oo[0?oooo]ZoookJP0VoookJP00
:ooonfX00onio`3ooo]ZoookJP0?oookJP03oomi0?oonf[ooo]Z01Gooo]Z00?oo`3ZoookJ_oonfX0
1OoonfX00ooo5P3ooo]ZoonB0003oookJP03ool0o?oonf[ooo]Z00?ooo]Z00Ko603oool60?oonf[o
oo]ZoolX0?oo0?H3oookJP03o`2Voooonf[ooo]Z00GoobP000Co07OooolX0?oo:03oobP01_oonfX0
0ol0nooooo]ZoookJP09oookJP03o`2Soooo003o/ol000Kooo]Z00GogOl0o`3og_oonf[ooo]Zool0
K008oookJP03of40oooonf[ooo]Z00_ooo]Z0_l0oi8ZoookJP;o0?nB2_oonfX2of40o`;ooo]Z2Ooo
0002ok?o00Go00001ooonfX00oooK03ooo]ZoookJP05oookJP05ool0m_oonf[ooo]ZoookJ_lH0?l0
0_oonfX00ooo0?cooo]ZoookJP02ool000Cooo]Z00?oo`00oookJ_oonfX02_oonfX00ooo:03ooo]Z
oookJP04oookJP?oogT000Sooe80oomi0?ooN@3o02[ooookJ_nDo`3ooo]Zo`3og`Cooo]Z00Coo`00
oolX0?oonf[oolX02_oo0002oookJP03obH0oolPo`3oQ03o00kooo]Z00Go0?mKoookJ_oo:03ooo]Z
oomi0002ool00004oookJ_l60?ooT_l0ool0m@;ooo]Z00?oo`00oa00oooonfX00_oonfX01_oo057o
oo]ZoookJ_l0[Ooooo]Zool0N@Gooo]Z00Ko0?mCoookJ_oonf[o0?l8o`3o7Ol0hOl:oookJP03o`3o
=?l0odkooo]Z00Cooo]Z00?oolT0oomi0?oonfX00_oonfX8oiCo00Gooo]Z1oooN@09oookJP03ool0
;Ooonf[ooo]Z00Gooo]Z00?ooeL0oookJ_oonfX01ooonfX3oomi04oooo]Z00?o^Ol0oookJ_oonfX0
4?oonfX00ol0Looooo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oookJ_ooTP00
0ooonfX00ooo0?cooo]ZoookJP02oookJP03oaP0oooonf[oo`H000;ooo]Z00?ojol0oookJ_oonfX0
0_oonfX00ol0Y_oooo]ZojP0o`02oookJP06ool0nOoonf[o07Ooo`3oV_oonf[oof`01ooonfX00ol0
nooooo]ZoookJP08oookJP04o`2SoonO0?oooo]Zok?o00Kooo]Z00?o0?oNoookJ_oonfX00_oo06`7
oookJP03of40oooonf[ooo]Z00_ooo]Z0_l0oi8ZoookJP?o0?nB2OoonfX2of40o`Cooo]Z00Goo`1/
oookJ_oonf[ooo]Zo`3ogP03oookJP03ok?o0?l0003o000000?o00001ooonfX00oooK03ooo]Zoook
JP05oookJP05ool0m_oonf[ooo]ZoookJ_lH0?l00_oonfX00ooo0?cooo]ZoookJP06oookJP03ool0
j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX01ooonfX01?ooDP3ooo]ZoookJ_l0:_l2oookJP03
o`3Lool0omoooo]Z00Cooo]Z00?o08koo`3o6ooobP000ooonfX00ol0nOooo`2CoookJP04oookJP05
om[o0?oonf[ooo]ZobH0oon40?l03_oonfX02ol0oe_ooo]Zo`3o/?n2o`3o033ooookJ_l0odgo0>So
o`H0oooonf[oT_l000;ooo]Z00?oo`1Zoa00oooonfX00ooonfX01Ooo057ooo]ZoookJ_l0[Oooo`1i
00Gooo]Z00Oo0?mCoookJ_oonf[o0?l8o`3o7Ooonf[o0>7o00Wooo]Z00?o0?ldo`3oC_l0obh01_oo
nfX01ol0ZOoooo]ZoookJ_oonf[o00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP0;oookJP03
ool0;Ooonf[ooo]Z00Gooo]Z00?ooeL0oookJ_oonfX02OoonfX00oo[0?oooo]ZoookJP0VoookJP00
:_oonfX00ol0oc?o^Ol0oookJP0AoookJP03oomi0?oonf[ooo]Z01Cooo]Z00?oo`3ZoookJ_oonfX0
1_oonfX00ooo5P3ooi80oookJP03oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Oo603ooookJ_oo1P3o
oo]ZoolX0?oonf[oo`3f00?ooo]Z00?o0:KooookJ_nX0?l01?oo:0000ol0MoooobP0oolX0003oolX
00Gooo]Z00?o0?_ooookJ_oonfX02OoonfX00ol0Xooooo]Zok?o0007oookJP03o`3og_oonf[ooo]Z
00;oo`1/1ooonfX2of40o`gooo]Z0_l0oi8UoookJP?o0?nB2OoonfX3of40o`03oolX0?oonf[ooo]Z
00Soo`0000Cooo]Zok?o0?l0Xooooo]Z1?l00007oookJP03oom/0?oonf[ooo]Z00Gooo]Z00Goo`3f
oookJ_oonf[ooo]ZoaP0o`02oookJP04ool0o?oonf[ooo]ZoookJP?oo`000_oonfX00ooo003ooo]Z
oookJP0:oookJP03oolX0?oonf[ooo]Z00Gooo]Z0oooN@002?ooDP3oogT0o`0Zoooonf[oU?l0oook
J_l0omoooo]Z0_oo0002oookJP04ool00?oo:03oolX0oookJPWoo`0000KohOl0oookJ_oonf[o9P3o
oookJ_n40?l=oookJP06o`3oFooonf[oobP0o`3o/?ooN@3ooo]Z0_oo00000ol60?oooo]Zoi;o0002
oookJP03ool00?l@0?oooo]Z00;ooo]Z00Koo`1AoookJ_oonf[o0:gooookJ_oo07T5oookJP07o`3o
Dooonf[ooo]ZoookJ_l0o`So0?lMo`3Qo`0:oookJP03o`3o=?l0odkooo]Z00Cooo]Z00?oolT0oomi
0?oonfX00_oonfX7oiCo00Kooo]Z1_ooN@09oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0oook
J_oonfX01ooonfX3oomi00;ooo]Z00?oolT0oookJ_oonfX0BOoonfX00ol0oc?o^Ol0oookJP0Aoook
JP03o`1coooonf[ooo]Z01Cooo]Z00?oo`3ZoookJ_oonfX01ooonfX00ooo5P3ooi80oookJP03oook
JP03ool0o?oonf[ooo]Z00;ooo]Z00Ko603ooookJ_oo1P3ooo]Zon_o0?oo0?H4oookJP03o`2VoonX
0?oooo]Z00;ooo]Z00Goo`3ioookJ_l0Mooo0?nJoom/0008oookJP03o`3koooonf[ooo]Z00Sooo]Z
00Co0:?ooookJ_oonf[o/ol01_oonfX01Ol0omkooo]ZoookJ_oonf[oo`1/00Oooo]Z0_mQ0?l=oook
JP;o0?nB9OoonfX3o`3oTPWooo]Z0omQ0?l4oookJP;oo`1/0_oonfX2o`3ogP;ooo]Z0_nco`000ooo
nf[o0000o`000002o`0000Oooo]Z00?oof`0oookJ_oonfX01OoonfX01Ooo0?Kooo]ZoookJ_oonf[o
603o00;ooo]Z00?oo`3loookJ_oonfX01_oonfX00ooo0>[ooo]ZoookJP0:oookJP03o`1coooonf[o
oo]Z00Oooo]Z00Co^Ol0oomB0?oonf[o02[o0_oonfX00ol0g?oo0?oOoookJP05oookJP03o`3o6olB
0?ooolX000?ooo]Z00?oo`2CoookJ_oonfX00ooonfX01_oJo`3ooo]ZoookJ_lV0?oooo]Zoh@0o`go
oo]Z00Go0?mKoookJ_oonf[oP_l0o`0`o`02oookJP08o`3oCOl0j?oooo]Zool0mOnBo`3ooo]Zool0
J_l@0?l4oookJP05ool0DOoonf[ooo]Zo`2]oooo07T01OoonfX02?l0oe?ooo]ZoookJ_oonf[o0?l8
o`3o7Ooonf[o0>7o2OoonfX00ol0ocCo0?m>oookJP05oookJP03o`2Yoooonf[ooo]Z00;ooo]Z00?o
00CooookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?o
oeL0oookJ_oonfX02OoonfX01Oo[0?oooo]ZoookJ_oonf[ookh002Cooo]Z000ZoookJP03oomB0?ni
o`3ooo]Z017ooo]Z00?oogT0oookJ_oonfX05?oonfX00ooo0>[ooo]ZoookJP06oookJP03oolF0?oo
nf[ooi8000Cooo]Z00?oo`3loookJ_oonfX00_oonfX01olH0?ooo`H0oookJ_oonf[oobP0oookJ_oo
0?H00_oonfX00ol0Y_oooo]ZoookJP05oolX0003o`1goooo:03oobP000?oobP01OoonfX00ol0nooo
oo]ZoookJP09oookJP03o`2Soooonf[o/ol000Oooo]Z00Co0?oNoookJ_oonf[ooo]Z0_oo06`7oook
JP;oH@3o3OoonfX4o`3oTQcooo]Z1Ol0oi8:oookJP;oH@3o00Gooo]ZoolX0?oo:03oobP0oookJP06
ool000?ooo]Z00Co/ol0oookJ_oonf[ooo]Z1?l00005oookJP;oof`01ooonfX00ooo0?Kooo]Zoook
JP02ool000?ooo]Z00?oo`3loookJ_oonfX01_oo000<oookJP03oolX0?oonf[ooo]Z00Gooo]Z0ooo
N@002OooDP3oogT0oookJ_l0:_oooo]ZoiCo0?l0omooo`00oookJP04ool00004oolX0?oonf[oolX0
oookJPOoo`0000Oooo]Zool00?oonf[ooo]ZobH0oolPo`3oQ03o00kooo]Z00_o0?mKoookJ_oo:03o
0?n`oomi0?oonf[oo`00oookJ_l60?ooT_l0ool0m@02oookJP03oa00oooonf[ooo]Z00;ooo]Z00Ko
o`1AoookJ_oonf[o0:gooookJ_oo07T5oookJP06o`3oDooonf[ooo]Zo`3o2?oonf[o0?lM2_oonfX0
0ol0ocCo0?m>oomi0005oookJP03oomi0?oonf[ooo]Z00;ooo]Z1_nDo`07oookJPKoogT02OoonfX0
0ooo02gooo]ZoookJP05oookJP03oomG0?oonf[ooo]Z00Sooo]Z0_ooN@03oookJP03ooo90?oonf[o
oo]Z04Wooo]Z00?ooe80okWo0?oonfX04_oonfX00ol0Looooo]ZoookJP0CoookJP03ool0j_oonf[o
oo]Z00Oooo]Z00?ooaH0oookJ_ooTP000ooonfX00ooo0?cooo]ZoookJP02oookJP03oaP0oooonf[o
o`H000;ooo]Z00?ojol0ool0m_oonfX00_oonfX00ol0Y_oooo]ZojP0o`03oookJP05ool0nOoonf[o
07Ooo`3oV_ooK0002?oonfX00ol0nooooo]ZoookJP08oookJP04o`2Soooonf[ooo]Zok?o00Kooo]Z
00Co0?oNoookJ_oonf[ooo]Z0_oo06`7oookJP;oH@3o3OoonfX4o`3oTQcooo]Z1Ol0oi8:oookJP;o
H@3o1OoonfX2ool0K0;ooo]Z0_l0omh3oookJP04ok?o0?oonf[ooo]ZoookJPCo00001_oonfX00ooo
K03ooo]ZoookJP05oookJP03ool0m_oonf[ooo]Z00;oo`H00ooonfX00ooo0?cooo]ZoookJP05oook
JP03ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oonfX01ooonfX02Onio`3ooe80oookJ_oonf[o
02[ooookJ_l0g?oo0?oOocd0o`05oookJP03o`2>ool0oa_oolX000?ooo]Z00?oo`2Cool04ooonfX0
1?oonfX01OoJo`3ooo]ZoookJ_lV0?ooQ03o00kooo]Z00_o0?mKoookJ_oonf[oP_l0o`0`oooonf[o
0?m=o`3Xool60?oooo]Zoi;o0002oookJP03ool0J_l@0?oooo]Z00?ooo]Z00Goo`1AoookJ_oonf[o
0:goool0N@05oookJP07o`3oDooonf[ooo]Zo`3o2?oonf[o0?lMo`3Qo`09oookJP03o`3o=?oonf[o
0?m>00Kooo]Z00Oo0:WooookJ_oonf[ooo]Zo`04oooonf[o0=Co00cooo]Z00?ooh40oookJ_oonfX0
2_oonfX00ooo02gooo]ZoookJP06oookJP03oomG0?oonf[ooo]Z00Sooo]Z00?oj`3ooookJ_oonfX0
0_oonfX00ooo_P3ooo]ZoookJP0RoookJP00:_oonfX00oooDP3o0?lcokWo000AoookJP03oomi0?oo
nf[ooo]Z01Gooo]Z00?oo`3ZoookJ_oonfX01_oonfX00ooo5P3ooi80oookJP03oookJP03ool0o?oo
nf[ooo]Z00;ooo]Z00Go603ooookJ_oo1P3ooo]Zon_o0002oookJP04ool0m_oonf[ooo]Zo`2Vo`;o
oo]Z1Ooo:0000ol0MoooobP0oolX0004oolX00Cooo]Z00?o0?_ooookJ_oonfX02OoonfX00ol0Xooo
oo]Zok?o0007oookJP03o`3og_oonf[ooo]Z00;ooo]Z00?oo`1/oookJ_oonfX01_oonfX00omQ0?oo
oo]ZoookJP0>oookJPOo0?nB4?oonfX5o`3oTPcooo]Z0omQ0?l2oookJPCoobP01?oo0004oookJP;o
/ol01?oonfX4o`0000Cooo]Z00?oof`0oookJ_oonfX01_oonfX01Ooo0?Kooo]ZoookJ_oo003o603o
00?ooo]Z00Coo`3loookJ_oonf[ooo]Z1_oo000;oookJP03oolX0?oonf[ooo]Z00Kooo]Z0_ooN@00
2OooDP3oogT0oookJ_l0:_oooo]ZoiCo0?oonf[o0?oOoookJP04ool00004oolX0?lB0?ooolX0oook
JPOoo`0000?ooo]Zool00?oQo`000_oonfX00olV0?oooo]Zoh@0o`0=oookJP06o`3oFooonf[oobP0
o`3o/?ooN@3ooo]Z0_oo00000ol60?oooo]Zoi;o0003oookJP05oa00oooonf[ooo]ZoookJ_oo0540
0_oonfX01?l0[Ooooo]ZoookJ_oo07T4oookJP07o`3oDooonf[ooo]ZoookJ_l0o`So0?lMo`3Qo`0:
oookJP03o`3o=?l0odkooo]Z00Gooo]Z00?oogT0oookJ_oonfX00_oonfX6oiCo00Oooo]Z1OooN@0:
oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooeL0oookJ_oonfX02?oonfX01OooN@3ooo]ZoookJ_oo
nf[oolT004cooo]Z00?ooe80o`3o<onio`004_oonfX00ol0Looooo]ZoookJP0DoookJP03ool0j_oo
nf[ooo]Z00Oooo]Z00?ooaH0oonB0?oonfX00ooonfX00ooo0?cooo]ZoookJP02oookJP07oaP0oooo
nf[oo`H0oookJ_o[o`3ooo]Zool0mP03oookJP03o`2Voooonf[oZ03o00;ooo]Z00Koo`3ioookJ_oo
nf[o07Ooo`3oV_ooK008oookJP03o`3koooonf[ooo]Z00Sooo]Z00Co0:?ooookJ_oonf[o/ol01_oo
nfX00ol0omkogOl0oookJP02oookJP;oo`1/1ooonfX00omQ0?oooo]ZoookJP0>oookJPOo0?nB4?oo
nfX5o`3oTPcooo]Z0omQ0?l6oookJP03ool0K?oonf[ooo]Z00;o0?oN0ooonfX00ol0Xooo/ol0oook
JP03oookJPCo00001?oonfX2oom/00Oooo]Z00Goo`3foookJ_oonf[oo`H0oaP0o`03oookJP03ool0
o?oonf[ooo]Z00Kooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ol0Looooo]ZoookJP07oookJP05okWo
0?ooDP3ooo]ZoookJ_l0:_l00_oonfX00ol0g?oo0?oOoookJP04oookJP04o`2>ool0oa_o4P3oooo:
00;ooo]Z00?o0?Woool0TooonfX01?oonfX01_oJo`3ooo]ZoookJ_lV0?oooo]Zoh@0o`gooo]Z00Go
0?mKoookJ_oonf[oP_l0o`0`o`02oookJP05o`3oCOl0j?oooo]Zool0mOnBo`000_oonfX00ol@0?oo
oo]ZoookJP02oookJP06ool0DOoonf[ooo]Zo`2]oooonf[oo`1i1?oonfX02?l0oe?ooo]ZoookJ_oo
nf[o0?l8o`3o7Ooonf[o0>7o2OoonfX00ol0ocCo0?m>o`3o;P06oookJP07o`2Yoooonf[ooo]Zoook
J_l01?oooo]Zo`3Do`0<oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX01OoonfX0
0oooE`3ooo]ZoookJP09oookJP05on/0oooonf[ooo]ZoookJ_oo_P009OoonfX002_ooo]Z00?ooe80
okWo0?oonfX04OoonfX00oooN@3ooo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0
oookJ_ooTP001?oonfX00ooo0?cooo]ZoookJP02oookJP05oaP0oooonf[oo`H0oookJ_o[o`000_oo
nfX00ooo0?Kooo]Zo`2Vo`02oookJPKoobP000?o07Oooom/0?oo:0001?oo:004oookJP03o`3koooo
nf[ooo]Z00Wooo]Z00?o0:?ooookJ_nco`001ooonfX00ol0omkooo]ZoookJP02oookJP;oo`1/1ooo
nfX2of40oaGooo]Z1_l0oi85oookJPGo0?nB3ooonfX2of40o`Cooo]Z0ooo:0001?oo06coo`00ool0
0?oo:005oookJP03ok?o0?oonf[ooo]Z00Cooo]Z1?l00003oookJP03oom/0?oonf[ooo]Z00Kooo]Z
00Goo`3foookJ_oonf[oo`00oaP0o`03oookJP04ool0o?oonf[ooo]ZoookJPSoo`002OoonfX00ooo
:03ooo]ZoookJP07oookJP;oogT000Oooe80oookJ_oonf[o02[ooiCo0?oonf[o0?oO00;ooo]Z1?oo
00000ooo:03oo`00ooo:0007ool000;ooo]Z00Koo`00oookJ_oonf[o9P3oob3o0?oo:00;oookJP;o
obP000cooo]Zo`3oFooonf[oobP0o`3o/?ooN@3ooo]Zool00?oonf[o1P3ooi;o0?oo0?D2oookJP03
oa00oooonf[ooo]Z00;ooo]Z00Koo`1AoookJ_oonf[o0:gooookJ_oo07T5oookJP06o`3oDooonf[o
oo]Zo`3o2?oonf[o0?lM2ooonfX00ol0odkoogT0oookJP04oookJP03o`28ooooN@3ooo]Z00;ooo]Z
00?o00CooiCo0?nDo`000onDo`07oookJPKoogT02OoonfX00ooo02gooo]ZoookJP06oookJP03oomG
0?oonf[ooo]Z00Oooo]Z00?oL03oon/0oooonfX00_oonfX00ooob@3ooo]ZoookJP1;oookJP03oomB
0?nio`3ooo]Z017ooo]Z00?o07?ooookJ_oonfX05?oonfX00ooo0>[ooo]ZoookJP07oookJP03oolF
0?oonf[ooi8000Cooo]Z00Goo`3loookJ_oonf[ooo]ZoaP0o`02oookJP05ool60?oonf[ojol0oook
J_oo0?H00_oonfX00ol0Y_oooo]ZojP0o`03oookJP05ool0nOoonf[o07OooookJ_ooK0002OoonfX0
0ol0nooooo]ZoookJP08oookJP04o`2Soooonf[ooo]Zok?o00Kooo]Z00?o0?oNomgo0?oonfX00ooo
nfX2ool0K0Kooo]Z0_mQ0?lEoookJPKo0?nB1OoonfX5o`3oTPoooo]Z0_mQ0?l7oookJP;oo`1/00?o
oo]Zo`3og_l0omh01?oonfX2ok?o00Gooo]Z1?l00003oookJP03oom/0?oonf[ooo]Z00Kooo]Z00Go
o`3foookJ_oonf[oo`H0oaP0o`03oookJP03ool0o?oonf[ooo]Z00Kooo]Z00?oo`3ZoookJ_oonfX0
2OoonfX00ol0Looooo]ZoookJP08oookJP08okWo0?ooDP3ooo]ZoookJ_l0:_oooo]Zo`3Lool0oml6
oookJP03o`3o6olB0?ooolX000?ooo]Z00?oo`2Cool04ooonfX00ooonfX01_oJo`3ohOl0oookJ_oo
nf[o9P3ooh@0o`kooo]Z00_o0?mKoookJ_oonf[oP_l0o`0`oooonf[o0?m=o`3Xool60?oooo]Zoi;o
0002oookJP03ool0J_l@0?oooo]Z00?ooo]Z00Goo`1AoookJ_l0[Ooooo]Zool0N@05oookJP07o`3o
Dooonf[ooo]Zo`3o2?oonf[o0?lMo`3Qo`0:oookJP03o`3o=?l0odkooo]Z00Gooo]Z00?o0:Wooook
J_oonfX00_oonfX00ol01?oooo]Zo`3Do`0;oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oook
J_oonfX01_oonfX00oooE`3ooo]ZoookJP08oookJP03og00ooo[0?oooo]Z00;ooo]Z00?ookh0oook
J_oonfX08ooonfX002_ooo]Z00?ooe80oookJ_nio`004OoonfX00oooN@3ooo]ZoookJP0DoookJP03
ool0j_oonf[ooo]Z00Oooo]Z00?ooaH0oonB0?oonfX01?oonfX01Ooo0?cooo]ZoookJ_oonf[o603o
00;ooo]Z00Goo`H0oookJ_o[o`3ooo]Zool0mP02oookJP03o`2Voooonf[ooo]Z00GoobP000Cooo]Z
o`1gooooK03oof`01?oo:004oookJP03o`3koooonf[ooo]Z00Wooo]Z00?o0:?ooookJ_nco`001ooo
nfX00ol0omkooo]ZoookJP03oookJP;oo`1/1ooonfX2of40oaWooo]Z1Ol0oi8AoookJP?oH@3o1Ooo
nfX01?oo:03oo`1/ool0K?oo06`4oolX00Cooo]Z00?o/ol0oookJ_oonfX01OoonfX4o`0000;ooo]Z
00?oof`0oookJ_oonfX01_oonfX01Ooo0?Kooo]ZoookJ_oo003o603o00?ooo]Z00?oo`3loookJ_oo
nfX00_oonfX9ool000Sooo]Z00?oobP0oookJ_oonfX01_oonfX2oomi0008oomB0?nDo`3ooo]Zo`0Z
oooonf[oU?l0ool00?l0oml2oookJP?oo`0000GoobP0oa80oooobP3oo`00oookJP05ool000;ooo]Z
00Ooo`00on7o0?oonf[o9P3oob3o0?oonf[oobP000_ooo]Z00?oo`00oolX0?l0oe/00_oo:0000ol0
ok3oogT0oookJP02ool00003oookJ_l60?ooT_l000?ooo]Z00Go403ooookJ_oonf[ooo]Zool0D@02
oookJP04o`2]oooonf[ooo]Zool0N@Gooo]Z00Ko0?mCoookJ_oonf[o0?l8o`3o7Ol0hOl7oookJP;o
ogT000Cooo]Zo`3o=?l0odkoogT01OoonfX00oooN@3ooo]ZoookJP02oookJPKoU?l01ooonfX5oomi
00[ooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooE`3ooo]ZoookJP08oookJP03on/0oooonf[ooo]Z
00;ooo]Z00?oolT0oookJ_oonfX0BooonfX00oooDP3ooo]ZokWo000BoookJP03o`1coooonf[ooo]Z
01?ooo]Z00?oo`3ZoookJ_oonfX02?oonfX00ooo5P3ooi80oookJP03oookJP05ool0o?oonf[ooo]Z
oookJ_lH0?l00_oonfX01Ooo1P3ooo]ZoookJ_o[o`3oo`3f00?ooo]Z00?o0:KooookJ_nX0?l00ooo
nfX01?oo0?Wooo]Zo`1goooonfX2oom/00Sooo]Z00?o0?_ooookJ_oonfX02?oonfX01?l0Xooooo]Z
oookJ_nco`06oookJP03o`3og_oMo`3ooo]Z00Cooo]Z00?oo`1/oookJ_oonfX01OoonfX2of40oaWo
oo]Z1Ol0oi8AoookJP?oH@3o1_oonfX3ool0K003oookJ_l0omko0?oN00Gooo]Z00?o/ol0oookJ_oo
nfX01OoonfX4o`0000;ooo]Z00?oof`0oookJ_oonfX01_oonfX01Ooo0?Kooo]ZoookJ_oo1P3o603o
00?ooo]Z00?oo`3loookJ_oonfX01_oonfX00ooo0>[ooo]ZoookJP0:oookJP03o`1coooonf[ooo]Z
00Oooo]Z00Wo^Ol0oomB0?oonf[ooo]Zo`0Zoooonf[o0=coocd0ool0oml01OoonfX01?l0S_oo0?lK
oa80oooobP02oookJP03o`3ioooo09?ooo]Z00Cooo]Z00Kof_l0oookJ_oonf[o9P3ooookJ_n40?l<
oookJP06oc7o0?l0oe_ooo]ZoookJ_n2o`3o033o0_oonfX01Ol0odgooo]Zo`H0oooo0?GoT_l000;o
oo]Z00?o403ooookJ_oonfX00_oonfX01_oo057ooo]ZoookJ_l0[Ooooo]Zool0N@Gooo]Z00Oo0?mC
oookJ_oonf[o0?l8o`3o7Ooonf[o0>7o00Wooo]Z00?o0?ldo`3oC_l0obh01_oonfX01ol0ZOoooo]Z
oookJ_oonf[o00CooookJ_l0e?l03?oonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z
00Kooo]Z00?ooeL0oookJ_oonfX02?oonfX00oo[0?oooo]ZoookJP02oookJP03oonn0?oonf[ooo]Z
02?ooo]Z000[oookJP03oomB0?l0oc?o^Ol0017ooo]Z00?oogT0oookJ_oonfX05OoonfX00ooo0>[o
oo]ZoookJP07oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00?oo`3loookJ_oonfX00_oonfX00olH0?oo
oo]Zool60002oookJP05on_o0?oonf[oo`3foookJ_l0Y_l00_oonfX5oolX0005oookJ_l0MoooobP0
oolX0?ooK0001Ooo:003oookJP03o`3koooonf[ooo]Z00Wooo]Z00?o0:?ooookJ_nco`001ooonfX0
0ol0omkooo]ZoookJP04oookJP03ool0K?oonf[ooo]Z00Kooo]Z00?oH@3ooookJ_oonfX0:_oonfX2
of40o`Kooo]Z0ooo06`7oolX00;ooo]Z0_nco`08oookJPCo00000_ooK007oookJP;oo`3f0_oonfX0
0ooo003o603ooookJP02oookJP03ool0o?oonf[ooo]Z00?ooo]Z1ooo0009oookJP03oolX0?oonf[o
oo]Z00Oooo]Z0_ooN@001oooDP3oU?l0o`0Zoooonf[oU?l0oookJ_l0oml00_oonfX4ool00003oolX
0?oobP3oo`0000;ooo]Z1?oo0002oookJP07ool00?oQo`3ooo]ZoookJ_lV0?oo8?l0oolX000<oook
JP03ool00?oo:03o0?mK00;oobP000So0?n`oomi0?oonf[oo`00oookJ_l60?ooT_l0ool0m@;ooo]Z
00?o403ooookJ_oonfX00_oonfX01?oo057ooo]ZoookJ_l0[Ol2oookJP03ool0NOoonf[ooo]Z00;o
oo]Z00Oo0?mCoookJ_oonf[ooo]Zo`3o2?l0oago0>7o00Oooo]Z0oooN@000ooob@3o0?m>oookJP04
oookJP03o`28ooooN@3ooo]Z00;ooo]Z00?o00CooiCo0?nDo`000onDo`08oookJPCoogT02_oonfX0
0ooo02gooo]ZoookJP06oookJP03oomG0?oonf[ooo]Z00Sooo]Z00Goj`3ooookJ_oonf[ooo]Zooo9
001>oookJP03oomB0?l0oc?o^Ol001;ooo]Z00?o07?ooookJ_oonfX05?oonfX00ooo0>[ooo]Zoook
JP08oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00Goo`3loookJ_oonf[ooo]ZoaP0o`02oookJP05ool6
0?oonf[ooo]Zon_o0?oo0?H00_oonfX00ol0Y_oooo]ZojP0o`04oookJP06ool0nOoonf[o07Oooook
J_l0oi[oof`02?oonfX00ol0nooooo]ZoookJP08oookJP04o`2Soooonf[ooo]Zok?o00Kooo]Z00?o
0?oNomgo0?oonfX01?oonfX2ool0K0Oooo]Z00?oH@3ooookJ_oonfX0:_oonfX2of40o`Oooo]Z0_oo
06`01?oonf[o0?oNo`3og_l0omh5oookJP;o/ol02?oonfX4o`000003oookJ_ooK03ooo]Z00Oooo]Z
00Goo`3foookJ_oonf[oo`H0oaP0o`03oookJP03ool0o?oonf[ooo]Z00Kooo]Z00?oo`3ZoookJ_oo
nfX02_oonfX00ol0Looooo]ZoookJP07oookJP05okWo0?oonf[ooe80oookJ_l0:_l00_oonfX00ol0
g?oo0?oOoookJP05oookJP03o`3o6olB0?ooolX000?ooo]Z00?oo`2Cool04ooonfX00ooonfX01_oJ
o`3ooo]ZoookJ_oonf[o9P3ooh@0o`gooo]Z00co<Ol0o`3oFooonf[ooo]Zoh;o0?l0<?oooo]Zo`3o
COl0j?oo1P3ooookJ_nBo`02oookJP03ool0J_l@0?oooo]Z00?ooo]Z00?oo`1AoookJ_l0[Ol00_oo
nfX00ooo07Wooo]ZoookJP02oookJP08o`3oDooonf[ooo]ZoookJ_l0o`So0?lMoookJ_l0hOl9oook
JP03o`3o=?l0odkooo]Z00Gooo]Z00?o0:WooookJ_oonfX00_oonfX00ol01?oooo]Zo`3Do`0<oook
JP03oon10?oonf[ooo]Z00Wooo]Z00?oo`0]oookJ_oonfX01_oonfX00oooE`3ooo]ZoookJP09oook
JP05on/0oooonf[ooo]ZoookJ_oo_P009_oonfX002cooo]Z00?ooe80okWo0?oonfX04OoonfX00ooo
N@3ooo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z00Oooo]Z00?ooaH0oonB0?oonfX01?oonfX01Ooo
0?cooo]ZoookJ_oonf[o603o00;ooo]Z00Ooo`H0oookJ_oonf[ojol0oookJ_oo0?Kooo]Z00GoobP0
0_oonfX00ooo:03ooo]Zo`1go`02oolX0003oom/0?oo:03oobP000?oobP00ooonfX00ol0nooooo]Z
oookJP09oookJP03o`2Soooonf[o/ol000Oooo]Z0_l0omh5oookJP;oo`1/1ooonfX3of40obKooo]Z
0omQ0?l6oookJP;oo`1/2_oo:002ok?o00[ooo]Z0ol000000oooK03ooo]ZoookJP06oookJP06ool0
m_oonf[ooo]ZoookJ_oo003o603o0ooonfX00ooo0?cooo]ZoookJP03oookJPOoo`002OoonfX00ooo
:03ooo]ZoookJP07oookJP05ool00?ooN@3ooe80oiCo0?l0:_l00onDo`001?l0omoooo]ZoolX0?oo
:003ool00003oolX0?oo003oolX000?ooo]Z0ooo0003oookJP06ool00?oQo`3ooo]ZobH0oolPo`3o
obP03?oonfX00ooo003oobP0o`3oF`05oolX0006ool00?oonf[ooo]Zo`H0oonBo`3oo`000_oonfX0
0ol@0?oooo]ZoookJP02oookJP03ool0DOoonf[o0:go00;ooo]Z00?oo`1ioookJ_oonfX00ooonfX0
1_l0oe?ooo]ZoookJ_l0o`So0?lMo`3Qo`Sooo]Z0oooN@001?l0odkoogT0oomi0?ooN@03oookJP03
o`28ooooN@3ooo]Z00;ooo]Z00?o00CooiCo0?nDo`000_nDo`09oookJPCoogT02_oonfX00ooo02go
oo]ZoookJP06oookJP03oomG0?oonf[ooo]Z00Oooo]Z00?oL03oon/0oooonfX00_oonfX00ooob@3o
oo]ZoookJP1=oookJP03oomB0?oonf[o^Ol0017ooo]Z00?o07?ooookJ_oonfX05?oonfX00ooo0>[o
oo]ZoookJP08oookJP03oolF0?ooTP3ooo]Z00?ooo]Z00Goo`3loookJ_oonf[ooo]ZoaP0o`03oook
JP05ool60?oonf[ooo]Zon_o0?oo0?H00_oonfX00ol0Y_oooo]ZojP0o`03oookJP03ool0nOoonf[o
07Oo00;ooo]Z00?o0?nJoom/0?oonfX01ooonfX00ol0nooooo]ZoookJP08oookJP04o`2Soooonf[o
oo]Zok?o00Kooo]Z0_l0omh6oookJP;oo`1/1_oonfX4of40obGooo]Z0omQ0?l6oookJP?oo`1/00?o
oo]Zo`3og_l0omh01_oonfX2ok?o00[ooo]Z0ol00002oom/00Sooo]Z00Goo`3foookJ_oonf[oo`H0
oaP0o`03oookJP03ool0o?oonf[ooo]Z00Kooo]Z00?oo`3ZoookJ_oonfX02_oonfX00ol0Looooo]Z
oookJP07oookJP05okWo0?oonf[ooe80oookJ_l0:_l00_oonfX00ol0g?oo0?oOoookJP05oookJP04
o`3o6olB0?oooo]Zooo:00;ooo]Z00?o0?Woool0TooonfX00ooonfX01_oJo`3ohOl0oookJ_oonf[o
9P3ooh@0o`gooo]Z00Ko<Ol0o`3oFooonf[ooo]Zoh;o0?l0<?l2oookJP05o`3oCOoonf[o1P3oool0
mOnBo`000_oonfX00ol@0?oooo]ZoookJP03oookJP05ool0DOoonf[o0:gooookJ_oo07T01OoonfX0
1ol0oe?ooo]ZoookJ_l0o`So0?lMoookJ_l0hOl02_oonfX00ol0ocCo0?m>oookJP05oookJP05o`2Y
oooonf[ooo]ZoookJ_l01?l00_oonfX00ol0e?oooo]ZoookJP09oookJP03oon10?oonf[ooo]Z00[o
oo]Z00?oo`0]oookJ_oonfX01_oonfX00oooE`3ooo]ZoookJP08oookJP03og00ooo[0?oooo]Z00;o
oo]Z00?ookh0oookJ_oonfX09?oonfX002cooo]Z00?ooe80oookJ_nio`004OoonfX00oooN@3ooo]Z
oookJP0DoookJP03ool0j_oonf[ooo]Z00Sooo]Z00?ooaH0oonB0?oonfX00ooonfX00ooo0?cooo]Z
oookJP02oookJP04oaP0oooonf[ooo]Zool600;ooo]Z00?ojol0oookJ_oo0?H01?oo:0001onX0?oo
oo]ZoookJ_oonf[oobP0oookJ_l0Mol00_oo:0000oooK03oobP0oolX0003oolX00?ooo]Z00?o0?_o
oookJ_oonfX02OoonfX2o`2So`03ok?o0?oonf[ooo]Z00Gooo]Z00Goo`00o`3og_l0omko0?oNool0
0003oookJP;oo`1/2?oonfX5of40oagooo]Z1?mQ0?l6oookJP?oo`1/2Ooo:003ok?o0003oolX0?oo
nf[ooo]Z00Wooo]Z0_l000000oooK03o0000oookJP04oookJP03ool00?oonf[oo`3f00;ooo]Z0_oo
00001OlH0?oooo]ZoookJ_oonf[oo`3l00Kooo]Z1_oo0009oookJP03oolX0?oonf[ooo]Z00Oooo]Z
00Goo`00oomi0?ooDP3oU?l0o`0Zo`03oiCo0003ool00?l0omoooo]Z00?oobP000Coo`00oolX0?oo
003oolX00ooonfX3ool000?ooo]Z00Ooo`00on7o0?oonf[ooo]ZobH0oolPo`3oobP000_ooo]Z00Co
o`00oolX0?l0oe_oobP00_oo0003oolX0005ool00?oonf[o1P3ooi;o0?oo0?D00_oo00000ol@0?oo
o`00oookJP02oookJP04ool0DOoonf[ooo]Zo`2]o`;ooo]Z00?oo`1ioookJ_oonfX00_oonfX01ol0
oe?ooo]ZoookJ_oonf[o0?l8o`3o7Ol0hOl02?oonfX2oomi0003ooo90?l0odkoogT000?oogT000?o
oo]Zo`28ooooN@001?oonfX00ol01?ooU?l0oiCo0002oiCo00Wooo]Z0oooN@0;oookJP03ool0;Ooo
nf[ooo]Z00Kooo]Z00?ooeL0oookJ_oonfX01ooonfX01Oo[0?oooo]ZoookJ_oonf[oolT0053ooo]Z
00?ooe80oookJ_nio`004_oonfX00ol0Looooo]ZoookJP0CoookJP03ool0j_oonf[ooo]Z00Wooo]Z
00?ooaH0oonB0?oonfX00ooonfX01Ooo0?cooo]ZoookJ_oonf[o603o00?ooo]Z00Goo`H0oookJ_oo
nf[ojol0ool0mP02oookJP03o`2Voooonf[oZ03o00?ooo]Z00?oo`3ioookJ_l0Mol00_oonfX00ol0
oi[oof`0oookJP07oookJP03o`3koooonf[ooo]Z00Sooo]Z0_l0Xol00ooonf[o/ol0oookJP06oook
JP?o0?oN1OoonfX00ooo06cooo]ZoookJP07oookJPGoH@3o7?oonfX4of40o`Oooo]Z0_oo06`2oook
JP;o0?oN1_oonfX2ok?o0003o`2Soooonf[ooo]Z00Wooo]Z0_l000000oooK03o0000oookJP07oook
JP05ool0m_oonf[oo`H0ool60?lH0?l00ooonfX00ooo0?cooo]ZoookJP06oookJP03ool0j_oonf[o
oo]Z00[ooo]Z00?o07?ooookJ_oonfX01ooonfX01Onio`3ooo]ZoomB0?oonf[o02[o00;ooo]Z00?o
0=coocd0ool0oml01OoonfX01?l0S_oo0?lKoookJ_oobP02oookJP03o`3ioooo09?ooo]Z00Cooo]Z
00Kof_l0oookJ_oonf[ooo]ZobH0oon40?l<oookJP03oc7o0?l0oe_ooo]Z00;ooo]Z00SoP_l0o`0`
oooonf[o0?m=o`3Xool60?oooo]Zoi;o00;ooo]Z00?o403oo`1MoooonfX00ooonfX00ooo057ooo]Z
o`2]o`02oookJP03ool0NOoonf[ooo]Z00;ooo]Z00So0?mCoookJ_oonf[ooo]Zo`3o2?l0oagooo]Z
o`3Qo`Wooo]Z00?o0?ldo`3oC_l0obh01OoonfX00ol0R?oo0:WooookJP02oookJP03o`04oooonf[o
0=Co00cooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP06oookJP03oomG0?oonf[o
oo]Z00Sooo]Z00Goj`3ooookJ_oonf[ooo]Zoonn000WoookJP00;?oonfX00oooDP3o0?lcokWo000A
oookJP03oomi0?oonf[ooo]Z01Gooo]Z00?oo`3ZoookJ_oonfX01ooonfX00ooo5P3ooi80oookJP04
oookJP05ool0o?oonf[ooo]ZoookJ_lH0?l00ooonfX01_oo1P3ooo]ZoookJ_o[o`3ooo]Zool0mP?o
obP000SoZ03ooookJ_oonf[ooo]ZoolX0?oonf[oobP0o`1go`;oobP000Coof`0oolX0?oo:03oobP0
1OoonfX00ol0nooooo]ZoookJP0:oookJP03o`2Soonco`3o/ol000Oooo]Z0_oo0002o`3ogPCoo`00
00?oo`1/ool00?oo00002_oonfX5of40oa7ooo]Z0_oo:005of40o`Sooo]Z0_oo06`2oookJPSoobP0
0_nco`02oolX00gooo]Z0_ooK002o`0000Gooo]Z00Ooo`00ool0m_oonf[ooo]Zool00?oonf[o603o
00;ooo]Z0_oo0?`6oookJPGoo`002_oonfX00ooo:03ooo]ZoookJP08oookJP05ool00?ooDP3ooo]Z
oiCo0?l0:_l00_nDo`000ooo003o0?oOoiCo0006oolX0003ool00?oobP3ooo]Z00;ooo]Z0_oo0004
oookJP06ool00?oQo`3ooo]ZobH0oolPo`3oobP03?oonfX01?oo003oobP0o`3oFooo:005ool00004
oolX0?oonf[o1P3ooi;o00?oo`0000So403oool00?oo003oo`00oookJ_oo057ooo]Zo`2]o`;ooo]Z
00?oo`1ioookJ_oonfX00ooonfX01ol0oe?ooo]ZoookJ_l0o`So0?lMoookJ_l0hOl02?oonfX2oomi
0003ooo90?l0odkoogT000?oogT000?ooo]Zo`28ooooN@000ooonfX00ol01?oooo]ZoiCo0002oiCo
00[ooo]Z0oooN@0:oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0oookJ_oonfX01ooonfX00om`
0?ooj`3ooookJP02oookJP03ooo90?oonf[ooo]Z04kooo]Z00?ooe80o`3o<onio`004_oonfX00ol0
Looooo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z00Sooo]Z00?ooaH0oonB0?oonfX01?oonfX01?oo
0?cooo]ZoookJ_lH0?l3oookJP06ool60?oonf[ooo]Zon_o0?oonf[oo`3f0_oonfX00ol0Y_ooZ03o
oookJP03oookJP03ool0nOoonf[o07Oo00;ooo]Z00?o0?nJoom/0?oonfX01ooonfX00ol0nooooo]Z
oookJP09oookJP;o0:?o0_nco`07oookJP03omgo0?l0omko0?oN00Cooo]Z0_oo06`<oookJPGoH@3o
4?oonfX7of40o`Sooo]Z0ooo06`2oookJP;o0?oN1_oonfX2ok?o0003o`2Soooonf[ooo]Z00_ooo]Z
00Co0000oom/0?l0003o00001ooonfX01Ooo0?Kooo]Zool60?oonf[o603o00;ooo]Z0_oo0?`9oook
JP03ool0j_oonf[ooo]Z00Wooo]Z00?o07?ooookJ_oonfX02?oonfX01Onio`3ooe80o`3o<ooonf[o
02[o00;ooo]Z00?o0=coo`3ogooonfX01OoonfX00ol0oa_o4P3oooo:0003oookJP03o`3ioooo09?o
oo]Z00?ooo]Z00Kof_l0on7o0?oonf[ooo]ZobH0oon40?l=oookJP06oc7o0?l0oe_ooo]ZoookJ_n2
o`3o0?n`0_oonfX01Ol0odgooo]Zo`H0oooo0?GoT_l000;ooo]Z00?o403ooookJ_oonfX00ooonfX0
1Ooo057ooo]Zo`2]oooonf[oo`1i00Gooo]Z00Go0?mCoookJ_oonf[o0?l8o`3o7@02oookJP03o`3Q
oooonf[ooo]Z00Oooo]Z00?o0?ldo`3oC_oonfX01OoonfX01Ol0ZOoooo]ZoookJ_oonf[o00Co00;o
oo]Z00?o0=CooookJ_oonfX02_oonfX00oooP@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z00Ko
oo]Z00?ooeL0oookJ_oonfX02?oonfX00om`0?ooj`3ooookJP02oookJP03oonn0?oonf[ooo]Z02Go
oo]Z000]oookJP03oomB0?oonf[o^Ol0017ooo]Z00?oogT0oookJ_oonfX05OoonfX00ooo0>[ooo]Z
oookJP07oookJP03oolF0?ooTP3ooo]Z00Cooo]Z00Goo`3loookJ_oonf[ooo]ZoaP0o`03oookJP06
ool60?oonf[ooo]Zon_o0?oo0?Kooo]Z0ooo:0001onX0?ooobP0oookJ_oonf[oobP0oookJ_l0Mol0
0ooo:0000oooK03oobP0oookJP06oookJP03o`3koooonf[ooo]Z00_ooo]Z00?o0:?ook?o0?nco`00
1_oonfX3ool000?o0?oN0_oo0004ool0K0;oo`002ooonfX5of40o`Gooo]Z1?mQ0?l5oolX00[ooo]Z
0ooo06`3oookJPOoobP00_nco`02oolX00kooo]Z00?oof`0o`000?l000000_l00004oookJP?oo`00
00Cooo]Zool00?oonf[o603o0_oonfX00ooo0?cooo]ZoookJP06oookJPCoo`002ooonfX00ooo:03o
oo]ZoookJP07oookJP05ool00?ooDP3ooo]ZoiCo0?l0:_l00onDo`000ooo003o0?oOoiCo0007oolX
00?ooo]Z00?oobP0ool00?oonfX00ooonfX01_oo003ohOl0oookJ_oonf[o9P3oob3o00cooo]Z00?o
o`00oookJ_l0oe/00_oo:007ool00005oookJ_nBo`3oo`00ool00?l@0?l01?oo00001?oo057ooo]Z
oookJ_l0[Ol2oookJP03ool0NOoonf[ooo]Z00;ooo]Z00Oo0?mCoookJ_oonf[ooo]Zo`3o2?l0oago
0>7o00Wooo]Z00?oogT0ooo90?l0odh01?ooN@000ooonf[o08Sooomi0004oookJP03o`04oooonf[o
U?l000;oU?l02_oonfX2oomi00_ooo]Z00?oo`0]oookJ_oonfX01_oonfX00oooE`3ooo]ZoookJP07
oookJP03on/0ool0o`Gooo]Z00;ooo]Z00?oolT0oookJ_oonfX0CooonfX00oooDP3ooo]ZokWo000A
oookJP03o`1coooonf[ooo]Z01Gooo]Z00?oo`3ZoookJ_oonfX02?oonfX00ooo5P3ooi80oookJP03
oookJP05ool0o?oonf[ooo]ZoookJ_lH0?l00ooonfX01Ooo1P3ooo]ZoookJ_o[o`3oo`3f00?ooo]Z
00?o0:KoojP0oooonfX00_oonfX01?oo0?Wooo]ZoookJ_l0Mol2oookJP03o`3oV_ooK03ooo]Z00Oo
oo]Z00?o0?_ooookJ_oonfX02_oonfX2o`2So`;o/ol02?oonfX3o`3ogP?ooo]Z1?oo06`=oookJPGo
H@3o1?oonfX7of40o`gooo]Z0_oo06`3oookJP;o0?oN1_oonfX2ok?o0003o`2Soooonf[ooo]Z00go
oo]Z00Coof`0o`000?l0003o00001_oonfX01Ooo0?Kooo]Zool60?oonf[o603o00;ooo]Z00?oo`3l
oookJ_oonfX02?oonfX00ooo0>[ooo]ZoookJP0:oookJP03o`1coooonf[ooo]Z00Oooo]Z00Go^Ol0
oomB0?l0oc?ooo]Zo`0Zo`02oookJP03o`3Loolm0?oo0?oO00Gooo]Z00Co08koo`3o6ooonf[oolX0
0_oonfX00ol0nOooo`2CoookJP04oookJP05om[o0?oonf[ooo]ZobH0oolPo`003OoonfX00olao`3o
0?mKoookJP02oookJP0<oh;o0?l0<?oooo]Zo`3oCOl0j?oo1P3ooookJ_oo0?GoT_l0oookJ_l@0?oo
05go1?oonfX00ooo057ooo]Zo`2]o`02oookJP03ool0NOoonf[ooo]Z00;ooo]Z00So0?mCoookJ_oo
nf[ooo]Zo`3o2?l0oagooo]Zo`3Qo`Wooo]Z00?o0?ldo`3oC_l0obh01OoonfX00ol0R?oo0:Wooook
JP02oookJP04o`04oooonf[ooo]Zo`3Do`_ooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]Z
oookJP06oookJP03oomG0?oonf[ooo]Z00Sooo]Z00?oj`3ooookJ_oonfX00_oonfX00ooo_P3ooo]Z
oookJP0UoookJP00;OoonfX00oooDP3ooo]ZokWo000AoookJP03oomi0?oonf[ooo]Z01Gooo]Z00?o
o`3ZoookJ_oonfX01ooonfX00ooo5P3ooi80oookJP04oookJP03ool0o?oonf[ooo]Z00;ooo]Z00Co
603ooookJ_oonf[oo`H00_oonfX00oo[o`3ooo]Zool0mP03oolX0008ojP0oooo:03oobP0oolX0?oo
nf[oobP0oookJ_l0Mol3oolX0003oom/0?oonf[ooo]Z00Kooo]Z00?o0?_ooookJ_oonfX03?oonfX0
0ol0Xooo/ol0ok?o0006oookJPCoo`000_l0omh4ool000Goo`1/3OoonfX5of40o`03oookJ_oo:03o
obP000KoobP01ooonfX3ool0K0?ooo]Z0_l0omh6oolX00;o/ol000?oobP0oookJ_oonfX03_oonfX0
0oooK03ooo]Zo`000003o`0000?ooo]Z1Ooo00001Ooonf[o603ooookJ_oonf[oo`3l00Sooo]Z1?oo
000;oookJP03oolX0?oonf[ooo]Z00Oooo]Z00Goo`00oomB0?oonf[ooo]Zo`0Zo`03oiCo0004ool0
0?l0omooU?l0oookJPSoobP000Cooo]ZoolX0?oonf[oo`2C0ooonfX01ooo003ooo]Zon7o0?oonf[o
9P3oob3o0?oo:0003?oonfX01?oo003ooo]Zo`3oFooo:00<ool00003oa00oooo003oo`0000;oo`00
00?oo`1AoookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP03oookJP07o`3oDooonf[ooo]Zo`3o2?l0
oagooo]Zo`3Qo`09oookJP03oomi0?oob@3o0?m>00?oogT00_oonfX00ol0R?ooogT0oookJP02oook
JP03o`04oooonf[ooo]Z00;oU?l02ooonfX00oooN@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z
00Oooo]Z00?ooeL0oookJ_oonfX01ooonfX01Oo[0?oooo]ZoookJ_oonf[oolT005;ooo]Z00?ooe80
oookJ_nio`004_oonfX00ol0Looooo]ZoookJP0DoookJP03ool0j_oonf[ooo]Z00Sooo]Z00?ooaH0
oonB0?oonfX01?oonfX01Ooo0?cooo]ZoookJ_oonf[o603o00?ooo]Z00Goo`H0oookJ_oonf[ojol0
ool0mP03oookJP03ojP0oooonf[ooo]Z00;ooo]Z00?oo`3ioookJ_l0Mol00ooonfX00ol0oi[oof`0
oookJP07oookJP03o`3koooonf[ooo]Z00_ooo]Z0_l0Xol2ok?o00Wooo]Z0_l0omh00ooMo`3ooo]Z
oookJP02oookJPGoo`1/3OoonfX4of40oa7ooo]Z0ooo06`2oookJP?o0?oN1OoonfX3ok?o0003o`2S
oooonf[ooo]Z00kooo]Z00?oof`0o`000?l000000_l00005oookJP05ool0m_oonf[oo`H0oookJ_lH
0?l00_oonfX00ooo0?cooo]ZoookJP08oookJP03ool0j_oonf[ooo]Z00[ooo]Z00?o07?ooookJ_oo
nfX01ooonfX01Onio`3ooe80o`3o<ooonf[o02[o00;ooo]Z00?o0=coocd0ool0oml01_oonfX00ol0
oa_ooo]Zooo:0002oookJP03o`3ioooonf[oo`2C00Cooo]Z00Kof_l0on7o0?oonf[ooo]ZobH0oon4
0?l=oookJP03oc7o0?l0oe_ooo]Z00;ooo]Z00SoP_l0oookJ_oonf[o0?m=oookJ_l60?ooo`3eoi;o
00;ooo]Z00?o403ooookJ_oonfX00ooonfX01Ooo057ooo]Zo`2]oooonf[oo`1i00Gooo]Z00Go0?mC
oookJ_oonf[o0?l8o`3o7@02oookJP03o`3Qoooonf[ooo]Z00Oooo]Z00?o0?ldo`3oC_l0obh01Ooo
nfX01Ol0ZOoooo]ZoookJ_oonf[o00Co00;ooo]Z00?o0=CooookJ_oonfX02_oonfX00oooP@3ooo]Z
oookJP09oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX02?oonfX01Oo[0?oooo]Z
oookJ_oonf[ookh002Sooo]Z000]oookJP03oomB0?l0oc?o^Ol0017ooo]Z00?oogT0oookJ_oonfX0
5_oonfX00ooo0>[ooo]ZoookJP07oookJP03oolF0?ooTP3ooo]Z00Cooo]Z00?oo`3loookJ_oonfX0
0_oonfX01?lH0?oooo]ZoookJ_oo1P02oookJP03on_o0?oonf[oo`3f00?oobP000?oZ03ooolX0?oo
:0001?oo:0001Ol0MoooobP0oookJ_oonf[oof`000Sooo]Z00?o0?_ooookJ_oonfX03?oonfX2o`2S
o`;o/ol01OoonfX5ool000?o0?oN0_oo0004oookJPGoo`1/2ooonfX;oolX0003oookJ_oo:03oobP0
00CoobP000?ooo]Zo`3og_l0omh00ol0omh2oookJPCoobP00_nco`02oolX013ooo]Z00?oof`0oook
J_oonfX01?l00003oookJPKoo`000_oonfX00ooo0?cooo]ZoookJP07oookJP;oo`001ooonfX00ooo
:03ooo]ZoookJP02oookJP03oolX0?oonf[ooo]Z00Oooo]Z00Goo`00o`3o<oooDP3ooo]Zo`0Zo`03
oiCo0004ool00?l0omooU?l0oookJPSoobP00_oonfX00ooo:03oo`2CoookJP03oookJP06ool00?oQ
o`3ooo]ZoookJ_lV0?oo8?l03?oonfX00ooo003ooo]Zo`3oF`02oolX00_oo`0000?o403oool00?oo
00000_oo00001_oo057ooo]ZoookJ_l0[Ooooo]Zool0N@Gooo]Z00So0?mCoookJ_oonf[ooo]Zo`3o
2?l0oagooo]Zo`3Qo`Wooo]Z00?oolT0o`3oC_ooN@000oooN@02oookJP03o`28ooooN@3ooo]Z00;o
oo]Z00Co00CooookJ_oonf[oU?l03?oonfX00oooP@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z
00Kooo]Z00?ooeL0oookJ_oonfX01ooonfX00oo[0?oo0?l5oookJP02oookJP03ooo90?oonf[ooo]Z
053ooo]Z00Cooe80o`3o<ooonf[o^Ol04OoonfX00ol0Looooo]ZoookJP0EoookJP03ool0j_oonf[o
oo]Z00Sooo]Z00?ooaH0oonB0?oonfX00ooonfX00ooo0?cooo]ZoookJP02oookJP04oaP0oooonf[o
oo]Zool600?ooo]Z00?ojol0ool0m_oonfX00_oonfX00onX0?oooo]ZoookJP02oookJP03ool0nOoo
nf[o07Oo00?ooo]Z00?o0?nJoom/0?oonfX01ooonfX00ol0nooooo]ZoookJP0<oookJP;o0:?o0_nc
o`09oookJP?o0?oN00?ogOl0oookJ_oonfX01?oonfX5ool0K1Oooo]Z1_oo06`00ooonf[o0?oNo`3o
gP02o`3ogPKooo]Z0_nco`02o`2Soa3ooo]Z0_ooK0000ooonf[o0000o`000002o`0000Cooo]Z00Go
o`3foookJ_oo1P3ooo]ZoaP0o`02oookJP03ool0o?oonf[ooo]Z00Sooo]Z00?oo`3ZoookJ_oonfX0
2_oonfX00ol0Looooo]ZoookJP07oookJP05okWo0?oonf[ooe80oookJ_l0:_l00ooonfX00olm0?oo
0?oOoookJP05oookJP04o`3o6ooonf[ooo]Zooo:00;ooo]Z00?o0?Woool0TooonfX00ooonfX01_oJ
o`3ohOl0oookJ_oonf[o9P3oob3o00gooo]Z00?o<Ol0o`3oFooonfX00_oonfX03?n2o`3o033ooook
J_l0odgooo]Zo`H0oooonf[oo`3eoi;o0?oonf[o403oool0JPCooo]Z00Goo`1AoookJ_l0[Ooooo]Z
ool0N@05oookJP06o`3oDooonf[ooo]ZoookJ_l0o`So0?lM0_oonfX00ol0hOoooo]ZoookJP06oook
JP03o`3o=?oonf[o0?m>00Gooo]Z00?o08Soo`2YoooonfX00_oonfX01?l01?oooo]ZoookJ_l0e?l<
oookJP03oon10?oonf[ooo]Z00Wooo]Z00?oo`0]oookJ_oonfX01ooonfX00oooE`3ooo]ZoookJP07
oookJP03on/0ool0o`Gooo]Z00;ooo]Z00?ookh0oookJ_oonfX09_oonfX002kooo]Z00?ooe80oook
J_nio`004OoonfX00oooN@3ooo]ZoookJP0FoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oonB
0?oonfX01?oonfX00ooo0?cooo]ZoookJP03oookJP04oaP0oooonf[ooo]Zool600;ooo]Z00?ojol0
oookJ_oo:0000ooo:002ool000?oobP000?ooo]ZoolX0?l0Mol00ooonfX00oooK03ooo]ZoookJP06
oookJP?oobP03OoonfX2o`2So`;o/ol01OoonfX6ool000;o0?oN00?oo`00oookJ_oonfX01_oonfX5
ool0K0?ooo]Z3ooo:003oookJPCo0?oN1OoonfX3oolX00?o/ol01?oo:00>oookJP;oof`00ooonfX4
o`0000;ooo]Z1ooo0002ool0o0[ooo]Z00?oo`00oookJ_oonfX01_oonfX2oolX00;ooo]Z00?oobP0
oookJ_oonfX02?oonfX01?l0oc?ooe80oookJ_l0:_l3oiCo0003ool00?nDo`3o0?oO00;ooo]Z1ooo
:002oookJP03oolX0?oo09?ooo]Z00?ooo]Z00Koo`00oookJ_oQo`3ooo]ZobH0oolPo`0<oookJP03
ool00?oonf[o0?mK00?oobP02?oo00001?oonf[oo`00ool00?l@0?l4ool00003ool0DOoo003o0:go
00;ooo]Z00?oo`1ioookJ_oonfX00ooonfX01ol0oe?ooo]ZoookJ_oonf[o0?lMoookJ_l0hOl02Ooo
nfX00oooN@3oolT0o`3oCP03oomi00;ooo]Z00?o08Sooomi0?oonfX00_oonfX01Ol01?oooo]Zoook
J_oonf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP07oookJP03oomG
0?oonf[ooo]Z00Oooo]Z00Goj`3oo`3o1Ooonf[ooo]Zooo9001DoookJP03oomB0?oonf[o^Ol0017o
oo]Z00?o07?ooookJ_oonfX05_oonfX00ooo0>[ooo]ZoookJP07oookJP03oolF0?ooTP3ooo]Z00Co
oo]Z00?oo`3loookJ_oonfX00_oonfX01?lH0?oooo]ZoookJ_oo1P03oookJP03on_o0?oo0?Kooo]Z
00;ooo]Z0_nX0?l3oookJP03ool0nOoonf[o07Oo00?ooo]Z00?o0?nJoom/0?oonfX01ooonfX2o`3k
o`kooo]Z0_l0Xol2ok?o00[ooo]Z0_l0omh2omgo00Sooo]Z1Ooo06`7oookJP_oo`1/0_oonfX5o`3o
gPSooo]Z0_nco`02o`2Soa7ooo]Z00Coof`0oookJ_oonf[ooo]Z1?l00003oookJP05ool0m_oonf[o
o`H0oookJ_lH0?l00_oonfX00ooo0?cooo]ZoookJP08oookJP03ool0j_oonf[ooo]Z00[ooo]Z00?o
07?ooookJ_oonfX02?oonfX01?nio`3ooe80oookJ_l0:_l3oookJP03o`3Loolm0?oo0?oO00Gooo]Z
00Co08koo`3o6ooonf[oolX00_oonfX00ol0nOooo`2CoookJP04oookJP05om[o0?oQo`3ooo]Zoook
J_lV0?l03OoonfX00olao`3o0?mKoookJP03oookJP08oh;o0?oonf[ooo]Zo`3oCOoonf[o1P3oool0
mOnBo`02oookJP03oa00oooonf[o01Wo00?ooo]Z00Goo`1AoookJ_l0[Ooooo]Zool0N@05oookJP05
o`3oDooonf[ooo]ZoookJ_l0oad00_oonfX00ol0hOoooo]ZoookJP07oookJP03o`3o=?l0odko0?l^
00Gooo]Z00Go08Soo`2Yoooonf[ooo]Zo`04o`03oookJP03o`3Doooonf[ooo]Z00Wooo]Z00?ooh40
oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z00Sooo]Z00Goj`3o
oookJ_oonf[ooo]Zoonn000YoookJP00:_oonfX01ol0:_oooo]ZoookJ_oonf[ooe80oookJ_nio`00
4OoonfX00oooN@3ooo]ZoookJP0FoookJP03ool0j_oonf[ooo]Z00Oooo]Z00?ooaH0oonB0?oonfX0
1?oonfX00ooo0?cooo]ZoookJP03oookJP04oaP0oooonf[ooo]Zool600;ooo]Z00?ojol0ool0m_oo
:0000_oo:005ool000;oobP000?ooo]Zool00?oo00000_oonfX2oom/00Sooo]Z1Ooo:00;oookJP;o
0:?o0onco`03oookJPKoo`0000Gooo]Zo`3og_l0omko0?oNool0000:oookJP;oo`1/4?oo:0000ol0
omkoolT0ooo90008oookJP;oobP00_nco`07oolX00gooo]Z00?oof`0oookJ_oonfX00ooonfX5o`00
00Ooo`0000?oo`3lool00?oo00002?oonfX00ooo0>[oo`00oookJP07oookJPGoobP02_oonfX01Ooo
003ooe80oookJ_oonf[o02[o00?oU?l000?oo`00o`3ogooonfX00_oonfX6oolX00;ooo]Z00?oobP0
ool0Tooo01<01?oonfX01_oo003ohOl0oookJ_lV0?oooo]Zob3o00cooo]Z00?oo`00oookJ_l0oe/0
0ooo:007ool00004oi;o0?oonf[oo`00oa00o`Coo`0000Koo`1AoookJ_oo003o0:gooookJ_oo07T5
oookJP08o`3oDooonf[ooo]ZoookJ_l0o`So0?lMoookJ_l0hOl9oookJP03ooo90?ooN@3o0?m>00;o
ogT00ooonfX00ol0R?ooogT0oookJP02oookJP04o`04oooonf[ooo]Zo`3Do`cooo]Z00?ooh40oook
J_oonfX02OoonfX00ooo02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z00Kooo]Z00?oL03oon/0
oooonfX00_oonfX00ooob@3ooo]ZoookJP1>oookJP05o`0Zoooonf[ooo]ZoookJ_ooDP000_oonfX0
0onio`3ooo]ZoookJP0?oookJP03o`1coooonf[ooo]Z01Gooo]Z00?oo`3ZoookJ_oonfX02?oonfX0
0ooo5P3ooi80oookJP03oookJP03ool0o?oonf[ooo]Z00?ooo]Z00Co603ooookJ_oonf[oo`H00ooo
nfX00oo[o`3ooo]ZoookJP02oookJP05o`2VoonX0?oooo]ZoookJ_oo0?T00_oonfX2o`1go`;ooo]Z
00?o0?nJoom/0?ooK0002?oonfX2o`3ko`kooo]Z00Co0:?ooookJ_nco`3o/ol02_oonfX3o`3ogP;o
gOl02_oonfX7ool0K0Wooo]Z1?l0omh;oookJP;o/ol000?o0:?ooookJ_oonfX04OoonfX00oooK03o
oo]ZoookJP02oookJPGo000000Oooo]Zool0m_oonf[oo`H0oookJ_lH0?oooo]Z00;oo`3l2OoonfX2
ool0jPcooo]Z00?o07?ooookJ_oonfX02?oonfX01Onio`3ooe80oookJ_oonf[o02[o00;ooo]Z00?o
0=coocd0ool0oml01_oonfX02?l0oa_ooo]ZoookJ_oobP3ooo]Zo`3ioooo09?oo`0C1?oonfX01_oJ
o`3ohOl0oookJ_oonf[o9P3oob3o00gooo]Z00?o<Ol0o`3oFooonfX00_oonfX03_n2o`3ooo]Zoook
J_l0odgooo]Zo`H0oooonf[oo`3eoi;o0?oonf[o403oool0J_oonf[o01Wo0_oonfX01Ooo057o5@3o
o`2]oooonf[oo`1i00Gooo]Z00Ko0?mCoookJ_oonf[ooo]Zo`3o2?l0oad2oookJP03o`3Qoooonf[o
oo]Z00Kooo]Z00?o0?ldoookJ_l0odh01OoonfX00ol0R?oo0:WooookJP02oookJP04o`04oooonf[o
oo]Zo`3Do`cooo]Z00?ooh40oookJ_oonfX02OoonfX00ooo02gooo]ZoookJP07oookJP03oomG0?oo
nf[ooo]Z00Oooo]Z00?oL03oon/0oooonfX00_oonfX00ooo_P3ooo]ZoookJP0WoookJP00:_oonfX0
2?l0:_oooo]ZoookJ_oonf[ooe80o`3o<ooonf[o^Ol04?oonfX00oooN@3ooo]ZoookJP0GoookJP03
ool0j_oonf[ooo]Z00Kooo]Z00?ooaH0oonB0?oonfX01OoonfX00ooo0?cooo]ZoookJP03oookJP03
oaP0oooonf[oo`H000?ooo]Z00?ojol0ool0m_oo:0000_oo:005ool000;oobP01Ooo00000ooo:03o
of`0oookJP07oookJPOoobP02_oonfX2o`2So`03oookJ_nco`3o/ol000;ooo]Z1Ooo0004oookJPco
0?oN1_oonfX:oolX00CoolT01ooonfX00ooo:03o/ol0ok?o000:oolX00_ooo]Z00?oof`0oookJ_oo
nfX01?oonfX4o`0000Ooo`0000?oo`3lool00?oonfX02?oonfX00ooo0>[ooo]ZoookJP08oookJPGo
obP00ooonfX2ool000Cooo]Z00Koo`00oomB0?oonf[ooo]Zo`0ZoooonfX2oiCo0003ool00?l0omoo
oo]Z00;ooo]Z1_oo:003oookJP03oolX0?oo003oo`0000?ooo]Z00Koo`00oookJ_oQo`3ooo]ZobH0
oolPo`0<oookJP04ool00?oonf[o0?mKoookJP?oobP01_oo00001?nBo`3ooo]Zool00?l@0?l4ool0
0004oookJ_oo057oo`00o`2]o`;ooo]Z00?oo`1ioookJ_oonfX00ooonfX01ol0oe?ooo]ZoookJ_oo
nf[o0?lMoookJ_l0hOl02_oonfX00ooob@3o0?m>oomi0002oomi00;ooo]Z00?o08SooookJ_ooN@00
0_oonfX01Ol01?oooo]ZoookJ_oonf[o0=Co00_ooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02go
oo]ZoookJP07oookJP03oomG0?oonf[ooo]Z00Kooo]Z00?oj`3oo`3o1OoonfX00_oonfX00ooob@3o
oo]ZoookJP1>oookJP08o`0Zoooonf[ooo]ZoookJ_ooDP3o0?lcoookJ_nio`0AoookJP03o`1coooo
nf[ooo]Z01Kooo]Z00?oo`3ZoookJ_oonfX01ooonfX00ooo5P3ooi80oookJP04oookJP03ool0o?oo
nf[ooo]Z00?ooo]Z00Co603ooookJ_oonf[oo`H00_oonfX00oo[o`3oo`3foookJP03oookJP05o`2V
oonX0?oooo]ZoookJ_oo0?T00ooonfX01_l0Mooooo]ZoookJ_l0oi[ooo]Zoom/00Wooo]Z00?o0?_o
oookJ_oonfX03?oonfX2o`2So`03oookJ_nco`3o/ol000_ooo]Z3?l0omh<oookJPCo0?oN3OoonfX2
ok?o0003o`2Soooonf[ooo]Z01;ooo]Z00?oof`0oookJ_oonfX00ooonfX4o`000008oookJ_oo0?Ko
o`H0ool60?oonf[o603ooookJ_oo0?`:oookJP03ool0j_oonf[ooo]Z00_ooo]Z00?o07?ooookJ_oo
nfX02?oonfX01Onio`3ooe80o`3o<ooonf[o02[o00?ooo]Z00?o?@3oo`3ogooonfX01OoonfX01?lB
0?oo0?lKoookJ_oobP02oookJP03o`3ioooo09?ooo]Z00Cooo]Z00Gof_l0on7o0?oonf[ooo]ZobH0
o`0=oookJP03oc7o0?l0oe_ooo]Z00;ooo]Z00Wo0?n`oh;o0?oonf[ooo]Zo`3oCOoonf[o1P3oool0
mOnBo`000_oonfX00ol@0?oooo]Zo`0Io`03oookJP05ool0DOoonf[o0:gooookJ_oo07T01OoonfX0
1Ol0oe?ooo]ZoookJ_oonf[o0?lM00;ooo]Z00?o0>7ooookJ_oonfX01ooonfX00ol0ocCo0?m>o`3o
;P05oookJP03o`28ool0ZOoooo]Z00;ooo]Z00Co00CooookJ_oonf[o0=Co2ooonfX00oooP@3ooo]Z
oookJP0:oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX01ooonfX00oo[0?oooo]Z
oookJP02oookJP03oonn0?oonf[ooo]Z02Oooo]Z000[oookJP07o`0Zoooonf[ooo]ZoookJ_ooDP3o
oo]ZokWo000AoookJP03oomi0?oonf[ooo]Z01Oooo]Z00?oo`3ZoookJ_oonfX01_oonfX00ooo5P3o
oi80oookJP04oookJP03ool0o?oonf[ooo]Z00Cooo]Z00?o603ooookJ_oo1P000ooonfX00oo[o`3o
obP0oolX0002oolX00Goo`0000?oobP0ool00?oo00001Ooo00000oooK03ooo]ZoookJP06oookJP[o
obP02?oonfX00ol0Xooooo]ZoookJP02ok?o00;ooo]Z0ooo000@oookJP_o0?oN0_oonfX00ooo:03o
olT0ooo90004ooo900Gooo]Z0ooob@09oolX00cooo]Z0_ooK007oookJP;o00000_oo0?H6ool00003
ool0o?oonf[ooo]Z00Sooo]Z00?oo`3ZoookJ_oonfX02?oonfX7oolX00;ooo]Z0ooo0002oookJP06
ool00?ooDP3ooo]ZoookJ_l0:_oooo]Z0_nDo`000ooo003o0?oOoookJP03oookJPGoobP00ooonfX0
0ooo:03oo`2Cool00003ool00007oookJ_oo003ohOl0oookJ_lV0?ooobP0ob3o000<oookJP04ool0
0?oonf[o0?mKoookJP;oobP01_oo00001Ol60?ooT_l0oookJ_oo003o403o00?oo`0000Oooo]Zool0
DOoo003ooo]Zo`2]oooonf[oo`1i00Gooo]Z00Go0?mCoookJ_oonf[ooo]Zo`3o7@02oookJP03o`3Q
oooonf[ooo]Z00Oooo]Z00?oolT0oomi0?l0odh00_ooN@03oookJP03o`28ooooN@3ooo]Z00;ooo]Z
00Co00CooookJ_oonf[o0=Co3?oonfX00oooP@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z00Oo
oo]Z00?ooeL0oookJ_oonfX01ooonfX01Oo[0?oo0?l5oookJ_oonf[oolT005;ooo]Z00Oo02[ooook
J_oonf[ooo]ZoomB0?oonf[o^Ol0017ooo]Z00?o07?ooookJ_oonfX05ooonfX00ooo0>[ooo]Zoook
JP07oookJP03oolF0?ooTP3ooo]Z00Cooo]Z00?oo`3loookJ_oonfX00ooonfX00olH0?oooo]Zool6
0003oookJP03on_o0?oo0?Kooo]Z00?ooo]Z00Go0:KoojP0oonX0?oooo]Zool0n@03oookJP;o07Oo
00Cooo]Zo`3oV_oonf[oof`02OoonfX2o`3ko`kooo]Z0_l0Xol00ooonf[o/ol0ok?o000EoookJPco
0?oN3_oonfX3ok?o0003o`2Soooonf[ooo]Z01;ooo]Z0_ooK006oookJP?o00000_oo0?H01_oo1P3o
oo]ZoaP0oolH0?oooo]Zool0o0[ooo]Z00?oo`3ZoookJ_oonfX03?oonfX00ol0Looooo]ZoookJP07
oookJP05okWo0?ooDP3o0?lcoookJ_l0:_l00ooonfX00olm0?oo0?oOoookJP05oookJP04oa80ool0
oa_ooo]Zooo:00;ooo]Z00?o0?Woool0Tooo01<01?oonfX01_oJo`3ohOl0oookJ_oonf[o9P3oob3o
00cooo]Z00?o<Ol0oookJ_l0oe/00ooonfX03On2o`3ooo]ZoookJ_l0j?oo0?m=oookJ_l60?ooo`3e
oi;o0?oonf[o403oool0J_l06Ol00ooonfX01Ooo057ooo]Zo`2]oooonf[oo`1i00Gooo]Z00Go0?mC
oookJ_oonf[ooo]Zo`3o7@03oookJP03o`3Qoooonf[ooo]Z00Kooo]Z00Co0?ldoookJ_l0odko0?l^
1?oonfX00ol0R?oo0:WooookJP02oookJP04o`04oooonf[ooo]Zo`3Do`cooo]Z00?ooh40oookJ_oo
nfX02OoonfX00ooo02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z00Sooo]Z00Goj`3ooookJ_oo
nf[ooo]Zoonn000ZoookJP00:ooonfX01ol0:_oooo]ZoookJ_oonf[ooe80oookJ_nio`004OoonfX0
0oooN@3ooo]ZoookJP0HoookJP03ool0j_oonf[ooo]Z00Kooo]Z00?ooi80oookJ_oonfX01?oonfX0
0ooo0?cooo]ZoookJP04oookJP03oaP0oooonf[oo`H000?ooo]Z00?ojol0oolX0?oo:0000_oo:005
ool00003oolX0?oo0?Woo`0000Koo`002?oonfX;oolX00Oooo]Z0_l0Xol2oookJP;o/ol000?ooo]Z
ool00?oonfX07?oonfX=ooo900OoobP03ooonfX2oom/00Wooo]Z00?o0000ool0m_l000001Ooo0002
ool0o0Cooo]Z0_oo0004oookJP03ool0j_oonf[ooo]Z00Wooo]Z2?oo:006ool00004oomB0?oonf[o
oo]Zo`0Zo`;ooo]Z00?oU?l0ool00?l0oml01OoonfX4oolX0006ooo:0?oonf[ooo]ZoolX0?oo09?o
o`0C1Ooo00001OoQo`3ooo]ZoookJ_lV0?oo8?l000cooo]Z00?oo`00oookJ_l0oe/00_oonfX2oolX
00Goo`0000Go1P3ooi;o0?oo0?Gooo]Zoa00o`04ool00004oookJ_oo057oo`00o`2]o`;ooo]Z00?o
o`1ioookJ_oonfX00ooonfX01ol0oe?ooo]ZoookJ_oonf[o0?lMoookJ_l0hOl02_oonfX00ooob@3o
ogT0o`3oCP03oomi0004oookJ_l0R?oooo]Zoomi00;ooo]Z00Go00CooookJ_oonf[ooo]Zo`3Do`0;
oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX01ooonfX00oooE`3ooo]ZoookJP06
oookJP03on/0ool0o`Gooo]Z00;ooo]Z00?oolT0oookJ_oonfX0D?oonfX01Ol0:_oooo]ZoookJ_oo
nf[ooe8000;ooo]Z00?o^Ol0oookJ_oonfX03ooonfX00ol0Looooo]ZoookJP0GoookJP03ool0j_oo
nf[ooo]Z00Oooo]Z00?ooi80oookJ_oonfX00ooonfX00ooo0?cooo]ZoookJP04oookJP03oaP0oooo
nf[oo`H000?ooo]Z00?ojol0ool0m_oonfX00ooonfX01?l0Y_oooo]ZojP0oooonfX2ool0n@?ooo]Z
00Go07OooookJ_l0oi[ooo]Zoom/000:oookJP;o0?_o3_oonfX2o`2So`03oookJ_nco`3o/ol002So
oo]Z1Onco`02o`2SoaCooo]Z0_ooK008oookJP;o000000Goo`3fo`000?oo1P3ooo]ZoaP0o`02oook
JP03ool0o?oonf[ooo]Z00;ooo]Z0_oo5P04oookJP03ool0j_oonf[ooo]Z00cooo]Z00?o07?ooook
J_oonfX01ooonfX01Onio`3ooe80o`3o<ooonf[o02[o00;ooo]Z00?o?ol0o`3Lool0oml01ooonfX0
2?l0oa_ooo]ZoookJ_oobP3ooo]Zo`3ioooo09?oo`0C1?oonfX00ooJo`3ohOl0oookJP02oookJP03
obH0oooonf[ooo]Z00_ooo]Z00?o<Ol0o`3oFooonfX00_oonfX02Ol0ok3oP_l0oookJ_oonf[o0?m=
oookJ_l60?oooo]Zoi;o0002oookJP03oa00oooonf[o01Wo00?ooo]Z00Goo`1AoookJ_l0[Ooooo]Z
ool0N@05oookJP05o`3oDooonf[ooo]ZoookJ_l0oad00_oonfX00ol0hOoooo]ZoookJP07oookJP03
o`3o=?oonf[o0?m>00Gooo]Z00?o08Soo`2YoooonfX00_oonfX01?l01?oooo]ZoookJ_l0e?l;oook
JP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX01ooonfX00oooE`3ooo]ZoookJP07oook
JP03on/0ool0o`Gooo]Z00;ooo]Z00?ookh0oookJ_oonfX0:?oonfX002_ooo]Z00?o02[ooookJ_oo
nfX00_oonfX00oooDP3ooo]ZokWo000@oookJP03oomi0?oonf[ooo]Z01Sooo]Z00?oo`3ZoookJ_oo
nfX01_oonfX00ooo5P3ooi80oonB0005oookJP03ool0o?oonf[ooo]Z00Cooo]Z00?o603ooookJ_oo
1P000_oonfX00oo[o`3oobP0oolX0002oolX00Ooo`0000?oo`3iool00?oo00001ooo0006oookJP[o
obP02OoonfX2o`2So`;ooo]Z0_nco`0KoookJP[oolT000Cooo]Zo`2Sool0Xooo0:?o0ooo:00Boook
JP;oof`02_oonfX2ool0mP03o`000?oo003oo`0000?oo`0000Coo`3loookJ_oonf[ooo]Z0ooo0005
oookJP03ool0j_oonf[ooo]Z00Wooo]Z1ooo:002oookJPGoo`0000Co0?lcoomB0?oonf[o02[o0ooo
nfX00ooo003oU?l0o`3og`04oookJPCoobP000KoolX0oolX0?oo:03oobP0ool0TooonfX8ool00003
ooo90?oo:03o8?l000_ooo]Z00Goo`00oookJ_oonf[o0?mKoookJP03oolX00Goo`0000Go1P3ooi;o
0?oonf[ooo]Zoa00o`03ool00007oookJ_oo057oo`00oookJ_l0[Ooooo]Zool0N@05oookJP08o`3o
Dooonf[ooo]ZoookJ_l0oago0?l8oookJ_l0hOl9oookJP03ooo90?oonf[o0?m>00OoogT00ooonfX0
1?l01?oooo]ZoookJ_l0e?l<oookJP03oon10?oonf[ooo]Z00Wooo]Z00?oo`0]oookJ_oonfX02?oo
nfX00oooE`3ooo]ZoookJP06oookJP03on/0ool0o`Gooo]Z00;ooo]Z00?oolT0oookJ_oonfX0D?oo
nfX00ol0:_oooo]ZoookJP02oookJP03oomB0?oonf[o^Ol0017ooo]Z00?o07?ooookJ_oonfX05ooo
nfX00ooo0>[ooo]ZoookJP07oookJP03oolF0?ooTP3ooo]Z00Cooo]Z00?oo`3loookJ_oonfX01?oo
nfX00olH0?oooo]Zool60003oookJP03on_o0?oo0?Kooo]Z00?ooo]Z00?o0:KooookJ_nX0?l00_oo
nfX02Ooo0?Wooo]ZoookJ_oonf[o07OooookJ_l0oi[ooo]Zoom/000;oookJP;o0?_o3_oonfX2o`2S
o`03oookJ_nco`3o/ol0027ooo]Z1Onco`000ooonf[o0:?oo`2So`02o`2SoaCooo]Z0_ooK00:oook
JP;oo`3f00Go0000ool60?lH0?oo603ooookJP02ool0o0?ooo]Z0_ooTP05oookJP03ool0j_oonf[o
oo]Z00cooo]Z00?o07?ooookJ_oonfX02?oonfX01?nio`3ooe80oookJ_l0:_l3oookJP03ocoo0?lm
0?oo0?oO00Kooo]Z00Co4P3oo`3o6ooonf[oolX00_oonfX00ooo09?ooo]Zool04`04oookJP06om[o
0?oonf[ooo]ZoookJ_lV0?oo8?l03?oonfX00olao`3ooo]Zo`3oF`02oookJP0>o`3o/?n2o`3ooo]Z
oookJ_l0j?oo0?m=oookJ_l60?ooo`3eoi;o0?oonf[o403oool0J_l06Ol3oookJP05ool0DOoonf[o
0:gooookJ_oo07T01OoonfX01_l0oe?ooo]ZoookJ_oonf[o0?lMo`3o20;ooo]Z00?o0>7ooookJ_oo
nfX01_oonfX01?l0ocCooo]Zo`3oC_l0obh4oookJP03o`28oooonf[o0:Wo00;ooo]Z00Co00Cooook
J_oonf[o0=Co3?oonfX00oooP@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00?ooeL0
oookJ_oonfX01ooonfX01Oo[0?oooo]ZoookJ_oonf[ookh002_ooo]Z000/oookJP07o`0Zoooonf[o
oo]ZoookJ_ooDP3ooo]ZokWo000AoookJP03oomi0?oonf[ooo]Z01Sooo]Z00?oo`3ZoookJ_oonfX0
1_oonfX00ooo5P3ooo]ZoonB0004oookJP03ool0o?oonf[ooo]Z00Gooo]Z00?o603oool60?oonfX0
0_oonfX01Oo[o`3oobP0oolX0?oo:03ooo]Z00Ooo`0000?oo`3iool00?oo00002?oo0005oookJPSo
obP03?oonfX4o`2So`Oo/ol04_oonfX=ooo901Kooo]Z0_ooK00:oookJP;oo`3f00?ooo]Zo`000?l0
00000ooo00000ooonf[oo`3loookJP02oookJP03ool00?oonf[oo`0000Cooo]Z0_oo0>X<oookJPKo
obP00ooonfX5ool00003oomB0?oo003o02[o00?ooo]Z00?oU?l0ool00?l0oml01OoonfX4oolX0006
ooo:0?oo:03oobP0oolX0?oo09?oo`0C2?oo00000ooob@3o8?l0oookJP0;oookJP03ool00?oonf[o
0?mK00;ooo]Z0_oo:0000oooN@3oo`00ool00002ool00005o`H0oonBo`3oo`3eoookJ_l@0?l00ooo
0002oookJP03ool0DOoo003o0:go00;ooo]Z00?oo`1ioookJ_oonfX00ooonfX01ol0oe?ooo]Zoook
J_oonf[o0?lMoookJ_l0hOl02_oonfX01Ooob@3ooo]Zo`3oC_ooN@3ooo]Z00OoogT000Go00Cooook
J_oonf[ooo]Zo`3Do`0;oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX01ooonfX0
0oooE`3ooo]ZoookJP06oookJP03og00ooo[0?oooo]Z00;ooo]Z00?oolT0oookJ_oonfX0D_oonfX0
1Ol0:_oooo]ZoookJ_oonf[ooe8000;ooo]Z00?o^Ol0oookJ_oonfX03_oonfX00ol0Looooo]Zoook
JP0HoookJP03ool0j_oonf[ooo]Z00Oooo]Z00?ooaH0oonB0?oonfX00ooonfX00ooo0?cooo]Zoook
JP05oookJP03oaP0oooo1P3ooo]Z00?ooo]Z00?ojol0oookJ_oonfX00ooonfX00ol0Y_oooo]ZojP0
o`02oookJP;oo`3i0_oonfX2o`1go`;o0?nJ00?oof`0oookJ_oonfX02_oonfX00ol0nooooo]Zoook
JP0=oookJP?o0:?o1onco`0FoookJPCo/ol01_l0XolFoookJP;oof`02_oonfX2ool0mP;o000000Go
o`H0oaP0oooonf[ooo]Zool0o004oookJP03oonB0?oo5P3ooo]Z00?ooo]Z0_oo0>X>oookJP03o`1c
oooonf[ooo]Z00Sooo]Z00Co^Ol0oomB0?oonf[o02[o0ooonfX00oloo`3o?@3oo`3og`06oookJP09
oa80ool0oa_ooo]ZoookJ_oobP3ooo]Zo`3ioooo09?oo`0C00Cooo]Z00?of_l0on7o0?oonfX00_oo
nfX00olV0?oooo]ZoookJP0;oookJP03oc7o0?l0oe_ooo]Z00;ooo]Z00Wo0?n`oh;o0?oonf[o0>So
o`3oCOoonf[o1P3ooookJ_nBo`000_oonfX00ol@0?ooo`1Zo`0Io`03oookJP05ool0DOoonf[o0:go
oookJ_oo07T01OoonfX01Ol0oe?ooo]ZoookJ_oonf[o0?lM00;ooo]Z00?o0>7ooookJ_oonfX01ooo
nfX01?l0ocCooo]Zo`3oC_l0obh4oookJP03o`28ool0ZOoooo]Z00;ooo]Z00Co00CooookJ_oonf[o
0=Co2ooonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oo
nfX01ooonfX00om`0?ooj`3ooookJP02oookJP03oonn0?oonf[ooo]Z02Wooo]Z000/oookJP05o`0Z
oooonf[ooo]ZoookJ_ooDP000_oonfX00onio`3ooo]ZoookJP0>oookJP03oomi0?oonf[ooo]Z01Wo
oo]Z00?oo`3ZoookJ_oonfX01OoonfX01?oo5P3ooo]ZoookJ_ooTP04oookJP03ool0o?oonf[ooo]Z
00Cooo]Z00?o603ooookJ_oo1P000ooonfX00oo[o`3oobP0oookJP02oookJQ;oo`001OoonfX7oolX
017ooo]Z1_l0Xol;ok?o00Gooo]Z3ooob@0DoookJP;oof`02ooonfX01Ooo0?Kooo]ZoookJ_oonf[o
000000;oo`0000?o0000ool0o?oo0?`00ooonfX3ool000Cooo]Z00?oo`3ZoookJ_oonfX02ooonfX6
oolX00?ooo]Z1Ooo00001?ooDP3oo`00ool00?l0:_l2oookJP;oo`0000?o0?oOoookJ_oonfX00ooo
nfX01Ol0S_ooobP0oolX0?oo:03oolX000?oobP000?oo`2Cool04ooo:0001ooo00000ooob@3o8?l0
oookJP0;oookJP03ool00?oonf[o0?mK00?ooo]Z00?oobP0oomi0?oonfX00ooo00000ooonf[o1P3o
oi;o0002oookJP03oa00oooo003oo`0000;ooo]Z00Koo`1Aool00?oonf[o0:gooookJ_oo07T6oook
JP06o`3oDooonf[ooo]Zo`3o7Ol0o`So0>7o2_oonfX01?oob@3ooo]Zo`3oC_ooN@02oookJPOoogT0
00Co00CooookJ_oonf[o0=Co3?oonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z00Oo
oo]Z00?ooeL0oookJ_oonfX01_oonfX00oo[0?oo0?l5oookJP02oookJP03ooo90?oonf[ooo]Z05;o
oo]Z00Go02[ooookJ_oonf[ooo]ZoomB0002oookJP03okWo0?oonf[ooo]Z00oooo]Z00?o07?ooook
J_oonfX06?oonfX00ooo0>[ooo]ZoookJP06oookJP03oolF0?oonf[ooi8000Cooo]Z00?oo`3loook
J_oonfX01OoonfX00olH0?ooo`H0oookJP02oookJP03on_o0?oo0?Kooo]Z00Cooo]Z00Co0:Kooook
J_nX0?ooZ03o0_oonfX2ool0n@;ooo]Z00Co07OooookJ_l0oi[oof`03?oonfX2o`3koa;ooo]Z1Ol0
Xol;ok?o00Kooo]Z1Onco`04o`2Soa[ooo]Z0_ooK00;oookJP09ool0m_oonf[ooo]Zo`000?oo1P3o
603oo`000?oonf[oo`3l00Cooo]Z00?ooi80oolF0?oonfX00ooonfX00ooo0>[ooo]ZoookJP0=oook
JP03o`1coooonf[ooo]Z00Sooo]Z00Go^Ol0oomB0?oonf[ooo]Zo`0Zo`02oookJP03ocoo0?l0g?oo
0?oO00Kooo]Z00Wo4P3ooookJ_l0oa_ooo]Zooo:0?oonf[o0?Woool0Tooo01<01?oonfX00ooJo`3o
hOl0oookJP02oookJP03obH0oooonf[ooo]Z00_ooo]Z00?o<Ol0o`3oFooonfX00_oonfX03_l0ok3o
P_l0oookJ_oonf[o0>Soo`3oCOoonf[o1P3oool0mOnBo`3ooo]Zoa00oooo06[o01Wo0ooonfX01Ooo
057ooo]Zo`2]oooonf[oo`1i00Kooo]Z00Oo0?mCoookJ_oonf[o0?lMo`3o2?oonf[o0>7o00Wooo]Z
00Co0?ldoookJ_oonf[o0?m>1OoonfX01Ol0R?oo0:WooookJ_oonf[o00Co00;ooo]Z00?o0=Cooook
J_oonfX02_oonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooeL0oook
J_oonfX01ooonfX01Oo[0?oo0?l5oookJ_oonf[ookh002cooo]Z000/oookJP03o`0Zoooonf[ooo]Z
00;ooo]Z00?ooe80oookJ_nio`004?oonfX00ol0Looooo]ZoookJP0IoookJP03ool0j_oonf[ooo]Z
00Kooo]Z0_oo5P000ooonf[ooi80oookJP02oookJP03ool0o?oonf[ooo]Z00Gooo]Z00?o603ooook
J_oo1P000ooonfX00oo[o`3oo`3foookJP02oookJQ7oo`001_oonfX7oolX01Sooo]Z1ol0Xol2oook
JPCo/ol04?oob@0BoookJP;oof`02ooonfX2ool0mP?ooo]Z00Goo`H0ool00?l0003o0000ool0o003
oookJP?oo`001OoonfX00ooo0>[ooo]ZoookJP0<oookJPCoobP01OoonfX4ool00004oomB0?oo003o
o`00o`0Zo`Goo`001_oonfX2oolX0003oookJ_oobP3oobP000;oobP000Coo`2CoolX0?oo01?oobP0
1_oo00000ooob@3o8?l0oookJP0<oookJP03ool00?oonf[o0?mK00?ooo]Z00?oP_l0oomi0?oo0000
0_oo00001_oonf[o1P3ooi;o0?oo0?Gooo]Zoa00o`;oo`000ooonfX01Ooo057ooo]Zo`2]oooonf[o
o`1i00Kooo]Z00Oo0?mCoookJ_oonf[ooo]Zo`3o7Ooonf[o0>7o00[ooo]Z00CoolT0oookJ_l0odko
0?l^0_oonfX6oomi0005o`04ooooN@3ooo]ZoookJ_l0e?l02ooonfX00oooP@3ooo]ZoookJP0:oook
JP03ool0;Ooonf[ooo]Z00Sooo]Z00?ooeL0oookJ_oonfX01OoonfX00om`0?ooj`3oo`3o1@02oook
JP03ooo90?oonf[ooo]Z05Cooo]Z00Go02[ooookJ_oonf[ooo]ZoomB0002oookJP03okWo0?oonf[o
oo]Z00kooo]Z00?o07?ooookJ_oonfX06?oonfX00ooo0>[ooo]ZoookJP07oookJP;ooaH000?ooi80
oookJ_oonfX00_oonfX00ooo0?cooo]ZoookJP05oookJP03oaP0oooo1P3ooo]Z00;ooo]Z00?ojol0
ool0m_oonfX01?oonfX01?l0Y_oooo]ZoookJ_nX0?l3oookJP03ool0nOoonf[ooo]Z00;o07Oo00?o
oo]Zoom/0?l0oiX03?oonfX2o`3koaOooo]Z1ol0Xol2oookJPKo/ol01?l0XolMoookJP;oof`02ooo
nfX2ool0mP;ooo]Z0_oo1P03o`000004ool0o?oonf[ooo]ZoookJP;ooi801OoonfX00ooo0>[ooo]Z
oookJP0>oookJP03o`1coooonf[ooo]Z00Oooo]Z00Go^Ol0oomB0?l0oc?ooo]Zo`0Zo`02oookJP03
ocoo0?oonf[oN?l000Kooo]Z00Go08kooa80ool0oa_ooo]Zooo:0002oookJP03ool0Tooonf[oo`0C
00Cooo]Z00Gof_l0oookJ_oonf[ooo]ZobH0o`0=oookJP03oc7o0?oonf[o0?mK00?ooo]Z00Wo0?n`
oh;o0?oonf[o0>Soo`3oCOoonf[o1P3ooookJ_nBo`000_oonfX00ol@0?oo01WooookJP02oookJP05
oaD0oooo057o0:gooookJ_oo07T01_oonfX01Ol0oe?ooo]ZoookJ_oonf[o0?lM00;ooo]Z00?o0>7o
oookJ_oonfX01ooonfX01?l0ocCooo]Zo`3oC_l0obh4oookJP03o`28oooonf[o0:Wo00;ooo]Z00Co
00CooookJ_oonf[o0=Co3?oonfX00oooP@3ooo]ZoookJP09oookJP03ool0;Ooonf[ooo]Z00Sooo]Z
00?ooeL0oookJ_oonfX01_oonfX00om`0?ooj`3ooookJP02oookJP03oonn0?oonf[ooo]Z02[ooo]Z
000]oookJP07o`0Zoooonf[ooo]ZoookJ_ooDP3ooo]ZokWo000AoookJP03o`1coooonf[ooo]Z01Wo
oo]Z00?oo`3ZoookJ_oonfX01ooonfX00ooo5P3ooo]ZoonB0003oookJP03ool0o?oonf[ooo]Z00Go
oo]Z00Co603ooookJ_oo1P3oo`H00_oonfX01?o[o`3oo`3foookJ_oonfX7ool00003oookJ_oo003o
o`0000Koo`0000?ooo]Zo`3oV_oonfX01OoonfX4oolX00;ooo]Z0_oo:00MoookJPKo0:?o2OoonfX7
ooo9017ooo]Z00?oof`0oookJ_oonfX02_oonfX01?oo0?Kooo]ZoookJ_oonfX2ool60005oaP0ool0
003o0000ool0o?l000000_oonfX3ool000Gooo]Z00?oo`3ZoookJ_oonfX03?oonfX4oolX00Gooo]Z
1?oo00001?ooDP3oo`00ool00?l0:_l4ool00003o`3ogooo003ooo]Z00Cooo]Z00Co4P3ooolX0?oo
nf[oolX00ooo:0001?oo09?oobP0ool04ooo:006ool00003ooo90?oo:03o8?l000cooo]Z00?oo`00
oookJ_l0oe/00_ooN@001?oonf[oP_l0oomi0?oonfX2ool000;ooo]Z00Ko1P3ooi;o0?oonf[ooo]Z
oa00oooo0003oookJP03ool0DOoo003o0:go00;ooo]Z00?oo`1ioookJ_oonfX01?oonfX01_l0oe?o
oo]ZoookJ_l0oago0?l8o`3Qo`[ooo]Z00CoolT0oookJ_oonf[o0?m>0ooonfX6oomi0004o`04oooo
nf[ooo]Zo`3Do`cooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP07oookJP03oomG
0?oonf[ooo]Z00Kooo]Z00?oj`3oo`3o1OoonfX00_oonfX00ooob@3ooo]ZoookJP1DoookJP05o`0Z
oooonf[ooo]ZoookJ_ooDP000_oonfX00onio`3ooo]ZoookJP0?oookJP03o`1coooonf[ooo]Z01So
oo]Z00?oo`3ZoookJ_oonfX02?oonfX00ooo5P3ooi80oookJP02oookJP03ool0o?oonf[ooo]Z00Ko
oo]Z00?o603oool60?oo1P000_oonfX00oo[o`3oo`3foookJP04oookJP04o`2Voooonf[ooo]ZojP0
o`?ooo]Z0_oo0?T2oookJP03o`1goooonf[oof`000;o0?nJ3?oonfX2o`3koacooo]Z1_l0XolQoook
JP;oof`03?oonfX00ooo0?Kooo]ZoookJP02ool60005oaP0ool0003o0000o`000?oo0?`00ooonfX0
0oooTP3ooaH0oookJP04oookJP03ool0j_oonf[ooo]Z00kooo]Z00?o07?ooookJ_oonfX02?oonfX0
1?ooDP3o0?lcoookJ_l0:_l2oookJP04ocoo0?oonf[o0?oOogSo00Kooo]Z00Co4P3oo`3o6ooonf[o
olX00_oonfX00ooo09?ooo]Zool04`04oookJP06om[o0?oonf[ooo]ZoookJ_lV0?oo8?l03OoonfX0
0olao`3o0?mKoookJP02oookJP0>o`3o/?n2o`3ooo]ZoookJ_l0j?oo0?m=oookJ_l60?ooo`3eoi;o
0?oonf[o403oool0J_l06Ol3oookJP05ool0DOoonf[o0:gooookJ_oo07T01_oonfX01ol0oe?ooo]Z
oookJ_l0oago0?l8oookJ_l0hOl02OoonfX01?l0ocCooo]ZoookJ_l0odh5oookJP05o`28ool0ZOoo
oo]ZoookJ_l01?l00_oonfX00ol0e?oooo]ZoookJP0:oookJP03oon10?oonf[ooo]Z00[ooo]Z00?o
o`0]oookJ_oonfX01ooonfX00oooE`3ooo]ZoookJP07oookJP03on/0ool0o`Gooo]Z00;ooo]Z00?o
okh0oookJ_oonfX0:_oonfX002gooo]Z00Go02[ooookJ_oonf[ooo]ZoomB0002oookJP03okWo0?oo
nf[ooo]Z00oooo]Z00?o07?ooookJ_oonfX06OoonfX00ooo0>[ooo]ZoookJP07oookJP03oolF0?oo
nf[ooi8000?ooo]Z0_oo0?`6oookJP04oaP0oooonf[ooo]Zool600;ooo]Z00Cojol0ool0m_oo0?Ko
oo]Z1Ooo00000ooonf[oo`00oookJP07ool000GoogT01?oonfX3oolX00Cooo]Z00?oobP0oookJ_oo
nfX09OoonfX2ool001Sooo]Z0_ooK00;oookJP;oo`3f0ooonfX01_oo1P3o603ooookJ_oonf[o0000
ool0o0;o000000?ooo]Zool00?oo00001_oonfX00ooo0>[ooo]ZoookJP0=oookJP?oobP01_oonfX3
ool00004oomB0?oo003oo`00o`0Zo`Coo`0000?o0?oOool00?oonfX01?oonfX01?l0S_oo4P3oo`3o
6ooobP04oolX0004ool0Tooo:03oo`0CoookJPKoo`0000?oolT0ob3o0?oonfX02ooonfX01?oo003o
oo]ZoookJ_l0oe/2oomi0005oh;o0?oonf[oogT0oookJ_oo00000_oonfX01ol60?ooT_l0ool0mOoo
nf[o403oool00?oo06X00ooonfX01Ooo057ooo]Zo`2]oooonf[oo`1i00Kooo]Z00Oo0?mCoookJ_oo
nf[ooo]Zo`3o7Ooonf[o0>7o00[ooo]Z00CoolT0oookJ_l0odko0?l^0ooonfX6oomi0004o`04oooo
nf[ooo]Zo`3Do`_ooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP08oookJP03oomG
0?oonf[ooo]Z00Kooo]Z00?oj`3oo`3o1OoonfX00_oonfX00ooob@3ooo]ZoookJP1DoookJP05o`0Z
oooonf[ooo]ZoookJ_ooDP000_oonfX00onio`3ooo]ZoookJP0@oookJP03o`1coooonf[ooo]Z01So
oo]Z00?oo`3ZoookJ_oonfX02?oonfX00ooo5P3ooi80oookJP02oookJP;oo`3l1ooonfX00olH0?oo
oo]Zool60002oookJP03on_o0?oo0?Koo`3f00Cooo]Z00?o0:KooookJ_oonfX00_nX0?l3oookJP05
ool0nOoonf[ooo]Zo`1goooonfX00_ooK002o`3oVPcooo]Z00?o0?_ooookJ_oonfX0?_oonfX2oom/
00cooo]Z0_oo0?H2oookJP05ool60?lH0?oooo]ZoookJ_l000000_oo0?`01Ol0003ooo]ZoookJ_oo
TP3ooaH000Gooo]Z00?oo`3ZoookJ_oonfX03_oonfX00ol0Looooo]ZoookJP08oookJP04oomB0?l0
oc?ooo]Zo`0Zo`;ooo]Z00Co?ol0oookJ_l0omooN?l01_oonfX01?lB0?oooo]Zo`3o6ooobP03oook
JP03ool0Tooonf[oo`0C00Cooo]Z00Gof_l0oookJ_oonf[ooo]ZobH0o`0=oookJP03oc7o0?oonf[o
0?mK00;ooo]Z00[o0?n`oh;o0?l0<?oooo]Zo`3Xool0odgooo]Zo`H0oooonf[oT_l00_oonfX00ol@
0?oo01WooookJP02oookJP05oaD0oooo057o0:gooookJ_oo07T01_oonfX01Ol0oe?ooo]ZoookJ_oo
nf[o0?lM00;ooo]Z00?o0>7ooookJ_oonfX01ooonfX01?l0ocCooo]Zo`3oC_l0obh4oookJP03o`28
oooonf[o0:Wo00;ooo]Z00Co00CooookJ_oonf[o0=Co3?oonfX00oooP@3ooo]ZoookJP09oookJP03
ool0;Ooonf[ooo]Z00Sooo]Z00?ooeL0oookJ_oonfX01ooonfX01Oo[0?oooo]ZoookJ_oonf[ookh0
02gooo]Z000^oookJP07o`0Zoooonf[ooo]ZoookJ_ooDP3ooo]ZokWo000BoookJP03o`1coooonf[o
oo]Z01Sooo]Z00?oo`3ZoookJ_oonfX02?oonfX00ooo5P3ooo]ZoonB0004oookJP03ool0o?oonf[o
oo]Z00Cooo]Z00?o603ooookJ_oonfX00_oo1P001Ooonf[ojol0oookJ_oo0?Kooo]Z00?oo`000ooo
nfX00ooo003ooo]Zool00004ool00003oookJ_oo003oo`0000SoogT000?oobP0oomi0?ooN@001?oo
nfX2oolX02;ooo]Z1Ooo000FoookJP;oof`02ooonfX2ool0mP?ooo]Z0_oo1P000olH0?oooo]Zoook
JP02ool0o0;o00000ooo0005oookJP;oo`3Z3ooonfX2oolX00Sooo]Z0_oo00001?l0oc?ooe80ool0
0?l0:_l8ool000?ooo]Z00Go08kooa80ool0oa_oolX0oookJP03oolX0003ool0Tooo:03oo`0C00;o
oo]Z1Ooo00000ooob@3o8?l0oookJP0<oookJP04ool00?oonf[o0?mKoookJP;oogT000WoP_l0oomi
0?ooN@3oo`00o`3oCOoonf[o1P3oool00?nBo`000_oonfX00ol@0?ooo`00oookJP03oookJP05ool0
DOl0[Ooooo]ZoookJ_oo07T01_oonfX01_l0oe?ooo]ZoookJ_l0oago0?l8o`3Qo`[ooo]Z00CoolT0
oookJ_oonf[o0?m>1?oonfX5oomi0004o`04oooonf[ooo]Zo`3Do`cooo]Z00?ooh40oookJ_oonfX0
2_oonfX00ooo02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z00Kooo]Z00?oj`3ooookJ_l0o`D0
0_oonfX00ooob@3ooo]ZoookJP1FoookJP05o`0Zoooonf[ooo]ZoookJ_ooDP000_oonfX00onio`3o
oo]ZoookJP0?oookJP03o`1coooonf[ooo]Z01Sooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ooo5P3o
oi80oookJP03oookJP03ool0o?oonf[ooo]Z00Gooo]Z00So603ooookJ_oo1P3oo`H0oookJ_o[o`3o
oo]Zool0mPCooo]Z00Go0:KooookJ_oonf[ooo]ZojP0o`03oookJP;oo`3i00Cooo]Zo`1gool0Mooo
oo]Z0oooK0000ol0oi[ooo]ZoookJP09oookJP;o0?_o??oonfX2oom/00cooo]Z0_oo0?H2oookJP;o
o`H000Go603ooookJ_oonf[ooo]Zool0o003o`0000;ooi801OoonfX2ool0jQ3ooo]Z00?o07?ooook
J_oonfX02?oonfX01?nio`3ooe80oookJ_l0:_l2oookJP04ocoo0?oonf[o0=coogSo00Kooo]Z00Co
08kooa80ool0oa_oolX00ooonfX00ooo09?ooo]Zool04`04oookJP05om[o0?oonf[ooo]ZoookJ_lV
0?l03OoonfX00olao`3ooo]Zo`3oF`03oookJP0>o`3o/?n2o`3ooo]Zo`3Xoooonf[o0?m=o`H0oooo
nf[oo`3eoi;o0?oonf[o403oool0J_l06Ol3oookJP05oaD0oooo057o0:gooookJ_oo07T01_oonfX0
1ol0oe?ooo]ZoookJ_l0oago0?l8oookJ_l0hOl02OoonfX01?l0ocCooo]ZoookJ_l0odh5oookJP05
o`28ool0ZOoooo]ZoookJ_l01?l00_oonfX00ol0e?oooo]ZoookJP0:oookJP03oon10?oonf[ooo]Z
00[ooo]Z00?oo`0]oookJ_oonfX01ooonfX00oooE`3ooo]ZoookJP07oookJP03on/0ool0o`Gooo]Z
00;ooo]Z00?ookh0oookJ_oonfX0:ooonfX002kooo]Z00Go02[ooookJ_oonf[ooo]ZoomB0002oook
JP03okWo0?oonf[ooo]Z00oooo]Z00?o07?ooookJ_oonfX06OoonfX00ooo0>[ooo]ZoookJP08oook
JP03oolF0?oonf[ooi8000Cooo]Z00?oo`3loookJ_oonfX01?oonfX01_lH0?oooo]ZoookJ_oonf[o
o`H0oookJP?oo`0000Coo`3fool00?oonf[oobP00ooonfX00ooo003ooo]Zool00002ool00005oook
J_oo0?Wooo]ZoookJ_oo00003_ooN@02oookJP03oolX0?l0nooo0?_o00;o0?_o6_oonfX8ool000Go
oo]Z1Ooo000:oookJP;oof`03?oonfX01?oo0?Kooo]ZoookJ_oonfX2ool60006oaP0oooonf[ooo]Z
ool00?oo0?coo`000_l00003ool000Gooo]Z00?oo`3ZoookJ_oonfX03ooonfX00ooo:03ooo]Zoook
JP06oookJP?oo`0000Cooe80ool00?oonf[o02[o2Ooo00001ooonf[o08kooa80ool0oa_ooo]Zooo:
0?oonfX00_oo:0000ooo09?oobP0ool04`02oookJPGoo`0000?oolT0ob3o0?oonfX03?oonfX01?oo
003ooo]ZoookJ_l0oe/2oomi0005oh;o0?ooN@3oogT0ool00?l0odd00_oonfX01_l60?ooT_l0ool0
mOoo003o403oool000Cooo]Z00Goo`1AoookJ_l0[Ooooo]Zool0N@06oookJP07o`3oDooonf[ooo]Z
oookJ_l0oago0?l8o`3Qo`0:oookJP04ooo90?oonf[ooo]Zo`3oCP?ooo]Z1_ooN@001?l01?oooo]Z
oookJ_l0e?l;oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX02?oonfX00oooE`3o
oo]ZoookJP06oookJP03on/0ool0o`Gooo]Z00;ooo]Z00?oolT0oookJ_oonfX0E_oonfX01Ol0:_oo
oo]ZoookJ_oonf[ooe8000;ooo]Z00?o^Ol0oookJ_oonfX04?oonfX00ol0Looooo]ZoookJP0Hoook
JP03ool0j_oonf[ooo]Z00Wooo]Z00?ooaH0oonB0?oonfX00ooonfX00ooo0?cooo]ZoookJP05oook
JP05oaP0oooonf[ooo]Zool60?oonfX00_o[o`02ool0mP?ooo]Z00Go0:KooookJ_oonf[ooo]ZojP0
o`04oookJP04ool0nOoonf[ooo]Zo`1go`?ooo]Z0_ooK00<oookJPGo0?_o9_oonfX5o`3ko`[ooo]Z
0_ooK00=oookJP03ool0m_oonf[ooo]Z00;oo`H000?o603ooookJ_oonfX00_oonfX01_oo0?co0000
o`000?l0003ooi80oolF00Gooo]Z00?oo`3ZoookJ_oonfX03ooonfX00ol0Looooo]ZoookJP08oook
JP0:okWo0?ooDP3ooo]ZoookJ_l0:_oooo]Zocoo0?oonf[o0=coogSo00Kooo]Z00Go08kooa80ool0
oa_ooo]Zooo:0002oookJP03ool0Tooonf[oo`0C00Cooo]Z00Kof_l0oookJ_oonf[ooo]ZobH0oon4
0?l=oookJP03oc7o0?oonf[o0?mK00;ooo]Z00[o0?n`oh;o0?l0<?oooo]Zo`3Xool0odgooo]Zo`H0
oooonf[oT_l00_oonfX00ol@0?oo01WooookJP02oookJP05oaD0oooo057o0:gooookJ_oo07T01_oo
nfX02?l0oe?ooo]ZoookJ_oonf[o0?lMo`3o2?oonf[o0>7o2OoonfX01?l0ocCooo]ZoookJ_l0odh4
oookJP03o`28oooonf[o0:Wo00;ooo]Z00Co00CooookJ_oonf[o0=Co3?oonfX00oooP@3ooo]Zoook
JP09oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00?ooeL0oookJ_oonfX01ooonfX01Oo[0?oo0?l5oook
J_oonf[ookh002kooo]Z000^oookJP05o`0Zoooonf[ooo]ZoookJ_ooDP000_oonfX00onio`3ooo]Z
oookJP0@oookJP03o`1coooonf[ooo]Z01Wooo]Z00?oo`3ZoookJ_oonfX02?oonfX00ooo5P3ooo]Z
oonB0004oookJP03ool0o?oonf[ooo]Z00Cooo]Z00Ko603ooookJ_oonf[ooo]Zool60?oonfX5ool0
0003oookJ_oo:03ooo]Z00;ooo]Z0ooo0003oookJP;oo`3i00?ooo]Zool00?oo00003?ooN@07oook
JPSo0?_o3ooonfX@ool000gooo]Z0_ooK00<oookJP;oo`3f0ooonfX00ooo1P3o603ooaP0o`03oook
JP03ool0o?oo003oo`0000?oo`0000?o0000oookJ_oonfX00ooonfX00ooo0>[ooo]ZoookJP0>oook
JP03o`1coooo:03ooo]Z00Sooo]Z0_oo00001OooDP3ooo]ZoookJ_l0:_oooo]Z00Ooo`000ooonfX0
1Ol0S_oo0?lKoookJ_oobP3ooo]Z00;oobP000?oo`2CoolX0?oo01<00ooonfX4ool00003ooo90?oo
:03o8?l000gooo]Z00Koo`00oookJ_l0oe_ooo]Zoomi0?n2o`03oomi0006o`3oCOooN@3oogT0o`H0
oooo003oT_l00_oo00000ol@0?ooo`1ZoookJP02oookJP03ool00?oo057o0:go00;ooo]Z00?oo`1i
oookJ_oonfX01?oonfX01_l0oe?ooo]ZoookJ_l0oago0?l8o`3Qo`[ooo]Z00CoolT0oookJ_oonf[o
0?m>1?oonfX5oomi0004o`04oooonf[ooo]Zo`3Do`cooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo
02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z00Kooo]Z00?oL03oon/0ool0o`D00_oonfX00ooo
b@3ooo]ZoookJP1HoookJP04o`0Zoooonf[ooo]ZoomB00?ooo]Z00?o^Ol0oookJ_oonfX04?oonfX0
0ol0Looooo]ZoookJP0HoookJP03ool0j_oonf[ooo]Z00Wooo]Z00?ooaH0oonB0?oonfX00ooonfX2
ool0o0Kooo]Z00Co603ooookJ_oonf[oo`H00_oonfX01?o[o`3ooo]Zool0m_oo0?H2oookJP05o`2V
oooonf[ooo]ZoookJ_nX0?l01?oonfX2ool0n@03oookJ_l0Mooo07Oo00?ooo]Z0oooK00>oookJPSo
0?_o5_oonfX8o`3ko`gooo]Z0_ooK00=oookJP;oo`3f0_oonfX00ooo1P3o603ooaP0o`04oookJP06
ool0o?oonf[o0000o`000?ooTP3ooaH01OoonfX00ooo0>[ooo]ZoookJP0>oookJP;o07?o2_oonfX0
2_nio`3ooe80oookJ_oonf[o02[ooookJ_loo`3ooo]Zo`3Loomho`06oookJP05o`2>oolB0?oo0?lK
oookJ_oobP000_oonfX00ooo09?o0?Woool04`05oookJP05om[o0?oonf[ooo]ZobH0oolPo`003Ooo
nfX00olao`3ooo]Zo`3oF`02oookJP0>o`3o/?n2o`3o033ooookJ_l0j?oo0?m=oookJ_l60?oooo]Z
ool0mOnBo`3ooo]Zoa00ool06Ol3oookJP06oaD0oooonf[oo`1Ao`2]oooonf[oo`1i1_oonfX01ol0
oe?ooo]ZoookJ_l0oago0?l8oookJ_l0hOl02OoonfX01?l0ocCooo]ZoookJ_l0odh5oookJP03o`28
oooonf[o0:Wo00;ooo]Z00?o00CooookJ_l0e?l03?oonfX00oooP@3ooo]ZoookJP0:oookJP03ool0
;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX01ooonfX00om`0?ooj`3ooookJP02oookJP03oonn
0?oonf[ooo]Z02cooo]Z000_oookJP07o`0Zoooonf[ooo]ZoookJ_ooDP3ooo]ZokWo000CoookJP03
o`1coooonf[ooo]Z01Sooo]Z00?oo`3ZoookJ_oonfX02OoonfX00ooo5P3ooo]ZoonB0004oookJP;o
o`3l1OoonfX01?lH0?oooo]ZoookJ_oonfX2ool600Soo`000ooonfX00ooo003ooo]ZoookJP03oook
JP;oo`3i00?ooo]Zool00?ooN@002OooN@0@oookJPSo0?_o1?oonfX?ool000oooo]Z0_ooK00=oook
JP04ool0m_oonf[ooo]ZoookJP;oo`H000?o603ooookJ_oonfX00_oonfX00ooo0?coo`00ool00003
ool000;o00001?oonfX00ooo0>[ooo]ZoookJP0>oookJP03o`1coooonf[ooo]Z00Sooo]Z0_oo0000
1OooDP3ooo]ZoookJ_l0:_oooo]Z00Ooo`000ooonfX01?l0S_oo0?lKoookJ_oobP02oookJP;oobP0
00?oo`2Cool04ooonfX00ooonfX3ool00003oookJ_oob@3o8?l000gooo]Z00?oo`00oookJ_l0oe/0
0_oonfX03OooN@3oP_l0oomi0?ooN@3oo`00o`3oCOooN@3o1P3oool00?nBo`3oo`3eool00?l@0?l0
0ooo0002oookJP05ool0DOoonf[o0:gooookJ_oo07T01_oonfX01ol0oe?ooo]ZoookJ_oonf[o0?lM
o`3o2?l0hOl02_oonfX01?oob@3ooo]Zo`3o;_l0odh4oookJPGoogT000Co00CooookJ_oonf[o0=Co
2ooonfX00oooP@3ooo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX0
1_oonfX00oo[0?oooo]Zo`3o1@02oookJP03ooo90?oonf[ooo]Z05Sooo]Z00Go02[ooookJ_oonf[o
oo]ZoomB0002oookJP03okWo0?oonf[ooo]Z017ooo]Z00?o07?ooookJ_oonfX05ooonfX00ooo0>[o
oo]ZoookJP0:oookJP03oolF0?ooTP3ooo]Z00Cooo]Z00?oo`3loookJ_oonfX01?oonfX00olH0?oo
oo]ZoookJP02ool60005oookJ_o[o`3ojol0oookJ_oo0?H00_oonfX2o`2Vo`;ooo]Z0_nX0?l4oook
JP;oo`3i00?ooo]Zo`1goooonfX00ooonfX01?l0oi[oof`0oom/0?ooK00CoookJPOo0?_o1ooonfX8
o`3koa?ooo]Z0_ooK00>oookJP03ool0m_oonf[ooo]Z00;oo`H000?o603ooookJ_oonfX00ooonfX0
0ooo0?cooo]ZoookJP02oonB00;o00001?oonfX00ooo0>[ooo]ZoookJP0>oookJP03o`1coooonf[o
oo]Z00[ooo]Z00Wooe80oookJ_oonf[o02[ooookJ_loo`3ooo]Zo`3Loomho`001ooonfX01?lB0?oo
0?lKoookJ_oobP03oookJP03ool0Tooo01?ooo]Z00Cooo]Z00Gof_l0oookJ_oonf[ooo]ZobH0o`0>
oookJP03oc7o0?l0oe_ooo]Z00;ooo]Z00Oo0?n`oh;o0?l0<?oooo]Zo`3Xool0odgo1P3o00;ooo]Z
00GoT_l0oookJ_oonf[o403oo`0Io`03oookJP05oaD0oooo057o0:gooookJ_oo07T01_oonfX02?l0
oe?ooo]ZoookJ_oonf[o0?lMo`3o2?oonf[o0>7o2OoonfX01?l0ocCooo]Zo`3o;_l0odh4oookJP03
o`28oooonf[o0:Wo00;ooo]Z00Co00CooookJ_oonf[o0=Co3?oonfX00oooP@3ooo]ZoookJP0:oook
JP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX01ooonfX00oo[0?oo0?l5oookJP02oook
JP03oonn0?oonf[ooo]Z02cooo]Z000ZoookJP03ocoo0?oonf[ooo]Z00;ooo]Z00Go02[ooookJ_oo
nf[ooo]ZoomB0002oookJP03okWo0?oonf[ooo]Z017ooo]Z00?o07?ooookJ_oonfX06?oonfX00ooo
0>[ooo]ZoookJP09oookJP03oolF0?oonf[ooi8000Gooo]Z00?oo`3loookJ_oonfX00ooonfX00olH
0?oooo]ZoookJP02oookJP03ool60?oo003oo`0000Soo`0000?ooo]Zool00?oonfX01OoonfX01?oo
0?Wooo]Zool00?oonfX8oomi01Sooo]Z0ol0nol@ool000cooo]Z0oooK00=oookJP;oo`3f0_oonfX2
ool600;o603o0ooonfX2ool0o0Ooo`000_l00002oookJP03ool0j_oonf[ooo]Z00kooo]Z00?o07?o
oookJ_oonfX02OoonfX01Ooo003ooe80oookJ_oonf[o02[o00;ooo]Z1_oo0003oookJP04o`2>ool0
oa_ooo]Zooo:00?ooo]Z00CoobP0ool0Tooo:03oo`0C1?oonfX2ool00003oookJ_oob@3o8?l000go
oo]Z00Coo`00oookJ_oonf[o0?mK0_oonfX01On2o`3oogT0oomi0?ooN@3o0?m=00;oogT000Oo1P3o
ool00?nBo`3oo`00oa00oooo003oo`1Z00Coo`0000Goo`1Ao`2]oooonf[ooo]Zool0N@06oookJP06
o`3oDooonf[ooo]Zo`3o7Ol0o`So0>7o2_oonfX01?oob@3ooo]ZoookJ_l0odh4oookJP03o`28oooo
N@3oogT000;oogT000Co00CooookJ_oonf[o0=Co3?oonfX00oooP@3ooo]ZoookJP0:oookJP03ool0
;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX01ooonfX00oo[0?oo0?l5oookJP02oookJP03ooo9
0?oonf[ooo]Z05?ooo]Z00?o?ol0oookJ_oonfX00ooonfX01?l0:_oooo]ZoookJ_ooDP03oookJP03
okWo0?oonf[ooo]Z013ooo]Z00?o07?ooookJ_oonfX06?oonfX00ooo0>[ooo]ZoookJP0:oookJP03
oolF0?ooTP3ooo]Z00Cooo]Z00?oo`3loookJ_oonfX01?oonfX01OlH0?oooo]ZoookJ_oonf[oo`H0
00;ooo]Z0_o[o`02ool0mP;ooo]Z0_l0Y_l2oookJP03ojP0oooonf[ooo]Z00?ooo]Z00?oo`3ioook
J_l0Mol01OoonfX2o`3oVP;oof`06?oonfX7o`3koaSooo]Z0oooK00>oookJP;oo`3f00?ooo]Zool6
0?oo1P000_lH0?l4oookJP;oo`3l0_oonfX00oooTP3ooaH0o`000003o`0000;ooo]Z00?oo`3Zoook
J_oonfX03_oonfX00ol0Looooo]ZoookJP0:oookJP04oomB0?l0oc?ooo]Zo`0Zo`;ooo]Z00Co?ol0
o`3Loomho`3o?@3o1_oonfX01?l0S_oo0?lKoookJ_oobP03oookJP03ool0Tooonf[oo`0C00Cooo]Z
00KohOl0om[o0?oonf[ooo]ZobH0oon40?l=oookJP03oc7o0?oonf[o0?mK00;ooo]Z00ko0?n`oh;o
0?l0<?oooo]Zo`3Xool0odgooo]Zo`H0oooonf[oo`3eoi;o0?oonf[o403oo`0Io`?ooo]Z00Ko5@3o
oookJ_oo057o0:gooookJ_oo07T6oookJP07o`3oDooonf[ooo]Zo`3o7Ol0o`Sooo]Zo`3Qo`09oook
JP04o`3o=?oonf[ooo]Zo`3oCPGooo]Z00?o08SooookJ_l0ZOl00_oonfX00ol01?oooo]Zo`3Do`0<
oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX01ooonfX00oooE`3ooo]ZoookJP08
oookJP05on/0ool0o`Gooo]ZoookJ_oo_P00;ooonfX002[ooo]Z00?o?ol0oookJ_oonfX00_oonfX0
2?l0:_oooo]ZoookJ_oonf[ooe80ooo90?oonf[o^Ol04ooonfX00ol0Looooo]ZoookJP0IoookJP03
ool0j_oonf[ooo]Z00Wooo]Z00?ooaH0oookJ_ooTP001OoonfX00ooo0?cooo]ZoookJP03oookJP03
oaP0oooonf[ooo]Z00;ooo]Z0_oo1P0;ool000Kooo]Z0_oo0?T00ooo003ooo]Zoomi0008oomi00_o
oo]Z1Ooo000>oookJP_oo`001ooonfX5oom/00kooo]Z0_oo0?H3oookJP03ool60?oonf[o603o00?o
oo]Z0_oo0?`:ool000;ooo]Z00?oo`3ZoookJ_oonfX03_oonfX00ol0Looooo]ZoookJP0:oookJP04
oomB0?oonf[ooo]Zo`0Zo`;ooo]Z0ooo00000ol0omooo`00oookJP03oookJP04o`2>ool0oa_ooo]Z
ooo:00Cooo]Z00?oo`2CoolX0?oo01<00ooonfX01_oo:03oo`00ool00?oonf[oolT0ob3o00kooo]Z
00?oo`00oookJ_l0oe/00_oonfX01On2o`3oogT0oomi0?ooN@3o0?m=00;oogT000Ko1P3ooookJ_nB
o`3oobP0ool00?l@0?l5ool00005ool0DOoonf[o0:gooookJ_oo07T01_oonfX01_l0oe?ooo]Zoook
J_oonf[o0?lMo`3Qo`_ooo]Z00CoolT0oookJ_l0obko0?m>1?oonfX02?l0R?ooogT0oomi0?ooN@3o
oo]Zo`04oooonf[o0=Co3OoonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z00Oooo]Z
00?ooeL0oookJ_oonfX01_oonfX00oo[0?oooo]Zo`3o1@02oookJP03ooo90?oonf[ooo]Z05Cooo]Z
00?o?ol0oookJ_oonfX00ooonfX01?l0:_oooo]ZoookJ_ooDP03oookJP03okWo0?oonf[ooo]Z017o
oo]Z00?o07?ooookJ_oonfX06?oonfX00ooo0>[ooo]ZoookJP0:oookJP03oolF0?ooTP3ooo]Z00Co
oo]Z0_oo0?`5oookJP04oaP0oooonf[ooo]ZoookJP;oo`H00_oonfX01?o[o`3ooo]Zool0m_oo0?H2
oookJP;o0:Ko00?ooo]ZojP0oooonfX01?oonfX2ool0n@03o`1goooonf[ooo]Z00Cooo]Z0_l0oiX3
oom/02oooo]Z1OooK00?oookJP;oo`3f0_oonfX00ooo1P3ooo]ZoaP0o`04oookJP;oo`3l0ooonfX0
0oooTP3ooaH0o`000003o`0000;ooo]Z00?oo`3ZoookJ_oonfX03_oonfX00ol0Looooo]ZoookJP0:
oookJP04oomB0?l0oc?ooo]Zo`0Zo`;ooo]Z00Co?ol0o`3Loomho`3o0?oO1_oonfX01?l0S_oo0?lK
oookJ_oobP03oookJP03ool0Tol0nOooo`0C00Cooo]Z00KohOl0om[o0?oonf[ooo]ZobH0oon40?l=
oookJP03oc7o0?oonf[o0?mK00;ooo]Z00So0?n`oh;o0?oonf[o033ooookJ_l0odgooo]Zo`H0o`;o
oo]Z00GoT_l0oookJ_oonf[o403oo`0Io`03oookJP05oaD0oooo057o0:gooookJ_oo07T01_oonfX0
1ol0oe?ooo]ZoookJ_oonf[o0?lMoookJ_l0hOl02_oonfX01?l0ocCooo]Zo`3o;_l0odh4oookJP03
o`28oooonf[o0:Wo00;ooo]Z00Co00CooookJ_oonf[o0=Co3?oonfX00oooP@3ooo]ZoookJP0:oook
JP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX01ooonfX00oo[0?oo0?l5oookJP02oook
JP03oonn0?oonf[ooo]Z02gooo]Z000ZoookJP03odCo0?loo`3ooo]Z00?ooo]Z00So02[ooookJ_oo
nf[ooo]ZoomB0?oob@3ooo]ZokWo01?ooo]Z00?o07?ooookJ_oonfX06OoonfX00ooo0>[ooo]Zoook
JP09oookJP03oolF0?oonf[ooi8000Gooo]Z0_oo0?`4oookJP?oogT00ooonfX00ooo1P3oo`00ool0
0007ool00003o`2Voooo003ooo]Z00Kooo]Z00?oo`3ioookJ_oonfX01OooN@02o`3oVP04oookJ_oo
N@3oogT0oookJPgoo`005OoonfX4ool000;ooo]Z1OooK00BoookJP04ool0m_oonf[ooo]ZoookJP;o
o`H00_lH0?l3oookJP03ool0o?oonf[oo`0000[oo`000_oo0>X@oookJP03o`1coooonf[ooo]Z00Wo
oo]Z00?o^Ol0ool00?ooDP000_oonfX00ol0:_oooo]Zool00002ool00003o`3ogooo003ooo]Z00?o
oo]Z00Go08kooookJ_l0oa_ooo]Zooo:0003oookJP03ool0Tooo:03oo`0C00Cooo]Z00KoobP0ool0
0?oo:03oolT0oookJ_lPo`0=oookJP04ool00?oonf[ooo]Zo`3oF`;ooo]Z00OoP_l0oomi0?ooN@3o
ogT0o`3oCOooN@3o1P3o00;ooo]Z00?oT_l0ool00?l@0?l01_oo00001?oo057o0:gooookJ_oo07T7
oookJP06o`3oDooonf[ooo]Zo`3o7Ol0o`So0>7o2_oonfX01?oob@3ooo]ZoookJ_l0odh4oookJP03
o`28oooonf[oogT000;oogT000Co00CooookJ_oonf[o0=Co3?oonfX00oooP@3ooo]ZoookJP0:oook
JP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX01ooonfX00oo[0?oo0?l5oookJP02oook
JP03ooo90?oonf[ooo]Z05Gooo]Z00?o?ol0oookJ_oonfX00_oonfX01Ol0:_oooo]ZoookJ_oonf[o
oe8000;ooo]Z00?o^Ol0oookJ_oonfX04_oonfX00ol0Looooo]ZoookJP0HoookJP03ool0j_oonf[o
oo]Z00[ooo]Z00?ooaH0oonB0?oonfX01OoonfX00ooo0?cooo]ZoookJP03oookJP;o603o0ooonfX0
0ooo1P3ooo]ZoookJP02on_o0003oookJ_oo0?Kooo]Z00;ooo]Z0_l0Y_l00onX0?oooo]ZoookJP04
oookJP03ool0nOoonf[ooo]Z00Kooo]Z0_l0oiX00ooonf[oof`0oom/000XoookJPGoof`04ooonfX0
0ooo0?Kooo]ZoookJP02ool600;o603o0ooonfX2ool0o0Cooo]Z00?ooi80oolF0?oonfX01?l00002
ool0jQ3ooo]Z00?o07?ooookJ_oonfX02OoonfX2okWo0009oomB0?oonf[ooo]Zo`0Zoooonf[o?ol0
o`3Loomho`3o0?oO00Kooo]Z00Go08koo`3o6ooonf[ooo]Zooo:0002oookJP03ool0Tol0nOooo`0C
00Gooo]Z00Gof_l0oookJ_oonf[o9P3oob3o000>oookJP03oc7o0?oonf[o0?mK00;ooo]Z00ko0?n`
oh;o0?l0<?oooo]Zo`3Xool0odgooo]Zo`H0oooonf[oo`3eoi;o0?oonf[o403oo`0Io`?ooo]Z00Go
5@3ooookJ_oo057o0:goool0N@07oookJP07o`3oDooonf[ooo]Zo`3o7Ol0o`Sooo]Zo`3Qo`09oook
JP04o`3o=?oonf[ooo]Zo`3oCPGooo]Z00?o08SooookJ_l0ZOl00_oonfX00ol01?oooo]Zo`3Do`0<
oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX02?oonfX00oooE`3ooo]ZoookJP07
oookJP05on/0ool0o`Gooo]ZoookJ_oo_P00<?oonfX002[ooo]Z0_m4o`001Oloo`3ooo]ZoookJ_oo
nf[o02[o00?ooo]Z00Cooe80ooo90?oob@3o^Ol05?oonfX00ol0Looooo]ZoookJP0HoookJP03ool0
j_oonf[ooo]Z00[ooo]Z0_oo5P000oooTP3ooo]ZoookJP04oookJP03ool0o?oonf[ooo]Z00?ooo]Z
1OooN@02ool600Koo`000ooonfX2o`2Vo`Kooo]Z6_oo000FoookJPGoof`05OoonfX2oiCo00;ooo]Z
0_oo1P000ooonf[o603ooookJP02oookJP;oo`3l00?ooo]Zool00?oo00002Ooo00000ooo0>[ooo]Z
oookJP0?oookJP03o`1coooonf[ooo]Z00Wooo]Z00?o^Ol0oookJ_ooDP000_oonfX00ol0:_oooo]Z
ool00002ool00003o`3ogooo003ooo]Z00Cooo]Z00Co08koo`3o6ooonf[oolX01?oonfX00ooo09?o
o`0CoookJP03oookJP;oobP000Cof_l0oolX0?oob@3o8?l03_oonfX00ooo003ooo]Zo`3oF`02oook
JP0:oh;o0?ooN@3oogT0oomi0?l0odgoogT0oookJ_l60?oooo]Zoi;o00;oo`0000?o403oool0J_oo
00000ooo00001Ooo057ooo]Zo`2]oooonf[oo`1i00Kooo]Z00Ko0?mCoookJ_oonf[ooo]Zo`3o7Ol0
hOl;oookJP03ooo90?oonf[o0?m>00Gooo]Z00So08SooookJ_ooN@3oogT0oookJ_l01?oooo]Zo`3D
o`gooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z
00Kooo]Z00?oL03oon/0ool0o`D00_oonfX00ooob@3ooo]ZoookJP1GoookJP03ocoo0?oonf[ooo]Z
00;ooo]Z00Go02[ooookJ_oonf[ooe80o`3o<`02oookJP03okWo0?oonf[ooo]Z017ooo]Z00?o07?o
oookJ_oonfX06?oonfX00ooo0>[ooo]ZoookJP0;oookJP03oolF0?ooTP3ooo]Z00Gooo]Z00?oo`3l
oookJ_oonfX01?oonfX2oaP0o`;ooo]Z0_oo1P02oookJP;ojol00_oo0?H4oookJP;o0:Ko1OoonfX3
ool0n@Oooo]Z0ol0oiX3oom/023ooo]Z1OooK00FoookJP;oo`3f00Gooo]Zool60?oo1P3ooo]ZoaP0
o`04oookJP03ool0o?oonf[ooo]Z00;ooo]Z0_ooTP03oookJP?o000000?oo`3ZoookJ_oonfX03ooo
nfX00ol0Looooo]ZoookJP09oookJP03okWo0?oonf[ooe8000;ooo]Z00Oo02[ooookJ_loo`3ooo]Z
ogSo0?l0omoo?@3o00Gooo]Z00Go08kooa80ool0oa_ooo]Zooo:0003oookJP03ool0Tooo01?ooo]Z
00Cooo]Z00KohOl0om[o0?oonf[ooo]ZobH0oon40?l=oookJP03oc7o0?oonf[o0?mK00;ooo]Z00_o
0?n`oh;o0?l0<?oo0?nao`3Xool0odgooo]Zo`H0oooonf[oo`3eoi;o0002oookJP0:oa00oooonf[o
oo]ZoookJ_lE0?oooo]Zool0DOl0[Ooooo]Zool0N@Kooo]Z00Oo0?mCoookJ_oonf[ooo]Zo`3o7Ooo
nf[o0>7o00[ooo]Z00?o0?ldoookJ_l0odh01OoonfX01_l0R?oooo]ZoookJ_l0ZOoooo]Zo`04o`;o
oo]Z00?o0=CooookJ_oonfX02_oonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z00Oo
oo]Z00?ooeL0oookJ_oonfX01ooonfX00om`0?ooj`3oo`3o1@02oookJP03oonn0?oonf[ooo]Z02ko
oo]Z000ZoookJP?oA?l00ooonfX01Ol0:_oooo]ZoookJ_oonf[ooe8000?oolT05OoonfX00ol0Looo
oo]ZoookJP0HoookJP03ool0j_oonf[ooo]Z00_ooo]Z00?ooaH0oonB0?oonfX01OoonfX00ooo0?co
oo]ZoookJP03oookJPGoogT000?oo`00ool60?oo00001?oo0002ool0mP?ooo]Z0_l0Y_l6oookJPko
o`003OooK00>oookJPGoof`03OoonfX2oiCo00Sooo]Z0onDo`03oookJP04ool60?oonf[o603ooaP0
o`;ooo]Z0_oo0?`3oookJPSoo`000_l000000ooo0>[o0000oookJP0>oookJP;o07?o2ooonfX00oni
o`3ooo]ZoomB0002oookJP04o`0Zoooonf[oo`00oookJP;oo`001_oonfX01?l0S_oo0?lKoookJ_oo
bP04oookJP03ool0Tooo01?ooo]Z00Cooo]Z00GoobP0om[o0?oo:03oolT0ob3o0003oolX00_ooo]Z
00?oo`00oookJ_l0oe/00_oonfX2ool000;oogT000Co0?m=ool00?oonf[o1P3o0_oonfX00onBo`3o
o`00oa00o`04ool00006oookJ_oo003oo`1Ao`2]oooonf[oo`1i1ooonfX01_l0oe?ooo]ZoookJ_l0
oago0?l8o`3Qo`[ooo]Z00CoolT0oookJ_oonf[o0?m>1?oonfX01_l0R?oooo]ZoookJ_ooN@3ooo]Z
o`04o`;ooo]Z00?o0=CooookJ_oonfX02_oonfX00oooP@3ooo]ZoookJP0;oookJP03ool0;Ooonf[o
oo]Z00Kooo]Z00?ooeL0oookJ_oonfX01ooonfX00oo[0?oooo]Zo`3o1@02oookJP03ooo90?oonf[o
oo]Z05Gooo]Z00?o0=cooookJ_loo`001?oonfX01Ol0:_oooo]ZoookJ_ooDP3o0?lc00;ooo]Z00?o
^Ol0oookJ_oonfX04_oonfX00ol0Looooo]ZoookJP0HoookJP03ool0j_oonf[ooo]Z00cooo]Z00?o
oi80oookJ_oonfX01?oonfX2ool0o0Kooo]Z0_lH0?l2oookJP06ool60?oonf[ooo]ZoookJ_o[o`3o
oo]Z0_oo0?H4oookJP;o0:Ko1_oonfX4ool0n@Sooo]Z00?o0?nJoom/0?ooK0002oooK00>oookJPGo
of`06?oonfX3ool0mP;ooo]Z00Coo`H0oookJ_lH0?oo603o0ooonfX2ool0o0Cooo]Z00?ooi80oolF
0?oonfX00ooonfX2o`000003ool0j_l0003ooo]Z00oooo]Z00?o07?ooookJ_oonfX02OoonfX00oni
o`3ooo]ZoomB0002oookJP07o`0Zoooonf[o?ol0oookJ_l0g?ooN?l0ocd0o`05oookJP05o`2>oooo
nf[o0?lKoookJ_oobP000ooonfX00ooo09?oo`0CoookJP04oookJP06on7o0?oJo`3ooo]ZoookJ_lV
0?ooQ03o3_oonfX03?lao`3o0?mKoookJ_oonf[o0?n`oh;o0?oonf[o033oo`3o/Ol0odgooo]Zo`H0
o`;ooo]Z00Goo`3eoi;o0?oonf[o403oo`0Io`03oookJP05oaD0oooonf[oo`1Ao`2]oooo07T01ooo
nfX01ol0oe?ooo]ZoookJ_l0oago0?l8oookJ_l0hOl02OoonfX01?l0ocCooo]ZoookJ_l0odh5oook
JP03o`28oooonf[o0:Wo00;ooo]Z00?o00CooookJ_l0e?l03?oonfX00oooP@3ooo]ZoookJP0;oook
JP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX01ooonfX00oo[0?oo0?l5oookJP02oook
JP03oonn0?oonf[ooo]Z02kooo]Z000ZoookJPCoA?l00ooonfX01Ol0:_oooo]ZoookJ_oonf[ooe80
00?oolT05?oonfX00ol0Looooo]ZoookJP0IoookJP03ool0j_oonf[ooo]Z00_ooo]Z00?ooaH0oonB
0?oonfX01OoonfX00ooo0?cooo]ZoookJP03oookJPGoogT000?oo`00ool60?oo1P001?oo00000ooo
nf[oo`3foookJP03oookJP;o0:Ko1_oonfXIool000koof`04OoonfX3oiCo00Gooo]Z0onDo`04oook
JP;oo`H00_lH0?l2oookJP;oo`3l1?oonfX7ool000;ooo]Z00Co0000ool0j_l0003o00003_oonfX0
0ol0Looooo]ZoookJP0:oookJP03okWo0?oonf[ooe8000;ooo]Z00Ko02[ooookJ_oo003ooo]Zo`3L
oooo0006oookJP04o`2>ool0oa_o4P3oooo:00Cooo]Z00?oo`2Co`3ioooo01<01?oonfX01OoQo`3o
f_l0oolX0?oob@3o8?l000GoobP02OoonfX01?oo003ooo]ZoookJ_l0oe/2oookJP?oo`0000CoogT0
o`3oCOoonf[o1P3o0_oonfX01?nBo`3oo`00ool00?l@0?l3ool00007oookJ_oo003oo`1AoookJ_l0
[Ooooo]Zool0N@07oookJP05o`3oDooonf[ooo]Zo`3o7Ol0hOl02ooonfX00ooob@3ooo]Zo`3oCP05
oookJP08o`28oooonf[ooo]Zo`2Yoooonf[o00CooookJ_l0e?l=oookJP03oon10?oonf[ooo]Z00[o
oo]Z00?oo`0]oookJ_oonfX01ooonfX00oooE`3ooo]ZoookJP07oookJP03on/0ool0o`Gooo]Z00;o
oo]Z00?oolT0oookJ_oonfX0EOoonfX01?l0g?oooo]ZoookJ_loo`04oookJP05o`0Zoooonf[ooo]Z
oomB0?l0oc<00_oonfX00onio`3ooo]ZoookJP0BoookJP03o`1coooonf[ooo]Z01Sooo]Z00?oo`3Z
oookJ_oonfX03?oonfX00oooTP3ooo]ZoookJP05oookJP03ool0o?oonf[ooo]Z00Gooo]Z00?o603o
oookJ_oonfX00_oo1P02oookJP;ojol000?ooo]Zool0m_oonfX01?oonfX2o`2Vo`Sooo]Z1?oo0?T<
oookJPKo0?nJ3_ooK00JoookJP?oo`3f0ooonfX2ool600;o603o0ooonfX2ool0o0Gooo]Z00?ooi80
oolF0?oonfX01?oonfX01?l0003oo`3Zo`000?l0000?oookJP03o`1coooonf[ooo]Z00Wooo]Z00?o
^Ol0oookJ_ooDP000_oonfX01ol0:_oooo]Zocoo0?oonf[o0=coogSo0?lm0?l01_oonfX01?l0S_oo
0?lKoookJ_oobP03oookJP03ool0Tol0nOooo`0C00Cooo]Z00KohOl0om[o0?oonf[ooo]ZobH0oon4
0?l>oookJP03oc7o0?oonf[o0?mK00;ooo]Z00ko0?n`oh;o0?l0<?oo0?nao`3Xool0odgooo]Zo`H0
oooonf[oo`3eoi;o0?oonf[o403oo`0Io`?ooo]Z00Ko5@3ooookJ_oo057o0:gooookJ_oo07T7oook
JP06o`3oDooonf[ooo]Zo`3o7Ooonf[o0>7o2_oonfX00ol0ocCooo]Zo`3oCP05oookJP06o`28oooo
nf[ooo]Zo`2Yoooonf[o00Co0_oonfX00ol0e?oooo]ZoookJP0:oookJP03oon10?oonf[ooo]Z00[o
oo]Z00?oo`0]oookJ_oonfX01ooonfX00oooE`3ooo]ZoookJP08oookJP05on/0ool0o`Gooo]Zoook
J_oo_P00<OoonfX002[ooo]Z1Om4o`02oookJP05o`0Zoooonf[ooo]ZoookJ_ooDP001?oob@0Doook
JP03o`1coooonf[ooo]Z01Sooo]Z00?oo`3ZoookJ_oonfX03?oonfX00ooo5P3ooi80oookJP05oook
JP;oo`3l1?oonfX5oomi00;oo`0000Coo`H0ool00?ooN@3oogT00_oo0002ool0mPCooo]Z0_l0Y_l6
oookJQ?oo`001_oonfX4ool001Oooo]Z1_nDo`001?oonf[oU?l0oiCo0?nDo`05oookJP;oo`H000?o
603ooookJ_oonfX00_oonfX00ooo0?cooo]ZoookJP03oookJPGoo`001OoonfX01?oo0>[o0000o`00
0?l0000=oookJP03o`1coooonf[ooo]Z00[ooo]Z00Co^Ol0oookJ_ooDP3oo`000_ooN@001_oonf[o
o`00oookJ_l0g?ooo`00o`3og`Gooo]Z00Co08koo`3o6olB0?ooolX01?oonfX00ooo09?o0?Woool0
4`05oookJP05om[o0?oo:03oolT0oolX0?lPo`000ooo:00;oookJP03ool00?oonf[o0?mK00;ooo]Z
00koP_l0ool00?oo003oo`00o`3oCOoo003ooo]Zo`H0oooonf[oobP0oi;o0?oo003o403oool0JP;o
o`000_oonfX01Ooo057ooo]Zo`2]oooonf[oo`1i00Oooo]Z00Ko0?mCoookJ_oonf[o0?lMoookJ_l0
hOl:oookJP04ooo90?oonf[ooo]Zo`3oCPCooo]Z00Ko08SooookJ_oonf[o0:WooookJ_l01?l2oook
JP03o`3Doooonf[ooo]Z00[ooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP07oook
JP03oomG0?oonf[ooo]Z00Kooo]Z00?oj`3ooookJ_l0o`D00_oonfX00ooob@3ooo]ZoookJP1Goook
JP03o`3Loooonf[o?ol000Cooo]Z00So02[ooookJ_oonf[ooe80oookJ_l0oc?ooo]ZokWo01Gooo]Z
00?o07?ooookJ_oonfX05ooonfX00ooo0>[ooo]ZoookJP0=oookJP03oonB0?oonf[ooo]Z00Gooo]Z
00?oo`3loookJ_oonfX01OoonfX2oaP0o`;ooo]Z00Coo`H0oookJ_oonf[ooo]Z0_o[o`02ool0mPGo
oo]Z0_l0Y_l:oookJPGoo`3i3ooonfX4o`3oVQoooo]Z0ooo0?H4oookJP;oo`H000?o603ooookJ_oo
nfX00_oonfX2ool0o0Gooo]Z0_ooTP07oookJP04ool0j_l0003o0000o`0000gooo]Z0_l0Lol;oook
JP04okWo0?oonf[ooe80o`3o<`;o02[o00Kooo]Zocoo0?oonf[o0=coogSo0?l0oml6oookJP04o`2>
ool0oa_ooo]Zooo:00?ooo]Z00?oo`2Co`3ioooo01<01OoonfX01_oJo`3ooo]ZoookJ_lV0?oo8?l0
oh@0o`gooo]Z00?o<Ol0oookJ_l0oe/00_oonfX03_l0ok3oP_l0oookJ_l0<?oooo]Zo`3oCOoonf[o
1P3ooookJ_oo0?Gooo]Zoi;o0?oonf[o403o1?oonfX01OlE0?ooo`1AoookJ_l0[Oooo`1i00Oooo]Z
00Co0?mCoookJ_oonf[o0?lM0_oonfX00ol0hOoooo]ZoookJP07oookJP04o`3o=?oonf[ooo]Zo`3o
CPGooo]Z00?o08SooookJ_l0ZOl00_oonfX00ol01?oooo]Zo`3Do`0<oookJP03oon10?oonf[ooo]Z
00_ooo]Z00?oo`0]oookJ_oonfX01ooonfX00oooE`3ooo]ZoookJP07oookJP03on/0ool0o`Gooo]Z
00;ooo]Z00?ookh0oookJ_oonfX0;ooonfX002[ooo]Z1_m4o`02oookJP05o`0Zoooonf[ooo]Zooo9
0?ooDP001?oob@0DoookJP03o`1coooonf[ooo]Z01Sooo]Z00?oo`3ZoookJ_oonfX03?oonfX00ooo
5P3ooi80oookJP06oookJP03ool0o?oonf[ooo]Z00;ooo]Z1OooN@02ool00003ool60?ooN@3oogT0
00;ooo]Z00Coo`00oookJ_oo0?Koo`3f1?oonfX3o`2Vo`Gooo]Z4Ooo000OoookJPWoU?l01_oonfX0
0olH0?ooo`H0oaP0o`04oookJP;oo`3l1OoonfX4ool000Gooo]Z0_oo:004o`0000cooo]Z00?o07?o
oookJ_oonfX02_oonfX03?nio`3ooe80oomB0?l0oc?oogT0ool00?oonf[oo`00oookJ_l0g?ooo`00
o`3og`Kooo]Z00?o0?lKoa80oooobP001OoonfX00ooo09?oo`0CoookJP04oookJP05om[o0?oo:03o
obP0ooo90?lPo`000ooo:007oookJP;oo`000_oonfX01_oo003ooo]ZoookJ_l0oe_ooo]Zoh;o00?o
o`0000Co0?m=ool00?oo003oo`000_oonfX01?nBo`3ooo]Zool00?l@0?l2ool000;ooo]Z00Koo`00
ool0DOoonf[o0:gooookJ_oo07T7oookJP05o`3oDooonf[ooo]Zo`3o7Ol0hOl02ooonfX00ooob@3o
oo]Zo`3oCP05oookJP08o`28oooonf[ooo]Zo`2Yoooonf[o00CooookJ_l0e?l=oookJP03oon10?oo
nf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX01ooonfX00oooE`3ooo]ZoookJP07oookJP03on/0oooo
nf[o0?l500;ooo]Z00?oolT0oookJ_oonfX0F?oonfX00ol0g?oooo]Zocoo0003oookJP06o`0Zoooo
nf[ooo]ZoookJ_ooDP3o0?lc0_oonfX00onio`3ooo]ZoookJP0BoookJP03o`1coooonf[ooo]Z01So
oo]Z00?oo`3ZoookJ_oonfX03OoonfX00oooTP3ooo]ZoookJP05oookJP;oo`3l1ooonfX2oaP0o`03
oookJ_oo1P3ooo]Z00?ooo]Z00Cojol0oookJ_oo0?Koo`3f1OoonfX3o`2Vo`cooo]Z1?oo0?T[oook
JP?oo`3f1OoonfX00olH0?ooo`H0oaP0o`04oookJP;oo`3l1_oonfX00oooTP3ooaH0oookJP05oook
JP;oo`3Z1?l0000<oookJP03o`1coooonf[ooo]Z00[ooo]Z00Go^Ol0oomB0?ooDP3o0?lco`0Zo`02
oookJP05ocoo0?oonf[o0=coogSo0?l0oml01_oonfX01?l0S_oo0?lKoookJ_oobP04oookJP03ool0
Tooo01?ooo]Z00Cooo]Z00Kof_l0oookJ_oonf[ooo]ZobH0oon40?l>oookJP0<oc7o0?oonf[o0?mK
oookJ_l0ok3oP_l0oookJ_l0<?oooo]Zo`3oCOoonf[o1P3o0_oonfX01Ooo0?GoT_l0oookJ_l@0?oo
01Wo00?ooo]Z00Ko5@3ooookJ_oo057o0:gooookJ_oo07T7oookJP06o`3oDooonf[ooo]Zo`3o7Ooo
nf[o0>7o2_oonfX00ol0ocCooo]Zo`3oCP05oookJP06o`28oooonf[ooo]Zo`2Yoooonf[o00Co0_oo
nfX00ol0e?oooo]ZoookJP0:oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX01ooo
nfX00oooE`3ooo]ZoookJP08oookJP05on/0ool0o`Gooo]ZoookJ_oo_P00<_oonfX002[ooo]Z00?o
N?l0odCo0?m4o`001?m4o`000ooonf[o02[ooookJP02oookJP03ooo90?ooDP3oolT000?oolT05?oo
nfX00ol0Looooo]ZoookJP0HoookJP;oo`3Z3OoonfX00ooo5P3ooi80oookJP06oookJP03ool0o?oo
nf[ooo]Z00;ooo]Z1OooN@001?oo003oogT0ool60?oo1P03oookJP;oo`0000?ooo]Zool0m_oonfX0
1OoonfX2o`2Vo`Gooo]Z1Ooo0004oookJPKoo`007_oonfX00onDo`3oobP0oolX0007oiCo00Cooo]Z
0ooo:004oookJP;oo`3l1_oonfX2ool000Oooo]Z00?oobP0oookJ_oonfX01?l0000;oookJP03o`1c
oooonf[ooo]Z00[ooo]Z00Go^Ol0oomB0?oonf[o0?lcoomi0003ool00004oookJ_l0g?ooo`00o`3o
g`Kooo]Z00Co08koo`3o6ooonf[oolX01?oonfX00ooo09?oo`0CoookJP04oookJP05om[o0?oonf[o
obP0ooo90?lPo`000ooo:008oookJP?oo`0000Cooo]Zool00?oonf[o0?mK0_oonfX01On2o`3oo`00
ool00?oo003o0?m=00Coo`0000CoT_l0oookJ_oonf[o403o0_oo0002oookJP06ool00?oo057ooo]Z
o`2]oooonf[oo`1i1ooonfX01_l0oe?ooo]ZoookJ_l0oagooo]Zo`3Qo`[ooo]Z00CoolT0oookJ_l0
obko0?m>1?oonfX01_l0R?oooo]ZoookJ_l0ZOoooo]Zo`04o`;ooo]Z00?o0=CooookJ_oonfX02_oo
nfX00oooP@3ooo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX01_oo
nfX00oo[0?oooo]Zo`3o1@02oookJP03ooo90?oonf[ooo]Z05Oooo]Z00?oN?l0oookJ_l0g?l00_oo
nfX01Oloo`3ooo]ZoookJ_oonf[o02[o00?ooo]Z00Cooe80o`3o<ooonf[o^Ol05OoonfX00ol0Looo
oo]ZoookJP0HoookJP;oo`3Z3_oonfX00oooTP3ooo]ZoookJP06oookJP03ool0o?oonf[ooo]Z00Ko
oo]Z0_lH0?l2ool600?ooo]Z0_o[o`000ooonf[oo`3foookJP06oookJP;o0:Ko3_oonfX4ool0nBCo
oo]Z0ooo0?H6oookJP?oo`H01OoonfX00ooo0?cooo]ZoookJP05oookJP03oonB0?oo5P3ooo]Z00Go
oo]Z00?oo`3ZoookJ_oonfX01?l0000;oookJP03o`1coooonf[ooo]Z00[ooo]Z00Go^Ol0oomB0?oo
nf[o0?lco`0Zo`02oookJP05ocoo0?oonf[o0=coogSo0?l0oml01_oonfX01Ol0S_oo0?lKoa80oooo
nf[oolX000?ooo]Z00?oo`2Cool04ooonfX01?oonfX01ooJo`3ooo]ZoookJ_oonf[o9P3ooookJ_n4
0?l03OoonfX00olao`3ooo]Zo`3oF`02oookJP0>o`3o/?n2o`3ooo]Zo`0`oooonf[o0?m=oookJ_l6
0?oooo]Zool0mOnBo`3ooo]Zool0J_l@0?l3oookJP06oaD0oooonf[oo`1AoookJ_l0[Oooo`1i1ooo
nfX01?l0oe?ooo]ZoookJ_l0oad2oookJP03o`3Qoooonf[ooo]Z00Oooo]Z00Co0?ldoookJ_l0obko
0?m>1OoonfX00ol0R?oooo]Zo`2Yo`02oookJP03o`04oooonf[o0=Co00cooo]Z00?ooh40oookJ_oo
nfX02ooonfX00ooo02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z00Oooo]Z00?oj`3ooookJ_l0
o`D00_oonfX00ooo_P3ooo]ZoookJP0`oookJP00:_oonfX00omho`3oA?l0odCo0002odCo0004ocoo
0?oonf[ooo]Zo`0Zo`?ooo]Z0_oob@000oooDP3oolT0ooo90002ooo901?ooo]Z00?o07?ooookJ_oo
nfX06_oonfX00ooo0>[ooo]ZoookJP0;oookJP03oolF0?ooTP3ooo]Z00Kooo]Z0_oo0?`3oookJPOo
ogT000?ooo]Zool60?oonfX00ooonfX2ool000?oo`3f1OoonfX2o`2Vo`Cooo]Z3_oo000LoookJP;o
U?l00ooo:007oiCo0004oookJ_oo:03oobP0oolX00Kooo]Z00?oo`3loookJ_oonfX01?oonfX00ooo
TP3oo`00oookJP06oookJP;oobP00ooonfX4o`0000[ooo]Z00?o07?ooookJ_oonfX02_oonfX01Oni
o`3ooe80oookJ_l0oc?oogT000Coo`0000?o0=coool00?l0oml01_oonfX01?l0S_oo0?lKoa80oooo
bP04oookJP03ool0Tooo01?ooo]Z00Cooo]Z00GohOl0om[o0?oo:03oolT0ob3o0003oolX00Sooo]Z
1_oo00001Ooonf[o0?mKoookJ_n2o`3ooo]Z00;oo`0000?o0?m=ool00?oo00000ooo00001OnBo`3o
oo]Zool00?l@0?ooo`0000?ooo]Z00Koo`1AoookJ_oonf[o0:gooookJ_oo07T7oookJP05o`3oDooo
nf[ooo]Zo`3o7Ol0hOl02ooonfX00ooob@3ooo]Zo`3oCP05oookJP03o`28oooonf[o0:Wo00;ooo]Z
00?o00CooookJ_l0e?l03OoonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z00Oooo]Z
00?ooeL0oookJ_oonfX01ooonfX00oo[0?oooo]Zo`3o1@02oookJP03ooo90?oonf[ooo]Z05Oooo]Z
00KoN?l0oookJ_oonf[o0=cooookJ_loo`03oookJP03o`0Zoooonf[ooo]Z00;ooo]Z00?ooe80o`3o
<onio`005_oonfX00ol0Looooo]ZoookJP0IoookJP03ool0j_oonf[ooo]Z00cooo]Z00?ooi80oook
J_oonfX01_oonfX00ooo0?cooo]ZoookJP07oookJP;o603o00?oo`H0oookJ_oonfX00_oonfX2on_o
00?oo`3f1_oonfX2o`2Voa3ooo]Z0_oo0?TOoookJP?oo`3f1_oonfX3ool600Kooo]Z0_oo0?`6oook
JP;ooi801_oonfX2ool0jP?ooo]Z1?l0000:oookJP03o`1coooonf[ooo]Z00[ooo]Z00Go^Ol0oomB
0?oonf[o0?lco`0Zo`02oookJP05ocoo0?oonf[o0=coogSo0?l0oml01_oonfX01Ol0S_oo0?lKoa80
oooonf[oolX000?ooo]Z00?oo`2Cool04ooonfX01?oonfX01ooQo`3of_l0oookJ_oonf[o9P3ooook
J_n40?l03OoonfX05?lao`3ooo]ZoookJ_l0oe_ooo]Zo`3o/?n2o`3ooo]Zo`0`oooonf[o0?m=oook
J_l60?oooo]Zool0mOoonf[oT_l0oookJ_l@0?oo01Wo0ooonfX01_lE0?ooo`1AoookJ_l0[Ooooo]Z
ool0N@Oooo]Z00Ko0?mCoookJ_oonf[o0?lMoookJ_l0hOl:oookJP03o`3o=?oonf[o0?m>00Gooo]Z
00?o08SooookJ_l0ZOl00ooonfX00ol01?oooo]Zo`3Do`0<oookJP03oon10?oonf[ooo]Z00[ooo]Z
00?oo`0]oookJ_oonfX01ooonfX00oooE`3ooo]ZoookJP08oookJP03on/0ool0o`Gooo]Z00;ooo]Z
00?ookh0oookJ_oonfX0<?oonfX002[ooo]Z00Co?@3oogSo0?m4o`3oA?l00_oonfX01?loo`3ooo]Z
oookJ_l0:_l2oookJP;oolT000?ooe80ooo90?oob@000ooob@0CoookJP03o`1coooonf[ooo]Z01[o
oo]Z00?oo`3ZoookJ_oonfX02ooonfX00ooo5P3ooi80oookJP07oookJP04ool0o?oonf[ooo]Zoook
JPGoogT000?ooo]Zoomi0?ooN@000ooo1P03oookJP03ool00?oonf[ooo]Z00Goo`3f0_oonfXAool0
01_ooo]Z0_nDo`05oolX00GoU?l00ooo:007oookJP;oo`3l0ol007l01Ooonf[ooi80oonB0?ooTP3o
oo]Z00Go001o00?ooo]ZoolX0?oo:0001OoonfX4o`0000Sooo]Z0_l0Lol<oookJP05okWo0?ooDP3o
oo]Zo`3o<oooN@001?oo00000ol0g?ooo`00o`3og`06oookJP04o`2>ool0oa_o4P3oooo:00Cooo]Z
00?oo`2CoookJ_oo01<01OoonfX01OoJo`3ooo]Zooo90?oo:03o8?l000;oobP02OoonfX7ool00003
oookJ_n2o`3o0?n`00;oo`0000?o0?m=ool00?oo00000ooo00001OnBo`3ooo]ZoookJ_l@0?ooo`00
00?ooo]Z00Koo`00ool0DOoonf[o0:gooookJ_oo07T7oookJP05o`3oDooonf[ooo]Zo`3o7Ol0hOl0
2ooonfX00ooob@3ooo]Zo`3oCP05oookJP06o`28oooonf[ooo]Zo`2Yoooonf[o00Co0_oonfX00ol0
e?oooo]ZoookJP0:oookJP03oon10?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX01ooonfX00ooo
E`3ooo]ZoookJP07oookJP03on/0oooonf[o0?l500;ooo]Z00?oolT0oookJ_oonfX0EooonfX01?lm
0?ooN?l0oookJ_l0g?l2oookJP05ocoo0?oonf[ooo]ZoookJ_l0:_l00ooonfX01?ooDP3o0?lcoook
J_nio`0EoookJP03o`1coooonf[ooo]Z01[ooo]Z0_oo0>X=oookJP03oonB0?oonf[ooo]Z00Kooo]Z
0_oo0?`9oookJP04oaP0oooo1P3oo`H0ool600?ooo]Z00?ojol0oookJ_oonfX01Ooo0?H3oookJPGo
0:Ko:OoonfX3ool0mPKooo]Z0ooo1P07oookJP;oo`3l0ol007l2oookJP?ooi801Ol007l00ooonf[o
o`3Zool0jP05oookJPCo00002OoonfX00ol0Looooo]ZoookJP0:oookJP05okWo0?ooDP3ooo]Zo`3o
<ol0:_l00ooonfX01?loo`3o0=coogSo0?l0oml6oookJP05o`2>ool0oa_o4P3ooookJ_oobP000ooo
nfX00ooo09?ooo]Zool04`05oookJP06om[o0?oonf[ooo]ZobH0oolPo`3oQ03o3_oonfX00olao`3o
oo]Zo`3oF`02oookJP07oh;o0?oonf[o0?nao`0`ool0odgooo]Zo`H0o`02oookJP05ool0mOnBo`3o
oo]Zool0J_l@0?l00ooonfX01_lE0?oooo]Zool0DOl0[Ooooo]Zool0N@Oooo]Z00Ko0?mCoookJ_oo
nf[o0?lMoookJ_l0hOl:oookJP03o`3o=?oonf[o0?m>00Kooo]Z00?o08SooookJ_l0ZOl00_oonfX0
0ol01?oooo]Zo`3Do`0=oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX01ooonfX0
0oooE`3ooo]ZoookJP08oookJP05on/0ool0o`Gooo]ZoookJ_oo_P00<ooonfX002[ooo]Z00GoA?l0
ogSo0?oonf[ooo]ZodCo0002oookJP03ocoo0?oonf[o02[o00?ooo]Z0_oob@000oooDP3oolT0ooo9
0003ooo901?ooo]Z00?o07?ooookJ_oonfX06_oonfX2ool0jPcooo]Z00?ooaH0oonB0?oonfX01ooo
nfX01?oo0?cooo]ZoookJ_oonfX4oomi00?ooo]Z0_ooN@001_oonf[oo`H0ool60?oo1P3ooo]Zool0
00Kooo]Z1?oo0?H00ooonf[oo`00ool0000<ool001[ooo]Z00?oU?l0oolX0?oo:0002_oo:0000olH
0?ooU?l0oiCo0005oookJP;oo`3l0_oonfX2o`00O`;ooi8000?ooaH0oookJ_oonfX01_l007l00ooo
:03ooo]ZoookJP05oookJPCo00001ooonfX00ol0Looooo]ZoookJP0;oookJP05okWo0?ooDP3o0?lc
o`3o<oooN@001?oo00000ol0g?ooo`00o`3og`06oookJP04o`2>ool0oa_o4P3oooo:00Cooo]Z00?o
0?Woool0Tooo01<01OoonfX01OoJo`3ooo]ZoookJ_oob@3o8?l000;oobP02_oonfX8ool00005oh;o
0?oonf[oo`00ool00?l0odd01?oo00001OnBo`3ooo]ZoookJ_oo003o403o00Cooo]Z00Goo`1Aoook
J_oonf[o0:goool0N@08oookJP05o`3oDooonf[o0?l8o`3o7Ol0hOl02ooonfX00ooob@3ooo]Zo`3o
CP05oookJP03o`28oooonf[o0:Wo00;ooo]Z00?o00CooookJ_l0e?l03OoonfX00oooP@3ooo]Zoook
JP0;oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0oookJ_oonfX01ooonfX00oo[0?oooo]Zo`3o
1@02oookJP03ooo90?oonf[ooo]Z05Wooo]Z00Co?@3oogSo0?oonf[o0=co0_oonfX01?loo`3ooo]Z
oookJ_l0:_l4oookJP03oomB0?l0oc?o^Ol001Kooo]Z00?o07?ooookJ_oonfX06ooonfX00ooo0>[o
oo]ZoookJP0;oookJP03oonB0?oonf[ooo]Z00Oooo]Z00?oo`3loookJ_oonfX02?oonfX2oaP0o`?o
o`H000?ooo]Zon_o0?oonfX01OoonfX4ool0mPCooo]Z2Ol0Y_lMoookJP?oo`3f1OoonfX4ool60003
oaP0oooonf[ooo]Z00Gooo]Z0_oo0?`2oookJP?o001o0_ooTP000ooo5P3ooo]Zo`00O`05o`00O`03
ool0j_oonf[ooo]Z00Gooo]Z1?l00008oookJP03o`1coooonf[ooo]Z00[ooo]Z00Go^Ol0oomB0?l0
oc?o0?lco`0Zo`03oookJP04ocoo0?l0g?ooN?l0o`3og`Oooo]Z00Co0?lKoa80oooonf[oolX00ooo
nfX00ol0nOooo`2Cool04`05oookJP07om[o0?oonf[ooo]ZoookJ_lV0?oooo]Zoh@0o`0=oookJP03
oc7o0?oonf[o0?mK00;ooo]Z00_o0?n`oh;o0?l0ok7o033ooookJ_l0odgooo]Zo`H0oooonf[oo`3e
oi;o0002oookJP03oa00oooonf[ooo]Z00;ooo]Z00Go5@3oool0DOoonf[o0:goool0N@08oookJP06
o`3oDooonf[o0?l8o`3o7Ooonf[o0>7o2_oonfX00ol0ocCooo]Zo`3oCP05oookJP03o`28oooonf[o
0:Wo00?ooo]Z00?o00CooookJ_l0e?l03?oonfX00oooP@3ooo]ZoookJP0;oookJP03ool0;Ooonf[o
oo]Z00Kooo]Z00?ooeL0oookJ_oonfX02?oonfX00oo[0?oooo]Zo`3o1@02oookJP03oonn0?oonf[o
oo]Z037ooo]Z000ZoookJP05o`3ogolm0?ooN?l0oookJ_m4o`000_oonfX00oloo`3ooo]Zo`0Zo`03
oookJP?oolT000?ooe80ooo90?oob@005OoonfX00ol0Looooo]ZoookJP0LoookJP03ool0j_oonf[o
oo]Z00[ooo]Z00?ooaH0oonB0?ooTP001ooonfX01?oo0?cooo]ZoookJ_oonfX3oomi00Gooo]Z0_oo
N@02oookJP?oo`H02OoonfX4ool0mQ7oo`003ooonfX4ool0mP03oiCo0?oo:03oobP000OoobP00olH
0?l7oookJP;oo`3l1?oonfX2oonB0003oolF0?oonf[ooo]Z00;ooo]Z0ol007l01?oonf[oobP0oolX
0?l007l7oookJPCo00001_oonfX00ol0Looooo]ZoookJP0;oookJP05okWo0?ooDP3o0?lcoookJ_oo
N@001?oo00001?l0g?ooo`00oookJ_l0oml6oookJP03o`3o6ooonf[oolX000Cooo]Z00?o0?Woool0
Tooo01<01OoonfX01OoJo`3ooo]ZoookJ_oob@3o8?l000;oobP02_oonfX8ool00005oh;o0?oonf[o
o`00ool00?l0odd01?oo00001_nBo`3ooo]ZoookJ_oonf[o403oo`1Mo`?ooo]Z00Koo`1AoookJ_oo
nf[o0:gooookJ_oo07T7oookJP05o`3oDooonf[ooo]Zo`3o7Ol0hOl02ooonfX00ooob@3ooo]Zo`3o
CP05oookJP04o`28oooonf[ooo]Zo`2Yo`;ooo]Z00?o00CooookJ_l0e?l03?oonfX00oooP@3ooo]Z
oookJP0;oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX01ooonfX00oo[0?oooo]Z
o`3o1@02oookJP03ooo90?oonf[ooo]Z05Sooo]Z00?o0?oOocd0oomho`000_oonfX00ol0g?oooo]Z
ocoo0002oookJP03o`0Zoooonf[ooo]Z00?ooo]Z00?ooe80o`3o<onio`005_oonfX00ol0Looooo]Z
oookJP0KoookJP;oo`3Z3?oonfX2oonB00Sooo]Z00?oo`3loookJ_oonfX02OoonfX00olH0?oooo]Z
oookJP03ool600Wooo]Z1?oo0?H9oookJPSo0:Ko4?oonfX5ool0mPGooo]Z0ooo1P03oaP0o`Oooo]Z
0_oo0?`4oookJP03o`00OoooTP3ooi8000Cooo]Z0ol007l01?oonf[oo`3Zool0j_l007l7oookJPCo
00001ooonfX00ol0Looooo]ZoookJP0:oookJP05okWo0?ooDP3o0?lcoookJ_l0:_l00ooonfX01Olo
o`3o0=coogSo0?lm0?oo0?oO00Kooo]Z00Co08koo`3o6ooonf[oolX00ooonfX00ol0nOooo`2Cool0
4`05oookJP07om[o0?oonf[ooo]ZoookJ_lV0?oooo]Zoh@0o`0>oookJP0?oc7o0?oonf[o0?mKoook
J_l0ok3oP_l0oookJ_l0<?oooo]Zo`3oCOoonf[o1P3ooookJ_oo0?GoT_l000;ooo]Z00?oo`1Zoa00
oooonfX00_oonfX01_lE0?ooo`1AoookJ_l0[Ooooo]Zool0N@Oooo]Z00Ko0?mCoookJ_oonf[o0?lM
oookJ_l0hOl:oookJP03o`3o=?oonf[o0?m>00Kooo]Z00?o08SooookJ_l0ZOl00_oonfX00ol01?oo
oo]Zo`3Do`0=oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX01ooonfX00oooE`3o
oo]ZoookJP08oookJP05on/0ool0o`Gooo]ZoookJ_oo_P00=?oonfX002[ooo]Z00Ko0?oOocd0oooo
nf[oN?l0oookJ_m4o`02oookJP03ocoo0?oonf[o02[o00;ooo]Z1?oob@000oooDP3o^Ol0oookJP0E
oookJP03o`1coooonf[ooo]Z01cooo]Z0_oo0>X;oookJP04oolF0?oonf[ooi80oonB00Kooo]Z1Ooo
N@08oookJP;oogT00ooonfX3ool600[ooo]Z0ooo0?H7ool000Oooo]Z1?oo0002oookJPWoo`3f0ooo
nfX;oolX00Wooo]Z00Coo`3loookJ_oonf[ooo]Z0oooTP001?oo5P3o001oo`00Oooo:002oookJP?o
001o0_oo:0001?oonf[o001oo`00Ool007l6oookJPCo00001OoonfX00ol0Looooo]ZoookJP0;oook
JP05okWo0?ooDP3o0?lcoookJ_ooN@001_oo00000ooonf[o0?oOoookJP05oookJP03o`3o6ooonf[o
olX000Cooo]Z00?o0?Woool0Tooo01<01OoonfX01ooJo`3ooo]ZoookJ_oob@3oobP0ob3o0?oo:000
2ooonfX7ool00005oh;o0?l0ok3oo`00o`0`ool0odd01?oo00001_oo:03oT_l0oookJ_oonf[o403o
o`1Mo`?ooo]Z00Koo`00ool0DOoonf[ooo]Zo`2]oooo07T7oookJP06o`3oDooonf[ooo]Zo`3o2?l0
oago0>7o2ooonfX00ooob@3ooo]Zo`3oCP05oookJP03o`28oooonf[o0:Wo00;ooo]Z00?o00Cooook
J_l0e?l03OoonfX00oooP@3ooo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0oook
J_oonfX01ooonfX01?o[0?oooo]ZoookJ_l0o`D2oookJP03ooo90?oonf[ooo]Z05Sooo]Z00Ko0?oO
oookJ_lm0?ooN?l0oookJ_l0g?l2oookJP04ocoo0?oonf[ooo]Zo`0Zo`Gooo]Z00?ooe80oookJ_ni
o`005_oonfX00ol0Looooo]ZoookJP0LoookJP03ool0j_oonf[ooo]Z00[ooo]Z00?ooaH0oonB0?oo
TP001ooonfX2ool0o0[ooo]Z0_lH0?l3oookJP?oo`H02_oonfX5ool0mPcooo]Z1?l0Y_l3oookJPWo
o`3f1_oonfX4ool60003oookJ_lH0?oo603o00Wooo]Z00?oo`3loookJ_oonfX00_oonfX3oonB00;o
001o0ooonfX3o`00O`;oo`3Z00Cooo]Zo`00Ool007oo001o1_oonfX4o`0000Kooo]Z00?o07?ooook
J_oonfX02_oonfX01Onio`3ooe80o`3o<ooonf[o02[o00?ooo]Z00Go?ol0o`3Loomho`3o?@3oo`3o
g`06oookJP04o`2>ool0oa_ooo]Zooo:00?ooo]Z00?o0?Woool0Tooo01<01OoonfX01ooJo`3ooo]Z
oookJ_oonf[o9P3oob3o0?n40?l03_oonfX00olao`3ooo]Zo`3oF`02oookJP0>oh;o0?oonf[o033o
oookJ_l0odgo0>SooookJ_l60?oooo]Zool0mOnBo`3ooo]Zool0J_l@0?l3oookJP06oaD0oooonf[o
o`1AoookJ_l0[Oooo`1i1ooonfX01ol0oe?ooo]ZoookJ_l0o`So0?lMoookJ_l0hOl02_oonfX00ol0
ocCooo]Zo`3oCP05oookJP03o`28oooonf[o0:Wo00?ooo]Z00?o00CooookJ_l0e?l03?oonfX00ooo
P@3ooo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0oookJ_oonfX02?oonfX00oo[
0?oooo]Zo`3o1@02oookJP03oonn0?oonf[ooo]Z03;ooo]Z000[oookJP03o`3ogolm0?ooN?l000;o
oo]Z00GoA?l0oookJ_loo`3ooo]Zo`0Zo`03oookJP;oolT000Cooo]ZoomB0?oob@3o^Ol05_oonfX0
0ol0Looooo]ZoookJP0MoookJP03ool0j_oonf[ooo]Z00Wooo]Z0_oo5P000ooonf[ooi80oonB0006
oookJP_oogT00_oonfX2oomi00Cooo]Z1?oo1P0;oookJP03ool0m_oo003oo`0000;oo`001?oonfX9
ool0mP[ooo]Z3_oo:006oookJP;oo`3l0_oonfX2oonB00;ooaH000?ooo]Zo`00Ool007l00_oo:002
oookJP;o001o00CoobP0oookJ_oonf[ooo]Z0ol007l6oookJPKo00000_oonfX00ol0Looooo]Zoook
JP0;oookJP06okWo0?ooDP3o0?lcoookJ_ooN@3ooo]Z1ooo0006oookJP04o`3o6ooonf[ooo]Zooo:
00?ooo]Z00?o0?Woool0Tooo01<01OoonfX01ooJo`3ohOl0oookJ_oonf[oolT0ob3o0?oo:0003?oo
nfX6ool00003oookJ_n2o`3ooo]Z00;oo`0000Ko0?m=ool00?oo003oo`00oookJ_nBo`03oookJP03
oa00oooonf[ooo]Z00;ooo]Z00Koo`1AoookJ_oonf[o0:gooookJ_oo07T7oookJP05o`3oDooonf[o
oo]Zo`3o7Ol0hOl02ooonfX00ooob@3ooo]Zo`3oCP06oookJP03o`28ool0ZOoooo]Z00;ooo]Z00?o
00CooookJ_l0e?l03?oonfX00oooP@3ooo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?o
oeL0oookJ_oonfX01ooonfX00oo[0?oooo]Zo`3o1@02oookJP03ooo90?oonf[ooo]Z05[ooo]Z00?o
0?oOocd0oomho`000_oonfX00ol0g?oooo]Zocoo0002oookJP03o`0Zoooonf[ooo]Z00Cooo]Z00?o
oe80oookJ_nio`005OoonfX00ol0Looooo]ZoookJP0MoookJP03ool0j_oonf[ooo]Z00[ooo]Z0_oo
5P02oonB00Oooo]Z0ooo0?`9oookJP;o603o1?oonfX4ool600_ooo]Z1?oo0?H6oookJPWoo`3f3?oo
nfX3ool600;ooo]Z0olH0?l9oookJP;oo`3l0ooonfX2oonB0003oolF0?oonf[o001o00;o001o0ooo
nfX2o`00O`04ool0j_oonf[ooo]ZoookJP?o001o1_oonfX6o`0000;ooo]Z0_l0Lol<oookJP05okWo
0?ooDP3o0?lcoookJ_l0:_l00ooonfX01Oloo`3ooo]ZogSo0?lm0?oo0?oO00Kooo]Z00Go08koo`3o
6ooonf[ooo]Zooo:0002oookJP03o`3ioooo09?oo`0C00Gooo]Z00?of_l0on7o0?oonfX00_oonfX0
0olV0?oooo]Zoh@0o`0=oookJP0@oc7o0?oonf[ooo]Zo`3oFooonf[o0?n`oh;o0?l0ok7o033ooook
J_l0odgooo]Zo`H0oooonf[oo`3eoi;o00;ooo]Z00?oo`1Zoa00oooonfX00_oonfX01_lE0?ooo`1A
oookJ_l0[Ooooo]Zool0N@Oooo]Z00Ko0?mCoookJ_oonf[o0?lMoookJ_l0hOl:oookJP03o`3o=?oo
nf[o0?m>00Kooo]Z00?o08Soo`2YoooonfX00_oonfX00ol01?oooo]Zo`3Do`0=oookJP03oon10?oo
nf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX01ooonfX00oooE`3ooo]ZoookJP08oookJP03on/0ool0
o`Gooo]Z00;ooo]Z00?ookh0oookJ_oonfX0<_oonfX002cooo]Z00Go0?oOoookJ_mho`3ooo]ZodCo
0002oookJP03ocoo0?oonf[o02[o00;ooo]Z00OoolT0oookJ_oonf[ooo]ZoomB0?oob@3o^Ol001Ko
oo]Z00?o07?ooookJ_oonfX07OoonfX00ooo0>[ooo]ZoookJP0:oookJP;ooaH000Cooo]ZoonB0?oo
TP3ooi801?oonfX?oomi00?o603o1?oonfX3ool600cooo]Z00?oo`00ool0m_oo0?H00_oo0?HBoook
JPooobP00ooonfX3ool0o0;ooo]Z0_ooTP000ooo5P3ooo]ZoookJP02oookJP03o`00Oooo:03oobP0
00;oobP000Cooo]ZoolX0?oo:03o001o0ooonfX3o`00O`Kooo]Z1?l00003oookJP03o`1coooonf[o
oo]Z00[ooo]Z0_nio`001OooDP3o0?lcoookJ_ooN@3ooo]Z00Woo`001?oonfX01?lB0?oo0?lKoook
J_oobP04oookJP03o`3ioooo09?ooo]Z00?ooo]Z0_oob@001_oJo`3ooo]ZoookJ_oob@3o8?l0oolX
00cooo]Z1_oo00001_oonf[oP_l0oookJ_oo003o033oo`3oC@?oo`0000?ooo]Zoi;o0?oonfX00_oo
nfX00ol@0?oooo]ZoookJP02oookJP06ool0DOoonf[ooo]ZoookJ_l0[Oooo`1i1ooonfX01_l0oe?o
oo]ZoookJ_l0o`So0?lMo`3Qo`_ooo]Z00?oolT0o`3oC_l0obh01OoonfX00ol0R?oooo]Zo`2Yo`02
oookJP03o`04oooonf[o0=Co00gooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP06
oookJP03oomG0?oonf[ooo]Z00Oooo]Z00Coj`3oog00oooonf[o0?l50_oonfX00ooob@3ooo]Zoook
JP1KoookJP03o`3ogolm0?ooN?l000;ooo]Z00?o0=cooookJ_loo`000_oonfX00ol0:_oooo]Zoook
JP03oookJP04oomB0?l0oc?ooo]ZokWo01Gooo]Z00?o07?ooookJ_oonfX07OoonfX2ool0jPcooo]Z
0_oo5P03oonB00Oooo]Z0ooo0?`8oookJPCo603o1?oonfX3ool600cooo]Z1_oo0?HBoookJP?oo`H0
00?ooo]ZoaP0oolH0?l00_lH0?l9oookJP?oo`3l0ooonfX2oonB0004oolF0?oonf[ooo]ZoookJP?o
001o0ooonfX2ool0jP04o`00Oooonf[ooo]ZoookJP?o001o1_oonfX4o`0000?ooo]Z00?o07?ooook
J_oonfX02_oonfX2okWo0004oomB0?l0oc?ooo]Zo`0Zo`?ooo]Z00Go?ol0oookJ_l0g?ooN?l0o`3o
g`06oookJP05o`2>ool0oa_ooo]ZoookJ_oobP000ooonfX00ol0nOooo`2CoookJP05oookJP07om[o
0?oonf[ooo]ZoookJ_lV0?oooo]Zoh@0o`0>oookJP0?oc7o0?oonf[o0?mKoookJ_l0ok3oP_l0oook
J_l0<?oooo]Zo`3oCOl0j?oo1P3ooookJ_oo0?GoT_l000;ooo]Z00?oo`1Zoa00oooonfX00_oonfX0
1_lE0?ooo`1AoookJ_oonf[o0:goool0N@Oooo]Z00Oo0?mCoookJ_oonf[o0?l8o`3o7Ooonf[o0>7o
00[ooo]Z00?o0?ldo`3oC_l0obh01OoonfX00ol0R?oooo]Zo`2Yo`03oookJP03o`04oooonf[o0=Co
00cooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP06oookJP03oomG0?oonf[ooo]Z
00Sooo]Z00?oj`3oog00ool0o`D00_oonfX00ooo_P3ooo]ZoookJP0coookJP00;OoonfX01Ol0omoo
N?l0oookJ_oonf[oA?l000;ooo]Z00?o?ol0oookJ_l0:_l01_oonfX00oooDP3o^Ol0oookJP0Eoook
JP03o`1coooonf[ooo]Z01kooo]Z0_oo0>X<oookJP?ooaH000?ooo]ZoonB0?ooTP001?oonfX<oomi
00Cooo]Z1olH0?l3ool601Sooo]Z1ooo1P08oolX00Oooo]Z1?oo0?`2oookJP?ooi8000?ooaH0oook
J_oonfX01?oonfX6oolX00?o001o0ooonfX3o`00O`Kooo]Z1?l000000ooonf[o07?oo`1co`0<oook
JP03okWo0?ooDP3ooe8000;ooo]Z00?oogT0oookJ_oonfX02_oo0002oookJP04oa80ool0oa_ooo]Z
ooo:00Cooo]Z00?o0?Woool0Tooo01<01?oonfX3ooo90004oookJ_oob@3o8?l0oolX00gooo]Z1Ooo
00001_oonf[oP_l0o`3o/?oo003o033oo`3oC@?oo`0000?ooo]ZoolX0?nBo`000_oonfX00ooo003o
403ooookJP03oookJP06ool0DOoonf[ooo]Zo`2]oooonf[oo`1i1_oonfX01_l0oe?ooo]ZoookJ_l0
o`So0?lMo`3Qo`_ooo]Z00?oolT0oookJ_l0odh01_oonfX00ol0R?oo0:WooookJP02oookJP03o`04
oooonf[o0=Co00cooo]Z00?ooh40oookJ_oonfX03?oonfX00ooo02gooo]ZoookJP06oookJP03oomG
0?oonf[ooo]Z00Oooo]Z00?oj`3ooookJ_l0o`D00_oonfX00ooob@3ooo]ZoookJP1MoookJP05o`3o
gooonf[oN?l0oookJ_l0g?l00_oonfX01?loo`3ooo]ZoookJ_l0:_l5oookJP03oomB0?oonf[o^Ol0
01Kooo]Z00?o07?ooookJ_oonfX07_oonfX00ooo0>[ooo]ZoookJP0;oookJP;ooaH000?ooo]ZoonB
0?ooTP002?oonfX3ool0o0Wooo]Z1olH0?l3ool601Sooo]Z2Ooo1P04oaP0o`Wooo]Z1?oo0?`3oook
JP?ooi8000?ooaH0oookJ_oonfX00ooonfX3o`00O`03oookJ_oo0>[oo`3Z00?o001o0ooonfX3o`00
O`Kooo]Z1?l00002oookJP03o`1coooonf[ooo]Z00[ooo]Z00Ko^Ol0oomB0?ooDP3o0?lcoookJ_l0
:_l3oookJP05ocoo0?oonf[o0=coogSo0?l0oml01ooonfX01?l0oa_ooo]ZoookJ_oobP03oookJP03
o`3ioooo09?oo`0C00Gooo]Z00Oof_l0oookJ_oonf[ooo]ZobH0oooonf[oQ03o00kooo]Z00?o<Ol0
oookJ_l0oe/00_oonfX03on2o`3ooo]Zo`0`oooonf[o0?m=o`3Xoooonf[o1P3ooookJ_oo0?GoT_l0
oookJ_oo06[o01Wooa00o`03oookJP06oaD0oooo057ooo]Zo`2]oooonf[oo`1i1_oonfX01ol0oe?o
oo]ZoookJ_l0o`So0?lMoookJ_l0hOl02_oonfX00ol0ocCooo]Zo`3oCP06oookJP03o`28ool0ZOoo
oo]Z00;ooo]Z00?o00CooookJ_l0e?l03OoonfX00oooP@3ooo]ZoookJP0;oookJP03ool0;Ooonf[o
oo]Z00Kooo]Z00?ooeL0oookJ_oonfX02?oonfX00oo[0?oooo]Zo`3o1@02oookJP03oonn0?oonf[o
oo]Z03?ooo]Z000]oookJP05o`3ogooonf[oN?l0oookJ_m4o`000_oonfX01?loo`3ooo]ZoookJ_l0
:_l5oookJP03oomB0?oob@3o^Ol001Kooo]Z00?o07?ooookJ_oonfX07ooonfX00ooo0>[ooo]Zoook
JP0<oookJP;ooaH000?ooo]ZoonB0?ooTP000ooonfX:oomi00cooo]Z0olH0?l3ool600Sooo]Z3Ooo
1P06oaP0o`cooo]Z1?oo0?`4oookJP;ooi800_oo5P07oookJPOoobP00ol007l3oookJP?o001o1_oo
nfX4o`000003o`1coooonf[ooo]Z00_ooo]Z00?o^Ol0oomB0?l0oc<00_oonfX00oooN@3ooo]Zoook
JP09ool000?ooo]Z00Co4P3oo`3o6ooonf[oolX01?oonfX00ol0nOooo`2Cool04`04oookJPKoolT0
00?o8?l0oh@0oooonfX03?oonfX4ool000;ooo]Z00GoP_l0ool00?l0<?oooo]Zo`3oC@02ool000;o
oo]Z00GoT_l0oookJ_oonf[ooo]Zoa00o`04oookJP06ool0DOoonf[ooo]ZoookJ_l0[Oooo`1i1ooo
nfX01_l0oe?ooo]ZoookJ_l0oagooo]Zo`3Qo`_ooo]Z00?oolT0o`3oC_l0obh01OoonfX00ol0R?oo
oo]Zo`2Yo`02oookJP03o`04oooonf[o0=Co00gooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02go
oo]ZoookJP06oookJP03oomG0?oonf[ooo]Z00Sooo]Z00?oj`3ooookJ_l0o`D00_oonfX00ooob@3o
oo]ZoookJP1MoookJP03o`3ogolm0?ooN?l000;ooo]Z00?o0=cooookJ_loo`000ooonfX00ol0:_oo
oo]ZoookJP03oookJP03oomB0?oonf[o^Ol001Gooo]Z00?o07?ooookJ_oonfX07ooonfX2ool0jPgo
oo]Z0ooo5P02oonB00Wooo]Z0ooo0?`=oookJP?o603o0ooo1P000olH0?oooo]ZoookJP05oookJPgo
o`H01_lH0?l<oookJPCoo`3l1OoonfX2oonB00;ooaH01ooonfX3o`00O`03ool0j_oonf[ooo]Z00?o
001o0ooonfX3o`00O`Kooo]Z1?l000000ooonf[o07?ooookJP0;oookJP03okWo0?ooDP3o0?lc00;o
oo]Z00So02[ooookJ_oonf[ooo]Zocoo0?oonf[o0=coogSo00Sooo]Z00Co0?lKoookJ_oonf[oolX0
0ooonfX00ol0nOooo`2Cool04`05oookJP08om[o0?oQo`3ooo]ZoookJ_lV0?oo8?l0oookJ_n40?l=
oookJP03oc7o0?oonf[o0?mK00;ooo]Z00?o0?n`oh;o0?l0<?l00_oonfX01_l0odgooo]Zo`H0oooo
nf[oo`3eoi;o00;ooo]Z00?oo`1Zoa00oooonfX00_oonfX01_lE0?ooo`1AoookJ_oonf[o0:goool0
N@Oooo]Z00Co0?mCoookJ_oonf[o0?lM0_oonfX00ol0hOoooo]ZoookJP08oookJP03o`3o=?l0odko
0?l^00Gooo]Z00?o08SooookJ_l0ZOl00ooonfX00ol01?oooo]Zo`3Do`0<oookJP03oon10?oonf[o
oo]Z00_ooo]Z00?oo`0]oookJ_oonfX01ooonfX00oooE`3ooo]ZoookJP08oookJP05on/0ool0o`Go
oo]ZoookJ_oo_P00=_oonfX002gooo]Z00?o?@3oo`3ogomho`000_oonfX01?m4o`3ooo]ZoookJ_lo
o`02oookJP03o`0Zoooonf[ooo]Z00?ooo]Z00?ooe80ooo90?nio`005_oonfX00ol0Looooo]Zoook
JP0OoookJP;oo`3Z3_oonfX2oolF0003oookJ_ooTP3ooi8000?ooo]Z2_ooN@0@oookJPSoo`H01Ooo
nfX7oaP0o`oooo]Z1?oo0?`6oookJP;ooi800_oo5P08oookJPSoobP00ol007l3oookJP?o001o1_oo
nfX3o`000003o`1coooonf[ooo]Z00_ooo]Z00?o^Ol0oomB0?l0oc<00_oonfX01?ooN@3ooo]Zoook
J_oonfX8ool000?ooo]Z00Co4P3oo`3o6ooonf[oolX01?oonfX00ol0nOooobP0ool04`05oookJPOo
olT03OoonfX4ool000;ooo]Z00GoP_l0oookJ_oo003o033oo`3oC@02ool00003o`H0oooonf[oT_l0
00?ooo]Z00?oo`00oa00oooonfX00_oonfX01ooo057ooo]ZoookJ_oonf[o0:gooookJ_oo07T01_oo
nfX01_l0oe?ooo]ZoookJ_l0o`So0?lMo`3Qo`_ooo]Z00?oolT0oookJ_l0odh01_oonfX00ol0R?oo
0:WooookJP02oookJP03o`04oooonf[o0=Co00cooo]Z00?ooh40oookJ_oonfX03?oonfX00ooo02go
oo]ZoookJP06oookJP03oomG0?oonf[ooo]Z00Oooo]Z00Coj`3ooookJ_oonf[o0?l50_oonfX00ooo
b@3ooo]ZoookJP1NoookJP05o`3ogooonf[oN?l0oookJ_l0g?l00_oonfX01Oloo`3ooo]ZoookJ_oo
nf[o02[o00Gooo]Z00?ooe80oookJ_nio`005OoonfX00ol0Looooo]ZoookJP0PoookJP03ool0j_oo
nf[ooo]Z00gooo]Z0_oo5P02oonB00[ooo]Z0ooo0?`@oookJPSoo`H01OoonfX7oaP0o`oooo]Z1?oo
0?`7oookJP;ooi800_oo5P09oookJP03o`00Oooo0>[oo`3Z00?ooo]Z0ol007l3oookJP?o001o1_oo
nfX4o`000003o`1coooonf[ooo]Z00[ooo]Z00?o^Ol0oomB0?l0oc<00_oonfX02?l0:_oooo]Zoook
J_oonf[o?ol0oookJ_l0g?ooN?l02?oonfX01?l0oa_ooo]ZoookJ_oobP03oookJP03o`3ioooo09?o
o`0C00Gooo]Z00?of_l0on7o0?oonfX00_oonfX00olV0?oooo]Zoh@0o`0>oookJP0?oc7o0?l0oe_o
oo]ZoookJ_l0ok3oP_l0o`3o/Ol0<?oooo]Zo`3oCOl0j?oo1P3ooookJ_oo0?GoT_l000;ooo]Z00?o
o`1Zo`0Iool@0?l00_oonfX01olE0?ooo`1AoookJ_oonf[o0:gooookJ_oo07T01_oonfX01ol0oe?o
oo]ZoookJ_l0o`So0?lMoookJ_l0hOl02_oonfX00ol0ocCooo]Zo`3oCP06oookJP03o`28ool0ZOoo
oo]Z00;ooo]Z00?o00CooookJ_l0e?l03OoonfX00oooP@3ooo]ZoookJP0;oookJP03ool0;Ooonf[o
oo]Z00Kooo]Z00?ooeL0oookJ_oonfX02?oonfX00oo[0?oooo]Zo`3o1@02oookJP03oonn0?oonf[o
oo]Z03Cooo]Z000^oookJP03ocd0ool0omooN?l000;ooo]Z00CoA?l0oookJ_oonf[o?ol00_oonfX0
0ol0:_oooo]ZoookJP03oookJP03oomB0?oonf[o^Ol001Kooo]Z00?o07?ooookJ_oonfX08?oonfX0
0ooo0>[ooo]ZoookJP0=oookJP;ooaH000?ooo]ZoonB0?ooTP000_oonfX6oomi00?ooo]Z0oooN@0D
oookJPKo603o4_oonfX4ool0o0Oooo]Z0oooTP02oolF00Wooo]Z2_oo:002o`00O`?ooo]Z0ol007l6
oookJP;o000000?o07?oo`000?oonfX02ooonfX00onio`3ooe80o`3o<`02oookJP04oomi0?oonf[o
oo]Zocoo00Ooo`001?oonfX01OlB0?oo0?lKoookJ_oonf[oolX000?ooo]Z00?o0?WooolX0?oo01<0
1OoonfX9ooo900cooo]Z0ooo00003Ol0oe_ooo]Zoh;o0?l0ok3oo`00o`0`ool0odgooo]Zool00?l6
0?oooo]ZoolX0?nBo`000_oonfX00ooo003o403ooookJP03oookJP06ool0DOoonf[ooo]ZoookJ_l0
[Oooo`1i1_oonfX01_l0oe?ooo]ZoookJ_oonf[o0?lMo`3Qo`cooo]Z00?oolT0o`3oC_oonfX01Ooo
nfX00ol0R?oooo]Zo`2Yo`02oookJP03o`04oooonf[o0=Co00gooo]Z00?ooh40oookJ_oonfX02ooo
nfX00ooo02gooo]ZoookJP06oookJP03oomG0?oonf[ooo]Z00Sooo]Z00?oj`3ooookJ_l0o`D00_oo
nfX00ooob@3ooo]ZoookJP1OoookJP03ocd0ool0omooN?l000;ooo]Z00Co0=cooookJ_oonf[o?ol0
0_oonfX00ol0:_oooo]ZoookJP03oookJP04oomB0?oonf[ooo]ZokWo01Gooo]Z00?o07?ooookJ_oo
nfX08?oonfX2ool0jPoooo]Z0_oo5P02oonB00_ooo]Z0ooo0?`EoookJPGo603o4_oonfX4ool0o0So
oo]Z0oooTP000ooo5P3ooo]ZoookJP07oookJP;o001o0_oo0>X2o`00O`?ooo]Z0ol007l3oookJP?o
001o1_oonfX3o`000003o`1coooonf[ooo]Z00[ooo]Z00?o^Ol0oomB0?l0oc<00_oonfX00ol0:_oo
oo]ZoookJP02ocoo0003oookJ_l0g?ooN?l000Sooo]Z00Go0?lKoookJ_oonf[ooo]Zooo:0002oook
JP03o`3ioooo09?oo`0C00Gooo]Z00?of_l0on7o0?oonfX00_oonfX00olV0?oooo]Zoh@0o`0>oook
JP03oc7o0?oonf[o0?mK00;ooo]Z00ooP_l0oookJ_l0<?oooo]Zo`3oCOl0j?oooo]Zo`H0oooonf[o
o`3eoi;o0?oonf[oo`1Zo`0Iool@0?l00ooonfX01_lE0?ooo`1AoookJ_oonf[o0:goool0N@Kooo]Z
00Oo0?mCoookJ_oonf[ooo]Zo`3o7Ooonf[o0>7o00_ooo]Z00?o0?ldo`3oC_oonfX01OoonfX00ol0
R?oooo]Zo`2Yo`03oookJP03o`04oooonf[o0=Co00cooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo
02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z00Sooo]Z00?oj`3ooookJ_l0o`D00_oonfX00ooo
_P3ooo]ZoookJP0doookJP00;_oonfX01_lm0?oo0?oOoookJ_mho`3ooo]ZodCo00;ooo]Z00Co?ol0
oookJ_oonf[o02[o1_oonfX00oooDP3ooo]ZokWo000EoookJP03o`1coooonf[ooo]Z027ooo]Z00?o
o`3ZoookJ_oonfX03_oonfX3oolF00;ooi8000?ooo]Zoomi0?ooN@000oooN@06oookJP?oogT08_oo
nfX2oolX0003oookJ_oo0?coo`3l00;oo`3l2OoonfX2oonB0003oookJ_oo5P3ooaH000[ooo]Z2Ooo
:002oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX01?l0003o07?oo`000?l0000;oookJP04
okWo0?ooDP3ooo]ZoookJP;oogT00_oonfX00oloo`3ooo]Zool00004ool000Gooo]Z00Go4P3oo`3o
6ooonf[ooo]Zooo:0003oookJP03o`3ioooo:03oo`0C00Gooo]Z00?of_l0ooo90?oob@001Ooob@0>
oookJP;oo`0000Oo0?mKoookJ_oonf[oP_l0ool00?l0<?oo0?m=00;ooo]Z00Co0>Soo`H0oooonf[o
T_l00_oo00000ooonf[o403oool00003oookJP06ool0DOoonf[ooo]ZoookJ_l0[Oooo`1i1ooonfX0
1_l0oe?ooo]ZoookJ_l0o`So0?lMo`3Qo`_ooo]Z00?oolT0oookJ_l0odh01_oonfX00ol0R?oo0:Wo
oookJP02oookJP03o`04oooonf[o0=Co00cooo]Z00?ooh40oookJ_oonfX03?oonfX00ooo02gooo]Z
oookJP06oookJP03oomG0?oonf[ooo]Z00Oooo]Z00Coj`3oog00oooonf[o0?l50_oonfX00ooob@3o
oo]ZoookJP1PoookJP03o`3ogooonf[oN?l000;ooo]Z00?o0=cooookJ_loo`000ooonfX00ol0:_oo
oo]ZoookJP03oookJP04oomB0?oonf[ooo]ZokWo01Gooo]Z00?o07?ooookJ_oonfX08OoonfX00ooo
0>[ooo]ZoookJP0>oookJP;ooaH00_ooTP0<oookJP?oo`3l9OoonfX4ool0o0[ooo]Z0_ooTP02oolF
00_ooo]Z00?o001oool0j_l007l00ol007l4oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX2
o`000003o`1cool0003ooo]Z00[ooo]Z00?o^Ol0oomB0?l0oc<00_oonfX01?l0:_oooo]ZoookJ_lo
o`02oookJP03o`3Loomho`3ooo]Z00Oooo]Z00Go4P3oo`3o6ooonf[ooo]Zooo:0002oookJP03o`3i
oooo09?oo`0C00Gooo]Z00?of_l0on7o0?oonfX00_oonfX00olV0?oooo]Zoh@0o`0?oookJP0?oc7o
0?l0oe_ooo]ZoookJ_l0ok3oP_l0o`0`oooonf[o0?m=oookJ_l0j?oo1P3ooookJ_oo0?GoT_l000;o
oo]Z00?oo`1Zoa00oooonfX00_oonfX01_lE0?ooo`1AoookJ_oonf[o0:goool0N@Oooo]Z00Oo0?mC
oookJ_oonf[o0?l8o`3o7Ooonf[o0>7o00[ooo]Z00?o0?ldoookJ_l0odh01_oonfX00ol0R?oo0:Wo
oookJP03oookJP03o`04ool0e?oooo]Z00cooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02gooo]Z
oookJP06oookJP03oomG0?oonf[ooo]Z00Sooo]Z00?oj`3oog00ool0o`D00_oonfX00ooo_P3ooo]Z
oookJP0eoookJP00;ooonfX00olm0?oo0?oOogSo0002oookJP04odCo0?oonf[ooo]Zocoo00;ooo]Z
00?o02[ooookJ_oonfX00ooonfX01?ooDP3oolT0oookJ_nio`0EoookJP03o`1coooonf[ooo]Z027o
oo]Z0_oo0>XAoookJP;ooaH00oooTP03oomi00Wooo]Z0oooN@0MoookJP03oolX0?oo0?coo`3l00;o
o`3l2_oonfX6oolX00_ooo]Z1ooo:0000ol007oooo]ZoookJP02oookJPOo001o1ooonfX01?l0Looo
0000o`000?l0000:oookJP05oomi0?ooDP3ooo]ZoookJ_ooN@000ooonfX00oloo`3ooo]ZoookJP04
ool000Gooo]Z00Go4P3ooolX0?l0oa_ooo]Zooo:0003oookJP04o`3ioooo:03ooo]Zool04`Cooo]Z
00?of_l0oookJ_oob@001Ooob@0>oookJP;oo`0000go0?mKoookJ_oonf[oP_l0oookJ_oo003o033o
o`3oCOoonf[o0>Soo`H0oooonf[oT_l000?oo`0000Oo403oool00?oo003oo`00oookJ_oo057oo`00
00;ooo]Z00?o0:gooookJ_oo07T01_oonfX01_l0oe?ooo]ZoookJ_l0o`So0?lMo`3Qo`cooo]Z00?o
olT0o`3oC_oonfX01OoonfX00ol0R?oo0:WooookJP02oookJP03o`04oooonf[o0=Co00gooo]Z00?o
oh40oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP06oookJP03oomG0?oonf[ooo]Z00Sooo]Z00Ko
j`3ooookJ_oonf[o0?l5oookJ_oob@1SoookJP06ocd0ool0omoooo]ZogSo0?oonf[o0=co0_oonfX0
1Oloo`3ooo]ZoookJ_oonf[o02[o00Gooo]Z00Cooe80oookJ_oonf[o^Ol05?oonfX00ol0Looooo]Z
oookJP0RoookJP;oo`3Z4?oonfX2oolF00?ooi803?oonfX3ool0o1kooo]Z1?oo0?`;oookJP?ooi80
0_oo5P0<oookJP;oo`3Z00?ooo]Zo`00Ool007l00_l007l4oookJPOo001o1ooonfX01?l0003o07?o
o`000?l0000:oookJP03okWo0?ooDP3o0?lc00;ooo]Z00Co02[ooookJ_oonf[o?ol00_oonfX00ol0
g?ooN?l0oookJP06oookJP03o`2>oolB0?oo0?lK00;ooo]Z00OoolX0oookJ_oonf[o0?Woool0Tooo
nf[oo`0C00Cooo]Z00?of_l0oookJ_oQo`000_oonfX00olV0?oo8?l0oh@0o`0?oookJP0?oc7o0?l0
oe_ooo]ZoookJ_l0ok3oP_l0o`3o/Ol0<?oooo]Zo`3oCOl0j?oo1P3ooookJ_oo0?GoT_l000;ooo]Z
00?oo`1Zoa00oooonfX00ooonfX01_oo057ooo]ZoookJ_l0[Ooooo]Zool0N@Kooo]Z00Oo0?mCoook
J_oonf[o0?l8o`3o7Ooonf[o0>7o00_ooo]Z00?o0?ldo`3oC_oonfX01OoonfX00ol0R?oo0:Wooook
JP03oookJP03o`04oooonf[o0=Co00cooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02gooo]Zoook
JP07oookJP03oomG0?oonf[ooo]Z00Sooo]Z00?oj`3ooookJ_l0o`D00_oonfX00ooo_P3ooo]Zoook
JP0eoookJP00;ooonfX01_lm0?oooo]Zo`3ogomho`3ooo]ZodCo00;ooo]Z00Go?ol0oookJ_oonf[o
oo]Zo`0Zo`05oookJP03oomB0?oonf[o^Ol001Kooo]Z00?o07?ooookJ_oonfX08_oonfX00ooo0>[o
oo]ZoookJP0@oookJP;ooaH000?ooo]ZoonB0?ooN@003OoonfX00oooN@3oo`3lool0o00Kool0o0Co
obP01OoonfX8oolX00gooo]Z1Ooo:0001?oonf[o001oo`00Ool007l5oookJPGo001o1_oonfX2o`1c
o`Co00002OoonfX01Onio`3ooe80oomi0?oonf[oogT000?ooo]Z00?o?ol0oookJ_oonfX00ooo0006
oookJP05oa80oooonf[o0?lKoookJ_oobP000ooonfX01?l0nOooobP0oookJ_oo01<5oookJP03om[o
0?oob@3oolT000CoolT03ooonfX03_oo003o0?mKoookJ_oonf[oP_l0o`3o/?oo003o033oo`3oCOoo
nf[o0>Soo`H0oooonf[oT_l01?oo00000ol@0?ooo`00ool00002ool00006ool0DOoonf[ooo]Zo`2]
oooonf[oo`1i1ooonfX01_l0oe?ooo]ZoookJ_l0o`So0?lMo`3Qo`_ooo]Z00?oolT0o`3oC_l0obh0
1_oonfX00ol0R?oo0:WooookJP02oookJP03o`04oooonf[o0=Co00cooo]Z00?ooh40oookJ_oonfX0
3?oonfX00ooo02gooo]ZoookJP06oookJP03oomG0?oonf[ooo]Z00Sooo]Z00?oj`3ooookJ_l0o`D0
0_oonfX00ooob@3ooo]ZoookJP0@oookJP03oon@0?oonf[ooo]Z04oooo]Z00?o?@3oo`3ogomho`00
0_oonfX00ol0g?oooo]Zocoo0004oookJP03o`0Zoooonf[ooo]Z00;ooo]Z00Co0?lcoomB0?oonf[o
^Ol05OoonfX00ol0Looooo]ZoookJP0SoookJP03ool0j_oonf[ooo]Z00oooo]Z0_oo5P000ooonf[o
oi80oonB000=oookJQkoo`3l2_oonfX5oonB00;ooaH03OoonfX2ool0jPCooo]Z0ol007l5oookJPGo
001o1ooonfX2o`1co`?o00002OoonfX00onio`3ooe80oookJP02oookJP04o`0Zoooonf[ooo]Zocoo
00;ooo]Z00?o0=coogSo0?oonfX01_oonfX00ol0S_oo4P3oo`3o6`02oookJP07ooo:0?oonf[ooo]Z
o`3ioooo09?ooo]Zool04`05oookJP03om[o0?oQo`3ooo]Z00;ooo]Z00?o9P3ooh@0oooonfX03_oo
nfX00olao`3o0?mKoookJP02oookJP0:oh;o0?l0ok7o033ooookJ_l0odgo0>SooookJ_l60?oooo]Z
oi;o00?ooo]Z00?oo`1Zoa00oooonfX00_oonfX01_lE0?ooo`1AoookJ_l0[Ooooo]Zool0N@Oooo]Z
00Oo0?mCoookJ_oonf[o0?l8o`3o7Ooonf[o0>7o00[ooo]Z00?o0?ldo`3oC_l0obh01_oonfX00ol0
R?oo0:WooookJP03oookJP03o`04ool0e?oooo]Z00cooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo
02gooo]ZoookJP06oookJP03oomG0?oonf[ooo]Z00Wooo]Z00Goj`3oo`3o1Ooonf[ooo]Zoonn000C
oookJP03oon@0?oonf[ooo]Z02;ooo]Z000_oookJP04ocd0oooonf[ooo]ZogSo00;ooo]Z00CoA?l0
oookJ_oonf[o?ol00ooonfX00ol0:_oooo]ZoookJP03oookJP03oomB0?oonf[o^Ol001Kooo]Z0_l0
LolSoookJP;oo`3Z4_oonfX2oolF0003oookJ_ooTP3ooi8002Cooo]Z4_oo:00@oookJP?oobP05Ooo
nfX2o`1co`;ooo]Z1?l00008oookJP03o`3o<oooDP3oogT000;oogT00_oonfX2ocoo0004oookJ_l0
g?oo0?oOool000Oooo]Z00Go4P3ooookJ_l0oa_ooo]Zooo:0003oookJP04o`3ioooo:03ooo]Zool0
4`Gooo]Z00?of_l0on7o0?oob@001?oob@0@oookJP0>oc7o0?oonf[ooo]ZoookJ_n2o`3oo`00o`0`
ool0odgooo]Zo`3Xoooonf[o1P3ooookJ_nBo`03ool00003oa00oooo003oo`0000;oo`0000Ooo`1A
ool00?oo003ooo]Zo`2]oooonf[oo`1i00Kooo]Z00Ko0?mCoookJ_oonf[o0?l8o`3o7Ol0hOl7oook
JP;oolT00ooonfX00ooob@3o0?m>oookJP05oookJP03o`28ool0ZOoooo]Z00;ooo]Z00?o00Cooook
J_l0e?l03OoonfX00oooP@3ooo]ZoookJP0<oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooeL0oook
J_oonfX02?oonfX01?o[0?oooo]ZoookJ_l0o`D2oookJP03ooo90?oonf[ooo]Z013ooo]Z00?ooi00
oookJ_oonfX0CooonfX01?lm0?oooo]Zo`3ogomho`02oookJP03o`3Loooonf[o?ol000Cooo]Z00?o
02[ooookJ_oonfX00_oonfX01?ooDP3ooo]ZoookJ_nio`0EoookJP;o07?o9?oonfX00ooo0>[ooo]Z
oookJP0@oookJP?ooaH00_ooTP0^oookJPGooi800ooo5P0@oookJP03ool0j_oonf[ooo]Z01Kooo]Z
0_l0Lol00ooonf[o0000o`000002o`0000Sooo]Z00?o^Ol0oomB0?oonfX00_oonfX02?l0:_oooo]Z
ocoo0?loo`3ooo]Zo`3Lool0omooN?l01ooonfX00ol0S_oo4P3oo`3o6`02oookJP07ooo:0?oonf[o
oo]Zo`3ioooo09?ooo]Zool04`05oookJP03om[o0?oQo`3ooo]Z00;ooo]Z00?o9P3ooh@0oooonfX0
3ooonfX03olao`3ooo]ZoookJ_oonf[o0?n`oh;o0?l0<?oooo]Zo`3oCOl0j?oooo]Zo`H0oooonf[o
o`3eoi;o0002oookJP03ool0J_l@0?oooo]Z00;ooo]Z00Oo5@3oool0DOoonf[ooo]Zo`2]oooonf[o
o`1i00Kooo]Z00Oo0?mCoookJ_oonf[o0?l8o`3o7Ooonf[o0>7o00_ooo]Z00?o0?ldo`3oC_oonfX0
1_oonfX00ol0ZOoooo]ZoookJP02oookJP03o`04oooonf[o0=Co00cooo]Z00?ooh40oookJ_oonfX0
3?oonfX00ooo02gooo]ZoookJP06oookJP03oomG0?oonf[ooo]Z00Sooo]Z00?oj`3ooookJ_l0o`D0
0_oonfX00ooo_P3ooo]ZoookJP0AoookJP03oon@0?oonf[ooo]Z02;ooo]Z000`oookJP04ocd0oooo
nf[o0?oOogSo00;ooo]Z00CoA?l0oookJ_oonf[o?ol00ooonfX00ol0:_oooo]ZoookJP03oookJP03
oomB0?oonf[o^Ol001Oooo]Z00?o07?ooookJ_oonfX08_oonfX00ooo0>[ooo]ZoookJP0AoookJP?o
oaH01_ooTP0LoookJQ3oobP04OoonfX2ool0jP03oolX0?oonf[ooo]Z01Gooo]Z00?o07?ooookJ_oo
nfX00_oonfX4o`0000Oooo]Z00?o0?lcoomB0?ooN@001?ooN@001_loo`3ooo]ZoookJ_l0g?ooN?l0
ool000Oooo]Z00?o4P3ooookJ_l0oa/00_oobP03oookJP04o`3ioooo:03ooo]Zool04`Gooo]Z00?o
f_l0on7o0?oob@001?oob@0@oookJP0>oc7o0?l0oe_ooo]ZoookJ_n2o`3o0?n`o`0`oooonf[o0?m=
o`3Xoooonf[o1P3ooookJ_nBo`03ool00003oa00oooo003oo`0000;oo`0000?oo`1Aool00?oo0000
0_oo00000ooonf[oo`1ioookJP05oookJP07o`3oDooonf[ooo]ZoookJ_l0o`So0?lMo`3Qo`07oook
JPGoolT000?o0?m>o`3o;_oonfX01OoonfX00ol0R?oo0:WooookJP02oookJP03o`04oooonf[o0=Co
00cooo]Z00?ooh40oookJ_oonfX03?oonfX00ooo02gooo]ZoookJP06oookJP03oomG0?oonf[ooo]Z
00Sooo]Z00Koj`3ooookJ_oonf[o0?l5oookJ_oob@0BoookJP03oon@0?oonf[ooo]Z057ooo]Z00?o
?@3oo`3ogomho`000_oonfX01?l0g?oooo]ZoookJ_loo`04oookJP03o`0Zoooonf[ooo]Z00;ooo]Z
00Cooe80oookJ_oonf[o^Ol05_oonfX00ol0Looooo]ZoookJP0RoookJP;oo`3Z4ooonfX2oolF00Ko
oi808ooonfX5oonB00CooaH04OoonfX3ool0jQSooo]Z00Co07?ooookJ_oonf[ooo]Z1?l00007oook
JP03okWo0?ooDP3ooo]Z00;ooo]Z00?o02[ooookJ_loo`000_oonfX00ol0g?ooN?l0ogSo0007oook
JP04o`2>oolB0?oo0?lKoookJP;oolX00_oonfX01?l0nOooo`2CoookJ_oo01<5oookJP03om[o0?oQ
o`3ooo]Z00;ooo]Z00?o9P3ooh@0oooonfX03ooonfX00olao`3o0?mKoookJP02oookJP05oh;o0?l0
<?oooo]ZoookJ_l0odd00_oonfX00ol60?ooo`3eoi;o0002oookJP03ool0J_l@0?oooo]Z00?ooo]Z
00Koo`1AoookJ_oonf[o0:gooookJ_oo07T6oookJP08o`3oDooonf[ooo]ZoookJ_l0o`So0?lMoook
J_l0hOl:oookJP03o`3o=?l0odko0?l^00Kooo]Z00?o08Soo`2YoooonfX00ooonfX00ol01?oo0=Co
oookJP0<oookJP03oon10?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX01_oonfX00oooE`3ooo]Z
oookJP09oookJP03on/0oooonf[o0?l500;ooo]Z00?ookh0oookJ_oonfX04?oonfX00oooT03ooo]Z
oookJP0SoookJP00<?oonfX01?lm0?oooo]ZoookJ_mho`02oookJP04odCo0?oonf[ooo]Zocoo00Co
oo]Z00?o02[ooookJ_oonfX00_oonfX01?ooDP3ooo]ZoookJ_nio`0GoookJP03o`1coooonf[ooo]Z
02;ooo]Z00?oo`3ZoookJ_oonfX04ooonfX2oolF00Cooo]Z2_ooTP0@oookJPkoobP04_oonfX3ool0
jQSooo]Z0_l0Lol5oookJPCo00001_oonfX2oomB00OoogT000?ooo]Zo`3Loomho`002?oonfX01?lB
0?oooo]Zo`3o6ooobP04oookJP04o`3ioooo:03ooo]Zool04`Gooo]Z00?of_l0on7o0?oonfX00ooo
b@000olPo`3ooo]ZoookJP0>oookJP0?oc7o0?l0oe_ooo]ZoookJ_n2o`3o0?n`ool00?l0<?oo0?m=
o`3Xoooonf[o1P3ooookJ_nBo`3ooo]Z00;oo`0000?o403oool00?oo00000ooo00000ooo057oo`00
ool00002ool00003oookJ_oo07Wooo]Z00Gooo]Z00Ko0?mCoookJ_oonf[o0?l8o`3o7Ol0hOl8oook
JPGoolT000?o0?m>ooo90?oonfX01?oonfX00ol0R?oo0:WooookJP02oookJP03o`04oooonf[o0=Co
00gooo]Z00?ooh40oookJ_oonfX03?oonfX00ooo02gooo]ZoookJP05oookJP03oomG0?oonf[ooo]Z
00Sooo]Z00Coj`3oog00oooonf[o0?l50_oonfX00ooob@3ooo]ZoookJP0@oookJP03oon@0?oonf[o
oo]Z057ooo]Z00Co?@3ooookJ_l0omooN?l00_oonfX00ol0g?oooo]Zocoo0004oookJP03o`0Zoooo
nf[ooo]Z00;ooo]Z00Go0?lcoomB0?oonf[ooo]ZokWo000FoookJP03o`1coooonf[ooo]Z02?ooo]Z
00?oo`3ZoookJ_oonfX04_oonfX2oolF00Cooo]Z2_ooTP0DoookJPGooi801?oo5P0CoookJP?oo`3Z
6OoonfX2o`1co`Cooo]Z1?l00006oookJP;ooe800ooonfX00ol0:_oooo]Zocoo0002oookJP03o`3L
oomho`3o?@3o00Oooo]Z00Go08kooa80ool0oa_ooo]Zooo:0003oookJP04o`3ioooo09?ooo]Zool0
4`Gooo]Z00?of_l0on7o0?oonfX00_oonfX00olV0?oo8?l0oookJP0?oookJP03oc7o0?l0oe_ooo]Z
00;ooo]Z00[oP_l0o`3o/Ol0<?oooo]Zo`3oCOl0j?oooo]Zo`H0oooonf[oT_l00_oonfX00ol0GOoo
403oo`0Io`03oookJP04oaD0oooo057ooo]Zo`2]o`;ooo]Z00?oo`1ioookJ_oonfX01?oonfX01ol0
oe?ooo]ZoookJ_l0o`So0?lMoookJ_l0hOl02ooonfX00ol0ocCo0?m>oookJP06oookJP03o`2Yoooo
nf[ooo]Z00;ooo]Z00?o00CooookJ_l0e?l03?oonfX00oooP@3ooo]ZoookJP0<oookJP03ool0;Ooo
nf[ooo]Z00Kooo]Z00?ooeL0oookJ_oonfX02?oonfX00oo[0?ooL03oo`3o1@02oookJP03oonn0?oo
nf[ooo]Z017ooo]Z00?ooi00oookJ_oonfX08ooonfX0037ooo]Z00Co?@3ooookJ_oonf[oN?l00_oo
nfX01?m4o`3ooo]ZoookJ_loo`04oookJP03o`0Zoooonf[ooo]Z00;ooo]Z00Cooe80oookJ_oonf[o
^Ol05ooonfX2o`1cob?ooo]Z0ooo0>XDoookJPSooaH01_oonfX9oonB00Gooo]Z4?oo:00?oookJP?o
o`3Z6OoonfX2o`1co`Oooo]Z1?l00005oookJP03oomB0?oonf[oogT000SoogT000?oN?l0oookJ_oo
nfX01_oonfX01?lB0?oooo]Zo`3o6ooobP04oookJP05o`3ioooo:03ooo]ZoookJ_oo01<01?oonfX0
0ooJo`3ohOl0oookJP03ooo90003ob3o0?oonf[ooo]Z00kooo]Z00?o<Ol0o`3oFooonfX00_oonfX0
2on2o`3oo`00o`0`ool0odgooo]Zo`3Xoooonf[o1P3ooolX0?nBo`3ooo]Z00;oo`0000?o403oool0
0?oo00000_oo00000ooo057oo`00ool00002ool00003oookJ_oo07Wooo]Z00Gooo]Z00Oo0?mCoook
J_oonf[o0?l8oookJ_l0oago0>7o00Oooo]Z1Ooob@001?l0odkoolT0ooo90?oob@04oookJP03o`28
ool0ZOoooo]Z00;ooo]Z00?o00CooookJ_l0e?l03?oonfX00oooP@3ooo]ZoookJP0<oookJP03ool0
;Ooonf[ooo]Z00Kooo]Z00?ooeL0oookJ_oonfX02?oonfX01_o[0?oooo]ZoookJ_l0o`Gooo]Zooo9
01;ooo]Z00?ooi00oookJ_oonfX0DooonfX01_lm0?oooo]Zo`3ogomho`3ooo]Zo`3Lo`;ooo]Z00?o
?ol0oookJ_oonfX00_oonfX00ol0:_oooo]ZoookJP02oookJP05o`3o<oooDP3ooo]ZoookJ_nio`00
5_oonfX2o`1cobCooo]Z0ooo0>XCoookJPSooaH01_oonfX9oonB00Kooo]Z1OooTP000ooonf[ooaH0
oolF0002oolF01Cooo]Z0ooo0>XJoookJP;o07?o1_oonfX4o`0000Gooo]Z00?ooe80o`3o<ooonfX0
0_oonfX00ol0:_oooo]Zocoo0002oookJP03o`3Loomho`3o?@3o00Oooo]Z00Go08kooa80ool0oa_o
oo]Zooo:0003oookJP05o`3ioooo09?ooo]ZoookJ_oo01<01?oonfX00ooJo`3ohOl0oookJP03oook
JP03obH0oooonf[ooo]Z00kooo]Z00?o<Ol0o`3oFooonfX00_oonfX02ol0ok3oP_l0o`0`oooonf[o
0?m=o`3Xoooonf[o1P3ooookJ_oo0?GoT_l000;ooo]Z00?o403oo`0IoooonfX00ooonfX01_oo057o
oo]ZoookJ_l0[Ooooo]Zool0N@Kooo]Z00So0?mCoookJ_oonf[o0?l8oookJ_l0oagooo]Zo`3Qo`[o
oo]Z00?o0?ldo`3oC_l0obh01_oonfX00ol0R?oo0:WooookJP03oookJP03o`04ool0e?oooo]Z00co
oo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP06oookJP03oomG0?oonf[ooo]Z00Wo
oo]Z00?oj`3ooookJ_l0o`D00_oonfX00ooo_P3ooo]ZoookJP0@oookJP03oon@0?oonf[ooo]Z02Co
oo]Z000boookJP03ocd0oooonf[oN?l000;ooo]Z00CoA?l0oookJ_oonf[o?ol01?oonfX00ol0:_oo
oo]ZoookJP03oookJP03oomB0?oonf[o^Ol001Wooo]Z00?o07?ooookJ_oonfX08ooonfX3ool0jQWo
oo]Z3ooo5P04oonB01;oobP02_oonfX4ool0jQ_ooo]Z00?o07?ooookJ_oonfX01ooonfX4o`0000Co
oo]Z00?ooe80oookJ_ooN@001oooN@000ol0g?ooN?l0oookJP07oookJP04oa80ool0oa_o0?lKooo:
00Gooo]Z00CoobP0oookJ_oonf[oo`0C1?oonfX01?oJo`3ohOl0oookJ_oonfX2ooo90003ob3o0?oo
nf[ooo]Z00kooo]Z00?o<Ol0o`3oFooonfX00_oonfX02on2o`3o0?n`o`0`oooonf[o0?m=o`3Xoooo
nf[o1P3ooookJ_nBo`3ooo]Z00;oo`0000?o403oool00?oo00000_oo00000ooo057oo`00ool00002
ool000;ooo]Z00?oo`1ioookJ_oonfX00ooonfX01ol0oe?ooo]ZoookJ_oonf[o0?l8o`3o7Ol0hOl0
2?oonfX5ooo90004o`3oC_oob@3oolT0ooo900?ooo]Z00?o08Soo`2YoooonfX00ooonfX00ol01?oo
0=CooookJP0<oookJP03oon10?oonf[ooo]Z00cooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooE`3o
oo]ZoookJP08oookJP07on/0oom`0?oooo]ZoookJ_l0o`Gooo]Zooo9000BoookJP03oon@0?oonf[o
oo]Z05Cooo]Z00?o?@3oo`3ogomho`000_oonfX00ol0g?oooo]Zocoo0005oookJP03o`0Zoooonf[o
oo]Z00;ooo]Z00Cooe80oookJ_oonf[o^Ol06?oonfX00ol0Looooo]ZoookJP0ToookJP?oo`3Z6?oo
nfX?oolF00Kooi800_oonfX4oolF01Cooo]Z1?oo0>XKoookJP;o07?o2?oonfX4o`0000Cooo]Z00?o
oe80oookJ_oonfX00_oonfX01?l0:_oooo]Zocoo0?oonfX2o`3Lo`03ogSo0?lm0?oooo]Z00Kooo]Z
00Go08koo`3o6ol0oa_ooo]Zooo:0004oookJP04ool0Tooonf[ooo]Zool04`Cooo]Z00?of_l0on7o
0?oonfX00ooonfX00olV0?oooo]ZoookJP0>oookJP03oc7o0?l0oe_ooo]Z00?ooo]Z00GoP_l0o`0`
oooonf[ooo]Zo`3oC@02oookJP03o`H0oooo0?GoT_l000;ooo]Z00?oo`1Zoa00ool06Ol00ooonfX0
1?oo057ooo]ZoookJ_l0[Ol2oookJP03ool0NOoonf[ooo]Z00?ooo]Z00So0?mCoookJ_oonf[ooo]Z
o`3o2?l0oagooo]Zo`3Qo`_ooo]Z00?o0?ldo`3oC_oonfX01_oonfX00ol0ZOoooo]ZoookJP02oook
JP03o`04oooonf[o0=Co00gooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP06oook
JP03oomG0?oonf[ooo]Z00Sooo]Z00Koj`3oog00oooonf[o0?l5oookJ_oo_P0CoookJP03oon@0?oo
nf[ooo]Z02Cooo]Z000coookJP03ocd0oooonf[oN?l000;ooo]Z00CoA?l0oookJ_oonf[o?ol01?oo
nfX00ol0:_oooo]ZoookJP02oookJP04ooo90?ooDP3ooo]ZokWo01Wooo]Z0_l0LolVoookJPCoo`3Z
9?oonfX6oolF013oobP01ooonfX3ool0jQgooo]Z0_l0Lol:oookJPGo000000Cooo]Zo`3o<oooDP3o
oo]Z1oooN@000ol0g?ooN?l0ogSo0008oookJP04oa80ool0oa_ooo]Zooo:00Gooo]Z00CoobP0oook
J_oonf[oo`0C1OoonfX01_oJo`3ooo]ZoookJ_oonf[oolT0ob3o013ooo]Z00?o<Ol0oookJ_l0oe/0
0_oonfX02_n2o`3o0?n`o`0`oooonf[o0?m=o`3Xoooonf[o1P3ooookJ_nBo`02oookJP03ool00?l@
0?ooo`0000Coo`0000Coo`1Aool00?oo003oo`000_oonfX00ooo07Wooo]ZoookJP04oookJP06o`3o
Dooonf[ooo]Zo`3o2?oonf[o0?lM2OoonfX4ooo90004o`3oC_oob@3oolT0ooo900Cooo]Z00?o0:Wo
oookJ_oonfX00_oonfX00ol01?oooo]Zo`3Do`0<oookJP03oon10?oonf[ooo]Z00gooo]Z00?oo`0]
oookJ_oonfX01OoonfX00oooE`3ooo]ZoookJP08oookJP04on/0oooonf[ooo]Zooo900;ooo]Z00?o
olT0oookJ_oonfX03ooonfX00oooT03ooo]ZoookJP1FoookJP03ocd0ool0omooN?l000;ooo]Z00?o
0=cooookJ_loo`001OoonfX01_l0:_oooo]ZoookJ_oonf[o0?lcoomB00;ooo]Z00?o^Ol0oookJ_oo
nfX05_oonfX2o`1cobOooo]Z1?oo0>XSoookJPSooaH05OoonfX3ool0jQgooo]Z0_l0Lol:oookJPGo
00000_oonfX00oooDP3ooo]ZoookJP02oookJP05o`0Zooloo`3o?ol0oookJ_l0g?l00_mho`000olm
0?oooo]ZoookJP05oookJP05o`2>ool0oa_ooo]ZoookJ_oobP001?oonfX01?oo09?ooo]ZoookJ_oo
01<5oookJP03om[o0?oonf[ooo]Z00;ooo]Z00?o9P3ooookJ_oonfX03_oonfX00olao`3ooo]Zo`3o
F`03oookJP05oh;o0?l0<?oooo]ZoookJ_l0odd00_oonfX00ol60?oooo]Zoi;o0002oookJP03o`1M
ool@0?oo01Wo00?ooo]Z00Co5@3oool0DOoonf[o0:go0_oonfX00ooo07Wooo]ZoookJP04oookJP07
o`3oDooonf[ooo]Zo`3o2?oonf[o0?lMo`3Qo`0;oookJP03o`3o=?l0odkooo]Z00Kooo]Z00?o0:Wo
oookJ_oonfX00ooonfX00ol01?oo0=CooookJP0<oookJP03oon10?oonf[ooo]Z00cooo]Z00?oo`0]
oookJ_oonfX01OoonfX00oooE`3ooo]ZoookJP09oookJP03on/0oooonf[o0?l500;ooo]Z00?ookh0
oookJ_oonfX04?oonfX00oooT03ooo]ZoookJP0UoookJP00=?oonfX00olm0?oooo]ZogSo0002oook
JP04odCo0?oonf[ooo]Zocoo00Cooo]Z00?o02[ooookJ_oonfX00_oonfX01?ooDP3ooo]ZoookJ_ni
o`0JoookJP03o`1coooonf[ooo]Z02Oooo]Z1?oo0>XjoookJP?oo`3Z7_oonfX2o`1co`cooo]Z1?l0
00001?oonf[o0?lcoomB0?oonfX6oomi0004oookJ_l0g?ooN?l0o`3og`Sooo]Z00Co4P3oo`3o6ooo
nf[oolX01OoonfX01?oo:03ooo]ZoookJ_oo01<5oookJP07om[o0?oonf[ooo]ZoookJ_oob@3oQ03o
ob3o000?oookJP03oc7o0?oonf[o0?mK00?ooo]Z00GoP_l0ool00?l0<?oo0?m=o`3Xo`02oookJP03
o`H0oonBo`3ooo]Z00;ooo]Z00Oo403oool00?oo003oo`00oookJ_oo003oo`1A00?oo`000_oonfX0
0ooo07Wooo]ZoookJP04oookJP07o`3oDooonf[ooo]ZoookJ_l0o`So0?lMo`3Qo`09oookJP?oolT0
00Co0?m>ooo90?oob@3oolT01OoonfX00ol0ZOoooo]ZoookJP02oookJP03o`04ool0e?oooo]Z00co
oo]Z00?ooh40oookJ_oonfX03?oonfX00ooo02gooo]ZoookJP05oookJP03oomG0?oonf[ooo]Z00Wo
oo]Z00Koj`3ooookJ_oonf[oolT0oookJ_oob@0BoookJP03oon@0?oonf[ooo]Z05Oooo]Z00Go?@3o
ogSo0?oonf[ooo]Zo`3Lo`02oookJP03ocoo0?oonf[ooo]Z00?ooo]Z00Ko02[ooookJ_oonf[ooo]Z
o`3o<oooDP02oookJP03okWo0?oonf[ooo]Z01Oooo]Z00?o07?ooookJ_oonfX0:?oonfX4ool0jSWo
oo]Z0ooo0>XOoookJP03o`1coooonf[ooo]Z00[ooo]Z1?l000000ooonf[o^Ol0oomB0004oookJP08
o`0Zooloo`3ooo]ZoookJ_l0g?ooN?l0o`3ogolm0?l7oookJP05o`2>ool0oa_ooo]ZoookJ_oobP00
1?oonfX01?oo09?ooo]ZoookJ_oo01<5oookJP04om[o0?oonf[ooo]ZoookJP;o9P3o00?o8?l0oook
J_oonfX03OoonfX00olao`3ooo]Zo`3oF`03oookJP05o`3o/?n2o`3o033ooookJ_l0odd00_oonfX0
0ol60?oooo]Zoi;o0003oookJP03oa00ool06Ooooo]Z00?ooo]Z00?oo`1AoookJ_l0[Ol00_oonfX0
0ooo07Wooo]ZoookJP04oookJP08o`3oDooonf[ooo]ZoookJ_l0o`So0?lMoookJ_l0hOl;oookJP03
o`3oC_l0obkooo]Z00Kooo]Z00?o0:WooookJ_oonfX00_oonfX00ol01?oooo]Zo`3Do`0=oookJP03
oon10?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX01_oonfX00oooE`3ooo]ZoookJP09oookJP05
on/0oooonf[o0?l5oookJ_oo_P004ooonfX00oooT03ooo]ZoookJP0UoookJP00=OoonfX01Olm0?oo
N?l0o`3ogooonf[oA?l000;ooo]Z00?o?ol0oookJ_oonfX00ooonfX00ol0:_oooo]ZoookJP02oook
JP04oomB0?oonf[ooo]ZokWo01[ooo]Z00?o07?ooookJ_oonfX0:_oonfX3ool0jS?ooo]Z1?oo0>XO
oookJP;o07?o3_oonfX4o`000004o`3o<oooDP3ooo]ZoookJPCoogT000Gooo]Zo`3Lool0g?ooN?l0
o`3og`08oookJP04oa80ool0oa_ooo]Zooo:00Gooo]Z00CoobP0oookJ_oo01?oo`0C1OoonfX01ooJ
o`3ooo]ZoookJ_oonf[o9P3ooh@0oolPo`004?oonfX00olao`3o0?mKoookJP02oookJP05oh;o0?l0
ok3o033ooookJ_l0odd00_oonfX00ol60?oooo]Zoi;o0002oookJP05ool00?l@0?ooo`00ool00?oo
nfX00_oo00000ooo057oo`00ool00003oookJP03ool0NOoonf[ooo]Z00?ooo]Z00Oo0?mCoookJ_oo
nf[ooo]Zo`3o2?oonf[o0?lM00[ooo]Z0ooob@000ol0odkoolT0ooo90005oookJP03o`2Yoooonf[o
oo]Z00;ooo]Z00?o00CooookJ_l0e?l03?oonfX00oooP@3ooo]ZoookJP0=oookJP03ool0;Ooonf[o
oo]Z00Gooo]Z00?ooeL0oookJ_oonfX02?oonfX01?o[0?oooo]ZoookJ_oob@02oookJP03ooo90?oo
nf[ooo]Z00oooo]Z00?ooi00oookJ_oonfX0FOoonfX01olm0?ooN?l0oookJ_oonf[o0=cooookJ_lo
o`001OoonfX00ol0:_oooo]ZoookJP02oookJP05o`3o<oooDP3ooo]ZoookJ_nio`006OoonfX00ol0
Looooo]ZoookJP0[oookJP?oo`3Z<_oonfX4ool0jR3ooo]Z0_l0Lol=oookJPCo000000?o^Ol0oomB
0?oonfX00ooonfX00ol0:_oo?ol0oookJP02o`3Lo`03ogSo0?l0omoo?@3o00Oooo]Z00Go08koo`3o
6ooonf[ooo]Zooo:0004oookJP04ool0Tooonf[oo`0Cool04`Gooo]Z00Oof_l0oookJ_oonf[ooo]Z
obH0oooonf[o8?l0013ooo]Z00?o<Ol0o`3oFooonfX00ooonfX01On2o`3o033ooookJ_oonf[o0?m=
00;ooo]Z00?o1P3oool0mOnBo`000_oonfX00ol@0?ooo`1Zo`0Io`03oookJP04oaD0oooo057ooo]Z
o`2]o`;ooo]Z00?oo`1ioookJ_oonfX00ooonfX02?l0oe?ooo]ZoookJ_oonf[o0?l8oookJ_l0oago
0>7o2ooonfX00ol0ocCo0?m>oookJP06oookJP03o`2Yoooonf[ooo]Z00?ooo]Z00?o00Coo`3Doooo
nfX03?oonfX00oooP@3ooo]ZoookJP0<oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooeL0oookJ_oo
nfX02OoonfX00oo[0?oooo]Zo`3o1@02oookJP03oonn0?oonf[ooo]Z013ooo]Z00?ooi00oookJ_oo
nfX09_oonfX003Kooo]Z00Go?@3oogSo0?oonf[ooo]ZodCo0002oookJP03ocoo0?oonf[ooo]Z00?o
oo]Z00Ko02[ooookJ_oonf[ooo]Zooo90?ooDP02oookJP03okWo0?oonf[ooo]Z01Sooo]Z0_l0Lol]
oookJPCoo`3Z;?oonfX3ool0jR;ooo]Z00?o07?ooookJ_oonfX03_oonfX2o`000003oolX0?l0oc?o
oe8000;ooo]Z0oooN@000oloo`3ooo]Zo`3Lo`02ogSo0003ocd0oooonf[ooo]Z00Gooo]Z00GoobP0
oa80ool0oa_ooo]Zooo:0005oookJP03oolX0?oonf[oo`0C00Kooo]Z00Oof_l0oookJ_oonf[ooo]Z
obH0oon40?oo8?l0013ooo]Z00?o<Ol0o`3oFooonfX00_oonfX02_n2o`3o0?n`o`0`oooonf[o0?m=
o`3Xoooonf[o1P3ooookJ_nBo`03oookJP03oa00oooo003oo`0000;ooo]Z00Goo`00ool0DOoo003o
o`00o`2]o`02oookJP03ool0NOoonf[ooo]Z00Cooo]Z00Oo0?mCoookJ_oonf[o0?l8oookJ_l0oago
0>7o00Wooo]Z0ooob@000ol0odkoolT0ooo90006oookJP03o`2Yoooonf[ooo]Z00;ooo]Z00?o00Co
o`3DoooonfX03?oonfX00oooP@3ooo]ZoookJP0<oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0
oookJ_oonfX02?oonfX01_o[0?ooolT0ooo90?oob@3ooo]Zooo901;ooo]Z00Gooi00oookJ_oonf[o
oo]ZonKo001HoookJP07o`3ogomho`3ooo]ZoookJ_l0g?oooo]Zocoo0005oookJP07o`0Zoooonf[o
oo]ZoookJ_l0oc?ooo]ZoomB0002oookJP03okWo0?oonf[ooo]Z01Oooo]Z0_l0Lol^oookJPCoo`3Z
:ooonfX3ool0jR;ooo]Z0_l0Lol?oookJP;o000000?o^Ol0o`3o<oooDP001?oonfX01?l0:_oo?ol0
oookJ_l0g?l2ogSo0003oookJ_lm0?oooo]Z00Gooo]Z0_l0S_l01?l0oa_ooo]Zooo:0?oobP04oook
JP03ool0Tooonf[oo`0C00Kooo]Z00Oof_l0oookJ_oonf[ooo]ZobH0oooonf[o8?l0013ooo]Z00?o
<Ol0o`3oFooonfX00ooonfX01On2o`3o033ooookJ_oonf[o0?m=00;ooo]Z00?o1P3ooookJ_nBo`00
0_oonfX00ol0GOoo403oo`0Io`04oookJP03ool0DOoonf[o0:go00;ooo]Z00?oo`1ioookJ_oonfX0
1?oonfX02?l0oe?ooo]ZoookJ_l0o`Sooo]Zo`3o7Ooonf[o0>7o2ooonfX00ol0odko0?l^oookJP06
oookJP03o`2Yoooonf[ooo]Z00?ooo]Z00?o00Coo`3DoooonfX03?oonfX00oooP@3ooo]ZoookJP0;
oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0oookJ_oonfX02OoonfX00oo[0?oooo]Zo`3o1@02
oookJP03oonn0?oonf[ooo]Z013ooo]Z00Gooi00oookJ_oonf[ooo]ZonKo000ToookJP00=ooonfX0
1?mho`3o0?oOoookJ_m4o`03oookJP03ocoo0?oonf[ooo]Z00?ooo]Z00Go02[ooookJ_oonf[ooo]Z
oomB0002oookJP03okWo0?oonf[ooo]Z01[ooo]Z00?o07?ooookJ_oonfX0;_oonfX4ool0jRGooo]Z
0ooo0>XSoookJP;o07?o4OoonfX01?oo:03o0?lco`3o<oooDP02oookJP;oogT00_loo`001Ooonf[o
0=coogSo0?l0omoo?@3o00Oooo]Z00GoobP0oa80ool0oa_ooo]Zooo:0005oookJP03oolX0?oonf[o
o`0C00Kooo]Z00Oof_l0oookJ_oonf[ooo]ZobH0oon40?oo8?l0013ooo]Z00?o<Ol0o`3oFooonfX0
0ooonfX01On2o`3o033ooookJ_l0odgo0>So00;ooo]Z00?o1P3ooi;o0?oonfX00_oonfX00ol@0?oo
o`00ool00003oookJP04ool0DOoo003oo`00o`2]o`?ooo]Z00?oo`1ioookJ_oonfX00ooonfX01ol0
oe?ooo]ZoookJ_oonf[o0?l8o`3o7Ol0hOl02_oonfX3ooo90003o`3oC_oob@3ooo]Z00Gooo]Z00?o
0:WooookJ_oonfX00_oonfX00ol01?oooo]Zo`3Do`0<oookJP03oon10?oonf[ooo]Z00gooo]Z00?o
o`0]oookJ_oonfX01OoonfX00oooE`3ooo]ZoookJP08oookJP03on/0oom`0?ooolT000CoolT04Ooo
nfX00oooT03ooo]ZoookJP02oookJP03onKo0?oonf[ooo]Z05Oooo]Z00CoN?l0oookJ_oonf[o0=co
0_oonfX00oloo`3ooo]ZoookJP03oookJP06o`0Zoooonf[ooo]ZoookJ_l0oc?ooe800_oonfX00oni
o`3ooo]ZoookJP0IoookJP03o`1coooonf[ooo]Z02oooo]Z1?oo0>XToookJP?oo`3Z8ooonfX2o`1c
oa7ooo]Z0_nio`000ol0oc?ooe80oookJP03oookJP08o`0Zooloo`3ooo]Zo`3Loomho`3o0?oOoook
J_lm0?l6oookJP05o`2>oooonf[o0?lKoookJ_oobP001OoonfX00ooo09?ooo]Zool04`06oookJP07
om[o0?oonf[ooo]ZoookJ_lV0?oooo]Zob3o000@oookJP03oc7o0?l0oe_ooo]Z00?ooo]Z00Go0?n`
oh;o0?oonf[ooo]Zo`3oC@02oookJP03o`H0oooonf[oT_l000;ooo]Z00Co05gooa00oooonf[o01Wo
0ooonfX00ooo057ooo]Zo`2]o`03oookJP03ool0NOoonf[ooo]Z00?ooo]Z00So0?mCoookJ_oonf[o
oo]Zo`3o2?l0oagooo]Zo`3Qo`_ooo]Z00?o0?ldo`3oC_oonfX01_oonfX00ol0ZOoooo]ZoookJP03
oookJP03o`04ool0e?oooo]Z00cooo]Z00?ooh40oookJ_oonfX03?oonfX00ooo02gooo]ZoookJP06
oookJP03oomG0?oonf[ooo]Z00Sooo]Z00?oj`3oog00ool0o`D00_oonfX00ooo_P3ooo]ZoookJP0@
oookJP03oon@0?oonf[ooo]Z00;ooo]Z00?oi_l0oookJ_oonfX08_oonfX003Sooo]Z00CoN?l0o`3o
gooonf[oA?l00_oonfX00oloo`3ooo]ZoookJP03oookJP03o`0Zoooonf[ooo]Z00;ooo]Z00Cooe80
oookJ_oonf[o^Ol07?oonfX2o`1coc;ooo]Z0ooo0>XAoookJQ7oo`3Z9?oonfX2o`1coa;ooo]Z00Ko
obP0o`3o<ol0003ooe80o`000?oonfX2oomi0007ocoo0?oonf[ooo]Zo`3Loomho`3o0?oOocd0o`07
oookJP05oolX0?l0oa_o0?lKoookJ_oobP001OoonfX00ooo:03ooo]Zool04`06oookJP07om[o0?oo
nf[ooo]ZoookJ_lV0?ooQ03oob3o000@oookJP04oc7o0?oonf[o0?mKool000;ooo]Z00[oP_l0ool0
0?l0<?oooo]Zo`3oCOoo:03ooo]Zo`H0oooonf[oT_l00_oonfX00ol@0?ooo`00ool00004oookJP03
ool0DOoo003o0:go00?ooo]Z00?oo`1ioookJ_oonfX00ooonfX02?l0oe?ooo]ZoookJ_oonf[o0?l8
o`3o7Ooonf[o0>7o2_oonfX2ooo90003o`3oC_oob@3oolT000Gooo]Z00?o0:Woo`28oooonfX00ooo
nfX00ol01?oo0=CooookJP0<oookJP03oon10?oonf[ooo]Z00cooo]Z00?oo`0]oookJ_oonfX01_oo
nfX00oooE`3ooo]ZoookJP08oookJP03on/0oooonf[oolT000KoolT03ooonfX01OooT03ooo]Zoook
J_oonf[oi_l005_ooo]Z00KoN?l0oookJ_oonf[o0=cooookJ_loo`06oookJP06o`0Zoooonf[ooo]Z
oookJ_l0oc?ooe800_oonfX00onio`3ooo]ZoookJP0IoookJP;o07?o<ooonfX3ool0jQ3ooo]Z4Ooo
0>XUoookJP03o`1coooonf[ooo]Z013ooo]Z00Go^Ol0o`000?l0oc?ooe80o`000003oookJP08o`0Z
oooonf[ooo]Zo`3Loomho`3o0?oOoookJ_lm0?l6oookJP05o`2>ool0oa_o0?lKoookJ_oobP001Ooo
nfX00ooo09?ooo]Zool04`06oookJP07om[o0?oonf[ooo]ZoookJ_lV0?oooo]Zob3o000@oookJP03
oc7o0?oonf[o0?mK00?ooo]Z00Ko0?n`oh;o0?l0<?oooo]Zo`3Xool0odd2oookJP03o`H0oooo0?Go
T_l000;ooo]Z00?o403oool0J_l06Ol00ooonfX01?lE0?ooo`1AoookJ_l0[Ol2oookJP03ool0NOoo
nf[ooo]Z00?ooo]Z00Ko0?mCoookJ_oonf[ooo]Zo`3o2?l0oad2oookJP03o`3Qoooonf[ooo]Z00Wo
oo]Z00?o0?m>o`3o;_oonfX01OoonfX00ol0ZOoo08SooookJP04oookJP03o`04ool0e?oooo]Z00co
oo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP06oookJP03oomG0?oonf[ooo]Z00Wo
oo]Z00?oj`3ooookJ_l0o`D00_oonfX00ooo_P3ooo]ZoookJP0@oookJP05oon@0?oonf[ooo]Zoook
J_oVo`009OoonfX002[ooo]Z00?o08kooookJ_oonfX02ooonfX01Omho`3o0?oOoookJ_oonf[oA?l0
00;ooo]Z00?o?ol0oookJ_oonfX00ooonfX01_l0:_oooo]ZoookJ_oonf[oolT0oomB00;ooo]Z00?o
^Ol0oookJ_oonfX06ooonfX00ol0Looooo]ZoookJP0boookJQ7oo`3Z<ooonfX2o`1coa;ooo]Z0_oo
:0000ol0oc?oiOl0onGo0002o`000004o`0ZooooN@3o?ol0oookJP;o0=co00?oN?l0o`3ogolm0?l0
1ooonfX00ooo:03o0?lKoookJP02ooo:00Gooo]Z00?oobP0oookJ_oo01<01_oonfX01ooQo`3of_l0
oookJ_oonf[o9P3ooh@0oolPo`004?oonfX00olao`3ooo]Zo`3oF`03ool00005oh;o0?oo003o033o
oookJ_l0odd00_oo:0000ol60?oooo]Zoi;o0003oookJP03oa00oooo003ooo]Z00?ooo]Z00Coo`1A
ool00?oonf[o0:go0_oonfX00ooo07Wooo]ZoookJP04oookJP07o`3oDooonf[ooo]ZoookJ_l0o`So
0?lMo`3Qo`0;oookJP;oolT000?o0?m>ooo90?oonfX01OoonfX00ol0ZOoooo]ZoookJP02oookJP03
o`04ool0e?oooo]Z00cooo]Z00?ooh40oookJ_oonfX03OoonfX00ooo02gooo]ZoookJP05oookJP03
oomG0?oonf[ooo]Z00Wooo]Z00?oj`3ooookJ_oob@001ooob@0=oookJP03oon@0?oonf[ooo]Z00;o
oo]Z00?oi_l0oookJ_oonfX0B_oonfX00ol0S_oooo]ZoookJP0<oookJP04ogSo0?lm0?oooo]Zo`3L
o`;ooo]Z00?o?ol0oookJ_oonfX01?oonfX01_l0:_oooo]ZoookJ_l0oc?ooo]ZoomB00;ooo]Z00?o
^Ol0oookJ_oonfX06_oonfX00ol0Looooo]ZoookJP0coookJQ3oo`3Z=?oonfX2o`1coa7ooo]Z0_ni
o`000ooonf[ooe80oomB0002o`000004oookJ_l0:_oo02[ooookJP;o0=co00CoN?l0o`3ogooonf[o
?@3o1_oonfX01Ol0S_oo0?lKoa80oooonf[oolX000Gooo]Z00?oo`2CoookJ_oo01<01_oonfX01ooQ
o`3of_l0oookJ_oonf[o9P3ooookJ_lPo`004?oonfX00olao`3ooo]Zo`3oF`03oookJP06o`3o/?n2
o`3o033ooookJ_l0j?oo0?m=0_oonfX00ol60?oooo]Zoi;o0002oookJP03oa00oooo06[o01Wo00Co
oo]Z00?oo`1AoookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP04oookJP08o`3oDooonf[ooo]Zoook
J_l0o`So0?lMoookJ_l0hOl;oookJP03o`3o=?l0odkooo]Z00Kooo]Z00?o0:WooookJ_oonfX00ooo
nfX00ol01?oo0=CooookJP0<oookJP03oon10?oonf[ooo]Z00cooo]Z00?oo`0]oookJ_oonfX01_oo
nfX00oooE`3ooo]ZoookJP09oookJP05on/0ool0o`Gooo]ZoookJ_oo_P004_oonfX00oooT03ooo]Z
oookJP02oookJP03onKo0?oonf[ooo]Z02?ooo]Z000ZoookJP03oomi0?oonf[ooo]Z00cooo]Z00Co
N?l0o`3ogooonf[oA?l00_oonfX00oloo`3ooo]ZoookJP04oookJP06o`0Zoooonf[ooo]ZoookJ_oo
b@3ooe800_oonfX00onio`3ooo]ZoookJP0KoookJP03o`1coooonf[ooo]Z07Cooo]Z00?o07?ooook
J_oonfX04OoonfX01?oo:03ooo]ZonGo0?oUo`03o`000005o`0Zoooonf[o?ol0oookJ_l0g?l00_mh
o`000ol0omoo?@3ooookJP06oookJP04oolX0?l0oa_ooo]Zooo:00Kooo]Z00?oobP0oookJ_oo01<0
1_oonfX01ooQo`3of_l0oookJ_oonf[o9P3ooh@0oolPo`004?oonfX00olao`3ooo]Zo`3oF`03ool0
0005o`3o/?n2o`3o033ooookJ_l0odd00ooo:0000ol60?ooT_l0oolX0002oookJP03oa00oooo06[o
01Wo00?ooo]Z00Coo`1Aool00?oonf[o0:go0_oonfX00ooo07Wooo]ZoookJP04oookJP08o`3oDooo
nf[ooo]ZoookJ_l0o`So0?lMoookJ_l0hOl;oookJP03ooo90?l0odkoolT000Kooo]Z00?o0:Woo`28
oooonfX00ooonfX00ol01?oo0=CooookJP0<oookJP03oon10?oonf[ooo]Z00gooo]Z00?oo`0]oook
J_oonfX01OoonfX00oooE`3ooo]ZoookJP08oookJP03on/0oooonf[oolT000SoolT03OoonfX00ooo
T03ooo]ZoookJP02oookJP03onKo0?oonf[ooo]Z04[ooo]Z00?o0?lKoookJ_oonfX03OoonfX01_mh
o`3o?@3ooookJ_l0g?oooo]Zocoo00Kooo]Z00Oo02[ooookJ_oonf[ooo]Zo`3o<ooonf[ooe8000;o
oo]Z00?o^Ol0oookJ_oonfX06_oonfX00ol0Looooo]ZoookJP1doookJP;o07?o4_oonfX01?nio`3o
oo]ZoookJ_ooDP04o`000004o`0Zooloo`3ooo]Zo`3Lo`;oN?l000?o0?oOoookJ_lm0?l01_oonfX0
1Ol0S_oo0?lKoa80oooonf[oolX000Gooo]Z00?oo`2CoookJ_oo01<01_oonfX01ooQo`3of_l0oook
J_oonf[o9P3ooookJ_lPo`004?oonfX00olao`3ooo]Zo`3oF`03oookJP03o`3o/?oonf[oP_l000;o
oo]Z00Ko0?m=oookJ_oonf[ooo]Zo`H0oonBo`02oookJP04o`1Mool@0?oooo]Zo`0Io`?ooo]Z00?o
o`1AoookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP04oookJP06o`3oDooonf[ooo]ZoookJ_l0o`So
0?lM0_oonfX00ol0hOoooo]ZoookJP09oookJP03o`3oC_l0obkooo]Z00Gooo]Z00?o0:Woo`28oooo
nfX01?oonfX00ol01?oo0=CooookJP0<oookJP03oon10?oonf[ooo]Z00cooo]Z00?oo`0]oookJ_oo
nfX01OoonfX00oooE`3ooo]ZoookJP09oookJP03on/0oooonf[o0?l500;ooo]Z00?ookh0oookJ_oo
nfX04?oonfX01OooT03ooo]ZoookJ_oonf[oi_l002Kooo]Z000ZoookJP03oomi0?l0S_oooo]Z00go
oo]Z00?oN?l0o`3ogooonfX00_m4o`000ooonf[o?ol0oookJP05oookJP06o`0Zoooonf[ooo]Zoook
J_ooDP3o0?lc0_oonfX00onio`3ooo]ZoookJP0KoookJP;o07?oL_oonfX2o`1coa;ooo]Z0_oo:000
1Ol0oc?oiOl0oookJ_oonf[o000000;o02[o0_loo`001_oonf[o0=coogSo0?oonf[o0?oOoolX00Oo
oo]Z00CoobP0o`3o6ooonf[oolX01_oonfX00ooo:03oo`0Cool04`06oookJP07on7o0?oJo`3ooo]Z
oookJ_lV0?oooo]Zob3o000@oookJP04oc7o0?oonf[o0?mKoookJP;oo`0000Ko0?n`oh;o0?oo003o
033oo`3Xool0odd2oolX0003o`H0oooo:03oT_l000;oobP000?o403ooookJ_l06Ol01?oonfX00ooo
057o5@3oo`2]o`02oookJP03ool0NOoonf[ooo]Z00Cooo]Z00So0?mCoookJ_oonf[ooo]Zo`3o2?l0
oagooo]Zo`3Qo`_ooo]Z00?oolT0o`3oC_oob@001ooonfX00ol0ZOoooo]ZoookJP02oookJP03o`04
ool0e?oooo]Z00gooo]Z00?ooh40oookJ_oonfX03?oonfX00ooo02gooo]ZoookJP05oookJP03oomG
0?oonf[ooo]Z00Wooo]Z00?oj`3ooookJ_oob@001ooob@0=oookJP03oon@0?oonf[ooo]Z00;ooo]Z
00?oi_l0oookJ_l0M?l0BooonfX00ol0oa_o08kooookJP0>oookJP03ogSo0?oonf[ooo]Z00;o0=co
00?o?ol0oookJ_oonfX01?oonfX01_l0:_oooo]ZoookJ_oonf[o0?lcoomB00?ooo]Z00?o^Ol0oook
J_oonfX06_oonfX2o`1cog;ooo]Z0_l0LolBoookJP;o^Ol000Cooo]ZoomB0?ooDP3ooo]Z0_l00002
o`0Zo`06ocoo0?oonf[o0=coogSo0?oonf[o0?oO0_lm0?l6oookJP05o`2>ool0oa_o4P3ooookJ_oo
bP001OoonfX00ooo09?ooo]Zool04`06oookJP07on7o0?oJo`3ooo]ZoookJ_lV0?oooo]Zob3o000@
oookJP03oc7o0?oonf[o0?mK00?ooo]Z00Oo0?n`oookJ_n2o`3o033ooookJ_l0j?oo0?m=00;ooo]Z
00?o1P3oool0mOnBo`000_oonfX00ol@0?ooo`1Zo`0Io`04oookJP03ool0DOl0[Ooooo]Z00;ooo]Z
00?oo`1ioookJ_oonfX00ooonfX01_l0oe?ooo]ZoookJ_oonf[o0?l8o`3o7@;ooo]Z00?o0>7ooook
J_oonfX02OoonfX00ol0odko0?l^oookJP06oookJP03o`2Yoooonf[ooo]Z00?ooo]Z00?o00Coo`3D
oooonfX03?oonfX00oooP@3ooo]ZoookJP0<oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0oook
J_oonfX02OoonfX00oo[0?oo0?l5oookJP02oookJP03oonn0?oonf[ooo]Z00oooo]Z00?ooi00oook
J_oonfX00_oonfX00ooVo`3ooo]Zo`1do`0ToookJP00:ooonfX00oooN@3o08kooookJP0<oookJP03
ogSo0?lm0?oo0?oO00;ooo]Z00Co0=cooookJ_loo`3o?ol01OoonfX01_l0:_oooo]ZoookJ_oonf[o
oe80o`3o<`;ooo]Z00?o^Ol0oookJ_oonfX07?oonfX00ol0Looooo]ZoookJP1]oookJP;o07?o4ooo
nfX01?oo:03o0?lconGo0?oUo`02oookJP;o02[o00Ko0000ocoo0?l0003ooo]Zo`3Loomho`02o`3o
g`Sooo]Z00CoobP0o`3o6ooonf[oolX01OoonfX00ol0nOooobP0ool04`07oookJP07on7o0?oJo`3o
oo]ZoookJ_lV0?oooo]Zob3o000AoookJP0@oc7o0?l0oe_ooo]ZoookJ_oo003o0?n`oh;o0?oo003o
033oool00?l0odgooo]ZoolX0?l60?ooobP0oi;o00;oobP000?o403ooolX0?l06Ol01?oonfX00ooo
057o5@3oo`2]o`03oookJP03ool0NOoonf[ooo]Z00Cooo]Z00Oo0?mCoookJ_oonf[ooo]Zo`3o7Ooo
nf[o0>7o00cooo]Z00?oolT0o`3oC_l0obh01_oonfX00ol0ZOoo08SooookJP02oookJP03o`04oooo
nf[o0=Co00gooo]Z00?ooh40oookJ_oonfX03OoonfX00ooo02gooo]ZoookJP05oookJP03oomG0?oo
nf[ooo]Z00Sooo]Z00?oj`3oog00oooob@001ooob@0>oookJP03oon@0?oonf[ooo]Z00;ooo]Z00?o
i_l0oookJ_l0M?l0C?oonfX00ol0oa_o08kooookJP0=oookJP03ogSo0?l0omoooo]Z00;ooo]Z00?o
0=coocoo0?loo`001OoonfX00ol0:_oooo]ZoookJP02oookJP05oomB0?oonf[ooo]ZoookJ_nio`00
7OoonfX00ol0Looooo]ZoookJP1]oookJP;o07?o4ooonfX01?nio`3ooo]ZoomB0?ooDP03oookJP;o
02[o00Go?ol0o`000?oonf[o0=coogSo0002o`3og`03ocd0oooonf[ooo]Z00Gooo]Z00Go08koo`3o
6olB0?oooo]Zooo:0004oookJP04o`3ioooo09?ooo]Zool04`Kooo]Z00OohOl0om[o0?oonf[ooo]Z
obH0oooonf[o8?l0017ooo]Z00?o<Ol0o`3oFooonfX00ooonfX01_l0ok3oP_l0o`0`oooonf[o0>So
o`3oC@;ooo]Z00?o1P3ooookJ_nBo`000_oonfX00ol@0?ooo`1Zo`0Io`04oookJP03ool0DOoonf[o
0:go00;ooo]Z00?oo`1ioookJ_oonfX01?oonfX02?l0oe?ooo]ZoookJ_oonf[o0?l8o`3o7Ooonf[o
0>7o3?oonfX00ol0odko0?l^oookJP05oookJP03o`2Yool0R?oooo]Z00?ooo]Z00?o00CooookJ_l0
e?l03OoonfX00oooP@3ooo]ZoookJP0<oookJP03ool0;Ooonf[ooo]Z00Gooo]Z00?ooeL0oookJ_oo
nfX02OoonfX00oo[0?ooL03oo`3o1@02oookJP03oonn0?oonf[ooo]Z013ooo]Z00?ooi00oookJ_oo
nfX00_oonfX00ooVo`3ooo]Zo`1do`0ToookJP00:_oonfX01?lB0?oooo]Zoomi0?l0S_l=oookJP;o
N?l00ooonfX01?l0g?oooo]ZoookJ_loo`05oookJP05o`0Zoooonf[ooo]ZoookJ_ooDP000_l0oc<0
0onio`3ooo]ZoookJP0MoookJP03o`1coooonf[ooo]Z06_ooo]Z00?o07?ooookJ_oonfX04OoonfX2
oolX00;oiOl00ooonfX01Ol0:_oooo]Zo`000?loo`3o000000;o0=co00?oN?l0o`3ogooo:0000ooo
nfX00ooo:03ooo]ZoookJP02oookJP06oolX0?l0oa_ooo]Zooo:0?oonf[oobP00ooonfX00ol0nOoo
obP0ool04`07oookJP07on7o0?oJo`3ooo]ZoookJ_lV0?oooo]Zob3o000AoookJP04oc7o0?oonf[o
0?mKoookJP;oo`0000Ko0?n`oh;o0?l0<?ooo`00o`3oCOoo0002oolX0003o`H0oonBo`3oobP000;o
obP000?o403oo`0IoooonfX00ooonfX01?oo057o5@3ooookJ_l0[Ol2oookJP03ool0NOoonf[ooo]Z
00Cooo]Z00So0?mCoookJ_oonf[ooo]Zo`3o2?l0oagooo]Zo`3Qo`cooo]Z00?o0?m>o`3o;_oonfX0
1_oonfX00ol0ZOoooo]ZoookJP02oookJP03o`04ool0e?oooo]Z00gooo]Z00?ooh40oookJ_oonfX0
3?oonfX00ooo02gooo]ZoookJP05oookJP03oomG0?oonf[ooo]Z00Wooo]Z00?oj`3ooookJ_oob@00
1ooob@0=oookJP03oon@0?oonf[ooo]Z00;ooo]Z00?oi_l0oookJ_l0M?l0C?oonfX01?lB0?oooo]Z
o`3o6ol0S_l>oookJP;oN?l00ooonfX00ol0g?oooo]Zocoo0005oookJP03o`0Zoooonf[ooo]Z00;o
oo]Z00Cooe80o`3o<ooonf[o^Ol07_oonfX00ol0Looooo]ZoookJP1[oookJP03o`1coooonf[ooo]Z
017ooo]Z0_nio`000ooonf[ooe80oookJP03oookJP04o`0Zool0003o?ol0o`0000;o0=co00CoN?l0
o`3ogolm0?oo?@3o1ooonfX01Ol0S_oo0?lKoa80oooonf[oolX000Cooo]Z00Co0?Woool0Tooo01?o
o`0C1_oonfX01ooQo`3of_l0oookJ_oonf[o9P3ooookJ_lPo`004OoonfX00olao`3ooo]Zo`3oF`03
oookJP06o`3o/?oonf[oP_l0oookJ_l0j?oo0?m=0ooonfX01ol60?ooT_l0oookJ_oonf[o403oool0
J_l06Ol01?oonfX00ooo057ooo]Zo`2]o`02oookJP03ool0NOoonf[ooo]Z00Cooo]Z00Ko0?mCoook
J_oonf[ooo]Zo`3o2?l0oad2oookJP03o`3Qoooonf[ooo]Z00Wooo]Z00?o0?m>o`3o;_oonfX01_oo
nfX00ol0ZOoooo]ZoookJP03oookJP03o`04ool0e?oooo]Z00cooo]Z00?ooh40oookJ_oonfX03?oo
nfX00ooo02gooo]ZoookJP06oookJP03oomG0?oonf[ooo]Z00Wooo]Z00?oj`3oo`3o1OoonfX00_oo
nfX00ooo_P3ooo]ZoookJP0?oookJP03oon@0?oonf[ooo]Z00;ooo]Z00?oi_l0oookJ_l0M?l09Ooo
nfX002[ooo]Z00Co4P3ooookJ_ooN@3o08ko3ooonfX01Omho`3ooo]ZoookJ_oonf[o0=co00;ooo]Z
00?o?ol0oookJ_oonfX00ooonfX01?l0:_oooo]ZoookJ_oonfX2oomB0003o`3o<onio`3ooo]Z01ko
oo]Z0_l0LomYoookJP;o07?o3OoonfX00ooo:03ooo]ZoookJP02oookJP;oobP000?o0?lconGo0?oo
nfX00_oonfX2o`0Zo`;ooo]Z00?o?ol0o`000?l0g?l00_mho`000ol0omoooo]ZoookJP03oookJP04
oolX0?oonf[ooo]ZoookJP;o0?lK00Cooo]Zooo:0?oonf[ooo]Z0_oo:0001?oonf[o0?WooolX0?oo
01<7oookJP;oobP00_oonfX00olV0?oooo]Zob3o000AoookJP03oc7o0?oonf[o0?mK00;ooo]Z00_o
o`00o`3o/?n2o`3o033oool00?l0j?oo0?m=oookJ_oo:03o1P3ooi;o0003oolX0003oa00ool06Ooo
o`1Z00Cooo]Z00?oo`1AoookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP05oookJP07o`3oDooonf[o
oo]ZoookJ_l0oagooo]Zo`3Qo`0=oookJP03o`3oC_oonf[ooo]Z00Gooo]Z00?o0:WooookJ_oonfX0
0_oonfX00ol01?oooo]Zo`3Do`0=oookJP03oon10?oonf[ooo]Z00gooo]Z00?oo`0]oookJ_oonfX0
1OoonfX00oooE`3ooo]ZoookJP08oookJP04on/0oom`0?ooolT0oookJPKoolT03_oonfX00oooT03o
oo]ZoookJP02oookJP04onKo0?oonf[o07CoodCo04_ooo]Z00Co4P3ooookJ_l0oa_o08ko3ooonfX0
0ol0omooN?l0oookJP02oookJP03o`3Loooonf[o?ol000Gooo]Z00?o02[ooookJ_oonfX00_oonfX2
oomB0003oookJ_nio`3ooo]Z01gooo]Z0_l0LomYoookJP;o07?o4_oonfX2okWo0003oookJ_ooDP3o
oe8000?ooo]Z0_l0:_l01?oonf[o?ol0o`000?l0g?l2ogSo0003o`3ogolm0?oooo]Z00Oooo]Z0_l0
oa/00olB0?ooolX0ooo:0004oookJP03o`3ioooo09?oo`0C00Oooo]Z0_oJo`02oookJP03obH0oooo
nf[o8?l0017ooo]Z00?o<Ol0oookJ_l0oe/00ooonfX01ol0ok3ooo]Zoh;o0?oonf[o0>SooookJ_l0
odd00_oonfX00ol60?ooT_l0oookJP02oookJP03oa00ool06Ooooo]Z00?ooo]Z00?o5@3oool0DOl0
[Ol00_oonfX00ooo07Wooo]ZoookJP05oookJP05o`3oDooonf[ooo]ZoookJ_l0oad00_oonfX00ol0
hOoooo]ZoookJP0:oookJP03o`3oC_oonf[ooo]Z00Gooo]Z00?o0:WooookJ_oonfX00ooonfX00ol0
1?oooo]Zo`3Do`0=oookJP03oon10?oonf[ooo]Z00cooo]Z00?oo`0]oookJ_oonfX01OoonfX00ooo
E`3ooo]ZoookJP09oookJP03on/0oom`0?oooo]Z00;ooo]Z00?ookh0oookJ_oonfX04?oonfX00ooo
T03ooo]ZoookJP02oookJP04onKo0?oonf[o07CooaP0obCooo]Z000[oookJP04oa80oooonf[oogT0
o`2>o`oooo]Z00GoN?l0oookJ_oonf[ooo]Zo`3Lo`02oookJP03ocoo0?oonf[ooo]Z00;ooo]Z00?o
02[ooookJ_oonfX00ooonfX00oooDP3o0?lcokWo000PoookJP03o`1coooonf[ooo]Z06Cooo]Z0_l0
Lol>oookJP;oobP00ooonfX01?oo:03o0?lconGo0?oUo`02oookJP;o02[o0ooonfX01_loo`3o0000
o`3Loomho`3oobP0o`3og`Gooo]Z0ooo:0001Ooonf[o0?lKoa80oooonf[oolX000;ooo]Z1Ooo:000
0ooo01?ooo]ZoookJP05oookJP07oolX0?oonf[ooo]ZoookJ_lV0?oooo]Zob3o000AoookJP03oc7o
0?oonf[o0?mK00;ooo]Z00coo`00o`3o/?n2o`3oo`00o`0`ool0j?oo0?m=oookJ_oo:03o1P3ooolX
0?nBo`02oolX0003oa00ool06Oooo`1Z00Cooo]Z00?oo`1AoookJ_l0[Ol00_oonfX00ooo07Wooo]Z
oookJP05oookJP05o`3oDooonf[ooo]ZoookJ_l0oad00_oonfX00ol0hOoooo]ZoookJP0:oookJP03
o`3oC_l0obkooo]Z00Gooo]Z00?o0:Woo`28oooonfX00_oonfX00ol01?oooo]Zo`3Do`0>oookJP03
oon10?oonf[ooo]Z00cooo]Z00?oo`0]oookJ_oonfX01OoonfX00oooE`3ooo]ZoookJP09oookJP04
on/0oooonf[oolT0oookJPGoolT03_oonfX00oooT03ooo]ZoookJP02oookJP05onKo0?oonf[o07Co
oookJ_m4o`00C?oonfX01?lB0?oooo]Zo`3o6ol0S_l?oookJP03o`3ogomho`3ooo]Z00;ooo]Z00?o
0=cooookJ_loo`001OoonfX00ol0:_oooo]ZoookJP03oookJP03oomB0?oonf[o^Ol001oooo]Z00?o
07?ooookJ_oonfX0I?oonfX2o`1coa?ooo]Z00Co^Ol0oookJ_ooDP3ooe800ooonfX2o`0Zo`;ooo]Z
00Oo?ol0o`000?l0g?ooN?l0o`000?l0omoo?@3o00Sooo]Z00Co0?lKoookJ_lB0?ooolX01OoonfX0
0ol0nOooo`2Cool04`07oookJP07om[o0?oonf[ooo]ZoookJ_lV0?oooo]Zob3o000AoookJP03oc7o
0?oonf[o0?mK00?ooo]Z00Oo0?n`oookJ_n2o`3o033ooookJ_l0j?oo0?m=00;ooo]Z00?o1P3ooook
J_nBo`000_oonfX00ol@0?oo01WooookJP03oookJP06oaD0oooo057ooo]Zo`2]oooonf[oo`1i1ooo
nfX01Ol0oe?ooo]ZoookJ_oonf[o0?lM00?ooo]Z00?o0>7ooookJ_oonfX02OoonfX00ol0odko0?l^
oookJP05oookJP03o`2Yool0R?oooo]Z00?ooo]Z00?o00CooookJ_l0e?l03OoonfX00oooP@3ooo]Z
oookJP0<oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0oookJ_oonfX02OoonfX00oo[0?oo0?l5
oookJP02oookJP03oonn0?oonf[ooo]Z00oooo]Z00?ooi00oookJ_oonfX00_oonfX01OoVo`3ooo]Z
o`1doooonf[o603o02Cooo]Z000/oookJP04oa80oooonf[oogT0o`2>o`kooo]Z00?o0?oOogSo0?oo
nfX00_oonfX00ol0g?oooo]ZoookJP02ocoo00?ooo]Z00?o02[ooookJ_oonfX00ooonfX2oomB0003
o`3o<ooonf[ooo]Z01kooo]Z0_l0LomQoookJP?o07?o3ooonfX6oolX00;oiOl00ooonfX01?l0:_oo
oo]ZoookJ_oonfX2ocoo0005oookJ_l0g?ooN?l0oolX0?l0oml01OoonfX4oolX0004o`3o6olB0?oo
oo]Zooo:00;ooo]Z1_oo:007oookJP07oolX0?oonf[ooo]ZoookJ_lV0?oooo]Zob3o000AoookJP03
oc7o0?oonf[o0?mK00?ooo]Z00Ko0?n`oh;o0?oo003o033oo`3Xoooo:002oookJP03oolX0?l60?oo
T_l000;oobP000Co403ooookJ_l06Oooo`1Z0ooonfX00ooo057o5@3oo`2]o`02oookJP03ool0NOoo
nf[ooo]Z00Gooo]Z00So0?mCoookJ_oonf[ooo]Zo`3o2?l0oagooo]Zo`3Qo`cooo]Z00?o0?ldo`3o
C_oonfX01_oonfX00ol0ZOoooo]ZoookJP02oookJP03o`04oooonf[o0=Co00gooo]Z00?ooh40oook
J_oonfX03?oonfX00ooo02gooo]ZoookJP06oookJP03oomG0?oonf[ooo]Z00Wooo]Z00Coj`3oooo9
0?oonf[ooo]Z1?oob@0?oookJP03oon@0?oonf[ooo]Z00;ooo]Z00Coi_l0oookJ_l0M?ooA?l0C_oo
nfX01?lB0?oooo]Zo`3o6ol0S_l>oookJP03o`3ogooonf[oN?l000?ooo]Z00Co0=cooookJ_loo`3o
?ol00ooonfX00ol0:_oooo]ZoookJP04oookJP;ooe8000?o^Ol0oookJ_oonfX07OoonfX2o`1cof7o
oo]Z0ol0LolCoookJP;o^Ol000?ooo]ZoomB0?oonfX00ooonfX00ol0:_oooo]ZoookJP02ocoo0005
oookJ_l0g?ooN?l0o`000?l0oml02?oonfX01Ol0S_oo0?lKoookJ_lB0?ooolX000Gooo]Z00?o0?Wo
ool0Tooo01<01ooonfX01ooJo`3ooo]ZoookJ_oonf[o9P3ooookJ_lPo`004OoonfX00olao`3ooo]Z
o`3oF`03oookJP07o`3o/?oonf[oP_l0o`0`oooonf[o0>Soo`3oC@03oookJP07o`H0oonBo`3ooo]Z
oookJ_l@0?oo01Woool0JP04oookJP03ool0DOoonf[o0:go00;ooo]Z00?oo`1ioookJ_oonfX01?oo
nfX01_l0oe?ooo]ZoookJ_oonf[o0?l8o`3o7@;ooo]Z00?o0>7ooookJ_oonfX02OoonfX00ol0ocCo
0?m>oookJP06oookJP03o`2Yoooonf[ooo]Z00?ooo]Z00?o00CooookJ_l0e?l03OoonfX00oooP@3o
oo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0oookJ_oonfX02_oonfX00oo[0?oo
oo]ZoookJP02oookJP03oonn0?oonf[ooo]Z00oooo]Z00?ooi00oookJ_oonfX00_oonfX01?oVo`3o
oo]Zo`1doolH0?lUoookJP00:_oonfX01ooobP3ooo]ZoookJ_lB0?ooogT0oookJ_l0S_l03_oonfX0
0ol0omooN?l0ogSo0002oookJP05o`3Loooonf[ooo]ZoookJ_loo`000ooonfX00ol0:_oooo]Zoook
JP04oookJP03oomB0?l0oc?o^Ol0023ooo]Z00?o07?ooookJ_oonfX0FooonfX3o`1coa7ooo]Z1Ooo
:0000ol0oc?oiOl0oookJP02oookJP;o02[o0ooonfX01oloo`3ooo]Zo`3Lool0g?ooN?l0oolX0?l0
oml00_l00004oookJP?oobP000Co0?lKoa80oooo:03oolX00ooonfX7oolX00Gooo]Z00OoobP0oook
J_oonf[ooo]ZobH0oooonf[o8?l0017ooo]Z00?o<Ol0oookJ_l0oe/00ooonfX01ol0ok3oP_l0ool0
0?l0<?ooo`00o`3Xoooo:0000_oonfX02?l60?ooT_l0oolX0?oo:03ooo]Zoa00ool06Oooo`1Z1?oo
nfX00ooo057ooo]Zo`2]o`02oookJP03ool0NOoonf[ooo]Z00Gooo]Z00Go0?mCoookJ_oonf[ooo]Z
o`3o7@02oookJP03o`3Qoooonf[ooo]Z00Wooo]Z00?o0?ldo`3oC_l0obh01_oonfX00ol0ZOoooo]Z
oookJP02oookJP03o`04oooonf[o0=Co00kooo]Z00?ooh40oookJ_oonfX03?oonfX00ooo02gooo]Z
oookJP05oookJP03oomG0?oonf[ooo]Z00Wooo]Z00?oj`3oog00oooob@000_oonfX4ooo900kooo]Z
00?ooi00oookJ_oonfX00ooonfX01?oVo`3o07CooookJ_m4o`1<oookJP07ooo:0?oonf[ooo]Zoa80
ool0oa_ooo]Zo`2>o`0>oookJP03o`3ogooonf[oN?l000?ooo]Z00Co0=cooookJ_oonf[o?ol00ooo
nfX00ol0:_oooo]ZoookJP05oookJP03oomB0?nio`3o^Ol001oooo]Z00?o07?ooookJ_oonfX0Fooo
nfX3o`1coaGooo]Z00Co^Ol0oookJ_ooDP3ooe800ooonfX2o`0Zo`;ooo]Z00Oo?ol0oookJ_l0g?oo
0=coogSo0?lm0?oo0?oO00;o00001_oonfX01Ol0S_oo0?lKoa80oolB0?ooolX000Cooo]Z0_l0nOl0
0ooo09?oo`0CoookJP06oookJP08om[o0?oonf[ooo]ZoookJ_lV0?oooo]Zob3o0?n40?l@oookJP03
oc7o0?oonf[o0?mK00?ooo]Z00So0?n`oookJ_n2o`3o033ooookJ_l0j?oooo]Zo`3oC@;ooo]Z00Oo
1P3ooi;o0?oonf[ooo]Zoa00oooonf[o01Wo00Cooo]Z00?o5@3oool0DOl0[Ol00_oonfX00ooo07Wo
oo]ZoookJP05oookJP05o`3oDooonf[ooo]ZoookJ_l0oad00ooonfX00ol0hOoooo]ZoookJP09oook
JP03o`3oC_l0obkooo]Z00Gooo]Z00?o0:WooookJ_oonfX00ooonfX00ol01?oooo]Zo`3Do`0=oook
JP03oon10?oonf[ooo]Z00cooo]Z00?oo`0]oookJ_oonfX01_oonfX00oooE`3ooo]ZoookJP09oook
JP03on/0oom`0?oooo]Z00;ooo]Z00?ookh0oookJ_oonfX03ooonfX00oooT03ooo]ZoookJP02oook
JP05onKo0?oonf[o07CooookJ_lH0?l09OoonfX002[ooo]Z00OoolX0oookJ_oonf[ooo]Zoa80oooo
N@3o08ko00oooo]Z00?o0?oOocd0oomho`000_oonfX2o`3Lo`;ooo]Z00Go?ol0oookJ_oonf[ooo]Z
o`0Zo`06oookJP;ooe8000?o0?lcokWo0?oonfX07_oonfX00ol0Looooo]ZoookJP1GoookJP?o07?o
4OoonfX00ooUo`3ooo]ZoolX0003oolX0003o`3o<ooUo`3oiOl000?ooo]Z00?o02[ooookJ_oonfX0
0_oonfX00oloo`3ooo]Zo`3Lo`02ogSo0004o`000?l0omoo0000o`0000Cooo]Z0ooo:0001Ol0oa_o
obP0oolX0?oobP3oobP000;ooo]Z2Ooo:003oookJP07oolX0?oonf[ooo]ZoookJ_lV0?oooo]Zob3o
000AoookJP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00Oo0?n`oh;o0?oo003o033oool00?l0j?ooobP0
00;ooo]Z00So1P3ooolX0?nBo`3oobP0oookJ_l@0?oo01WooolX00Cooo]Z00?oo`1AoookJ_l0[Ol0
0_oonfX00ooo07Wooo]ZoookJP05oookJP05o`3oDooonf[ooo]ZoookJ_l0oad00_oonfX00ol0hOoo
oo]ZoookJP0:oookJP03o`3oC_l0obkooo]Z00Gooo]Z00?o08Soo`2YoooonfX00_oonfX01?l01?oo
oo]ZoookJ_l0e?l=oookJP03oon10?oonf[ooo]Z00cooo]Z00?oo`0]oookJ_oonfX01_oonfX00ooo
E`3ooo]ZoookJP09oookJP03on/0oooob@3ooo]Z00;ooo]Z0ooob@0?oookJP03oon@0?oonf[ooo]Z
00;ooo]Z00Coi_l0oookJ_l0M?ooA?l0COoonfX01ooobP3ooo]ZoookJ_oonf[o4P3oo`3o6ol0S_l0
3ooonfX01?l0omoooo]ZogSo0?mho`02oookJP;o0=co00?ooo]Zocoo0?oonfX00_oonfX00ol0:_oo
oo]ZoookJP05oookJP;ooe800_nio`0NoookJP03o`1coooonf[ooo]Z05Oooo]Z0ol0LolFoookJP;o
^Ol00_ooDP04oookJP07o`0Zoooonf[ooo]ZoookJ_loo`3ooo]Zo`3Lo`02ogSo0004ocd0ool0omoo
0000o`0000Kooo]Z00Go08koo`3o6olB0?oooo]Zooo:0004oookJP04o`3ioooonf[oo`2Cool04`Oo
oo]Z00Sof_l0oookJ_oonf[ooo]ZobH0oooonf[o8?l0oh@0oa3ooo]Z00Co<Ol0oookJ_oonf[o0?mK
0_oonfX02?l0ok3ooo]Zoh;o0?l0<?oooo]Zo`3Xoooonf[o0?m=0_oonfX01ol60?oooo]Zoi;o0?oo
nf[o403oo`1Mool06Ol01?oonfX00olE0?ooo`1Ao`2]o`02oookJP03ool0NOoonf[ooo]Z00Gooo]Z
00Go0?mCoookJ_oonf[ooo]Zo`3o7@03oookJP03o`3Qoooonf[ooo]Z00Wooo]Z00?o0?m>o`3o;_oo
nfX01_oonfX00ol0ZOoooo]ZoookJP02oookJP04o`04oooonf[ooo]Zo`3Do`gooo]Z00?ooh40oook
J_oonfX02ooonfX00ooo02gooo]ZoookJP06oookJP03oomG0?oonf[ooo]Z00[ooo]Z00?oj`3ooook
J_oonfX00_oonfX00ooo_P3ooo]ZoookJP0?oookJP03oon@0?oonf[ooo]Z00;ooo]Z00Coi_l0oook
J_l0M?oo603o9_oonfX002_ooo]Z00OoolX0oookJ_oonf[ooo]Zoa80ooooN@3o08ko00oooo]Z00?o
0?oOocd0oomho`000ooonfX01?l0g?oooo]ZoookJ_loo`03oookJP03o`0Zoooonf[ooo]Z00Gooo]Z
00?ooe80o`3o<onio`007ooonfX3o`1coe?ooo]Z0ol0LolCoookJP;oiOl01?oo:002onGo00?oobP0
0_l0:_l4oookJP05ocoo0?oonf[o0=coogSo0?oo:0000_l0oml3o`0000?ooo]Z0_oo:002o`3o6`03
oolX0?oobP3oolX000?oobP000?ooo]ZoolX0?oo:0001Ooo:004oookJP07oolX0?oonf[ooo]Zoook
J_lV0?oooo]Zob3o000BoookJP03oc7o0?oonf[o0?mK00;ooo]Z00Oo0?n`oh;o0?oo003oo`00o`0`
ool0j?ooobP000;ooo]Z00Wo1P3ooolX0?nBo`3oobP0oookJ_l@0?oo01WooookJ_oo:0000ooonfX0
0ooo057ooo]Zo`2]o`02oookJP03ool0NOoonf[ooo]Z00Gooo]Z00So0?mCoookJ_oonf[ooo]Zo`3o
7Ol0o`Sooo]Zo`3Qo`cooo]Z00?o0?ldo`3oC_l0obh01_oonfX00ol0ZOoooo]ZoookJP02oookJP03
o`04oooonf[o0=Co00kooo]Z00?ooh40oookJ_oonfX03?oonfX00ooo02gooo]ZoookJP05oookJP03
oomG0?oonf[ooo]Z00Wooo]Z00?oj`3oog00oooob@000_oonfX3ooo900oooo]Z00?ooi00oookJ_oo
nfX00ooonfX01?oVo`3o07CooookJ_m4o`1>oookJP07ooo:0?oonf[ooo]ZoookJ_lB0?oo0?lKo`2>
o`0?oookJP04o`3ogooonf[o?@3oogSo00?ooo]Z00Co0=cooookJ_loo`3o?ol00_oonfX00ol0:_oo
oo]ZoookJP06oookJP03oomB0?oonf[o^Ol001kooo]Z0ol0LomCoookJP?o07?o6?oonfX00onio`3o
oo]ZoomB0004oookJP;o02[o0ooonfX01Oloo`3ooo]Zo`3Loomho`3o?@3o00;o0?oO0ol00005oook
JP;o0?lK00?o4P3ooookJ_oobP001?oonfX01?l0nOoooo]Zool0Tooo01<7oookJP08om[o0?oonf[o
oo]ZoookJ_lV0?oooo]Zob3o0?n40?lAoookJP03oc7o0?oonf[o0?mK00?ooo]Z00Oo0?n`oh;o0?l0
ok7o033ooookJ_l0j?oo0?m=00;ooo]Z00?o1P3ooookJ_nBo`000_oonfX00ol@0?oo01Woool0JP03
oookJP06oaD0oooo057ooo]Zo`2]oooonf[oo`1i1ooonfX00ol0oe?ooo]ZoookJP02oookJP04o`3o
7Ooonf[ooo]Zo`3Qo`_ooo]Z00?o0?ldo`3oC_l0obh01_oonfX00ol0ZOoooo]ZoookJP03oookJP03
o`04oooonf[o0=Co00kooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP06oookJP03
oomG0?oonf[ooo]Z00Wooo]Z00?oj`3oog00oooonfX00_oonfX00ooo_P3ooo]ZoookJP0?oookJP03
oon@0?oonf[ooo]Z00?ooo]Z00Coi_l0o`1doooonf[o603o9_oonfX002cooo]Z00OoolX0oookJ_oo
nf[ooo]Zoomi0?oonf[o08ko00kooo]Z00Co0?oOoookJ_lm0?ooN?l00ooonfX00ol0g?oooo]Zoook
JP02ocoo00;ooo]Z0_l0:_l6oookJP;ooe800_nio`0PoookJP?o07?oCOoonfX3o`1coaGooo]Z1?oU
o`000ooo:03oiOl0onGo0003oolX00;o02[o00CoobP0oookJ_oonf[ooo]Z0_oo:002o`3Lo`04ogSo
0?l0omoo0?oOoookJPCo00000_oonfX2oolX0004o`3o6olB0?ooobP0ooo:00?oobP00_oonfX7oolX
00?ooo]Z0_oo:003oookJP04obH0oooonf[o8?l0oh@0oa7ooo]Z00?o<Ol0oookJ_l0oe/00_oonfX0
1ol0ok3oP_l0ool00?oo003o033oo`3Xoooo:0000_oonfX01?l60?ooobP0oi;o0?oo:002oookJP03
oa00oooonf[oobP000?ooo]Z00?o5@3oool0DOl0[Ol00_oonfX00ooo07Wooo]ZoookJP06oookJP07
o`3oDooonf[ooo]ZoookJ_l0oagooo]Zo`3Qo`0<oookJP03o`3o=?l0odko0?l^00Kooo]Z00?o0:Wo
oookJ_oonfX00_oonfX01?l01?oooo]ZoookJ_l0e?l=oookJP03oon10?oonf[ooo]Z00cooo]Z00?o
o`0]oookJ_oonfX01_oonfX00oooE`3ooo]ZoookJP09oookJP03on/0oooob@3ooo]Z00;ooo]Z0ooo
b@0?oookJP03oon@0?oonf[ooo]Z00;ooo]Z00Coi_l0oookJ_l0M?ooA?l0D?oonfX01ooobP3ooo]Z
oookJ_oonf[o0?lKoookJ_l0S_l03_oonfX01Ol0omoooo]ZoookJ_lm0?ooN?l000?ooo]Z00Co0=co
oookJ_oonf[o?ol00_oonfX2o`0Zo`Oooo]Z0_ooDP02okWo01oooo]Z0ol0Lom=oookJP?o07?o6Ooo
nfX2okWo00;ooe800ooonfX2o`0Zo`?ooo]Z0_loo`02o`3Lo`04ogSo0?l0omoo0?oOoookJPCo0000
1?oonfX01Ol0oa_o4P3ooookJ_oonf[oolX000Cooo]Z00Co0?WooookJ_oo09?oo`0C1_oonfX2om[o
00?ooo]Z00Co9P3ooookJ_lPo`3oQ03o4OoonfX00olao`3ooo]Zo`3oF`03oookJP07o`3o/?n2o`3o
oo]Zo`0`oooonf[o0>Soo`3oC@02oookJP03o`H0oooonf[oT_l000;ooo]Z00?o403oo`0Ioooo06X0
0ooonfX01?lE0?oooo]Zool0DOl0[Ol2oookJP03ool0NOoonf[ooo]Z00Gooo]Z00Go0?mCoookJ_oo
nf[ooo]Zo`3o7@02oookJP03o`3Qoooonf[ooo]Z00Wooo]Z00?o0?ldo`3oC_l0obh01_oonfX00ol0
ZOoooo]ZoookJP03oookJP04o`04oooonf[ooo]Zo`3Do`gooo]Z00?ooh40oookJ_oonfX02ooonfX0
0ooo02gooo]ZoookJP06oookJP03oomG0?oonf[ooo]Z00[ooo]Z00?oj`3ooookJ_oonfX00_oonfX0
0ooo_P3ooo]ZoookJP0?oookJP03oon@0?oonf[ooo]Z00;ooo]Z00Coi_l0oookJ_l0M?oo603o9ooo
nfX002gooo]Z00OoolX0oookJ_oonf[ooo]Zoomi0?oonf[o08ko00kooo]Z00Co0?oOocd0oooonf[o
N?l00ooonfX01Ol0g?oooo]ZoookJ_oonf[o?ol000?ooo]Z00?o02[ooookJ_oonfX01OoonfX01?oo
DP3o0?lcokWo0?nio`0QoookJPCo07?oA_oonfX3o`1coaOooo]Z1_oUo`04oolX0003o`0Zoooo:03o
oo]Z00;ooo]Z0_oo:0001Ooonf[o0=coogSo0?mho`3o0?oO00?ooo]Z1?l00002oookJP05oolX0?l0
oa_oobP0oolX0?oobP000_oo:003oookJPKoobP01?oonfX00ooo:03ohOl0oookJP02oookJP04obH0
oooonf[o8?l0oh@0oa7ooo]Z00?o<Ol0oookJ_l0oe/00_oonfX01ol0ok3oP_l0oookJ_oo003o033o
o`3Xoooo:0000_oonfX01?l60?oooo]ZoolX0?nBo`02oookJP03oa00oooonf[oobP000?ooo]Z00Ko
5@3oool0DOoonf[o0:gooookJ_oo07T8oookJP05o`3oDooonf[ooo]ZoookJ_l0oad00_oonfX00ol0
hOoooo]ZoookJP0:oookJP03o`3o=?l0odko0?l^00Gooo]Z00?o08Soo`2YoooonfX00ooonfX00ol0
1?oooo]Zo`3Do`0>oookJP03oon10?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX01_oonfX00ooo
E`3ooo]ZoookJP0:oookJP03on/0oooonf[ooo]Z00;ooo]Z0_oob@0?oookJP03oon@0?oonf[ooo]Z
00?ooo]Z00Coi_l0o`1doooonf[oA?l0DOoonfX01ooobP3ooo]ZoookJ_oonf[o0?lKoookJ_l0S_l0
3_oonfX01Ol0omoooo]Zocd0oooonf[oN?l000?ooo]Z00Co0=cooookJ_oonf[o?ol00ooonfX00ol0
:_oooo]ZoookJP05oookJP03o`3o<oooDP3ooo]Z00;o^Ol08?oonfX4o`1codKooo]Z0ol0LolJoook
JP;o^Ol00_ooDP04oookJP04o`0Zoooonf[ooo]ZoookJP;o?ol000Gooo]Zo`3Loomho`3oN?l0o`3o
g`03oookJPCo00000ooonfX00ol0oa_o4P3ooookJP02ooo:00Cooo]Z00?o0?WooookJ_oo09<01ooo
nfX00ooJo`3ohOl0oookJP02oookJP04obH0oooonf[o8?l0oh@0oa7ooo]Z00?o<Ol0oookJ_l0oe/0
0ooonfX01ol0ok3oP_l0oookJ_l0<?oooo]Zo`3Xool0odd00_oonfX02?l60?oooo]ZoookJ_nBo`3o
oo]Zoa00ool06Oooo`1Z0ooonfX01?lE0?oooo]Zool0DOl0[Ol2oookJP03ool0NOoonf[ooo]Z00Go
oo]Z00Go0?mCoookJ_oonf[ooo]Zo`3o7@03oookJP03o`3Qoooonf[ooo]Z00Wooo]Z00?o0?ldo`3o
C_l0obh01_oonfX00ol0ZOoooo]ZoookJP02oookJP04o`04oooonf[ooo]Zo`3Do`kooo]Z00?ooh40
oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z00[ooo]Z00?oj`3o
oookJ_oonfX00_oonfX00ooo_P3ooo]ZoookJP0>oookJP03oon@0?oonf[ooo]Z00?ooo]Z00Coi_l0
o`1doooonf[o603o9ooonfX002gooo]Z00?oolX0oookJ_oonfX00_oonfX00oooN@3o08kooookJP0>
oookJP;o0?oO00?ooo]ZogSo0?mho`000_oonfX01Ol0g?oooo]ZoookJ_oonf[o?ol000?ooo]Z0_l0
:_l6oookJP;ooe8000?ooo]ZokWo0?oonfX08ooonfX3o`1cod3ooo]Z0ol0LolIoookJPOoiOl00_oo
:002o`0Zo`?ooo]Z0_oo:002oookJP04oolX0?mho`3o0?oOo`3og`Cooo]Z1?l000000ooonf[o4P3o
o`3o6`02oolX0003ooo:0?oo:03ooo]Z00;ooo]Z0_l0nOl4oolX00Gooo]Z00?oobP0on7o0?oonfX0
0_oonfX01?lV0?oooo]Zob3o0?n40?lAoookJP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00KoP_l0oook
J_oonf[o033oo`3Xoooo:002oookJP04o`H0oooonf[ooo]Zoi;o00;ooo]Z00?o403oo`0Ioooo:000
1?oonfX00ooo057ooo]Zo`2]o`02oookJP03ool0NOoonf[ooo]Z00Gooo]Z00So0?mCoookJ_oonf[o
oo]Zo`3o7Ol0o`Sooo]Zo`3Qo`cooo]Z00?o0?ldo`3oC_l0obh01_oonfX00ol0ZOoooo]ZoookJP02
oookJP04o`04oooonf[ooo]Zo`3Do`gooo]Z00?ooh40oookJ_oonfX03?oonfX00ooo02gooo]Zoook
JP06oookJP03oomG0?oonf[ooo]Z00Wooo]Z00?oj`3oog00oooonfX00ooonfX00ooob@3ooo]Zoook
JP0>oookJP03oon@0?oonf[ooo]Z00?ooo]Z00?oi_l0o`1doom4o`00DooonfX01_oobP3ooo]Zoook
J_oonf[o0?lKo`2>o`oooo]Z0_l0oml00olm0?oooo]ZogSo0003oookJP04o`3Loooonf[ooo]Zocoo
00?ooo]Z0_l0:_l7oookJP;ooe8000?ooo]ZokWo0?oonfX08_oonfX3o`1cod3ooo]Z0ol0LolLoook
JP03okWo0?l0oc?ooe8000Cooo]Z0_l0:_l2oookJP;o?ol00_oonfX01?l0g?ooN?l0o`3ogol0oml4
oookJPCo00000_oonfX01?l0oa_o4P3ooookJ_oobP04oookJP;o0?Wo00?ooo]Zool0TooonfX01_oo
nfX00ooJo`3ohOl0oookJP02oookJP04obH0oooonf[o8?l0oh@0oa7ooo]Z00Co<Ol0oookJ_oonf[o
0?mK0_oonfX01ol0ok3oP_l0oookJ_l0<?oooo]Zo`3Xool0odd00_oonfX02?l60?oooo]ZoookJ_nB
o`3ooo]Zoa00ool06Oooo`1Z1?oonfX00olE0?ooo`1Ao`2]o`02oookJP03ool0NOoonf[ooo]Z00Go
oo]Z00Ko0?mCoookJ_oonf[ooo]Zo`3o7Ol0o`P2oookJP03o`3Qoooonf[ooo]Z00Wooo]Z00?o0?ld
o`3oC_l0obh01_oonfX00ol0ZOoooo]ZoookJP03oookJP04o`04oooonf[ooo]Zo`3Do`gooo]Z00?o
oh40oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z00Wooo]Z00?o
j`3oog00oooonfX00_oonfX00ooo_P3ooo]ZoookJP0?oookJP03oon@0?oonf[ooo]Z00;ooo]Z00Co
i_l0oookJ_l0M?oo603o:?oonfX002kooo]Z00OoolX0oookJ_oonf[ooo]Zoomi0?lB0?oo08ko013o
oo]Z00Co0?oOoookJ_oonf[oN?l00_oonfX01Ol0g?oooo]ZoookJ_oonf[o?ol000Cooo]Z0_l0:_l6
oookJP04oomB0?l0oc?o^Ol0okWo02Gooo]Z1?l0LolioookJP?o07?o6ooonfX9onGo0004o`0Zoooo
nf[ooo]ZoookJP;oobP00ooonfX00ooo:03oN?l0o`3og`06oookJPCo000000Go4P3oo`3o6ooo:03o
obP0ooo:0004oookJP03o`3ioooonf[oobP000?oobP01OoonfX00ooo:03ohOl0oookJP02oookJP04
obH0oooonf[o8?l0oh@0oa7ooo]Z00Co<Ol0oookJ_oonf[o0?mK0_oonfX01_n2o`3ooo]ZoookJ_oo
003o033ooolX00;ooo]Z00Co1P3ooookJ_oonf[oT_l00_oonfX00ol@0?oo01WooolX0004oookJP03
oaD0oooo057o0:go00;ooo]Z00?oo`1ioookJ_oonfX01_oonfX01ol0oe?ooo]ZoookJ_l0oago0?l8
oookJ_l0hOl03?oonfX00ol0ocCo0?m>o`3o;P06oookJP03o`28ool0ZOoooo]Z00;ooo]Z00Co00Co
oookJ_oonf[o0=Co3_oonfX00oooP@3ooo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?o
oeL0oookJ_oonfX02_oonfX00oo[0?oooo]ZoookJP03oookJP03oonn0?oonf[ooo]Z00gooo]Z00?o
oi00oookJ_oonfX00ooonfX01?oVo`3o07CooookJ_m4o`1CoookJP07ooo:0?oonf[ooo]ZoookJ_l0
oa_o4P3oo`2>o`0@oookJP03o`3ogolm0?oooo]Z00;oN?l00_oonfX00ol0g?oooo]ZoookJP02ocoo
00?ooo]Z0_l0:_l6oookJP03o`3o<oooDP3ooo]Z00;o^Ol09?oonfX4o`1cocWooo]Z0ol0LolMoook
JP;o^Ol00_ooDP04oookJP05o`0Zoooonf[ooo]ZoookJ_loo`000ooonfX00ol0g?ooN?l0o`3og`06
oookJPCo000000Gooo]Zo`3o6ooonf[ooo]Zooo:0004oookJP04o`3ioooonf[ooo]Zool0T`Oooo]Z
00?of_l0on7o0?oonfX00_oonfX01?lV0?oooo]Zob3o0?n40?lAoookJP04oc7o0?oonf[ooo]Zo`3o
F`;ooo]Z00Oo0?n`oh;o0?oonf[o0?nao`0`ool0j?oo0?m=00;ooo]Z00Co1P3ooookJ_oonf[oT_l0
0_oonfX00ol@0?oo01WooookJP03oookJP06oaD0oooonf[oo`1Ao`2]oooonf[oo`1i2?oonfX01Ol0
oe?ooo]ZoookJ_oonf[o0?lM00;ooo]Z00?o0>7ooookJ_oonfX02OoonfX00ol0ocCo0?m>o`3o;P06
oookJP03o`28ool0ZOoooo]Z00?ooo]Z00Co00CooookJ_oonf[o0=Co3_oonfX00oooP@3ooo]Zoook
JP0:oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX02_oonfX00oo[0?oooo]Zoook
JP02oookJP03oonn0?oonf[ooo]Z00kooo]Z00?ooi00oookJ_oonfX00ooonfX01?oVo`3o07Cooook
J_lH0?lXoookJP00;ooonfX01ooobP3ooo]ZoookJ_oonf[oogT0oa80ool0S_l04?oonfX2o`3og`04
oookJ_mho`3ooo]ZoookJP;o0=co0_oonfX2ocoo00Cooo]Z00?o02[ooookJ_oonfX01?oonfX2oomB
0003oookJ_nio`3o^Ol002Oooo]Z1?l0LolboookJP?o07?o7OoonfX:onGo00?ooo]Z0_oo:002oook
JP;oobP000?oN?l0oookJ_oonfX01_oonfX3o`000005oa80ool0oa_oobP0oolX0?oobP001?oonfX0
0ol0nOoooo]Zool04`02oolX00Kooo]Z00?oobP0on7o0?oonfX00_oonfX01?lV0?oooo]Zob3o0?n4
0?lAoookJP04oc7o0?oonf[ooo]Zo`3oF`;ooo]Z00KoP_l0oookJ_oonf[ooo]Zo`0`oooo:002oook
JP05o`H0oooonf[ooo]Zoi;o0?oo0?D00_oonfX00ol@0?ooobP0oookJP03oookJP03oaD0oooo057o
0:go00;ooo]Z00?oo`1ioookJ_oonfX01_oonfX01ol0oe?ooo]ZoookJ_oonf[o0?lMo`3o2?l0hOl0
3?oonfX01?l0ocCooo]Zo`3oC_l0obh5oookJP03o`28ool0ZOoooo]Z00?ooo]Z00Co00CooookJ_oo
nf[o0=Co3OoonfX00oooP@3ooo]ZoookJP0<oookJP03ool0;Ooonf[ooo]Z00Kooo]Z00?ooeL0oook
J_oonfX02OoonfX00oo[0?ooL03ooookJP03oookJP03oonn0?oonf[ooo]Z00kooo]Z00?ooi00oook
J_oonfX00ooonfX00ooVo`3o07CoodCo001EoookJP07ooo:0?oonf[ooo]ZoookJ_l0oa_o4P3oo`2>
o`0@oookJP;o0?oO0_oonfX00omho`3ooo]ZoookJP02o`3Lo`;ooo]Z00?o?ol0oookJ_oonfX00_oo
nfX00ol0:_oooo]ZoookJP05oookJP;ooe8000?ooo]ZokWo0?nio`009_oonfX4o`1coc;ooo]Z0ol0
LolOoookJP03okWo0?ooDP3ooe8000Cooo]Z0_l0:_l2oookJP;o?ol00_oonfX00ol0g?oo?@3oogSo
0008oookJP?o000000Go4P3oo`3o6ooonf[ooo]Zooo:0004oookJP04o`3ioooonf[ooo]Zool0T`Oo
oo]Z00?of_l0on7o0?oonfX00_oonfX01?lV0?oooo]Zob3o0?n40?lAoookJP04oc7o0?oonf[ooo]Z
o`3oF`;ooo]Z00Oo0?n`oh;o0?oonf[ooo]Zo`0`oooonf[o0?m=00;ooo]Z00So1P3ooookJ_oonf[o
T_l0ool0mOoonf[o403oo`0Io`Cooo]Z00Ko5@3ooookJ_oo057o0:gooookJ_oo07T8oookJP08o`3o
Dooonf[ooo]ZoookJ_l0oago0?l8oookJ_l0hOl<oookJP03o`3o=?l0odko0?l^00Kooo]Z00?o0:Wo
oookJ_oonfX00_oonfX01Ol01?oooo]ZoookJ_oonf[o0=Co00gooo]Z00?ooh40oookJ_oonfX02ooo
nfX00ooo02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z00Wooo]Z00?oj`3oog00oooonfX00_oo
nfX00ooo_P3ooo]ZoookJP0?oookJP03oon@0?oonf[ooo]Z00;ooo]Z00Coi_l0oookJ_l0M?oo603o
:OoonfX0033ooo]Z00OoolX0oookJ_oonf[ooo]Zoomi0?lB0?oo08ko013ooo]Z00Co?@3oo`3ogooo
nf[oN?l00ooonfX01Ol0g?oooo]ZoookJ_oonf[o?ol000Cooo]Z0_l0:_l6oookJP;ooe8000?ooo]Z
okWo0?oonfX0:OoonfX3o`1cobcooo]Z0ol0LolOoookJPcoiOl02?oo:009oookJP07o`000?lB0?oo
0?lKo`3o6ooo:03ooo]Zooo:0004oookJP04o`3ioooonf[oo`0CoolX00Oooo]Z00?oobP0on7o0?oo
nfX00_oonfX01?lV0?oooo]Zob3o0?n40?lBoookJP03oc7o0?oonf[o0?mK00;ooo]Z00KoP_l0oook
J_oonf[ooo]Zo`0`oooo:002oookJP05o`H0oooonf[ooo]ZoookJ_nBo`000_oonfX00ol@0?ooobP0
oookJP03oookJP06oaD0oooo057ooo]Zo`2]oooonf[oo`1i2?oonfX02?l0oe?ooo]ZoookJ_oonf[o
0?lMo`3o2?oonf[o0>7o3?oonfX00ol0ocCo0?m>o`3o;P06oookJP03o`28ool0ZOoooo]Z00;ooo]Z
00Co00CooookJ_oonf[o0=Co3_oonfX00oooP@3ooo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z00Ko
oo]Z00?ooeL0oookJ_oonfX02_oonfX00oo[0?oooo]ZoookJP03oookJP03oonn0?oonf[ooo]Z00go
oo]Z00?ooi00oookJ_oonfX00ooonfX01?oVo`3o07CooookJ_m4o`1FoookJP07ooo:0?oonf[ooo]Z
oookJ_l0oa_o4P3oo`2>o`0AoookJP04o`3ogooonf[ooo]ZogSo00?ooo]Z00Co0=cooookJ_oonf[o
?ol01?oonfX2o`0Zo`Kooo]Z00Go0?lcoomB0?oonf[ooo]ZokWo000YoookJP?o07?o;?oonfX3o`1c
ob3ooo]Z00?o^Ol0o`3o<oooDP001?oonfX2o`0Zo`;ooo]Z0_loo`02oookJP;o0=co0_mho`09oook
JP;o00000_l0oa/2oookJP03ooo:0?oonf[ooo]Z00;ooo]Z00Co0?WooookJ_oonf[oo`2C1ooonfX0
0ooJo`3ohOl0oookJP02oookJP04obH0oooonf[o8?l0oh@0oa;ooo]Z00?o<Ol0oookJ_l0oe/00_oo
nfX01ol0ok3oP_l0oookJ_oonf[o033ooookJ_l0odd00_oonfX02?l60?oooo]ZoookJ_oonf[oT_l0
oookJ_l@0?oo01Wo1?oonfX01?lE0?oooo]Zool0DOl0[Ol2oookJP03ool0NOoonf[ooo]Z00Gooo]Z
00So0?mCoookJ_oonf[ooo]Zo`3o7Ol0o`Sooo]Zo`3Qo`cooo]Z00?o0?ldo`3oC_l0obh01_oonfX0
0ol0R?oo0:WooookJP03oookJP04o`04oooonf[ooo]Zo`3Do`kooo]Z00?ooh40oookJ_oonfX02_oo
nfX00ooo02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z00[ooo]Z00?oj`3ooookJ_oonfX00_oo
nfX00ooo_P3ooo]ZoookJP0>oookJP03oon@0?oonf[ooo]Z00?ooo]Z00Coi_l0o`1doooonf[o603o
:OoonfX0033ooo]Z00OoolX0oookJ_oonf[ooo]Zoomi0?oonf[o4P3o017ooo]Z00?o?@3oo`3ogooo
nfX00_mho`02oookJP05o`3Loooonf[ooo]ZoookJ_loo`001OoonfX2o`0Zo`Gooo]Z00?o0?lcoomB
0?oonfX00_nio`0[oookJPCo07?o7_oonfX:o`1cob3ooo]Z00?o^Ol0onGo0?oUo`002?oUo`000ooo
nf[oobP0oolX0006oolX00_ooo]Z00Ko4P3oo`3o6ooo:03o0000oookJ_oobP04oookJP04o`3ioooo
nf[oo`2CoolX00Oooo]Z00?oobP0on7o0?oonfX00_oonfX01?lV0?oooo]Zob3o0?n40?lBoookJP03
oc7o0?oonf[o0?mK00;ooo]Z00KoP_l0oookJ_oonf[ooo]Zo`3o/Ooo:002oookJP05o`H0oooonf[o
oo]ZoookJ_nBo`000_oonfX00ol@0?ooobP0oookJP03oookJP06oaD0oooonf[oo`1Ao`2]oooonf[o
o`1i2OoonfX01ol0oe?ooo]ZoookJ_l0oago0?l8oookJ_l0hOl03?oonfX01?l0ocCooo]Zo`3oC_l0
obh5oookJP03o`28ool0ZOoooo]Z00;ooo]Z00Co00CooookJ_oonf[o0=Co3_oonfX00oooP@3ooo]Z
oookJP0;oookJP03ool0;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX02OoonfX00oo[0?ooL03o
oookJP03oookJP03oonn0?oonf[ooo]Z00kooo]Z00?ooi00oookJ_oonfX00ooonfX00ooVo`3o07Co
odCo001HoookJP06ooo:0?oonf[ooo]Zo`3o6ooonf[o4P3o4_oonfX2o`3og`03oookJ_mho`3ooo]Z
00;ooo]Z00?o0=cooookJ_oonfX00_loo`04oookJP;o02[o1OoonfX01?l0oc?ooe80oookJ_oonfX2
okWo02[ooo]Z1?l0LolNoookJP[o07?o8?oonfX3okWo00;ooe801?oonfX00ol0:_oooo]ZoookJP02
ocoo00;ooo]Z0_l0g?l2ogSo00_ooo]Z00Ko4P3oo`3o6ol0S_oo0000oookJ_oobP04oookJP04o`3i
oooonf[oo`2Cool0T`Oooo]Z00?of_l0on7o0?oonfX00_oonfX01?lV0?oooo]Zob3o0?n40?lBoook
JP03oc7o0?oonf[o0?mK00?ooo]Z00KoP_l0oookJ_oonf[o0?nao`0`ool0odd2oookJP08o`H0oooo
nf[ooo]ZoookJ_nBo`3ooo]Zoa00ool06Ol4oookJP07oaD0oooonf[ooo]Zool0DOl0[Ooooo]Zool0
N@08oookJP05o`3oDooonf[ooo]ZoookJ_l0oad00_oonfX00ol0hOoooo]ZoookJP09oookJP04o`3o
=?oonf[o0?m>o`3o;PGooo]Z00?o08Soo`2YoooonfX00ooonfX01?l01?oooo]ZoookJ_l0e?l>oook
JP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX02?oonfX00oooE`3ooo]ZoookJP09oook
JP03on/0oom`0?oooo]Z00;ooo]Z00?ookh0oookJ_oonfX03ooonfX00oooT03ooo]ZoookJP03oook
JP03onKo0?l0M?oo603o02[ooo]Z000aoookJP07ooo:0?oonf[ooo]ZoookJ_ooN@3ooo]Zoa80o`0A
oookJP05ocd0ool0omoo0?oOoookJ_mho`000_oonfX01Ol0g?oooo]ZoookJ_oonf[o?ol000Kooo]Z
00?o02[ooookJ_oonfX01?oonfX2oomB0003oookJ_nio`3o^Ol002gooo]Z0ol0Lol:oookJQ7o07?o
:?oonfX2okWo00OoiOl000?o02[ooookJ_oonfX00_oo:0000ooonf[oobP0oolX0005oolX00Wooo]Z
0_lB0?l01Ol0oa_o0000o`000?l0003oolX000?ooo]Z0_l0nOl00ooonf[oo`2CoookJP06oookJP;o
obP000SohOl0oookJ_oonf[ooo]ZobH0oooonf[o8?l0oh@0oa;ooo]Z00Oo<Ol0oookJ_oonf[o0?mK
oookJ_l0ok3oP_l000;ooo]Z00?o0?naoolX0?oonfX00_oonfX01?l60?oooo]ZoookJ_nBo`02oook
JP03oa00ool06OooobP000Cooo]Z00?o5@3oool0DOl0[Ol00_oonfX00ooo07Wooo]ZoookJP06oook
JP07o`3oDooonf[ooo]Zo`3o7Ooonf[o0?l8o`3Qo`0<oookJP04o`3o=?oonf[o0?m>o`3o;PGooo]Z
00?o08Soo`2YoooonfX00ooonfX01?l01?oooo]ZoookJ_l0e?l>oookJP03oon10?oonf[ooo]Z00_o
oo]Z00?oo`0]oookJ_oonfX01_oonfX00oooE`3ooo]ZoookJP0:oookJP03on/0oooonf[ooo]Z00;o
oo]Z00?ookh0oookJ_oonfX03_oonfX00oooT03ooo]ZoookJP04oookJP03onKo0?oonf[oA?l005Wo
oo]Z00KoolX0oookJ_oonf[o0?lKoookJ_lB0?lBoookJP04ocd0ool0omoooo]ZogSo00?ooo]Z00Go
0=cooookJ_oonf[ooo]Zocoo0005oookJP03o`0Zoooonf[ooo]Z00Cooo]Z0_ooDP02oookJP;o^Ol0
;?oonfX3o`1co`[ooo]Z4Ol0LolXoookJP;o^Ol000?ooo]ZoomB0?ooDP001?oonfX2o`0Zo`03oook
J_loo`3o?ol000;ooo]Z0_l0g?l2ogSo00cooo]Z00?o4P3oo`3o6ol000000_l000001?oobP3ooo]Z
oookJ_oonfX2o`3io`03oookJ_oo09?oo`0C00Kooo]Z0_oJo`002?oQo`3ooo]ZoookJ_oonf[o9P3o
oookJ_lPo`3oQ03o4_oonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP06o`3o/?n2o`3ooo]Zo`3o/Ol0
<?oo0?m=0ooonfX01?l60?oooo]ZoookJ_nBo`02oookJP03oa00oooo06[ooo]Z00?ooo]Z00Ko5@3o
oookJ_oo057o0:gooookJ_oo07T8oookJP08o`3oDooonf[ooo]ZoookJ_l0oago0?l8oookJ_l0hOl<
oookJP03o`3o=?l0odko0?l^00Kooo]Z00?o0:WooookJ_oonfX00_oonfX01Ol01?oooo]ZoookJ_oo
nf[o0=Co00kooo]Z00?ooh40oookJ_oonfX02_oonfX00ooo02gooo]ZoookJP07oookJP03oomG0?oo
nf[ooo]Z00[ooo]Z00Goj`3ooookJ_oonf[ooo]Zoonn000AoookJP03oon@0?oonf[ooo]Z00?ooo]Z
00Coi_l0o`1doooonf[o603o:_oonfX003;ooo]Z00OoolX0oookJ_oonf[ooo]Zoomi0?l0oa_o4P3o
017ooo]Z00Go?@3ooookJ_l0omoooo]ZogSo0002oookJP05o`3Loooonf[ooo]ZoookJ_loo`001_oo
nfX2o`0Zo`Gooo]Z00Go0?lcoomB0?oonf[ooo]ZokWo000_oookJP[o07?o=_oonfX3okWo0003o`3o
<ooUo`3oiOl000?oiOl00_l0:_l3oookJP03oolX0?oonf[ooo]Z00WoobP01ooonfX00olB0?oo08ko
o`3o6`03o`000006ooo:0?oonf[ooo]ZoookJ_l0nOoooo]Z0_oo09<7oookJP03oolX0?oonf[ohOl0
00?ooo]Z00Co9P3ooookJ_lPo`3oQ03o4_oonfX01olao`3ooo]ZoookJ_l0oe_ooo]Zo`3o/?n2o`00
0_oonfX00ol0ok7oobP0o`3Xo`02oookJP05o`H0oooonf[ooo]Zool0mOnBo`000_oonfX00ol@0?oo
obP0oookJP03oookJP03oaD0oooo057o0:go00;ooo]Z00?oo`1ioookJ_oonfX01_oonfX01ol0oe?o
oo]ZoookJ_oonf[o0?lMo`3o2?l0hOl03OoonfX01?l0ocCooo]Zo`3oC_l0obh5oookJP03o`28ool0
ZOoooo]Z00;ooo]Z00Co00CooookJ_oonf[o0=Co3_oonfX00oooP@3ooo]ZoookJP0;oookJP03ool0
;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX02OoonfX00om`0?ooj`3ooookJP03oookJP03oonn
0?oonf[ooo]Z00kooo]Z00?ooi00oookJ_oonfX00ooonfX00ooVo`3o07CoodCo001JoookJP04ooo:
0?oonf[ooo]ZoookJP;o0?lK00?o4P3ooookJ_oonfX04?oonfX01?lm0?oo0?oOo`3ogomho`03oook
JP05o`3Loooonf[ooo]ZoookJ_loo`001OoonfX2o`0Zo`Gooo]Z00?o0?lcoomB0?oonfX00_oonfX0
0onio`3ooo]ZoookJP0/oookJP[o07?o=_oonfX3okWo0003oookJ_l0oc?ooe8000Cooo]Z0_l0:_l2
oookJP03ocoo0?oonf[ooo]Z00;o0=co0_mho`000olm0?oooo]ZoookJP0:oookJP03oa80ool0oa_o
000000;o000000KoolX0oookJ_oonf[ooo]Zo`3ioooonfX2ool0T`03ool04ooonf[ooo]Z00Cooo]Z
00?of_l0oookJ_oQo`000ooonfX01?lV0?oooo]Zob3o0?n40?lBoookJP04oc7o0?oonf[ooo]Zo`3o
F`;ooo]Z00Ko0?n`oh;o0?oonf[o0?nao`0`ool0odd3oookJP08o`H0oooonf[ooo]Zool0mOnBo`3o
oo]Zoa00oooo06X4oookJP06oaD0oooonf[oo`1Ao`2]oooonf[oo`1i2?oonfX02?l0oe?ooo]Zoook
J_oonf[o0?lMo`3o2?oonf[o0>7o3?oonfX01?l0ocCooo]Zo`3oC_l0obh5oookJP03o`28ool0ZOoo
oo]Z00?ooo]Z00Co00CooookJ_oonf[o0=Co3_oonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooo
nf[ooo]Z00Sooo]Z00?ooeL0oookJ_oonfX02OoonfX00om`0?ooj`3ooookJP02oookJP03oonn0?oo
nf[ooo]Z00oooo]Z00?ooi00oookJ_oonfX00ooonfX00ooVo`3o07CooaP0o`0[oookJP00<_oonfX0
0ooobP3ooo]ZoookJP03oookJP03o`3o6ol0S_oooo]Z013ooo]Z00Go?@3ooookJ_l0omoo0?oOogSo
0002oookJP04o`3Loooonf[ooo]ZoookJP;o?ol01_oonfX2o`0Zo`Gooo]Z0_ooDP000ooonf[o^Ol0
okWo001ZoookJP?o^Ol00_oonfX00oooDP3oiOl0onGo0003oookJP04o`0Zoooonf[ooo]ZoookJP;o
obP000?ooo]Zo`3Loooo:0000_oo:0000ol0omooobP0oolX0005oolX00Gooo]Z00Go4P3oo`2>ool0
oa_ooo]Zo`000002ooo:0007o`000?oonf[ooo]Zo`3ioooonf[oo`2Cool04`07oookJP03oolX0?oo
nf[ohOl000?ooo]Z00?o9P3ooookJ_lPo`004ooonfX01olao`3ooo]ZoookJ_l0oe_ooo]Zo`3o/?n2
o`000_oonfX00ol0<?ooobP0o`3Xo`02oookJP05o`H0oooonf[ooo]Zool0mOnBo`000_oonfX00ol@
0?ooobP0oookJP03oookJP06oaD0oooonf[oo`1Ao`2]oooonf[oo`1i2OoonfX01ol0oe?ooo]Zoook
J_l0oagooo]Zo`3o2?l0hOl03?oonfX01?l0ocCooo]Zo`3oC_l0obh5oookJP03o`28ool0ZOoooo]Z
00;ooo]Z00Co00CooookJ_oonf[o0=Co3_oonfX00oooP@3ooo]ZoookJP0<oookJP03ool0;Ooonf[o
oo]Z00Kooo]Z00?ooeL0oookJ_oonfX02_oonfX00oo[0?oooo]ZoookJP02oookJP03oonn0?oonf[o
oo]Z00kooo]Z00?ooi00oookJ_oonfX01?oonfX00ooVo`3ooo]ZodCo001KoookJP03ooo:0?oonf[o
oo]Z00;ooo]Z00?o0?lKo`2>oooonfX04OoonfX00olm0?oooo]Zo`3og`02ogSo00;ooo]Z00Go0=co
oookJ_oonf[ooo]Zocoo0006oookJP;o02[o1OoonfX2oomB00;ooo]Z0_nio`1ZoookJP;o^Ol00ooo
nfX2oomB00Cooo]Z00?o02[ooookJ_oonfX00_loo`000ooonf[o0=coo`3Lo`02ogSo0003o`3ogooo
nf[ooo]Z00[ooo]Z0_lB0?l00ol0oa_ooo]Zo`000002ooo:0007o`000?oonf[ooo]Zo`3ioooonf[o
o`2Cool04`07oookJP03om[o0?oonf[ohOl000?ooo]Z00?o9P3ooookJ_lPo`004ooonfX01?lao`3o
oo]ZoookJ_l0oe/2oookJP03o`3o/?n2o`3ooo]Z00;o033o00Go0?m=o`3Xoooonf[ooo]Zo`H0o`02
oookJP05ool0mOnBo`3ooo]Zoa00oooo06X01?oonfX01?lE0?oooo]ZoookJ_oo0542oookJP03ool0
NOoonf[ooo]Z00Kooo]Z00Oo0?mCoookJ_oonf[o0?lMoookJ_l0o`So0>7o00cooo]Z00Co0?ldoook
J_l0odko0?l^1OoonfX00ol0R?oo0:WooookJP03oookJP04o`04oooonf[ooo]Zo`3Do`kooo]Z00?o
oh40oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP07oookJP03oomG0?oonf[ooo]Z00[ooo]Z00Go
j`3ooookJ_oonf[ooo]Zoonn000AoookJP03oon@0?oonf[ooo]Z00?ooo]Z00Coi_l0o`1doooonf[o
603o:ooonfX002[ooo]Z00?oo`2CoookJ_oonfX01_oonfX00ooobP3ooo]ZoookJP03oookJP03o`3o
6ooonf[ooo]Z013ooo]Z00Co?@3ooookJ_oonf[o0?oO0_mho`000ooonf[o0=cooookJP03oookJP03
ocoo0?oonf[ooo]Z00Gooo]Z00?o02[ooookJ_oonfX00ooonfX01?l0oc?ooe80oookJ_oonfX2okWo
06Kooo]Z0_nio`02oookJP?ooe8000Cooo]ZoolX0?oo:03ooo]Z0_l0:_l2oookJP;oobP000?ooo]Z
o`3Lool0g?l00_oo:0000ol0omooobP0oolX0005oolX00Gooo]Z0_lB0?l01Ooonf[o0?lKoookJ_oo
nf[oolX000?o000000Gooo]Zo`3ioooo09?oo`2Cool04`07oookJP03oolX0?oonf[ohOl000?ooo]Z
00?o9P3ooookJ_lPo`004ooonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP06oh;o0?oonf[ooo]Zo`0`
oooo:03o0>So0_oonfX01Ol60?oooo]ZoookJ_oo0?GoT_l000;ooo]Z00?o403ooolX0?oonfX00ooo
nfX01_lE0?oooo]Zool0DOl0[Ooooo]Zool0N@Wooo]Z00Oo0?mCoookJ_oonf[o0?lMoookJ_l0o`So
0>7o00cooo]Z00Co0?ldoookJ_l0odko0?l^1OoonfX00ol0R?oooo]Zo`2Yo`03oookJP04o`04oooo
nf[ooo]Zo`3Do`kooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP07oookJP03oomG
0?oonf[ooo]Z00Wooo]Z00?oL03oon/0oooonfX00ooonfX00ooo_P3ooo]ZoookJP0>oookJP03oon@
0?oonf[ooo]Z00?ooo]Z00?oi_l0o`1doom4o`00DooonfX00ooo09?ooo]ZoookJP07oookJP03ooo:
0?oonf[ooo]Z00;ooo]Z00?o0?lKoookJ_oonfX04OoonfX01Olm0?oooo]Zo`3ogol0omooN?l000;o
oo]Z00Co0=cooookJ_oonf[ooo]Z0_loo`06oookJP03o`0Zoooonf[ooo]Z00?ooo]Z00?o0?lcoomB
0?oonfX00_oonfX2okWo06Gooo]Z0onio`02oookJP?ooe801?oonfX2o`0Zo`04oookJ_loo`3o?ol0
oookJP;o0=co00Cooo]ZogSo0?l0omoo?@3o3?oonfX00olB0?oooo]Zo`3o6`02oookJP06ooo:0?l0
003o0000o`000?oonf[o0?Wo0_oo09<00ooo01?ooo]ZoookJP05oookJP03om[o0?oonf[ohOl000?o
oo]Z00?o9P3ooookJ_lPo`004ooonfX01?lao`3ooo]ZoookJ_l0oe/2oookJP07o`3o/?n2o`3ooo]Z
o`0`oooonf[o0?m=o`3Xo`02oookJP08o`H0oooonf[ooo]Zool0mOnBo`3ooo]Zoa00ool06Ol4oook
JP07oaD0oooonf[ooo]Zool0DOl0[Ooooo]Zool0N@08oookJP08o`3oDooonf[ooo]ZoookJ_l0oago
0?l8oookJ_l0hOl;oookJP04o`3o=?oonf[o0?m>o`3o;PKooo]Z00?o08Soo`2YoooonfX00_oonfX0
1?l01?oooo]ZoookJ_l0e?l?oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX02?oo
nfX00oooE`3ooo]ZoookJP09oookJP03og00ooo[0?oooo]Z00;ooo]Z00?ookh0oookJ_oonfX03_oo
nfX00oooT03ooo]ZoookJP04oookJP03onKo0?l0M?oo603o02cooo]Z000ZoookJP03ool0Tooonf[o
oo]Z00Oooo]Z00?oolX0oookJ_oonfX00ooonfX2o`3o6a7ooo]Z0_lm0?l01Ooonf[o0?oOo`3ogomh
o`3ooo]Z00;o0=co0ooonfX00oloo`3ooo]ZoookJP05oookJP;o02[o1?oonfX00ol0oc?ooe80oomB
0002oookJP03okWo0?oonf[ooo]Z063ooo]Z0onio`001Ooonf[ooe80oomB0?ooDP3o0?lc00;ooo]Z
00CoobP0o`0Zool0:_oo02[o0_oonfX2oolX0003oookJ_l0g?oo0=co00;oobP000?o0?oOoolX0?oo
:0001?oo:007oookJP05oa80ool0S_oo0?lKo`3o6ooonfX00_oobP04o`000003o`3ioooo09?oo`0C
00Sooo]Z00?oobP0oookJ_oQo`000ooonfX00olV0?oooo]Zob3o000CoookJP04oc7o0?oonf[o0?mK
o`3oF`;ooo]Z00KoP_l0oookJ_oonf[o033ooookJ_oo:002oookJP05o`H0oooonf[ooo]Zool0mOnB
o`000_oonfX00ol@0?ooobP0oookJP03oookJP06oaD0oooonf[oo`1Ao`2]oooonf[oo`1i2_oonfX0
1_l0oe?ooo]Zo`3o7Ooonf[o0?l8o`3Qo`cooo]Z00Co0?ldoookJ_oonf[o0?m>1OoonfX00ol0R?oo
oo]Zo`2Yo`03oookJP04o`04oooonf[ooo]Zo`3Do`kooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo
02gooo]ZoookJP08oookJP03oomG0?oonf[ooo]Z00Wooo]Z00?oj`3ooookJ_oonfX00_oonfX00ooo
_P3ooo]ZoookJP0?oookJP03oon@0?oonf[ooo]Z00?ooo]Z00?oi_l0oookJ_m4o`001ooonfX00omX
0?oooo]ZoookJP19oookJP03ool0Tooonf[ooo]Z00Sooo]Z00?oolX0oookJ_oonfX00_oonfX2o`3o
6a;ooo]Z0_lm0?l00ooonf[o0?oOogSo0002oookJP;o0=co0ooonfX00oloo`3ooo]ZoookJP04oook
JP;o02[o1?oonfX00ol0oc?ooe80oomB0003oookJP03okWo0?oonf[ooo]Z063ooo]Z0_nio`02oook
JP?ooe8000Co0?lcoookJ_oonf[ooo]Z0ol0:_l01?oonf[o?ol0ocoo0?oonfX2o`3Lo`04oookJ_mh
o`3oN?l0ocd0o`cooo]Z0_lB0?l2o`3o6`03oookJ_oobP3oolX000Co000000Co0?Woool0Tooonf[o
o`0C1ooonfX00ooJo`3ooo]Zon7o0003oookJP03obH0oooonf[o8?l001?ooo]Z00Co<Ol0oookJ_l0
oe_o0?mK0_oonfX01?l0ok3oP_l0oookJ_l0<?l2oookJP04o`3oCOoonf[ooo]Zo`H0o`;ooo]Z00Go
o`3eoi;o0?oonf[ooo]Zoa00o`04oookJP07oaD0oooonf[ooo]Zool0DOl0[Ooooo]Zool0N@09oook
JP07o`3oDooonf[ooo]Zo`3o7Ol0o`Sooo]Zo`3Qo`0<oookJP03o`3o=?oonf[o0?m>00Kooo]Z00?o
08Soo`2YoooonfX00ooonfX01?l01?oooo]ZoookJ_l0e?l>oookJP03oon10?oonf[ooo]Z00[ooo]Z
00?oo`0]oookJ_oonfX02?oonfX00oooE`3ooo]ZoookJP0:oookJP05on/0oooonf[ooo]ZoookJ_oo
_P004OoonfX00oooT03ooo]ZoookJP03oookJP04onKo0?l0M?oooo]ZoaP0o`Oooo]Z00?oJ03ooook
J_oonfX08_oonfX002[ooo]Z00?o0?Woool0TooonfX02?oonfX00ooobP3ooo]ZoookJP03oookJP03
oa80ool0oa_ooo]Z017ooo]Z0_lm0?l00ooonf[o0?oOogSo0002oookJP05o`3Loooonf[ooo]Zoook
J_loo`002?oonfX2o`0Zo`Cooo]Z00Co0?lcoomB0?oonf[ooo]Z0_nio`1NoookJP;o^Ol000Gooo]Z
oomB0?ooDP3ooe80o`3o<`04oookJP;o02[o1Ooo:0000ooonf[o0=coo`3Lo`02oolX00;o0?oO1?oo
:008oookJP05o`2>oolB0?oo0?lKo`3o6ooonfX00_oobP02oookJP;o000000Co0?Woool0Tooo09?o
o`0C2?oonfX00ooo:03ooo]Zon7o0003oookJP03obH0oon40?oo8?l001Cooo]Z00?o<Ol0o`3oFooo
nfX00_oonfX01_n2o`3ooo]ZoookJ_l0<?oooo]ZoolX00;ooo]Z00Go1P3ooookJ_oonf[oo`3eoi;o
0002oookJP03o`0Iool@0?oooo]Z00Cooo]Z00Ko5@3oool0DOoonf[o0:gooookJ_oo07T9oookJP06
o`3oDooonf[ooo]Zo`3o7Ol0o`So0>7o3OoonfX01?l0ocCooo]Zo`3oC_l0obh5oookJP03o`28oooo
nf[o0:Wo00;ooo]Z00Co00CooookJ_oonf[o0=Co3_oonfX00oooP@3ooo]ZoookJP0<oookJP03ool0
;Ooonf[ooo]Z00Oooo]Z00?ooeL0oookJ_oonfX02OoonfX00om`0?ooj`3ooookJP02oookJP03oonn
0?oonf[ooo]Z00oooo]Z00?ooi00oookJ_oonfX00ooonfX00ooVo`3o07CoodCo0008oookJP03ofP0
oooonf[ooo]Z04Wooo]Z00?o0?Woool0TooonfX02?oonfX00ooobP3ooo]ZoookJP03oookJP03oa80
ool0oa_ooo]Z01;ooo]Z0_lm0?l00ol0omooN?l0oookJP02oookJP05o`3Loooonf[ooo]ZoookJ_lo
o`001ooonfX2o`0Zo`Cooo]Z00?o0?lcoomB0?oonfX00_oonfX2okWo05gooo]Z0onio`001Ooonf[o
oe80oomB0?ooDP3o0?lc00?ooo]Z0ol0:_l2oookJP;o?ol000Cooo]Zo`3Lool0g?oooo]Z0_mho`00
0ol0omoo?@3ooookJP0;oookJP04oa80ool0oa_o0?lKoookJP;oolX00_oonfX2o`000005o`3ioooo
09?oo`2CoookJ_oo01<01ooonfX00ooJo`3ooo]Zon7o0003oookJP03obH0oon40?oo8?l001Cooo]Z
00?o<Ol0o`3oFooonfX00_oonfX01?l0ok3oP_l0oookJ_l0<?l2oookJP04o`3oCOoonf[ooo]Zo`H0
o`;ooo]Z00Koo`3eoi;o0?oonf[ooo]Zoa00ool0GOl4oookJP06oaD0oooonf[oo`1Ao`2]oooonf[o
o`1i2OoonfX01ol0oe?ooo]ZoookJ_l0oago0?l8oookJ_l0hOl03?oonfX01?l0ocCooo]Zo`3oC_l0
obh5oookJP03o`28oooonf[o0:Wo00?ooo]Z00Co00CooookJ_oonf[o0=Co3_oonfX00oooP@3ooo]Z
oookJP0;oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00?ooeL0oookJ_oonfX02OoonfX01Oo[0?oooo]Z
oookJ_oonf[ookh0017ooo]Z00?ooi00oookJ_oonfX01?oonfX00ooVo`3o07CooaP0o`08oookJP03
ofP0oooonf[ooo]Z02;ooo]Z000/oookJP03ool0Tooonf[ooo]Z00Kooo]Z00?oolX0oookJ_oonfX0
1?oonfX00olB0?oo0?lKoookJP0BoookJP;o?@3o00Go0?oOogSo0?oonf[ooo]Zo`3Lo`03oookJP;o
?ol02?oonfX00ol0:_oooo]ZoookJP02oookJP03o`3o<oooDP3ooe8000;ooo]Z0_nio`1IoookJP?o
^Ol000Cooo]ZoomB0?ooDP3o0?lc1?oonfX3o`0Zo`KoobP00_l0g?l2oolX00;o0?oO0ooo:00:oook
JP03oa80ool0oa_o0?lK00;ooo]Z00?oolX0oookJ_oonfX00_oonfX01Ol0003o0?Woool0Tol0003o
o`0C00;ooo]Z00?oobP0oookJ_oonfX00_oonfX2oolX00;ohOl00ooonfX00olV0?ooQ03oob3o000D
oookJP03oc7o0?l0oe_ooo]Z00;ooo]Z00KoP_l0oookJ_oonf[o033ooookJ_oo:002oookJP05o`H0
oooonf[ooo]Zool0mOnBo`000ooonfX00ol@0?oooo]ZoookJP03oookJP06oaD0oooo057ooo]Zo`2]
oooonf[oo`1i2OoonfX01ol0oe?ooo]ZoookJ_l0oago0?l8oookJ_l0hOl03?oonfX01?l0ocCooo]Z
oookJ_l0odh5oookJP03o`28oooonf[o0:Wo00?ooo]Z00Co00CooookJ_oonf[o0=Co3_oonfX00ooo
P@3ooo]ZoookJP0;oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00?ooeL0oookJ_oonfX02?oonfX00om`
0?ooj`3ooookJP03oookJP03oonn0?oonf[ooo]Z00oooo]Z00?ooi00oookJ_oonfX00ooonfX00ooV
o`3ooo]ZodCo0007oookJP03ofP0oooonf[ooo]Z04cooo]Z00?oo`2CoookJ_oonfX01ooonfX00ooo
bP3ooo]ZoookJP03oookJP03oa80ool0oa_ooo]Z01?ooo]Z0_lm0?l01Omho`3ooo]ZoookJ_oonf[o
0=co00?ooo]Z0_loo`07oookJP03o`0Zoooonf[ooo]Z00;ooo]Z00?o0?lcoomB0?ooDP000ooonfX2
okWo05Wooo]Z0_nio`001Ooonf[ooe80oomB0?ooDP3o0?lc00Cooo]Z0_l0:_l4oookJP05ocoo0?oo
nf[o0=coo`3LoooonfX00_mho`000ol0omoo?@3ooookJP0;oookJP03o`2>ool0oa_o0?lK00;ooo]Z
00?oolX0oookJ_oonfX00_oonfX01_l0003o0?Woool0Tol0003ooo]Zool04`Kooo]Z0_oJo`02on7o
00?ooo]Z00?o9P3ooh@0oolPo`005?oonfX00olao`3o0?mKoookJP03oookJP03oh;o0?oonf[o033o
00;ooo]Z00Co0?m=oookJ_oonf[o1P3o0_oonfX01_oo0?GoT_l0oookJ_oonf[o403oo`1Mo`Cooo]Z
00Ko5@3ooookJ_oo057ooo]Zo`2]oooo07T9oookJP07o`3oDooonf[ooo]ZoookJ_l0oagooo]Zo`3Q
o`0<oookJP04o`3o=?oonf[ooo]Zo`3oCPKooo]Z00?o08Soo`2YoooonfX00_oonfX01?l01?oooo]Z
oookJ_l0e?l?oookJP03oon10?oonf[ooo]Z00[ooo]Z00?oo`0]oookJ_oonfX02?oonfX00oooE`3o
oo]ZoookJP09oookJP03og00ooo[0?oooo]Z00;ooo]Z00?ookh0oookJ_oonfX03ooonfX00oooT03o
oo]ZoookJP03oookJP04onKo0?l0M?oooo]ZoaP0o`Oooo]Z00?oJ03ooookJ_oonfX08ooonfX002go
oo]Z00?oo`2CoookJ_oonfX01_oonfX00ooobP3ooo]ZoookJP04oookJP03oa80ool0oa_o0?lK01?o
oo]Z0_lm0?l01?mho`3ooo]ZoookJ_l0g?l4oookJP03ocoo0?oonf[ooo]Z00Kooo]Z0_l0:_l5oook
JP05oomB0?l0oc?o0?lcoookJ_nio`00E_oonfX2okWo0004oookJ_ooDP3ooe80oomB00Cooo]Z0ol0
:_l00ooonf[oobP0oolX0004oolX00;o0=co0_oo:002o`3og`;oobP02ooonfX00ol0S_oo4P3oo`3o
6`02oookJP;oolX01OoonfX01?l0nOooo`2Co`000?oo01<3oookJP07oolX0?oonf[ooo]ZoookJ_oo
:03ooo]Zon7o0004oookJP03obH0oon40?oo8?l001Cooo]Z00?o<Ol0o`3oFooonfX00_oonfX02On2
o`3ooo]ZoookJ_l0<?oooo]ZoolX0?l0j?oooo]Zo`H0o`02oookJP03ool0mOnBo`3ooo]Z00;ooo]Z
00?o403ooolX0?oonfX00ooonfX01_lE0?ooo`1AoookJ_l0[Ooooo]Zool0N@[ooo]Z00Ko0?mCoook
J_l0oago0?l8oookJ_l0hOl<oookJP04o`3o=?oonf[ooo]Zo`3oCPGooo]Z00?o08SooookJ_l0ZOl0
0ooonfX01?l01?oooo]ZoookJ_l0e?l>oookJP03oon10?oonf[ooo]Z00cooo]Z00?oo`0]oookJ_oo
nfX01ooonfX00oooE`3ooo]ZoookJP09oookJP03on/0oooonf[ooo]Z00;ooo]Z00?ookh0oookJ_oo
nfX03ooonfX00oooT03ooo]ZoookJP04oookJP03onKo0?m4o`3ooo]Z00Oooo]Z00?oJ03ooookJ_oo
nfX0COoonfX00ooo09?ooo]ZoookJP07oookJP03ooo:0?oonf[ooo]Z00?ooo]Z00?o4P3oo`3o6ol0
oa/05?oonfX00olm0?ooN?l0ogSo0002oookJP03o`3Loooonf[ooo]Z00;ooo]Z00?o?ol0oookJ_oo
nfX01OoonfX2o`0Zo`Gooo]Z00?ooe80o`3o<ol0oc<00_oonfX00onio`3ooo]ZoookJP1CoookJP?o
^Ol00oooDP000ol0oc?ooo]ZoookJP02oookJP?o02[o1?oonfX2ocoo00;o0=co00Cooo]ZogSo0?mh
o`3o0?oO0_lm0?l;oookJP03o`2>oolB0?oo0?lK00;ooo]Z0_oobP05oookJP05o`3ioooo09?o0000
o`000?oo01<01_oonfX00ooJo`3ooo]Zon7o0004oookJP03obH0oon40?oo8?l001Cooo]Z00?o<Ol0
o`3oFooonfX00ooonfX00on2o`3ooo]Zo`0`o`02oookJP04o`3oCOl0j?oooo]Zo`H0o`;ooo]Z00Ko
o`3eoi;o0?oonf[ooo]Zoa00ool0GOl4oookJP07oaD0oooonf[oo`1AoookJ_l0[Ooooo]Zool0N@09
oookJP06o`3oDooonf[ooo]Zo`3o7Ol0o`So0>7o3OoonfX00ol0ocCooo]Zo`3oCP06oookJP03o`28
ool0ZOoooo]Z00?ooo]Z00Co00CooookJ_oonf[o0=Co3_oonfX00oooP@3ooo]ZoookJP0;oookJP03
ool0;Ooonf[ooo]Z00Sooo]Z00?ooeL0oookJ_oonfX02OoonfX01Oo[0?oooo]ZoookJ_oonf[ookh0
017ooo]Z00?ooi00oookJ_oonfX01?oonfX00ooVo`3o07CooaP0o`08oookJP03ofP0oooonf[ooo]Z
02?ooo]Z000ZoookJP05ool04ooonf[ooo]ZoookJ_oo09<02?oonfX00ooobP3ooo]ZoookJP04oook
JP03oa80ool0S_oo0?lK01Cooo]Z00Go?@3oogSo0?mho`3ooo]Zo`3Lo`04oookJP03ocoo0?oonf[o
oo]Z00Oooo]Z0_l0:_l4oookJP?ooe800_l0oc<00onio`3ooo]ZoookJP1?oookJP;o^Ol000Co0?lc
oomB0?ooDP3ooe801OoonfX2o`0Zo`?ooo]Z1Ooo:002o`3Lo`?oobP000?o0?oOocd0oooonfX02ooo
nfX01Ol0S_oo4P3oo`3o6ol0oa_ooo]Z00;oolX01_oonfX2ool0T`03o`000?oo01?o000000;ooo]Z
0ooo:0001?oonf[oobP0on7o0?oQo`04oookJP03obH0oon40?oo8?l001Cooo]Z00?o<Ol0o`3oFooo
nfX00_oonfX02On2o`3ooo]ZoookJ_l0<?oooo]ZoolX0?l0j?oooo]Zo`H0o`02oookJP03ool0mOnB
o`3ooo]Z00;ooo]Z00?o403ooolX0?oonfX00ooonfX01_lE0?ooo`1AoookJ_l0[Ooooo]Zool0N@[o
oo]Z00Ko0?mCoookJ_oonf[o0?lMo`3o2?l0hOl<oookJP04o`3o=?oonf[ooo]Zo`3oCPKooo]Z00?o
08SooookJ_l0ZOl00_oonfX01?l01?oooo]ZoookJ_l0e?l>oookJP03oon10?oonf[ooo]Z00cooo]Z
00?oo`0]oookJ_oonfX02?oonfX00oooE`3ooo]ZoookJP08oookJP03og00ooo[0?oooo]Z00?ooo]Z
00?ookh0oookJ_oonfX03ooonfX00oooT03ooo]ZoookJP03oookJP03onKo0?oonf[oA?l000Oooo]Z
00?oJ03ooookJ_oonfX0BooonfX01Ooo01?ooo]ZoookJ_oonf[oo`2C00Wooo]Z00?oolX0oookJ_oo
nfX00ooonfX00olB0?oo08koo`3o6`0EoookJP05o`3ogomho`3ooo]ZoookJ_l0g?l01?oonfX00olo
o`3ooo]ZoookJP06oookJP;o02[o1?oonfX3oomB00;o0?lc0_nio`1AoookJP;o^Ol00oooDP05oook
JP?o02[o1OoonfX2ocoo00;o0=co00Cooo]ZogSo0?mho`3o0?oO0_lm0?l<oookJP04o`2>ool0oa_o
0?lKoookJP;oolX01_oonfX2ool0T`;o000000?oo`0CoookJ_oonfX01?oonfX00ooJo`3ohOl0on7o
0004oookJP03obH0oon40?oo8?l001Cooo]Z00?o<Ol0o`3oFooonfX00ooonfX00on2o`3ooo]Zo`0`
o`02oookJP04o`3oCOl0j?oooo]Zo`H0o`;ooo]Z00Ooo`3eoi;o0?oonf[ooo]Zoa00oooonf[o05go
00?ooo]Z00Oo5@3ooookJ_oo057ooo]Zo`2]oooonf[oo`1i00Wooo]Z00Oo0?mCoookJ_oonf[o0?lM
o`3o2?oonf[o0>7o00cooo]Z00?o0?ldoookJ_l0odh01_oonfX00ol0R?oooo]Zo`2Yo`03oookJP04
o`04oooonf[ooo]Zo`3Do`kooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP08oook
JP03oomG0?oonf[ooo]Z00Wooo]Z00?oL03oon/0oooonfX00_oonfX00ooo_P3ooo]ZoookJP0?oook
JP03oon@0?oonf[ooo]Z00Cooo]Z00?oi_l0oookJ_lH0?l01ooonfX00omX0?oooo]ZoookJP0Toook
JP00:_oonfX00ooo01?ooo]ZoookJP02oookJP03ool0Tooonf[ooo]Z00Kooo]Z0_oobP05oookJP03
oa80oooonf[o0?lK01Gooo]Z00Co0?oOogSo0?oonf[o0=co1?oonfX00oloo`3ooo]ZoookJP08oook
JP03o`0Zoooonf[ooo]Z00Cooo]Z1?ooDP000ol0oc?o^Ol0okWo001:oookJP;o^Ol000Co0?lcoomB
0?ooDP3ooe801OoonfX3o`0Zo`Cooo]Z2Ooo:002o`3og`03oolX0?oonf[ooo]Z00[ooo]Z00?o08ko
o`3o6ol0oa/00_oonfX00ooobP3ooo]ZoookJP05oookJP04ool0Tooonf[oo`0Cool04`;o000000?o
oo]ZoolX0?oo:0000ooo:0000ooQo`3ooo]ZoookJP03oookJP03obH0oon40?oo8?l001Cooo]Z00?o
<Ol0o`3oFooonfX00_oonfX02On2o`3ooo]ZoookJ_l0<?oooo]ZoolX0?l0j?oooo]Zo`H0o`03oook
JP06oi;o0?oonf[ooo]ZoookJ_l06Ooo403o1?oonfX01olE0?ooo`1AoookJ_oonf[o0:gooookJ_oo
07T02OoonfX01_l0oe?ooo]ZoookJ_l0oago0?l8o`3Qo`gooo]Z00Co0?ldoookJ_l0odko0?l^1Ooo
nfX00ol0R?oooo]Zo`2Yo`03oookJP04o`04oooonf[ooo]Zo`3Do`kooo]Z00?ooh40oookJ_oonfX0
2ooonfX00ooo02gooo]ZoookJP08oookJP03oomG0?oonf[ooo]Z00Wooo]Z00?oj`3ooookJ_oonfX0
0_oonfX00ooo_P3ooo]ZoookJP0?oookJP03oon@0?oonf[ooo]Z00Cooo]Z00?oi_l0odCo0?oonfX0
1ooonfX00omX0?oooo]ZoookJP1;oookJP03ool04ooonf[ooo]Z00;ooo]Z00?oo`2CoookJ_oonfX0
1ooonfX2ooo:00Cooo]Z00?o4P3ooookJ_l0oa/05_oonfX01?mho`3ooo]ZoookJ_l0g?l4oookJP03
ocoo0?oonf[ooo]Z00Oooo]Z00?o02[ooookJ_oonfX01?oonfX4oomB0004o`3o<onio`3o^Ol0okWo
04[ooo]Z00?o^Ol0o`3o<ol0oc<00_ooDP06oookJP;o02[o1_oonfX2ocoo00;o0=co00?ooo]ZogSo
0?mho`000_l0oml=oookJP03o`2>ool0oa_o0?lK00;ooo]Z00?oolX0oookJ_oonfX01OoonfX00ooo
09?ooo]Zo`000002ool04`03o`000?oonf[ooo]Z00?ooo]Z00?of_l0on7o0?oonfX01?oonfX00olV
0?ooQ03oob3o000DoookJP03oc7o0?l0oe_ooo]Z00?ooo]Z00?oP_l0oookJ_l0<?l00_oonfX01?l0
odgo0>SooookJ_l60?l2oookJP03ool0mOnBo`3ooo]Z00;ooo]Z00?o403oo`1MoooonfX00_oonfX0
1olE0?oooo]Zool0DOoonf[o0:gooookJ_oo07T02OoonfX01ol0oe?ooo]ZoookJ_l0oago0?l8oook
J_l0hOl03?oonfX01?l0ocCooo]Zo`3oC_l0obh5oookJP03o`28oooonf[o0:Wo00?ooo]Z00Co00Co
oookJ_oonf[o0=Co3ooonfX00oooP@3ooo]ZoookJP0:oookJP03ool0;Ooonf[ooo]Z00Wooo]Z00?o
oeL0oookJ_oonfX02OoonfX01Oo[0?oooo]ZoookJ_oonf[ookh0017ooo]Z00?ooi00oookJ_oonfX0
1?oonfX00ooVo`3ooo]ZoaP0o`08oookJP03ofP0oooonf[ooo]Z02Cooo]Z000[oookJP03ool04ooo
nf[ooo]Z00;ooo]Z00?oo`2Co`3ioooonfX01ooonfX00ooobP3ooo]ZoookJP03oookJP04oa80oooo
nf[o0?lKo`2>oaGooo]Z00?oN?l0ocd0ool0g?l01?oonfX2ocoo00Wooo]Z0_l0:_l8oookJPCooe80
1?nio`13oookJP03okWo0?l0oc?ooe8000;ooe801_oonfX2o`0Zo`Kooo]Z2?oo:002o`3og`gooo]Z
00?o08koo`3o6ol0oa/00_oonfX2ooo:00Kooo]Z0_oo09<00ooonf[oo`0Co`000003o`000003oook
J_oo:03oobP000CoobP01?oonfX00olV0?oooo]Zob3o000DoookJP03oc7o0?l0oe_ooo]Z00;ooo]Z
00WoP_l0oookJ_oonf[o033ooookJ_oo:03o0>SooookJ_l60?l00ooonfX01_nBo`3ooo]ZoookJ_oo
nf[o01Wooa00o`Cooo]Z00Oo5@3oool0DOoonf[ooo]Zo`2]oooonf[oo`1i00[ooo]Z00Ko0?mCoook
J_l0oago0?l8oookJ_l0hOl<oookJP04o`3o=?oonf[ooo]Zo`3oCPGooo]Z00Co08SooookJ_oonf[o
0:Wo0_oonfX01?l01?oooo]ZoookJ_l0e?l>oookJP03oon10?oonf[ooo]Z00cooo]Z00?oo`0]oook
J_oonfX02?oonfX00oooE`3ooo]ZoookJP08oookJP03og00ooo[0?oooo]Z00?ooo]Z00?ookh0oook
J_oonfX03ooonfX00oooT03ooo]ZoookJP03oookJP03onKo0?l0M?ooA?l000Sooo]Z00?oJ03ooook
J_oonfX0C?oonfX00ooo01?ooo]ZoookJP02oookJP03ool0Tol0nOoooo]Z00Sooo]Z00?oolX0oook
J_oonfX00_oonfX01?lB0?oooo]Zo`3o6ol0oa/EoookJP04ogSo0?l0omoooo]Zo`3Lo`Cooo]Z0_lo
o`08oookJP;o02[o2?oonfX4oomB00Go^Ol0@ooonfX2o`3o<`?ooe801OoonfX3o`0Zo`Kooo]Z0_lo
o`02o`3Lo`03oookJ_mho`3oN?l000;o0?oO3OoonfX00ol0S_oo0?lKo`3o6`02oookJP;oolX01_oo
nfX2ool0T`;ooo]Z00Coo`0Co`000?l0003o00001?oonfX00ooJo`3ohOl0oookJP04oookJP03obH0
oooonf[o8?l001Cooo]Z00?o<Ol0o`3oFooonfX00ooonfX00on2o`3ooo]Zo`0`o`02oookJP04o`3o
COl0j?oooo]Zo`H0o`;ooo]Z00?oo`3eoi;o0?oonfX00_oonfX00ol@0?oo05gooookJP02oookJP03
oaD0oooonf[oo`1A00;ooo]Z00?o0:goool0NOoonfX02OoonfX01_l0oe?ooo]ZoookJ_l0oagooo]Z
o`3Qo`cooo]Z00Co0?ldoookJ_oonf[o0?m>1_oonfX00ol0R?oooo]Zo`2Yo`03oookJP04o`04oooo
nf[ooo]Zo`3Do`kooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP09oookJP03oomG
0?oonf[ooo]Z00Sooo]Z00?oj`3ooookJ_oonfX00_oonfX00ooo_P3ooo]ZoookJP0?oookJP03oon@
0?oonf[ooo]Z00Cooo]Z00?oi_l0oookJ_lH0?l01ooonfX00omX0?oooo]ZoookJP0UoookJP00;?oo
nfX00ooo01?ooo]ZoookJP02oookJP03ool0Tol0nOoooo]Z00Oooo]Z0_oobP04oookJP04oa80oooo
nf[o0?lKo`3o6aGooo]Z00CoN?l0o`3ogolm0?oo0=co1?oonfX3ocoo00Sooo]Z0_l0:_l:oookJPCo
oe801Onio`0koookJP?o0?lc0_ooDP06oookJP?o02[o1ooonfX9oolX00gooo]Z00Go08koo`3o6ol0
oa_o4P3ooookJP02ooo:00Oooo]Z00Goo`2CoookJ_oo01?oo`0CoookJP04o`0000SoobP00_oonfX0
0olV0?oooo]Zob3o000CoookJP;oobP000Go0?mKoookJ_oonf[ooo]Zoh;o0002oookJP03o`0`oooo
nf[oobP000;oobP000Gooo]Zo`H0oooonf[ooo]Zoi;o0003oookJP03o`0Iool@0?oooo]Z00Cooo]Z
00Koo`1AoookJ_oonf[o0:gooookJ_oo07T9oookJP07oomi0?l0oe?ooo]Zo`3o7Ol0o`Sooo]Zo`3Q
o`0<oookJP04o`3o=?oonf[ooo]Zo`3oCPKooo]Z00?o08SooookJ_l0ZOl00ooonfX00ol01?oooo]Z
o`3Do`0?oookJP03oon10?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX02?oonfX00oooE`3ooo]Z
oookJP08oookJP03og00ooo[0?oooo]Z00?ooo]Z00?ookh0oookJ_oonfX03ooonfX00oooT03ooo]Z
oookJP04oookJP03onKo0?m4o`3ooo]Z00Oooo]Z00?oJ03ooookJ_oonfX0C_oonfX00ooo01?ooo]Z
oookJP02oookJP03ool0Tol0nOoooo]Z00Sooo]Z0_oobP03oookJP04oa80oooonf[ooo]Zo`3o6aGo
oo]Z00?oN?l0o`3ogolm0?l00_l0g?l4oookJP?o?ol01ooonfX2o`0Zo`[ooo]Z1?ooDP000ooonf[o
^Ol0okWo0003okWo03_ooo]Z0_l0oc<3oomB00Kooo]Z0_l0:_l8oookJP04ocoo0?l0g?oo0=cooook
JP;oN?l000?o?@3oo`3ogooonfX03OoonfX2o`3o6`04oa80oooonf[oolX0ooo:00Oooo]Z00?oo`2C
oookJ_oonfX00_oo01<4o`0000?ooo]Z00?of_l0on7o0?oonfX01?oonfX00olV0?oooo]Zob3o000C
oookJP;o<Ol000?o0?mKoookJ_oonfX00_oonfX00on2o`3ooo]Zo`0`o`02oookJP08o`3oCOl0j?oo
oo]ZoookJ_l60?oooo]Zool0mOnBo`03oookJP03oa00ool0GOoooo]Z00?ooo]Z00Oo5@3oool0DOoo
nf[ooo]Zo`2]oooonf[oo`1i00Wooo]Z00Ko0?mCoookJ_oonf[o0?lMoookJ_l0hOl=oookJP03o`3o
=?oonf[o0?m>00Kooo]Z00?o08SooookJ_l0ZOl00ooonfX01?l01?oooo]ZoookJ_l0e?l>oookJP03
oon10?oonf[ooo]Z00_ooo]Z00?oo`0]oookJ_oonfX02OoonfX00oooE`3ooo]ZoookJP08oookJP03
og00ooo[0?oooo]Z00;ooo]Z00?ookh0oookJ_oonfX03ooonfX00oooT03ooo]ZoookJP04oookJP03
onKo0?oonf[o603o00Sooo]Z00?oJ03ooookJ_oonfX09OoonfX002gooo]Z00?oo`0CoookJ_oonfX0
0_oonfX00ooo09?o0?WooookJP08oookJP03ooo:0?oonf[ooo]Z00;ooo]Z00Go4P3ooookJ_oonf[o
0?lKo`2>o`0DoookJP;oN?l00_lm0?l2o`3Lo`Cooo]Z0oloo`07oookJP03o`0Zoooonf[ooo]Z00_o
oo]Z1?ooDP000ooonf[o^Ol0okWo0003okWo037ooo]Z0_nio`03o`3o<`?ooe801_oonfX2o`0Zo`Wo
oo]Z2_oo:00<oookJP03o`2>ool0oa_o4P3o00;ooo]Z00?oolX0oookJ_oonfX01OoonfX2ool0T`03
oookJ_oo01?ooo]Z00;ooo]Z0ol00009oolX00;o9P3o0_lPo`0CoookJP03oolX0?oonf[o0?mK00?o
oo]Z00KoP_l0o`3o/?oonf[o033ooookJ_oo:003oookJP04o`H0oooonf[ooo]Zoi;o00Cooo]Z00?o
403ooookJ_oonfX00ooonfX01_oo057ooo]ZoookJ_l0[Ooooo]Zool0N@[ooo]Z00KoogT0oookJ_oo
nf[o0?lMoookJ_l0hOl=oookJP03o`3o=?oonf[o0?m>00Kooo]Z00?o08SooookJ_l0ZOl00ooonfX0
1?l01?oooo]ZoookJ_l0e?l>oookJP03oon10?oonf[ooo]Z00cooo]Z00?oo`0]oookJ_oonfX02?oo
nfX00oooE`3ooo]ZoookJP08oookJP03on/0oooob@3ooo]Z00;ooo]Z00?ookh0oookJ_oonfX04?oo
nfX00oooT03ooo]ZoookJP04oookJP03onKo0?m4o`3ooo]Z00Oooo]Z00?oJ03ooookJ_oonfX0Cooo
nfX00ooo01?ooo]ZoookJP02oookJP03ool0Tol0nOoooo]Z00Wooo]Z00GoolX0oookJ_oonf[ooo]Z
oa80o`02oookJP03o`3o6ol0S_oooo]Z01?ooo]Z0_mho`000ol0omoo?@3oo`3Lo`02o`3Lo`Cooo]Z
0oloo`06oookJP03o`0Zoooonf[ooo]Z00_ooo]Z1?ooDP02oookJPGo^Ol0<?oonfX2okWo00?o0?lc
0oooDP06oookJP?o02[o2?oonfX00oloo`3o0=coo`3Lo`02oookJP04ogSo0?lm0?oo0?oOo`3og`go
oo]Z00?o08koo`3o6olB0?l00_oonfX00ooobP3ooo]ZoookJP05oookJP;oo`2C00?ooo]Zool04ooo
01<00_oonfX4o`0000;ooo]Z00?of_l0oookJ_oonfX00ooonfX2obH0o`;o8?l04ooonfX00olao`3o
oo]Zo`3oF`04oookJP03oh;o0?oonf[o033o00;ooo]Z00So0?m=oookJ_oonf[ooo]Zo`H0oooonf[o
o`3eoi;o00?ooo]Z00?o403oo`1MoooonfX00ooonfX01olE0?ooo`1AoookJ_oonf[o0:gooookJ_oo
07T02OoonfX01?l0oe?ooo]ZoookJ_l0oad2oookJP03o`3Qoooonf[ooo]Z00[ooo]Z00?o0?ldoook
J_l0odh01_oonfX00ol0R?oooo]Zo`2Yo`03oookJP04o`04oooonf[ooo]Zo`3Do`oooo]Z00?ooh40
oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP09oookJP03oomG0?oonf[ooo]Z00Sooo]Z00Goj`3o
oookJ_oonf[ooo]Zoonn000BoookJP03oon@0?oonf[ooo]Z00Cooo]Z00?oi_l0oookJ_lH0?l01ooo
nfX00omX0?oooo]ZoookJP0VoookJP00;OoonfX00ooo01?ooo]ZoookJP03oookJP03ool0Tol0nOoo
oo]Z00Sooo]Z0_oobP03oookJP05oa80oooonf[ooo]Zo`3o6ol0S_l05OoonfX3ogSo0004oookJ_l0
g?oo0=coo`3Lo`Cooo]Z0oloo`05oookJP?o02[o3OoonfX01?l0oc?ooe80oomB0?ooDP03oookJPGo
^Ol08ooonfX8okWo00?o0?lc0oooDP06oookJP?o02[o2?oonfX2ocoo00_oobP02_oonfX01Ol0S_oo
0?lKo`3o6olB0?oooo]Z00;oolX01ooonfX01?oo09?o0?Woool04ooo01<4oookJP;o00002Ooo:000
0olV0?ooQ03oob3o000DoookJP03oolX0?oonf[o0?mK00Cooo]Z00GoP_l0oookJ_l0<?oooo]ZoolX
0003oookJP04o`H0oooonf[ooo]Zoi;o00Cooo]Z00?o403ooookJ_oonfX00ooonfX01_lE0?ooo`1A
oookJ_oonf[o0:goool0N@_ooo]Z00GoogT0oookJ_l0oagooo]Zo`3Qo`0=oookJP04o`3o=?oonf[o
0?m>o`3o;PGooo]Z00Co08SooookJ_oonf[o0:Wo0_oonfX01?l01?oooo]ZoookJ_l0e?l>oookJP03
oon10?oonf[ooo]Z00cooo]Z00?oo`0]oookJ_oonfX02?oonfX00oooE`3ooo]ZoookJP08oookJP03
og00ooo[0?oooo]Z00?ooo]Z00?ookh0oookJ_oonfX03ooonfX00oooT03ooo]ZoookJP04oookJP03
onKo0?m4o`3ooo]Z00Oooo]Z00?oJ03ooookJ_oonfX0DOoonfX00ooo01?ooo]ZoookJP02oookJP03
ool0Tol0nOoooo]Z00Wooo]Z0_oobP02oookJP03oa80oooonf[ooo]Z00;o0?lK5OoonfX3ogSo0003
ocd0oooonf[o0=co00;o0=co1?oonfX2ocoo00Gooo]Z0ol0:_l=oookJP04o`3o<oooDP3ooe80oomB
00Cooo]Z1Onio`0RoookJPSo^Ol00ol0oc<3oomB00Kooo]Z0ol0:_l8oookJP;o?ol00_l0g?l2oook
JP;oN?l00_l0oml>oookJP;o0?lK00Co4P3ooookJ_oobP3oolX01ooonfX01?oo09?o0?WooookJ_oo
01<4oookJPCo00000_oJo`05oookJP03obH0oon40?oo8?l001Cooo]Z00?o<Ol0oookJ_l0oe/01Ooo
nfX01On2o`3o033ooookJ_oonf[o0?m=00?ooo]Z00Co1P3ooookJ_oo0?GoT_l00ooonfX00ol@0?oo
05gooookJP03oookJP03oaD0oooonf[oo`1A00;ooo]Z00?o0:goool0NOoonfX02OoonfX01_l0oe?o
oo]ZoookJ_l0oagooo]Zo`3Qo`cooo]Z00Co0?ldoookJ_l0odko0?l^1_oonfX00ol0R?oooo]Zo`2Y
o`03oookJP03o`04oooonf[o0=Co00oooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02gooo]Zoook
JP09oookJP03oomG0?oonf[ooo]Z00Sooo]Z00?oL03oon/0oooonfX00_oonfX00ooo_P3ooo]Zoook
JP0?oookJP03oon@0?oonf[ooo]Z00Cooo]Z00?oi_l0oookJ_lH0?l02?oonfX00omX0?oooo]Zoook
JP0VoookJP00;_oonfX00ooo01?ooo]ZoookJP03oookJP03ool0Tol0nOoo0?Wo00Wooo]Z00GoolX0
oookJ_oonf[ooo]Zoa80o`02oookJP;o0?lK00?o08kooookJ_oonfX04ooonfX00ol0omooN?l0ogSo
0002oookJP?o0=co1?oonfX2ocoo00Kooo]Z1Ol0:_l;oookJP03o`3o<oooDP3ooe8000;ooe801?oo
nfX5okWo01Gooo]Z2Onio`05oookJP?o0?lc0oooDP06oookJP?o02[o1ooonfX4ocoo0003o`3Loooo
:03oobP000_oobP01ooonfX01Ol0S_oo0?lKo`3o6olB0?oooo]Z00;oolX01ooonfX2ool0T`03o`3i
oooo01?ooo]Z00Gooo]Z0_l00007oolX00;o9P3o0_lPo`0DoookJP03oolX0?oonf[o0?mK00Cooo]Z
00GoP_l0oookJ_l0<?oooo]ZoolX0003oookJP04o`H0oooonf[ooo]Zoi;o00Cooo]Z00?o403ooook
J_oonfX00ooonfX01olE0?ooo`1AoookJ_oonf[o0:gooookJ_oo07T02_oonfX00oooN@3ooo]Zo`3o
7@02oookJP03o`3Qoooonf[ooo]Z00[ooo]Z00Co0?ldoookJ_oonf[o0?m>1_oonfX00ol0R?oooo]Z
o`2Yo`03oookJP03o`04oooonf[o0=Co00oooo]Z00?ooh40oookJ_oonfX03?oonfX00ooo02gooo]Z
oookJP08oookJP03oomG0?oonf[ooo]Z00Sooo]Z00?oj`3oooo90?oonfX00_oonfX00ooo_P3ooo]Z
oookJP0@oookJP03oon@0?oonf[ooo]Z00Cooo]Z00?oi_l0odCo0?oonfX01ooonfX00omX0?oooo]Z
oookJP1BoookJP03ool04ooonf[ooo]Z00;ooo]Z00?oo`2Co`3iool0nOl02_oonfX01?oobP3ooo]Z
oookJ_lB0?l3oookJP03o`3o6ol0S_oooo]Z01Cooo]Z00Co0?oOogSo0?mho`3o?@3o0_oonfX3o`3L
o`?ooo]Z0oloo`05oookJPGo02[o2ooonfX00ol0oc?ooe80oomB0002oomB00Gooo]Z1Onio`0Doook
JPWo^Ol01OoonfX3o`3o<`?ooe801ooonfX2o`0Zo`Oooo]Z1?loo`02o`3Lo`04oookJ_lm0?ooN?l0
ogSo00;o0?oO3_oonfX2o`3o6`;o4P3o0_oobP07oookJP;oo`2C00?o0?Woool04ooo01<01OoonfX3
o`000003om[o0?oonf[ooo]Z00Cooo]Z00?o9P3oob3o0?lPo`005?oonfX00olao`3ooo]Zo`3oF`05
oookJP05oh;o0?l0<?oooo]ZoookJ_l0odd00ooonfX01?l60?oooo]Zool0mOnBo`03oookJP03oa00
ool0GOoooo]Z00?ooo]Z00?o5@3ooookJ_oo05400_oonfX00ol0[Oooo`1ioookJP09oookJP06o`3o
Dooonf[ooo]Zo`3o7Ooonf[o0>7o3OoonfX00ol0ocCooo]Zo`3oCP06oookJP03o`28oooonf[o0:Wo
00?ooo]Z00Co00CooookJ_oonf[o0=Co3_oonfX00oooP@3ooo]ZoookJP0<oookJP03ool0;Ooonf[o
oo]Z00Wooo]Z00?ooeL0oookJ_oonfX02?oonfX01Oo[0?oooo]ZoookJ_oonf[ookh001;ooo]Z00?o
oi00oookJ_oonfX01?oonfX00ooVo`3ooo]ZoaP0o`07oookJP03ofP0oooonf[ooo]Z02Oooo]Z000_
oookJP03ool04ooonf[ooo]Z00;ooo]Z00Coo`2CoookJ_oonf[o0?Wo2OoonfX01OoobP3ooo]Zoook
J_oonf[o4P3o00?ooo]Z00?o0?lKo`2>oooonfX05?oonfX00ol0omoooo]ZogSo0002ogSo00;ooo]Z
0_l0g?l4oookJP?o?ol02?oonfX4o`0Zo`[ooo]Z0_l0oc<4oomB00Gooo]Z1Onio`07oookJPWo^Ol0
0ooonfX4o`3o<`[ooe801ooonfX2o`0Zo`Kooo]Z1?loo`001?oonf[o0=coo`3Lool0g?l;oolX00Wo
oo]Z0_l0oa/01?oonf[o4P3ooookJ_oobP08oookJP04ool0Tol0nOooo`0Cool04`Oooo]Z00?o0000
oolX0?oo:0001?oo:0001?oonf[o9P3ooh@0oolPo`0EoookJP03oolX0?oonf[o0?mK00Cooo]Z00Go
P_l0oookJ_l0<?oooo]ZoolX0003oookJP04o`H0oooonf[ooo]Zoi;o00Cooo]Z00?o403ooookJ_oo
nfX00ooonfX01olE0?ooo`1AoookJ_oonf[o0:gooookJ_oo07T02_oonfX01_ooN@3ooo]Zo`3o7Ol0
o`Sooo]Zo`3Qo`cooo]Z00Co0?ldoookJ_oonf[o0?m>1_oonfX01?l0R?oooo]ZoookJ_l0ZOl2oook
JP03o`04oooonf[o0=Co00oooo]Z00?ooh40oookJ_oonfX03?oonfX00ooo02gooo]ZoookJP08oook
JP;oiOl02OoonfX00om`0?ooj`3ooookJP03oookJP03oonn0?oonf[ooo]Z00oooo]Z00?ooi00oook
J_oonfX01?oonfX00ooVo`3oA?l0oookJP07oookJP03ofP0oooonf[ooo]Z05Cooo]Z00Goo`0Coook
J_oonf[ooo]Zool0T`02oookJP03o`3ioooonf[ooo]Z00Sooo]Z00CoolX0oookJ_oonf[o4P3o0ooo
nfX2o`3o6aKooo]Z00Co0?oOogSo0?mho`3oN?l00ooonfX2o`3Lo`Cooo]Z0oloo`07oookJPCo02[o
2_oonfX2o`3o<`Cooe801_oonfX5okWo00Kooo]Z2Onio`03oookJPCo0?lc2_ooDP07oookJP?o02[o
1OoonfX4ocoo0006oookJ_l0g?oo0=coo`3Loooonf[o?@3o0_mho`000ol0omoooo]ZoookJP0=oook
JP;o0?lK00Cooo]Zoa80oooonf[oolX02?oonfX01?oo09?o0?Woo`3ioooo01<7oookJP;o000000?o
f_l0o`000?oonfX00ooonfX2obH0o`03ob3o0?oonf[ooo]Z01?ooo]Z00?o<Ol0oookJ_l0oe/01Ooo
nfX01On2o`3o033ooookJ_oonf[o0?m=00?ooo]Z00Co1P3ooookJ_oo0?GoT_l00ooonfX00ol@0?oo
05gooookJP03oookJP03oaD0oooonf[oo`1A00;ooo]Z00?o0:goool0NOoonfX02OoonfX01_l0oe?o
oo]ZoookJ_l0oagooo]Zo`3Qo`gooo]Z00?o0?ldoookJ_l0odh01_oonfX01?l0R?oooo]ZoookJ_l0
ZOl2oookJP04o`04oooonf[ooo]Zo`3Do`oooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02gooo]Z
oookJP09oookJP03oomG0?oonf[ooo]Z00Sooo]Z00?oj`3oo`3o1OoonfX00_oonfX00ooo_P3ooo]Z
oookJP0?oookJP03oon@0?oonf[ooo]Z00Cooo]Z00?o07CoonKo0?lH0?l02?oonfX00omX0?oooo]Z
oookJP0WoookJP00<?oonfX2oomi00?ooo]Z00Coo`2CoookJ_oonf[o0?Wo2OoonfX2ooo:00;ooo]Z
0_lB0?l2oookJP03o`3o6ol0S_oo08ko01Cooo]Z0_l0oml00ooonf[o?@3oogSo0002ogSo0004oook
J_l0g?oo0=coo`3Lo`Cooo]Z0oloo`09oookJPGo02[o2?oonfX3o`3o<`Cooe801_oonfX4o`3o<a?o
oe803_oonfX3o`0Zo`Gooo]Z0oloo`000ooonf[o0=coo`3Lo`02o`3Lo`03oookJ_lm0?ooobP000Ko
obP03?oonfX2o`3o6`03oookJ_oob@3oolT000;oolX01ooonfX2ool0T`;oo`0C2OoonfX5oolX00;o
oo]Z00?o9P3ooh@0oolPo`005?oonfX2oolX0003oookJ_l0oe_ooo]Z00?ooo]Z00GoP_l0oookJ_l0
<?oooo]ZoolX0003oookJP04o`H0oooonf[ooo]Zoi;o00Cooo]Z00?o403ooookJ_oonfX01?oonfX0
1_oo057ooo]ZoookJ_l0[Ooooo]Zool0N@[ooo]Z00KoogT0oookJ_oonf[o0?lMoookJ_l0hOl=oook
JP03o`3o=?oonf[o0?m>00Kooo]Z00Co08SooookJ_oonf[o0:Wo0_oonfX01?l01?oooo]ZoookJ_l0
e?l>oookJP03oon10?oonf[ooo]Z00cooo]Z00?oo`0]oookJ_oonfX02OoonfX00ooUo`3ooo]Zoook
JP07oookJP03og00ooo[0?ooolT000?ooo]Z00?ookh0oookJ_oonfX04?oonfX00oooT03ooo]Zoook
JP04oookJP03onKo0?m4o`3ooo]Z00Oooo]Z00?oJ03ooookJ_oonfX0EOoonfX2ool04`;ooo]Z00Co
o`2CoookJ_oonf[o0?Wo2_oonfX2ooo:0003oookJ_lB0?oo4P3o00?ooo]Z00?o0?lKo`2>oooonfX0
5?oonfX2o`3og`04oookJ_mho`3oN?l0ogSo00;ooo]Z0ol0g?l4oookJP?o?ol02?oonfX5o`0Zo`So
oo]Z0ol0oc<4oomB00Kooo]Z1?l0oc<CoomB00kooo]Z0ol0:_l5oookJP?o?ol000?ooo]Zo`3Lool0
g?l00_l0g?l00ooonf[o?@3oo`3og`02ogSo013ooo]Z0_l0oa/00ooonf[o4P3ooa80o`02ooo:00Oo
oo]Z0_oo09<00ol0nOooo`0Cool04`08oookJP04on7o0?oJo`3o0000o`0000?ooo]Z00?o9P3ooh@0
oolPo`005?oonfX2oc7o0003oookJ_l0oe_ooo]Z00Cooo]Z00GoP_l0o`0`oooonf[ooo]Zo`3oC@03
oookJP04o`H0oooonf[ooo]Zoi;o00?ooo]Z00?o403oo`0IoooonfX01?oonfX01olE0?ooo`1Aoook
J_oonf[o0:gooookJ_oo07T02OoonfX01?l0oe?ooo]ZoookJ_l0oad2oookJP03o`3Qoooonf[ooo]Z
00[ooo]Z00?o0?ldoookJ_l0odh01ooonfX00ol0R?oooo]Zo`2Yo`03oookJP03o`04oooonf[o0=Co
00oooo]Z00?ooh40oookJ_oonfX02ooonfX00ooo02gooo]ZoookJP0:oookJP03oomG0?oonf[ooo]Z
00Oooo]Z00?oL03oon/0oooonfX00_oonfX00ooo_P3ooo]ZoookJP0@oookJP03oon@0?oonf[ooo]Z
00Cooo]Z00?oi_l0oookJ_lH0?l01ooonfX00omX0?oooo]ZoookJP0XoookJP00<?oonfX5oomi0005
oookJ_oo09?ooo]ZoookJ_l0nOl02_oonfX01?oobP3ooo]ZoookJ_oonfX2oa80o`03oookJ_l0oa_o
0?lK00;o08ko5?oonfX00ol0omoooo]ZoookJP02ocd0o`;oN?l00_oonfX3o`3Lo`Cooo]Z0oloo`0;
oookJPCo02[o1ooonfX4o`3o<`[ooe806ooonfX6o`0Zo`Cooo]Z1?loo`04o`3Lo`?ooo]Z0_mho`03
oolX00oooo]Z00?o08koo`3o6ooonfX00_oob@02ooo:00Sooo]Z00?oo`2Co`3ioooo01<02_oonfX0
1_oQo`3oobP0oolX0?oo:03o0000oookJP;o9P3o0_lPo`0DoookJP04oolX0?oonf[ooo]Zo`3oF`Co
oo]Z00GoP_l0oookJ_l0<?oooo]ZoolX0003oookJP04o`H0oooonf[ooo]Zoi;o00Cooo]Z00?o403o
oolX0?oonfX01?oonfX01_oo057ooo]ZoookJ_oonf[o0:goool0N@[ooo]Z00KoogT0oookJ_oonf[o
0?lMoookJ_l0hOl=oookJP03o`3o=?oonf[o0?m>00Kooo]Z00Co08SooookJ_oonf[o0:Wo0ooonfX0
0ol01?oooo]Zo`3Do`0?oookJP03oon10?oonf[ooo]Z00cooo]Z00?oo`0]oookJ_oonfX02?oonfX0
0ooUo`3ooo]ZoookJP08oookJP03og00ooo[0?oooo]Z00?ooo]Z00?ookh0oookJ_oonfX03ooonfX0
0oooT03ooo]ZoookJP04oookJP03o`1doom4o`3ooo]Z00Oooo]Z00?oJ03ooookJ_oonfX0F?oonfX0
1?oo01?ooo]ZoookJ_oo09<2oookJP03o`3ioooonf[ooo]Z00Wooo]Z00?oolX0oookJ_oonfX00_lB
0?l2oookJP03o`3o6ol0S_oo08ko01Gooo]Z00Co0?oOoookJ_oonf[o?@3o0_mho`03oookJP?o0=co
1?oonfX2ocoo00_ooo]Z1?l0:_l7oookJPCo0?lc2_ooDP0KoookJPKo02[o1?oonfX4ocoo00Co0=co
0ooonfX01?l0omooN?l0ogSo0?mho`0AoookJP04o`3o6ol0S_oo4P3ooa80o`;oolX02?oonfX01?oo
09?o0?WooookJ_oo01<9oookJP03on7o0?oJo`3o000000;o000000?ooo]ZobH0oolV0?l00_lPo`0D
oookJP04oc7o0?oonf[ooo]Zo`3oF`Gooo]Z00GoP_l0o`0`oooonf[ooo]Zo`3oC@03oookJP04o`H0
oooonf[ooo]Zoi;o00?ooo]Z00?o403oo`0IoooonfX01?oonfX00olE0?ooo`1AoookJP02oookJP03
o`2]oooo07Wooo]Z00Sooo]Z00Oo0?mCoookJ_oonf[o0?l8o`3o7Ooonf[o0>7o00gooo]Z00?o0?ld
o`3oC_oonfX01_oonfX00ol0R?oooo]Zo`2Yo`03oookJP04o`04oooonf[ooo]Zo`3Do`kooo]Z00?o
oh40oookJ_oonfX03?oonfX00ooo02gooo]ZoookJP09oookJP03oomG0?oonf[ooo]Z00Sooo]Z00?o
j`3oo`3o1OoonfX00_oonfX00ooo_P3ooo]ZoookJP0?oookJP03oon@0?oonf[ooo]Z00Cooo]Z00?o
07CoonKo0?lH0?l02?oonfX00omX0?oooo]ZoookJP0XoookJP00<OoonfX6oomi0004ool0Tooonf[o
oo]Zo`3io`[ooo]Z0_oobP03oookJP;o4P3o00Cooo]Zo`3o6ooonf[o08ko5?oonfX3o`3og`03oook
J_lm0?oo?@3o00?oN?l00_oonfX3o`3Lo`Cooo]Z0oloo`0<oookJPGo02[o8_oonfX9o`0Zo`Kooo]Z
1?loo`04o`3Lo`?ooo]Z1?mho`0CoookJP;o0?lK0_oob@000ooonf[oolX0oookJP07oookJP;oo`2C
0_oo01<9oookJP;ohOl00_oo:003o`000003obH0oon40?oo8?l001Gooo]Z00CoobP0oookJ_l0oe_o
0?mK1?oonfX01?oo:03ooo]Zo`0`oooonfX2oolX00;ooo]Z00Go1P3ooookJ_oonf[oo`3eoi;o0003
oookJP03oa00ool06Ooooo]Z00Cooo]Z00Koo`1AoookJ_oonf[ooo]Zo`2]oooo07T:oookJP04oomi
0?oonf[ooo]Zo`3o7@;ooo]Z00?o0>7ooookJ_oonfX02_oonfX01?l0ocCooo]ZoookJ_l0odh6oook
JP03o`28oooonf[o0:Wo00?ooo]Z00?o00CooookJ_l0e?l03ooonfX00oooP@3ooo]ZoookJP0<oook
JP03ool0;Ooonf[ooo]Z00Sooo]Z00?oiOl0oookJ_oonfX02?oonfX00om`0?ooj`3ooookJP03oook
JP03oonn0?oonf[ooo]Z013ooo]Z00?ooi00oookJ_oonfX01?oonfX00ooVo`3oA?l0oookJP07oook
JP03ofP0oooonf[ooo]Z05Wooo]Z0_oo01<01Ooonf[oo`2CoookJ_oonf[o0?Wo00_ooo]Z0_oobP02
oookJP;o4P3o00Cooo]Zo`3o6ol0oa_o08ko5OoonfX3o`3og`03oookJ_lm0?ooN?l000;oN?l00ooo
nfX3o`3Lo`?ooo]Z0oloo`0<oookJPGo02[o8_oonfX9o`0Zo`Kooo]Z1?loo`001?oonf[o0=coo`3L
ool0g?l4oookJPCoN?l04_oonfX2o`3o6`;o4P3o00?ooo]Zooo:0?oonfX01ooonfX2ool0T`03oook
J_oo01?oo`0C00Sooo]Z0_oQo`000ooJo`3o0000o`000002o`000003obH0oon40?oo8?l001Gooo]Z
00Co<Ol0oookJ_l0oe_o0?mK1OoonfX01_n2o`3o033ooookJ_oonf[o0>Soo`3oC@;ooo]Z00Co1P3o
oookJ_oonf[oT_l00ooonfX00ol@0?oo01WooookJP04oookJP03oaD0oooo057ooo]Z00;ooo]Z00?o
0:goool0NOoonfX02?oonfX01ol0oe?ooo]ZoookJ_oonf[o0?lMoookJ_l0hOl03OoonfX00ol0ocCo
oo]Zo`3oCP06oookJP03o`28oooonf[o0:Wo00?ooo]Z00Co00CooookJ_oonf[o0=Co3_oonfX00ooo
P@3ooo]ZoookJP0<oookJP03ool0;Ooonf[ooo]Z00Wooo]Z00?ooeL0oookJ_oonfX02?oonfX00oo[
0?oo0?l5oookJP02oookJP03oonn0?oonf[ooo]Z013ooo]Z00?ooi00oookJ_oonfX01?oonfX00ooV
o`3ooo]ZoaP0o`07oookJP03ofP0oooonf[ooo]Z02Wooo]Z000boookJPKoogT000?oo`2Coomi0?oo
nfX00_l0nOl:oookJP03ooo:0?oonf[ooo]Z00;ooo]Z0_lB0?l01?l0oa_ooo]Zo`2>ool0S_lEoook
JPCo0?oO00Co?@3ooookJ_mho`3oN?l00ooonfX3o`3Lo`Cooo]Z0_loo`0?oookJPCo02[o5?oonfX:
o`0Zo`_ooo]Z1?loo`04o`3Lo`?ooo]Z1?mho`000ol0omoooo]ZoookJP0BoookJP;o0?lK00?oolT0
oookJ_oonfX00_oobP07oookJP04o`3ioooo09?ooo]Zool04`[ooo]Z00CohOl0om[o0?oo:03ooo]Z
0_l00002obH0o`;o8?l05OoonfX00ooo:03ooo]Zo`3oF`04oookJP05o`3o/?n2o`3oobP0oolX0?oo
nfX00_oo:002oookJP05o`H0oooonf[ooo]Zool0mOnBo`000ooonfX00ol@0?oo01WooookJP04oook
JP07ool0DOoonf[ooo]ZoookJ_l0[Ooooo]Zool0N@09oookJP04oomi0?oonf[ooo]Zo`3o7@;ooo]Z
00?o0>7ooookJ_oonfX02_oonfX01?l0ocCooo]ZoookJ_l0odh6oookJP04o`28oooonf[ooo]Zo`2Y
o`;ooo]Z00Co00CooookJ_oonf[o0=Co3_oonfX00oooP@3ooo]ZoookJP0=oookJP03ool0;Ooonf[o
oo]Z00Sooo]Z00?oiOl0oookJ_oonfX02?oonfX00oo[0?ooolT0oookJP02oookJP03oonn0?oonf[o
oo]Z013ooo]Z00?ooi00oookJ_oonfX01?oonfX00ol0M?ooA?l0oookJP07oookJP03ofP0oooonf[o
oo]Z05cooo]Z00?oo`0CoookJ_oo09<00_oonfX2o`3io`_ooo]Z00CoolX0oookJ_oonf[ooo]Z0_lB
0?l01?oonf[o0?lKo`2>ool0S_lFoookJPCo0?oO00?ooo]ZogSo0?mho`001?oonfX3o`3Lo`?ooo]Z
0oloo`0>oookJPCo02[o5?oonfX:o`0Zo`_ooo]Z1?loo`000ooonf[o0=coo`3Lo`02o`3Lo`?ooo]Z
1?mho`000olm0?oooo]ZoookJP0AoookJP;o0?lK00?o4P3ooookJ_oonfX00_oobP08oookJP04ool0
Tol0nOooo`0Cool04`Wooo]Z00CohOl0om[o0?oJo`3ooo]Z0ol000000olV0?oo8?l0ob3o000Eoook
JP03oc7o0?oonf[o0?mK00Gooo]Z00?o0?n`oh;o0?l0<?l00_oonfX01Ol0j?oo0?m=oookJ_oonf[o
1P3o00;ooo]Z00KoT_l0oookJ_oonf[ooo]Zoa00ool06Ol5oookJP03oaD0oooo057ooo]Z00;ooo]Z
00?o0:goool0NOoonfX02?oonfX01ol0oe?ooo]ZoookJ_oonf[o0?lMoookJ_l0hOl03OoonfX00ol0
ocCooo]Zo`3oCP07oookJP03o`28oooonf[o0:Wo00?ooo]Z00?o00CooookJ_l0e?l03ooonfX00ooo
P@3ooo]ZoookJP0<oookJP03ool0;Ooonf[ooo]Z00Wooo]Z00?ooeL0oookJ_oonfX02?oonfX01Oo[
0?oo0?l5oookJ_oonf[ookh001;ooo]Z00?ooi00oookJ_oonfX01?oonfX00ol0M?ooi_l0oaP0o`08
oookJP03ofP0oooonf[ooo]Z02Wooo]Z000coookJPKoogT000Goo`2Coomi0?ooN@3ooo]Zo`3io`0:
oookJP;oolX01?oonfX01OlB0?oo0?lKo`3o6ooonf[o08ko01Sooo]Z0ol0oml01?oonf[oN?l0ogSo
0?mho`03oookJP;o0=co1?oonfX3ocoo013ooo]Z1Ol0:_l6oookJPWo02[o4OoonfX4ocoo0004oook
J_l0g?oo0=coo`3Lo`?ooo]Z1?mho`02o`3og`03ocd0oooonf[ooo]Z01;ooo]Z0_l0oa/00ooob@3o
oo]ZoookJP02ooo:00Sooo]Z00Co0?Woool0Tooo01?oo`0C2_oonfX2om[o00?ooo]Z00Co0000obH0
oon40?oo8?l05_oonfX00ooo:03ooo]Zo`3oF`04oookJP03o`3o/?n2o`3oobP000CoobP00_oonfX0
1Ol60?oooo]ZoookJ_oo0?GoT_l000?ooo]Z00?o403oo`0IoooonfX01?oonfX01ooo057ooo]Zoook
J_oonf[o0:gooookJ_oo07T02OoonfX01oooN@3ooo]ZoookJ_l0o`So0?lMoookJ_l0hOl03OoonfX0
0ol0ocCooo]Zo`3oCP06oookJP04o`28oooonf[ooo]Zo`2Yo`?ooo]Z00?o00CooookJ_l0e?l03ooo
nfX00oooP@3ooo]ZoookJP0<oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00?oiOl0oookJ_oonfX02?oo
nfX00om`0?ooj`3ooookJP03oookJP03oonn0?oonf[ooo]Z013ooo]Z00?ooi00oookJ_oonfX01?oo
nfX00ooVo`3oA?l0oookJP07oookJP03ofP0oooonf[ooo]Z05gooo]Z00?oo`0CoookJ_oo09<00ooo
nfX00ol0nOoooo]ZoookJP09oookJP;oolX00ooonfX2oa80o`03o`3o6ooonf[o08ko01Wooo]Z0ol0
oml3ogSo00Cooo]Z0_l0g?l4oookJP;o?ol04?oonfX5o`0Zo`Kooo]Z2Ol0:_lAoookJPCo?ol000?o
oo]Zo`3Lool0g?l00_l0g?l3oookJPCoN?l000?o0?oOocd0oooonfX04ooonfX2o`3o6`03oa80oooo
nf[ooo]Z00;oolX02?oonfX01?l0nOooo`2CoookJ_oo01<:oookJP03on7o0?oJo`3ooo]Z00;ooo]Z
00Co0000obH0oolV0?oo8?l05_oonfX00olao`3ooo]Zo`3oF`05oookJP03o`3o/?n2o`3o033o00;o
oo]Z00Go0>Soo`3oCOoonf[ooo]Zo`H0o`02oookJP06oi;o0?oonf[ooo]ZoookJ_l@0?oo01Wo1Ooo
nfX00olE0?ooo`1AoookJP02oookJP03o`2]oooonf[oo`1i00Sooo]Z00Oo0?mCoookJ_oonf[ooo]Z
o`3o2?l0oago0>7o00gooo]Z00?o0?ldoookJ_l0odh01ooonfX00ol0R?oooo]Zo`2Yo`03oookJP03
o`04oooonf[o0=Co00oooo]Z00?ooh40oookJ_oonfX03?oonfX00ooo02gooo]ZoookJP09oookJP03
oomG0?oonf[ooo]Z00Sooo]Z00?oj`3oo`3o1OoonfX00_oonfX00ooo_P3ooo]ZoookJP0@oookJP03
oon@0?oonf[ooo]Z00Cooo]Z00?oi_l0oookJ_lH0?l02?oonfX00omX0?oooo]ZoookJP0YoookJP00
=?oonfX6oomi0003ool0ToooN@3oogT000;oogT02ooonfX00ooobP3ooo]ZoookJP02oookJP;o4P3o
00Co0?lKoookJ_l0S_oo08ko6OoonfX4o`3og`;oN?l00ooonfX3o`3Lo`Cooo]Z0oloo`0BoookJPKo
02[o5ooonfX3ocoo0003oookJ_l0g?oo0=co00;o0=co0_oonfX4ogSo00?o0?oO0_lm0?lDoookJP;o
0?lK00GoolT0oookJ_oonf[ooo]Zooo:0008oookJP04o`3ioooo09?oo`2Cool04`[ooo]Z00?ohOl0
om[o0?oonfX00ooonfX2obH0o`;o8?l000?o0000oookJ_oonfX04ooonfX00ooo:03ooo]Zo`3oF`04
oookJP03o`3o/?n2o`3oobP000GoobP00_oonfX01?l60?oooo]Zool0mOnBo`03oookJP03oa00ool0
6Ooooo]Z00Cooo]Z00Ooo`1AoaD0oooonf[ooo]Zo`2]oooonf[oo`1i00Wooo]Z00OoogT0oookJ_oo
nf[ooo]Zo`3o7Ooonf[o0>7o00gooo]Z00?o0?ldoookJ_l0odh01ooonfX00ol0R?oooo]Zo`2Yo`03
oookJP03o`04oooonf[o0=Co00oooo]Z00?ooh40oookJ_oonfX03?oonfX00ooo02gooo]ZoookJP09
oookJP03onGo0?oonf[ooo]Z00Oooo]Z00?oL03oon/0oooob@000ooonfX00ooo_P3ooo]ZoookJP0@
oookJP03oon@0?oonf[ooo]Z00Cooo]Z00?o07CoodCo0?oonfX02?oonfX00omX0?oooo]ZoookJP1N
oookJP;oo`0C00Goo`2CoookJ_oonf[ooo]Zo`3io`0<oookJP03ooo:0?oonf[ooo]Z00;ooo]Z00?o
4P3oo`3o6ol0oa/00_l0S_lIoookJP04ocd0ool0omoo0?oOo`3og`;oN?l01?oonfX3o`3Lo`?ooo]Z
0oloo`0BoookJPKo02[o5ooonfX3ocoo0003oookJ_l0g?oo0=co00;o0=co0ooonfX4ogSo00;o0?oO
0_lm0?lDoookJP;o0?lK00Go4P3ooookJ_oonf[ooo]Zooo:0008oookJP03o`3ioooo09?oo`2C00;o
o`0C2OoonfX00ooQo`3of_l0om[o0004oookJP04obH0oolPo`3o8?l0o`0001Gooo]Z00?o<Ol0oook
J_l0oe/01OoonfX00ol0ok3oP_l0o`0`o`02oookJP03o`3Xool0odgooo]Z00;ooo]Z00?o1P3ooook
J_nBo`000ooonfX00ol@0?oo01WooookJP05oookJP07ool0DOoonf[ooo]ZoookJ_l0[Ooooo]Zool0
N@08oookJP08o`3oDooonf[ooo]ZoookJ_l0o`So0?lMoookJ_l0hOl=oookJP03o`3o=?l0odkooo]Z
00Kooo]Z00?o08SooookJ_l0ZOl00ooonfX01?l01?oooo]ZoookJ_l0e?l>oookJP03oon10?oonf[o
oo]Z00cooo]Z00?oo`0]oookJ_oonfX02OoonfX00oooE`3ooo]ZoookJP08oookJP03og00ooo[0?oo
0?l500;ooo]Z00?ookh0oookJ_oonfX04?oonfX00oooT03ooo]ZoookJP04oookJP03o`1doooVo`3o
603o00Sooo]Z00?oJ03ooookJ_oonfX0:_oonfX002[ooo]Z00?ohOl0oookJ_oonfX02?oonfX6oomi
0003ool0ToooN@3oogT000;oogT02ooonfX2ooo:00Cooo]Z00Go4P3oo`3o6ooonf[ooo]Zo`2>o`0J
oookJP;o?@3o0_l0oml3ogSo00?ooo]Z0ol0g?l4oookJP?o?ol0:?oonfX4ocoo00Co0=co0ooonfX3
ogSo0004oookJ_l0omoo0?oOo`3og`;o?@3o5OoonfX00ooob@3o0?lKooo90003oookJP;oolX01ooo
nfX2o`3io`03ool0Tooo01?oo`0C00[ooo]Z0_oJo`04oookJP03obH0oooonf[o8?l000?o00004ooo
nfX2oolX0003oookJ_l0oe_ooo]Z00?ooo]Z00?o0?n`oh;o0?oonfX01ooo:0001?l60?oooo]ZoolX
0?nBo`03oookJP03oa00ool06Ooooo]Z00Cooo]Z00Ooo`1AoaD0oooonf[ooo]Zo`2]oooonf[oo`1i
00Wooo]Z00GoogT0oookJ_oonf[ooo]Zo`3o7@02oookJP03o`3Qoooonf[ooo]Z00[ooo]Z00Co0?ld
oookJ_oonf[o0?m>1_oonfX00ol0R?oooo]Zo`2Yo`03oookJP04o`04oooonf[ooo]Zo`3Do`kooo]Z
00?ooh40oookJ_oonfX03OoonfX00ooo02gooo]ZoookJP08oookJP03onGo0?oonf[ooo]Z00Sooo]Z
00?oL03oon/0oooonfX00ooonfX00ooo_P3ooo]ZoookJP0@oookJP03oon@0?oonf[ooo]Z00Cooo]Z
00?oi_l0odCo0?oonfX01ooonfX00omX0?oooo]ZoookJP1AoookJP03on7o0?oonf[ooo]Z00gooo]Z
00?oo`0Cool0TooonfX00_oonfX00ol0nOoooo]ZoookJP0:oookJP;oolX01?oonfX01?lB0?oo0?lK
oookJ_l0S_lJoookJP?o?@3o00Co0?oOogSo0?mho`3oN?l01?oonfX3o`3Lo`?ooo]Z0oloo`0Xoook
JPCo?ol01?l0g?l4oookJP?oN?l00ol0oml3ocd0oaCooo]Z00Co4P3oo`3o6olB0?oo08ko0_oonfX2
ooo:00Oooo]Z0_l0nOl00ooo09?ooo]Zool04`0:oookJP;of_l01?oonfX2obH0o`04ob3o0?l0003o
0000o`0001?ooo]Z0_lao`000ooonf[o0?mKoookJP04oookJP03o`3o/?n2o`3o033o00;ooo]Z00?o
0>Soo`3oCOoonfX00_oonfX00ol60?oooo]Zoi;o0003oookJP03oa00oooo06[o01Wo00Gooo]Z00Oo
o`1AoookJ_oonf[ooo]Zo`2]oooonf[oo`1i00Sooo]Z00So0?mCoookJ_oonf[ooo]Zo`3o2?l0oago
oo]Zo`3Qo`gooo]Z00?o0?ldoookJ_l0odh01ooonfX00ol0R?oo0:WooookJP03oookJP03o`04oooo
nf[o0=Co00oooo]Z00?ooh40oookJ_oonfX03?oonfX00ooo02gooo]ZoookJP09oookJP03oomG0?oo
nf[ooo]Z00Sooo]Z00?oj`3oo`3o1OoonfX00_oonfX00ooo_P3ooo]ZoookJP0@oookJP03oon@0?oo
nf[ooo]Z00Cooo]Z00?o07CoonKo0?lH0?l02?oonfX00omX0?oooo]ZoookJP0ZoookJP00:_oonfX2
om[o00[ooo]Z1_ooN@001Ooo09?oogT0oomi0?ooN@3o0?Wo00cooo]Z00?oolX0oookJ_oonfX00ooo
nfX00ol0oa_o4P3ooookJP02o`2>oacooo]Z0_lm0?l01Ol0omooN?l0ogSo0?mho`3o?@3o00;ooo]Z
0ol0g?l4oookJRSo?ol01?l0g?l3oookJPCoN?l000Cooo]Zo`3ogol0omoo0?oO0olm0?lEoookJP03
ooo90?l0oa_o0?lK00?ooo]Z0_oobP07oookJP;o0?Wo0_oo09<00ooo01?ooo]ZoookJP08oookJP;o
f_l01OoonfX00olV0?oooo]Zob3o0004o`0001;ooo]Z00CoobP0oookJ_oonf[o0?mK1?oonfX00ol0
ok3oP_l0oookJP09oolX0008oookJ_nBo`3oobP0oolX0?oonf[o403ooolX0?l06Ol5oookJP06ool0
DOoonf[ooo]Zo`2]oooonf[oo`1i2OoonfX02?ooN@3ooo]ZoookJ_oonf[o0?l8o`3o7Ooonf[o0>7o
3OoonfX00ol0ocCooo]Zo`3oCP06oookJP04o`28oooonf[ooo]Zo`2Yo`?ooo]Z00?o00CooookJ_l0
e?l03ooonfX00oooP@3ooo]ZoookJP0<oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00?oiOl0oookJ_oo
nfX02?oonfX00om`0?ooj`3oooo90003oookJP03oonn0?oonf[ooo]Z013ooo]Z00?ooi00oookJ_oo
nfX01?oonfX00ol0M?ooA?l0oookJP08oookJP03ofP0oooonf[ooo]Z057ooo]Z0_oJo`0?oookJP03
ool04ooo09?ooo]Z00;ooo]Z00?o0?WooookJ_oonfX02ooonfX00ooobP3ooo]ZoookJP03oookJP04
o`3o6olB0?oo08koo`2>oacooo]Z0olm0?l3ogSo0004ocd0oooonf[ooo]ZoookJP?o0=co0ooonfXX
ocoo0004oookJ_l0g?oo0=coo`3Lo`Cooo]Z1?mho`03o`3og`?o?@3o5OoonfX01?lB0?oo0?lKo`3o
6ol0S_l2oookJP;oolX01ooonfX2o`3io`;oo`2C0_oo01<9oookJP03on7o0?oJo`3ooo]Z00Cooo]Z
00?o9P3ooookJ_lPo`001?l0000BoookJP04oc7o0?oonf[ooo]Zo`3oF`Gooo]Z00?o0?n`oh;o0?l0
<?l00_oonfX00ol0j?oo0?m=oookJP02oookJP03o`H0oooonf[oT_l000?ooo]Z00?o403oool0J_l0
6Ol01OoonfX01olE0?ooo`1AoookJ_oonf[o0:gooookJ_oo07T02?oonfX00ol0oe?ooo]ZoookJP02
oookJP03o`3o7Ooonf[o0>7o00gooo]Z00?o0?ldoookJ_l0odh01ooonfX00ol0R?oooo]Zo`2Yo`03
oookJP03o`04oooonf[o0=Co00oooo]Z00?ooh40oookJ_oonfX03?oonfX00ooo02gooo]ZoookJP09
oookJP03oomG0?oonf[ooo]Z00Sooo]Z00?oj`3ooookJ_l0o`D00_oonfX00ooo_P3ooo]ZoookJP0@
oookJP03oon@0?oonf[ooo]Z00Cooo]Z00?o07CoonKo0?lH0?l02?oonfX00omX0?oooo]ZoookJP0[
oookJP00:ooonfX00ooQo`3of_l0oookJP09oookJPKoogT00_oo09<2oookJP;o0?Wo2ooonfX2ooo:
00Cooo]Z0_l0oa/00olB0?oooo]Zo`2>o`0PoookJP04o`3ogomho`3oN?l0o`3og`Co?@3o4ol0g?l2
oookJP?oogT03ooonfX4o`3Lo`?ooo]Z1?mho`02ocd0o`?o0?oO00?o?@3ooookJ_oonfX03OoonfX2
ooo900Kooo]Z00Co08koooo90?l0oa_o0?lK1?oonfX00ooobP3ooo]ZoookJP05oookJP;o0?Wo00Co
oo]Zool0Tooo01?oo`0C2_oonfX00ooJo`3ooo]ZoookJP03oookJP;o9P3o0_lPo`000ooonf[o0000
o`000002o`00017ooo]Z00CoobP0oookJ_oonf[o0?mK1?oonfX01?l0ok3oP_l0oookJ_l0<?l7oolX
00;ooo]Z00OoT_l0oolX0?oo:03oobP0oa00oooo:03o01Wo00Gooo]Z00Coo`1AoookJ_oonf[o0:go
0_oonfX00ooo07Wooo]ZoookJP07oookJP07oomi0?oonf[ooo]Zo`3o2?l0oagooo]Zo`3Qo`0=oook
JP03o`3o=?oonf[o0?m>00Oooo]Z00?o08SooookJ_l0ZOl00ooonfX00ol01?oooo]Zo`3Do`0?oook
JP03oon10?oonf[ooo]Z00gooo]Z00?oo`0]oookJ_oonfX02?oonfX00ooUo`3ooo]ZoookJP08oook
JP03og00ooo[0?oooo]Z00;ooo]Z00?ookh0oookJ_oonfX04OoonfX00oooT03ooo]ZoookJP04oook
JP03o`1doom4o`3ooo]Z00Oooo]Z00?oJ03ooookJ_oonfX0DooonfX00ooQo`3of_l0oookJP0?oook
JP;oo`2C0_oonfX2o`3io`cooo]Z0_oobP04oookJP;o0?lK00?o4P3oo`2>oooonfX08?oonfX2ogSo
00;o0?oO0olm0?lDo`3LoaCooo]Z1?l0g?l3oookJPCoN?l000Go?@3oo`3ogol0omoo0?oOocd0o`0H
oookJP03oa80ool0oa_o0?lK00Cooo]Z00?oolX0oookJ_oonfX01_oonfX00ol0nOoooo]Zool0T`02
ool04`[ooo]Z0_oJo`05oookJP04obH0oolPo`3o8?l0oookJPCo00004OoonfX01?lao`3ooo]Zoook
J_l0oe/5oookJP03o`3o/?n2o`3o033o00;ooo]Z00?o0>Soo`3oCOoonfX00_oonfX00ol60?oooo]Z
oi;o0003oookJP03oa00oooo06[o01Wo00Gooo]Z00Oo5@3oool0DOoonf[ooo]Zo`2]oooonf[oo`1i
00Wooo]Z00Oo0?mCoookJ_oonf[ooo]Zo`3o2?l0oago0>7o00kooo]Z00?o0?ldo`3oC_oonfX01_oo
nfX00ol0R?oooo]Zo`2Yo`03oookJP04o`04oooonf[ooo]Zo`3Do`kooo]Z00?ooh40oookJ_oonfX0
3OoonfX00ooo02gooo]ZoookJP08oookJP03oomG0?oonf[ooo]Z00Wooo]Z00Goj`3oo`3o1Ooonf[o
oo]Zoonn000CoookJP03oon@0?oonf[ooo]Z00Cooo]Z00?o07CoonKo0?lH0?l02?oonfX00omX0?oo
oo]ZoookJP0[oookJP00;?oonfX00ooQo`3of_l0oookJP09oookJPKoogT000?ooo]Zool0Tooo09<0
0_oonfX00ol0nOoooo]ZoookJP0:oookJP03ooo:0?oonf[ooo]Z00?ooo]Z00?o0?lKoa80oolB0?l0
0_l0S_lQoookJP?oN?l00_l0oml6ocd0o`_ooo]Z1oooN@0?o`3Lo`03oookJ_lm0?oo?@3o00CoN?l0
0_lm0?l01?oonf[o0?oOo`3ogol0omlBoookJP?oolT00ooonfX2o`2>o`03ooo90?l0oa_o0?lK00Co
oo]Z0_oobP06oookJP;o0?Wo00Cooo]Zool0Tooo09?oo`0C2_oonfX2om[o00Gooo]Z00?o9P3ooook
J_lPo`000ooonfX4o`00013ooo]Z00CoobP0oookJ_oonf[o0?mK1?oonfX01?l0ok3oP_l0oookJ_l0
<?l7oolX00;ooo]Z00OoT_l0oolX0?oo:03oobP0oa00oooo:03o01Wo00Gooo]Z00Coo`1AoookJ_oo
nf[o0:go0_oonfX00ooo07Wooo]ZoookJP07oookJP07oomi0?oonf[ooo]Zo`3o2?l0oagooo]Zo`3Q
o`0=oookJP03o`3o=?oonf[o0?m>00Oooo]Z00?o08SooookJ_l0ZOl00ooonfX01?l01?oooo]Zoook
J_l0e?l>oookJP03oon10?oonf[ooo]Z00gooo]Z00?oo`0]oookJ_oonfX02?oonfX00ooUo`3ooo]Z
oookJP08oookJP03og00ooo[0?ooolT000?ooo]Z00?ookh0oookJ_oonfX04?oonfX00oooT03ooo]Z
oookJP04oookJP03o`1doom4o`3ooo]Z00Sooo]Z00?oJ03ooookJ_oonfX0E?oonfX00ooQo`3of_l0
oookJP0?oookJP03ool04ooo09?oo`2C00;ooo]Z00?o0?WooookJ_oonfX02ooonfX00ooobP3ooo]Z
oookJP03oookJP04o`3o6olB0?oo08koo`2>ob7ooo]Z0omho`03o`3og`Go?@3o3_oonfXDo`3Lo`?o
?@3o1?mho`000olm0?oooo]Zo`3og`02o`3ogaWooo]Z00Co08kooa80ool0oa_o0?lK1?oonfX2ooo:
00Oooo]Z0_l0nOl2ool0T`03ool04ooonf[ooo]Z00Sooo]Z0_oJo`05oookJP;o9P3o00Co8?l0oook
J_oonf[ooo]Z1?l0000@oookJP04oc7o0?oonf[ooo]Zo`3oF`Gooo]Z00?o0?n`oh;o0?l0<?l00_oo
nfX00ol0j?oo0?m=oookJP02oookJP03o`H0oooonf[oT_l000?ooo]Z00?o403oool0J_l06Ol01Ooo
nfX01OlE0?ooo`1AoookJ_oonf[o0:go00;ooo]Z00?oo`1ioookJ_oonfX01_oonfX02?l0oe?ooo]Z
oookJ_oonf[o0?l8o`3o7Ooonf[o0>7o3OoonfX00ol0ocCo0?m>oookJP07oookJP03o`28ool0ZOoo
oo]Z00?ooo]Z00?o00CooookJ_l0e?l03ooonfX00oooP@3ooo]ZoookJP0<oookJP03ool0;Ooonf[o
oo]Z00Wooo]Z00?ooeL0oookJ_oonfX02?oonfX00oo[0?oo0?l5oookJP02oookJP03oonn0?oonf[o
oo]Z013ooo]Z00?ooi00oookJ_oonfX01?oonfX00ol0M?ooi_l0oaP0o`08oookJP03ofP0oooonf[o
oo]Z02cooo]Z000]oookJP03on7o0?oJo`3of_l000Wooo]Z1oooN@001Ooonf[oo`2Cool0Tooonf[o
0?Wo00cooo]Z0_oobP04oookJP05o`3o6ooonf[o4P3ooa80ool0S_l08ooonfXDogSo00KoogT02Ooo
nfX4ocd0o`03oomi0?mho`3oN?l000;oN?l01_ooN@000ol0omoooo]ZoookJP0AoookJPKoolT00_l0
S_l3o`3o6`?ooo]Z0ooobP06oookJP;o0?Wo00?ooo]Zool0Tooo09<00_oo01<9oookJP;of_l000?o
hOl0oookJ_oonfX00_oonfX2obH0o`;o8?l01?oonfX4o`0000oooo]Z00CoobP0oookJ_oonf[o0?mK
0ooonfX01Ol0ok3oP_l0oh;o0?oonf[o033o00KoobP000Co1P3ooookJ_oonf[oT_l00ooo:0000ol@
0?ooobP0o`0Io`02oolX00?ooo]Z00Coo`1AoookJ_oonf[o0:go0_oonfX00ooo07Wooo]ZoookJP07
oookJP05oomi0?oonf[ooo]Zo`3o2?l0oad00_oonfX00ol0hOoooo]ZoookJP0:oookJP04o`3o=?oo
nf[ooo]Zo`3oCPKooo]Z00Co08SooookJ_oonf[o0:Wo0ooonfX00ol01?oooo]Zo`3Do`0?oookJP03
oon10?oonf[ooo]Z00cooo]Z00?oo`0]oookJ_oonfX02OoonfX00ooUo`3ooo]ZoookJP07oookJP03
og00ooo[0?ooolT000?ooo]Z00?ookh0oookJ_oonfX04OoonfX00oooT03ooo]ZoookJP04oookJP03
o`1doom4o`3ooo]Z00Oooo]Z00?oJ03ooookJ_oonfX0E_oonfX00ooQo`3of_l0om[o000?oookJP;o
o`0C0_oo09<00ooonf[o0?WooookJP0<oookJP;oolX01?oonfX01?l0oa_o4P3ooa80ool0S_lSoook
JQGoN?l03_oonfX5ocd0o`03o`3ogomho`3oN?l000;oN?l01_l0omlIoookJP;o08ko0ol0oa/3oook
JP?oolX01ooonfX2o`3io`;oo`2C0_oo01<:oookJP03om[o0?oQo`3ooo]Z00Cooo]Z00?o9P3oob3o
0?lPo`001?oonfX4o`0000oooo]Z00Co<Ol0oookJ_oonf[o0?mK1?oonfX01?l0ok3oP_l0oh;o0?l0
<?l2oookJP03o`3Xool0odgooo]Z00;ooo]Z00?o1P3ooookJ_nBo`000ooonfX00ol@0?oo05goo`0I
o`05oookJP05oaD0oooo057ooo]ZoookJ_l0[Ol00_oonfX00ooo07Wooo]ZoookJP06oookJP08o`3o
Dooonf[ooo]ZoookJ_l0o`So0?lMoookJ_l0hOl=oookJP03o`3o=?oonf[o0?m>00Oooo]Z00?o08So
oookJ_l0ZOl00ooonfX00ol01?oooo]Zo`3Do`0?oookJP03oon10?oonf[ooo]Z00cooo]Z00?oo`0]
oookJ_oonfX02OoonfX00oooE`3ooo]ZoookJP08oookJP03og00ooo[0?oo0?l500;ooo]Z00?ookh0
oookJ_oonfX04OoonfX00oooT03ooo]ZoookJP04oookJP03o`1doooVo`3o603o00Sooo]Z00?oJ03o
oookJ_oonfX0;?oonfX002kooo]Z00?ohOl0oookJ_oJo`002OoonfX3oomi00?ooo]Z00?oogT0oook
J_oonfX00_oo09<00ol0nOoooo]ZoookJP0;oookJP03ooo:0?oonf[ooo]Z00;ooo]Z0ol0oa/2oa80
o`03o`2>oooonf[ooo]Z02Cooo]Z1?l0oml3oookJPSoogT05?mho`0MoookJPKoolT00ol0oa/3oook
JP?oolX01ooonfX2o`3io`?oo`2C0_oo01<9oookJP;of_l000?ohOl0oookJ_oonfX00ooonfX01?lV
0?oooo]Zob3o0?n40?l5oookJPCo00003OoonfX2oolX00;ooo]Z00Ko0?mKoookJ_oonf[ooo]Zo`3o
/?n2o`02oookJP03o`0`oooonf[oobP000?oobP000Kooo]Zo`H0oooonf[ooo]Zoi;o0?oonfX2oolX
0003oa00oooo:03o01Wo00CoobP000Gooo]Zool0DOlE0?oooo]Zo`2]o`02oookJP03ool0NOoonf[o
oo]Z00Oooo]Z00SoogT0oookJ_oonf[o0?l8oookJ_l0oagooo]Zo`3Qo`gooo]Z00?o0?ldoookJ_l0
odh01ooonfX00ol0R?oooo]Zo`2Yo`03oookJP03o`04oooonf[o0=Co00oooo]Z00?ooh40oookJ_oo
nfX03OoonfX00ooo02gooo]ZoookJP08oookJP03onGo0?oonf[ooo]Z00Sooo]Z00?oL03oon/0oooo
b@000ooonfX00ooo_P3ooo]ZoookJP0@oookJP03oon@0?oonf[ooo]Z00Cooo]Z00?o07CoodCo0?oo
nfX02?oonfX00omX0?oooo]ZoookJP1GoookJP03on7o0?oonf[of_l0013ooo]Z00Goo`0CoookJ_oo
09?oo`2Co`3io`0>oookJP03ooo:0?oonf[ooo]Z00;ooo]Z0ol0oa/00olB0?oo08kooookJP0Voook
JPCo0?oO1OoonfX6ocd0oaCoN?l08?oonfX2o`2>o`?o0?lK0ooonfX3ooo:00Sooo]Z0_l0nOl2ool0
T`03oookJ_oo01?ooo]Z00Wooo]Z0_oJo`06oookJP03obH0oolPo`3oQ03o00Gooo]Z1?l0000=oook
JP;o<Ol00_oonfX00ol0oe_ooo]ZoookJP02oookJP04o`3o/?n2o`3ooo]Zo`0`o`;ooo]Z00?o0>So
o`3oCOoonfX00_oonfX00ol60?oooo]Zoi;o0003oookJP03oa00ool0GOoo01Wo00Kooo]Z00Coo`1A
oookJ_oonf[o0:go0_oonfX00ooo07Wooo]ZoookJP06oookJP08o`3oDooonf[ooo]ZoookJ_l0o`So
oo]Zo`3o7Ol0hOl>oookJP03o`3o=?l0odkooo]Z00Kooo]Z00?o08SooookJ_l0ZOl00ooonfX01?l0
1?oooo]ZoookJ_l0e?l>oookJP03oon10?oonf[ooo]Z00gooo]Z00?oo`0]oookJ_oonfX02?oonfX0
0oooE`3ooo]ZoookJP09oookJP03on/0ool0o`Gooo]Z00;ooo]Z00?ookh0oookJ_oonfX04?oonfX0
0oooT03ooo]ZoookJP04oookJP03o`1doooVo`3o603o00Sooo]Z00?oJ03ooookJ_oonfX0;OoonfX0
02oooo]Z00?ohOl0oookJ_oJo`002OoonfX00oooN@3ooo]ZoookJP03oookJP;oogT00_oonfX2ool0
T`03o`3ioooonf[ooo]Z00[ooo]Z00?oolX0oookJ_oonfX01?oonfX3o`3o6`03oa80oooonf[ooo]Z
02Oooo]Z00?o0?oOoomi0?ooN@003oooN@0XoookJPGoolT00ol0oa/2ooo900;ooo]Z0_oobP08oook
JP;o0?Wo0_oo09<2oookJP03ool04ooonf[ooo]Z00Sooo]Z00?of_l0on7o0?oQo`001?oonfX2obH0
o`;o8?l000?oQ03ooookJ_oonfX01?oonfX4o`0000cooo]Z00GoobP0oookJ_oonf[ooo]Zo`3oF`03
oookJP06o`3o/?n2o`3ooo]ZoookJ_l0<?oooo]Z1?oo:0001_oonf[o1P3ooookJ_oonf[oT_l0oook
JP;oobP000?o403ooolX0?oo:0000ooo:002oookJP04ool0DOlE0?oooo]Zo`2]o`;ooo]Z0_oob@08
oookJP08oomi0?oonf[ooo]ZoookJ_l0o`So0?lMoookJ_l0hOl=oookJP03o`3o=?oonf[o0?m>00Oo
oo]Z00?o08SooookJ_l0ZOl01?oonfX00ol01?oooo]Zo`3Do`0?oookJP03oon10?oonf[ooo]Z00co
oo]Z00?oo`0]oookJ_oonfX02?oonfX00ooUo`3ooo]ZoookJP08oookJP03og00ooo[0?ooolT000?o
oo]Z00?ookh0oookJ_oonfX04OoonfX00oooT03ooo]ZoookJP04oookJP03onKo0?m4o`3ooo]Z00Oo
oo]Z00?oJ03ooookJ_oonfX0FOoonfX00ooQo`3ooo]Zom[o000@oookJP;oo`0C00Cooo]Zool0Tooo
09?o0?Wo3OoonfX00ooobP3ooo]ZoookJP04oookJP?o0?lK:_oonfX;o`3og`Ko?@3o;?oonfX01?l0
S_oo0?lKo`3o6ol0oa/4oookJP;oolX02OoonfX2o`3io`;oo`2C00?ooo]Zool04ooo01<02OoonfX2
om[o0003on7o0?oonf[ooo]Z00?ooo]Z0_lV0?l00olPo`3oQ03ooookJP05oookJPCo00003?oonfX0
1Olao`3ooo]ZoookJ_oonf[o0?mK00Cooo]Z00Co0?n`oh;o0?oonf[o033o0_oonfX00ol0j?oo0?m=
oookJP02oookJP03o`H0oooonf[oT_l000?ooo]Z00?o403oo`1Mool06Ol01_oonfX01?oo057ooo]Z
oookJ_l0[Ol2oookJP03ool0NOoonf[ooo]Z00Kooo]Z00So0?mCoookJ_oonf[ooo]Zo`3o2?oonf[o
0?lMo`3Qo`kooo]Z00?o0?ldo`3oC_oonfX01ooonfX00ol0R?oo0:WooookJP03oookJP03o`04oooo
nf[o0=Co00oooo]Z00?ooh40oookJ_oonfX03?oonfX00ooo02gooo]ZoookJP09oookJP03oomG0?oo
nf[ooo]Z00Sooo]Z00?oj`3ooookJ_l0o`D00_oonfX00ooo_P3ooo]ZoookJP0AoookJP03oon@0?oo
nf[ooo]Z00Cooo]Z00?o07CoonKo0?lH0?l02?oonfX00omX0?oooo]ZoookJP0]oookJP00<?oonfX0
0ooQo`3ooo]Zom[o000@oookJP06oomi0?oonf[ooo]ZoookJ_oo09?o0?Wo3?oonfX2ooo:00Oooo]Z
0ol0oa/00ol0S_oooo]ZoookJP0YoookJPgoogT09ooonfX3ooo900?o0?lK1?oob@03ooo:00Wooo]Z
00?o0?Woool0Tooo09<00_oonfX2ool04`Sooo]Z00Co001oom[o0?oJo`3ohOl01?oonfX01Ol007oo
9P3oo`00OolPo`3oQ03o00Sooo]Z1?l0000;oookJP05oolX0?oonf[ooo]ZoookJ_l0oe/00ooonfX0
1_l0ok3oP_l0oookJ_oonf[o033ooookJP?oobP00_oonfX01?l60?oooo]ZoookJ_nBo`02oookJP03
oolX0?l@0?ooobP000CoobP00_oonfX01?oo057o5@3ooookJ_l0[Ol3oookJP03ooo90?oonf[ooo]Z
00Kooo]Z00SoogT0oookJ_oonf[ooo]Zo`3o2?l0oagooo]Zo`3Qo`gooo]Z00?o0?ldoookJ_l0odh0
1ooonfX00ol0R?oooo]Zo`2Yo`04oookJP03o`04oooonf[o0=Co00oooo]Z00?ooh40oookJ_oonfX0
3OoonfX00ooo02gooo]ZoookJP08oookJP03onGo0?oonf[ooo]Z00Sooo]Z00?oL03oon/0oooonfX0
0ooonfX00ooo_P3ooo]ZoookJP0@oookJP03oon@0?oonf[ooo]Z00Cooo]Z00?o07CoodCo0?oonfX0
2?oonfX00omX0?oooo]ZoookJP1JoookJP03on7o0?oonf[of_l0017ooo]Z00Goo`0CoookJ_oonf[o
o`2Co`3io`0=oookJP;oolX01ooonfX3o`3o6f7ooo]Z00Go08koo`3o6ol0oa_o0?lKoa80o`03oook
JP?oolX02OoonfX01?l0nOooo`2Cool0Tooo09<2oookJP03ool04ooonf[ooo]Z00Kooo]Z0_l007l0
0ooJo`3ohOl0oookJP03oookJP;o001o00?o9P3oob3o0?n40?l02?oonfX4o`0000_ooo]Z00Go<Ol0
oookJ_oonf[ooo]Zo`3oF`04oookJP;oP_l000Kooo]Zo`0`oooonf[ooo]Zo`3Xool0odd3oookJP03
o`H0oooonf[oT_l000?ooo]Z00Co403oo`1Moooo06[o01Wo1OoonfX01?oo057ooo]ZoookJ_l0[Ol2
oookJP03ool0NOoonf[ooo]Z00Kooo]Z00?o0?mCoookJ_oonfX00_oonfX00ol0o`So0?lMo`3Qo`0>
oookJP03o`3o=?l0odkooo]Z00Oooo]Z00?o08Soo`2YoooonfX00ooonfX00ol01?oooo]Zo`3Do`0?
oookJP03oon10?oonf[ooo]Z00gooo]Z00?oo`0]oookJ_oonfX02?oonfX00oooE`3ooo]ZoookJP09
oookJP03on/0ool0o`Gooo]Z00;ooo]Z00?ookh0oookJ_oonfX04?oonfX00oooT03ooo]ZoookJP04
oookJP03o`1doooVo`3o603o00Sooo]Z00?oJ03ooookJ_oonfX0;_oonfX0037ooo]Z00CohOl0oook
J_oJo`3of_l03ooonfX01?ooN@3ooo]ZoookJ_oonfX2ool0T`gooo]Z00?oolX0oookJ_oonfX01_oo
nfX01OlB0?oo0?lKo`3o6ol0oa_o08ko02gooo]Z2?ooN@0UoookJP03o`2>oooob@3o0?lK00;o0?lK
1Ooob@02ooo:0003ooo90?oonf[ooo]Z00Oooo]Z00?o0?Woool0Tooo09<00ooonfX00ooo01?ooo]Z
oookJP07oookJP;of_l000?o001oon7o0?oonfX00ooonfX01Ol007oo9P3oo`00OolPo`3oQ03o00;o
001o1ooonfX4o`0000[ooo]Z00GoobP0oookJ_oonf[ooo]Zo`3oF`03oookJP06o`3o/?n2o`3ooo]Z
oookJ_l0<?oooo]Z0_oo:003oookJP04o`H0oooonf[ooo]Zoi;o00;ooo]Z00?oobP0oa00oooo:000
0ooo:003oookJP04ool0DOlE0?oooo]Zo`2]o`?ooo]Z00?oolT0oookJ_oonfX01_oonfX01_ooN@3o
oo]ZoookJ_oonf[o0?l8o`3o7@;ooo]Z00?o0>7ooookJ_oonfX02ooonfX00ol0ocCooo]Zo`3oCP06
oookJP04o`28oooonf[ooo]Zo`2Yo`?ooo]Z00?o00CooookJ_l0e?l03ooonfX00oooP@3ooo]Zoook
JP0=oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00?oiOl0oookJ_oonfX02?oonfX00om`0?ooj`3oooo9
0003oookJP03oonn0?oonf[ooo]Z017ooo]Z00?ooi00oookJ_oonfX01?oonfX00ooVo`3oA?l0oook
JP08oookJP03ofP0oooonf[ooo]Z05_ooo]Z00CohOl0oookJ_oJo`3of_l04?oonfX00ooo01?ooo]Z
oookJP02ool0T`kooo]Z00?oolX0oookJ_oonfX01_oonfX01?lB0?oo0?lKo`3o6ol0oa]KoookJP04
o`2>ool0oa_o0?lKo`3o6`;o4P3o0ooonfX2ooo:00_ooo]Z0_oo09<3oookJP;oo`0C2OoonfX2om[o
0003on7o0?oonf[ooo]Z00;ooo]Z00Go001oobH0oolV0?oo8?l0oh@0o`02o`00O`Oooo]Z1?l0000:
oookJP05oc7o0?oonf[ooo]ZoookJ_l0oe/01?oonfX01?n2o`3ooo]ZoookJ_l0<?l2oookJP03o`3X
ool0odgooo]Z00;ooo]Z00?o1P3ooookJ_nBo`000ooonfX01?l@0?oo05goool0J_l06Ol5oookJP04
ool0DOoonf[ooo]Zo`2]o`;ooo]Z00?oo`1ioookJ_oonfX01_oonfX00ol0oe?ooo]ZoookJP02oook
JP04o`3o2?l0oagooo]Zo`3Qo`gooo]Z00?o0?ldoookJ_l0odh01ooonfX00ol0R?oooo]Zo`2Yo`03
oookJP03o`04oooonf[o0=Co00oooo]Z00?ooh40oookJ_oonfX03OoonfX00ooo02gooo]ZoookJP08
oookJP03oomG0?oonf[ooo]Z00Wooo]Z00?oj`3ooookJ_l0o`D00_oonfX00ooo_P3ooo]ZoookJP0A
oookJP03oon@0?oonf[ooo]Z00Cooo]Z00?o07CoonKo0?lH0?l02?oonfX00omX0?oooo]ZoookJP0^
oookJP00<_oonfX01?oQo`3ooo]ZoookJ_oJo`0?oookJP;oogT00ooonfX2ool0T`cooo]Z0_oobP08
oookJP;o4P3o0ol0oa/2o`2>obkooo]Z0oooN@0RoookJP;o08ko0ol0oa/5ooo900?oolX01?oob@06
oookJP?oo`2C0ooonfX2ool04`Wooo]Z00Gof_l0oookJ_oQo`3ohOl0o`00O`03oookJP;o9P3o0_lP
o`001?n40?oo001oo`00Ool007l7oookJPCo00002OoonfX01Ooo:03ooo]ZoookJ_oonf[o0?mK00?o
oo]Z00Ko0?n`oh;o0?oonf[ooo]Zo`0`oooonfX2oolX00?ooo]Z00Co1P3ooookJ_oonf[oT_l00ooo
nfX00ol@0?ooobP0oolX0002oolX00?ooo]Z00Coo`1AoolX0?oonf[o0:go0ooonfX00ooob@3ooo]Z
oookJP06oookJP09oomi0?oonf[ooo]ZoookJ_l0o`Sooo]Zo`3o7Ooonf[o0>7o00gooo]Z00?o0?ld
oookJ_l0odh01ooonfX00ol0R?oooo]Zo`2Yo`04oookJP03o`04oooonf[o0=Co00oooo]Z00?ooh40
oookJ_oonfX03?oonfX00ooo02gooo]ZoookJP09oookJP03onGo0?oonf[ooo]Z00Oooo]Z00?oL03o
on/0oooob@000ooonfX00ooo_P3ooo]ZoookJP0AoookJP03oon@0?oonf[ooo]Z00Cooo]Z00?o07Co
odCo0?oonfX02?oonfX00omX0?oooo]ZoookJP1MoookJP04on7o0?oonf[ooo]Zom[o013ooo]Z0_oo
01<2oookJP;oo`2C3OoonfX2ooo:00Sooo]Z0_lB0?l3o`3o6`03o`2>oooonf[ooo]Z05;ooo]Z00Co
08koo`3o6ol0oa_o0?lK0olB0?l2oookJP?oolX02ooonfX2ool0T`?ooo]Z0_oo01<9oookJP;of_l0
0_oQo`001_l007oooo]ZoookJ_oonf[o001oobH0o`;o8?l000CoQ03oo`00Ool007oo001o1ooonfX4
o`0000Wooo]Z00Go<Ol0oookJ_oonf[ooo]Zo`3oF`04oookJP04oh;o0?oonf[ooo]Zo`0`o`;ooo]Z
00?o0>Soo`3oCOoonfX00_oonfX00ol60?oooo]Zoi;o0003oookJP04oa00ool0GOooo`1Zo`0Io`Go
oo]Z00Coo`1AoookJ_oonf[o0:go0_oonfX00ooo07Wooo]ZoookJP06oookJP03o`3oDooonf[ooo]Z
00;ooo]Z00Co0?l8oookJ_l0oago0>7o3_oonfX00ol0ocCo0?m>oookJP07oookJP03o`28ool0ZOoo
oo]Z00?ooo]Z00?o00CooookJ_l0e?l03ooonfX00oooP@3ooo]ZoookJP0<oookJP03ool0;Ooonf[o
oo]Z00Wooo]Z00?ooeL0oookJ_oonfX02?oonfX00om`0?ooj`3oo`3o1@02oookJP03oonn0?oonf[o
oo]Z017ooo]Z00?ooi00oookJ_oonfX01?oonfX00ol0M?ooi_l0oaP0o`08oookJP03ofP0oooonf[o
oo]Z02oooo]Z000coookJP04on7o0?oonf[ooo]Zom[o013ooo]Z00GoogT0oookJ_oonf[ooo]Zo`3i
o`02ool0T`cooo]Z00?oolX0oookJ_oonfX01ooonfX2oa80o`04oookJ_l0oa_o0?lKo`3o6`;o08ko
COoonfX2o`2>o`?o0?lK1Ooob@03ooo:00;oolT02OoonfX2ool0T`Gooo]Z00?oo`0CoookJ_oonfX0
1ooonfX2om[o0003oookJ_oQo`3o001o00;o001o0_oonfX00olV0?oo001oob3o0002oh@0o`;ooo]Z
0ol007l6oookJPCo00002?oonfX01Ooo:03ooo]ZoookJ_oonf[o0?mK00?ooo]Z00Wo0?n`oh;o0?oo
nf[ooo]Zo`0`oooonf[oobP0oookJ_l0odd00_oonfX01?l60?oooo]ZoookJ_nBo`03oookJP04oa00
oooo:03oobP0oolX00Cooo]Z00Coo`1AoolX0?oonf[o0:go0ooonfX00ooob@3ooo]ZoookJP06oook
JP09oomi0?oonf[ooo]ZoookJ_l0o`Sooo]Zo`3o7Ooonf[o0>7o00gooo]Z00?o0?ldoookJ_l0odh0
1ooonfX00ol0R?oooo]Zo`2Yo`04oookJP03o`04oooonf[o0=Co00oooo]Z00?ooh40oookJ_oonfX0
3OoonfX00ooo02gooo]ZoookJP08oookJP03onGo0?oonf[ooo]Z00Sooo]Z00?oL03oon/0oooob@00
0ooonfX00ooo_P3ooo]ZoookJP0AoookJP03oon@0?oonf[ooo]Z00Cooo]Z00?oi_l0odCo0?oonfX0
2?oonfX00omX0?oooo]ZoookJP1NoookJP04on7o0?oonf[ooo]Zom[o017ooo]Z00Coo`0CoookJ_oo
nf[o0?Wo0_oo09<=oookJP03ooo:0?oonf[ooo]Z00Oooo]Z0_lB0?l01Ooonf[o0?lKo`3o6ol0oa_o
08ko04kooo]Z00Go08koo`3o6ol0oa_o0?lKoookJP02oa80o`;ooo]Z0ooobP0<oookJP;oo`2C1?oo
nfX00ooo01?ooo]ZoookJP08oookJP03om[o0?oonf[ohOl000?o001o0ooonfX01?lV0?oo8?l0o`00
Oon40?l2oookJP?o001o1_oonfX4o`0000Sooo]Z00Go<Ol0oookJ_oonf[ooo]Zo`3oF`04oookJP04
oh;o0?oonf[ooo]Zo`0`o`;ooo]Z00?o0>Soo`3oCOoonfX00_oonfX00ol60?oooo]Zoi;o0003oook
JP04oa00ool0GOooo`1Zo`0Io`Gooo]Z00Coo`1AoookJ_oonf[o0:go0_oonfX00ooo07Wooo]Zoook
JP06oookJP03o`3oDooonf[ooo]Z00;ooo]Z00Co0?l8oookJ_l0oago0>7o3_oonfX00ol0ocCo0?m>
oookJP07oookJP03o`28ool0ZOoooo]Z00?ooo]Z00?o00CooookJ_l0e?l03ooonfX00oooP@3ooo]Z
oookJP0=oookJP03ool0;Ooonf[ooo]Z00Sooo]Z00?ooeL0oookJ_oonfX02OoonfX00oo[0?oooo]Z
o`3o1@02oookJP03oonn0?oonf[ooo]Z017ooo]Z00?ooi00oookJ_oonfX01?oonfX00ol0M?ooi_l0
oaP0o`08oookJP03ofP0oooonf[ooo]Z02oooo]Z000doookJP04on7o0?oonf[ooo]Zom[o013ooo]Z
00OoogT0oookJ_oonf[ooo]Zo`3ioooonf[oo`2C00cooo]Z00?oolX0oomi0?ooN@003?ooN@02o`3o
6`;o08koB_oonfX01?l0S_oo0?lKo`3o6ooonfX4ooo900;ooo]Z00?oolX0oookJ_oonfX02ooonfX0
0ooo09?ooo]ZoookJP04oookJP03ool04ooonf[ooo]Z00Oooo]Z00Gof_l0oookJ_oonf[ohOl0oook
JP03o`00O`05oookJ_lV0?oooo]Zob3o0?n40?l01?oonfX3o`00O`Kooo]Z1_l00005oookJP05oolX
0?oonf[ooo]ZoookJ_l0oe/00ooonfX02Ol0ok3oP_l0oookJ_oonf[o033ooookJ_oo:03ooo]Zo`3o
C@02oookJP04o`H0oooonf[ooo]Zoi;o00?ooo]Z00Co403ooolX0?oo:03oobP01?oonfX01?oo057o
obP0oookJ_l0[Ol3oookJP03ooo90?oonf[ooo]Z00Kooo]Z00WoogT0oookJ_oonf[ooo]Zo`3o2?oo
nf[o0?lMoookJ_l0hOl03OoonfX00ol0ocCooo]Zo`3oCP07oookJP03o`28oooonf[o0:Wo00Cooo]Z
00?o00CooookJ_l0e?l03ooonfX00oooP@3ooo]ZoookJP0=oookJP03ool0;Ooonf[ooo]Z00Sooo]Z
00?oiOl0oookJ_oonfX02?oonfX00om`0?ooj`3oooo90003oookJP03oonn0?oonf[ooo]Z017ooo]Z
00?ooi00oookJ_oonfX01?oonfX00ooVo`3oA?l0oookJP08oookJP03ofP0oooonf[ooo]Z063ooo]Z
00CohOl0oookJ_oonf[of_l04OoonfX01_oo01?ooo]ZoookJ_l0nOoooo]Zool0T`gooo]Z00?oolX0
oookJ_oonfX02?oonfX01?lB0?oooo]ZoookJ_oonfX2o`3o6`03o`2>oooonf[ooo]Z04Wooo]Z0_l0
oa/3oookJP05oa80oooonf[ooo]ZoookJ_oobP003_oonfX00ooo09?ooo]ZoookJP03oookJP03ool0
4ooonf[ooo]Z00Sooo]Z00Cof_l0oookJ_oQo`3ooo]Z0ol007l2oookJP04obH0oolPo`3ooo]Zoh@0
o`?ooo]Z0ol007l6oookJPKo00001OoonfX01Olao`3ooo]ZoookJ_oonf[o0?mK00Cooo]Z00CoP_l0
oookJ_oonf[o033o0_oonfX00ol0j?oo0?m=oookJP02oookJP03o`H0oooonf[oT_l000?ooo]Z00Co
403oo`1Moooo06[o01Wo1OoonfX01?oo057ooo]ZoookJ_l0[Ol2oookJP03ool0NOoonf[ooo]Z00Ko
oo]Z00?o0?mCoookJ_oonfX00_oonfX01?l0o`Sooo]Zo`3o7Ol0hOl>oookJP03o`3o=?l0odkooo]Z
00Oooo]Z00?o08Soo`2YoooonfX00ooonfX00ol01?oooo]Zo`3Do`0?oookJP03oon10?oonf[ooo]Z
00gooo]Z00?oo`0]oookJ_oonfX02?oonfX00oooE`3ooo]ZoookJP09oookJP03on/0oooonf[o0?l5
00;ooo]Z00?ookh0oookJ_oonfX04OoonfX00oooT03ooo]ZoookJP04oookJP03o`1doooVo`3o603o
00Sooo]Z00?oJ03ooookJ_oonfX0<?oonfX00>Kooo]Z0ol007l9oookJP?o001o1_oonfX4o`000?oo
oo]Zf_oonfX3o`00O`Wooo]Z0ol007l6oookJPCo0000mooonfX00>Kooo]Z0ol007l4oookJP;o001o
0_oonfX4o`00O`Kooo]Z1?l0003ooookJ][ooo]Z0ol007l4oookJP;o001o0_oonfX4o`00O`Kooo]Z
1?l0003goookJP00i_oonfX3o`00O`Cooo]Z1ol007oooookJ^Gooo]Z0ol007l4oookJPOo001ooooo
nfX3oookJP00i_oonfX3o`00O`Cooo]Z1_l007oooookJ^Kooo]Z0ol007l4oookJPKo001ooooonfX4
oookJP00hooonfX6o`00O`Cooo]Z0_l007oooookJ^Oooo]Z1_l007l4oookJP;o001ooooonfX8oook
JP00hooonfX6o`00O`Cooo]Z0_l007oooookJ^Oooo]Z1_l007l4oookJP;o001ooooonfX8oookJP00
iOoonfX4o`00O`Gooo]Z1ol007oooookJ^?ooo]Z1?l007l5oookJPOo001ooooonfX2oookJP00i_oo
nfX3o`00O`Gooo]Z1ol007oooookJ^Cooo]Z0ol007l5oookJPOo001ooooonfX2oookJP00oooonf[o
oookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00
oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[
oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Z
oooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooook
J_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z
003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooook
J^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooo
nf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oo
oo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]Zjooo
nfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oo
oo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00\
\>"],
  ImageRangeCache->{{{0, 999}, {999, 0}} -> {-0.0500105, -0.0500105, \
0.00210213, 0.00210213}, {{23.75, 476.812}, {975.188, 522.125}} -> {-71.9892, \
-71.0885, 0.283964, 0.283964}, {{522.125, 975.188}, {975.188, 522.125}} -> \
{-213.51, -71.0885, 0.283964, 0.283964}, {{23.75, 476.812}, {476.812, 23.75}} -> \
{-17.9973, -53.1523, 0.070991, 0.070991}, {{522.125, 975.188}, {476.812, \
23.75}} -> {-53.3774, -53.1523, 0.070991, 0.070991}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
In this next example, the eigenvalues are complex, with a negative \
real part, and the system of equations has an stable, attractive circulation \
pattern. The eigenvectors are complex and and there are no directions along \
which the system will evolve along a straight trajectory.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CritPointPlotPointsMany[\(-0.25\), \(-2.0\), 2, \(-1.5\)]\)], "Input",
  CellTags->"mmtag:25:fixed_point__stable_focus_node_visualization"],

Cell[BoxData[
    \("Stable and Attractive"\)], "Print"],

Cell[BoxData[
    \("Circulation"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Eigenvalues = "\[InvisibleSpace]\(\(-0.875`\) + 
          1.8998355191963328`\ \[ImaginaryI]\)\[InvisibleSpace]" and "\
\[InvisibleSpace]\(\(-0.875`\) - 1.8998355191963328`\ \[ImaginaryI]\)\),
      SequenceForm[ "Eigenvalues = ", 
        Complex[ -0.875, 1.8998355191963328], " and ", 
        Complex[ -0.875, -1.8998355191963328]],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{\(-0.875`\) + 1.8998355191963328`\ \[ImaginaryI], \(-0.875`\) - 
          1.8998355191963328`\ \[ImaginaryI]}, {{\(\(0.22097086912079625`\)\(\
\[InvisibleSpace]\)\) + 
            0.6716932893813963`\ \[ImaginaryI], \(\(0.7071067811865478`\)\(\
\[InvisibleSpace]\)\) + 
            0.`\ \[ImaginaryI]}, {\(\(0.22097086912079625`\)\(\
\[InvisibleSpace]\)\) - 
            0.6716932893813963`\ \[ImaginaryI], \(\(0.7071067811865478`\)\(\
\[InvisibleSpace]\)\) + 0.`\ \[ImaginaryI]}}}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 1000 1000 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto fill
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto
-15. 3.75 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -13.4688 -20 ]
[0 .4875 13.4688 0 ]
[.125 .4875 -25.9688 -20 ]
[.125 .4875 25.9688 0 ]
[.25 .4875 -20.9688 -20 ]
[.25 .4875 20.9688 0 ]
[.375 .4875 -25.9688 -20 ]
[.375 .4875 25.9688 0 ]
[.625 .4875 -19.5 -20 ]
[.625 .4875 19.5 0 ]
[.75 .4875 -14.5 -20 ]
[.75 .4875 14.5 0 ]
[.875 .4875 -19.5 -20 ]
[.875 .4875 19.5 0 ]
[1 .4875 -7 -20 ]
[1 .4875 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .125 -51.9375 -10 ]
[.4875 .125 0 10 ]
[.4875 .25 -41.9375 -10 ]
[.4875 .25 0 10 ]
[.4875 .375 -51.9375 -10 ]
[.4875 .375 0 10 ]
[.4875 .625 -39 -10 ]
[.4875 .625 0 10 ]
[.4875 .75 -29 -10 ]
[.4875 .75 0 10 ]
[.4875 .875 -39 -10 ]
[.4875 .875 0 10 ]
[.4875 1 -14 -10 ]
[.4875 1 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 .5 m
.125 .50625 L
s
gsave
.125 .4875 -86.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.25 .5 m
.25 .50625 L
s
gsave
.25 .4875 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.375 .5 m
.375 .50625 L
s
gsave
.375 .4875 -86.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.625 .5 m
.625 .50625 L
s
gsave
.625 .4875 -80.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.75 .5 m
.75 .50625 L
s
gsave
.75 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.875 .5 m
.875 .50625 L
s
gsave
.875 .4875 -80.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .125 m
.50625 .125 L
s
gsave
.4875 .125 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.5 .25 m
.50625 .25 L
s
gsave
.4875 .25 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .375 m
.50625 .375 L
s
gsave
.4875 .375 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.5 .625 m
.50625 .625 L
s
gsave
.4875 .625 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.5 .75 m
.50625 .75 L
s
gsave
.4875 .75 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .875 m
.50625 .875 L
s
gsave
.4875 .875 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.01 w
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.305 0 1 r
.5 Mabswid
.54941 1 m
.47351 .9466 L
.39332 .87158 L
.33026 .79374 L
.28411 .71665 L
.25401 .64328 L
.23858 .57595 L
.23607 .51639 L
.24453 .46575 L
.26184 .4246 L
.2859 .39307 L
.31466 .37088 L
.34621 .35742 L
.37885 .35182 L
.41109 .35304 L
.44171 .35995 L
.46975 .37134 L
.49449 .38606 L
.51548 .40296 L
.53249 .42104 L
.54546 .43937 L
.55453 .45718 L
.55997 .47384 L
.56214 .48888 L
.56147 .50194 L
.55845 .51283 L
.55358 .52146 L
.54735 .52785 L
.54022 .53209 L
.53263 .53438 L
.52496 .53492 L
.51752 .53397 L
.51057 .53182 L
.50431 .52875 L
.49889 .52501 L
.49438 .52088 L
.49082 .51657 L
.4882 .5123 L
.48647 .50822 L
.48556 .50446 L
.48538 .50113 L
.4858 .49829 L
.48673 .49597 L
.48804 .49419 L
.48962 .49292 L
.49136 .49214 L
.49316 .49181 L
.49495 .49185 L
.49665 .49221 L
.49822 .49282 L
Mistroke
.4996 .49363 L
.50078 .49456 L
.50174 .49555 L
.50247 .49657 L
.50299 .49756 L
.5033 .49849 L
.50344 .49933 L
.50341 .50006 L
.50325 .50067 L
.50299 .50116 L
.50265 .50152 L
.50226 .50176 L
.50184 .5019 L
.50141 .50193 L
.501 .50189 L
.50061 .50177 L
.50026 .50161 L
.49996 .5014 L
.49971 .50117 L
.4995 .50093 L
.49936 .5007 L
.49926 .50047 L
.4992 .50026 L
.49919 .50008 L
.49921 .49992 L
.49926 .49979 L
.49933 .49968 L
.49942 .49961 L
.49951 .49957 L
.49961 .49955 L
.49971 .49955 L
.49981 .49957 L
.4999 .4996 L
.49997 .49964 L
.50004 .49969 L
.50009 .49975 L
.50013 .49981 L
.50016 .49986 L
.50018 .49991 L
.50019 .49996 L
.50019 .5 L
.50018 .50003 L
.50017 .50006 L
.50015 .50008 L
.50013 .5001 L
.5001 .5001 L
.50008 .50011 L
.50006 .5001 L
.50004 .5001 L
.50002 .50009 L
Mistroke
.5 .50008 L
.49998 .50007 L
.49997 .50005 L
.49996 .50004 L
.49996 .50003 L
.49996 .50002 L
.49996 .5 L
.49996 .5 L
.49996 .49999 L
.49996 .49998 L
.49997 .49998 L
.49997 .49998 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-8.9436086 4.9917992 -9.4651578 2.5781378 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-9.524467 0.44887386 -9.193374 -1.356502 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.0290653 -5.0345058 -1.0241102 -4.612732 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
2.2461187 -0.3652267 2.2152809 0.10129766 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
0.61392115 1.2230286 0.36454317 1.1426071 MAarrowhead1
% End of user PostScript
.581 1 0 r
.23858 .57595 m
.23607 .51639 L
s
% Start of user PostScript
-0.52284727 0.15189797 -0.52785088 0.032788515 MAarrowhead1
% End of user PostScript
.266 1 0 r
.41109 .35304 m
.44171 .35995 L
s
% Start of user PostScript
-0.17782533 -0.29391545 -0.11658245 -0.28010572 MAarrowhead1
% End of user PostScript
0 1 .049 r
.55997 .47384 m
.56214 .48888 L
s
% Start of user PostScript
0.11994201 -0.052317428 0.12427222 -0.022247202 MAarrowhead1
% End of user PostScript
0 1 .364 r
.52496 .53492 m
.51752 .53397 L
s
% Start of user PostScript
0.049915244 0.06983358 0.035031864 0.067948442 MAarrowhead1
% End of user PostScript
0 1 .679 r
.48647 .50822 m
.48556 .50446 L
s
% Start of user PostScript
-0.027053709 0.016431982 -0.028874003 0.0089214462 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49316 .49181 m
.49495 .49185 L
s
% Start of user PostScript
-0.013676736 -0.016389977 -0.01009857 -0.016304827 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50299 .49756 m
.5033 .49849 L
s
% Start of user PostScript
0.0059798908 -0.0048807253 0.0066096755 -0.0030243449 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50184 .5019 m
.50141 .50193 L
s
% Start of user PostScript
0.0036749743 0.0037949576 0.0028244503 0.0038678152 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49936 .5007 m
.49926 .50047 L
s
% Start of user PostScript
-0.0012888227 0.0013954384 -0.0014871267 0.00094134422 MAarrowhead1
% End of user PostScript
1 0 .962 r
0 .1296 m
.00685 .12511 L
.09651 .09421 L
.18791 .0845 L
.27712 .09297 L
.36092 .11635 L
.43682 .15132 L
.50307 .19462 L
.55856 .24318 L
.6028 .29422 L
.63583 .34529 L
.65812 .39435 L
.67051 .43975 L
.67409 .48028 L
.67014 .51509 L
.66001 .54371 L
.64512 .56598 L
.62681 .58204 L
.60637 .59224 L
.58496 .59712 L
.56358 .59733 L
.5431 .59361 L
.52418 .58675 L
.50733 .57752 L
.4929 .56667 L
.48106 .55489 L
.47188 .54282 L
.4653 .53096 L
.46117 .51978 L
.45925 .5096 L
.45927 .50066 L
.46091 .49314 L
.46386 .4871 L
.46777 .48254 L
.47235 .47942 L
.4773 .47762 L
.48236 .477 L
.48731 .4774 L
.49198 .47864 L
.49622 .48054 L
.49992 .48291 L
.50304 .48558 L
.50554 .4884 L
.50741 .49123 L
.50868 .49396 L
.50941 .49649 L
.50964 .49876 L
.50945 .50071 L
.50891 .50232 L
.5081 .50358 L
Mistroke
.5071 .50449 L
.50597 .50508 L
.50479 .50537 L
.5036 .5054 L
.50247 .5052 L
.50141 .50483 L
.50047 .50433 L
.49966 .50374 L
.49899 .50309 L
.49848 .50242 L
.4981 .50176 L
.49786 .50114 L
.49775 .50057 L
.49774 .50007 L
.49783 .49965 L
.49799 .49931 L
.4982 .49905 L
.49845 .49887 L
.49872 .49877 L
.499 .49873 L
.49928 .49875 L
.49954 .49881 L
.49977 .49891 L
.49998 .49904 L
.50016 .49919 L
.5003 .49935 L
.5004 .4995 L
.50048 .49966 L
.50052 .4998 L
.50053 .49992 L
.50052 .50003 L
.5005 .50012 L
.50045 .50019 L
.5004 .50025 L
.50034 .50028 L
.50027 .5003 L
.5002 .5003 L
.50014 .50029 L
.50008 .50027 L
.50003 .50024 L
.49998 .50021 L
.49995 .50017 L
.49992 .50014 L
.4999 .5001 L
.49988 .50007 L
.49988 .50003 L
.49987 .50001 L
.49988 .49998 L
.49989 .49996 L
.4999 .49995 L
Mistroke
.49991 .49994 L
.49993 .49993 L
.49994 .49993 L
.49996 .49993 L
.49997 .49993 L
.49999 .49994 L
.5 .49995 L
.50001 .49995 L
.50002 .49996 L
.50002 .49997 L
.50003 .49998 L
.50003 .49999 L
.50003 .5 L
.50003 .5 L
.50003 .50001 L
.50003 .50001 L
.50002 .50001 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
2.2446763 -9.1460436 3.8132692 -7.299559 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
4.977544 -5.4576074 5.7558522 -3.69312 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.7872839 3.3511804 3.0127228 3.5142501 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.0359688 1.5152592 -1.2670577 1.0883865 MAarrowhead1
% End of user PostScript
.897 1 0 r
.00685 .12511 m
.09651 .09421 L
s
% Start of user PostScript
-0.98630947 -0.74978206 -0.80698851 -0.81157649 MAarrowhead1
% End of user PostScript
.581 1 0 r
.6028 .29422 m
.63583 .34529 L
s
% Start of user PostScript
0.20560069 -0.41156598 0.27165266 -0.30942469 MAarrowhead1
% End of user PostScript
.266 1 0 r
.62681 .58204 m
.60637 .59224 L
s
% Start of user PostScript
0.25361573 0.16408593 0.2127352 0.18448833 MAarrowhead1
% End of user PostScript
0 1 .049 r
.48106 .55489 m
.47188 .54282 L
s
% Start of user PostScript
-0.037878141 0.10978682 -0.056233204 0.085630594 MAarrowhead1
% End of user PostScript
0 1 .364 r
.46777 .48254 m
.47235 .47942 L
s
% Start of user PostScript
-0.064455921 -0.034912463 -0.055302906 -0.04116493 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50304 .48558 m
.50554 .4884 L
s
% Start of user PostScript
0.0060818564 -0.028838209 0.01107092 -0.023197471 MAarrowhead1
% End of user PostScript
0 1 .995 r
.5081 .50358 m
.5071 .50449 L
s
% Start of user PostScript
0.016202123 0.0071512982 0.014197255 0.0089783233 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49966 .50374 m
.49899 .50309 L
s
% Start of user PostScript
-0.00068061648 0.0074729718 -0.0020122669 0.0061743542 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49799 .49931 m
.4982 .49905 L
s
% Start of user PostScript
-0.004029805 -0.0013856681 -0.0036027366 -0.0019018628 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49998 .49904 m
.50016 .49919 L
s
% Start of user PostScript
-0.000035901902 -0.0019128691 0.00031407087 -0.0016187318 MAarrowhead1
% End of user PostScript
1 0 .664 r
.8357 0 m
.83904 .00448 L
.9146 .14412 L
.96145 .27558 L
.98232 .3949 L
.98056 .49927 L
.95986 .58692 L
.92409 .65702 L
.87711 .70958 L
.82259 .74533 L
.76392 .76552 L
.70412 .77186 L
.64576 .7663 L
.59093 .75099 L
.54127 .7281 L
.49794 .69977 L
.46164 .66799 L
.4327 .6346 L
.41111 .60118 L
.39653 .56909 L
.38843 .53938 L
.38609 .51287 L
.38869 .4901 L
.39532 .47138 L
.40507 .45681 L
.41705 .44631 L
.43042 .43964 L
.44443 .43645 L
.45842 .43632 L
.47182 .43876 L
.48419 .44325 L
.49522 .44929 L
.50466 .45639 L
.5124 .46409 L
.5184 .472 L
.52271 .47975 L
.52541 .48707 L
.52666 .49373 L
.52665 .49957 L
.52557 .50449 L
.52365 .50845 L
.52108 .51142 L
.51809 .51347 L
.51485 .51465 L
.51154 .51505 L
.5083 .51479 L
.50525 .51397 L
.50247 .51273 L
.50005 .51118 L
.49801 .50943 L
Mistroke
.49638 .50759 L
.49515 .50573 L
.49432 .50395 L
.49384 .50229 L
.49369 .50081 L
.49382 .49954 L
.49417 .49848 L
.4947 .49766 L
.49536 .49706 L
.49609 .49668 L
.49687 .49649 L
.49764 .49647 L
.49839 .4966 L
.49908 .49684 L
.49969 .49717 L
.50022 .49756 L
.50066 .49798 L
.501 .49842 L
.50124 .49885 L
.5014 .49926 L
.50147 .49963 L
.50148 .49995 L
.50142 .50023 L
.50132 .50045 L
.50118 .50062 L
.50101 .50074 L
.50084 .50081 L
.50065 .50083 L
.50047 .50082 L
.5003 .50078 L
.50015 .50071 L
.50001 .50063 L
.4999 .50053 L
.49981 .50043 L
.49974 .50032 L
.49969 .50023 L
.49966 .50013 L
.49965 .50005 L
.49966 .49998 L
.49968 .49992 L
.4997 .49987 L
.49974 .49984 L
.49978 .49982 L
.49982 .49981 L
.49987 .4998 L
.49991 .49981 L
.49995 .49982 L
.49998 .49984 L
.50001 .49986 L
.50003 .49989 L
Mistroke
.50005 .49991 L
.50007 .49993 L
.50008 .49996 L
.50008 .49998 L
.50008 .5 L
.50008 .50001 L
.50007 .50002 L
.50007 .50003 L
.50006 .50004 L
.50005 .50004 L
.50004 .50005 L
.50003 .50005 L
.50002 .50004 L
.50001 .50004 L
.5 .50004 L
.49999 .50003 L
.49999 .50002 L
.49999 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-0.17802447 7.1368351 -1.4702354 5.9825973 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-2.4961966 4.7744221 -3.2576249 3.5692832 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.9630355 -1.9615034 -2.4773233 -2.1928796 MAarrowhead1
% End of user PostScript
1 .788 0 r
.8357 0 m
.83904 .00448 L
s
% Start of user PostScript
0.46574865 -1.2765282 0.67807129 -0.99104253 MAarrowhead1
% End of user PostScript
.897 1 0 r
.87711 .70958 m
.82259 .74533 L
s
% Start of user PostScript
0.75422299 0.41916175 0.64518249 0.49065209 MAarrowhead1
% End of user PostScript
.581 1 0 r
.46164 .66799 m
.4327 .6346 L
s
% Start of user PostScript
-0.076720012 0.33598005 -0.13459103 0.26919459 MAarrowhead1
% End of user PostScript
.266 1 0 r
.40507 .45681 m
.41705 .44631 L
s
% Start of user PostScript
-0.18986793 -0.086377454 -0.16590473 -0.10738331 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50466 .45639 m
.5124 .46409 L
s
% Start of user PostScript
0.0093195332 -0.087218752 0.024801887 -0.071811679 MAarrowhead1
% End of user PostScript
0 1 .364 r
.52365 .50845 m
.52108 .51142 L
s
% Start of user PostScript
0.047292034 0.016890791 0.042165542 0.022849726 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50005 .51118 m
.49801 .50943 L
s
% Start of user PostScript
0.000092833557 0.022361848 -0.0039842543 0.018863784 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49417 .49848 m
.4947 .49766 L
s
% Start of user PostScript
-0.011657379 -0.0030346421 -0.010599332 -0.0046809533 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49969 .49717 m
.50022 .49756 L
s
% Start of user PostScript
-0.00061226905 -0.0056677901 0.00044662144 -0.0048884127 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50142 .50023 m
.50132 .50045 L
s
% Start of user PostScript
0.0028437189 0.00046178001 0.0026363434 0.00090715931 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50015 .50071 m
.50001 .50063 L
s
% Start of user PostScript
0.00029475712 0.0014210066 0.0000231534 0.0012513321 MAarrowhead1
% End of user PostScript
.35 0 1 r
.10956 1 m
.04684 .88285 L
s
.04684 .88285 m
0 .74939 L
s
0 .4049 m
.0005 .40285 L
.03985 .32714 L
.09128 .27049 L
.1508 .23212 L
.21473 .21063 L
.2798 .20415 L
.34323 .21055 L
.40275 .22749 L
.4566 .25261 L
.50354 .28359 L
.54281 .31825 L
.57405 .35462 L
.59732 .39096 L
.61297 .42583 L
.62158 .45806 L
.62395 .4868 L
.62098 .51145 L
.61365 .53169 L
.60295 .54741 L
.58986 .55871 L
.57527 .56585 L
.56001 .56921 L
.54481 .56926 L
.53025 .56653 L
.51682 .56158 L
.50487 .55497 L
.49465 .54721 L
.48628 .53882 L
.47981 .53022 L
.47518 .52179 L
.47228 .51384 L
.47096 .50662 L
.47102 .50029 L
.47222 .49497 L
.47434 .4907 L
.47715 .48749 L
.48042 .48529 L
.48395 .48404 L
.48755 .48362 L
.49107 .48393 L
.49439 .48483 L
.49739 .48619 L
.50002 .48789 L
.50223 .48979 L
.50399 .4918 L
.50531 .49382 L
.50621 .49576 L
.50671 .49756 L
.50686 .49916 L
Mistroke
.50672 .50054 L
.50633 .50168 L
.50575 .50257 L
.50503 .50321 L
.50423 .50362 L
.50338 .50382 L
.50254 .50384 L
.50173 .5037 L
.50098 .50343 L
.50031 .50307 L
.49974 .50265 L
.49927 .50218 L
.4989 .50171 L
.49864 .50124 L
.49847 .5008 L
.4984 .50039 L
.49839 .50004 L
.49846 .49974 L
.49857 .4995 L
.49872 .49932 L
.4989 .49919 L
.4991 .49912 L
.4993 .49909 L
.49949 .49911 L
.49968 .49916 L
.49984 .49923 L
.49999 .49932 L
.50012 .49943 L
.50021 .49954 L
.50029 .49965 L
.50034 .49976 L
.50037 .49986 L
.50038 .49995 L
.50037 .50002 L
.50035 .50009 L
.50032 .50014 L
.50028 .50018 L
.50024 .5002 L
.50019 .50021 L
.50014 .50021 L
.5001 .50021 L
.50006 .50019 L
.50002 .50017 L
.49999 .50015 L
.49996 .50012 L
.49994 .5001 L
.49993 .50007 L
.49992 .50005 L
.49991 .50002 L
.49991 .5 L
Mistroke
.49991 .49999 L
.49992 .49997 L
.49993 .49996 L
.49994 .49996 L
.49995 .49995 L
.49996 .49995 L
.49997 .49995 L
.49998 .49995 L
.49999 .49996 L
.5 .49996 L
.50001 .49997 L
.50001 .49997 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-3.3650095 -9.7875576 -1.4364087 -8.8620034 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
0.24001039 -7.7306514 1.6376942 -6.4717837 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
4.0813124 1.1911598 3.6874398 1.7473102 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
0.14715815 1.9665781 -0.21741994 1.6842631 MAarrowhead1
% End of user PostScript
.897 1 0 r
.0005 .40285 m
.03985 .32714 L
s
% Start of user PostScript
-0.9989992 -0.19430966 -0.92030383 -0.34572801 MAarrowhead1
% End of user PostScript
.581 1 0 r
.4566 .25261 m
.50354 .28359 L
s
% Start of user PostScript
-0.086796398 -0.49477615 0.0070861517 -0.43281358 MAarrowhead1
% End of user PostScript
.266 1 0 r
.62098 .51145 m
.61365 .53169 L
s
% Start of user PostScript
0.2419619 0.022901158 0.22730239 0.063373184 MAarrowhead1
% End of user PostScript
0 1 .049 r
.51682 .56158 m
.50487 .55497 L
s
% Start of user PostScript
0.033636896 0.12316814 0.0097445862 0.10993455 MAarrowhead1
% End of user PostScript
0 1 .364 r
.47102 .50029 m
.47222 .49497 L
s
% Start of user PostScript
-0.057966446 0.00057980858 -0.055559411 -0.010069537 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49439 .48483 m
.49739 .48619 L
s
% Start of user PostScript
-0.011225438 -0.030343575 -0.0052119716 -0.027618625 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50686 .49916 m
.50672 .50054 L
s
% Start of user PostScript
0.013726811 -0.0016770969 0.013437274 0.0010867681 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50173 .5037 m
.50098 .50343 L
s
% Start of user PostScript
0.0034621624 0.0073978424 0.0019646213 0.0068656141 MAarrowhead1
% End of user PostScript
0 .375 1 r
.4984 .50039 m
.49839 .50004 L
s
% Start of user PostScript
-0.0032099491 0.00078758891 -0.0032142632 0.000079119664 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49949 .49911 m
.49968 .49916 L
s
% Start of user PostScript
-0.0010160481 -0.0017844664 -0.00064697715 -0.0016890394 MAarrowhead1
% End of user PostScript
0 1 .338 r
.32053 0 m
.37041 .01858 L
.46371 .07065 L
.54349 .13152 L
.60872 .19737 L
.65913 .26474 L
.69508 .3307 L
.71746 .39285 L
.72756 .4493 L
.72693 .49872 L
.71732 .54025 L
.70057 .57351 L
.67849 .59849 L
.65281 .61552 L
.62515 .62519 L
.59692 .62831 L
.56935 .62579 L
.54343 .61865 L
.51994 .60791 L
.49942 .59458 L
.48221 .57961 L
.46848 .56386 L
.45822 .54808 L
.45127 .53291 L
.44739 .51886 L
.44624 .50632 L
.44742 .49553 L
.45051 .48665 L
.45509 .47974 L
.46072 .47474 L
.46703 .47156 L
.47364 .47002 L
.48024 .46993 L
.48657 .47106 L
.49243 .47316 L
.49764 .476 L
.50212 .47934 L
.50579 .48298 L
.50864 .48671 L
.51068 .49037 L
.51197 .49383 L
.51258 .49698 L
.51258 .49975 L
.51208 .50208 L
.51118 .50395 L
.50998 .50537 L
.50857 .50634 L
.50704 .50691 L
.50548 .5071 L
.50395 .50698 L
Mistroke
.5025 .50661 L
.50119 .50602 L
.50004 .50529 L
.49908 .50447 L
.4983 .5036 L
.49772 .50272 L
.49732 .50188 L
.4971 .5011 L
.49702 .5004 L
.49708 .49979 L
.49724 .49929 L
.49749 .4989 L
.4978 .49862 L
.49815 .49843 L
.49851 .49834 L
.49888 .49833 L
.49923 .49839 L
.49956 .4985 L
.49985 .49866 L
.5001 .49884 L
.50031 .49904 L
.50047 .49925 L
.50058 .49945 L
.50066 .49964 L
.5007 .49982 L
.5007 .49998 L
.50067 .50011 L
.50062 .50021 L
.50056 .50029 L
.50048 .50035 L
.5004 .50038 L
.50031 .50039 L
.50022 .50039 L
.50014 .50037 L
.50007 .50034 L
.50001 .5003 L
.49995 .50025 L
.49991 .5002 L
.49988 .50015 L
.49985 .50011 L
.49984 .50006 L
.49984 .50002 L
.49984 .49999 L
.49985 .49996 L
.49986 .49994 L
.49988 .49992 L
.4999 .49991 L
.49992 .49991 L
.49994 .49991 L
.49996 .49991 L
Mistroke
.49997 .49992 L
.49999 .49993 L
.5 .49994 L
.50002 .49995 L
.50003 .49996 L
.50003 .49997 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50003 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
7.1935904 2.7306203 6.3844088 3.6116698 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
5.4498249 4.2068434 4.4473451 4.5382357 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.1694252 2.2652799 -1.5313406 1.6962061 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.4030344 -0.92286625 -1.1741237 -1.0333579 MAarrowhead1
% End of user PostScript
.897 1 0 r
.60872 .19737 m
.65913 .26474 L
s
% Start of user PostScript
0.21744176 -0.60526965 0.31826231 -0.47052405 MAarrowhead1
% End of user PostScript
.581 1 0 r
.67849 .59849 m
.65281 .61552 L
s
% Start of user PostScript
0.35697749 0.19697464 0.30562612 0.23103406 MAarrowhead1
% End of user PostScript
.266 1 0 r
.48221 .57961 m
.46848 .56386 L
s
% Start of user PostScript
-0.035572323 0.15921635 -0.0630306 0.12771048 MAarrowhead1
% End of user PostScript
0 1 .049 r
.45509 .47974 m
.46072 .47474 L
s
% Start of user PostScript
-0.089828039 -0.04052365 -0.078553189 -0.050515481 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50212 .47934 m
.50579 .48298 L
s
% Start of user PostScript
0.004230479 -0.041311073 0.011571643 -0.03404699 MAarrowhead1
% End of user PostScript
0 1 .679 r
.51118 .50395 m
.50998 .50537 L
s
% Start of user PostScript
0.022365207 0.0079043939 0.01995602 0.010735608 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50004 .50529 m
.49908 .50447 L
s
% Start of user PostScript
0.000087522302 0.010586817 -0.0018445908 0.0089386578 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49724 .49929 m
.49749 .4989 L
s
% Start of user PostScript
-0.0055107672 -0.0014139486 -0.0050143532 -0.0021954456 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49985 .49866 m
.5001 .49884 L
s
% Start of user PostScript
-0.00030019744 -0.0026821638 0.0002013536 -0.0023152438 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50067 .50011 m
.50062 .50021 L
s
% Start of user PostScript
0.001343761 0.00021306995 0.0012467044 0.00042433555 MAarrowhead1
% End of user PostScript
1 .153 0 r
0 .06766 m
.02409 .05746 L
.12533 .04034 L
.22529 .04435 L
.32019 .06593 L
.40705 .10141 L
.48368 .14713 L
.54866 .19963 L
.60126 .2557 L
.64137 .31255 L
.66938 .36776 L
.68613 .4194 L
.69274 .46597 L
.69058 .50643 L
.68115 .54013 L
.66599 .56682 L
.64662 .58655 L
.6245 .59965 L
.60096 .60667 L
.57715 .60829 L
.55408 .60532 L
.53256 .59862 L
.51318 .58904 L
.49639 .57745 L
.48244 .56462 L
.47143 .55126 L
.46333 .538 L
.458 .52535 L
.45521 .51372 L
.45465 .5034 L
.45599 .49461 L
.45888 .48744 L
.46296 .48192 L
.46785 .47802 L
.47325 .47562 L
.47885 .47458 L
.4844 .47472 L
.48968 .47585 L
.49452 .47777 L
.49881 .48027 L
.50246 .48315 L
.50542 .48625 L
.50769 .4894 L
.50929 .49246 L
.51026 .49534 L
.51066 .49794 L
.51057 .50021 L
.51008 .5021 L
.50926 .50361 L
.5082 .50473 L
Mistroke
.50699 .50548 L
.50568 .50589 L
.50437 .506 L
.50308 .50585 L
.50188 .50549 L
.5008 .50497 L
.49986 .50434 L
.49908 .50363 L
.49846 .50289 L
.498 .50216 L
.49769 .50145 L
.49753 .5008 L
.49749 .50023 L
.49756 .49973 L
.49771 .49933 L
.49793 .49902 L
.4982 .4988 L
.4985 .49866 L
.49881 .49859 L
.49911 .4986 L
.49941 .49866 L
.49968 .49876 L
.49992 .4989 L
.50012 .49906 L
.50029 .49923 L
.50042 .4994 L
.50051 .49957 L
.50057 .49973 L
.50059 .49988 L
.50059 .5 L
.50056 .50011 L
.50052 .50019 L
.50046 .50026 L
.50039 .5003 L
.50032 .50032 L
.50025 .50033 L
.50018 .50032 L
.50011 .50031 L
.50005 .50028 L
.5 .50024 L
.49995 .5002 L
.49992 .50016 L
.49989 .50012 L
.49987 .50008 L
.49986 .50005 L
.49986 .50001 L
.49986 .49999 L
.49987 .49996 L
.49988 .49995 L
.4999 .49993 L
Mistroke
.49992 .49993 L
.49993 .49992 L
.49995 .49992 L
.49997 .49993 L
.49998 .49993 L
.49999 .49994 L
.50001 .49995 L
.50002 .49996 L
.50002 .49997 L
.50003 .49998 L
.50003 .49998 L
.50003 .49999 L
.50003 .5 L
.50003 .50001 L
.50003 .50001 L
.50003 .50001 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
6.7527548 -2.7833605 6.9670172 -1.1158848 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
6.8682724 0.32851334 6.5107201 1.5278863 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.1226883 3.540555 0.42913486 3.188519 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.636934 0.097993849 -1.5838275 -0.21556621 MAarrowhead1
% End of user PostScript
.897 1 0 r
.32019 .06593 m
.40705 .10141 L
s
% Start of user PostScript
-0.35961204 -0.86813572 -0.18589889 -0.79717777 MAarrowhead1
% End of user PostScript
.581 1 0 r
.69274 .46597 m
.69058 .50643 L
s
% Start of user PostScript
0.38548159 -0.068056402 0.38116833 0.012854065 MAarrowhead1
% End of user PostScript
.266 1 0 r
.55408 .60532 m
.53256 .59862 L
s
% Start of user PostScript
0.10816851 0.21063882 0.065113303 0.1972315 MAarrowhead1
% End of user PostScript
0 1 .049 r
.45521 .51372 m
.45465 .5034 L
s
% Start of user PostScript
-0.08958978 0.027432031 -0.09070294 0.0068019046 MAarrowhead1
% End of user PostScript
0 1 .364 r
.4844 .47472 m
.48968 .47585 L
s
% Start of user PostScript
-0.031203528 -0.050555978 -0.020642524 -0.048292796 MAarrowhead1
% End of user PostScript
0 1 .679 r
.51026 .49534 m
.51066 .49794 L
s
% Start of user PostScript
0.020514972 -0.0093206769 0.02132342 -0.0041189279 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50437 .506 m
.50308 .50585 L
s
% Start of user PostScript
0.0087318962 0.011995714 0.0061684584 0.011700611 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49769 .50145 m
.49753 .5008 L
s
% Start of user PostScript
-0.0046174606 0.0029049328 -0.0049464242 0.0016072775 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49881 .49859 m
.49911 .4986 L
s
% Start of user PostScript
-0.0023867098 -0.0028112383 -0.0017712056 -0.002804074 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50051 .49957 m
.50057 .49973 L
s
% Start of user PostScript
0.0010179839 -0.00085847889 0.0011302241 -0.0005381188 MAarrowhead1
% End of user PostScript
1 .052 0 r
.0419 1 m
.01783 .9584 L
s
.01783 .9584 m
0 .91285 L
s
0 .30432 m
.03624 .25939 L
.10017 .21274 L
.16982 .18507 L
.2415 .17443 L
.312 .17852 L
.37871 .19481 L
.43955 .22069 L
.49305 .25358 L
.53823 .29105 L
.57463 .33086 L
.60221 .37104 L
.62127 .40993 L
.63242 .44617 L
.63648 .47875 L
.63444 .50695 L
.62734 .53035 L
.6163 .54877 L
.60237 .56229 L
.58659 .57114 L
.56988 .57573 L
.55305 .57655 L
.53681 .57418 L
.5217 .56923 L
.50815 .5623 L
.49645 .55399 L
.48677 .54486 L
.47917 .5354 L
.47363 .52604 L
.47003 .51714 L
.46821 .50899 L
.46795 .50179 L
.46901 .49567 L
.47114 .4907 L
.47409 .48691 L
.47759 .48425 L
.48144 .48264 L
.4854 .48199 L
.48932 .48216 L
.49303 .48302 L
.49642 .48442 L
.49942 .48622 L
.50195 .48828 L
.504 .49047 L
.50556 .4927 L
.50665 .49486 L
.5073 .49688 L
.50755 .4987 L
.50746 .50028 L
.50709 .5016 L
Mistroke
.50649 .50264 L
.50573 .5034 L
.50486 .50391 L
.50394 .50418 L
.503 .50424 L
.5021 .50412 L
.50126 .50386 L
.5005 .50348 L
.49985 .50302 L
.4993 .50252 L
.49887 .502 L
.49856 .50148 L
.49835 .50098 L
.49824 .50053 L
.49822 .50013 L
.49828 .49978 L
.49839 .4995 L
.49855 .49929 L
.49874 .49914 L
.49896 .49904 L
.49918 .499 L
.49939 .49901 L
.4996 .49906 L
.49979 .49913 L
.49996 .49923 L
.5001 .49934 L
.50021 .49946 L
.5003 .49959 L
.50036 .49971 L
.5004 .49982 L
.50042 .49992 L
.50041 .50001 L
.50039 .50008 L
.50036 .50014 L
.50032 .50019 L
.50027 .50021 L
.50022 .50023 L
.50017 .50023 L
.50012 .50023 L
.50007 .50021 L
.50003 .50019 L
.49999 .50017 L
.49996 .50014 L
.49994 .50011 L
.49992 .50008 L
.49991 .50006 L
.4999 .50003 L
.4999 .50001 L
.4999 .49999 L
.49991 .49997 L
Mistroke
.49992 .49996 L
.49993 .49995 L
.49994 .49995 L
.49995 .49994 L
.49997 .49995 L
.49998 .49995 L
.49999 .49995 L
.5 .49996 L
.5 .49996 L
.50001 .49997 L
.50002 .49998 L
.50002 .49998 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
3.75205 -4.5549378 4.4190637 -3.1555533 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
4.802276 -1.8546405 4.9319247 -0.68841361 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.873189 2.7629207 1.2887449 2.6698169 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.0895215 0.59703713 -1.151041 0.30474196 MAarrowhead1
% End of user PostScript
.897 1 0 r
.2415 .17443 m
.312 .17852 L
s
% Start of user PostScript
-0.51700702 -0.65114272 -0.37599519 -0.64296153 MAarrowhead1
% End of user PostScript
.581 1 0 r
.62127 .40993 m
.63242 .44617 L
s
% Start of user PostScript
0.24253374 -0.18014818 0.26483355 -0.10765545 MAarrowhead1
% End of user PostScript
.266 1 0 r
.56988 .57573 m
.55305 .57655 L
s
% Start of user PostScript
0.13975444 0.15146184 0.10610879 0.15310949 MAarrowhead1
% End of user PostScript
0 1 .049 r
.47363 .52604 m
.47003 .51714 L
s
% Start of user PostScript
-0.052742345 0.052081638 -0.059942476 0.034288453 MAarrowhead1
% End of user PostScript
0 1 .364 r
.48144 .48264 m
.4854 .48199 L
s
% Start of user PostScript
-0.037129581 -0.034716874 -0.029196692 -0.036022771 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50556 .4927 m
.50665 .49486 L
s
% Start of user PostScript
0.011128896 -0.014598398 0.013305499 -0.010276676 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50486 .50391 m
.50394 .50418 L
s
% Start of user PostScript
0.0097186994 0.0078230064 0.0078725183 0.0083635354 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49887 .502 m
.49856 .50148 L
s
% Start of user PostScript
-0.0022529915 0.0039954381 -0.002883075 0.0029570429 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49874 .49914 m
.49896 .49904 L
s
% Start of user PostScript
-0.0025105091 -0.0017271273 -0.0020871023 -0.0019129195 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50021 .49946 m
.5003 .49959 L
s
% Start of user PostScript
0.00042865394 -0.0010725834 0.00060543731 -0.00082591165 MAarrowhead1
% End of user PostScript
.721 1 0 r
.7513 0 m
.82883 .11862 L
.88404 .23846 L
.91503 .34952 L
.92445 .44877 L
.91538 .53413 L
.89116 .60443 L
.85519 .65926 L
.81078 .69892 L
.76108 .72426 L
.70891 .73656 L
.65677 .73743 L
.60673 .72866 L
.56045 .71216 L
.51919 .68982 L
.48378 .66348 L
.45471 .63483 L
.43211 .60539 L
.41586 .57646 L
.40558 .54911 L
.40073 .52419 L
.40062 .50231 L
.40451 .48385 L
.41159 .46899 L
.42107 .45776 L
.43219 .45003 L
.44423 .44553 L
.45657 .44393 L
.46866 .44484 L
.48007 .4478 L
.49044 .45237 L
.49953 .45812 L
.50718 .46462 L
.51331 .47149 L
.51793 .47839 L
.52109 .48505 L
.5229 .49124 L
.5235 .49679 L
.52306 .50158 L
.52178 .50553 L
.51983 .50863 L
.5174 .51088 L
.51466 .51234 L
.51178 .51307 L
.50889 .51316 L
.5061 .51271 L
.50352 .51182 L
.50122 .51061 L
.49923 .50916 L
.4976 .50758 L
Mistroke
.49632 .50595 L
.4954 .50435 L
.4948 .50282 L
.49451 .50143 L
.49449 .50021 L
.49469 .49917 L
.49507 .49834 L
.49559 .4977 L
.4962 .49726 L
.49686 .497 L
.49755 .4969 L
.49822 .49694 L
.49885 .49709 L
.49943 .49734 L
.49994 .49766 L
.50037 .49801 L
.50072 .49839 L
.50098 .49878 L
.50116 .49915 L
.50126 .49949 L
.5013 .4998 L
.50128 .50007 L
.50121 .50029 L
.50111 .50047 L
.50097 .50059 L
.50082 .50068 L
.50066 .50072 L
.5005 .50073 L
.50035 .50071 L
.5002 .50066 L
.50008 .50059 L
.49996 .50051 L
.49987 .50043 L
.4998 .50034 L
.49975 .50025 L
.49971 .50016 L
.4997 .50008 L
.49969 .50002 L
.4997 .49996 L
.49973 .49991 L
.49975 .49987 L
.49979 .49985 L
.49982 .49983 L
.49986 .49983 L
.4999 .49983 L
.49993 .49984 L
.49997 .49985 L
.49999 .49987 L
.50002 .49989 L
.50004 .49991 L
Mistroke
.50005 .49993 L
.50006 .49995 L
.50007 .49997 L
.50007 .49999 L
.50007 .5 L
.50007 .50002 L
.50006 .50003 L
.50005 .50003 L
.50005 .50004 L
.50004 .50004 L
.50003 .50004 L
.50002 .50004 L
.50001 .50004 L
.5 .50003 L
.5 .50003 L
.49999 .50002 L
.49999 .50002 L
.49999 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
0.59333598 6.7925924 -0.66960918 5.8329631 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-1.7030199 4.7941371 -2.5024205 3.7303711 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.8238687 -1.5501128 -2.4191209 -1.8208057 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
0.2771897 -1.2605906 0.4947828 -1.0119549 MAarrowhead1
% End of user PostScript
.897 1 0 r
.85519 .65926 m
.81078 .69892 L
s
% Start of user PostScript
0.71037167 0.31851986 0.62156323 0.39784248 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48378 .66348 m
.45471 .63483 L
s
% Start of user PostScript
-0.032438994 0.32696163 -0.09058679 0.26965923 MAarrowhead1
% End of user PostScript
.266 1 0 r
.41159 .46899 m
.42107 .45776 L
s
% Start of user PostScript
-0.17681556 -0.062015426 -0.15785551 -0.084473252 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49953 .45812 m
.50718 .46462 L
s
% Start of user PostScript
-0.00094012643 -0.083763135 0.01435753 -0.070767967 MAarrowhead1
% End of user PostScript
0 1 .364 r
.52178 .50553 m
.51983 .50863 L
s
% Start of user PostScript
0.043554648 0.011057899 0.039652582 0.017252943 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50122 .51061 m
.49923 .50916 L
s
% Start of user PostScript
0.0024338788 0.021214803 -0.0015357584 0.018323444 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49469 .49917 m
.49507 .49834 L
s
% Start of user PostScript
-0.010617391 -0.0016542611 -0.0098558516 -0.0033281223 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49943 .49734 m
.49994 .49766 L
s
% Start of user PostScript
-0.0011369838 -0.0053151425 -0.00011958117 -0.0046867697 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50128 .50007 m
.50121 .50029 L
s
% Start of user PostScript
0.0025607326 0.0001392115 0.0024243773 0.00058375001 MAarrowhead1
% End of user PostScript
0 .06 1 r
.5002 .50066 m
.50008 .50059 L
s
% Start of user PostScript
0.00040984289 0.0013177363 0.00015206061 0.0011852566 MAarrowhead1
% End of user PostScript
0 1 .592 r
1 .99908 m
.99638 1 L
s
.766 1 m
.73859 .9956 L
.63798 .96116 L
.548 .9138 L
.47055 .8575 L
.40671 .79594 L
.35685 .73243 L
.32072 .66982 L
.29756 .61048 L
.28621 .55624 L
.28524 .50846 L
.293 .46801 L
.3078 .43534 L
.32791 .41049 L
.35168 .39322 L
.37755 .38299 L
.40418 .37908 L
.43035 .38063 L
.45512 .38671 L
.4777 .39634 L
.49754 .40857 L
.5143 .4225 L
.5278 .43728 L
.53802 .45221 L
.54508 .46664 L
.5492 .4801 L
.55069 .49219 L
.54992 .50265 L
.54727 .51132 L
.54316 .51815 L
.53798 .52316 L
.53212 .52644 L
.52591 .52813 L
.51966 .52843 L
.51363 .52754 L
.50802 .5257 L
.503 .52312 L
.49865 .52003 L
.49506 .51664 L
.49225 .51312 L
.49019 .50965 L
.48886 .50635 L
.48819 .50332 L
.4881 .50065 L
.48849 .49838 L
.48929 .49654 L
.49038 .49513 L
.49169 .49414 L
.49312 .49355 L
.49459 .49331 L
Mistroke
.49604 .49338 L
.49742 .4937 L
.49868 .49422 L
.49979 .49489 L
.50073 .49565 L
.50149 .49647 L
.50207 .49729 L
.50247 .4981 L
.50271 .49885 L
.5028 .49952 L
.50277 .50011 L
.50263 .5006 L
.50241 .50098 L
.50213 .50127 L
.5018 .50145 L
.50146 .50155 L
.50111 .50158 L
.50078 .50153 L
.50047 .50143 L
.50018 .50129 L
.49994 .50112 L
.49974 .50093 L
.49958 .50074 L
.49946 .50055 L
.49939 .50036 L
.49935 .5002 L
.49934 .50005 L
.49936 .49992 L
.4994 .49981 L
.49946 .49974 L
.49953 .49968 L
.49961 .49964 L
.49969 .49963 L
.49978 .49963 L
.49985 .49965 L
.49992 .49968 L
.49998 .49971 L
.50004 .49976 L
.50008 .4998 L
.50011 .49985 L
.50014 .49989 L
.50015 .49993 L
.50016 .49997 L
.50015 .5 L
.50015 .50003 L
.50013 .50005 L
.50012 .50007 L
.5001 .50008 L
.50008 .50009 L
.50006 .50009 L
Mistroke
.50004 .50009 L
.50003 .50008 L
.50001 .50007 L
.5 .50006 L
.49999 .50005 L
.49998 .50004 L
.49997 .50003 L
.49997 .50002 L
.49996 .50001 L
.49996 .5 L
.49996 .5 L
.49997 .49999 L
.49997 .49999 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-0.041090977 -3.2681082 0.55595464 -2.7618913 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
1.0349163 -2.2264967 1.395598 -1.688019 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.3574403 0.84729345 1.144271 0.96135948 MAarrowhead1
% End of user PostScript
1 .788 0 r
.40671 .79594 m
.35685 .73243 L
s
% Start of user PostScript
-0.18657742 0.59188499 -0.28629791 0.46486501 MAarrowhead1
% End of user PostScript
.897 1 0 r
.32791 .41049 m
.35168 .39322 L
s
% Start of user PostScript
-0.34417368 -0.17901533 -0.29664848 -0.21356557 MAarrowhead1
% End of user PostScript
.581 1 0 r
.5143 .4225 m
.5278 .43728 L
s
% Start of user PostScript
0.028608609 -0.15500774 0.055602168 -0.1254318 MAarrowhead1
% End of user PostScript
.266 1 0 r
.54316 .51815 m
.53798 .52316 L
s
% Start of user PostScript
0.086318586 0.036307717 0.075963764 0.04632301 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49865 .52003 m
.49506 .51664 L
s
% Start of user PostScript
-0.0026906801 0.040060093 -0.0098707315 0.033273111 MAarrowhead1
% End of user PostScript
0 1 .364 r
.48929 .49654 m
.49038 .49513 L
s
% Start of user PostScript
-0.021421937 -0.0069280049 -0.01923148 -0.0097408836 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49979 .49489 m
.50073 .49565 L
s
% Start of user PostScript
-0.00041954196 -0.010228965 0.0014617826 -0.0086975301 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50263 .5006 m
.50241 .50098 L
s
% Start of user PostScript
0.0052613734 0.0011912665 0.0048163298 0.0019623405 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50018 .50129 m
.49994 .50112 L
s
% Start of user PostScript
0.00036946357 0.0025826601 -0.00011696597 0.002243997 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49936 .49992 m
.4994 .49981 L
s
% Start of user PostScript
-0.0012787593 -0.00016318794 -0.0011936059 -0.00037045466 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49992 .49968 m
.49998 .49971 L
s
% Start of user PostScript
-0.00015576042 -0.00064512663 -0.000031503164 -0.00057209238 MAarrowhead1
% End of user PostScript
0 .145 1 r
.38019 0 m
.45655 .04182 L
.54189 .10592 L
.61185 .1755 L
.66611 .24688 L
.70501 .31692 L
.72947 .38304 L
.74083 .44322 L
.74073 .49601 L
.73102 .54049 L
.71364 .5762 L
.6905 .60314 L
.66345 .62162 L
.63422 .63228 L
.6043 .63593 L
.57502 .63356 L
.54744 .62623 L
.5224 .61503 L
.50047 .60103 L
.48205 .58524 L
.4673 .56857 L
.45623 .55183 L
.44869 .53571 L
.44441 .52075 L
.44303 .50737 L
.44416 .49583 L
.44734 .48632 L
.45212 .47888 L
.45804 .47348 L
.46469 .47 L
.47168 .46829 L
.47869 .46811 L
.48542 .46924 L
.49165 .47142 L
.49722 .47439 L
.50201 .47791 L
.50594 .48175 L
.50901 .4857 L
.51122 .48959 L
.51263 .49327 L
.51331 .49663 L
.51335 .49958 L
.51284 .50208 L
.51191 .50409 L
.51065 .50562 L
.50916 .50667 L
.50755 .50729 L
.50589 .50752 L
.50427 .50741 L
.50273 .50703 L
Mistroke
.50133 .50642 L
.50011 .50565 L
.49907 .50478 L
.49824 .50386 L
.49761 .50294 L
.49718 .50204 L
.49693 .50121 L
.49685 .50046 L
.4969 .49981 L
.49707 .49928 L
.49733 .49886 L
.49765 .49855 L
.49802 .49835 L
.4984 .49825 L
.49879 .49823 L
.49917 .49829 L
.49951 .49841 L
.49983 .49857 L
.50009 .49876 L
.50031 .49897 L
.50049 .49919 L
.50061 .49941 L
.5007 .49961 L
.50074 .4998 L
.50074 .49997 L
.50071 .50011 L
.50066 .50022 L
.5006 .50031 L
.50051 .50037 L
.50042 .5004 L
.50033 .50042 L
.50024 .50041 L
.50016 .50039 L
.50008 .50036 L
.50001 .50032 L
.49995 .50027 L
.49991 .50022 L
.49987 .50017 L
.49985 .50012 L
.49983 .50007 L
.49983 .50003 L
.49983 .49999 L
.49984 .49996 L
.49985 .49994 L
.49987 .49992 L
.49989 .49991 L
.49991 .4999 L
.49993 .4999 L
.49995 .49991 L
.49997 .49991 L
Mistroke
.49999 .49992 L
.5 .49993 L
.50002 .49994 L
.50003 .49995 L
.50003 .49997 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50004 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
6.1204167 -8.958254 7.4868051 -6.4353467 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
8.3344343 -4.0601268 8.7126911 -1.9038686 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.69022 4.9110996 2.6357373 4.811292 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.8686752 1.2495115 -2.0152649 0.71273868 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-1.004474 -1.1478891 -0.75185307 -1.1504152 MAarrowhead1
% End of user PostScript
.581 1 0 r
.70501 .31692 m
.72947 .38304 L
s
% Start of user PostScript
0.41002518 -0.366161 0.45894584 -0.23392216 MAarrowhead1
% End of user PostScript
.266 1 0 r
.63422 .63228 m
.6043 .63593 L
s
% Start of user PostScript
0.26843039 0.26455352 0.20860818 0.2718622 MAarrowhead1
% End of user PostScript
0 1 .049 r
.45623 .55183 m
.44869 .53571 L
s
% Start of user PostScript
-0.087539596 0.10366955 -0.10262779 0.071429371 MAarrowhead1
% End of user PostScript
0 1 .364 r
.46469 .47 m
.47168 .46829 L
s
% Start of user PostScript
-0.070619967 -0.059996744 -0.056630824 -0.06342905 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50901 .4857 m
.51122 .48959 L
s
% Start of user PostScript
0.018016577 -0.028597927 0.022444546 -0.020821127 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50916 .50667 m
.50755 .50729 L
s
% Start of user PostScript
0.018325556 0.013349154 0.015099746 0.014588731 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49824 .50386 m
.49761 .50294 L
s
% Start of user PostScript
-0.0035163253 0.0077270717 -0.0047713402 0.0058720074 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49765 .49855 m
.49802 .49835 L
s
% Start of user PostScript
-0.0046968057 -0.0029011937 -0.0039647821 -0.0033006585 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50031 .49897 m
.50049 .49919 L
s
% Start of user PostScript
0.00062965289 -0.0020521517 0.00097614559 -0.0016148947 MAarrowhead1
% End of user PostScript
1 0 .654 r
.64754 1 m
.59495 .97672 L
.504 .91908 L
.42749 .85394 L
.36617 .7851 L
.32004 .71591 L
.28852 .64919 L
.27051 .58722 L
.26457 .53171 L
.269 .48384 L
.28196 .44431 L
.30155 .41335 L
.32594 .39082 L
.35337 .37628 L
.38226 .36902 L
.41122 .36816 L
.43908 .37271 L
.46491 .38162 L
.48799 .39384 L
.50785 .40834 L
.5242 .42418 L
.53696 .4405 L
.5462 .45659 L
.5521 .47183 L
.55498 .48574 L
.55519 .498 L
.55316 .50837 L
.54933 .51673 L
.54415 .52309 L
.53803 .5275 L
.53137 .53011 L
.52453 .53109 L
.5178 .53067 L
.51144 .52909 L
.50565 .5266 L
.50056 .52345 L
.49626 .51987 L
.49281 .51606 L
.49019 .51223 L
.48839 .50852 L
.48734 .50507 L
.48697 .50196 L
.48718 .49928 L
.48786 .49706 L
.48892 .49531 L
.49026 .49403 L
.49177 .49319 L
.49336 .49276 L
.49497 .49269 L
.49652 .49293 L
Mistroke
.49796 .4934 L
.49925 .49407 L
.50036 .49486 L
.50128 .49574 L
.502 .49664 L
.50253 .49753 L
.50287 .49838 L
.50304 .49916 L
.50306 .49984 L
.50296 .50043 L
.50275 .5009 L
.50247 .50126 L
.50213 .50151 L
.50176 .50166 L
.50139 .50172 L
.50101 .5017 L
.50066 .50162 L
.50033 .50148 L
.50005 .50131 L
.49981 .50111 L
.49961 .5009 L
.49947 .50069 L
.49936 .50049 L
.4993 .50029 L
.49928 .50012 L
.49929 .49997 L
.49932 .49985 L
.49938 .49975 L
.49945 .49967 L
.49954 .49963 L
.49963 .4996 L
.49972 .4996 L
.4998 .49961 L
.49988 .49963 L
.49995 .49967 L
.50002 .49971 L
.50007 .49976 L
.50011 .49981 L
.50014 .49986 L
.50016 .49991 L
.50017 .49995 L
.50017 .49999 L
.50016 .50002 L
.50015 .50005 L
.50014 .50007 L
.50012 .50008 L
.5001 .50009 L
.50008 .5001 L
.50006 .50009 L
.50004 .50009 L
Mistroke
.50002 .50008 L
.5 .50007 L
.49999 .50006 L
.49998 .50005 L
.49997 .50004 L
.49997 .50003 L
.49996 .50002 L
.49996 .50001 L
.49996 .5 L
.49996 .49999 L
.49997 .49999 L
.49997 .49998 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
1.3636011 -2.1067387 1.6882224 -1.5272175 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
1.8932165 -0.97966142 1.989591 -0.48083524 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
0.86821263 1.1234967 0.62594109 1.1050378 MAarrowhead1
% End of user PostScript
1 .788 0 r
.28852 .64919 m
.27051 .58722 L
s
% Start of user PostScript
-0.42296613 0.29838355 -0.45898062 0.17444128 MAarrowhead1
% End of user PostScript
.897 1 0 r
.38226 .36902 m
.41122 .36816 L
s
% Start of user PostScript
-0.23548302 -0.26196512 -0.17756043 -0.26367951 MAarrowhead1
% End of user PostScript
.581 1 0 r
.5462 .45659 m
.5521 .47183 L
s
% Start of user PostScript
0.092396555 -0.086824973 0.10420608 -0.056347863 MAarrowhead1
% End of user PostScript
.266 1 0 r
.53137 .53011 m
.52453 .53109 L
s
% Start of user PostScript
0.062740806 0.060210085 0.049054339 0.062173719 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49019 .51223 m
.48839 .50852 L
s
% Start of user PostScript
-0.019612645 0.024454891 -0.023216803 0.017038606 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49177 .49319 m
.49336 .49276 L
s
% Start of user PostScript
-0.016463273 -0.013611228 -0.013270452 -0.014470408 MAarrowhead1
% End of user PostScript
0 1 .679 r
.502 .49664 m
.50253 .49753 L
s
% Start of user PostScript
0.0040040645 -0.0067186616 0.0050542624 -0.0049332669 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50213 .50151 m
.50176 .50166 L
s
% Start of user PostScript
0.0042622316 0.0030168037 0.0035279877 0.0033189414 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49961 .5009 m
.49947 .50069 L
s
% Start of user PostScript
-0.00077189921 0.0018093259 -0.0010679969 0.0013843285 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49945 .49967 m
.49954 .49963 L
s
% Start of user PostScript
-0.0010900793 -0.0006524583 -0.00092398711 -0.00074845167 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50007 .49976 m
.50011 .49981 L
s
% Start of user PostScript
0.00013523551 -0.00047916141 0.00021664963 -0.0003792116 MAarrowhead1
% End of user PostScript
0 .012 1 r
0 .12308 m
.00583 .11935 L
.09659 .08917 L
.1889 .08027 L
.27884 .08958 L
.36318 .11381 L
.43945 .14959 L
.5059 .19364 L
.56145 .24287 L
.60562 .29448 L
.63847 .34602 L
.66052 .39545 L
.6726 .44112 L
.67584 .48181 L
.67153 .5167 L
.66106 .54532 L
.64582 .56753 L
.6272 .58348 L
.60648 .59352 L
.58483 .59822 L
.56326 .59823 L
.54263 .59431 L
.5236 .58725 L
.50669 .57784 L
.49222 .56682 L
.48039 .5549 L
.47124 .5427 L
.46471 .53075 L
.46064 .51949 L
.45879 .50925 L
.45889 .50029 L
.46062 .49276 L
.46365 .48673 L
.46764 .48219 L
.47229 .4791 L
.4773 .47733 L
.48241 .47676 L
.4874 .47721 L
.4921 .4785 L
.49636 .48044 L
.50008 .48285 L
.5032 .48556 L
.50569 .48841 L
.50756 .49127 L
.50882 .49402 L
.50952 .49657 L
.50974 .49884 L
.50953 .5008 L
.50897 .50241 L
.50814 .50366 L
Mistroke
.50712 .50457 L
.50598 .50515 L
.50478 .50543 L
.50359 .50545 L
.50244 .50524 L
.50138 .50486 L
.50043 .50435 L
.49962 .50375 L
.49896 .50309 L
.49844 .50241 L
.49807 .50175 L
.49783 .50112 L
.49772 .50055 L
.49772 .50005 L
.49781 .49963 L
.49797 .49929 L
.49819 .49903 L
.49845 .49885 L
.49872 .49875 L
.49901 .49871 L
.49928 .49873 L
.49954 .4988 L
.49978 .49891 L
.49999 .49904 L
.50017 .49919 L
.50031 .49935 L
.50041 .49951 L
.50048 .49966 L
.50053 .4998 L
.50054 .49993 L
.50053 .50004 L
.5005 .50013 L
.50045 .5002 L
.5004 .50025 L
.50034 .50028 L
.50027 .5003 L
.5002 .5003 L
.50014 .50029 L
.50008 .50027 L
.50003 .50024 L
.49998 .50021 L
.49994 .50017 L
.49992 .50014 L
.49989 .5001 L
.49988 .50006 L
.49987 .50003 L
.49987 .5 L
.49988 .49998 L
.49989 .49996 L
.4999 .49995 L
Mistroke
.49991 .49994 L
.49993 .49993 L
.49994 .49993 L
.49996 .49993 L
.49997 .49993 L
.49999 .49994 L
.5 .49995 L
.50001 .49995 L
.50002 .49996 L
.50002 .49997 L
.50003 .49998 L
.50003 .49999 L
.50003 .5 L
.50003 .5 L
.50003 .50001 L
.50003 .50001 L
.50002 .50001 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
2.3489096 -9.155572 3.9147199 -7.2886043 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
5.0726019 -5.429896 5.8417421 -3.6524503 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.790728 3.3969883 3.007674 3.553485 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.0592357 1.5107416 -1.2884932 1.0803411 MAarrowhead1
% End of user PostScript
.897 1 0 r
.00583 .11935 m
.09659 .08917 L
s
% Start of user PostScript
-0.98833511 -0.76130657 -0.80682723 -0.82165846 MAarrowhead1
% End of user PostScript
.581 1 0 r
.60562 .29448 m
.63847 .34602 L
s
% Start of user PostScript
0.21123581 -0.41103462 0.27694673 -0.30795045 MAarrowhead1
% End of user PostScript
.266 1 0 r
.6272 .58348 m
.60648 .59352 L
s
% Start of user PostScript
0.25440015 0.1669547 0.21296309 0.18704905 MAarrowhead1
% End of user PostScript
0 1 .049 r
.48039 .5549 m
.47124 .5427 L
s
% Start of user PostScript
-0.039228086 0.10980083 -0.057527184 0.085396517 MAarrowhead1
% End of user PostScript
0 1 .364 r
.46764 .48219 m
.47229 .4791 L
s
% Start of user PostScript
-0.064717607 -0.035619185 -0.055424524 -0.041808229 MAarrowhead1
% End of user PostScript
0 1 .679 r
.5032 .48556 m
.50569 .48841 L
s
% Start of user PostScript
0.0064015183 -0.028877394 0.011383862 -0.023172272 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50814 .50366 m
.50712 .50457 L
s
% Start of user PostScript
0.016282815 0.0073235926 0.014243067 0.0091382331 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49962 .50375 m
.49896 .50309 L
s
% Start of user PostScript
-0.00075536446 0.0074913456 -0.0020871215 0.006176225 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49797 .49929 m
.49819 .49903 L
s
% Start of user PostScript
-0.0040534827 -0.0014272264 -0.0036178184 -0.0019412014 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49999 .49904 m
.50017 .49919 L
s
% Start of user PostScript
-0.000018666379 -0.0019195011 0.00033176728 -0.0016211821 MAarrowhead1
% End of user PostScript
1 0 .043 r
.18771 1 m
.16702 .9717 L
.09553 .83691 L
.0517 .71028 L
.03283 .59557 L
.03567 .49546 L
.05663 .4116 L
.09195 .34474 L
.13792 .29482 L
.19098 .26112 L
.24789 .24238 L
.30574 .23696 L
.36207 .24292 L
.41488 .25821 L
.46261 .28071 L
.50417 .30837 L
.5389 .33925 L
.56649 .3716 L
.58699 .40389 L
.60073 .43485 L
.60823 .46343 L
.6102 .4889 L
.60744 .51071 L
.60084 .5286 L
.59126 .54247 L
.57956 .55242 L
.56657 .55867 L
.553 .56157 L
.53948 .56155 L
.52656 .55906 L
.51465 .55462 L
.50407 .5487 L
.49502 .54179 L
.48763 .53431 L
.48191 .52667 L
.47784 .51918 L
.47531 .51213 L
.47417 .50572 L
.47425 .50012 L
.47534 .49541 L
.47725 .49164 L
.47975 .48881 L
.48267 .48688 L
.48581 .48579 L
.48901 .48544 L
.49214 .48572 L
.49508 .48654 L
.49775 .48776 L
.50008 .48927 L
.50203 .49097 L
Mistroke
.50358 .49276 L
.50475 .49455 L
.50553 .49627 L
.50597 .49787 L
.5061 .49929 L
.50597 .50051 L
.50562 .50152 L
.5051 .5023 L
.50445 .50287 L
.50374 .50323 L
.50299 .5034 L
.50224 .50341 L
.50152 .50328 L
.50086 .50304 L
.50026 .50272 L
.49976 .50234 L
.49934 .50193 L
.49902 .50151 L
.49879 .50109 L
.49864 .5007 L
.49857 .50034 L
.49857 .50003 L
.49863 .49976 L
.49873 .49955 L
.49887 .49939 L
.49903 .49928 L
.4992 .49922 L
.49938 .49919 L
.49955 .49921 L
.49972 .49925 L
.49987 .49932 L
.5 .4994 L
.50011 .49949 L
.50019 .49959 L
.50026 .49969 L
.5003 .49979 L
.50033 .49988 L
.50034 .49996 L
.50033 .50002 L
.50031 .50008 L
.50028 .50012 L
.50025 .50016 L
.50021 .50018 L
.50017 .50019 L
.50013 .50019 L
.50009 .50018 L
.50005 .50017 L
.50002 .50015 L
.49999 .50013 L
.49997 .50011 L
Mistroke
.49995 .50009 L
.49993 .50006 L
.49993 .50004 L
.49992 .50002 L
.49992 .5 L
.49992 .49999 L
.49993 .49998 L
.49994 .49997 L
.49995 .49996 L
.49996 .49996 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49999 .49996 L
.5 .49997 L
.50001 .49997 L
.50001 .49998 L
.50001 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-1.2344159 -7.8549641 0.24982191 -6.8451132 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
1.4857854 -5.7236527 2.4639076 -4.5533476 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.2682245 1.5648528 2.8415307 1.9141652 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.20115449 1.4905516 -0.46392933 1.2196185 MAarrowhead1
% End of user PostScript
.897 1 0 r
.09195 .34474 m
.13792 .29482 L
s
% Start of user PostScript
-0.81610426 -0.31052829 -0.72416829 -0.41036557 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50417 .30837 m
.5389 .33925 L
s
% Start of user PostScript
0.0083432889 -0.38326526 0.077790887 -0.32150159 MAarrowhead1
% End of user PostScript
.266 1 0 r
.60084 .5286 m
.59126 .54247 L
s
% Start of user PostScript
0.20167065 0.057198114 0.18251067 0.084940348 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50407 .5487 m
.49502 .54179 L
s
% Start of user PostScript
0.0081386843 0.097403885 -0.0099555777 0.08357575 MAarrowhead1
% End of user PostScript
0 1 .364 r
.47534 .49541 m
.47725 .49164 L
s
% Start of user PostScript
-0.049319894 -0.009180312 -0.045509914 -0.016720589 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49775 .48776 m
.50008 .48927 L
s
% Start of user PostScript
-0.004500502 -0.024483643 0.00015411393 -0.02145489 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50597 .50051 m
.50562 .50152 L
s
% Start of user PostScript
0.011934599 0.0010259871 0.011230398 0.0030385249 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50086 .50304 m
.50026 .50272 L
s
% Start of user PostScript
0.0017132025 0.0060894641 0.00052978519 0.0054443332 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49857 .50003 m
.49863 .49976 L
s
% Start of user PostScript
-0.0028564193 0.000054867301 -0.0027425971 -0.0004740351 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49972 .49925 m
.49987 .49932 L
s
% Start of user PostScript
-0.00056688606 -0.0014988694 -0.00026930431 -0.0013665224 MAarrowhead1
% End of user PostScript
1 .607 0 r
.82778 0 m
.8656 .05636 L
.93056 .19269 L
.96787 .31942 L
.98049 .43302 L
.97186 .53107 L
.94575 .61213 L
.906 .67569 L
.8564 .72203 L
.80051 .75204 L
.74158 .76716 L
.68244 .76917 L
.62551 .76009 L
.57269 .74207 L
.52545 .71726 L
.48478 .68774 L
.45124 .65546 L
.42504 .62214 L
.40604 .58929 L
.39385 .55814 L
.38786 .52967 L
.38732 .50458 L
.39137 .48333 L
.39911 .46617 L
.40965 .45311 L
.4221 .44402 L
.43568 .43863 L
.44964 .43656 L
.46338 .43736 L
.47638 .44054 L
.48823 .44558 L
.49865 .45199 L
.50746 .45929 L
.51455 .46705 L
.51992 .47488 L
.52363 .48246 L
.5258 .48952 L
.52659 .49586 L
.52619 .50136 L
.52481 .50592 L
.52266 .50951 L
.51994 .51214 L
.51687 .51386 L
.51361 .51476 L
.51033 .51492 L
.50717 .51445 L
.50423 .51349 L
.50159 .51214 L
.49931 .51052 L
.49742 .50874 L
Mistroke
.49594 .5069 L
.49486 .50507 L
.49416 .50334 L
.4938 .50175 L
.49375 .50035 L
.49396 .49915 L
.49438 .49819 L
.49495 .49745 L
.49563 .49693 L
.49638 .49662 L
.49716 .49649 L
.49792 .49652 L
.49864 .49669 L
.4993 .49696 L
.49989 .49731 L
.50038 .49772 L
.50078 .49814 L
.50108 .49858 L
.5013 .499 L
.50142 .49939 L
.50147 .49975 L
.50145 .50005 L
.50138 .50031 L
.50126 .50051 L
.50112 .50066 L
.50095 .50076 L
.50077 .50081 L
.50059 .50083 L
.50041 .5008 L
.50025 .50075 L
.5001 .50068 L
.49997 .50059 L
.49986 .50049 L
.49978 .50039 L
.49972 .50029 L
.49968 .50019 L
.49966 .5001 L
.49965 .50002 L
.49966 .49996 L
.49969 .4999 L
.49972 .49986 L
.49976 .49983 L
.4998 .49981 L
.49984 .49981 L
.49988 .49981 L
.49992 .49982 L
.49996 .49983 L
.49999 .49985 L
.50002 .49987 L
.50004 .4999 L
Mistroke
.50006 .49992 L
.50007 .49994 L
.50008 .49996 L
.50008 .49998 L
.50008 .5 L
.50008 .50002 L
.50007 .50003 L
.50006 .50004 L
.50005 .50004 L
.50004 .50004 L
.50003 .50005 L
.50002 .50004 L
.50001 .50004 L
.50001 .50004 L
.5 .50003 L
.49999 .50003 L
.49999 .50002 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
4.3903142 9.358486 2.4954226 8.6871284 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
0.80495129 7.7761568 -0.64631647 6.7004691 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-3.9081662 -0.65187096 -3.6200268 -1.2612527 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.39608856 -1.9505341 -0.023642514 -1.7160821 MAarrowhead1
% End of user PostScript
.897 1 0 r
.97186 .53107 m
.94575 .61213 L
s
% Start of user PostScript
0.94371637 0.062133823 0.89149229 0.22425899 MAarrowhead1
% End of user PostScript
.581 1 0 r
.57269 .74207 m
.52545 .71726 L
s
% Start of user PostScript
0.14538688 0.48413717 0.050902456 0.43451877 MAarrowhead1
% End of user PostScript
.266 1 0 r
.38732 .50458 m
.39137 .48333 L
s
% Start of user PostScript
-0.22536709 0.0091551126 -0.21726575 -0.03333308 MAarrowhead1
% End of user PostScript
0 1 .049 r
.47638 .44054 m
.48823 .44558 L
s
% Start of user PostScript
-0.047246127 -0.11892389 -0.023536966 -0.10883627 MAarrowhead1
% End of user PostScript
0 1 .364 r
.52659 .49586 m
.52619 .50136 L
s
% Start of user PostScript
0.053186158 -0.0082702059 0.052387087 0.0027172657 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50717 .51445 m
.50423 .51349 L
s
% Start of user PostScript
0.01433975 0.028908143 0.0084527434 0.026976074 MAarrowhead1
% End of user PostScript
0 1 .995 r
.4938 .50175 m
.49375 .50035 L
s
% Start of user PostScript
-0.012390553 0.0035009526 -0.012491141 0.00069379343 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49792 .49652 m
.49864 .49669 L
s
% Start of user PostScript
-0.0041625834 -0.0069516583 -0.002715951 -0.006617141 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50142 .49939 m
.50147 .49975 L
s
% Start of user PostScript
0.0028450198 -0.0012147879 0.0029429637 -0.00050563838 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50059 .50083 m
.50041 .5008 L
s
% Start of user PostScript
0.0011703196 0.0016528403 0.00081853634 0.0016062027 MAarrowhead1
% End of user PostScript
.617 1 0 r
.91093 0 m
.9535 .07419 L
s
.9535 .07419 m
1 .19428 L
s
1 .62959 m
.98409 .66434 L
.93317 .72668 L
.87311 .76995 L
.80777 .79547 L
.74061 .80509 L
.67461 .80096 L
.61222 .78545 L
.55536 .76103 L
.50542 .73008 L
.46328 .6949 L
.42937 .65758 L
.40373 .61994 L
.38606 .58355 L
.37578 .54967 L
.37211 .51923 L
.37415 .49292 L
.3809 .47111 L
.39132 .45396 L
.40442 .4414 L
.41924 .4332 L
.43491 .42899 L
.45066 .4283 L
.46586 .43058 L
.47998 .43527 L
.49264 .4418 L
.50356 .44961 L
.51259 .45818 L
.51966 .46705 L
.52481 .47581 L
.52814 .48413 L
.52981 .49175 L
.53002 .49847 L
.529 .50418 L
.52698 .50881 L
.52421 .51234 L
.52091 .51481 L
.51731 .51629 L
.51359 .51688 L
.50993 .5167 L
.50645 .51588 L
.50328 .51456 L
.50049 .51287 L
.49812 .51094 L
.49621 .50888 L
.49476 .50679 L
.49375 .50477 L
.49315 .50288 L
.49292 .50118 L
.49302 .4997 L
Mistroke
.49337 .49848 L
.49394 .49751 L
.49465 .4968 L
.49547 .49633 L
.49633 .49608 L
.49721 .49603 L
.49805 .49614 L
.49884 .49639 L
.49955 .49675 L
.50016 .49718 L
.50066 .49765 L
.50106 .49814 L
.50136 .49863 L
.50155 .49909 L
.50165 .49951 L
.50166 .49989 L
.50161 .50021 L
.5015 .50047 L
.50135 .50067 L
.50117 .50081 L
.50097 .5009 L
.50077 .50093 L
.50056 .50093 L
.50037 .50088 L
.50019 .50081 L
.50004 .50072 L
.4999 .50061 L
.4998 .5005 L
.49971 .50038 L
.49966 .50027 L
.49962 .50017 L
.49961 .50007 L
.49961 .49999 L
.49963 .49992 L
.49966 .49987 L
.4997 .49983 L
.49975 .4998 L
.49979 .49978 L
.49984 .49978 L
.49989 .49979 L
.49993 .4998 L
.49997 .49982 L
.50001 .49984 L
.50003 .49987 L
.50006 .4999 L
.50007 .49992 L
.50009 .49995 L
.50009 .49997 L
.50009 .49999 L
.50009 .50001 L
Mistroke
.50008 .50003 L
.50008 .50004 L
.50007 .50004 L
.50005 .50005 L
.50004 .50005 L
.50003 .50005 L
.50002 .50005 L
.50001 .50005 L
.5 .50004 L
.5 .50003 L
.49999 .50003 L
.49998 .50002 L
.49998 .50002 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-2.6283851 5.5937852 -3.533325 4.2357765 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-4.1516866 2.926399 -4.5047498 1.7102071 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.3101504 -2.5710225 -1.7417185 -2.5876721 MAarrowhead1
% End of user PostScript
1 .788 0 r
.9535 .07419 m
0 0 rlineto s
.9535 .07419 m
1 .19428 L
s
% Start of user PostScript
0.90699616 -0.8516275 1.0227994 -0.55256004 MAarrowhead1
% End of user PostScript
.897 1 0 r
.80777 .79547 m
.74061 .80509 L
s
% Start of user PostScript
0.6155322 0.59094955 0.48121344 0.61017561 MAarrowhead1
% End of user PostScript
.581 1 0 r
.40373 .61994 m
.38606 .58355 L
s
% Start of user PostScript
-0.19254227 0.23988613 -0.22788992 0.16710903 MAarrowhead1
% End of user PostScript
.266 1 0 r
.41924 .4332 m
.43491 .42899 L
s
% Start of user PostScript
-0.16152297 -0.13359814 -0.13018749 -0.14201871 MAarrowhead1
% End of user PostScript
0 1 .049 r
.51966 .46705 m
.52481 .47581 L
s
% Start of user PostScript
0.039314022 -0.065909678 0.049614911 -0.048388797 MAarrowhead1
% End of user PostScript
0 1 .364 r
.52091 .51481 m
.51731 .51629 L
s
% Start of user PostScript
0.041818722 0.029612619 0.034612282 0.032574931 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49621 .50888 m
.49476 .50679 L
s
% Start of user PostScript
-0.0075804374 0.017750288 -0.01048495 0.013579462 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49465 .4968 m
.49547 .49633 L
s
% Start of user PostScript
-0.010695624 -0.0064049586 -0.0090653843 -0.0073463254 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50066 .49765 m
.50106 .49814 L
s
% Start of user PostScript
0.0013285609 -0.0047009907 0.002127227 -0.0037200714 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50135 .50067 m
.50117 .50081 L
s
% Start of user PostScript
0.002704678 0.0013417695 0.0023430451 0.0016235013 MAarrowhead1
% End of user PostScript
0 .06 1 r
.4999 .50061 m
.4998 .5005 L
s
% Start of user PostScript
-0.00019087532 0.0012270875 -0.00040610748 0.00099943967 MAarrowhead1
% End of user PostScript
1 0 .225 r
1 .97129 m
.91056 .98863 L
.80376 .9866 L
.70196 .96544 L
.60843 .92907 L
.52558 .88137 L
.45501 .82609 L
.39756 .76663 L
.35344 .70606 L
.32226 .64698 L
.30319 .5915 L
.29505 .54127 L
.29642 .49745 L
.30571 .46077 L
.32128 .43155 L
.34149 .40976 L
.3648 .39507 L
.38977 .38694 L
.41514 .38463 L
.43983 .38731 L
.46297 .39406 L
.48387 .40397 L
.50206 .41613 L
.51725 .42969 L
.52931 .44388 L
.53826 .45804 L
.54424 .4716 L
.5475 .48413 L
.54833 .49527 L
.5471 .50482 L
.54418 .51264 L
.53996 .5187 L
.53482 .52304 L
.52912 .52576 L
.52316 .52701 L
.51724 .52699 L
.51158 .52588 L
.50636 .52392 L
.50173 .52132 L
.49777 .51828 L
.49453 .515 L
.49204 .51165 L
.49026 .50837 L
.48916 .50528 L
.48867 .50247 L
.48871 .50002 L
.48919 .49796 L
.49003 .49631 L
.49114 .49508 L
.49242 .49424 L
Mistroke
.4938 .49376 L
.4952 .49361 L
.49657 .49374 L
.49786 .4941 L
.49903 .49464 L
.50005 .4953 L
.5009 .49605 L
.50158 .49684 L
.50209 .49762 L
.50243 .49838 L
.50262 .49907 L
.50268 .4997 L
.50262 .50023 L
.50246 .50067 L
.50223 .50101 L
.50195 .50126 L
.50164 .50142 L
.50131 .50149 L
.50098 .5015 L
.50066 .50144 L
.50037 .50133 L
.50011 .50119 L
.49989 .50103 L
.49971 .50084 L
.49957 .50066 L
.49947 .50048 L
.4994 .5003 L
.49937 .50015 L
.49937 .50001 L
.4994 .49989 L
.49944 .4998 L
.4995 .49973 L
.49957 .49968 L
.49965 .49966 L
.49973 .49965 L
.4998 .49965 L
.49988 .49967 L
.49994 .4997 L
.5 .49974 L
.50005 .49978 L
.50009 .49982 L
.50011 .49987 L
.50013 .49991 L
.50014 .49995 L
.50015 .49998 L
.50015 .50001 L
.50014 .50004 L
.50012 .50005 L
.50011 .50007 L
.50009 .50008 L
Mistroke
.50007 .50008 L
.50006 .50008 L
.50004 .50008 L
.50002 .50007 L
.50001 .50007 L
.49999 .50006 L
.49998 .50005 L
.49998 .50004 L
.49997 .50003 L
.49997 .50002 L
.49997 .50001 L
.49997 .5 L
.49997 .49999 L
.49997 .49999 L
.49997 .49999 L
.49998 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
0.11776426 -2.9958029 0.65832542 -2.5034541 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
1.085777 -1.9900361 1.4011844 -1.4794628 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.2435707 0.8412456 1.0364388 0.93552166 MAarrowhead1
% End of user PostScript
1 .788 0 r
.39756 .76663 m
.35344 .70606 L
s
% Start of user PostScript
-0.20487658 0.53326876 -0.29312729 0.41212937 MAarrowhead1
% End of user PostScript
.897 1 0 r
.34149 .40976 m
.3648 .39507 L
s
% Start of user PostScript
-0.31701895 -0.18048748 -0.27040267 -0.20986026 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51725 .42969 m
.52931 .44388 L
s
% Start of user PostScript
0.03449402 -0.14062759 0.058613217 -0.11224002 MAarrowhead1
% End of user PostScript
.266 1 0 r
.53996 .5187 m
.53482 .52304 L
s
% Start of user PostScript
0.079919867 0.03739778 0.069643859 0.046076246 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49777 .51828 m
.49453 .515 L
s
% Start of user PostScript
-0.0044655127 0.036569102 -0.01093277 0.030007581 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49003 .49631 m
.49114 .49508 L
s
% Start of user PostScript
-0.019933765 -0.0073733096 -0.017726706 -0.0098451317 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50005 .4953 m
.5009 .49605 L
s
% Start of user PostScript
0.00009336573 -0.0093906112 0.0017997568 -0.007897531 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50246 .50067 m
.50223 .50101 L
s
% Start of user PostScript
0.0049203263 0.0013434629 0.0044623444 0.0020284943 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50011 .50119 m
.49989 .50103 L
s
% Start of user PostScript
0.00022573935 0.0023836193 -0.00021820628 0.0020500643 MAarrowhead1
% End of user PostScript
0 .375 1 r
.4994 .49989 m
.49944 .4998 L
s
% Start of user PostScript
-0.0012019246 -0.00021078228 -0.0011114327 -0.00039657289 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49994 .4997 m
.5 .49974 L
s
% Start of user PostScript
-0.00011643383 -0.00059845007 -0.0000023830783 -0.00052558966 MAarrowhead1
% End of user PostScript
0 .548 1 r
0 .00877 m
.05115 0 L
s
.20459 0 m
.30102 .02176 L
.39675 .06069 L
.48125 .11094 L
.55292 .16867 L
.61098 .23039 L
.65528 .29299 L
.68625 .35381 L
.70481 .41071 L
.71219 .46205 L
.70991 .50667 L
.69959 .54385 L
.68295 .57331 L
.66167 .59511 L
.63734 .60961 L
.61142 .6174 L
.58521 .61924 L
.5598 .61601 L
.53607 .60867 L
.51472 .59816 L
.4962 .58541 L
.48081 .57129 L
.46865 .55659 L
.4597 .54199 L
.4538 .52805 L
.4507 .51522 L
.45006 .50385 L
.45153 .49415 L
.45469 .48624 L
.45916 .48015 L
.46455 .47583 L
.47049 .47317 L
.47665 .47201 L
.48276 .47216 L
.48858 .4734 L
.49392 .4755 L
.49865 .47824 L
.50267 .48142 L
.50594 .48482 L
.50844 .48829 L
.51021 .49167 L
.51129 .49484 L
.51174 .49771 L
.51165 .5002 L
.5111 .50229 L
.51021 .50396 L
.50904 .50519 L
.5077 .50602 L
.50627 .50648 L
.50482 .5066 L
Mistroke
.50341 .50644 L
.50209 .50605 L
.5009 .50548 L
.49986 .50478 L
.49899 .50401 L
.49831 .50319 L
.4978 .50238 L
.49746 .50161 L
.49728 .50089 L
.49723 .50026 L
.49731 .49971 L
.49748 .49927 L
.49772 .49892 L
.49801 .49868 L
.49834 .49852 L
.49868 .49845 L
.49902 .49846 L
.49935 .49852 L
.49964 .49863 L
.49991 .49878 L
.50013 .49896 L
.50032 .49915 L
.50046 .49934 L
.50056 .49953 L
.50062 .4997 L
.50065 .49986 L
.50065 .5 L
.50062 .50012 L
.50057 .50021 L
.50051 .50028 L
.50043 .50033 L
.50035 .50036 L
.50027 .50037 L
.50019 .50036 L
.50012 .50034 L
.50005 .50031 L
.5 .50027 L
.49995 .50022 L
.49991 .50018 L
.49988 .50014 L
.49986 .50009 L
.49985 .50005 L
.49985 .50002 L
.49985 .49999 L
.49986 .49996 L
.49987 .49994 L
.49989 .49993 L
.49991 .49992 L
.49993 .49991 L
.49994 .49991 L
Mistroke
.49996 .49992 L
.49998 .49992 L
.49999 .49993 L
.50001 .49994 L
.50002 .49995 L
.50002 .49996 L
.50003 .49997 L
.50003 .49998 L
.50004 .49999 L
.50004 .5 L
.50003 .50001 L
.50003 .50001 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
6.5584596 2.714442 5.7797554 3.4823496 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
4.894936 3.9877169 3.9564211 4.2524835 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.1595805 2.0057904 -1.4746583 1.4792979 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.2657027 -0.88194965 -1.0501976 -0.97385881 MAarrowhead1
% End of user PostScript
.897 1 0 r
.61098 .23039 m
.65528 .29299 L
s
% Start of user PostScript
0.22195732 -0.53921165 0.31055011 -0.41402697 MAarrowhead1
% End of user PostScript
.581 1 0 r
.66167 .59511 m
.63734 .60961 L
s
% Start of user PostScript
0.32334022 0.19022451 0.2746764 0.21921815 MAarrowhead1
% End of user PostScript
.266 1 0 r
.48081 .57129 m
.46865 .55659 L
s
% Start of user PostScript
-0.038386488 0.14258537 -0.062693557 0.11318108 MAarrowhead1
% End of user PostScript
0 1 .049 r
.45916 .48015 m
.46455 .47583 L
s
% Start of user PostScript
-0.08167547 -0.039699921 -0.070904043 -0.048336294 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50267 .48142 m
.50594 .48482 L
s
% Start of user PostScript
0.0053366232 -0.037168278 0.011875257 -0.030353908 MAarrowhead1
% End of user PostScript
0 1 .679 r
.51021 .50396 m
.50904 .50519 L
s
% Start of user PostScript
0.020410733 0.0079107172 0.018085114 0.010384943 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49986 .50478 m
.49899 .50401 L
s
% Start of user PostScript
-0.00028406426 0.0095655366 -0.0020140508 0.0080102261 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49748 .49927 m
.49772 .49892 L
s
% Start of user PostScript
-0.0050475866 -0.0014671421 -0.004561561 -0.0021559125 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49991 .49878 m
.50013 .49896 L
s
% Start of user PostScript
-0.00018514773 -0.0024330084 0.00026603429 -0.0020842966 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50062 .50012 m
.50057 .50021 L
s
% Start of user PostScript
0.0012353588 0.00023878416 0.0011383173 0.00042626309 MAarrowhead1
% End of user PostScript
.216 1 0 r
.21102 1 m
.18871 .97053 L
.1165 .83987 L
.07122 .7166 L
.05035 .60445 L
.05082 .50613 L
.06917 .42335 L
.10181 .35693 L
.14513 .30689 L
.19568 .27261 L
.25029 .25292 L
.30612 .24627 L
.36074 .25084 L
.41216 .26464 L
.45884 .28564 L
.49966 .31183 L
.53395 .34135 L
.56138 .37247 L
.58195 .4037 L
.59593 .43376 L
.60384 .46165 L
.60633 .48659 L
.60416 .50806 L
.59818 .52577 L
.58923 .5396 L
.57815 .54963 L
.56572 .55606 L
.55266 .55922 L
.53959 .5595 L
.52704 .55736 L
.51542 .55327 L
.50505 .5477 L
.49614 .54112 L
.48882 .53396 L
.48312 .52658 L
.47901 .51933 L
.47639 .51247 L
.47515 .50621 L
.47509 .5007 L
.47605 .49606 L
.4778 .49231 L
.48016 .48948 L
.48294 .48752 L
.48595 .48637 L
.48904 .48596 L
.49208 .48617 L
.49494 .4869 L
.49754 .48804 L
.49983 .48947 L
.50176 .49109 L
Mistroke
.5033 .49281 L
.50447 .49454 L
.50527 .49622 L
.50573 .49777 L
.50589 .49916 L
.50578 .50037 L
.50547 .50136 L
.50498 .50214 L
.50437 .50271 L
.50369 .50308 L
.50297 .50327 L
.50224 .5033 L
.50155 .50319 L
.5009 .50297 L
.50032 .50267 L
.49982 .5023 L
.49941 .50191 L
.49909 .5015 L
.49885 .5011 L
.4987 .50072 L
.49863 .50037 L
.49862 .50006 L
.49867 .4998 L
.49876 .49959 L
.49889 .49943 L
.49904 .49932 L
.49921 .49925 L
.49938 .49922 L
.49955 .49923 L
.49971 .49927 L
.49985 .49933 L
.49998 .49941 L
.50009 .4995 L
.50018 .4996 L
.50024 .49969 L
.50029 .49978 L
.50032 .49987 L
.50033 .49995 L
.50032 .50002 L
.5003 .50007 L
.50028 .50012 L
.50024 .50015 L
.50021 .50017 L
.50017 .50018 L
.50013 .50018 L
.50009 .50018 L
.50005 .50017 L
.50002 .50015 L
.49999 .50013 L
.49997 .50011 L
Mistroke
.49995 .50008 L
.49994 .50006 L
.49993 .50004 L
.49992 .50002 L
.49992 .5 L
.49993 .49999 L
.49993 .49998 L
.49994 .49997 L
.49995 .49996 L
.49996 .49996 L
.49997 .49996 L
.49997 .49996 L
.49998 .49996 L
.49999 .49996 L
.5 .49997 L
.5 .49997 L
.50001 .49998 L
.50001 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
3.8405812 -0.42404714 3.7513428 0.34214386 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
3.5264159 0.97164605 3.1965791 1.4612302 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
0.15720363 1.707138 -0.16055458 1.4674331 MAarrowhead1
% End of user PostScript
1 .788 0 r
.06917 .42335 m
.10181 .35693 L
s
% Start of user PostScript
-0.86165551 -0.15329507 -0.79638405 -0.2861441 MAarrowhead1
% End of user PostScript
.897 1 0 r
.45884 .28564 m
.49966 .31183 L
s
% Start of user PostScript
-0.082329727 -0.42872537 -0.00067150698 -0.3763315 MAarrowhead1
% End of user PostScript
.581 1 0 r
.60416 .50806 m
.59818 .52577 L
s
% Start of user PostScript
0.20831919 0.016126497 0.19635194 0.051535607 MAarrowhead1
% End of user PostScript
.266 1 0 r
.51542 .55327 m
.50505 .5477 L
s
% Start of user PostScript
0.030834513 0.1065377 0.010092801 0.095407754 MAarrowhead1
% End of user PostScript
0 1 .049 r
.47509 .5007 m
.47605 .49606 L
s
% Start of user PostScript
-0.04981194 0.001409614 -0.047909518 -0.0078848758 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49494 .4869 m
.49754 .48804 L
s
% Start of user PostScript
-0.010122101 -0.026200606 -0.0049110751 -0.023925908 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50589 .49916 m
.50578 .50037 L
s
% Start of user PostScript
0.011771718 -0.0016722632 0.011566046 0.00073473456 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50155 .50319 m
.5009 .50297 L
s
% Start of user PostScript
0.0030912368 0.0063764433 0.0017958152 0.0059372031 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49863 .50037 m
.49862 .50006 L
s
% Start of user PostScript
-0.0027465823 0.00073475679 -0.0027613587 0.00011899125 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49955 .49923 m
.49971 .49927 L
s
% Start of user PostScript
-0.00090115199 -0.0015352636 -0.00058245201 -0.0014580803 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50032 .49987 m
.50033 .49995 L
s
% Start of user PostScript
0.0006317382 -0.00025880902 0.00065149491 -0.00010306086 MAarrowhead1
% End of user PostScript
.331 0 1 r
.37655 0 m
.46374 .04902 L
.54746 .1133 L
.61584 .18273 L
.6686 .2537 L
.70616 .32312 L
.72944 .38848 L
.73981 .4478 L
.73892 .49968 L
.72862 .54325 L
.71083 .57809 L
.68747 .60422 L
.66036 .62198 L
.63119 .63202 L
.60146 .63516 L
.57244 .6324 L
.54519 .62478 L
.5205 .6134 L
.49896 .59931 L
.48091 .58351 L
.46653 .5669 L
.4558 .55029 L
.44855 .53433 L
.44453 .51957 L
.44337 .50639 L
.44466 .49507 L
.44796 .48576 L
.45281 .47852 L
.45876 .4733 L
.46541 .46999 L
.47238 .46841 L
.47933 .46834 L
.48599 .46955 L
.49215 .47179 L
.49763 .47479 L
.50232 .47832 L
.50617 .48215 L
.50915 .48608 L
.51129 .48994 L
.51263 .49357 L
.51326 .49689 L
.51325 .49979 L
.51271 .50224 L
.51176 .5042 L
.51048 .50568 L
.50899 .5067 L
.50738 .50728 L
.50574 .50748 L
.50412 .50735 L
.50261 .50695 L
Mistroke
.50123 .50633 L
.50002 .50556 L
.49901 .50469 L
.4982 .50377 L
.49759 .50285 L
.49717 .50196 L
.49694 .50114 L
.49686 .5004 L
.49693 .49977 L
.4971 .49925 L
.49737 .49884 L
.49769 .49854 L
.49806 .49835 L
.49844 .49825 L
.49883 .49824 L
.4992 .49831 L
.49954 .49843 L
.49985 .49859 L
.50011 .49878 L
.50033 .499 L
.5005 .49921 L
.50062 .49943 L
.5007 .49963 L
.50073 .49982 L
.50073 .49998 L
.50071 .50011 L
.50066 .50023 L
.50059 .50031 L
.5005 .50037 L
.50042 .5004 L
.50032 .50041 L
.50023 .50041 L
.50015 .50039 L
.50007 .50035 L
.50001 .50031 L
.49995 .50026 L
.4999 .50021 L
.49987 .50016 L
.49984 .50011 L
.49983 .50007 L
.49983 .50003 L
.49983 .49999 L
.49984 .49996 L
.49985 .49994 L
.49987 .49992 L
.49989 .49991 L
.49991 .4999 L
.49993 .4999 L
.49995 .49991 L
.49997 .49991 L
Mistroke
.49999 .49992 L
.50001 .49993 L
.50002 .49994 L
.50003 .49996 L
.50003 .49997 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50004 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
6.206859 -8.7131705 7.5248601 -6.213042 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
8.3303484 -3.8658339 8.6733931 -1.74086 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.5880119 4.8821785 2.5432274 4.7683004 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.872835 1.2001373 -2.0102513 0.67036768 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-0.9794801 -1.1432536 -0.72878692 -1.1419558 MAarrowhead1
% End of user PostScript
.581 1 0 r
.70616 .32312 m
.72944 .38848 L
s
% Start of user PostScript
0.41231464 -0.3537511 0.45887568 -0.22304591 MAarrowhead1
% End of user PostScript
.266 1 0 r
.63119 .63202 m
.60146 .63516 L
s
% Start of user PostScript
0.26238272 0.26403782 0.20291659 0.27032602 MAarrowhead1
% End of user PostScript
0 1 .049 r
.4558 .55029 m
.44855 .53433 L
s
% Start of user PostScript
-0.08840993 0.10058323 -0.10289824 0.068669654 MAarrowhead1
% End of user PostScript
0 1 .364 r
.46541 .46999 m
.47238 .46841 L
s
% Start of user PostScript
-0.069172634 -0.060025614 -0.055240969 -0.063189759 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50915 .48608 m
.51129 .48994 L
s
% Start of user PostScript
0.018304373 -0.02783831 0.022581508 -0.020128491 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50899 .5067 m
.50738 .50728 L
s
% Start of user PostScript
0.017983198 0.013394678 0.014763937 0.014564742 MAarrowhead1
% End of user PostScript
0 .69 1 r
.4982 .50377 m
.49759 .50285 L
s
% Start of user PostScript
-0.003604604 0.0075420541 -0.0048220926 0.0056999926 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49769 .49854 m
.49806 .49835 L
s
% Start of user PostScript
-0.0046168446 -0.002921774 -0.0038845385 -0.0033034395 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50033 .499 m
.5005 .49921 L
s
% Start of user PostScript
0.00065546485 -0.0020075674 0.00099271796 -0.001572617 MAarrowhead1
% End of user PostScript
1 0 .097 r
.50191 1 m
.46192 .971 L
.37778 .89002 L
.31204 .80646 L
.26437 .72405 L
.23377 .64591 L
.21873 .57449 L
.21736 .51155 L
.22751 .45825 L
.24692 .41518 L
.27334 .38242 L
.30458 .35961 L
.33863 .34609 L
.37365 .34089 L
.40811 .34288 L
.44071 .35084 L
.47045 .36349 L
.4966 .37957 L
.51868 .39788 L
.53647 .41733 L
.54995 .43697 L
.55926 .45597 L
.56471 .47369 L
.5667 .48961 L
.5657 .50339 L
.56224 .51483 L
.55684 .52383 L
.55003 .53044 L
.54232 .53477 L
.53415 .53701 L
.52593 .53741 L
.51799 .53626 L
.51061 .53383 L
.50399 .53045 L
.49827 .52639 L
.49354 .52192 L
.48982 .5173 L
.48711 .51273 L
.48535 .50838 L
.48446 .50439 L
.48433 .50087 L
.48485 .49788 L
.4859 .49546 L
.48734 .4936 L
.48905 .4923 L
.49093 .49152 L
.49286 .4912 L
.49478 .49128 L
.49659 .4917 L
.49825 .49238 L
Mistroke
.49971 .49326 L
.50095 .49427 L
.50196 .49534 L
.50272 .49643 L
.50325 .49749 L
.50357 .49848 L
.50369 .49936 L
.50365 .50014 L
.50346 .50078 L
.50317 .50129 L
.5028 .50166 L
.50237 .50191 L
.50192 .50204 L
.50147 .50207 L
.50103 .50201 L
.50062 .50188 L
.50025 .5017 L
.49993 .50148 L
.49966 .50123 L
.49945 .50098 L
.4993 .50072 L
.49919 .50048 L
.49914 .50026 L
.49913 .50006 L
.49916 .49989 L
.49921 .49976 L
.49929 .49965 L
.49939 .49958 L
.49949 .49953 L
.4996 .49951 L
.4997 .49952 L
.4998 .49954 L
.4999 .49958 L
.49998 .49962 L
.50005 .49968 L
.5001 .49974 L
.50015 .4998 L
.50018 .49986 L
.5002 .49991 L
.5002 .49996 L
.5002 .5 L
.50019 .50004 L
.50018 .50007 L
.50016 .50009 L
.50013 .50011 L
.50011 .50011 L
.50008 .50011 L
.50006 .50011 L
.50004 .5001 L
.50001 .50009 L
Mistroke
.5 .50008 L
.49998 .50007 L
.49997 .50006 L
.49996 .50004 L
.49996 .50003 L
.49995 .50002 L
.49995 .5 L
.49995 .49999 L
.49996 .49999 L
.49996 .49998 L
.49997 .49998 L
.49997 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-4.4729193 -5.7508464 -3.2315549 -5.6616058 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-2.0602539 -5.3602862 -0.99460815 -4.8929851 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.4103281 -0.33659341 2.367157 0.15533985 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
0.62991432 1.3048127 0.36494665 1.214449 MAarrowhead1
% End of user PostScript
.897 1 0 r
.21873 .57449 m
.21736 .51155 L
s
% Start of user PostScript
-0.56253222 0.14897195 -0.56528267 0.023094071 MAarrowhead1
% End of user PostScript
.581 1 0 r
.40811 .34288 m
.44071 .35084 L
s
% Start of user PostScript
-0.1837756 -0.3142311 -0.11857443 -0.29831184 MAarrowhead1
% End of user PostScript
.266 1 0 r
.56471 .47369 m
.5667 .48961 L
s
% Start of user PostScript
0.12942737 -0.052623003 0.13340208 -0.02077705 MAarrowhead1
% End of user PostScript
0 1 .049 r
.52593 .53741 m
.51799 .53626 L
s
% Start of user PostScript
0.051862125 0.074827908 0.03598467 0.072512342 MAarrowhead1
% End of user PostScript
0 1 .364 r
.48535 .50838 m
.48446 .50439 L
s
% Start of user PostScript
-0.029294338 0.01675984 -0.031077225 0.0087896541 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49286 .4912 m
.49478 .49128 L
s
% Start of user PostScript
-0.014270113 -0.017604987 -0.01044492 -0.017436934 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50325 .49749 m
.50357 .49848 L
s
% Start of user PostScript
0.0065024229 -0.005023003 0.0071354725 -0.0030490827 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50192 .50204 m
.50147 .50207 L
s
% Start of user PostScript
0.0038477176 0.0040873821 0.0029364426 0.0041457387 MAarrowhead1
% End of user PostScript
0 .375 1 r
.4993 .50072 m
.49919 .50048 L
s
% Start of user PostScript
-0.0014089439 0.0014453081 -0.0016111245 0.00096149581 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49949 .49953 m
.4996 .49951 L
s
% Start of user PostScript
-0.0010200692 -0.00093486378 -0.00080557345 -0.00097371504 MAarrowhead1
% End of user PostScript
0 1 .591 r
.2223 1 m
.18814 .95397 L
.11897 .82581 L
.07614 .70519 L
.05714 .59574 L
.0589 .50003 L
.07801 .41968 L
.11094 .35544 L
.15413 .3073 L
.20422 .27459 L
.2581 .25615 L
.313 .25042 L
.36657 .25559 L
.41687 .2697 L
.46242 .29076 L
.50216 .3168 L
.53543 .34599 L
.56195 .37666 L
.58173 .40733 L
.59507 .43678 L
.60246 .46403 L
.60457 .48835 L
.60216 .50923 L
.59605 .52639 L
.58708 .53973 L
.57607 .54935 L
.56378 .55545 L
.55092 .55835 L
.53808 .55845 L
.52579 .5562 L
.51443 .55206 L
.50432 .54651 L
.49566 .53999 L
.48857 .53291 L
.48307 .52566 L
.47913 .51854 L
.47666 .51182 L
.47552 .50571 L
.47554 .50036 L
.47653 .49584 L
.47831 .49222 L
.48066 .48949 L
.48342 .48762 L
.48639 .48655 L
.48943 .48618 L
.4924 .48643 L
.4952 .48718 L
.49775 .48832 L
.49997 .48975 L
.50184 .49135 L
Mistroke
.50334 .49305 L
.50446 .49475 L
.50522 .49639 L
.50565 .4979 L
.50579 .49926 L
.50567 .50043 L
.50535 .5014 L
.50486 .50215 L
.50426 .5027 L
.50358 .50305 L
.50287 .50322 L
.50216 .50324 L
.50148 .50312 L
.50084 .5029 L
.50028 .5026 L
.49979 .50224 L
.49939 .50185 L
.49908 .50145 L
.49886 .50105 L
.49872 .50068 L
.49865 .50034 L
.49864 .50004 L
.4987 .49979 L
.49879 .49958 L
.49892 .49943 L
.49907 .49932 L
.49923 .49926 L
.4994 .49924 L
.49957 .49925 L
.49972 .49929 L
.49987 .49935 L
.49999 .49943 L
.5001 .49951 L
.50018 .49961 L
.50024 .4997 L
.50029 .49979 L
.50031 .49988 L
.50032 .49995 L
.50031 .50002 L
.5003 .50007 L
.50027 .50012 L
.50024 .50015 L
.5002 .50017 L
.50016 .50018 L
.50012 .50018 L
.50008 .50017 L
.50005 .50016 L
.50002 .50015 L
.49999 .50013 L
.49997 .5001 L
Mistroke
.49995 .50008 L
.49994 .50006 L
.49993 .50004 L
.49993 .50002 L
.49992 .5 L
.49993 .49999 L
.49993 .49998 L
.49994 .49997 L
.49995 .49996 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49999 .49996 L
.5 .49997 L
.5 .49997 L
.50001 .49998 L
.50001 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-8.5953079 -8.8386304 -6.6128327 -9.0148989 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-4.6841848 -8.8023656 -2.8778486 -8.271949 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.7129671 -1.2319464 3.7764138 -0.36200888 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.3428268 2.1083516 0.90059756 2.021535 MAarrowhead1
% End of user PostScript
.897 1 0 r
.07614 .70519 m
.05714 .59574 L
s
% Start of user PostScript
-0.84771544 0.41038879 -0.88571955 0.19147555 MAarrowhead1
% End of user PostScript
.581 1 0 r
.313 .25042 m
.36657 .25559 L
s
% Start of user PostScript
-0.37399602 -0.49916456 -0.26686505 -0.48882372 MAarrowhead1
% End of user PostScript
.266 1 0 r
.59507 .43678 m
.60246 .46403 L
s
% Start of user PostScript
0.19013547 -0.12643751 0.20492352 -0.071931357 MAarrowhead1
% End of user PostScript
0 1 .049 r
.55092 .55835 m
.53808 .55845 L
s
% Start of user PostScript
0.1018392 0.11670001 0.076168684 0.11690572 MAarrowhead1
% End of user PostScript
0 1 .364 r
.47913 .51854 m
.47666 .51182 L
s
% Start of user PostScript
-0.041738019 0.037079254 -0.046682564 0.023648602 MAarrowhead1
% End of user PostScript
0 1 .679 r
.48639 .48655 m
.48943 .48618 L
s
% Start of user PostScript
-0.027223438 -0.026903206 -0.021143155 -0.027632964 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50446 .49475 m
.50522 .49639 L
s
% Start of user PostScript
0.0089160996 -0.01050381 0.010442818 -0.0072287477 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50358 .50305 m
.50287 .50322 L
s
% Start of user PostScript
0.0071639996 0.0061031946 0.0057418083 0.0064487324 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49908 .50145 m
.49886 .50105 L
s
% Start of user PostScript
-0.0018364839 0.0028987745 -0.0022848714 0.0021086238 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49907 .49932 m
.49923 .49926 L
s
% Start of user PostScript
-0.0018594699 -0.0013584723 -0.0015314316 -0.0014836295 MAarrowhead1
% End of user PostScript
.925 1 0 r
.83554 0 m
.88065 .07011 L
.94245 .20702 L
.97664 .33366 L
.98627 .44662 L
.97492 .54358 L
.94639 .62324 L
.9046 .68517 L
.85333 .72976 L
.79617 .758 L
.73633 .77139 L
.67666 .77178 L
.6195 .76124 L
.56673 .74194 L
.51977 .71607 L
.47956 .6857 L
.44662 .65279 L
.42111 .61905 L
.40284 .58597 L
.39139 .55476 L
.38613 .52637 L
.38626 .50148 L
.39092 .48053 L
.39919 .46373 L
.41017 .45107 L
.42298 .4424 L
.43681 .43742 L
.45095 .43575 L
.46478 .43691 L
.47779 .44041 L
.48961 .44573 L
.49994 .45237 L
.50862 .45985 L
.51556 .46773 L
.52076 .47564 L
.5243 .48325 L
.5263 .49031 L
.52692 .49662 L
.52637 .50206 L
.52486 .50654 L
.52259 .51004 L
.51978 .51257 L
.51663 .5142 L
.51333 .515 L
.51002 .51507 L
.50684 .51452 L
.5039 .51349 L
.50127 .51208 L
.49902 .51041 L
.49716 .50859 L
Mistroke
.49572 .50673 L
.49468 .50489 L
.49402 .50315 L
.49371 .50157 L
.49369 .50017 L
.49393 .499 L
.49438 .49805 L
.49498 .49733 L
.49568 .49684 L
.49645 .49655 L
.49723 .49644 L
.498 .4965 L
.49872 .49668 L
.49938 .49697 L
.49996 .49733 L
.50045 .49775 L
.50084 .49818 L
.50113 .49862 L
.50133 .49904 L
.50145 .49944 L
.50149 .49979 L
.50146 .50009 L
.50138 .50035 L
.50126 .50054 L
.50111 .50069 L
.50093 .50078 L
.50075 .50083 L
.50057 .50084 L
.50039 .50081 L
.50023 .50075 L
.50008 .50067 L
.49995 .50058 L
.49985 .50048 L
.49977 .50038 L
.49971 .50028 L
.49967 .50018 L
.49965 .50009 L
.49965 .50001 L
.49966 .49995 L
.49969 .4999 L
.49972 .49985 L
.49976 .49983 L
.4998 .49981 L
.49984 .4998 L
.49989 .49981 L
.49993 .49982 L
.49996 .49983 L
.5 .49985 L
.50002 .49987 L
.50004 .4999 L
Mistroke
.50006 .49992 L
.50007 .49995 L
.50008 .49997 L
.50008 .49999 L
.50008 .5 L
.50008 .50002 L
.50007 .50003 L
.50006 .50004 L
.50005 .50004 L
.50004 .50005 L
.50003 .50005 L
.50002 .50004 L
.50001 .50004 L
.5 .50004 L
.5 .50003 L
.49999 .50003 L
.49999 .50002 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
6.228493 9.802682 4.1730153 9.3963151 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
2.2806525 8.6794317 0.60089261 7.730551 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-4.1016868 -0.0059616467 -3.9228071 -0.75211988 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.76977605 -2.1406229 -0.34650853 -1.9443563 MAarrowhead1
% End of user PostScript
.897 1 0 r
.98627 .44662 m
.97492 .54358 L
s
% Start of user PostScript
0.97254498 -0.10675601 0.94983345 0.087167242 MAarrowhead1
% End of user PostScript
.581 1 0 r
.6195 .76124 m
.56673 .74194 L
s
% Start of user PostScript
0.2389946 0.52247372 0.13346986 0.48387938 MAarrowhead1
% End of user PostScript
.266 1 0 r
.38613 .52637 m
.38626 .50148 L
s
% Start of user PostScript
-0.22774349 0.052741061 -0.22747804 0.0029689137 MAarrowhead1
% End of user PostScript
0 1 .049 r
.46478 .43691 m
.47779 .44041 L
s
% Start of user PostScript
-0.070449654 -0.12617394 -0.044414153 -0.11917308 MAarrowhead1
% End of user PostScript
0 1 .364 r
.5263 .49031 m
.52692 .49662 L
s
% Start of user PostScript
0.052599043 -0.019384918 0.053849893 -0.0067573067 MAarrowhead1
% End of user PostScript
0 1 .679 r
.51002 .51507 m
.50684 .51452 L
s
% Start of user PostScript
0.020031986 0.030134042 0.013674951 0.029046083 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49402 .50315 m
.49371 .50157 L
s
% Start of user PostScript
-0.011957982 0.0063037862 -0.012587839 0.0031348502 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49723 .49644 m
.498 .4965 L
s
% Start of user PostScript
-0.0055444015 -0.007112255 -0.0040086205 -0.0070041833 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50133 .49904 m
.50145 .49944 L
s
% Start of user PostScript
0.0026684869 -0.0019140777 0.002901454 -0.0011271637 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50075 .50083 m
.50057 .50084 L
s
% Start of user PostScript
0.0015021466 0.0016570881 0.0011352061 0.0016702229 MAarrowhead1
% End of user PostScript
1 .612 0 r
.4585 0 m
.4622 .0021 L
.55453 .07348 L
.62985 .15045 L
.68789 .22905 L
.7291 .30586 L
.75453 .37811 L
.7657 .44363 L
.76445 .50088 L
.75283 .54891 L
.73296 .58728 L
.70696 .61599 L
.67687 .63545 L
.64453 .64638 L
.6116 .64969 L
.5795 .64649 L
.54937 .63794 L
.5221 .62525 L
.49833 .60959 L
.47844 .59206 L
.46261 .57366 L
.45081 .55527 L
.44288 .53763 L
.4385 .52131 L
.43728 .50676 L
.43877 .49427 L
.44247 .48402 L
.44787 .47605 L
.4545 .47032 L
.46187 .4667 L
.46959 .46499 L
.47729 .46495 L
.48465 .46632 L
.49145 .46882 L
.4975 .47217 L
.50268 .47609 L
.50692 .48033 L
.5102 .48469 L
.51255 .48895 L
.51402 .49297 L
.51469 .49663 L
.51467 .49984 L
.51406 .50253 L
.51299 .5047 L
.51157 .50632 L
.50992 .50744 L
.50813 .50808 L
.50631 .50829 L
.50453 .50813 L
.50285 .50768 L
Mistroke
.50133 .50699 L
.5 .50613 L
.49888 .50517 L
.49799 .50415 L
.49732 .50313 L
.49686 .50215 L
.49661 .50124 L
.49653 .50043 L
.4966 .49973 L
.4968 .49915 L
.49709 .4987 L
.49745 .49838 L
.49786 .49817 L
.49829 .49807 L
.49871 .49806 L
.49912 .49813 L
.4995 .49826 L
.49984 .49844 L
.50013 .49866 L
.50037 .49889 L
.50055 .49913 L
.50069 .49937 L
.50077 .4996 L
.50081 .4998 L
.50081 .49998 L
.50078 .50013 L
.50072 .50025 L
.50065 .50034 L
.50056 .50041 L
.50046 .50045 L
.50036 .50046 L
.50026 .50045 L
.50016 .50043 L
.50008 .50039 L
.5 .50034 L
.49994 .50029 L
.49989 .50023 L
.49985 .50018 L
.49983 .50012 L
.49981 .50007 L
.49981 .50003 L
.49981 .49999 L
.49982 .49996 L
.49984 .49993 L
.49986 .49991 L
.49988 .4999 L
.4999 .49989 L
.49993 .49989 L
.49995 .4999 L
.49997 .4999 L
Mistroke
.49999 .49991 L
.50001 .49992 L
.50002 .49994 L
.50003 .49995 L
.50004 .49996 L
.50004 .49998 L
.50004 .49999 L
.50005 .5 L
.50004 .50001 L
.50004 .50001 L
.50004 .50002 L
.50003 .50002 L
.50003 .50002 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
7.401983 4.2517745 6.3067 4.931677 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
5.1350539 5.3052096 3.9461581 5.4066204 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.8021829 1.9495058 -2.0791542 1.3148146 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.3574039 -1.209685 -1.078229 -1.2667815 MAarrowhead1
% End of user PostScript
.897 1 0 r
.68789 .22905 m
.7291 .30586 L
s
% Start of user PostScript
0.37578486 -0.54190175 0.45819974 -0.38827555 MAarrowhead1
% End of user PostScript
.581 1 0 r
.67687 .63545 m
.64453 .64638 L
s
% Start of user PostScript
0.3537307 0.27090705 0.28905377 0.29275393 MAarrowhead1
% End of user PostScript
.266 1 0 r
.46261 .57366 m
.45081 .55527 L
s
% Start of user PostScript
-0.074783403 0.14732791 -0.098376615 0.1105487 MAarrowhead1
% End of user PostScript
0 1 .049 r
.4545 .47032 m
.46187 .4667 L
s
% Start of user PostScript
-0.091009835 -0.059356215 -0.076253531 -0.066603084 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50692 .48033 m
.5102 .48469 L
s
% Start of user PostScript
0.013840063 -0.039331561 0.02040413 -0.030628307 MAarrowhead1
% End of user PostScript
0 1 .679 r
.51157 .50632 m
.50992 .50744 L
s
% Start of user PostScript
0.023142478 0.012648528 0.019835486 0.014875605 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49888 .50517 m
.49799 .50415 L
s
% Start of user PostScript
-0.0022428744 0.010338531 -0.0040287492 0.0083049321 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49709 .4987 m
.49745 .49838 L
s
% Start of user PostScript
-0.0058202607 -0.0025963906 -0.0050950571 -0.0032483962 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50013 .49866 m
.50037 .49889 L
s
% Start of user PostScript
0.00025882388 -0.0026807193 0.00073588019 -0.0022122042 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50072 .50025 m
.50065 .50034 L
s
% Start of user PostScript
0.0014483443 0.00050472958 0.0012936304 0.00068919948 MAarrowhead1
% End of user PostScript
.689 1 0 r
.52009 1 m
.49063 .98047 L
.40352 .90324 L
.33426 .82228 L
.28274 .74143 L
.24818 .66391 L
.22924 .59228 L
.22417 .52846 L
.23094 .47375 L
.24739 .42887 L
.2713 .39404 L
.30051 .36903 L
.33301 .35328 L
.36697 .34593 L
.4008 .34592 L
.43317 .35207 L
.46301 .36315 L
.48954 .37792 L
.51223 .39521 L
.53079 .41391 L
.54513 .43305 L
.55537 .45179 L
.56175 .46945 L
.56464 .4855 L
.56448 .49956 L
.56176 .51137 L
.55702 .52083 L
.55075 .52794 L
.54346 .53279 L
.5356 .53556 L
.52758 .53645 L
.51975 .53575 L
.51238 .53372 L
.5057 .53068 L
.49987 .5269 L
.49497 .52264 L
.49107 .51817 L
.48815 .51369 L
.48617 .50938 L
.48506 .50538 L
.48473 .50181 L
.48506 .49875 L
.48593 .49622 L
.48723 .49425 L
.48883 .49283 L
.49062 .49192 L
.4925 .49149 L
.49437 .49146 L
.49617 .49178 L
.49784 .49237 L
Mistroke
.49932 .49318 L
.50059 .49413 L
.50164 .49516 L
.50245 .49622 L
.50303 .49726 L
.5034 .49824 L
.50357 .49914 L
.50358 .49992 L
.50343 .50059 L
.50318 .50112 L
.50284 .50152 L
.50244 .5018 L
.502 .50196 L
.50156 .50202 L
.50112 .50198 L
.50071 .50188 L
.50034 .50171 L
.50001 .50151 L
.49974 .50127 L
.49952 .50102 L
.49935 .50078 L
.49924 .50054 L
.49918 .50031 L
.49915 .50011 L
.49917 .49994 L
.49922 .4998 L
.49929 .49969 L
.49937 .49961 L
.49947 .49956 L
.49958 .49953 L
.49968 .49953 L
.49978 .49954 L
.49987 .49957 L
.49996 .49962 L
.50003 .49967 L
.50009 .49973 L
.50013 .49979 L
.50017 .49984 L
.50019 .4999 L
.5002 .49995 L
.5002 .49999 L
.50019 .50003 L
.50018 .50006 L
.50016 .50008 L
.50014 .5001 L
.50011 .50011 L
.50009 .50011 L
.50006 .50011 L
.50004 .5001 L
.50002 .5001 L
Mistroke
.5 .50008 L
.49999 .50007 L
.49997 .50006 L
.49996 .50004 L
.49996 .50003 L
.49995 .50002 L
.49995 .50001 L
.49995 .5 L
.49996 .49999 L
.49996 .49998 L
.49997 .49998 L
.49997 .49998 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-7.9585954 8.514058 -9.1643978 5.72616 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-9.8101355 3.1568519 -9.9599001 0.87378669 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-3.4966995 -5.5570089 -2.332957 -5.3204248 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
2.2423626 -1.0594227 2.3381309 -0.48446448 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
0.97564538 1.316779 0.69351191 1.2875069 MAarrowhead1
% End of user PostScript
.581 1 0 r
.24818 .66391 m
.22924 .59228 L
s
% Start of user PostScript
-0.5036329 0.32782445 -0.54151324 0.18456156 MAarrowhead1
% End of user PostScript
.266 1 0 r
.36697 .34593 m
.4008 .34592 L
s
% Start of user PostScript
-0.26605398 -0.30813947 -0.19839589 -0.30816419 MAarrowhead1
% End of user PostScript
0 1 .049 r
.55537 .45179 m
.56175 .46945 L
s
% Start of user PostScript
0.11074312 -0.096419505 0.12350497 -0.06109256 MAarrowhead1
% End of user PostScript
0 1 .364 r
.5356 .53556 m
.52758 .53645 L
s
% Start of user PostScript
0.071207083 0.071111457 0.055168018 0.072903622 MAarrowhead1
% End of user PostScript
0 1 .679 r
.48815 .51369 m
.48617 .50938 L
s
% Start of user PostScript
-0.023708813 0.027372028 -0.027666754 0.018751119 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49062 .49192 m
.4925 .49149 L
s
% Start of user PostScript
-0.018758126 -0.016151988 -0.015003048 -0.017029788 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50245 .49622 m
.50303 .49726 L
s
% Start of user PostScript
0.0048981434 -0.007566475 0.0060640097 -0.0054849652 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50244 .5018 m
.502 .50196 L
s
% Start of user PostScript
0.0048733385 0.0036004834 0.0040062918 0.0039221839 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49952 .50102 m
.49935 .50078 L
s
% Start of user PostScript
-0.00096147985 0.0020479039 -0.0012928153 0.0015508745 MAarrowhead1
% End of user PostScript
.033 0 1 r
.48305 0 m
.56277 .06291 L
.63966 .14305 L
.69862 .22459 L
.74018 .30406 L
.76546 .37861 L
.77606 .44604 L
.77392 .5048 L
.76117 .55394 L
.74003 .59303 L
.71268 .62213 L
.68121 .64167 L
.64755 .65241 L
.6134 .65533 L
.58019 .65157 L
.54911 .64235 L
.52105 .62892 L
.49666 .61249 L
.47631 .5942 L
.46018 .57508 L
.44823 .55602 L
.44027 .53779 L
.43598 .52097 L
.43493 .50601 L
.43666 .49322 L
.44064 .48275 L
.44636 .47465 L
.4533 .46886 L
.461 .46525 L
.46902 .46361 L
.47699 .46368 L
.4846 .4652 L
.49161 .46787 L
.49782 .47139 L
.50313 .47549 L
.50746 .47991 L
.51079 .48443 L
.51316 .48884 L
.51462 .49299 L
.51527 .49676 L
.5152 .50005 L
.51453 .50281 L
.51339 .50501 L
.51189 .50666 L
.51016 .50778 L
.50831 .50841 L
.50641 .5086 L
.50457 .50842 L
.50284 .50793 L
.50127 .5072 L
Mistroke
.49991 .5063 L
.49876 .50529 L
.49785 .50423 L
.49717 .50318 L
.49672 .50216 L
.49647 .50123 L
.4964 .50039 L
.49648 .49967 L
.49669 .49908 L
.497 .49862 L
.49739 .49829 L
.49781 .49809 L
.49825 .49799 L
.49869 .49799 L
.49912 .49806 L
.49951 .49821 L
.49986 .4984 L
.50015 .49863 L
.5004 .49887 L
.50059 .49912 L
.50072 .49936 L
.50081 .4996 L
.50084 .49981 L
.50084 .49999 L
.50081 .50015 L
.50075 .50027 L
.50066 .50036 L
.50057 .50043 L
.50047 .50046 L
.50036 .50048 L
.50026 .50047 L
.50016 .50044 L
.50008 .5004 L
.5 .50035 L
.49994 .5003 L
.49988 .50024 L
.49985 .50018 L
.49982 .50012 L
.49981 .50007 L
.4998 .50002 L
.4998 .49998 L
.49982 .49995 L
.49983 .49993 L
.49985 .49991 L
.49988 .49989 L
.4999 .49989 L
.49993 .49989 L
.49995 .49989 L
.49997 .4999 L
.49999 .49991 L
Mistroke
.50001 .49992 L
.50002 .49994 L
.50003 .49995 L
.50004 .49996 L
.50004 .49998 L
.50005 .49999 L
.50005 .5 L
.50004 .50001 L
.50004 .50001 L
.50004 .50002 L
.50003 .50002 L
.50003 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
8.6060308 3.4487493 7.6048222 4.4741857 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
6.4602361 5.156074 5.2410623 5.5223001 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.4746142 2.6619305 -1.895548 1.9749205 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.6676285 -1.1368897 -1.3882656 -1.2619339 MAarrowhead1
% End of user PostScript
.897 1 0 r
.63966 .14305 m
.69862 .22459 L
s
% Start of user PostScript
0.27932302 -0.71390312 0.39724811 -0.55081057 MAarrowhead1
% End of user PostScript
.581 1 0 r
.71268 .62213 m
.68121 .64167 L
s
% Start of user PostScript
0.42535421 0.24425985 0.36242626 0.28334106 MAarrowhead1
% End of user PostScript
.266 1 0 r
.47631 .5942 m
.46018 .57508 L
s
% Start of user PostScript
-0.047375048 0.18839569 -0.079636543 0.15015344 MAarrowhead1
% End of user PostScript
0 1 .049 r
.44636 .47465 m
.4533 .46886 L
s
% Start of user PostScript
-0.10728626 -0.050708783 -0.093399499 -0.062279551 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50313 .47549 m
.50746 .47991 L
s
% Start of user PostScript
0.0062583384 -0.049021552 0.014916015 -0.040176127 MAarrowhead1
% End of user PostScript
0 1 .679 r
.51339 .50501 m
.51189 .50666 L
s
% Start of user PostScript
0.026772876 0.010026188 0.02378616 0.013326714 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49991 .5063 m
.49876 .50529 L
s
% Start of user PostScript
-0.0001896977 0.012595472 -0.0024756576 0.010581086 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49669 .49908 m
.497 .49862 L
s
% Start of user PostScript
-0.0066117006 -0.0018356227 -0.0059907598 -0.0027513661 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49986 .4984 m
.50015 .49863 L
s
% Start of user PostScript
-0.00028749709 -0.0031988111 0.00030760735 -0.002748368 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50081 .50015 m
.50075 .50027 L
s
% Start of user PostScript
0.00161589 0.00029093271 0.0014928553 0.00053952586 MAarrowhead1
% End of user PostScript
.884 1 0 r
0 .17023 m
.01372 .15973 L
.09678 .12464 L
.18263 .1102 L
.26738 .11366 L
.34784 .13202 L
.42146 .16215 L
.4864 .20095 L
.54146 .24548 L
.58602 .29303 L
.61999 .34124 L
.64371 .38805 L
.65787 .43182 L
.66345 .47129 L
.66159 .50557 L
.65357 .53413 L
.6407 .55674 L
.62426 .57345 L
.6055 .58454 L
.58553 .59046 L
.56534 .59182 L
.54579 .58929 L
.52754 .5836 L
.51112 .57547 L
.49689 .56563 L
.48507 .55475 L
.47574 .54342 L
.46889 .53218 L
.46437 .52146 L
.46201 .51159 L
.46154 .50285 L
.46269 .4954 L
.46515 .48933 L
.4686 .48466 L
.47276 .48135 L
.47734 .47932 L
.48209 .47844 L
.48679 .47857 L
.49126 .47953 L
.49537 .48116 L
.499 .48328 L
.50209 .48572 L
.5046 .48835 L
.50653 .49102 L
.50788 .49362 L
.5087 .49606 L
.50904 .49826 L
.50897 .50018 L
.50854 .50179 L
.50785 .50306 L
Mistroke
.50695 .50401 L
.50592 .50465 L
.50482 .50499 L
.5037 .50509 L
.50261 .50496 L
.50159 .50466 L
.50068 .50421 L
.49988 .50368 L
.49922 .50308 L
.49869 .50245 L
.4983 .50183 L
.49804 .50123 L
.4979 .50068 L
.49787 .50019 L
.49793 .49977 L
.49806 .49943 L
.49825 .49917 L
.49847 .49898 L
.49873 .49886 L
.49899 .49881 L
.49925 .49881 L
.4995 .49886 L
.49973 .49895 L
.49993 .49906 L
.5001 .4992 L
.50025 .49934 L
.50035 .49949 L
.50043 .49964 L
.50048 .49977 L
.5005 .4999 L
.5005 .5 L
.50048 .50009 L
.50044 .50017 L
.50039 .50022 L
.50033 .50026 L
.50027 .50028 L
.50021 .50028 L
.50015 .50028 L
.50009 .50026 L
.50004 .50024 L
.5 .50021 L
.49996 .50017 L
.49993 .50014 L
.49991 .5001 L
.49989 .50007 L
.49988 .50004 L
.49988 .50001 L
.49988 .49999 L
.49989 .49997 L
.4999 .49995 L
Mistroke
.49991 .49994 L
.49993 .49994 L
.49994 .49993 L
.49996 .49993 L
.49997 .49994 L
.49998 .49994 L
.5 .49995 L
.50001 .49996 L
.50001 .49996 L
.50002 .49997 L
.50002 .49998 L
.50003 .49999 L
.50003 .49999 L
.50003 .5 L
.50003 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
5.72745 -2.3542889 5.9080033 -0.9410098 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
5.8233107 0.28300794 5.5193424 1.2992008 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
0.94954211 3.0012662 0.36172183 2.7024615 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.3880036 0.081949844 -1.3427651 -0.18374727 MAarrowhead1
% End of user PostScript
.897 1 0 r
.34784 .13202 m
.42146 .16215 L
s
% Start of user PostScript
-0.30432922 -0.73595988 -0.15708735 -0.67570874 MAarrowhead1
% End of user PostScript
.581 1 0 r
.66345 .47129 m
.66159 .50557 L
s
% Start of user PostScript
0.32689111 -0.057417422 0.32317973 0.011148873 MAarrowhead1
% End of user PostScript
.266 1 0 r
.54579 .58929 m
.52754 .5836 L
s
% Start of user PostScript
0.091573703 0.17858255 0.055076662 0.16719139 MAarrowhead1
% End of user PostScript
0 1 .049 r
.46201 .51159 m
.46154 .50285 L
s
% Start of user PostScript
-0.07598055 0.023187782 -0.07691056 0.0057036248 MAarrowhead1
% End of user PostScript
0 1 .364 r
.48679 .47857 m
.49126 .47953 L
s
% Start of user PostScript
-0.02642324 -0.042865581 -0.0174702 -0.040940524 MAarrowhead1
% End of user PostScript
0 1 .679 r
.5087 .49606 m
.50904 .49826 L
s
% Start of user PostScript
0.01740066 -0.007885245 0.018082648 -0.0034763775 MAarrowhead1
% End of user PostScript
0 1 .995 r
.5037 .50509 m
.50261 .50496 L
s
% Start of user PostScript
0.0073956376 0.010171858 0.0052223253 0.0099200495 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49804 .50123 m
.4979 .50068 L
s
% Start of user PostScript
-0.0039170396 0.0024587488 -0.0041950945 0.0013588044 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49899 .49881 m
.49925 .49881 L
s
% Start of user PostScript
-0.0020217804 -0.0023840393 -0.0014999062 -0.0023775553 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50043 .49964 m
.50048 .49977 L
s
% Start of user PostScript
0.0008637124 -0.00072685282 0.00095866495 -0.00045528206 MAarrowhead1
% End of user PostScript
1 .716 0 r
.87861 0 m
.901 .03423 L
.96845 .18048 L
s
.96845 .18048 m
1 .29333 L
s
1 .56145 m
.97739 .62721 L
.93353 .69417 L
.87937 .74261 L
.81874 .77357 L
.75509 .78863 L
.69146 .78972 L
.63039 .77906 L
.57391 .75894 L
.52354 .7317 L
.48032 .69957 L
.44482 .66461 L
.41723 .62869 L
.39738 .59339 L
.38482 .56001 L
.37888 .5296 L
.37874 .50289 L
.38347 .48035 L
.3921 .46221 L
.40366 .4485 L
.41722 .43904 L
.43191 .43355 L
.44696 .43159 L
.46172 .43268 L
.47564 .43629 L
.4883 .44187 L
.4994 .44888 L
.50874 .4568 L
.51623 .46518 L
.52186 .47361 L
.52572 .48174 L
.52793 .4893 L
.52867 .49607 L
.52815 .50191 L
.52658 .50673 L
.5242 .51052 L
.52123 .51327 L
.5179 .51505 L
.51438 .51595 L
.51085 .51606 L
.50746 .51551 L
.50431 .51443 L
.50149 .51295 L
.49907 .51118 L
.49707 .50926 L
.49551 .50727 L
.49438 .50531 L
.49366 .50345 L
.49331 .50175 L
.49328 .50026 L
Mistroke
.49352 .49899 L
.49399 .49797 L
.49462 .4972 L
.49536 .49666 L
.49617 .49634 L
.497 .49621 L
.49782 .49626 L
.4986 .49645 L
.4993 .49676 L
.49993 .49714 L
.50045 .49758 L
.50087 .49804 L
.50119 .49851 L
.50141 .49896 L
.50154 .49938 L
.50159 .49976 L
.50156 .50008 L
.50148 .50036 L
.50135 .50057 L
.50119 .50073 L
.501 .50083 L
.50081 .50088 L
.50061 .50089 L
.50043 .50086 L
.50025 .5008 L
.50009 .50072 L
.49996 .50063 L
.49985 .50052 L
.49976 .50041 L
.49969 .5003 L
.49965 .5002 L
.49963 .5001 L
.49963 .50002 L
.49964 .49995 L
.49966 .49989 L
.4997 .49985 L
.49974 .49982 L
.49978 .4998 L
.49983 .49979 L
.49988 .49979 L
.49992 .4998 L
.49996 .49982 L
.49999 .49984 L
.50002 .49986 L
.50005 .49989 L
.50006 .49992 L
.50008 .49994 L
.50008 .49996 L
.50009 .49999 L
.50009 .5 L
Mistroke
.50008 .50002 L
.50008 .50003 L
.50007 .50004 L
.50006 .50005 L
.50005 .50005 L
.50003 .50005 L
.50002 .50005 L
.50001 .50004 L
.50001 .50004 L
.5 .50004 L
.49999 .50003 L
.49999 .50002 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-0.81315526 7.1206568 -2.0748887 5.8532771 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-3.0510855 4.5552956 -3.7485488 3.2835309 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.9531908 -2.2209929 -2.420641 -2.4097878 MAarrowhead1
% End of user PostScript
1 .788 0 r
.87861 0 m
.901 .03423 L
s
% Start of user PostScript
0.60308029 -1.2356116 0.80199739 -0.9315434 MAarrowhead1
% End of user PostScript
.897 1 0 r
.87937 .74261 m
.81874 .77357 L
s
% Start of user PostScript
0.75873856 0.48521975 0.63747029 0.54714917 MAarrowhead1
% End of user PostScript
.581 1 0 r
.44482 .66461 m
.41723 .62869 L
s
% Start of user PostScript
-0.11035728 0.32922992 -0.16554074 0.25737867 MAarrowhead1
% End of user PostScript
.266 1 0 r
.40366 .4485 m
.41722 .43904 L
s
% Start of user PostScript
-0.19268209 -0.10300843 -0.16556769 -0.12191271 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50874 .4568 m
.51623 .46518 L
s
% Start of user PostScript
0.017472102 -0.086395023 0.032451034 -0.069632492 MAarrowhead1
% End of user PostScript
0 1 .364 r
.5242 .51052 m
.52123 .51327 L
s
% Start of user PostScript
0.048398178 0.021033586 0.042469156 0.026542808 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49907 .51118 m
.49707 .50926 L
s
% Start of user PostScript
-0.0018616404 0.022368172 -0.0058551604 0.018513119 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49399 .49797 m
.49462 .4972 L
s
% Start of user PostScript
-0.012028965 -0.0040559229 -0.010768792 -0.005609385 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49993 .49714 m
.50045 .49758 L
s
% Start of user PostScript
-0.00014908846 -0.0057209835 0.0008994136 -0.0048488796 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50148 .50036 m
.50135 .50057 L
s
% Start of user PostScript
0.0029587686 0.0007109354 0.0027010241 0.0011381065 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50009 .50072 m
.49996 .50063 L
s
% Start of user PostScript
0.00018635491 0.0014467208 -0.000085233632 0.0012532596 MAarrowhead1
% End of user PostScript
0 1 .928 r
.33949 1 m
.27878 .92895 L
.21024 .82123 L
.16429 .71796 L
.13914 .62255 L
.13246 .53756 L
.14155 .46471 L
.16352 .40497 L
.19541 .35862 L
.23437 .32536 L
.27769 .30443 L
.32295 .29468 L
.36802 .2947 L
.41113 .30293 L
.45088 .31772 L
.48621 .33743 L
.51642 .36047 L
.54112 .38539 L
.56021 .4109 L
.57383 .43587 L
.58231 .4594 L
.58614 .48077 L
.58591 .49949 L
.58228 .51522 L
.57594 .52781 L
.56758 .53727 L
.55787 .54372 L
.54739 .54739 L
.53671 .54857 L
.52627 .54762 L
.51646 .54492 L
.50756 .54086 L
.49979 .53581 L
.49328 .53015 L
.48808 .52418 L
.48419 .51821 L
.48156 .51247 L
.48009 .50715 L
.47965 .5024 L
.48009 .49831 L
.48126 .49495 L
.48299 .49233 L
.48513 .49044 L
.48751 .48923 L
.49002 .48865 L
.49252 .48862 L
.49491 .48904 L
.49713 .48984 L
.4991 .49091 L
.5008 .49218 L
Mistroke
.50219 .49355 L
.50327 .49497 L
.50404 .49635 L
.50453 .49766 L
.50476 .49885 L
.50476 .4999 L
.50458 .50079 L
.50423 .5015 L
.50378 .50203 L
.50324 .5024 L
.50267 .50261 L
.50207 .50269 L
.5015 .50264 L
.50095 .5025 L
.50045 .50228 L
.50002 .502 L
.49965 .50169 L
.49936 .50136 L
.49914 .50103 L
.49899 .50071 L
.4989 .50042 L
.49887 .50015 L
.49889 .49992 L
.49896 .49973 L
.49905 .49958 L
.49917 .49948 L
.4993 .49941 L
.49944 .49937 L
.49958 .49937 L
.49971 .49939 L
.49983 .49943 L
.49994 .49949 L
.50004 .49956 L
.50012 .49964 L
.50018 .49972 L
.50022 .49979 L
.50025 .49987 L
.50026 .49993 L
.50026 .49999 L
.50025 .50004 L
.50024 .50008 L
.50021 .50011 L
.50018 .50013 L
.50015 .50014 L
.50012 .50015 L
.50009 .50015 L
.50005 .50014 L
.50003 .50013 L
.5 .50011 L
.49998 .50009 L
Mistroke
.49997 .50008 L
.49995 .50006 L
.49994 .50004 L
.49994 .50002 L
.49994 .50001 L
.49994 .5 L
.49994 .49999 L
.49995 .49998 L
.49995 .49997 L
.49996 .49997 L
.49997 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.5 .49997 L
.5 .49998 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-6.2771831 -7.4282443 -4.6520831 -7.4039747 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-3.1018461 -7.0875187 -1.6764469 -6.5384397 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.1158277 -0.64225721 3.0977504 0.0262243 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
0.9224366 1.7152892 0.57002352 1.6136852 MAarrowhead1
% End of user PostScript
.897 1 0 r
.13914 .62255 m
.13246 .53756 L
s
% Start of user PostScript
-0.72171688 0.24510069 -0.73507645 0.075118258 MAarrowhead1
% End of user PostScript
.581 1 0 r
.36802 .2947 m
.41113 .30293 L
s
% Start of user PostScript
-0.2639588 -0.41059325 -0.17773024 -0.39413203 MAarrowhead1
% End of user PostScript
.266 1 0 r
.58231 .4594 m
.58614 .48077 L
s
% Start of user PostScript
0.1646279 -0.081199959 0.17228189 -0.038450558 MAarrowhead1
% End of user PostScript
0 1 .049 r
.53671 .54857 m
.52627 .54762 L
s
% Start of user PostScript
0.073414737 0.097145722 0.052538008 0.09524777 MAarrowhead1
% End of user PostScript
0 1 .364 r
.48156 .51247 m
.48009 .50715 L
s
% Start of user PostScript
-0.03688502 0.02493518 -0.039827962 0.014297351 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49002 .48865 m
.49252 .48862 L
s
% Start of user PostScript
-0.019968693 -0.022695161 -0.014969345 -0.022764962 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50404 .49635 m
.50453 .49766 L
s
% Start of user PostScript
0.0080861518 -0.0072963672 0.0090646307 -0.0046766398 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50267 .50261 m
.50207 .50269 L
s
% Start of user PostScript
0.0053330407 0.0052276663 0.0041496868 0.0053773278 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49914 .50103 m
.49899 .50071 L
s
% Start of user PostScript
-0.0017243913 0.0020635636 -0.0020255095 0.0014251134 MAarrowhead1
% End of user PostScript
0 .06 1 r
.4993 .49941 m
.49944 .49937 L
s
% Start of user PostScript
-0.0014022938 -0.0011847965 -0.0011257064 -0.0012539815 MAarrowhead1
% End of user PostScript
1 .255 0 r
.45764 0 m
.48274 .01524 L
.57178 .08829 L
.64366 .16608 L
.69825 .24474 L
.73615 .32097 L
.75853 .39212 L
.76697 .45617 L
.76338 .51169 L
.74983 .55782 L
.72847 .59424 L
.7014 .62104 L
.67063 .6387 L
.63797 .64798 L
.60503 .64985 L
.57319 .64542 L
.54353 .6359 L
.51689 .62246 L
.49385 .60629 L
.47476 .58846 L
.45974 .56996 L
.44874 .55163 L
.44156 .53418 L
.43787 .51816 L
.43725 .50399 L
.43925 .49193 L
.44335 .48213 L
.44906 .47462 L
.45589 .46933 L
.46339 .46612 L
.47114 .46478 L
.47881 .46506 L
.48609 .46669 L
.49276 .46939 L
.49865 .47289 L
.50365 .4769 L
.5077 .4812 L
.51079 .48556 L
.51295 .48979 L
.51425 .49375 L
.51477 .49733 L
.51462 .50044 L
.5139 .50303 L
.51275 .50509 L
.51127 .50661 L
.50957 .50762 L
.50777 .50817 L
.50595 .5083 L
.50418 .50808 L
.50252 .50757 L
Mistroke
.50104 .50684 L
.49974 .50595 L
.49867 .50497 L
.49782 .50395 L
.4972 .50293 L
.49679 .50196 L
.49657 .50107 L
.49652 .50027 L
.49662 .4996 L
.49684 .49905 L
.49715 .49862 L
.49753 .49832 L
.49794 .49813 L
.49837 .49805 L
.4988 .49806 L
.4992 .49815 L
.49957 .49829 L
.4999 .49848 L
.50018 .4987 L
.50041 .49894 L
.50059 .49918 L
.50071 .49942 L
.50079 .49964 L
.50082 .49984 L
.50081 .50001 L
.50077 .50016 L
.50071 .50027 L
.50063 .50036 L
.50054 .50042 L
.50044 .50045 L
.50034 .50046 L
.50024 .50045 L
.50015 .50042 L
.50006 .50038 L
.49999 .50033 L
.49993 .50028 L
.49988 .50022 L
.49985 .50017 L
.49982 .50011 L
.49981 .50006 L
.49981 .50002 L
.49981 .49998 L
.49982 .49995 L
.49984 .49993 L
.49986 .49991 L
.49988 .4999 L
.49991 .49989 L
.49993 .49989 L
.49995 .4999 L
.49998 .4999 L
Mistroke
.49999 .49992 L
.50001 .49993 L
.50002 .49994 L
.50003 .49995 L
.50004 .49997 L
.50004 .49998 L
.50005 .49999 L
.50004 .5 L
.50004 .50001 L
.50004 .50001 L
.50004 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
9.6483994 -1.4276124 9.4902051 0.55418111 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
8.9778973 2.1956501 8.1888135 3.4857893 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
0.5453977 4.3845377 -0.27685815 3.7946896 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-2.1863479 -0.31976612 -2.033334 -0.66773222 MAarrowhead1
% End of user PostScript
.897 1 0 r
.45764 0 m
.48274 .01524 L
s
% Start of user PostScript
-0.24503132 -1.0973805 -0.034529415 -0.96951831 MAarrowhead1
% End of user PostScript
.581 1 0 r
.76338 .51169 m
.74983 .55782 L
s
% Start of user PostScript
0.52675839 0.023371724 0.49966824 0.1156436 MAarrowhead1
% End of user PostScript
.266 1 0 r
.54353 .6359 m
.51689 .62246 L
s
% Start of user PostScript
0.087055959 0.27179233 0.033777198 0.24492701 MAarrowhead1
% End of user PostScript
0 1 .049 r
.43725 .50399 m
.43925 .49193 L
s
% Start of user PostScript
-0.12549562 0.0079779465 -0.12150896 -0.01613428 MAarrowhead1
% End of user PostScript
0 1 .364 r
.48609 .46669 m
.49276 .46939 L
s
% Start of user PostScript
-0.027812574 -0.066619813 -0.014472634 -0.061213978 MAarrowhead1
% End of user PostScript
0 1 .679 r
.51477 .49733 m
.51462 .50044 L
s
% Start of user PostScript
0.029540685 -0.0053355181 0.029232029 0.00088379342 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50418 .50808 m
.50252 .50757 L
s
% Start of user PostScript
0.0083520213 0.016158489 0.0050468275 0.015139864 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49657 .50107 m
.49652 .50027 L
s
% Start of user PostScript
-0.0068623797 0.0021326674 -0.0069533708 0.00054750415 MAarrowhead1
% End of user PostScript
0 .375 1 r
.4988 .49806 m
.4992 .49815 L
s
% Start of user PostScript
-0.002406533 -0.0038768105 -0.0015960826 -0.0037057637 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50079 .49964 m
.50082 .49984 L
s
% Start of user PostScript
0.0015705719 -0.00072191403 0.001633985 -0.00032236976 MAarrowhead1
% End of user PostScript
0 .298 1 r
.405 0 m
.45618 .02813 L
.54403 .09432 L
.61601 .1661 L
.6718 .23972 L
.71176 .31192 L
.73684 .38006 L
.74842 .44205 L
.74821 .49641 L
.7381 .54218 L
.7201 .57892 L
.69618 .6066 L
.66826 .62558 L
.6381 .63649 L
.60725 .64019 L
.57707 .63769 L
.54865 .63008 L
.52284 .61849 L
.50027 .60403 L
.48131 .58773 L
.46614 .57053 L
.45476 .55328 L
.44702 .53667 L
.44264 .52125 L
.44125 .50746 L
.44244 .49559 L
.44574 .4858 L
.45068 .47815 L
.4568 .4726 L
.46366 .46904 L
.47087 .46728 L
.4781 .46712 L
.48503 .4683 L
.49146 .47056 L
.49719 .47363 L
.50211 .47726 L
.50616 .48122 L
.50932 .4853 L
.51159 .4893 L
.51304 .4931 L
.51373 .49656 L
.51376 .4996 L
.51324 .50217 L
.51227 .50424 L
.51097 .50581 L
.50943 .50689 L
.50777 .50753 L
.50606 .50776 L
.50438 .50764 L
.5028 .50724 L
Mistroke
.50136 .50661 L
.5001 .50582 L
.49903 .50492 L
.49818 .50397 L
.49753 .50302 L
.49709 .50209 L
.49684 .50124 L
.49675 .50046 L
.4968 .4998 L
.49698 .49925 L
.49725 .49882 L
.49758 .4985 L
.49796 .4983 L
.49836 .49819 L
.49876 .49818 L
.49914 .49824 L
.4995 .49836 L
.49982 .49853 L
.5001 .49873 L
.50033 .49894 L
.5005 .49917 L
.50063 .49939 L
.50072 .4996 L
.50076 .4998 L
.50076 .49997 L
.50074 .50011 L
.50068 .50023 L
.50061 .50032 L
.50053 .50038 L
.50044 .50041 L
.50034 .50043 L
.50025 .50042 L
.50016 .5004 L
.50008 .50037 L
.50001 .50033 L
.49995 .50028 L
.4999 .50022 L
.49987 .50017 L
.49984 .50012 L
.49983 .50007 L
.49982 .50003 L
.49982 .49999 L
.49983 .49996 L
.49985 .49994 L
.49986 .49992 L
.49989 .49991 L
.49991 .4999 L
.49993 .4999 L
.49995 .4999 L
.49997 .49991 L
Mistroke
.49999 .49992 L
.5 .49993 L
.50002 .49994 L
.50003 .49995 L
.50003 .49997 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50004 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
1.6864995 4.6732007 0.76220275 4.245823 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-0.044184886 3.7172686 -0.71934571 3.1249174 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.9490703 -0.53558179 -1.7670322 -0.80640611 MAarrowhead1
% End of user PostScript
1 .788 0 r
.45618 .02813 m
.54403 .09432 L
s
% Start of user PostScript
-0.087645711 -0.94374523 0.088050425 -0.81136563 MAarrowhead1
% End of user PostScript
.897 1 0 r
.7381 .54218 m
.7201 .57892 L
s
% Start of user PostScript
0.4762036 0.084358743 0.44019645 0.15783608 MAarrowhead1
% End of user PostScript
.581 1 0 r
.52284 .61849 m
.50027 .60403 L
s
% Start of user PostScript
0.045689184 0.23698974 0.00054259143 0.20806022 MAarrowhead1
% End of user PostScript
.266 1 0 r
.44244 .49559 m
.44574 .4858 L
s
% Start of user PostScript
-0.1151204 -0.0088208251 -0.10852367 -0.028402738 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49146 .47056 m
.49719 .47363 L
s
% Start of user PostScript
-0.017087099 -0.058886916 -0.0056205677 -0.05274301 MAarrowhead1
% End of user PostScript
0 1 .364 r
.51376 .4996 m
.51324 .50217 L
s
% Start of user PostScript
0.027524447 -0.0008020303 0.026477443 0.0043374351 MAarrowhead1
% End of user PostScript
0 1 .679 r
.5028 .50724 m
.50136 .50661 L
s
% Start of user PostScript
0.0056052144 0.014480785 0.0027246679 0.013225559 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49675 .50046 m
.4968 .4998 L
s
% Start of user PostScript
-0.0065040553 0.0009299013 -0.0063915025 -0.00040093729 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49914 .49824 m
.4995 .49836 L
s
% Start of user PostScript
-0.0017110625 -0.0035239035 -0.00099503797 -0.0032816534 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50076 .4998 m
.50076 .49997 L
s
% Start of user PostScript
0.001517372 -0.00040747321 0.0015258177 -0.000067044713 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50025 .50042 m
.50016 .5004 L
s
% Start of user PostScript
0.00049865847 0.00084838278 0.00032251601 0.00080585611 MAarrowhead1
% End of user PostScript
1 0 .706 r
.67536 1 m
.59389 .96419 L
.50527 .90833 L
.43067 .84511 L
.37081 .77823 L
.32574 .71097 L
.29486 .64606 L
.27715 .58574 L
.27119 .53167 L
.27534 .48502 L
.28781 .44645 L
.30676 .41622 L
.3304 .39419 L
.35702 .37993 L
.38509 .37276 L
.41324 .37183 L
.44035 .37618 L
.46549 .38477 L
.48797 .3966 L
.50733 .41066 L
.52328 .42604 L
.53574 .44191 L
.54478 .45755 L
.55057 .47238 L
.55341 .48593 L
.55366 .49787 L
.55172 .50798 L
.54802 .51614 L
.543 .52235 L
.53707 .52667 L
.5306 .52923 L
.52395 .53021 L
.51741 .52982 L
.51122 .52831 L
.50558 .5259 L
.50062 .52285 L
.49643 .51937 L
.49306 .51567 L
.49051 .51195 L
.48874 .50834 L
.48771 .50498 L
.48734 .50196 L
.48753 .49934 L
.48819 .49717 L
.48922 .49547 L
.49051 .49422 L
.49197 .4934 L
.49352 .49297 L
.49509 .4929 L
.49659 .49312 L
Mistroke
.49799 .49358 L
.49925 .49422 L
.50033 .49499 L
.50123 .49584 L
.50194 .49672 L
.50245 .49759 L
.50278 .49841 L
.50295 .49917 L
.50297 .49984 L
.50287 .5004 L
.50268 .50086 L
.5024 .50122 L
.50208 .50146 L
.50172 .50161 L
.50135 .50167 L
.50099 .50165 L
.50065 .50158 L
.50033 .50144 L
.50005 .50128 L
.49982 .50109 L
.49963 .50088 L
.49948 .50068 L
.49938 .50048 L
.49932 .50029 L
.4993 .50012 L
.49931 .49997 L
.49934 .49985 L
.4994 .49976 L
.49947 .49968 L
.49955 .49964 L
.49964 .49961 L
.49972 .49961 L
.49981 .49962 L
.49988 .49964 L
.49995 .49968 L
.50001 .49972 L
.50006 .49977 L
.5001 .49981 L
.50013 .49986 L
.50015 .49991 L
.50016 .49995 L
.50016 .49999 L
.50016 .50002 L
.50015 .50005 L
.50013 .50007 L
.50012 .50008 L
.5001 .50009 L
.50008 .50009 L
.50006 .50009 L
.50004 .50009 L
Mistroke
.50002 .50008 L
.5 .50007 L
.49999 .50006 L
.49998 .50005 L
.49997 .50004 L
.49997 .50003 L
.49996 .50002 L
.49996 .50001 L
.49996 .5 L
.49996 .49999 L
.49997 .49999 L
.49997 .49998 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-4.8021669 9.87454 -6.3925923 7.4477158 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-7.4720483 5.1126691 -8.0794001 2.9480437 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-4.0772396 -4.6059753 -3.0615573 -4.6246221 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.6364463 -1.4936387 1.8375686 -0.96079141 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
1.0881708 1.0603038 0.84787497 1.0918418 MAarrowhead1
% End of user PostScript
.581 1 0 r
.32574 .71097 m
.29486 .64606 L
s
% Start of user PostScript
-0.3485267 0.42193387 -0.41027176 0.29212985 MAarrowhead1
% End of user PostScript
.266 1 0 r
.35702 .37993 m
.38509 .37276 L
s
% Start of user PostScript
-0.2859605 -0.24013546 -0.22982601 -0.25447531 MAarrowhead1
% End of user PostScript
0 1 .049 r
.53574 .44191 m
.54478 .45755 L
s
% Start of user PostScript
0.071487965 -0.11618844 0.089552172 -0.084904159 MAarrowhead1
% End of user PostScript
0 1 .364 r
.53707 .52667 m
.5306 .52923 L
s
% Start of user PostScript
0.074131298 0.053342391 0.061201998 0.058460235 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49306 .51567 m
.49051 .51195 L
s
% Start of user PostScript
-0.013880767 0.031348613 -0.018989028 0.023892754 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49051 .49422 m
.49197 .4934 L
s
% Start of user PostScript
-0.01898234 -0.011569141 -0.016052279 -0.013208141 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50123 .49584 m
.50194 .49672 L
s
% Start of user PostScript
0.0024632412 -0.0083153883 0.0038710617 -0.0065596611 MAarrowhead1
% End of user PostScript
0 .375 1 r
.5024 .50122 m
.50208 .50146 L
s
% Start of user PostScript
0.0048055246 0.0024325036 0.0041541573 0.0029254424 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49982 .50109 m
.49963 .50088 L
s
% Start of user PostScript
-0.00036446892 0.0021735326 -0.00074456517 0.0017654977 MAarrowhead1
% End of user PostScript
0 1 .709 r
.60995 0 m
.68091 .07658 L
.75019 .17609 L
.79835 .27257 L
.82684 .36266 L
.83769 .44378 L
.83329 .51413 L
.81627 .57261 L
.78934 .61881 L
.75515 .65283 L
.71626 .67528 L
.67496 .68712 L
.63329 .68958 L
.59298 .68405 L
.55543 .67206 L
.52169 .65511 L
.49249 .63468 L
.46829 .61214 L
.44924 .58874 L
.43527 .56554 L
.42614 .54345 L
.42143 .52317 L
.42061 .50522 L
.4231 .48994 L
.42827 .47751 L
.43548 .46798 L
.44411 .46126 L
.45358 .45717 L
.4634 .45545 L
.4731 .45578 L
.48232 .45783 L
.49076 .46124 L
.49822 .46565 L
.50456 .47073 L
.50969 .47616 L
.51361 .48167 L
.51636 .48703 L
.51802 .49205 L
.51868 .49658 L
.5185 .50052 L
.5176 .50381 L
.51614 .50642 L
.51427 .50835 L
.51213 .50964 L
.50985 .51033 L
.50754 .5105 L
.5053 .51023 L
.50321 .50958 L
.50133 .50866 L
.49969 .50754 L
Mistroke
.49833 .5063 L
.49726 .50501 L
.49646 .50372 L
.49594 .50249 L
.49566 .50136 L
.4956 .50036 L
.49573 .4995 L
.496 .4988 L
.4964 .49826 L
.49687 .49788 L
.49739 .49764 L
.49793 .49754 L
.49847 .49755 L
.49899 .49765 L
.49946 .49784 L
.49987 .49808 L
.50023 .49836 L
.50052 .49866 L
.50074 .49896 L
.5009 .49926 L
.50099 .49954 L
.50103 .49979 L
.50103 .50001 L
.50098 .5002 L
.5009 .50035 L
.5008 .50046 L
.50068 .50053 L
.50055 .50057 L
.50043 .50058 L
.5003 .50057 L
.50019 .50053 L
.50008 .50048 L
.49999 .50042 L
.49991 .50035 L
.49985 .50028 L
.49981 .50021 L
.49978 .50014 L
.49976 .50008 L
.49976 .50002 L
.49976 .49998 L
.49978 .49994 L
.4998 .49991 L
.49982 .49988 L
.49985 .49987 L
.49988 .49986 L
.49991 .49986 L
.49994 .49987 L
.49997 .49988 L
.49999 .49989 L
.50001 .49991 L
Mistroke
.50003 .49992 L
.50004 .49994 L
.50005 .49996 L
.50005 .49997 L
.50006 .49999 L
.50006 .5 L
.50005 .50001 L
.50005 .50002 L
.50004 .50002 L
.50004 .50003 L
.50003 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.5 .50003 L
.5 .50002 L
.5 .50002 L
.49999 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
0.70141228 5.5535284 -0.34053025 4.8083482 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-1.2015785 3.990517 -1.8763408 3.1444033 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.3098201 -1.1775178 -1.9952203 -1.4131469 MAarrowhead1
% End of user PostScript
1 .788 0 r
.60995 0 m
.68091 .07658 L
s
% Start of user PostScript
0.17952517 -1.0435826 0.3618251 -0.84684654 MAarrowhead1
% End of user PostScript
.897 1 0 r
.78934 .61881 m
.75515 .65283 L
s
% Start of user PostScript
0.5786711 0.23761062 0.51030851 0.30566266 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49249 .63468 m
.46829 .61214 L
s
% Start of user PostScript
-0.015013767 0.26935748 -0.06342467 0.22428355 MAarrowhead1
% End of user PostScript
.266 1 0 r
.42827 .47751 m
.43548 .46798 L
s
% Start of user PostScript
-0.14345761 -0.044975817 -0.12904717 -0.064036102 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49822 .46565 m
.50456 .47073 L
s
% Start of user PostScript
-0.0035506151 -0.068696635 0.0091159329 -0.058545196 MAarrowhead1
% End of user PostScript
0 1 .364 r
.5176 .50381 m
.51614 .50642 L
s
% Start of user PostScript
0.035196697 0.0076177187 0.032283526 0.012831166 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50133 .50866 m
.49969 .50754 L
s
% Start of user PostScript
0.0026550541 0.01732552 -0.00061576304 0.015085789 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49573 .4995 m
.496 .4988 L
s
% Start of user PostScript
-0.0085451639 -0.0010025584 -0.0079921513 -0.0024014156 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49946 .49784 m
.49987 .49808 L
s
% Start of user PostScript
-0.0010867568 -0.0043231083 -0.00025222383 -0.0038415211 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50103 .50001 m
.50098 .5002 L
s
% Start of user PostScript
0.002052267 0.000028659106 0.0019580883 0.00039796125 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50019 .50053 m
.50008 .50048 L
s
% Start of user PostScript
0.00037174993 0.0010675143 0.00016119513 0.00096742765 MAarrowhead1
% End of user PostScript
0 .635 1 r
0 .02501 m
.04723 .01182 L
.15577 .00609 L
.26066 .02102 L
.35827 .05272 L
.44589 .09721 L
.5216 .15067 L
.58429 .20951 L
.63355 .27052 L
.66956 .33092 L
.693 .38838 L
.70497 .44108 L
.70682 .48767 L
.7001 .52728 L
.68645 .55944 L
.66754 .58406 L
.64497 .60136 L
.62022 .61183 L
.59464 .61615 L
.56938 .61514 L
.54541 .60968 L
.52346 .60071 L
.5041 .58915 L
.48769 .57588 L
.4744 .56171 L
.46427 .54735 L
.45719 .5334 L
.45296 .52035 L
.4513 .50858 L
.45184 .49836 L
.45423 .48985 L
.45806 .48311 L
.46296 .47812 L
.46855 .47482 L
.4745 .47305 L
.48051 .47264 L
.48634 .47339 L
.49178 .47508 L
.49667 .4775 L
.50092 .48043 L
.50444 .48368 L
.50722 .48705 L
.50927 .4904 L
.51061 .4936 L
.51132 .49654 L
.51146 .49914 L
.51112 .50137 L
.51039 .50318 L
.50936 .50457 L
.50812 .50556 L
Mistroke
.50676 .50616 L
.50534 .50642 L
.50394 .50639 L
.50261 .5061 L
.50138 .50562 L
.5003 .50499 L
.49938 .50426 L
.49863 .50347 L
.49806 .50268 L
.49765 .5019 L
.49741 .50118 L
.49731 .50052 L
.49733 .49995 L
.49745 .49947 L
.49766 .49909 L
.49793 .49881 L
.49824 .49862 L
.49856 .49851 L
.4989 .49848 L
.49922 .49852 L
.49952 .49861 L
.4998 .49874 L
.50004 .4989 L
.50023 .49908 L
.50039 .49927 L
.50051 .49946 L
.50058 .49963 L
.50062 .4998 L
.50063 .49994 L
.50062 .50007 L
.50058 .50017 L
.50052 .50025 L
.50045 .5003 L
.50038 .50034 L
.5003 .50036 L
.50022 .50035 L
.50015 .50034 L
.50008 .50031 L
.50002 .50028 L
.49997 .50024 L
.49993 .5002 L
.49989 .50015 L
.49987 .50011 L
.49986 .50007 L
.49985 .50003 L
.49985 .5 L
.49986 .49997 L
.49987 .49995 L
.49988 .49993 L
.4999 .49992 L
Mistroke
.49992 .49992 L
.49994 .49992 L
.49996 .49992 L
.49997 .49992 L
.49999 .49993 L
.5 .49994 L
.50001 .49995 L
.50002 .49996 L
.50003 .49997 L
.50003 .49998 L
.50003 .49999 L
.50004 .5 L
.50003 .5 L
.50003 .50001 L
.50003 .50001 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
5.9972909 3.090405 5.1744322 3.6970033 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
4.2767538 4.0583744 3.3521651 4.1994367 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.3129552 1.6733025 -1.5608242 1.1711364 MAarrowhead1
% End of user PostScript
1 .788 0 r
0 .02501 m
.04723 .01182 L
s
% Start of user PostScript
-1.1210152 -0.91618356 -0.90554627 -0.97635774 MAarrowhead1
% End of user PostScript
.897 1 0 r
.63355 .27052 m
.66956 .33092 L
s
% Start of user PostScript
0.2670942 -0.45895196 0.33911169 -0.3381616 MAarrowhead1
% End of user PostScript
.581 1 0 r
.64497 .60136 m
.62022 .61183 L
s
% Start of user PostScript
0.28994276 0.20272428 0.24044985 0.22367 MAarrowhead1
% End of user PostScript
.266 1 0 r
.4744 .56171 m
.46427 .54735 L
s
% Start of user PostScript
-0.051205623 0.12342554 -0.07146719 0.094697987 MAarrowhead1
% End of user PostScript
0 1 .049 r
.46296 .47812 m
.46855 .47482 L
s
% Start of user PostScript
-0.07408787 -0.043751013 -0.062907459 -0.050368579 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50444 .48368 m
.50722 .48705 L
s
% Start of user PostScript
0.0088813987 -0.032648339 0.014443102 -0.025898783 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50936 .50457 m
.50812 .50556 L
s
% Start of user PostScript
0.018718872 0.0091382244 0.016243006 0.011111342 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49938 .50426 m
.49863 .50347 L
s
% Start of user PostScript
-0.0012437327 0.0085129937 -0.0027404071 0.0069483311 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49766 .49909 m
.49793 .49881 L
s
% Start of user PostScript
-0.0046788979 -0.0018230564 -0.0041440262 -0.0023887277 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50004 .4989 m
.50023 .49908 L
s
% Start of user PostScript
0.00007014385 -0.0021914489 0.0004662614 -0.0018342072 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50058 .50017 m
.50052 .50025 L
s
% Start of user PostScript
0.0011573484 0.00033876436 0.0010454776 0.0004963187 MAarrowhead1
% End of user PostScript
0 1 .753 r
1 .95739 m
.97975 .9651 L
.87424 .97938 L
.77071 .97219 L
.67297 .94728 L
.584 .90847 L
.50596 .85957 L
.44021 .80413 L
.3874 .74544 L
.34758 .68635 L
.32024 .62929 L
.30448 .57623 L
.29907 .52864 L
.30257 .48754 L
.3134 .45354 L
.32995 .42685 L
.35064 .40737 L
.37399 .39473 L
.39862 .38832 L
.42336 .38741 L
.44719 .39115 L
.4693 .39864 L
.4891 .40898 L
.50615 .4213 L
.52022 .43479 L
.53122 .44872 L
.5392 .46247 L
.54434 .47551 L
.54688 .48744 L
.54713 .49795 L
.54546 .50686 L
.54225 .51406 L
.53785 .51954 L
.53265 .52337 L
.52698 .52564 L
.52114 .52653 L
.51539 .52621 L
.50995 .52489 L
.50499 .52279 L
.50062 .52012 L
.49693 .51707 L
.49395 .51383 L
.4917 .51055 L
.49014 .50738 L
.48922 .50442 L
.48888 .50176 L
.48904 .49946 L
.48961 .49755 L
.49051 .49604 L
.49164 .49494 L
Mistroke
.49293 .49421 L
.49429 .49383 L
.49566 .49376 L
.49698 .49395 L
.49822 .49435 L
.49932 .49492 L
.50028 .49559 L
.50107 .49633 L
.50169 .49711 L
.50214 .49787 L
.50244 .49859 L
.50259 .49926 L
.50261 .49985 L
.50253 .50035 L
.50235 .50075 L
.50212 .50106 L
.50183 .50128 L
.50152 .50141 L
.50119 .50147 L
.50087 .50145 L
.50057 .50138 L
.50029 .50127 L
.50005 .50113 L
.49984 .50096 L
.49968 .50078 L
.49955 .5006 L
.49946 .50042 L
.49941 .50026 L
.49938 .50011 L
.49939 .49998 L
.49942 .49987 L
.49947 .49979 L
.49953 .49972 L
.4996 .49968 L
.49968 .49966 L
.49975 .49965 L
.49983 .49966 L
.4999 .49969 L
.49996 .49972 L
.50001 .49975 L
.50006 .49979 L
.50009 .49984 L
.50012 .49988 L
.50013 .49992 L
.50014 .49996 L
.50014 .49999 L
.50014 .50002 L
.50013 .50004 L
.50012 .50006 L
.5001 .50007 L
Mistroke
.50009 .50008 L
.50007 .50008 L
.50005 .50008 L
.50003 .50008 L
.50002 .50007 L
.5 .50006 L
.49999 .50005 L
.49998 .50004 L
.49998 .50003 L
.49997 .50002 L
.49997 .50001 L
.49997 .50001 L
.49997 .5 L
.49997 .49999 L
.49997 .49999 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-4.1870883 8.711376 -5.5923126 6.5794175 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-6.548303 4.5266211 -7.0889512 2.6223685 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-3.5972074 -4.0428976 -2.7048937 -4.0626178 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.4329232 -1.3206528 1.6113592 -0.85206692 MAarrowhead1
% End of user PostScript
.897 1 0 r
.97975 .9651 m
.87424 .97938 L
s
% Start of user PostScript
0.9595065 0.9301964 0.74848607 0.9587502 MAarrowhead1
% End of user PostScript
.581 1 0 r
.34758 .68635 m
.32024 .62929 L
s
% Start of user PostScript
-0.30484354 0.37269807 -0.35951414 0.25858984 MAarrowhead1
% End of user PostScript
.266 1 0 r
.37399 .39473 m
.39862 .38832 L
s
% Start of user PostScript
-0.25202374 -0.21054065 -0.2027508 -0.22335104 MAarrowhead1
% End of user PostScript
0 1 .049 r
.53122 .44872 m
.5392 .46247 L
s
% Start of user PostScript
0.062431613 -0.10255078 0.078404371 -0.075059706 MAarrowhead1
% End of user PostScript
0 1 .364 r
.53265 .52337 m
.52698 .52564 L
s
% Start of user PostScript
0.065304723 0.046733897 0.053961718 0.051282802 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49395 .51383 m
.4917 .51055 L
s
% Start of user PostScript
-0.012093754 0.027651494 -0.01660607 0.021102264 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49164 .49494 m
.49293 .49421 L
s
% Start of user PostScript
-0.016715385 -0.010126426 -0.01414637 -0.01157929 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50107 .49633 m
.50169 .49711 L
s
% Start of user PostScript
0.0021371826 -0.0073307488 0.0033797909 -0.0057891828 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50212 .50106 m
.50183 .50128 L
s
% Start of user PostScript
0.0042300155 0.0021265162 0.0036593281 0.0025627268 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49984 .50096 m
.49968 .50078 L
s
% Start of user PostScript
-0.00031316058 0.0019152533 -0.00064843698 0.0015571619 MAarrowhead1
% End of user PostScript
0 1 .037 r
.45934 1 m
.39052 .93825 L
.31544 .84942 L
.2598 .76088 L
.22269 .67612 L
.20263 .59793 L
.19769 .52837 L
.20562 .46885 L
.22406 .42013 L
.25057 .38242 L
.2828 .35547 L
.31854 .33862 L
.35579 .33094 L
.39284 .33125 L
.42822 .33825 L
.46079 .3506 L
.48971 .36695 L
.51439 .38598 L
.53453 .40653 L
.55006 .42751 L
.56109 .44802 L
.56791 .46732 L
.57092 .48483 L
.57061 .50013 L
.56753 .51297 L
.56224 .52323 L
.55531 .53092 L
.54728 .53613 L
.53865 .53906 L
.52986 .53996 L
.52129 .53912 L
.51324 .53685 L
.50595 .53347 L
.4996 .52929 L
.49428 .52461 L
.49005 .5197 L
.48689 .51479 L
.48476 .51008 L
.48359 .50572 L
.48326 .50183 L
.48365 .49849 L
.48463 .49575 L
.48607 .49362 L
.48784 .49209 L
.48981 .49112 L
.49187 .49066 L
.49392 .49064 L
.49589 .49101 L
.49771 .49167 L
.49932 .49256 L
Mistroke
.50071 .49361 L
.50184 .49474 L
.50272 .4959 L
.50335 .49704 L
.50374 .49812 L
.50392 .49909 L
.50392 .49995 L
.50376 .50067 L
.50347 .50125 L
.50309 .50169 L
.50265 .50198 L
.50217 .50215 L
.50169 .50221 L
.50121 .50217 L
.50076 .50205 L
.50036 .50187 L
.5 .50164 L
.4997 .50138 L
.49946 .50111 L
.49928 .50084 L
.49916 .50058 L
.49909 .50033 L
.49907 .50012 L
.49909 .49993 L
.49914 .49977 L
.49922 .49965 L
.49932 .49957 L
.49943 .49951 L
.49954 .49948 L
.49966 .49948 L
.49976 .4995 L
.49987 .49954 L
.49996 .49958 L
.50003 .49964 L
.5001 .4997 L
.50015 .49977 L
.50018 .49983 L
.50021 .49989 L
.50022 .49995 L
.50022 .49999 L
.50021 .50003 L
.50019 .50007 L
.50017 .50009 L
.50015 .50011 L
.50012 .50012 L
.5001 .50012 L
.50007 .50012 L
.50004 .50011 L
.50002 .5001 L
.5 .50009 L
Mistroke
.49998 .50008 L
.49997 .50006 L
.49996 .50005 L
.49995 .50003 L
.49995 .50002 L
.49995 .50001 L
.49995 .5 L
.49995 .49999 L
.49996 .49998 L
.49996 .49998 L
.49997 .49997 L
.49997 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49998 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-8.7959523 9.1969748 -10.089847 6.1492126 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-10.772526 3.3448421 -10.914815 0.85693428 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-3.776192 -6.0853811 -2.5040951 -5.816652 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
2.4655546 -1.1324941 2.5649577 -0.50539709 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
1.0558516 1.4433796 0.74718199 1.4088167 MAarrowhead1
% End of user PostScript
.581 1 0 r
.22269 .67612 m
.20263 .59793 L
s
% Start of user PostScript
-0.55461626 0.35224434 -0.59473457 0.19585669 MAarrowhead1
% End of user PostScript
.266 1 0 r
.35579 .33094 m
.39284 .33125 L
s
% Start of user PostScript
-0.28841022 -0.33812417 -0.21432155 -0.33750776 MAarrowhead1
% End of user PostScript
0 1 .049 r
.56109 .44802 m
.56791 .46732 L
s
% Start of user PostScript
0.12218517 -0.10395735 0.13582402 -0.065361464 MAarrowhead1
% End of user PostScript
0 1 .364 r
.53865 .53906 m
.52986 .53996 L
s
% Start of user PostScript
0.077298553 0.078124493 0.059718066 0.079923827 MAarrowhead1
% End of user PostScript
0 1 .679 r
.48689 .51479 m
.48476 .51008 L
s
% Start of user PostScript
-0.026222414 0.029585403 -0.03047455 0.020158747 MAarrowhead1
% End of user PostScript
0 1 .995 r
.48981 .49112 m
.49187 .49066 L
s
% Start of user PostScript
-0.020387348 -0.017769477 -0.016267034 -0.018689782 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50272 .4959 m
.50335 .49704 L
s
% Start of user PostScript
0.0054356191 -0.0081940642 0.006692499 -0.0059160083 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50265 .50198 m
.50217 .50215 L
s
% Start of user PostScript
0.0053022734 0.0039676215 0.0043497621 0.0043097406 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49946 .50111 m
.49928 .50084 L
s
% Start of user PostScript
-0.0010723335 0.0022212273 -0.0014304336 0.0016767626 MAarrowhead1
% End of user PostScript
.214 1 0 r
.2334 1 m
.16499 .89658 L
.10728 .77322 L
.07453 .65874 L
.06406 .55629 L
.07271 .46804 L
.09705 .39524 L
.1336 .33831 L
.17893 .29699 L
.22983 .27042 L
.28335 .25729 L
.33695 .25598 L
.38847 .26464 L
.43617 .28132 L
.47877 .30407 L
.51538 .331 L
.54549 .36036 L
.56895 .3906 L
.58589 .42035 L
.59668 .44852 L
.60186 .47422 L
.60214 .49682 L
.59829 .51593 L
.59113 .53133 L
.58147 .543 L
.57011 .55108 L
.55777 .55582 L
.54509 .55757 L
.53265 .55674 L
.5209 .55377 L
.51021 .54912 L
.50082 .54326 L
.4929 .53661 L
.48654 .52956 L
.48174 .52246 L
.47844 .51561 L
.47653 .50923 L
.47587 .5035 L
.47628 .49856 L
.47757 .49446 L
.47955 .49125 L
.48203 .4889 L
.48483 .48737 L
.48779 .48659 L
.49076 .48648 L
.49362 .48692 L
.49628 .48781 L
.49866 .48905 L
.50072 .49053 L
.50241 .49215 L
Mistroke
.50374 .49382 L
.5047 .49547 L
.50532 .49704 L
.50563 .49848 L
.50566 .49974 L
.50546 .50081 L
.50508 .50168 L
.50455 .50234 L
.50393 .5028 L
.50325 .50308 L
.50255 .50319 L
.50186 .50315 L
.5012 .50299 L
.50061 .50274 L
.50008 .50242 L
.49964 .50205 L
.49928 .50167 L
.49901 .50127 L
.49882 .50089 L
.49871 .50054 L
.49866 .50022 L
.49868 .49994 L
.49875 .49971 L
.49886 .49953 L
.49899 .49939 L
.49915 .49931 L
.49931 .49926 L
.49948 .49925 L
.49964 .49927 L
.49978 .49932 L
.49992 .49939 L
.50003 .49947 L
.50013 .49956 L
.5002 .49965 L
.50026 .49974 L
.50029 .49983 L
.50031 .49991 L
.50031 .49998 L
.5003 .50004 L
.50028 .50009 L
.50025 .50013 L
.50022 .50015 L
.50018 .50017 L
.50014 .50018 L
.50011 .50017 L
.50007 .50017 L
.50004 .50015 L
.50001 .50014 L
.49998 .50012 L
.49996 .50009 L
Mistroke
.49995 .50007 L
.49994 .50005 L
.49993 .50003 L
.49993 .50001 L
.49993 .5 L
.49993 .49998 L
.49994 .49997 L
.49994 .49997 L
.49995 .49996 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49999 .49996 L
.49999 .49997 L
.5 .49997 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
3.6860454 -0.86834687 3.6844319 -0.060465768 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
3.535738 0.6201337 3.2695228 1.1666687 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
0.3424809 1.7604693 0.0069776189 1.5461285 MAarrowhead1
% End of user PostScript
1 .788 0 r
.07271 .46804 m
.09705 .39524 L
s
% Start of user PostScript
-0.85458703 -0.063916854 -0.80590163 -0.20952743 MAarrowhead1
% End of user PostScript
.897 1 0 r
.43617 .28132 m
.47877 .30407 L
s
% Start of user PostScript
-0.12766117 -0.4373579 -0.04246563 -0.39186393 MAarrowhead1
% End of user PostScript
.581 1 0 r
.60214 .49682 m
.59829 .51593 L
s
% Start of user PostScript
0.20428424 -0.0063503449 0.19658591 0.031856876 MAarrowhead1
% End of user PostScript
.266 1 0 r
.5209 .55377 m
.51021 .54912 L
s
% Start of user PostScript
0.041809109 0.10753007 0.020410933 0.098243084 MAarrowhead1
% End of user PostScript
0 1 .049 r
.47587 .5035 m
.47628 .49856 L
s
% Start of user PostScript
-0.048262079 0.0070025071 -0.047445547 -0.0028888111 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49362 .48692 m
.49628 .48781 L
s
% Start of user PostScript
-0.012750045 -0.026162554 -0.0074320377 -0.024372499 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50563 .49848 m
.50566 .49974 L
s
% Start of user PostScript
0.011256662 -0.0030495298 0.011324177 -0.00051985871 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50186 .50315 m
.5012 .50299 L
s
% Start of user PostScript
0.0037132395 0.0062974275 0.0024052484 0.0059839012 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49871 .50054 m
.49866 .50022 L
s
% Start of user PostScript
-0.0025881239 0.0010703916 -0.0026709025 0.00043073111 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49948 .49925 m
.49964 .49927 L
s
% Start of user PostScript
-0.0010465246 -0.0014988094 -0.0007281631 -0.0014538349 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50029 .49983 m
.50031 .49991 L
s
% Start of user PostScript
0.00058531305 -0.0003397325 0.00062182181 -0.00017972032 MAarrowhead1
% End of user PostScript
0 .506 1 r
.21147 1 m
.15763 .92032 L
.09592 .79189 L
.06027 .67241 L
.04792 .56521 L
.05564 .47262 L
.07989 .39599 L
.11705 .33582 L
.16355 .29187 L
.21604 .2633 L
.27147 .24879 L
.32713 .24665 L
.38077 .25499 L
.43056 .27178 L
.47514 .29501 L
.51356 .3227 L
.54526 .35304 L
.57007 .38438 L
.58809 .41532 L
.5997 .44468 L
.60545 .47153 L
.60607 .49521 L
.60234 .51529 L
.59512 .53152 L
.58526 .54389 L
.57357 .55252 L
.56081 .55767 L
.54767 .55968 L
.53473 .55898 L
.52249 .55604 L
.5113 .55132 L
.50147 .54532 L
.49315 .53846 L
.48644 .53117 L
.48135 .5238 L
.47783 .51666 L
.47575 .51 L
.47498 .50401 L
.47533 .49883 L
.47662 .49452 L
.47863 .49112 L
.48117 .48862 L
.48406 .48698 L
.48712 .48613 L
.49021 .48596 L
.49319 .48638 L
.49597 .48728 L
.49846 .48855 L
.50061 .49007 L
.50239 .49174 L
Mistroke
.50379 .49347 L
.50482 .49519 L
.50548 .49682 L
.50583 .49832 L
.50588 .49965 L
.50569 .50077 L
.5053 .50169 L
.50476 .50239 L
.50412 .50288 L
.50342 .50318 L
.50269 .5033 L
.50197 .50327 L
.50129 .50312 L
.50067 .50286 L
.50012 .50253 L
.49965 .50216 L
.49927 .50176 L
.49898 .50135 L
.49878 .50095 L
.49866 .50058 L
.49862 .50024 L
.49863 .49995 L
.4987 .49971 L
.49881 .49952 L
.49895 .49938 L
.49911 .49928 L
.49927 .49923 L
.49945 .49922 L
.49961 .49924 L
.49977 .49929 L
.49991 .49936 L
.50003 .49944 L
.50013 .49954 L
.50021 .49963 L
.50026 .49973 L
.5003 .49982 L
.50032 .4999 L
.50033 .49998 L
.50032 .50004 L
.5003 .50009 L
.50027 .50013 L
.50023 .50016 L
.50019 .50018 L
.50015 .50018 L
.50011 .50018 L
.50007 .50017 L
.50004 .50016 L
.50001 .50014 L
.49998 .50012 L
.49996 .5001 L
Mistroke
.49994 .50008 L
.49993 .50005 L
.49993 .50003 L
.49992 .50001 L
.49992 .5 L
.49993 .49998 L
.49993 .49997 L
.49994 .49997 L
.49995 .49996 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49999 .49996 L
.49999 .49996 L
.5 .49997 L
.50001 .49997 L
.50001 .49998 L
.50001 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
0.58081398 -6.3280926 1.7082582 -5.2276125 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
2.5863865 -4.0947561 3.2201086 -2.9800238 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.6251841 1.9148824 2.1626083 2.0920495 MAarrowhead1
% End of user PostScript
1 .788 0 r
.21147 1 m
.15763 .92032 L
s
% Start of user PostScript
-0.50507036 1.1065675 -0.68473133 0.84063516 MAarrowhead1
% End of user PostScript
.897 1 0 r
.16355 .29187 m
.21604 .2633 L
s
% Start of user PostScript
-0.67289791 -0.41625809 -0.56791145 -0.47339201 MAarrowhead1
% End of user PostScript
.581 1 0 r
.54526 .35304 m
.57007 .38438 L
s
% Start of user PostScript
0.090528282 -0.29392147 0.14014006 -0.23123195 MAarrowhead1
% End of user PostScript
.266 1 0 r
.58526 .54389 m
.57357 .55252 L
s
% Start of user PostScript
0.17051153 0.087787828 0.14713047 0.10504635 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49315 .53846 m
.48644 .53117 L
s
% Start of user PostScript
-0.013703236 0.07691854 -0.027119456 0.062332055 MAarrowhead1
% End of user PostScript
0 1 .364 r
.47863 .49112 m
.48117 .48862 L
s
% Start of user PostScript
-0.042740438 -0.017759346 -0.03765304 -0.022752712 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50061 .49007 m
.50239 .49174 L
s
% Start of user PostScript
0.0012182949 -0.01986576 0.0047839038 -0.016521233 MAarrowhead1
% End of user PostScript
0 1 .995 r
.5053 .50169 m
.50476 .50239 L
s
% Start of user PostScript
0.010601257 0.0033750228 0.0095269912 0.0047754653 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50012 .50253 m
.49965 .50216 L
s
% Start of user PostScript
0.00023555309 0.0050694713 -0.00069802823 0.004315525 MAarrowhead1
% End of user PostScript
0 .375 1 r
.4987 .49971 m
.49881 .49952 L
s
% Start of user PostScript
-0.0026023286 -0.00057596682 -0.0023846182 -0.00095942988 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49991 .49936 m
.50003 .49944 L
s
% Start of user PostScript
-0.00018965584 -0.0012792361 0.000051569536 -0.0011127024 MAarrowhead1
% End of user PostScript
.823 1 0 r
.79431 0 m
.86561 .11574 L
.91975 .24274 L
.94842 .35963 L
.95455 .46337 L
.94152 .55192 L
.91292 .62418 L
.8724 .67987 L
.8235 .71943 L
.76951 .74386 L
.71341 .75462 L
.65778 .75347 L
.60477 .74236 L
.55609 .72335 L
.51297 .69846 L
.47626 .66963 L
.4464 .63864 L
.42347 .60709 L
.40728 .57631 L
.3974 .54743 L
.39321 .52129 L
.39396 .49849 L
.39883 .47941 L
.40697 .46422 L
.41752 .4529 L
.42967 .44528 L
.44269 .44107 L
.4559 .43989 L
.46876 .44131 L
.48081 .44485 L
.49169 .45002 L
.50115 .45636 L
.50905 .46343 L
.51532 .47083 L
.51997 .4782 L
.52307 .48527 L
.52476 .49178 L
.52518 .49758 L
.52453 .50255 L
.523 .50662 L
.5208 .50977 L
.51812 .51202 L
.51514 .51343 L
.51204 .51408 L
.50895 .51406 L
.50601 .51348 L
.50329 .51245 L
.50088 .5111 L
.49882 .50951 L
.49714 .5078 L
Mistroke
.49584 .50605 L
.49492 .50435 L
.49435 .50274 L
.49409 .50128 L
.49412 .5 L
.49437 .49893 L
.49481 .49807 L
.49539 .49743 L
.49606 .49699 L
.49677 .49675 L
.49751 .49667 L
.49822 .49674 L
.49889 .49693 L
.4995 .49721 L
.50003 .49756 L
.50047 .49795 L
.50083 .49836 L
.50109 .49876 L
.50127 .49916 L
.50137 .49952 L
.50139 .49984 L
.50136 .50012 L
.50128 .50035 L
.50116 .50053 L
.50101 .50066 L
.50085 .50074 L
.50068 .50078 L
.50051 .50078 L
.50034 .50075 L
.50019 .50069 L
.50006 .50062 L
.49994 .50053 L
.49985 .50044 L
.49977 .50034 L
.49972 .50025 L
.49969 .50016 L
.49967 .50008 L
.49967 .5 L
.49969 .49994 L
.49971 .4999 L
.49974 .49986 L
.49978 .49983 L
.49982 .49982 L
.49986 .49982 L
.4999 .49982 L
.49994 .49983 L
.49997 .49984 L
.5 .49986 L
.50002 .49988 L
.50004 .49991 L
Mistroke
.50006 .49993 L
.50007 .49995 L
.50008 .49997 L
.50008 .49999 L
.50008 .50001 L
.50007 .50002 L
.50006 .50003 L
.50006 .50004 L
.50005 .50004 L
.50004 .50004 L
.50003 .50004 L
.50002 .50004 L
.50001 .50004 L
.5 .50003 L
.5 .50003 L
.49999 .50002 L
.49999 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-2.0046331 4.9260446 -2.8149859 3.7866078 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-3.3826718 2.6786742 -3.7239477 1.6414922 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.0359091 -2.1353738 -1.5587152 -2.17055 MAarrowhead1
% End of user PostScript
1 .788 0 r
.86561 .11574 m
.91975 .24274 L
s
% Start of user PostScript
0.73122462 -0.76851367 0.8395083 -0.51452619 MAarrowhead1
% End of user PostScript
.897 1 0 r
.76951 .74386 m
.71341 .75462 L
s
% Start of user PostScript
0.53901844 0.48772199 0.42681851 0.50923751 MAarrowhead1
% End of user PostScript
.581 1 0 r
.42347 .60709 m
.40728 .57631 L
s
% Start of user PostScript
-0.15306595 0.21417151 -0.185441 0.15262675 MAarrowhead1
% End of user PostScript
.266 1 0 r
.42967 .44528 m
.44269 .44107 L
s
% Start of user PostScript
-0.14065906 -0.10944263 -0.11462772 -0.11785988 MAarrowhead1
% End of user PostScript
0 1 .049 r
.51532 .47083 m
.51997 .4782 L
s
% Start of user PostScript
0.030634123 -0.05834727 0.039933812 -0.043596082 MAarrowhead1
% End of user PostScript
0 1 .364 r
.51812 .51202 m
.51514 .51343 L
s
% Start of user PostScript
0.036234904 0.024038284 0.030285831 0.026859748 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49714 .5078 m
.49584 .50605 L
s
% Start of user PostScript
-0.0057223086 0.015603593 -0.0083163585 0.012108643 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49539 .49743 m
.49606 .49699 L
s
% Start of user PostScript
-0.0092247271 -0.0051388776 -0.0078888545 -0.0060113406 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50047 .49795 m
.50083 .49836 L
s
% Start of user PostScript
0.00094471793 -0.0041076113 0.0016519421 -0.0032898775 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50116 .50053 m
.50101 .50066 L
s
% Start of user PostScript
0.002322553 0.001059558 0.0020288869 0.0013160479 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49994 .50053 m
.49985 .50044 L
s
% Start of user PostScript
-0.00011554037 0.0010664939 -0.00030478696 0.00087781086 MAarrowhead1
% End of user PostScript
0 1 .947 r
.39396 1 m
.36382 .97176 L
.2838 .8728 L
.22527 .77482 L
.18712 .68158 L
.16761 .59605 L
.16452 .52041 L
.17534 .4561 L
.19741 .40386 L
.22804 .36386 L
.26463 .33572 L
.30475 .31867 L
.34624 .31161 L
.38722 .31322 L
.42613 .32204 L
.46175 .33655 L
.49318 .35528 L
.51983 .37678 L
.54141 .39976 L
.55788 .42306 L
.56938 .4457 L
.57627 .46687 L
.57899 .48597 L
.57813 .50256 L
.57427 .51639 L
.56807 .52734 L
.56014 .53544 L
.55107 .54082 L
.54142 .54371 L
.53167 .54438 L
.52221 .54318 L
.51338 .54043 L
.50544 .53652 L
.49855 .53177 L
.49283 .52651 L
.48831 .52104 L
.48498 .5156 L
.48279 .51041 L
.48164 .50564 L
.48141 .50141 L
.48196 .4978 L
.48314 .49486 L
.48481 .4926 L
.48681 .491 L
.48903 .49001 L
.49132 .48958 L
.4936 .48964 L
.49576 .4901 L
.49775 .49088 L
.4995 .49191 L
Mistroke
.501 .49309 L
.50222 .49436 L
.50315 .49565 L
.5038 .49691 L
.5042 .49808 L
.50437 .49915 L
.50433 .50008 L
.50413 .50086 L
.5038 .50148 L
.50336 .50193 L
.50287 .50224 L
.50233 .50241 L
.50179 .50246 L
.50127 .5024 L
.50077 .50225 L
.50033 .50204 L
.49995 .50178 L
.49962 .50149 L
.49937 .50119 L
.49918 .50089 L
.49905 .5006 L
.49899 .50033 L
.49897 .50009 L
.499 .49989 L
.49906 .49973 L
.49915 .4996 L
.49926 .49951 L
.49938 .49945 L
.49951 .49942 L
.49964 .49943 L
.49976 .49945 L
.49987 .49949 L
.49997 .49955 L
.50005 .49961 L
.50012 .49968 L
.50017 .49975 L
.50021 .49982 L
.50023 .49989 L
.50024 .49995 L
.50024 .5 L
.50023 .50004 L
.50021 .50008 L
.50019 .50011 L
.50016 .50012 L
.50013 .50013 L
.5001 .50014 L
.50007 .50013 L
.50004 .50013 L
.50002 .50011 L
.5 .5001 L
Mistroke
.49998 .50008 L
.49997 .50007 L
.49996 .50005 L
.49995 .50003 L
.49994 .50002 L
.49994 .50001 L
.49994 .49999 L
.49995 .49999 L
.49995 .49998 L
.49996 .49997 L
.49997 .49997 L
.49997 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49997 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
0.46155464 1.4517308 0.17712462 1.307608 MAarrowhead1
% End of user PostScript
1 .158 0 r
.39396 1 m
.36382 .97176 L
s
% Start of user PostScript
-0.068725326 1.1343322 -0.27235748 0.94351297 MAarrowhead1
% End of user PostScript
1 .473 0 r
.19741 .40386 m
.22804 .36386 L
s
% Start of user PostScript
-0.6051722 -0.19227523 -0.54391842 -0.27228037 MAarrowhead1
% End of user PostScript
1 .788 0 r
.49318 .35528 m
.51983 .37678 L
s
% Start of user PostScript
-0.013648986 -0.28944396 0.039662968 -0.24643345 MAarrowhead1
% End of user PostScript
.897 1 0 r
.57427 .51639 m
.56807 .52734 L
s
% Start of user PostScript
0.14854356 0.032780709 0.13613392 0.05468427 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50544 .53652 m
.49855 .53177 L
s
% Start of user PostScript
0.0108759 0.073033338 -0.0028980756 0.063534481 MAarrowhead1
% End of user PostScript
.266 1 0 r
.48196 .4978 m
.48314 .49486 L
s
% Start of user PostScript
-0.036080524 -0.0043911862 -0.033716733 -0.010272783 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49775 .49088 m
.4995 .49191 L
s
% Start of user PostScript
-0.0045061318 -0.01823181 -0.00099000217 -0.016186784 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50433 .50008 m
.50413 .50086 L
s
% Start of user PostScript
0.0086695256 0.0001610849 0.0082643913 0.0017148618 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50077 .50225 m
.50033 .50204 L
s
% Start of user PostScript
0.0015495144 0.0045040532 0.00066196463 0.0040783122 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49897 .50009 m
.499 .49989 L
s
% Start of user PostScript
-0.002059538 0.00018799397 -0.002004506 -0.0002166874 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49976 .49945 m
.49987 .49949 L
s
% Start of user PostScript
-0.00048623217 -0.0011011812 -0.00026458277 -0.0010166547 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50024 .49995 m
.50024 .5 L
s
% Start of user PostScript
0.00048329277 -0.00010203253 0.00048092826 0.0000020341784 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50007 .50013 m
.50004 .50013 L
s
% Start of user PostScript
0.00014433781 0.00026638935 0.000089560196 0.00025080682 MAarrowhead1
% End of user PostScript
1 .128 0 r
.52661 0 m
.56887 .03352 L
.65085 .11939 L
.71364 .2067 L
.7578 .29171 L
.78457 .37141 L
.79565 .44345 L
.79314 .50619 L
.7793 .55861 L
.75652 .60027 L
.72714 .63124 L
.69339 .65198 L
.65732 .66331 L
.62076 .6663 L
.58523 .66215 L
.552 .65219 L
.52203 .63774 L
.49599 .6201 L
.47428 .60049 L
.45709 .58001 L
.44438 .55962 L
.43593 .54012 L
.4314 .52214 L
.43034 .50617 L
.43224 .49251 L
.43654 .48135 L
.44269 .47272 L
.45014 .46657 L
.45839 .46274 L
.46698 .46102 L
.47551 .46113 L
.48365 .46278 L
.49114 .46566 L
.49778 .46944 L
.50344 .47384 L
.50806 .47858 L
.51161 .48341 L
.51413 .48814 L
.51568 .49257 L
.51635 .4966 L
.51626 .50011 L
.51554 .50306 L
.51431 .5054 L
.5127 .50716 L
.51085 .50835 L
.50886 .50901 L
.50683 .50921 L
.50486 .50901 L
.50301 .50847 L
.50133 .50769 L
Mistroke
.49987 .50672 L
.49865 .50564 L
.49768 .50451 L
.49696 .50338 L
.49648 .5023 L
.49621 .50129 L
.49614 .5004 L
.49624 .49964 L
.49647 .49901 L
.4968 .49852 L
.49721 .49817 L
.49766 .49795 L
.49814 .49785 L
.49861 .49784 L
.49906 .49793 L
.49948 .49809 L
.49985 .49829 L
.50017 .49853 L
.50043 .49879 L
.50063 .49906 L
.50077 .49932 L
.50086 .49957 L
.5009 .4998 L
.5009 .49999 L
.50086 .50016 L
.5008 .50029 L
.50071 .50039 L
.50061 .50046 L
.5005 .5005 L
.50039 .50051 L
.50028 .5005 L
.50017 .50047 L
.50008 .50043 L
.5 .50038 L
.49993 .50032 L
.49988 .50025 L
.49983 .50019 L
.49981 .50013 L
.49979 .50008 L
.49979 .50003 L
.49979 .49998 L
.4998 .49995 L
.49982 .49992 L
.49984 .4999 L
.49987 .49989 L
.49989 .49988 L
.49992 .49988 L
.49995 .49988 L
.49997 .49989 L
.49999 .4999 L
Mistroke
.50001 .49992 L
.50002 .49993 L
.50003 .49995 L
.50004 .49996 L
.50005 .49998 L
.50005 .49999 L
.50005 .5 L
.50005 .50001 L
.50004 .50002 L
.50004 .50002 L
.50003 .50003 L
.50003 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-2.0363175 2.101445 -2.3308146 1.4002251 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-2.4848237 0.75558647 -2.5147404 0.1842244 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-0.86270328 -1.4014742 -0.57003877 -1.3383176 MAarrowhead1
% End of user PostScript
1 .788 0 r
.78457 .37141 m
.79565 .44345 L
s
% Start of user PostScript
0.56913322 -0.2571814 0.59130718 -0.11309216 MAarrowhead1
% End of user PostScript
.897 1 0 r
.62076 .6663 m
.58523 .66215 L
s
% Start of user PostScript
0.24151438 0.33259664 0.17046528 0.32430731 MAarrowhead1
% End of user PostScript
.581 1 0 r
.43593 .54012 m
.4314 .52214 L
s
% Start of user PostScript
-0.12813598 0.080235655 -0.13719613 0.044284592 MAarrowhead1
% End of user PostScript
.266 1 0 r
.46698 .46102 m
.47551 .46113 L
s
% Start of user PostScript
-0.066035044 -0.077960748 -0.048972616 -0.077734247 MAarrowhead1
% End of user PostScript
0 1 .049 r
.51413 .48814 m
.51568 .49257 L
s
% Start of user PostScript
0.028259328 -0.023727427 0.03135618 -0.014850553 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50886 .50901 m
.50683 .50921 L
s
% Start of user PostScript
0.017712783 0.018025267 0.013661812 0.018418211 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49696 .50338 m
.49648 .5023 L
s
% Start of user PostScript
-0.0060731374 0.0067624373 -0.0070416216 0.0045932936 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49766 .49795 m
.49814 .49785 L
s
% Start of user PostScript
-0.0046749658 -0.0041030791 -0.0037249733 -0.0043096461 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50063 .49906 m
.50077 .49932 L
s
% Start of user PostScript
0.0012612592 -0.001875041 0.0015481144 -0.0013505804 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50061 .50046 m
.5005 .5005 L
s
% Start of user PostScript
0.0012165994 0.00091700807 0.00099683706 0.00099446268 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49988 .50025 m
.49983 .50019 L
s
% Start of user PostScript
-0.00024951356 0.00050874173 -0.00033136198 0.00038332731 MAarrowhead1
% End of user PostScript
1 0 .861 r
.89528 0 m
.96384 .13418 L
s
.96384 .13418 m
1 .24455 L
s
1 .60116 m
.99795 .60859 L
.95659 .68222 L
.90361 .73674 L
.84299 .77305 L
.77839 .7926 L
.71303 .79731 L
.64964 .78938 L
.59044 .77115 L
.53714 .745 L
.4909 .71326 L
.45245 .67808 L
.42208 .64143 L
.39969 .605 L
.38492 .57023 L
.37711 .53823 L
.37548 .50984 L
.37908 .48561 L
.38695 .46585 L
.39807 .45062 L
.41148 .43982 L
.42628 .43315 L
.44165 .43023 L
.45689 .43057 L
.4714 .43363 L
.48473 .43886 L
.49653 .44568 L
.50657 .45359 L
.51474 .46208 L
.52101 .47073 L
.52543 .47915 L
.52812 .48706 L
.52926 .49422 L
.52905 .50046 L
.5277 .50568 L
.52547 .50983 L
.52257 .51292 L
.51924 .515 L
.51567 .51615 L
.51205 .51647 L
.50853 .51607 L
.50523 .5151 L
.50226 .51368 L
.49967 .51194 L
.49751 .51 L
.49579 .50798 L
.49452 .50596 L
.49367 .50402 L
.49322 .50224 L
.4931 .50065 L
Mistroke
.49328 .49929 L
.4937 .49818 L
.49431 .49732 L
.49504 .4967 L
.49586 .49632 L
.49671 .49614 L
.49755 .49615 L
.49836 .49631 L
.4991 .49659 L
.49976 .49696 L
.50033 .4974 L
.50079 .49787 L
.50114 .49834 L
.50139 .49881 L
.50155 .49925 L
.50162 .49965 L
.50161 .5 L
.50154 .5003 L
.50142 .50053 L
.50126 .50071 L
.50108 .50082 L
.50088 .50089 L
.50068 .50091 L
.50049 .50089 L
.5003 .50084 L
.50014 .50076 L
.49999 .50067 L
.49987 .50056 L
.49977 .50045 L
.4997 .50034 L
.49965 .50023 L
.49963 .50013 L
.49962 .50004 L
.49963 .49997 L
.49965 .4999 L
.49968 .49985 L
.49972 .49982 L
.49977 .4998 L
.49981 .49979 L
.49986 .49979 L
.49991 .49979 L
.49995 .49981 L
.49998 .49983 L
.50002 .49985 L
.50004 .49988 L
.50006 .49991 L
.50008 .49993 L
.50009 .49996 L
.50009 .49998 L
.50009 .5 L
Mistroke
.50009 .50002 L
.50008 .50003 L
.50007 .50004 L
.50006 .50005 L
.50005 .50005 L
.50004 .50005 L
.50003 .50005 L
.50002 .50005 L
.50001 .50004 L
.5 .50004 L
.49999 .50003 L
.49999 .50003 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-4.4505663 1.3021525 -4.4948282 0.28683067 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-4.3522374 -0.57695861 -4.0584939 -1.2790002 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-0.51887664 -2.1927072 -0.096997926 -1.9425539 MAarrowhead1
% End of user PostScript
1 .788 0 r
1 .60116 m
.99795 .60859 L
s
% Start of user PostScript
1.047015 0.031416818 0.99590822 0.21718545 MAarrowhead1
% End of user PostScript
.897 1 0 r
.59044 .77115 m
.53714 .745 L
s
% Start of user PostScript
0.18088865 0.54230331 0.074270764 0.49000841 MAarrowhead1
% End of user PostScript
.581 1 0 r
.37548 .50984 m
.37908 .48561 L
s
% Start of user PostScript
-0.24904532 0.019670611 -0.24183294 -0.028783307 MAarrowhead1
% End of user PostScript
.266 1 0 r
.4714 .43363 m
.48473 .43886 L
s
% Start of user PostScript
-0.057197885 -0.13273584 -0.030541594 -0.12228982 MAarrowhead1
% End of user PostScript
0 1 .049 r
.52926 .49422 m
.52905 .50046 L
s
% Start of user PostScript
0.058521995 -0.011561604 0.05809114 0.00091511766 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50853 .51607 m
.50523 .5151 L
s
% Start of user PostScript
0.017063594 0.032147721 0.01046845 0.030202565 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49322 .50224 m
.4931 .50065 L
s
% Start of user PostScript
-0.013568641 0.0044763886 -0.013795832 0.0013013234 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49755 .49615 m
.49836 .49631 L
s
% Start of user PostScript
-0.0048938371 -0.0077012119 -0.0032789811 -0.0073820683 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50155 .49925 m
.50162 .49965 L
s
% Start of user PostScript
0.0030985618 -0.0014932236 0.0032362309 -0.0006941268 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50068 .50091 m
.50049 .50089 L
s
% Start of user PostScript
0.0013634632 0.0018236007 0.00097220493 0.0017853018 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49965 .50023 m
.49963 .50013 L
s
% Start of user PostScript
-0.00069516164 0.00046042245 -0.00074889173 0.00026143128 MAarrowhead1
% End of user PostScript
1 0 .709 r
.54895 0 m
.61631 .06151 L
.69114 .15162 L
.74631 .24119 L
.78277 .32674 L
.80207 .40548 L
.80619 .47535 L
.79741 .535 L
.77814 .58367 L
.75085 .62118 L
.7179 .64782 L
.68153 .66428 L
.64374 .67152 L
.60627 .67074 L
.57056 .66326 L
.53777 .65045 L
.50873 .63368 L
.484 .61426 L
.46388 .59338 L
.44844 .57213 L
.43754 .5514 L
.43088 .53194 L
.42806 .51433 L
.42857 .49898 L
.43185 .48613 L
.43733 .47589 L
.44444 .46827 L
.45263 .46314 L
.4614 .4603 L
.4703 .45951 L
.47896 .46047 L
.48707 .46285 L
.4944 .46633 L
.50078 .47061 L
.5061 .47537 L
.51032 .48035 L
.51345 .48532 L
.51554 .49008 L
.51668 .49447 L
.51696 .49837 L
.51652 .50172 L
.51549 .50446 L
.51401 .50658 L
.5122 .5081 L
.5102 .50905 L
.50811 .50948 L
.50603 .50947 L
.50404 .50908 L
.50222 .50839 L
.50059 .50747 L
Mistroke
.4992 .50641 L
.49807 .50525 L
.4972 .50408 L
.49658 .50293 L
.49619 .50184 L
.49602 .50086 L
.49604 .5 L
.49621 .49928 L
.49651 .4987 L
.49689 .49827 L
.49734 .49798 L
.49783 .49781 L
.49832 .49776 L
.4988 .4978 L
.49925 .49793 L
.49966 .49812 L
.50002 .49835 L
.50032 .49862 L
.50056 .49889 L
.50073 .49917 L
.50085 .49943 L
.50092 .49968 L
.50094 .4999 L
.50092 .50008 L
.50086 .50024 L
.50078 .50036 L
.50068 .50044 L
.50057 .5005 L
.50046 .50052 L
.50034 .50053 L
.50023 .5005 L
.50013 .50047 L
.50004 .50042 L
.49996 .50036 L
.4999 .5003 L
.49985 .50023 L
.49981 .50017 L
.49979 .50011 L
.49978 .50005 L
.49978 .5 L
.49979 .49996 L
.49981 .49993 L
.49983 .49991 L
.49985 .49989 L
.49988 .49988 L
.49991 .49988 L
.49993 .49988 L
.49996 .49988 L
.49998 .4999 L
.5 .49991 L
Mistroke
.50002 .49992 L
.50003 .49994 L
.50004 .49995 L
.50005 .49997 L
.50005 .49998 L
.50005 .49999 L
.50005 .5 L
.50005 .50001 L
.50004 .50002 L
.50004 .50002 L
.50003 .50003 L
.50003 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50003 L
.5 .50002 L
.5 .50002 L
.49999 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
9.0149128 -9.1196723 10.285236 -6.0441788 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
10.940315 -3.2207293 11.052725 -0.7217687 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.7430109 6.1558697 2.4595131 5.870017 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-2.5086083 1.105452 -2.6012197 0.47476372 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-1.0498459 -1.4621291 -0.73802156 -1.4235252 MAarrowhead1
% End of user PostScript
.581 1 0 r
.78277 .32674 m
.80207 .40548 L
s
% Start of user PostScript
0.56553682 -0.34652379 0.6041398 -0.18904622 MAarrowhead1
% End of user PostScript
.266 1 0 r
.64374 .67152 m
.60627 .67074 L
s
% Start of user PostScript
0.28748137 0.34303696 0.21253812 0.34147914 MAarrowhead1
% End of user PostScript
0 1 .049 r
.43754 .5514 m
.43088 .53194 L
s
% Start of user PostScript
-0.12492511 0.10279506 -0.13823349 0.06388281 MAarrowhead1
% End of user PostScript
0 1 .364 r
.4614 .4603 m
.4703 .45951 L
s
% Start of user PostScript
-0.077208027 -0.079394735 -0.059400098 -0.080977916 MAarrowhead1
% End of user PostScript
0 1 .679 r
.51345 .48532 m
.51554 .49008 L
s
% Start of user PostScript
0.026902651 -0.029363008 0.031084794 -0.019847408 MAarrowhead1
% End of user PostScript
0 1 .995 r
.5102 .50905 m
.50811 .50948 L
s
% Start of user PostScript
0.020399416 0.018093958 0.016219476 0.018965458 MAarrowhead1
% End of user PostScript
0 .69 1 r
.4972 .50408 m
.49658 .50293 L
s
% Start of user PostScript
-0.0056027534 0.0081556274 -0.0068453875 0.0058531708 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49734 .49798 m
.49783 .49781 L
s
% Start of user PostScript
-0.0053136994 -0.004049581 -0.0043457644 -0.0043808984 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50056 .49889 m
.50073 .49917 L
s
% Start of user PostScript
0.0011129707 -0.0022158926 0.0014683376 -0.0016648647 MAarrowhead1
% End of user PostScript
0 1 .282 r
0 .10309 m
.08814 .07491 L
.18342 .06671 L
.27607 .07715 L
.36279 .10283 L
.44108 .14027 L
.50916 .18608 L
.56594 .23709 L
.61097 .29043 L
.64433 .34358 L
.66656 .39446 L
.67857 .44139 L
.6815 .48313 L
.67671 .51884 L
.66562 .54806 L
.64969 .57067 L
.63032 .58683 L
.60886 .59692 L
.58649 .60151 L
.56425 .60131 L
.54301 .59709 L
.52346 .58966 L
.50611 .57984 L
.49131 .5684 L
.47922 .55607 L
.46991 .54347 L
.4633 .53116 L
.45921 .51958 L
.45742 .50907 L
.45761 .49989 L
.45947 .49218 L
.46265 .48603 L
.46681 .48142 L
.47163 .4783 L
.47682 .47654 L
.48209 .47601 L
.48724 .47652 L
.49207 .47788 L
.49644 .47992 L
.50026 .48243 L
.50345 .48523 L
.50599 .48818 L
.50788 .49113 L
.50915 .49396 L
.50986 .49658 L
.51005 .49891 L
.50982 .50091 L
.50922 .50256 L
.50836 .50383 L
.5073 .50475 L
Mistroke
.50612 .50534 L
.50488 .50561 L
.50364 .50562 L
.50246 .5054 L
.50137 .505 L
.5004 .50446 L
.49957 .50384 L
.49889 .50315 L
.49837 .50246 L
.49799 .50177 L
.49775 .50113 L
.49765 .50054 L
.49765 .50003 L
.49775 .4996 L
.49792 .49925 L
.49814 .49899 L
.49841 .49881 L
.4987 .49871 L
.49899 .49867 L
.49927 .4987 L
.49954 .49877 L
.49979 .49888 L
.5 .49902 L
.50018 .49917 L
.50032 .49933 L
.50043 .4995 L
.5005 .49965 L
.50054 .4998 L
.50056 .49993 L
.50055 .50004 L
.50051 .50014 L
.50047 .50021 L
.50041 .50026 L
.50034 .50029 L
.50028 .50031 L
.50021 .50031 L
.50014 .5003 L
.50008 .50028 L
.50003 .50025 L
.49998 .50021 L
.49994 .50018 L
.49991 .50014 L
.49989 .5001 L
.49988 .50006 L
.49987 .50003 L
.49987 .5 L
.49987 .49998 L
.49988 .49996 L
.4999 .49994 L
.49991 .49993 L
Mistroke
.49993 .49993 L
.49994 .49993 L
.49996 .49993 L
.49997 .49993 L
.49999 .49994 L
.5 .49994 L
.50001 .49995 L
.50002 .49996 L
.50002 .49997 L
.50003 .49998 L
.50003 .49999 L
.50003 .5 L
.50003 .5 L
.50003 .50001 L
.50003 .50001 L
.50002 .50001 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
0.79945781 3.215865 0.1790554 2.8559915 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-0.34890613 2.4396829 -0.77815449 1.9926475 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.3394762 -0.51852796 -1.1869682 -0.68099934 MAarrowhead1
% End of user PostScript
1 .788 0 r
.50916 .18608 m
.56594 .23709 L
s
% Start of user PostScript
0.018317627 -0.62783426 0.13187951 -0.52581096 MAarrowhead1
% End of user PostScript
.897 1 0 r
.66562 .54806 m
.64969 .57067 L
s
% Start of user PostScript
0.33123688 0.096125223 0.29937034 0.14134829 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50611 .57984 m
.49131 .5684 L
s
% Start of user PostScript
0.012229684 0.15968194 -0.017385449 0.13680971 MAarrowhead1
% End of user PostScript
.266 1 0 r
.45947 .49218 m
.46265 .48603 L
s
% Start of user PostScript
-0.081063698 -0.01563095 -0.074702794 -0.027939201 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49644 .47992 m
.50026 .48243 L
s
% Start of user PostScript
-0.007114241 -0.040167356 0.00051035682 -0.035149416 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50982 .50091 m
.50922 .50256 L
s
% Start of user PostScript
0.019630378 0.0018237538 0.018447285 0.0051126295 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50137 .505 m
.5004 .50446 L
s
% Start of user PostScript
0.0027468277 0.0099973538 0.00080680988 0.0089262248 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49765 .50003 m
.49775 .4996 L
s
% Start of user PostScript
-0.0047019169 0.000055716501 -0.0045082536 -0.00080946467 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49954 .49877 m
.49979 .49888 L
s
% Start of user PostScript
-0.00091508002 -0.0024625002 -0.00042688625 -0.002242105 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50056 .49993 m
.50055 .50004 L
s
% Start of user PostScript
0.0011132136 -0.0001382392 0.001090139 0.000086254638 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50014 .5003 m
.50008 .50028 L
s
% Start of user PostScript
0.00028193808 0.00060025594 0.00016038437 0.00055725718 MAarrowhead1
% End of user PostScript
.592 1 0 r
0 .06355 m
.01261 .05788 L
.11426 .0386 L
.21502 .04087 L
.311 .06113 L
.39913 .09569 L
.47715 .14087 L
.54355 .19316 L
.59755 .24932 L
.63898 .30649 L
.66821 .36222 L
.68601 .41452 L
.69352 .46184 L
.69208 .50308 L
.68319 .53758 L
.66841 .56504 L
.64926 .58549 L
.62722 .59924 L
.60363 .60681 L
.57968 .6089 L
.55639 .60629 L
.53458 .59986 L
.5149 .59046 L
.49777 .57895 L
.48349 .56614 L
.47216 .55274 L
.46376 .53938 L
.45816 .52659 L
.45513 .51479 L
.45438 .50429 L
.45558 .49531 L
.45836 .48795 L
.46236 .48226 L
.46722 .47819 L
.47261 .47565 L
.47824 .47449 L
.48383 .47454 L
.48917 .47559 L
.49408 .47746 L
.49844 .47992 L
.50217 .48279 L
.50521 .48589 L
.50755 .48906 L
.50922 .49215 L
.51025 .49507 L
.5107 .49771 L
.51065 .50002 L
.51019 .50196 L
.50939 .5035 L
.50835 .50466 L
Mistroke
.50714 .50545 L
.50583 .50589 L
.50451 .50603 L
.50321 .5059 L
.502 .50556 L
.5009 .50505 L
.49994 .50442 L
.49914 .50371 L
.4985 .50297 L
.49802 .50223 L
.4977 .50152 L
.49752 .50086 L
.49747 .50028 L
.49753 .49977 L
.49768 .49936 L
.4979 .49904 L
.49816 .49881 L
.49846 .49866 L
.49877 .49859 L
.49908 .49859 L
.49938 .49864 L
.49965 .49874 L
.4999 .49888 L
.50011 .49904 L
.50028 .49921 L
.50041 .49938 L
.5005 .49955 L
.50056 .49972 L
.50059 .49986 L
.50059 .49999 L
.50057 .5001 L
.50052 .50019 L
.50047 .50025 L
.5004 .5003 L
.50033 .50033 L
.50025 .50033 L
.50018 .50033 L
.50012 .50031 L
.50005 .50028 L
.5 .50025 L
.49996 .50021 L
.49992 .50017 L
.49989 .50013 L
.49987 .50009 L
.49986 .50005 L
.49986 .50002 L
.49986 .49999 L
.49987 .49997 L
.49988 .49995 L
.4999 .49993 L
Mistroke
.49991 .49993 L
.49993 .49992 L
.49995 .49992 L
.49996 .49992 L
.49998 .49993 L
.49999 .49994 L
.50001 .49995 L
.50001 .49996 L
.50002 .49997 L
.50003 .49997 L
.50003 .49998 L
.50003 .49999 L
.50003 .5 L
.50003 .50001 L
.50003 .50001 L
.50003 .50001 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
5.1114994 -6.8421524 6.1361868 -4.8356347 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
6.7509836 -2.9578736 6.9971093 -1.2632895 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.8163734 3.932426 1.9780278 3.8272869 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.5223812 0.92821921 -1.6254603 0.50502425 MAarrowhead1
% End of user PostScript
.897 1 0 r
.11426 .0386 m
.21502 .04087 L
s
% Start of user PostScript
-0.77147804 -0.92279518 -0.56995607 -0.9182642 MAarrowhead1
% End of user PostScript
.581 1 0 r
.66821 .36222 m
.68601 .41452 L
s
% Start of user PostScript
0.33641 -0.27555094 0.37201759 -0.17096327 MAarrowhead1
% End of user PostScript
.266 1 0 r
.60363 .60681 m
.57968 .6089 L
s
% Start of user PostScript
0.20725244 0.21362712 0.15935799 0.21779756 MAarrowhead1
% End of user PostScript
0 1 .049 r
.46376 .53938 m
.45816 .52659 L
s
% Start of user PostScript
-0.072479366 0.078750637 -0.083681549 0.053170486 MAarrowhead1
% End of user PostScript
0 1 .364 r
.47261 .47565 m
.47824 .47449 L
s
% Start of user PostScript
-0.054772252 -0.048698305 -0.043527989 -0.051020011 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50755 .48906 m
.50922 .49215 L
s
% Start of user PostScript
0.015104003 -0.021881769 0.018434917 -0.015691163 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50714 .50545 m
.50583 .50589 L
s
% Start of user PostScript
0.014270303 0.01090255 0.011665907 0.011788062 MAarrowhead1
% End of user PostScript
0 .69 1 r
.4985 .50297 m
.49802 .50223 L
s
% Start of user PostScript
-0.0030031198 0.0059471915 -0.0039561869 0.0044653768 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49816 .49881 m
.49846 .49866 L
s
% Start of user PostScript
-0.0036708458 -0.0023878563 -0.0030767951 -0.0026811388 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50028 .49921 m
.50041 .49938 L
s
% Start of user PostScript
0.0005549687 -0.0015872852 0.00082002632 -0.001236702 MAarrowhead1
% End of user PostScript
.558 1 0 r
1 .97805 m
.9054 .99449 L
.79775 .9906 L
.69549 .96772 L
.60182 .92981 L
.51912 .88079 L
.44893 .82442 L
.39206 .76413 L
.34863 .70295 L
.31822 .64348 L
.29997 .58781 L
.29264 .53758 L
.29479 .4939 L
.30479 .45748 L
.321 .42861 L
.34176 .40723 L
.36552 .39299 L
.39084 .38531 L
.41646 .38346 L
.44131 .38656 L
.46452 .3937 L
.48542 .40395 L
.50354 .41639 L
.51862 .43018 L
.53053 .44454 L
.53931 .45882 L
.5451 .47245 L
.54817 .485 L
.54881 .49613 L
.5474 .50563 L
.54432 .51338 L
.53996 .51935 L
.53471 .52358 L
.52891 .5262 L
.52288 .52735 L
.51691 .52722 L
.51122 .52602 L
.50599 .52397 L
.50137 .52129 L
.49743 .5182 L
.49423 .51487 L
.49177 .51148 L
.49003 .50818 L
.48898 .50508 L
.48853 .50227 L
.48861 .49982 L
.48914 .49778 L
.49002 .49615 L
.49115 .49494 L
.49246 .49412 L
Mistroke
.49385 .49367 L
.49527 .49355 L
.49665 .4937 L
.49795 .49408 L
.49911 .49464 L
.50013 .49532 L
.50098 .49608 L
.50165 .49687 L
.50215 .49766 L
.50248 .49842 L
.50266 .49912 L
.5027 .49974 L
.50263 .50028 L
.50247 .50071 L
.50223 .50105 L
.50194 .50129 L
.50162 .50144 L
.50129 .50151 L
.50096 .50151 L
.50064 .50145 L
.50035 .50134 L
.50009 .50119 L
.49987 .50102 L
.49969 .50084 L
.49955 .50065 L
.49945 .50047 L
.49939 .50029 L
.49937 .50014 L
.49937 .5 L
.4994 .49988 L
.49944 .49979 L
.49951 .49972 L
.49958 .49968 L
.49965 .49965 L
.49973 .49964 L
.49981 .49965 L
.49988 .49967 L
.49995 .4997 L
.5 .49974 L
.50005 .49978 L
.50009 .49982 L
.50012 .49987 L
.50014 .49991 L
.50015 .49995 L
.50015 .49998 L
.50015 .50001 L
.50014 .50004 L
.50012 .50006 L
.50011 .50007 L
.50009 .50008 L
Mistroke
.50007 .50008 L
.50005 .50008 L
.50004 .50008 L
.50002 .50007 L
.50001 .50007 L
.49999 .50006 L
.49998 .50005 L
.49998 .50004 L
.49997 .50003 L
.49997 .50002 L
.49996 .50001 L
.49996 .5 L
.49997 .49999 L
.49997 .49999 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-4.7932432 -3.8934302 -3.87631 -4.1544946 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-2.9515715 -4.20751 -2.0572609 -4.083757 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.6405238 -0.96087783 1.7444304 -0.51103049 MAarrowhead1
% End of user PostScript
1 .788 0 r
.9054 .99449 m
.79775 .9906 L
s
% Start of user PostScript
0.81079058 0.98897889 0.59550962 0.98120527 MAarrowhead1
% End of user PostScript
.897 1 0 r
.31822 .64348 m
.29997 .58781 L
s
% Start of user PostScript
-0.36355604 0.28695059 -0.40006332 0.17562658 MAarrowhead1
% End of user PostScript
.581 1 0 r
.39084 .38531 m
.41646 .38346 L
s
% Start of user PostScript
-0.21831925 -0.22937147 -0.16707736 -0.23308287 MAarrowhead1
% End of user PostScript
.266 1 0 r
.53931 .45882 m
.5451 .47245 L
s
% Start of user PostScript
0.078613979 -0.082357764 0.090207263 -0.055093242 MAarrowhead1
% End of user PostScript
0 1 .049 r
.52891 .5262 m
.52288 .52735 L
s
% Start of user PostScript
0.057811449 0.052398445 0.045761491 0.054692111 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49177 .51148 m
.49003 .50818 L
s
% Start of user PostScript
-0.016463123 0.022958348 -0.019931216 0.016350963 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49246 .49412 m
.49385 .49367 L
s
% Start of user PostScript
-0.015088474 -0.011760564 -0.012292332 -0.012660232 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50165 .49687 m
.50215 .49766 L
s
% Start of user PostScript
0.0032969094 -0.0062560523 0.0042934988 -0.004672177 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50194 .50129 m
.50162 .50144 L
s
% Start of user PostScript
0.0038874579 0.0025838243 0.0032483235 0.0028857578 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49969 .50084 m
.49955 .50065 L
s
% Start of user PostScript
-0.00061646482 0.0016733571 -0.00089453423 0.0012980435 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49951 .49972 m
.49958 .49968 L
s
% Start of user PostScript
-0.0009898027 -0.00055256124 -0.0008462528 -0.00064599232 MAarrowhead1
% End of user PostScript
1 .041 0 r
.41213 0 m
.41796 .00278 L
.51209 .06599 L
.59061 .13642 L
.65291 .21007 L
.69909 .28349 L
.7299 .35379 L
.74656 .41865 L
.75069 .47634 L
.74413 .52572 L
.72887 .56615 L
.7069 .59744 L
.68018 .61981 L
.65055 .63379 L
.61965 .64018 L
.58893 .63994 L
.55959 .63415 L
.53257 .62391 L
.50859 .61037 L
.48812 .59459 L
.4714 .57755 L
.45852 .56015 L
.44936 .54314 L
.4437 .52714 L
.44119 .51262 L
.44144 .49992 L
.444 .48927 L
.44838 .48075 L
.45412 .47438 L
.46078 .47005 L
.46793 .46761 L
.47522 .46686 L
.48233 .46756 L
.48901 .46944 L
.49505 .47224 L
.50032 .4757 L
.50473 .47958 L
.50825 .48365 L
.51087 .48772 L
.51263 .49163 L
.51361 .49525 L
.51388 .49847 L
.51356 .50124 L
.51275 .50352 L
.51155 .50529 L
.51009 .50656 L
.50846 .50737 L
.50675 .50775 L
.50504 .50776 L
.50341 .50746 L
Mistroke
.50191 .50691 L
.50057 .50617 L
.49942 .5053 L
.49848 .50436 L
.49775 .5034 L
.49723 .50246 L
.4969 .50156 L
.49675 .50075 L
.49675 .50004 L
.49689 .49944 L
.49712 .49896 L
.49744 .4986 L
.4978 .49836 L
.4982 .49821 L
.4986 .49817 L
.49899 .4982 L
.49937 .4983 L
.4997 .49845 L
.5 .49864 L
.50025 .49885 L
.50044 .49908 L
.50059 .4993 L
.50069 .49952 L
.50075 .49972 L
.50077 .4999 L
.50075 .50006 L
.50071 .50019 L
.50064 .50029 L
.50056 .50036 L
.50047 .50041 L
.50038 .50043 L
.50029 .50043 L
.5002 .50041 L
.50011 .50039 L
.50004 .50034 L
.49997 .5003 L
.49992 .50025 L
.49988 .50019 L
.49985 .50014 L
.49983 .50009 L
.49982 .50004 L
.49982 .50001 L
.49983 .49997 L
.49984 .49994 L
.49986 .49992 L
.49988 .49991 L
.4999 .4999 L
.49992 .4999 L
.49994 .4999 L
.49996 .49991 L
Mistroke
.49998 .49991 L
.5 .49992 L
.50001 .49994 L
.50002 .49995 L
.50003 .49996 L
.50004 .49997 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50004 .50002 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-2.1268662 0.42027716 -2.1112247 -0.033179314 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-2.0136671 -0.4125097 -1.8512457 -0.71444512 MAarrowhead1
% End of user PostScript
1 .473 0 r
.41796 .00278 m
.51209 .06599 L
s
% Start of user PostScript
-0.16407236 -0.99443888 0.024170116 -0.86801155 MAarrowhead1
% End of user PostScript
1 .788 0 r
.74413 .52572 m
.72887 .56615 L
s
% Start of user PostScript
0.48826897 0.051446558 0.45773356 0.13229486 MAarrowhead1
% End of user PostScript
.897 1 0 r
.53257 .62391 m
.50859 .61037 L
s
% Start of user PostScript
0.065145768 0.24782666 0.017181927 0.22073761 MAarrowhead1
% End of user PostScript
.581 1 0 r
.44144 .49992 m
.444 .48927 L
s
% Start of user PostScript
-0.11711199 -0.00015688481 -0.11200702 -0.021463405 MAarrowhead1
% End of user PostScript
.266 1 0 r
.48901 .46944 m
.49505 .47224 L
s
% Start of user PostScript
-0.021985725 -0.061121233 -0.0098998891 -0.055518376 MAarrowhead1
% End of user PostScript
0 1 .049 r
.51388 .49847 m
.51356 .50124 L
s
% Start of user PostScript
0.027767902 -0.0030514948 0.02712007 0.002485899 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50341 .50746 m
.50191 .50691 L
s
% Start of user PostScript
0.0068255094 0.014918032 0.0038124257 0.013816346 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49675 .50075 m
.49675 .50004 L
s
% Start of user PostScript
-0.0065023945 0.0015067189 -0.0064949773 0.00008551502 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49899 .4982 m
.49937 .4983 L
s
% Start of user PostScript
-0.0020118995 -0.0036025644 -0.0012685072 -0.0034027454 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50075 .49972 m
.50077 .4999 L
s
% Start of user PostScript
0.0015017526 -0.00055369162 0.0015375082 -0.00019312457 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50029 .50043 m
.5002 .50041 L
s
% Start of user PostScript
0.00057205429 0.00086038776 0.00039054375 0.00082934264 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49983 .50009 m
.49982 .50004 L
s
% Start of user PostScript
-0.00034140558 0.00018003837 -0.00035939964 0.00008955404 MAarrowhead1
% End of user PostScript
1 .104 0 r
.38724 1 m
.31265 .91789 L
.24466 .81808 L
.19779 .72158 L
.17053 .6317 L
.16082 .55099 L
.16624 .48119 L
.18413 .42336 L
.21178 .37787 L
.24652 .34457 L
.28582 .32283 L
.32737 .31167 L
.36916 .30983 L
.40947 .31589 L
.44693 .32834 L
.48049 .34565 L
.50945 .36636 L
.53338 .38909 L
.55214 .4126 L
.5658 .43584 L
.57463 .45791 L
.57906 .47812 L
.57962 .49596 L
.57691 .5111 L
.57155 .52336 L
.5642 .53272 L
.55545 .53927 L
.5459 .5432 L
.53604 .54477 L
.52632 .54429 L
.51711 .54213 L
.5087 .53862 L
.50129 .53414 L
.49501 .529 L
.48995 .52354 L
.4861 .51801 L
.48342 .51264 L
.48183 .50764 L
.48123 .50313 L
.48147 .49922 L
.48242 .49597 L
.48392 .4934 L
.48582 .49151 L
.48798 .49026 L
.49027 .4896 L
.49259 .48946 L
.49483 .48977 L
.49692 .49044 L
.49879 .49138 L
.50042 .49251 L
Mistroke
.50176 .49377 L
.50282 .49507 L
.5036 .49636 L
.50411 .49758 L
.50437 .49871 L
.50441 .49971 L
.50427 .50056 L
.50399 .50125 L
.50359 .50178 L
.50311 .50215 L
.50258 .50238 L
.50203 .50248 L
.5015 .50246 L
.50098 .50234 L
.50051 .50215 L
.5001 .50191 L
.49975 .50163 L
.49946 .50133 L
.49924 .50102 L
.49909 .50072 L
.499 .50044 L
.49896 .50019 L
.49897 .49997 L
.49902 .49979 L
.4991 .49964 L
.49921 .49954 L
.49933 .49946 L
.49945 .49943 L
.49958 .49942 L
.49971 .49943 L
.49982 .49947 L
.49993 .49952 L
.50002 .49958 L
.50009 .49965 L
.50015 .49972 L
.5002 .49979 L
.50023 .49986 L
.50024 .49992 L
.50024 .49998 L
.50024 .50003 L
.50022 .50007 L
.5002 .5001 L
.50017 .50012 L
.50015 .50013 L
.50011 .50014 L
.50008 .50014 L
.50006 .50013 L
.50003 .50012 L
.50001 .50011 L
.49999 .50009 L
Mistroke
.49997 .50007 L
.49996 .50006 L
.49995 .50004 L
.49994 .50003 L
.49994 .50001 L
.49994 .5 L
.49995 .49999 L
.49995 .49998 L
.49996 .49997 L
.49996 .49997 L
.49997 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.5 .49997 L
.5 .49998 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-0.62323376 -5.5250673 0.410136 -4.7701211 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
1.2612043 -3.9456205 1.9252043 -3.0957035 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.2976155 1.2024577 1.9790021 1.4319436 MAarrowhead1
% End of user PostScript
1 .788 0 r
.38724 1 m
.31265 .91789 L
s
% Start of user PostScript
-0.19484574 1.0337722 -0.37469468 0.83578763 MAarrowhead1
% End of user PostScript
.897 1 0 r
.21178 .37787 m
.24652 .34457 L
s
% Start of user PostScript
-0.57643607 -0.24425672 -0.50695981 -0.31085699 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50945 .36636 m
.53338 .38909 L
s
% Start of user PostScript
0.018904774 -0.26727427 0.066767572 -0.22181907 MAarrowhead1
% End of user PostScript
.266 1 0 r
.57155 .52336 m
.5642 .53272 L
s
% Start of user PostScript
0.14310318 0.046720048 0.1283904 0.065441607 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50129 .53414 m
.49501 .529 L
s
% Start of user PostScript
0.0025731853 0.068271108 -0.0099734875 0.058008523 MAarrowhead1
% End of user PostScript
0 1 .364 r
.48242 .49597 m
.48392 .4934 L
s
% Start of user PostScript
-0.035158713 -0.0080693548 -0.032164925 -0.013204893 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49879 .49138 m
.50042 .49251 L
s
% Start of user PostScript
-0.0024121024 -0.01724342 0.00083322963 -0.014972342 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50427 .50056 m
.50399 .50125 L
s
% Start of user PostScript
0.0085480802 0.0011180814 0.0079738996 0.0024993112 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50051 .50215 m
.5001 .50191 L
s
% Start of user PostScript
0.0010269931 0.0043087033 0.00019767445 0.0038184948 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49897 .49997 m
.49902 .49979 L
s
% Start of user PostScript
-0.0020560077 -0.000057875001 -0.0019563453 -0.00042326615 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49982 .49947 m
.49993 .49952 L
s
% Start of user PostScript
-0.00035720151 -0.0010654392 -0.0001476553 -0.00096302882 MAarrowhead1
% End of user PostScript
.383 1 0 r
0 .25706 m
.03533 .22185 L
.10613 .18094 L
.18132 .15935 L
.25718 .15485 L
.33058 .16487 L
.39896 .18669 L
.46041 .21754 L
.51357 .25472 L
.55766 .29575 L
.59236 .33836 L
.6178 .38059 L
.63444 .42082 L
.64304 .45775 L
.64454 .49045 L
.64001 .51827 L
.63061 .5409 L
.6175 .55826 L
.6018 .57051 L
.58454 .57797 L
.56668 .58111 L
.54901 .5805 L
.53222 .57678 L
.51684 .57058 L
.50326 .56255 L
.49172 .55331 L
.48237 .54343 L
.47522 .53339 L
.47022 .52363 L
.4672 .51449 L
.46599 .50624 L
.46633 .49906 L
.46796 .49308 L
.47061 .48833 L
.47401 .48481 L
.4779 .48246 L
.48205 .48119 L
.48626 .48088 L
.49033 .48138 L
.49414 .48255 L
.49758 .48422 L
.50056 .48626 L
.50303 .48852 L
.50499 .49088 L
.50644 .49322 L
.50739 .49546 L
.5079 .49752 L
.50801 .49935 L
.50778 .50091 L
.50728 .50218 L
Mistroke
.50656 .50317 L
.5057 .50386 L
.50475 .5043 L
.50376 .50449 L
.50278 .50447 L
.50185 .50427 L
.50099 .50394 L
.50023 .5035 L
.49958 .50299 L
.49906 .50244 L
.49865 .50189 L
.49837 .50135 L
.49819 .50084 L
.49812 .50038 L
.49813 .49997 L
.49822 .49964 L
.49836 .49937 L
.49855 .49917 L
.49876 .49904 L
.49899 .49896 L
.49922 .49894 L
.49945 .49897 L
.49966 .49903 L
.49985 .49912 L
.50002 .49923 L
.50016 .49936 L
.50027 .49949 L
.50035 .49962 L
.50041 .49974 L
.50044 .49985 L
.50044 .49996 L
.50043 .50004 L
.50041 .50012 L
.50037 .50017 L
.50032 .50021 L
.50027 .50024 L
.50021 .50025 L
.50016 .50025 L
.50011 .50024 L
.50006 .50022 L
.50002 .5002 L
.49998 .50017 L
.49995 .50014 L
.49993 .50011 L
.49991 .50008 L
.4999 .50005 L
.4999 .50002 L
.4999 .5 L
.4999 .49998 L
.49991 .49997 L
Mistroke
.49992 .49995 L
.49993 .49995 L
.49994 .49994 L
.49996 .49994 L
.49997 .49994 L
.49998 .49995 L
.49999 .49995 L
.5 .49996 L
.50001 .49996 L
.50001 .49997 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
4.3093214 -4.2056085 4.8885514 -2.7596304 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
5.1792982 -1.4354372 5.2162492 -0.26643112 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.7253706 2.9019627 1.1220084 2.7600793 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.1899675 0.50069258 -1.2295844 0.20524587 MAarrowhead1
% End of user PostScript
.897 1 0 r
.25718 .15485 m
.33058 .16487 L
s
% Start of user PostScript
-0.48563383 -0.69030106 -0.33884949 -0.6702503 MAarrowhead1
% End of user PostScript
.581 1 0 r
.63444 .42082 m
.64304 .45775 L
s
% Start of user PostScript
0.26888958 -0.15836968 0.28608015 -0.084499685 MAarrowhead1
% End of user PostScript
.266 1 0 r
.56668 .58111 m
.54901 .5805 L
s
% Start of user PostScript
0.13335041 0.16221925 0.098022964 0.16100953 MAarrowhead1
% End of user PostScript
0 1 .049 r
.47022 .52363 m
.4672 .51449 L
s
% Start of user PostScript
-0.059565392 0.047255003 -0.065590629 0.028977725 MAarrowhead1
% End of user PostScript
0 1 .364 r
.48205 .48119 m
.48626 .48088 L
s
% Start of user PostScript
-0.035895328 -0.037613646 -0.027488312 -0.038239399 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50644 .49322 m
.50739 .49546 L
s
% Start of user PostScript
0.01287384 -0.01355462 0.014784689 -0.0090791358 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50475 .5043 m
.50376 .50449 L
s
% Start of user PostScript
0.0095025578 0.008590113 0.0075260223 0.0089706946 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49865 .50189 m
.49837 .50135 L
s
% Start of user PostScript
-0.0026942173 0.0037768292 -0.003265357 0.0026924299 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49876 .49904 m
.49899 .49896 L
s
% Start of user PostScript
-0.0024795168 -0.0019273459 -0.002020985 -0.0020760215 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50027 .49949 m
.50035 .49962 L
s
% Start of user PostScript
0.00053902579 -0.0010287978 0.00070304967 -0.00076890504 MAarrowhead1
% End of user PostScript
0 1 .221 r
.47698 0 m
.54522 .05088 L
.62507 .12971 L
.68709 .2107 L
.73168 .29025 L
.75984 .36542 L
.77309 .4339 L
.77329 .49403 L
.76253 .54475 L
.743 .58553 L
.71689 .61635 L
.6863 .63757 L
.65316 .64988 L
.61923 .65422 L
.58597 .65169 L
.55461 .64351 L
.52611 .6309 L
.50113 .61508 L
.48012 .59719 L
.46328 .5783 L
.45061 .5593 L
.44195 .54098 L
.437 .52397 L
.43537 .50873 L
.43658 .49558 L
.44013 .48473 L
.44551 .47622 L
.4522 .47003 L
.45973 .46604 L
.46766 .46404 L
.47562 .46381 L
.48326 .46505 L
.49036 .4675 L
.49669 .47085 L
.50215 .47483 L
.50664 .47918 L
.51014 .48366 L
.51268 .48808 L
.5143 .49226 L
.51509 .49608 L
.51515 .49945 L
.5146 .50229 L
.51355 .50459 L
.51212 .50634 L
.51044 .50755 L
.50861 .50826 L
.50674 .50853 L
.50489 .50842 L
.50314 .50799 L
.50155 .5073 L
Mistroke
.50016 .50644 L
.49898 .50546 L
.49803 .50441 L
.49731 .50336 L
.49681 .50234 L
.49653 .50139 L
.49642 .50054 L
.49648 .4998 L
.49667 .49919 L
.49696 .49871 L
.49733 .49836 L
.49774 .49813 L
.49818 .49801 L
.49862 .49799 L
.49904 .49806 L
.49944 .49819 L
.49979 .49837 L
.5001 .49859 L
.50035 .49883 L
.50055 .49908 L
.50069 .49932 L
.50079 .49956 L
.50083 .49977 L
.50084 .49996 L
.50081 .50012 L
.50075 .50025 L
.50068 .50034 L
.50059 .50041 L
.50048 .50046 L
.50038 .50047 L
.50028 .50047 L
.50018 .50044 L
.50009 .50041 L
.50001 .50036 L
.49995 .50031 L
.49989 .50025 L
.49985 .50019 L
.49983 .50013 L
.49981 .50008 L
.4998 .50003 L
.4998 .49999 L
.49981 .49996 L
.49983 .49993 L
.49985 .49991 L
.49987 .4999 L
.4999 .49989 L
.49992 .49989 L
.49995 .49989 L
.49997 .4999 L
.49999 .49991 L
Mistroke
.5 .49992 L
.50002 .49993 L
.50003 .49995 L
.50004 .49996 L
.50004 .49997 L
.50005 .49999 L
.50005 .5 L
.50005 .50001 L
.50004 .50001 L
.50004 .50002 L
.50003 .50002 L
.50003 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
9.8807407 -2.2201766 9.8568356 -0.071483531 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
9.4425963 1.7351106 8.7172536 3.1822821 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
0.87340433 4.6906481 -0.018825467 4.112428 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-2.2843578 -0.19072208 -2.1506001 -0.57682398 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-0.33087197 -1.1663422 -0.10408826 -1.0432755 MAarrowhead1
% End of user PostScript
.581 1 0 r
.77329 .49403 m
.76253 .54475 L
s
% Start of user PostScript
0.54658739 -0.011936725 0.52506893 0.089496868 MAarrowhead1
% End of user PostScript
.266 1 0 r
.55461 .64351 m
.52611 .6309 L
s
% Start of user PostScript
0.10922652 0.28701293 0.052214411 0.26179337 MAarrowhead1
% End of user PostScript
0 1 .049 r
.43537 .50873 m
.43658 .49558 L
s
% Start of user PostScript
-0.12926449 0.01745443 -0.12684053 -0.0088338434 MAarrowhead1
% End of user PostScript
0 1 .364 r
.48326 .46505 m
.49036 .4675 L
s
% Start of user PostScript
-0.033470314 -0.069894053 -0.01928875 -0.065004073 MAarrowhead1
% End of user PostScript
0 1 .679 r
.51509 .49608 m
.51515 .49945 L
s
% Start of user PostScript
0.03018403 -0.00783793 0.030303285 -0.0011080928 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50489 .50842 m
.50314 .50799 L
s
% Start of user PostScript
0.0097797294 0.016839389 0.006288628 0.015973784 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49653 .50139 m
.49642 .50054 L
s
% Start of user PostScript
-0.0069488443 0.0027841797 -0.0071547562 0.0010808588 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49862 .49799 m
.49904 .49806 L
s
% Start of user PostScript
-0.0027629729 -0.004011779 -0.0019124885 -0.0038844403 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50079 .49956 m
.50083 .49977 L
s
% Start of user PostScript
0.0015738729 -0.00088939875 0.0016676491 -0.00046292696 MAarrowhead1
% End of user PostScript
0 1 .586 r
.71311 0 m
.76042 .05902 L
.82945 .17577 L
.87423 .28674 L
.89685 .38842 L
.89997 .47825 L
.8866 .55452 L
.85991 .61636 L
.82311 .66363 L
.7793 .69676 L
.73136 .71671 L
.68186 .72478 L
.63303 .72257 L
.58672 .71182 L
.54438 .69432 L
.50707 .67186 L
.47546 .64613 L
.4499 .61869 L
.43046 .59091 L
.41691 .56395 L
.40886 .53877 L
.40575 .51607 L
.40691 .49638 L
.41161 .47999 L
.41908 .46704 L
.42859 .45748 L
.43943 .45116 L
.45095 .4478 L
.46259 .44707 L
.47385 .44858 L
.48435 .4519 L
.49379 .45661 L
.50196 .4623 L
.50874 .46858 L
.51409 .47511 L
.51801 .48159 L
.52058 .48776 L
.52192 .49344 L
.52216 .49846 L
.52148 .50274 L
.52005 .50622 L
.51805 .5089 L
.51565 .51079 L
.51301 .51194 L
.51027 .51243 L
.50756 .51235 L
.50498 .51178 L
.50262 .51084 L
.50053 .50961 L
.49876 .5082 L
Mistroke
.49732 .50668 L
.49622 .50514 L
.49544 .50365 L
.49498 .50224 L
.49479 .50098 L
.49483 .49987 L
.49508 .49895 L
.49549 .49822 L
.49601 .49768 L
.4966 .49732 L
.49724 .49712 L
.49788 .49707 L
.49851 .49714 L
.49909 .49732 L
.49962 .49758 L
.50008 .49789 L
.50046 .49823 L
.50076 .4986 L
.50098 .49896 L
.50113 .4993 L
.50121 .49962 L
.50123 .4999 L
.50119 .50014 L
.50112 .50033 L
.50101 .50048 L
.50088 .50059 L
.50073 .50066 L
.50058 .50069 L
.50043 .50068 L
.50029 .50066 L
.50015 .5006 L
.50004 .50054 L
.49994 .50046 L
.49986 .50038 L
.49979 .50029 L
.49975 .50021 L
.49972 .50013 L
.49971 .50006 L
.49971 .5 L
.49973 .49995 L
.49975 .4999 L
.49978 .49987 L
.49981 .49985 L
.49984 .49984 L
.49988 .49984 L
.49991 .49984 L
.49995 .49985 L
.49998 .49986 L
.5 .49988 L
.50002 .4999 L
Mistroke
.50004 .49992 L
.50005 .49994 L
.50006 .49996 L
.50007 .49998 L
.50007 .49999 L
.50007 .50001 L
.50006 .50002 L
.50006 .50003 L
.50005 .50003 L
.50004 .50004 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50001 .50003 L
.5 .50003 L
.5 .50003 L
.49999 .50002 L
.49999 .50002 L
.49999 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
9.9683156 7.1754004 8.2292718 7.86319 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
6.4403331 8.1261131 4.6810489 8.021865 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-3.0289889 2.2420492 -3.3060673 1.3379196 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.7413069 -1.8905208 -1.3214814 -1.9105247 MAarrowhead1
% End of user PostScript
.897 1 0 r
.82945 .17577 m
.87423 .28674 L
s
% Start of user PostScript
0.65890204 -0.64846393 0.74845438 -0.42651969 MAarrowhead1
% End of user PostScript
.581 1 0 r
.73136 .71671 m
.68186 .72478 L
s
% Start of user PostScript
0.46271393 0.43341148 0.36371384 0.4495655 MAarrowhead1
% End of user PostScript
.266 1 0 r
.43046 .59091 m
.41691 .56395 L
s
% Start of user PostScript
-0.13908924 0.18182176 -0.16617785 0.1279077 MAarrowhead1
% End of user PostScript
0 1 .049 r
.43943 .45116 m
.45095 .4478 L
s
% Start of user PostScript
-0.12113596 -0.097685367 -0.098092388 -0.1043947 MAarrowhead1
% End of user PostScript
0 1 .364 r
.51409 .47511 m
.51801 .48159 L
s
% Start of user PostScript
0.028174563 -0.049775495 0.036019573 -0.036819664 MAarrowhead1
% End of user PostScript
0 1 .679 r
.51565 .51079 m
.51301 .51194 L
s
% Start of user PostScript
0.031296216 0.021572353 0.026010371 0.023881878 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49732 .50668 m
.49622 .50514 L
s
% Start of user PostScript
-0.00536548 0.013365146 -0.0075672787 0.010287043 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49601 .49768 m
.4966 .49732 L
s
% Start of user PostScript
-0.0079888211 -0.0046439585 -0.0067966669 -0.0053691038 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50046 .49823 m
.50076 .4986 L
s
% Start of user PostScript
0.00091921031 -0.0035305948 0.0015224404 -0.0028082061 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50101 .50048 m
.50088 .50059 L
s
% Start of user PostScript
0.0020164927 0.00096668541 0.0017530093 0.0011820267 MAarrowhead1
% End of user PostScript
.578 0 1 r
.85631 0 m
.85788 .00217 L
.93305 .1456 L
.97883 .28019 L
.99811 .40195 L
.99438 .50809 L
.97147 .59687 L
.93339 .66752 L
.88409 .72012 L
.82735 .75548 L
.76663 .77495 L
.70499 .7803 L
.64505 .77357 L
.58893 .75699 L
.53827 .73279 L
.49421 .70317 L
.45745 .67018 L
.4283 .63568 L
.40669 .60129 L
.39229 .56838 L
.3845 .53801 L
.38258 .511 L
.38567 .48788 L
.39283 .46896 L
.40313 .45432 L
.41565 .44386 L
.42953 .43732 L
.444 .43434 L
.45839 .43446 L
.47213 .43718 L
.48478 .44198 L
.49601 .44833 L
.5056 .45572 L
.51342 .4637 L
.51945 .47185 L
.52373 .47982 L
.52638 .48731 L
.52755 .49411 L
.52742 .50005 L
.52623 .50504 L
.52417 .50903 L
.52148 .51201 L
.51836 .51403 L
.51501 .51517 L
.51159 .51552 L
.50826 .51519 L
.50514 .51431 L
.50231 .513 L
.49984 .51137 L
.49778 .50956 L
Mistroke
.49613 .50765 L
.49491 .50574 L
.49408 .50391 L
.49363 .50222 L
.4935 .50071 L
.49365 .49941 L
.49403 .49835 L
.49459 .49752 L
.49528 .49693 L
.49604 .49655 L
.49684 .49637 L
.49764 .49637 L
.4984 .49651 L
.49911 .49677 L
.49974 .49711 L
.50027 .49752 L
.50071 .49796 L
.50106 .49841 L
.5013 .49885 L
.50145 .49927 L
.50152 .49965 L
.50152 .49998 L
.50146 .50026 L
.50135 .50049 L
.5012 .50065 L
.50103 .50077 L
.50084 .50084 L
.50066 .50086 L
.50047 .50084 L
.5003 .5008 L
.50014 .50073 L
.5 .50064 L
.49988 .50054 L
.49979 .50043 L
.49972 .50033 L
.49967 .50022 L
.49965 .50013 L
.49964 .50004 L
.49965 .49997 L
.49967 .49991 L
.4997 .49987 L
.49974 .49983 L
.49978 .49981 L
.49982 .4998 L
.49987 .4998 L
.49991 .49981 L
.49995 .49982 L
.49998 .49984 L
.50001 .49986 L
.50004 .49989 L
Mistroke
.50006 .49991 L
.50007 .49993 L
.50008 .49996 L
.50008 .49998 L
.50008 .5 L
.50008 .50001 L
.50008 .50003 L
.50007 .50004 L
.50006 .50004 L
.50005 .50005 L
.50004 .50005 L
.50003 .50005 L
.50002 .50004 L
.50001 .50004 L
.5 .50004 L
.49999 .50003 L
.49999 .50002 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
5.0878791 9.8504216 3.0731476 9.2287954 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
1.2589728 8.3379101 -0.31429484 7.2566196 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-4.1158992 -0.49228235 -3.8478233 -1.1645864 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.51855151 -2.0809923 -0.11703503 -1.8483398 MAarrowhead1
% End of user PostScript
.897 1 0 r
.99438 .50809 m
.97147 .59687 L
s
% Start of user PostScript
0.98875119 0.016184021 0.94294445 0.19373466 MAarrowhead1
% End of user PostScript
.581 1 0 r
.58893 .75699 m
.53827 .73279 L
s
% Start of user PostScript
0.17786275 0.51398461 0.076534098 0.46558987 MAarrowhead1
% End of user PostScript
.266 1 0 r
.38258 .511 m
.38567 .48788 L
s
% Start of user PostScript
-0.23483061 0.021995228 -0.22865781 -0.024234972 MAarrowhead1
% End of user PostScript
0 1 .049 r
.47213 .43718 m
.48478 .44198 L
s
% Start of user PostScript
-0.055733038 -0.125635 -0.030433613 -0.11603833 MAarrowhead1
% End of user PostScript
0 1 .364 r
.52755 .49411 m
.52742 .50005 L
s
% Start of user PostScript
0.055090752 -0.011775842 0.054847652 0.00010957663 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50826 .51519 m
.50514 .51431 L
s
% Start of user PostScript
0.016528889 0.030385845 0.010277838 0.028620239 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49363 .50222 m
.4935 .50071 L
s
% Start of user PostScript
-0.01274954 0.0044401417 -0.013005635 0.0014199677 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49764 .49637 m
.4984 .49651 L
s
% Start of user PostScript
-0.0047205683 -0.0072685713 -0.0031920256 -0.0069858729 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50145 .49927 m
.50152 .49965 L
s
% Start of user PostScript
0.0029053343 -0.0014624117 0.0030457669 -0.00070335319 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50066 .50086 m
.50047 .50084 L
s
% Start of user PostScript
0.0013109664 0.0017184706 0.00094113244 0.0016871348 MAarrowhead1
% End of user PostScript
1 0 .219 r
1 .81558 m
.99729 .81801 L
.91781 .8586 L
.83438 .87833 L
.75098 .87977 L
.67093 .86579 L
.59689 .83942 L
.53087 .80372 L
.47421 .7616 L
.42768 .71578 L
.39151 .66869 L
.36549 .62241 L
.34902 .57867 L
.34123 .53881 L
.34105 .50379 L
.34725 .47424 L
.35856 .45047 L
.37371 .43249 L
.39148 .4201 L
.41074 .41289 L
.43048 .41033 L
.44982 .41176 L
.46807 .41649 L
.48467 .4238 L
.49921 .43299 L
.51145 .44338 L
.52127 .45436 L
.52866 .46541 L
.53372 .47607 L
.53661 .48597 L
.53758 .49484 L
.53689 .5025 L
.53484 .50883 L
.53172 .51378 L
.52783 .5174 L
.52346 .51973 L
.51885 .5209 L
.51422 .52105 L
.50977 .52033 L
.50565 .51892 L
.50196 .51697 L
.49878 .51466 L
.49616 .51213 L
.49412 .50953 L
.49264 .50696 L
.49169 .50452 L
.49123 .5023 L
.49119 .50034 L
.49151 .49868 L
.49212 .49734 L
Mistroke
.49294 .49632 L
.49392 .49562 L
.49498 .4952 L
.49607 .49504 L
.49715 .4951 L
.49816 .49535 L
.49909 .49575 L
.4999 .49625 L
.50059 .49682 L
.50114 .49743 L
.50156 .49804 L
.50185 .49863 L
.50202 .49919 L
.50208 .49968 L
.50205 .50011 L
.50194 .50047 L
.50177 .50075 L
.50156 .50095 L
.50132 .50109 L
.50106 .50115 L
.50081 .50117 L
.50056 .50113 L
.50033 .50105 L
.50012 .50095 L
.49994 .50082 L
.4998 .50068 L
.49968 .50054 L
.4996 .5004 L
.49954 .50026 L
.49952 .50014 L
.49951 .50003 L
.49953 .49993 L
.49956 .49986 L
.49961 .4998 L
.49966 .49976 L
.49972 .49974 L
.49978 .49973 L
.49984 .49973 L
.49989 .49974 L
.49995 .49976 L
.49999 .49979 L
.50003 .49982 L
.50006 .49986 L
.50009 .49989 L
.5001 .49992 L
.50011 .49995 L
.50012 .49998 L
.50011 .5 L
.50011 .50002 L
.5001 .50004 L
Mistroke
.50009 .50005 L
.50007 .50006 L
.50006 .50006 L
.50005 .50006 L
.50003 .50006 L
.50002 .50006 L
.50001 .50005 L
.5 .50005 L
.49999 .50004 L
.49998 .50003 L
.49998 .50002 L
.49997 .50001 L
.49997 .50001 L
.49997 .5 L
.49997 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
1.0512303 -1.2211173 1.2280816 -0.83769989 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
1.3274301 -0.48233805 1.3577453 -0.16473851 MAarrowhead1
% End of user PostScript
1 .473 0 r
.75098 .87977 m
.67093 .86579 L
s
% Start of user PostScript
0.50195347 0.75953813 0.34185064 0.73157678 MAarrowhead1
% End of user PostScript
1 .788 0 r
.34902 .57867 m
.34123 .53881 L
s
% Start of user PostScript
-0.30196234 0.15734401 -0.31753251 0.077611252 MAarrowhead1
% End of user PostScript
.897 1 0 r
.43048 .41033 m
.44982 .41176 L
s
% Start of user PostScript
-0.13904689 -0.17934476 -0.10035322 -0.17648072 MAarrowhead1
% End of user PostScript
.581 1 0 r
.53372 .47607 m
.53661 .48597 L
s
% Start of user PostScript
0.067433031 -0.047867912 0.07322887 -0.028061254 MAarrowhead1
% End of user PostScript
.266 1 0 r
.51885 .5209 m
.51422 .52105 L
s
% Start of user PostScript
0.037697836 0.041805756 0.028449122 0.042100883 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49264 .50696 m
.49169 .50452 L
s
% Start of user PostScript
-0.014722844 0.013917707 -0.016619679 0.0090483668 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49498 .4952 m
.49607 .49504 L
s
% Start of user PostScript
-0.010040533 -0.0096055177 -0.0078557288 -0.0099244804 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50156 .49804 m
.50185 .49863 L
s
% Start of user PostScript
0.003122977 -0.0039177025 0.0037011906 -0.0027330641 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50132 .50109 m
.50106 .50115 L
s
% Start of user PostScript
0.0026338572 0.0021706193 0.0021243246 0.0023091678 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49968 .50054 m
.4996 .5004 L
s
% Start of user PostScript
-0.00063695346 0.0010758362 -0.00080530026 0.00079071277 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49966 .49976 m
.49972 .49974 L
s
% Start of user PostScript
-0.00068170443 -0.00048087575 -0.00056456655 -0.00052945672 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50006 .49986 m
.50009 .49989 L
s
% Start of user PostScript
0.00012260501 -0.00028961018 0.00017004111 -0.00022175577 MAarrowhead1
% End of user PostScript
0 .89 1 r
.28235 1 m
.2393 .9466 L
.16926 .82891 L
.12368 .71697 L
.10048 .61432 L
.09697 .52358 L
.11015 .44646 L
.1368 .38387 L
.17369 .33597 L
.21771 .30232 L
.26596 .28197 L
.31581 .27361 L
.36503 .27565 L
.41175 .28633 L
.45449 .30384 L
.49219 .32639 L
.52415 .35225 L
.55002 .37988 L
.56973 .40787 L
.58349 .43505 L
.5917 .46047 L
.59492 .48338 L
.59384 .50328 L
.58917 .51986 L
.58169 .53298 L
.57214 .54267 L
.56124 .54911 L
.54964 .55254 L
.53792 .55332 L
.52656 .55185 L
.51597 .54854 L
.50643 .54382 L
.49817 .5381 L
.49131 .53178 L
.4859 .5252 L
.48192 .51867 L
.4793 .51244 L
.47794 .50672 L
.47767 .50164 L
.47834 .49732 L
.47976 .49379 L
.48177 .49108 L
.48419 .48916 L
.48684 .48799 L
.4896 .48748 L
.49233 .48755 L
.49493 .48811 L
.49732 .48906 L
.49943 .49029 L
.50122 .49171 L
Mistroke
.50268 .49324 L
.50379 .49479 L
.50458 .4963 L
.50505 .49771 L
.50525 .49899 L
.50521 .50011 L
.50496 .50104 L
.50456 .50178 L
.50404 .50233 L
.50344 .5027 L
.5028 .5029 L
.50215 .50295 L
.50151 .50288 L
.50092 .5027 L
.50039 .50245 L
.49993 .50213 L
.49954 .50179 L
.49924 .50142 L
.49901 .50106 L
.49886 .50071 L
.49878 .50039 L
.49876 .50011 L
.4988 .49987 L
.49887 .49967 L
.49898 .49952 L
.49911 .49941 L
.49926 .49934 L
.49941 .49931 L
.49956 .49931 L
.49971 .49934 L
.49984 .49939 L
.49996 .49946 L
.50006 .49954 L
.50014 .49962 L
.50021 .49971 L
.50025 .49979 L
.50028 .49987 L
.50029 .49994 L
.50029 .5 L
.50028 .50005 L
.50025 .5001 L
.50023 .50013 L
.50019 .50015 L
.50016 .50016 L
.50012 .50016 L
.50009 .50016 L
.50005 .50015 L
.50002 .50014 L
.5 .50012 L
.49998 .5001 L
Mistroke
.49996 .50008 L
.49995 .50006 L
.49994 .50004 L
.49993 .50002 L
.49993 .50001 L
.49993 .49999 L
.49994 .49998 L
.49994 .49997 L
.49995 .49997 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49999 .49997 L
.5 .49997 L
.5 .49997 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-4.7499759 -8.0862875 -3.0712168 -7.6804119 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-1.5391536 -7.0325594 -0.19150217 -6.2074851 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.3815951 0.16602962 3.2047735 0.75586742 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
0.55051813 1.742602 0.20925157 1.5689623 MAarrowhead1
% End of user PostScript
.897 1 0 r
.09697 .52358 m
.11015 .44646 L
s
% Start of user PostScript
-0.80605786 0.047160493 -0.77970803 -0.10707063 MAarrowhead1
% End of user PostScript
.581 1 0 r
.41175 .28633 m
.45449 .30384 L
s
% Start of user PostScript
-0.17650897 -0.427336 -0.091021471 -0.39231464 MAarrowhead1
% End of user PostScript
.266 1 0 r
.59492 .48338 m
.59384 .50328 L
s
% Start of user PostScript
0.18984744 -0.033234992 0.18767175 0.0065685539 MAarrowhead1
% End of user PostScript
0 1 .049 r
.52656 .55185 m
.51597 .54854 L
s
% Start of user PostScript
0.053124928 0.10369946 0.031933972 0.097075694 MAarrowhead1
% End of user PostScript
0 1 .364 r
.47794 .50672 m
.47767 .50164 L
s
% Start of user PostScript
-0.044129899 0.01343851 -0.044664758 0.0032881911 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49233 .48755 m
.49493 .48811 L
s
% Start of user PostScript
-0.015331576 -0.024892544 -0.010132992 -0.023772326 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50505 .49771 m
.50525 .49899 L
s
% Start of user PostScript
0.010107162 -0.0045724192 0.010501887 -0.002012745 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50215 .50295 m
.50151 .50288 L
s
% Start of user PostScript
0.0042917205 0.0059072523 0.0030297221 0.0057604227 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49886 .50071 m
.49878 .50039 L
s
% Start of user PostScript
-0.0022754135 0.001426205 -0.0024365561 0.00078757365 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49941 .49931 m
.49956 .49931 L
s
% Start of user PostScript
-0.0011733661 -0.0013846041 -0.00087030827 -0.0013806844 MAarrowhead1
% End of user PostScript
1 0 .949 r
.30931 0 m
.39244 .03415 L
.48195 .08778 L
.55782 .14929 L
.61919 .21495 L
.66594 .28146 L
.69856 .34604 L
.71799 .40641 L
.72559 .46082 L
.72295 .50807 L
.71181 .54741 L
.694 .57854 L
.67128 .60153 L
.64536 .61677 L
.61779 .62489 L
.58994 .62672 L
.56296 .62318 L
.5378 .61529 L
.51516 .60405 L
.49555 .59045 L
.47927 .57543 L
.46643 .55979 L
.45699 .54428 L
.45079 .52949 L
.44755 .51589 L
.44693 .50384 L
.44853 .49357 L
.45194 .48521 L
.45671 .47878 L
.46246 .47423 L
.46878 .47144 L
.47533 .47024 L
.48182 .47043 L
.488 .47176 L
.49366 .47402 L
.49867 .47695 L
.50292 .48033 L
.50638 .48395 L
.50903 .48764 L
.51089 .49122 L
.51201 .49459 L
.51248 .49763 L
.51237 .50027 L
.51179 .50248 L
.51082 .50424 L
.50958 .50554 L
.50816 .50642 L
.50663 .50689 L
.50509 .50702 L
.50359 .50684 L
Mistroke
.50219 .50642 L
.50092 .50581 L
.49983 .50507 L
.49891 .50424 L
.49819 .50337 L
.49765 .50251 L
.49729 .50169 L
.4971 .50093 L
.49706 .50026 L
.49714 .49968 L
.49732 .49921 L
.49758 .49885 L
.4979 .49859 L
.49825 .49843 L
.49861 .49835 L
.49897 .49836 L
.49931 .49843 L
.49963 .49855 L
.49991 .49871 L
.50015 .4989 L
.50034 .4991 L
.50049 .4993 L
.5006 .4995 L
.50066 .49969 L
.50069 .49986 L
.50069 .50001 L
.50066 .50013 L
.5006 .50023 L
.50054 .5003 L
.50046 .50035 L
.50037 .50038 L
.50029 .50039 L
.5002 .50038 L
.50013 .50036 L
.50006 .50032 L
.49999 .50028 L
.49994 .50024 L
.4999 .50019 L
.49987 .50014 L
.49985 .5001 L
.49984 .50005 L
.49984 .50002 L
.49984 .49998 L
.49985 .49996 L
.49986 .49994 L
.49988 .49992 L
.4999 .49991 L
.49992 .49991 L
.49994 .49991 L
.49996 .49991 L
Mistroke
.49998 .49992 L
.49999 .49993 L
.50001 .49994 L
.50002 .49995 L
.50003 .49996 L
.50003 .49997 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50003 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
6.0965866 -7.7224801 7.2389198 -5.3981598 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
7.9083772 -3.2311221 8.1541043 -1.2827754 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.1771232 4.574362 2.2062159 4.4340277 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.7895521 1.0280566 -1.899235 0.54050516 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-0.87394554 -1.0760471 -0.64006813 -1.0660908 MAarrowhead1
% End of user PostScript
.581 1 0 r
.69856 .34604 m
.71799 .40641 L
s
% Start of user PostScript
0.39711295 -0.30791868 0.43598486 -0.18718661 MAarrowhead1
% End of user PostScript
.266 1 0 r
.61779 .62489 m
.58994 .62672 L
s
% Start of user PostScript
0.23558965 0.24978211 0.17988149 0.25343093 MAarrowhead1
% End of user PostScript
0 1 .049 r
.45699 .54428 m
.45079 .52949 L
s
% Start of user PostScript
-0.08601585 0.088560357 -0.09841805 0.058972672 MAarrowhead1
% End of user PostScript
0 1 .364 r
.46878 .47144 m
.47533 .47024 L
s
% Start of user PostScript
-0.062444502 -0.057118054 -0.049334072 -0.059513742 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50903 .48764 m
.51089 .49122 L
s
% Start of user PostScript
0.018054163 -0.024726504 0.021775348 -0.017551392 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50816 .50642 m
.50663 .50689 L
s
% Start of user PostScript
0.016311411 0.01283501 0.013266556 0.013788541 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49819 .50337 m
.49765 .50251 L
s
% Start of user PostScript
-0.0036274255 0.0067463963 -0.004699001 0.0050252444 MAarrowhead1
% End of user PostScript
0 .375 1 r
.4979 .49859 m
.49825 .49843 L
s
% Start of user PostScript
-0.0042057408 -0.0028239886 -0.0035090656 -0.0031461447 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50034 .4991 m
.50049 .4993 L
s
% Start of user PostScript
0.00068187725 -0.0018064167 0.00098134719 -0.0013982736 MAarrowhead1
% End of user PostScript
0 1 .743 r
0 .15129 m
.01989 .13803 L
.10663 .10748 L
.19517 .09753 L
.2817 .10527 L
.36306 .12755 L
.43683 .16115 L
.50129 .20291 L
.55534 .24984 L
.59851 .29924 L
.63081 .34874 L
.65269 .39634 L
.66495 .44045 L
.66865 .47985 L
.66501 .51374 L
.65535 .54163 L
.64103 .56339 L
.62337 .57911 L
.60362 .58915 L
.58289 .59401 L
.56217 .59433 L
.5423 .59083 L
.52392 .58425 L
.50754 .57537 L
.49348 .56489 L
.48195 .55351 L
.47298 .54181 L
.46654 .53031 L
.46247 .51945 L
.46055 .50956 L
.46052 .50087 L
.46207 .49354 L
.46489 .48765 L
.46866 .4832 L
.47308 .48013 L
.47787 .47835 L
.48277 .47772 L
.48758 .47809 L
.49211 .47927 L
.49622 .48109 L
.49983 .48337 L
.50287 .48596 L
.5053 .48869 L
.50713 .49143 L
.50838 .49408 L
.5091 .49653 L
.50934 .49874 L
.50916 .50064 L
.50865 .5022 L
.50787 .50343 L
Mistroke
.50691 .50433 L
.50582 .50491 L
.50467 .50519 L
.50352 .50523 L
.50242 .50505 L
.50139 .5047 L
.50048 .50421 L
.49969 .50364 L
.49904 .50301 L
.49854 .50236 L
.49817 .50172 L
.49793 .50112 L
.49782 .50057 L
.49781 .50008 L
.49789 .49967 L
.49804 .49934 L
.49825 .49908 L
.49849 .49891 L
.49876 .49881 L
.49903 .49877 L
.49929 .49878 L
.49955 .49885 L
.49978 .49894 L
.49998 .49907 L
.50015 .49921 L
.50028 .49936 L
.50039 .49951 L
.50046 .49966 L
.5005 .4998 L
.50052 .49992 L
.50051 .50003 L
.50048 .50012 L
.50044 .50019 L
.50039 .50024 L
.50033 .50027 L
.50026 .50029 L
.5002 .50029 L
.50014 .50028 L
.50008 .50026 L
.50003 .50024 L
.49999 .5002 L
.49995 .50017 L
.49992 .50013 L
.4999 .5001 L
.49989 .50006 L
.49988 .50003 L
.49988 .50001 L
.49988 .49998 L
.49989 .49996 L
.4999 .49995 L
Mistroke
.49992 .49994 L
.49993 .49993 L
.49995 .49993 L
.49996 .49993 L
.49997 .49994 L
.49999 .49994 L
.5 .49995 L
.50001 .49996 L
.50002 .49996 L
.50002 .49997 L
.50003 .49998 L
.50003 .49999 L
.50003 .5 L
.50003 .5 L
.50003 .50001 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
4.407299 2.8907048 3.6897351 3.2390866 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
2.9398195 3.402008 2.1927352 3.4027282 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.2221947 1.0657997 -1.3633452 0.67565602 MAarrowhead1
% End of user PostScript
1 .788 0 r
.10663 .10748 m
.19517 .09753 L
s
% Start of user PostScript
-0.78674258 -0.78503988 -0.60965017 -0.80494247 MAarrowhead1
% End of user PostScript
.897 1 0 r
.63081 .34874 m
.65269 .39634 L
s
% Start of user PostScript
0.26161317 -0.30251321 0.30537395 -0.2073112 MAarrowhead1
% End of user PostScript
.581 1 0 r
.60362 .58915 m
.58289 .59401 L
s
% Start of user PostScript
0.20723504 0.17829392 0.16577705 0.18801508 MAarrowhead1
% End of user PostScript
.266 1 0 r
.47298 .54181 m
.46654 .53031 L
s
% Start of user PostScript
-0.054035575 0.083613067 -0.066922892 0.060628025 MAarrowhead1
% End of user PostScript
0 1 .049 r
.47308 .48013 m
.47787 .47835 L
s
% Start of user PostScript
-0.053835474 -0.039739408 -0.044263621 -0.043298701 MAarrowhead1
% End of user PostScript
0 1 .364 r
.5053 .48869 m
.50713 .49143 L
s
% Start of user PostScript
0.010603182 -0.022627883 0.014265091 -0.017139793 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50691 .50433 m
.50582 .50491 L
s
% Start of user PostScript
0.013811743 0.0086555914 0.011636493 0.0098107705 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49904 .50301 m
.49854 .50236 L
s
% Start of user PostScript
-0.001916415 0.0060175788 -0.0029294075 0.0047226363 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49825 .49908 m
.49849 .49891 L
s
% Start of user PostScript
-0.0035028244 -0.0018302044 -0.0030176294 -0.002180538 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50015 .49921 m
.50028 .49936 L
s
% Start of user PostScript
0.00029548547 -0.0015764486 0.00056981696 -0.0012748319 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50044 .50019 m
.50039 .50024 L
s
% Start of user PostScript
0.00087872509 0.00037162037 0.0007729472 0.00047326079 MAarrowhead1
% End of user PostScript
1 0 .923 r
.29065 1 m
.20878 .88353 L
.15155 .7702 L
.11744 .66426 L
.1041 .56876 L
.10874 .48584 L
.12828 .4168 L
.15954 .36217 L
.19941 .32182 L
.24489 .29508 L
.29327 .28082 L
.34216 .27762 L
.3895 .28383 L
.43367 .29768 L
.47339 .3174 L
.50781 .34125 L
.53638 .36763 L
.55892 .39506 L
.57548 .42229 L
.58636 .44825 L
.59204 .47212 L
.59313 .49326 L
.59032 .51129 L
.58435 .52596 L
.57597 .53725 L
.56589 .54523 L
.55479 .55012 L
.54329 .55222 L
.5319 .5519 L
.52107 .54955 L
.51113 .5456 L
.50234 .54046 L
.49487 .53453 L
.4888 .52816 L
.48416 .5217 L
.48089 .5154 L
.47892 .5095 L
.4781 .50417 L
.47829 .49952 L
.47932 .49564 L
.48101 .49256 L
.48319 .49027 L
.48569 .48874 L
.48836 .4879 L
.49107 .48768 L
.4937 .48799 L
.49616 .48873 L
.49838 .4898 L
.50031 .49111 L
.50191 .49256 L
Mistroke
.50318 .49408 L
.50412 .49559 L
.50475 .49703 L
.50508 .49837 L
.50516 .49955 L
.50502 .50056 L
.5047 .50138 L
.50424 .50202 L
.50369 .50248 L
.50308 .50276 L
.50244 .50289 L
.50181 .50288 L
.50121 .50276 L
.50065 .50254 L
.50016 .50226 L
.49974 .50194 L
.4994 .50159 L
.49914 .50123 L
.49895 .50088 L
.49884 .50055 L
.49879 .50025 L
.4988 .49999 L
.49885 .49977 L
.49894 .4996 L
.49906 .49947 L
.4992 .49938 L
.49934 .49933 L
.49949 .49932 L
.49964 .49933 L
.49978 .49937 L
.4999 .49943 L
.50001 .4995 L
.5001 .49958 L
.50017 .49967 L
.50023 .49975 L
.50026 .49983 L
.50028 .4999 L
.50029 .49997 L
.50028 .50003 L
.50026 .50007 L
.50024 .50011 L
.50021 .50014 L
.50017 .50015 L
.50014 .50016 L
.5001 .50016 L
.50007 .50015 L
.50004 .50014 L
.50001 .50013 L
.49999 .50011 L
.49997 .50009 L
Mistroke
.49995 .50007 L
.49994 .50005 L
.49994 .50003 L
.49993 .50002 L
.49993 .5 L
.49994 .49999 L
.49994 .49998 L
.49995 .49997 L
.49995 .49997 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49999 .49997 L
.49999 .49997 L
.5 .49997 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
2.7616344 -2.7375704 3.1405577 -1.8042486 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
3.3330575 -0.94861374 3.3613648 -0.19241024 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.1233149 1.8709409 0.73384354 1.7814593 MAarrowhead1
% End of user PostScript
1 .788 0 r
.11744 .66426 m
.1041 .56876 L
s
% Start of user PostScript
-0.76512902 0.32851675 -0.79180051 0.13751524 MAarrowhead1
% End of user PostScript
.897 1 0 r
.34216 .27762 m
.3895 .28383 L
s
% Start of user PostScript
-0.31568963 -0.44475912 -0.22099563 -0.43234994 MAarrowhead1
% End of user PostScript
.581 1 0 r
.58636 .44825 m
.59204 .47212 L
s
% Start of user PostScript
0.17271778 -0.10349747 0.18408245 -0.055769693 MAarrowhead1
% End of user PostScript
.266 1 0 r
.54329 .55222 m
.5319 .5519 L
s
% Start of user PostScript
0.086580412 0.1044436 0.063803737 0.10379656 MAarrowhead1
% End of user PostScript
0 1 .049 r
.48089 .5154 m
.47892 .5095 L
s
% Start of user PostScript
-0.038214327 0.030802648 -0.042168369 0.019000409 MAarrowhead1
% End of user PostScript
0 1 .364 r
.48836 .4879 m
.49107 .48768 L
s
% Start of user PostScript
-0.023282516 -0.024198147 -0.017865766 -0.02463529 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50412 .49559 m
.50475 .49703 L
s
% Start of user PostScript
0.0082464139 -0.0088192552 0.00949533 -0.0059309601 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50308 .50276 m
.50244 .50289 L
s
% Start of user PostScript
0.006158322 0.0055213034 0.004885711 0.0057751288 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49914 .50123 m
.49895 .50088 L
s
% Start of user PostScript
-0.0017221867 0.002453949 -0.0020945066 0.0017545371 MAarrowhead1
% End of user PostScript
0 .375 1 r
.4992 .49938 m
.49934 .49933 L
s
% Start of user PostScript
-0.0016056942 -0.0012374693 -0.0013106961 -0.0013354229 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50017 .49967 m
.50023 .49975 L
s
% Start of user PostScript
0.00034350493 -0.00066770064 0.00045023247 -0.00050018016 MAarrowhead1
% End of user PostScript
1 .129 0 r
.67961 1 m
.63146 .98223 L
.53793 .93038 L
.45789 .86964 L
.39239 .80386 L
.34171 .7365 L
.30549 .67049 L
.28287 .60827 L
.27256 .5517 L
.273 .50215 L
.28245 .46046 L
.29908 .42705 L
.32108 .40192 L
.3467 .38475 L
.37434 .37494 L
.40256 .37171 L
.43015 .37413 L
.45611 .38119 L
.47965 .39187 L
.50023 .40516 L
.51749 .42011 L
.53128 .43585 L
.54161 .45163 L
.54862 .46682 L
.55255 .48089 L
.55376 .49346 L
.55262 .50428 L
.54956 .51319 L
.54501 .52015 L
.53939 .52518 L
.53309 .52839 L
.52649 .52996 L
.51988 .53007 L
.51354 .52897 L
.50768 .52688 L
.50245 .52405 L
.49796 .52072 L
.49428 .51709 L
.49141 .51336 L
.48935 .5097 L
.48805 .50623 L
.48743 .50308 L
.48741 .5003 L
.4879 .49796 L
.4888 .49608 L
.49 .49466 L
.49141 .49367 L
.49293 .4931 L
.49449 .4929 L
.49602 .49301 L
Mistroke
.49747 .49339 L
.49878 .49397 L
.49994 .49469 L
.50091 .49552 L
.50168 .49639 L
.50227 .49726 L
.50267 .4981 L
.5029 .49889 L
.50298 .49959 L
.50292 .5002 L
.50276 .5007 L
.50251 .50109 L
.5022 .50138 L
.50186 .50156 L
.50149 .50166 L
.50113 .50167 L
.50077 .50161 L
.50045 .5015 L
.50016 .50134 L
.4999 .50116 L
.4997 .50096 L
.49953 .50075 L
.49942 .50055 L
.49934 .50036 L
.49931 .50018 L
.4993 .50003 L
.49933 .4999 L
.49938 .49979 L
.49944 .49971 L
.49952 .49965 L
.4996 .49962 L
.49969 .49961 L
.49977 .49961 L
.49985 .49963 L
.49993 .49966 L
.49999 .4997 L
.50005 .49975 L
.50009 .4998 L
.50012 .49984 L
.50015 .49989 L
.50016 .49994 L
.50016 .49997 L
.50016 .50001 L
.50015 .50004 L
.50014 .50006 L
.50012 .50008 L
.5001 .50009 L
.50008 .50009 L
.50006 .50009 L
.50004 .50009 L
Mistroke
.50003 .50008 L
.50001 .50008 L
.5 .50007 L
.49998 .50005 L
.49997 .50004 L
.49997 .50003 L
.49996 .50002 L
.49996 .50001 L
.49996 .5 L
.49996 .49999 L
.49997 .49999 L
.49997 .49998 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-5.8299906 8.3683629 -7.1015232 5.9910775 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-7.8849323 3.7558672 -8.2272545 1.7293081 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-3.446669 -4.6344702 -2.4531295 -4.5337837 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.7701428 -1.1604961 1.9047901 -0.65566228 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
0.93943341 1.0841736 0.70123713 1.0848682 MAarrowhead1
% End of user PostScript
.581 1 0 r
.30549 .67049 m
.28287 .60827 L
s
% Start of user PostScript
-0.38901575 0.34098873 -0.43426213 0.21653336 MAarrowhead1
% End of user PostScript
.266 1 0 r
.37434 .37494 m
.40256 .37171 L
s
% Start of user PostScript
-0.25132938 -0.25011414 -0.19487848 -0.25657765 MAarrowhead1
% End of user PostScript
0 1 .049 r
.54161 .45163 m
.54862 .46682 L
s
% Start of user PostScript
0.08322333 -0.096732117 0.097235009 -0.066368583 MAarrowhead1
% End of user PostScript
0 1 .364 r
.53309 .52839 m
.52649 .52996 L
s
% Start of user PostScript
0.066184688 0.056786781 0.052972472 0.059915791 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49141 .51336 m
.48935 .5097 L
s
% Start of user PostScript
-0.017176439 0.026724886 -0.021299663 0.019395528 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49141 .49367 m
.49293 .4931 L
s
% Start of user PostScript
-0.017189354 -0.012652284 -0.014139724 -0.013794448 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50168 .49639 m
.50227 .49726 L
s
% Start of user PostScript
0.0033665942 -0.0072299531 0.0045375526 -0.0054803015 MAarrowhead1
% End of user PostScript
0 .375 1 r
.5022 .50138 m
.50186 .50156 L
s
% Start of user PostScript
0.0044090515 0.0027544812 0.0037162238 0.0031245947 MAarrowhead1
% End of user PostScript
0 .06 1 r
.4997 .50096 m
.49953 .50075 L
s
% Start of user PostScript
-0.00060727801 0.0019221462 -0.00093106094 0.0015093997 MAarrowhead1
% End of user PostScript
.424 0 1 r
.99211 0 m
1 .01699 L
s
1 .73565 m
.94652 .78394 L
.87544 .82064 L
.80077 .83863 L
.72605 .84018 L
.65429 .82788 L
.58788 .80445 L
.52862 .7726 L
.47773 .73496 L
.43589 .69397 L
.40334 .65181 L
.37988 .61034 L
.36499 .57112 L
.35789 .53535 L
.35761 .50391 L
.36307 .47736 L
.37313 .45598 L
.38665 .43979 L
.40253 .42861 L
.41976 .42207 L
.43743 .41971 L
.45477 .42093 L
.47113 .42512 L
.48602 .43163 L
.49908 .43983 L
.51008 .44912 L
.51891 .45896 L
.52556 .46885 L
.53013 .4784 L
.53276 .48729 L
.53365 .49525 L
.53306 .50213 L
.53124 .50781 L
.52846 .51228 L
.52499 .51553 L
.52108 .51764 L
.51695 .51871 L
.51281 .51886 L
.50882 .51822 L
.50512 .51697 L
.50181 .51523 L
.49895 .51317 L
.4966 .51091 L
.49476 .50857 L
.49343 .50627 L
.49257 .50409 L
.49215 .50209 L
.49211 .50033 L
.49239 .49884 L
.49293 .49764 L
Mistroke
.49367 .49672 L
.49454 .49608 L
.49549 .4957 L
.49647 .49556 L
.49743 .49561 L
.49834 .49583 L
.49917 .49619 L
.4999 .49663 L
.50052 .49714 L
.50102 .49769 L
.50139 .49824 L
.50165 .49877 L
.50181 .49926 L
.50186 .49971 L
.50184 .50009 L
.50174 .50041 L
.50159 .50066 L
.5014 .50085 L
.50118 .50097 L
.50096 .50103 L
.50073 .50104 L
.5005 .50101 L
.5003 .50095 L
.50011 .50085 L
.49995 .50074 L
.49982 .50061 L
.49972 .50048 L
.49964 .50036 L
.49959 .50023 L
.49957 .50012 L
.49956 .50003 L
.49958 .49994 L
.49961 .49987 L
.49965 .49982 L
.49969 .49979 L
.49975 .49976 L
.4998 .49975 L
.49985 .49976 L
.4999 .49977 L
.49995 .49979 L
.49999 .49981 L
.50003 .49984 L
.50005 .49987 L
.50008 .4999 L
.50009 .49993 L
.5001 .49996 L
.5001 .49998 L
.5001 .5 L
.5001 .50002 L
.50009 .50004 L
Mistroke
.50008 .50005 L
.50007 .50005 L
.50005 .50006 L
.50004 .50006 L
.50003 .50006 L
.50002 .50005 L
.50001 .50005 L
.5 .50004 L
.49999 .50003 L
.49998 .50003 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-3.5638123 5.3741143 -4.3881931 3.8802529 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-4.9047428 2.4710502 -5.1422249 1.1892686 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.2143177 -2.9014042 -1.589863 -2.848667 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.0975427 -0.75604338 1.1876764 -0.43729362 MAarrowhead1
% End of user PostScript
.897 1 0 r
.80077 .83863 m
.72605 .84018 L
s
% Start of user PostScript
0.60153384 0.67725323 0.45210221 0.68036384 MAarrowhead1
% End of user PostScript
.581 1 0 r
.37988 .61034 m
.36499 .57112 L
s
% Start of user PostScript
-0.2402382 0.22067874 -0.27001989 0.14223328 MAarrowhead1
% End of user PostScript
.266 1 0 r
.41976 .42207 m
.43743 .41971 L
s
% Start of user PostScript
-0.16048244 -0.15585146 -0.12513876 -0.16058459 MAarrowhead1
% End of user PostScript
0 1 .049 r
.52556 .46885 m
.53013 .4784 L
s
% Start of user PostScript
0.0511283 -0.062298282 0.06025929 -0.04319317 MAarrowhead1
% End of user PostScript
0 1 .364 r
.52108 .51764 m
.51695 .51871 L
s
% Start of user PostScript
0.04215944 0.035282806 0.033905443 0.037415902 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49476 .50857 m
.49343 .50627 L
s
% Start of user PostScript
-0.010476576 0.017146404 -0.013145558 0.012542987 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49454 .49608 m
.49549 .4957 L
s
% Start of user PostScript
-0.010926067 -0.0078337407 -0.0090255957 -0.0085924965 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50102 .49769 m
.50139 .49824 L
s
% Start of user PostScript
0.0020310892 -0.0046243113 0.0027853365 -0.003527484 MAarrowhead1
% End of user PostScript
0 .375 1 r
.5014 .50085 m
.50118 .50097 L
s
% Start of user PostScript
0.0027970233 0.0016979796 0.0023665062 0.0019405401 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49982 .50061 m
.49972 .50048 L
s
% Start of user PostScript
-0.00035944784 0.001226188 -0.00056720913 0.00096797714 MAarrowhead1
% End of user PostScript
1 .91 0 r
.1835 1 m
.14869 .94967 L
.08201 .815 L
.04275 .68935 L
.02808 .57631 L
.03464 .47835 L
.05876 .397 L
.09664 .33282 L
.14458 .28563 L
.19903 .25459 L
.25678 .23834 L
.31498 .23517 L
.37124 .2431 L
.42361 .26003 L
.47063 .28383 L
.51128 .31246 L
.54495 .344 L
.57142 .3767 L
.59078 .40909 L
.6034 .43992 L
.60986 .46819 L
.61089 .4932 L
.60732 .51447 L
.60004 .53175 L
.58992 .54498 L
.57783 .55428 L
.56457 .55993 L
.55085 .56227 L
.53731 .56174 L
.52444 .55883 L
.51267 .55404 L
.50228 .54785 L
.49346 .54074 L
.48632 .53315 L
.48088 .52545 L
.47707 .51796 L
.47479 .51096 L
.47389 .50465 L
.47417 .49916 L
.47545 .49459 L
.4775 .49097 L
.48012 .48829 L
.48311 .48651 L
.4863 .48555 L
.48953 .48533 L
.49265 .48573 L
.49557 .48663 L
.4982 .48793 L
.50047 .4895 L
.50237 .49123 L
Mistroke
.50386 .49304 L
.50496 .49484 L
.50569 .49655 L
.50607 .49813 L
.50614 .49953 L
.50596 .50072 L
.50557 .5017 L
.50502 .50244 L
.50436 .50298 L
.50363 .5033 L
.50287 .50344 L
.50212 .50343 L
.5014 .50327 L
.50075 .50301 L
.50016 .50268 L
.49967 .50229 L
.49927 .50187 L
.49896 .50144 L
.49874 .50102 L
.49861 .50063 L
.49856 .50028 L
.49857 .49997 L
.49863 .49972 L
.49874 .49951 L
.49889 .49936 L
.49905 .49926 L
.49923 .4992 L
.49941 .49919 L
.49958 .49921 L
.49974 .49926 L
.49989 .49933 L
.50002 .49941 L
.50012 .49951 L
.50021 .49961 L
.50027 .49971 L
.50031 .4998 L
.50033 .49989 L
.50034 .49997 L
.50033 .50004 L
.50031 .50009 L
.50028 .50013 L
.50024 .50016 L
.5002 .50018 L
.50016 .50019 L
.50012 .50019 L
.50008 .50018 L
.50004 .50017 L
.50001 .50015 L
.49998 .50013 L
.49996 .50011 L
Mistroke
.49994 .50008 L
.49993 .50006 L
.49992 .50004 L
.49992 .50002 L
.49992 .5 L
.49992 .49999 L
.49993 .49997 L
.49994 .49997 L
.49995 .49996 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49999 .49996 L
.49999 .49996 L
.5 .49997 L
.50001 .49997 L
.50001 .49998 L
.50001 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
0.50397441 -6.6951093 1.7015991 -5.5509351 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
2.6389071 -4.3684698 3.3202078 -3.2011472 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.7779836 1.9800408 2.2969162 2.1747972 MAarrowhead1
% End of user PostScript
1 .788 0 r
.1835 1 m
.14869 .94967 L
s
% Start of user PostScript
-0.51029651 1.1773588 -0.70262511 0.8993471 MAarrowhead1
% End of user PostScript
.897 1 0 r
.14458 .28563 m
.19903 .25459 L
s
% Start of user PostScript
-0.710842 -0.42874685 -0.60193605 -0.49082898 MAarrowhead1
% End of user PostScript
.581 1 0 r
.54495 .344 m
.57142 .3767 L
s
% Start of user PostScript
0.089898647 -0.31200979 0.14283239 -0.24659172 MAarrowhead1
% End of user PostScript
.266 1 0 r
.58992 .54498 m
.57783 .55428 L
s
% Start of user PostScript
0.1798366 0.089953005 0.15565696 0.10856969 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49346 .54074 m
.48632 .53315 L
s
% Start of user PostScript
-0.013076511 0.081488532 -0.027352291 0.066297861 MAarrowhead1
% End of user PostScript
0 1 .364 r
.4775 .49097 m
.48012 .48829 L
s
% Start of user PostScript
-0.045008284 -0.018062221 -0.039767417 -0.023421053 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50047 .4895 m
.50237 .49123 L
s
% Start of user PostScript
0.00094908814 -0.021008019 0.0047344212 -0.017532979 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50557 .5017 m
.50502 .50244 L
s
% Start of user PostScript
0.011146891 0.0033919603 0.010045888 0.004889124 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50016 .50268 m
.49967 .50229 L
s
% Start of user PostScript
0.00032952495 0.0053520052 -0.00065959143 0.0045707648 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49863 .49972 m
.49874 .49951 L
s
% Start of user PostScript
-0.0027321292 -0.00056585914 -0.0025106333 -0.00097455331 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49989 .49933 m
.50002 .49941 L
s
% Start of user PostScript
-0.0002193915 -0.0013483971 0.000035720033 -0.0011764084 MAarrowhead1
% End of user PostScript
.342 0 1 r
.88036 0 m
.9479 .12748 L
.99634 .26762 L
s
.99634 .26762 m
1 .28997 L
s
1 .56095 m
.99069 .59809 L
.95155 .67205 L
.90064 .72725 L
.84188 .76451 L
.77889 .7852 L
.71485 .79117 L
.6525 .78454 L
.59406 .76759 L
.54125 .74266 L
.49526 .71203 L
.45685 .67784 L
.42633 .64203 L
.40365 .60628 L
.38847 .57203 L
.38018 .54039 L
.37802 .51222 L
.38108 .48808 L
.38841 .46829 L
.39902 .45295 L
.41197 .44195 L
.42636 .43504 L
.44138 .43184 L
.45634 .43188 L
.47064 .43463 L
.48382 .43956 L
.49553 .44611 L
.50554 .45377 L
.51372 .46204 L
.52004 .47051 L
.52454 .47879 L
.52734 .4866 L
.5286 .49368 L
.52851 .49988 L
.52729 .50509 L
.52518 .50926 L
.5224 .51239 L
.51917 .51453 L
.5157 .51574 L
.51215 .51612 L
.50869 .5158 L
.50543 .5149 L
.50248 .51355 L
.49991 .51187 L
.49775 .50999 L
.49603 .50801 L
.49474 .50603 L
.49387 .50412 L
.49339 .50236 L
.49325 .50078 L
Mistroke
.4934 .49943 L
.49379 .49832 L
.49436 .49745 L
.49507 .49682 L
.49586 .49642 L
.49669 .49623 L
.49752 .49622 L
.49832 .49637 L
.49905 .49663 L
.49971 .49699 L
.50027 .49741 L
.50073 .49786 L
.50109 .49833 L
.50134 .49879 L
.50151 .49923 L
.50158 .49962 L
.50158 .49997 L
.50152 .50026 L
.5014 .5005 L
.50125 .50068 L
.50108 .5008 L
.50088 .50087 L
.50069 .50089 L
.50049 .50088 L
.50031 .50083 L
.50015 .50076 L
.5 .50066 L
.49988 .50056 L
.49979 .50045 L
.49971 .50034 L
.49966 .50024 L
.49964 .50014 L
.49963 .50005 L
.49963 .49997 L
.49965 .49991 L
.49969 .49986 L
.49972 .49983 L
.49977 .4998 L
.49981 .49979 L
.49986 .49979 L
.4999 .4998 L
.49994 .49981 L
.49998 .49983 L
.50001 .49985 L
.50004 .49988 L
.50006 .49991 L
.50007 .49993 L
.50008 .49996 L
.50009 .49998 L
.50009 .5 L
Mistroke
.50008 .50001 L
.50008 .50003 L
.50007 .50004 L
.50006 .50004 L
.50005 .50005 L
.50004 .50005 L
.50003 .50005 L
.50002 .50005 L
.50001 .50004 L
.5 .50004 L
.49999 .50003 L
.49999 .50003 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-4.3410058 1.3810089 -4.40438 0.37324772 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-4.2814501 -0.48765058 -4.0070418 -1.1908367 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-0.55216479 -2.1680632 -0.13333189 -1.9278468 MAarrowhead1
% End of user PostScript
1 .788 0 r
1 .56095 m
.99069 .59809 L
s
% Start of user PostScript
1.0278761 0.010639688 0.98138332 0.19618816 MAarrowhead1
% End of user PostScript
.897 1 0 r
.59406 .76759 m
.54125 .74266 L
s
% Start of user PostScript
0.18812977 0.53517572 0.082496256 0.4853201 MAarrowhead1
% End of user PostScript
.581 1 0 r
.37802 .51222 m
.38108 .48808 L
s
% Start of user PostScript
-0.24395962 0.024433829 -0.23783528 -0.023842474 MAarrowhead1
% End of user PostScript
.266 1 0 r
.47064 .43463 m
.48382 .43956 L
s
% Start of user PostScript
-0.0587264 -0.13073738 -0.03236786 -0.1208839 MAarrowhead1
% End of user PostScript
0 1 .049 r
.5286 .49368 m
.52851 .49988 L
s
% Start of user PostScript
0.057190598 -0.01263516 0.057012996 -0.00023219569 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50869 .5158 m
.50543 .5149 L
s
% Start of user PostScript
0.017373208 0.031600628 0.010864293 0.029797862 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49339 .50236 m
.49325 .50078 L
s
% Start of user PostScript
-0.013224669 0.0047134644 -0.013509952 0.0015637863 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49752 .49622 m
.49832 .49637 L
s
% Start of user PostScript
-0.0049527964 -0.0075543145 -0.0033621411 -0.0072690001 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50151 .49923 m
.50158 .49962 L
s
% Start of user PostScript
0.0030107585 -0.0015442589 0.0031615292 -0.00075313284 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50069 .50089 m
.50049 .50088 L
s
% Start of user PostScript
0.0013735632 0.001784796 0.00098893516 0.0017544363 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49966 .50024 m
.49964 .50014 L
s
% Start of user PostScript
-0.00067299897 0.0004710457 -0.00072962469 0.00027442149 MAarrowhead1
% End of user PostScript
.355 1 0 r
0 .15525 m
.07929 .11936 L
.16685 .10256 L
.25368 .10436 L
.33642 .12168 L
.41242 .15135 L
.47972 .1902 L
.53703 .23521 L
.58365 .28357 L
.61945 .33283 L
.64472 .38086 L
.66015 .42595 L
.66669 .46676 L
.66552 .50235 L
.65792 .53213 L
.64522 .55584 L
.62876 .57351 L
.60979 .58541 L
.58947 .59198 L
.56884 .59382 L
.54877 .59161 L
.52996 .58609 L
.51298 .57802 L
.49821 .56812 L
.48588 .55709 L
.47609 .54554 L
.46884 .53403 L
.46399 .523 L
.46136 .51283 L
.4607 .50377 L
.46171 .49602 L
.4641 .48967 L
.46753 .48476 L
.47172 .48124 L
.47636 .47904 L
.4812 .47803 L
.48602 .47806 L
.49062 .47896 L
.49486 .48056 L
.49863 .48268 L
.50184 .48515 L
.50447 .48782 L
.50649 .49055 L
.50793 .49322 L
.50882 .49573 L
.50922 .49801 L
.50918 .5 L
.50878 .50167 L
.5081 .50301 L
.5072 .50401 L
Mistroke
.50616 .50469 L
.50504 .50508 L
.50389 .50519 L
.50278 .50509 L
.50173 .50479 L
.50078 .50436 L
.49996 .50381 L
.49926 .50321 L
.49871 .50257 L
.4983 .50193 L
.49802 .50132 L
.49787 .50075 L
.49782 .50024 L
.49787 .49981 L
.498 .49945 L
.49819 .49917 L
.49842 .49897 L
.49867 .49885 L
.49894 .49879 L
.49921 .49878 L
.49946 .49883 L
.4997 .49892 L
.49991 .49903 L
.50009 .49917 L
.50024 .49931 L
.50035 .49947 L
.50043 .49961 L
.50049 .49975 L
.50051 .49988 L
.50051 .49999 L
.50049 .50009 L
.50045 .50016 L
.5004 .50022 L
.50035 .50026 L
.50028 .50028 L
.50022 .50029 L
.50016 .50028 L
.5001 .50027 L
.50005 .50024 L
.5 .50021 L
.49996 .50018 L
.49993 .50014 L
.49991 .50011 L
.49989 .50008 L
.49988 .50004 L
.49988 .50002 L
.49988 .49999 L
.49989 .49997 L
.4999 .49996 L
.49991 .49994 L
Mistroke
.49993 .49994 L
.49994 .49993 L
.49996 .49993 L
.49997 .49993 L
.49998 .49994 L
.49999 .49995 L
.5 .49995 L
.50001 .49996 L
.50002 .49997 L
.50002 .49998 L
.50003 .49999 L
.50003 .49999 L
.50003 .5 L
.50003 .5 L
.50003 .50001 L
.50002 .50001 L
.50002 .50001 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
5.2071384 2.0705983 4.6042812 2.693575 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
3.9140847 3.1088218 3.1781712 3.3330829 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-0.88554284 1.6148753 -1.1412966 1.1997435 MAarrowhead1
% End of user PostScript
1 .788 0 r
0 .15525 m
.07929 .11936 L
s
% Start of user PostScript
-1.0099729 -0.68498077 -0.84142933 -0.7612712 MAarrowhead1
% End of user PostScript
.897 1 0 r
.58365 .28357 m
.61945 .33283 L
s
% Start of user PostScript
0.16730972 -0.43285478 0.23889908 -0.33434163 MAarrowhead1
% End of user PostScript
.581 1 0 r
.62876 .57351 m
.60979 .58541 L
s
% Start of user PostScript
0.25751513 0.1470298 0.21957224 0.17082344 MAarrowhead1
% End of user PostScript
.266 1 0 r
.48588 .55709 m
.47609 .54554 L
s
% Start of user PostScript
-0.028238557 0.11417424 -0.047810602 0.091084163 MAarrowhead1
% End of user PostScript
0 1 .049 r
.46753 .48476 m
.47172 .48124 L
s
% Start of user PostScript
-0.064930142 -0.030484654 -0.056563067 -0.037519487 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50184 .48515 m
.50447 .48782 L
s
% Start of user PostScript
0.0036807884 -0.029696272 0.0089302201 -0.024357997 MAarrowhead1
% End of user PostScript
0 1 .679 r
.5081 .50301 m
.5072 .50401 L
s
% Start of user PostScript
0.01619767 0.0060160317 0.014399777 0.008020694 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49996 .50381 m
.49926 .50321 L
s
% Start of user PostScript
-0.000088745511 0.0076271705 -0.0014741377 0.0064121204 MAarrowhead1
% End of user PostScript
0 .69 1 r
.498 .49945 m
.49819 .49917 L
s
% Start of user PostScript
-0.0039987831 -0.0010979188 -0.003625471 -0.0016536932 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49991 .49903 m
.50009 .49917 L
s
% Start of user PostScript
-0.00018028707 -0.0019363459 0.00018022045 -0.0016648173 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50049 .50009 m
.50045 .50016 L
s
% Start of user PostScript
0.00097697277 0.00017284519 0.00090314178 0.0003236255 MAarrowhead1
% End of user PostScript
.114 0 1 r
.39307 1 m
.35369 .96197 L
.27588 .8627 L
.21953 .76487 L
.18345 .67215 L
.16581 .58743 L
.16437 .51282 L
.17659 .44967 L
.19977 .39868 L
.23124 .35992 L
.26841 .33298 L
.30887 .31705 L
.35047 .311 L
.39138 .31347 L
.43006 .32301 L
.46533 .33809 L
.49633 .35722 L
.52249 .379 L
.54356 .40211 L
.5595 .42543 L
.5705 .44799 L
.57692 .46901 L
.57923 .48789 L
.578 .50422 L
.57385 .51777 L
.56741 .52843 L
.55931 .53624 L
.55014 .54134 L
.54044 .54398 L
.53067 .54443 L
.52125 .54303 L
.51249 .54014 L
.50464 .53611 L
.49786 .53128 L
.49226 .52597 L
.48786 .52048 L
.48466 .51505 L
.48258 .50989 L
.48154 .50516 L
.4814 .50099 L
.48202 .49744 L
.48327 .49457 L
.48498 .49238 L
.48702 .49084 L
.48925 .48992 L
.49156 .48954 L
.49383 .48965 L
.49598 .49015 L
.49795 .49097 L
.49968 .49201 L
Mistroke
.50115 .49321 L
.50234 .49449 L
.50324 .49578 L
.50387 .49703 L
.50424 .4982 L
.50438 .49926 L
.50433 .50017 L
.50411 .50093 L
.50376 .50154 L
.50332 .50198 L
.50281 .50227 L
.50228 .50243 L
.50174 .50246 L
.50121 .50239 L
.50073 .50224 L
.50029 .50202 L
.49991 .50175 L
.49959 .50146 L
.49934 .50116 L
.49916 .50085 L
.49904 .50057 L
.49898 .5003 L
.49897 .50007 L
.499 .49987 L
.49907 .49971 L
.49916 .49959 L
.49927 .4995 L
.4994 .49944 L
.49952 .49942 L
.49965 .49943 L
.49977 .49945 L
.49988 .4995 L
.49998 .49955 L
.50006 .49962 L
.50013 .49969 L
.50018 .49976 L
.50021 .49983 L
.50023 .4999 L
.50024 .49995 L
.50024 .50001 L
.50023 .50005 L
.50021 .50008 L
.50019 .50011 L
.50016 .50012 L
.50013 .50013 L
.5001 .50014 L
.50007 .50013 L
.50004 .50012 L
.50002 .50011 L
.5 .5001 L
Mistroke
.49998 .50008 L
.49996 .50007 L
.49995 .50005 L
.49995 .50003 L
.49994 .50002 L
.49994 .5 L
.49994 .49999 L
.49995 .49998 L
.49995 .49998 L
.49996 .49997 L
.49997 .49997 L
.49997 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49998 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
1.0829146 1.6034823 0.74391029 1.5486828 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
0.42958196 1.4407497 0.14853798 1.2925293 MAarrowhead1
% End of user PostScript
1 .473 0 r
.16437 .51282 m
.17659 .44967 L
s
% Start of user PostScript
-0.67125239 0.025638544 -0.64682583 -0.1006557 MAarrowhead1
% End of user PostScript
1 .788 0 r
.43006 .32301 m
.46533 .33809 L
s
% Start of user PostScript
-0.13987095 -0.35398826 -0.069331393 -0.32382278 MAarrowhead1
% End of user PostScript
.897 1 0 r
.57923 .48789 m
.578 .50422 L
s
% Start of user PostScript
0.15845717 -0.024219411 0.15600001 0.0084494787 MAarrowhead1
% End of user PostScript
.581 1 0 r
.52125 .54303 m
.51249 .54014 L
s
% Start of user PostScript
0.042503068 0.086067939 0.024983998 0.080280904 MAarrowhead1
% End of user PostScript
.266 1 0 r
.48154 .50516 m
.4814 .50099 L
s
% Start of user PostScript
-0.036926177 0.010323877 -0.037205982 0.0019752457 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49383 .48965 m
.49598 .49015 L
s
% Start of user PostScript
-0.01234805 -0.020702135 -0.008042047 -0.019697162 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50424 .4982 m
.50438 .49926 L
s
% Start of user PostScript
0.0084815874 -0.0035925003 0.0087682905 -0.0014829435 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50174 .50246 m
.50121 .50239 L
s
% Start of user PostScript
0.0034738058 0.0049234532 0.0024264537 0.0047822854 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49904 .50057 m
.49898 .5003 L
s
% Start of user PostScript
-0.0019159042 0.0011348208 -0.0020395566 0.00060747332 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49952 .49942 m
.49965 .49943 L
s
% Start of user PostScript
-0.00095349472 -0.0011567341 -0.00070147252 -0.0011485843 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50021 .49983 m
.50023 .4999 L
s
% Start of user PostScript
0.00042424914 -0.00033832581 0.00046748324 -0.00020787148 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50013 .50013 m
.5001 .50014 L
s
% Start of user PostScript
0.00025657819 0.00026814195 0.00019661613 0.00027272778 MAarrowhead1
% End of user PostScript
1 0 .666 r
.09778 1 m
.04203 .89777 L
s
.04203 .89777 m
0 .78116 L
s
0 .38505 m
.02896 .3275 L
.0808 .26882 L
.14108 .2288 L
.20603 .20606 L
.27231 .19872 L
.33706 .2046 L
.39793 .22136 L
.45311 .24656 L
.5013 .27786 L
.54171 .31301 L
.57396 .35 L
.59807 .38705 L
.61439 .42267 L
.62352 .45566 L
.62624 .48513 L
.62348 .51046 L
.61622 .53131 L
.60548 .54755 L
.59225 .55929 L
.57745 .56678 L
.56193 .57039 L
.54643 .5706 L
.53155 .56796 L
.51781 .56303 L
.50556 .55636 L
.49505 .54851 L
.48643 .53999 L
.47973 .53123 L
.47492 .52263 L
.47189 .5145 L
.47046 .5071 L
.47045 .50061 L
.47162 .49513 L
.47374 .49073 L
.47657 .4874 L
.47988 .48511 L
.48346 .48379 L
.48713 .48332 L
.49073 .4836 L
.49411 .48449 L
.4972 .48586 L
.49989 .48757 L
.50216 .4895 L
.50398 .49155 L
.50535 .4936 L
.50628 .49558 L
.50681 .49742 L
.50699 .49907 L
.50686 .50049 L
Mistroke
.50647 .50166 L
.50589 .50258 L
.50516 .50324 L
.50435 .50367 L
.50349 .50389 L
.50263 .50391 L
.5018 .50378 L
.50104 .50351 L
.50035 .50315 L
.49976 .50272 L
.49928 .50225 L
.4989 .50176 L
.49863 .50129 L
.49845 .50083 L
.49837 .50042 L
.49836 .50006 L
.49842 .49975 L
.49854 .4995 L
.49869 .49931 L
.49887 .49918 L
.49907 .49911 L
.49927 .49908 L
.49947 .49909 L
.49966 .49914 L
.49983 .49921 L
.49998 .4993 L
.50011 .49941 L
.50021 .49952 L
.50029 .49964 L
.50034 .49975 L
.50038 .49985 L
.50039 .49994 L
.50038 .50002 L
.50036 .50009 L
.50033 .50014 L
.50029 .50018 L
.50024 .5002 L
.5002 .50021 L
.50015 .50022 L
.5001 .50021 L
.50006 .5002 L
.50002 .50018 L
.49999 .50015 L
.49996 .50013 L
.49994 .5001 L
.49992 .50007 L
.49991 .50005 L
.49991 .50002 L
.49991 .5 L
.49991 .49999 L
Mistroke
.49992 .49997 L
.49993 .49996 L
.49994 .49996 L
.49995 .49995 L
.49996 .49995 L
.49997 .49995 L
.49998 .49995 L
.49999 .49996 L
.5 .49996 L
.50001 .49997 L
.50001 .49997 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
0.16214499 -7.9367091 1.600736 -6.6596346 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
2.7443584 -5.3212686 3.5946342 -3.9849719 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.2952996 2.1664616 2.757853 2.426141 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.5101459 1.4217412 -0.74699368 1.1053434 MAarrowhead1
% End of user PostScript
.897 1 0 r
.0808 .26882 m
.14108 .2288 L
s
% Start of user PostScript
-0.83840295 -0.46236211 -0.71784488 -0.54239478 MAarrowhead1
% End of user PostScript
.581 1 0 r
.54171 .31301 m
.57396 .35 L
s
% Start of user PostScript
0.083412251 -0.37397327 0.1479134 -0.29999685 MAarrowhead1
% End of user PostScript
.266 1 0 r
.60548 .54755 m
.59225 .55929 L
s
% Start of user PostScript
0.2109648 0.095109661 0.18449661 0.11858559 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49505 .54851 m
.48643 .53999 L
s
% Start of user PostScript
-0.0099031982 0.097029251 -0.02714717 0.079973793 MAarrowhead1
% End of user PostScript
0 1 .364 r
.47374 .49073 m
.47657 .4874 L
s
% Start of user PostScript
-0.052523967 -0.018548125 -0.046868817 -0.025199512 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49989 .48757 m
.50216 .4895 L
s
% Start of user PostScript
-0.00021342089 -0.024864879 0.0043248047 -0.020995338 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50647 .50166 m
.50589 .50258 L
s
% Start of user PostScript
0.012941461 0.0033167868 0.011776362 0.0051526359 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50035 .50315 m
.49976 .50272 L
s
% Start of user PostScript
0.00070692646 0.0062992947 -0.00047109152 0.0054378947 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49842 .49975 m
.49854 .4995 L
s
% Start of user PostScript
-0.0031555839 -0.00049942827 -0.0029278328 -0.00099569396 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49983 .49921 m
.49998 .4993 L
s
% Start of user PostScript
-0.0003338667 -0.0015786372 -0.000031856343 -0.0013913089 MAarrowhead1
% End of user PostScript
.72 1 0 r
1 .78295 m
.94568 .82215 L
.86769 .85269 L
.78751 .86422 L
.70871 .85934 L
.63421 .84087 L
.5663 .81174 L
.50665 .77481 L
.45631 .73283 L
.41579 .68827 L
.38515 .64334 L
.36402 .59989 L
.35172 .55942 L
.34732 .52307 L
.34974 .49164 L
.35778 .46558 L
.37021 .44509 L
.38584 .43008 L
.40352 .42028 L
.42223 .41523 L
.44104 .41439 L
.45919 .41711 L
.47605 .4227 L
.49117 .43049 L
.50421 .43981 L
.51499 .45004 L
.52344 .46062 L
.5296 .47108 L
.53358 .48102 L
.53559 .49012 L
.53584 .49815 L
.53463 .50497 L
.53222 .5105 L
.52891 .51472 L
.52498 .51767 L
.52068 .51944 L
.51624 .52015 L
.51186 .51994 L
.50772 .51897 L
.50393 .51739 L
.50059 .51537 L
.49776 .51306 L
.49548 .5106 L
.49375 .50811 L
.49254 .5057 L
.49182 .50344 L
.49155 .50141 L
.49166 .49965 L
.49208 .49819 L
.49276 .49703 L
Mistroke
.49361 .49618 L
.49459 .49562 L
.49562 .49532 L
.49666 .49526 L
.49767 .49539 L
.49861 .49569 L
.49945 .49612 L
.50019 .49663 L
.50079 .49719 L
.50127 .49778 L
.50162 .49836 L
.50185 .49891 L
.50197 .49942 L
.50199 .49987 L
.50192 .50025 L
.5018 .50056 L
.50162 .5008 L
.5014 .50097 L
.50116 .50107 L
.50092 .50111 L
.50067 .50111 L
.50044 .50106 L
.50023 .50097 L
.50005 .50086 L
.49989 .50073 L
.49976 .5006 L
.49966 .50046 L
.49959 .50032 L
.49955 .5002 L
.49953 .50009 L
.49954 .49999 L
.49956 .4999 L
.4996 .49984 L
.49964 .49979 L
.4997 .49976 L
.49975 .49974 L
.49981 .49974 L
.49987 .49974 L
.49992 .49976 L
.49997 .49978 L
.50001 .49981 L
.50004 .49984 L
.50007 .49987 L
.50009 .49991 L
.5001 .49994 L
.50011 .49997 L
.50011 .49999 L
.50011 .50001 L
.5001 .50003 L
.50009 .50004 L
Mistroke
.50008 .50005 L
.50007 .50006 L
.50005 .50006 L
.50004 .50006 L
.50003 .50006 L
.50001 .50005 L
.5 .50005 L
.49999 .50004 L
.49999 .50003 L
.49998 .50003 L
.49998 .50002 L
.49998 .50001 L
.49997 .50001 L
.49997 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-4.9546437 3.4986372 -5.377131 2.046244 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-5.516761 0.74519367 -5.4133607 -0.37678227 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.428591 -2.9829819 -0.82333594 -2.7743069 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.2881895 -0.33457682 1.2932919 -0.047350718 MAarrowhead1
% End of user PostScript
.897 1 0 r
.70871 .85934 m
.63421 .84087 L
s
% Start of user PostScript
0.41741479 0.71867866 0.26841871 0.68174168 MAarrowhead1
% End of user PostScript
.581 1 0 r
.35172 .55942 m
.34732 .52307 L
s
% Start of user PostScript
-0.29655985 0.11884076 -0.30535108 0.046144205 MAarrowhead1
% End of user PostScript
.266 1 0 r
.44104 .41439 m
.45919 .41711 L
s
% Start of user PostScript
-0.11792676 -0.1712156 -0.081629253 -0.16578246 MAarrowhead1
% End of user PostScript
0 1 .049 r
.53358 .48102 m
.53559 .49012 L
s
% Start of user PostScript
0.067168589 -0.03796213 0.071171617 -0.019760691 MAarrowhead1
% End of user PostScript
0 1 .364 r
.51624 .52015 m
.51186 .51994 L
s
% Start of user PostScript
0.032476308 0.040301947 0.023727838 0.039882385 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49254 .5057 m
.49182 .50344 L
s
% Start of user PostScript
-0.014921625 0.011398942 -0.016351067 0.0068893097 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49562 .49532 m
.49666 .49526 L
s
% Start of user PostScript
-0.0087629701 -0.0093620274 -0.006677894 -0.0094865637 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50162 .49836 m
.50185 .49891 L
s
% Start of user PostScript
0.0032365871 -0.0032842721 0.0036945009 -0.0021785068 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50116 .50107 m
.50092 .50111 L
s
% Start of user PostScript
0.002324558 0.0021426005 0.0018335359 0.0022292163 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49966 .50046 m
.49959 .50032 L
s
% Start of user PostScript
-0.00068060697 0.00091821764 -0.00081835235 0.00064991843 MAarrowhead1
% End of user PostScript
0 1 .303 r
.07864 .9885 m
.00793 .83496 L
s
.00793 .83496 m
0 .80655 L
s
0 .36444 m
.04498 .29591 L
.10188 .24511 L
.16556 .21266 L
.2324 .19691 L
.2992 .19581 L
.36331 .20705 L
.4226 .2282 L
.47546 .25683 L
.52081 .29058 L
.55806 .32729 L
.587 .36501 L
.60781 .40208 L
.62098 .43711 L
.62719 .46903 L
.62732 .49706 L
.62233 .52071 L
.61326 .53974 L
.60111 .55412 L
.58687 .56403 L
.57144 .56979 L
.55563 .57183 L
.54014 .57067 L
.52552 .56688 L
.51224 .56101 L
.50059 .55365 L
.4908 .54533 L
.48294 .53653 L
.47703 .52768 L
.47298 .51914 L
.47066 .51121 L
.46989 .50411 L
.47045 .49798 L
.4721 .49291 L
.4746 .48895 L
.47772 .48606 L
.48122 .48419 L
.48492 .48325 L
.48862 .48314 L
.49218 .48372 L
.49549 .48485 L
.49844 .48641 L
.50099 .48826 L
.50308 .49029 L
.50472 .49238 L
.5059 .49443 L
.50666 .49638 L
.50703 .49816 L
.50706 .49973 L
.5068 .50106 L
Mistroke
.50631 .50213 L
.50565 .50295 L
.50487 .50351 L
.50402 .50385 L
.50314 .50398 L
.50228 .50392 L
.50147 .50372 L
.50073 .5034 L
.50008 .503 L
.49953 .50254 L
.49908 .50206 L
.49875 .50157 L
.49852 .50109 L
.49838 .50065 L
.49833 .50025 L
.49836 .49991 L
.49845 .49963 L
.49858 .4994 L
.49875 .49924 L
.49895 .49913 L
.49915 .49908 L
.49936 .49907 L
.49955 .4991 L
.49974 .49916 L
.4999 .49924 L
.50005 .49934 L
.50016 .49945 L
.50026 .49957 L
.50032 .49968 L
.50037 .49979 L
.50039 .49989 L
.50039 .49998 L
.50038 .50005 L
.50035 .50011 L
.50032 .50016 L
.50027 .50019 L
.50023 .50021 L
.50018 .50022 L
.50013 .50022 L
.50008 .50021 L
.50004 .50019 L
.50001 .50017 L
.49998 .50014 L
.49995 .50012 L
.49993 .50009 L
.49992 .50006 L
.49991 .50004 L
.49991 .50002 L
.49991 .5 L
.49991 .49998 L
Mistroke
.49992 .49997 L
.49993 .49996 L
.49994 .49995 L
.49995 .49995 L
.49996 .49995 L
.49997 .49995 L
.49998 .49995 L
.49999 .49996 L
.5 .49996 L
.50001 .49997 L
.50001 .49998 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
.07864 .9885 m
.00793 .83496 L
s
% Start of user PostScript
-0.84272506 0.97699227 -0.98414859 0.66992576 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-1.0635118 0.3853665 -1.0876042 0.13108053 MAarrowhead1
% End of user PostScript
1 .473 0 r
.2992 .19581 m
.36331 .20705 L
s
% Start of user PostScript
-0.40159507 -0.6083795 -0.27337499 -0.58589856 MAarrowhead1
% End of user PostScript
1 .788 0 r
.62098 .43711 m
.62719 .46903 L
s
% Start of user PostScript
0.24195483 -0.12578881 0.25437854 -0.061946062 MAarrowhead1
% End of user PostScript
.897 1 0 r
.55563 .57183 m
.54014 .57067 L
s
% Start of user PostScript
0.11126494 0.14366488 0.080274374 0.14134892 MAarrowhead1
% End of user PostScript
.581 1 0 r
.47298 .51914 m
.47066 .51121 L
s
% Start of user PostScript
-0.054039967 0.038282581 -0.058670443 0.022422064 MAarrowhead1
% End of user PostScript
.266 1 0 r
.48492 .48325 m
.48862 .48314 L
s
% Start of user PostScript
-0.030169761 -0.033491822 -0.022761691 -0.033722595 MAarrowhead1
% End of user PostScript
0 1 .049 r
.5059 .49443 m
.50666 .49638 L
s
% Start of user PostScript
0.011800762 -0.011133656 0.013317162 -0.0072341681 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50402 .50385 m
.50314 .50398 L
s
% Start of user PostScript
0.0080363973 0.0076960836 0.0062862563 0.0079501427 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49875 .50157 m
.49852 .50109 L
s
% Start of user PostScript
-0.0025037259 0.0031346262 -0.0029661496 0.0021858691 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49895 .49913 m
.49915 .49908 L
s
% Start of user PostScript
-0.0021083351 -0.0017393496 -0.001700135 -0.0018499674 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50026 .49957 m
.50032 .49968 L
s
% Start of user PostScript
0.00051081747 -0.00086092778 0.00064548766 -0.00063255979 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50027 .50019 m
.50023 .50021 L
s
% Start of user PostScript
0.00054573508 0.00038539135 0.00045188286 0.00042421522 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49995 .50012 m
.49993 .50009 L
s
% Start of user PostScript
-0.000098374631 0.00023178689 -0.00013632889 0.0001774349 MAarrowhead1
% End of user PostScript
1 .75 0 r
0 .01986 m
.09502 .00371 L
.20297 .00795 L
.30547 .03119 L
.39929 .06945 L
.48208 .11878 L
.55229 .17544 L
.60914 .23598 L
.6525 .29736 L
.6828 .35699 L
.70092 .41276 L
.7081 .46307 L
.70581 .50678 L
.69565 .5432 L
.6793 .57205 L
.65841 .59338 L
.63453 .60756 L
.60911 .61515 L
.5834 .61693 L
.55849 .61374 L
.53524 .60651 L
.51431 .59619 L
.49617 .58368 L
.4811 .56983 L
.4692 .55541 L
.46044 .54109 L
.45467 .52742 L
.45164 .51486 L
.45103 .50371 L
.45248 .49421 L
.45559 .48646 L
.45998 .4805 L
.46527 .47628 L
.47109 .47368 L
.47714 .47255 L
.48313 .4727 L
.48883 .47392 L
.49407 .47599 L
.4987 .47868 L
.50264 .4818 L
.50584 .48514 L
.50829 .48854 L
.51002 .49185 L
.51107 .49496 L
.51151 .49777 L
.51142 .50021 L
.51089 .50226 L
.51 .50389 L
.50886 .5051 L
.50755 .50591 L
Mistroke
.50614 .50636 L
.50472 .50648 L
.50334 .50632 L
.50204 .50593 L
.50087 .50537 L
.49985 .50469 L
.49901 .50392 L
.49834 .50313 L
.49784 .50233 L
.49751 .50157 L
.49733 .50087 L
.49729 .50025 L
.49736 .49971 L
.49753 .49928 L
.49776 .49894 L
.49805 .4987 L
.49838 .49855 L
.49871 .49848 L
.49904 .49849 L
.49936 .49855 L
.49965 .49866 L
.49991 .49881 L
.50013 .49898 L
.50031 .49916 L
.50045 .49935 L
.50055 .49954 L
.50061 .49971 L
.50064 .49987 L
.50063 .5 L
.50061 .50012 L
.50056 .50021 L
.5005 .50028 L
.50042 .50032 L
.50035 .50035 L
.50027 .50036 L
.50019 .50035 L
.50012 .50033 L
.50005 .5003 L
.5 .50026 L
.49995 .50022 L
.49991 .50018 L
.49988 .50013 L
.49986 .50009 L
.49985 .50005 L
.49985 .50002 L
.49985 .49999 L
.49986 .49996 L
.49988 .49994 L
.49989 .49993 L
.49991 .49992 L
Mistroke
.49993 .49992 L
.49995 .49992 L
.49996 .49992 L
.49998 .49993 L
.49999 .49993 L
.50001 .49994 L
.50002 .49995 L
.50002 .49996 L
.50003 .49997 L
.50003 .49998 L
.50004 .49999 L
.50004 .5 L
.50003 .50001 L
.50003 .50001 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
6.6650478 -5.0150903 7.289607 -3.0127928 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
7.5223884 -1.2114694 7.4169802 0.34911053 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.0499524 4.0943847 1.2153288 3.8241894 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.7513561 0.50574956 -1.7675599 0.1072547 MAarrowhead1
% End of user PostScript
.897 1 0 r
.20297 .00795 m
.30547 .03119 L
s
% Start of user PostScript
-0.59405753 -0.98409302 -0.38906112 -0.93761089 MAarrowhead1
% End of user PostScript
.581 1 0 r
.70092 .41276 m
.7081 .46307 L
s
% Start of user PostScript
0.4018446 -0.17447032 0.41620466 -0.073852643 MAarrowhead1
% End of user PostScript
.266 1 0 r
.5834 .61693 m
.55849 .61374 L
s
% Start of user PostScript
0.16680934 0.23385344 0.11698387 0.22747814 MAarrowhead1
% End of user PostScript
0 1 .049 r
.45467 .52742 m
.45164 .51486 L
s
% Start of user PostScript
-0.090660071 0.05484707 -0.096720307 0.029712733 MAarrowhead1
% End of user PostScript
0 1 .364 r
.47714 .47255 m
.48313 .4727 L
s
% Start of user PostScript
-0.045718291 -0.054894576 -0.033737876 -0.054593195 MAarrowhead1
% End of user PostScript
0 1 .679 r
.51002 .49185 m
.51107 .49496 L
s
% Start of user PostScript
0.020045062 -0.016300494 0.022145206 -0.010087206 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50614 .50636 m
.50472 .50648 L
s
% Start of user PostScript
0.012287435 0.012712712 0.0094392804 0.012952525 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49784 .50233 m
.49751 .50157 L
s
% Start of user PostScript
-0.0043218203 0.0046623848 -0.0049837072 0.0031423312 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49838 .49855 m
.49871 .49848 L
s
% Start of user PostScript
-0.0032485478 -0.0028991941 -0.0025796654 -0.0030351825 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50045 .49935 m
.50055 .49954 L
s
% Start of user PostScript
0.00090150689 -0.0012963081 0.0010985437 -0.00092834283 MAarrowhead1
% End of user PostScript
0 .178 1 r
.48513 1 m
.48014 .99659 L
.39055 .91492 L
.31972 .82976 L
.26747 .74509 L
.23291 .66421 L
.21458 .58975 L
.2106 .52366 L
.21884 .46723 L
.23699 .42117 L
.26275 .38565 L
.29386 .36041 L
.32822 .34481 L
.36394 .33791 L
.39936 .33861 L
.43312 .34565 L
.46413 .35773 L
.4916 .37356 L
.51499 .3919 L
.53403 .41162 L
.54866 .43171 L
.55898 .45131 L
.5653 .46971 L
.56798 .48636 L
.56752 .50089 L
.56443 .51305 L
.55926 .52273 L
.55255 .52995 L
.54482 .53482 L
.53653 .53751 L
.52812 .53827 L
.51993 .53737 L
.51226 .53513 L
.50533 .53184 L
.4993 .52781 L
.49426 .52331 L
.49027 .5186 L
.4873 .5139 L
.48532 .5094 L
.48424 .50525 L
.48397 .50156 L
.48438 .49839 L
.48535 .4958 L
.48675 .49379 L
.48846 .49235 L
.49035 .49145 L
.49232 .49104 L
.49429 .49105 L
.49617 .49142 L
.4979 .49207 L
Mistroke
.49943 .49293 L
.50074 .49394 L
.50182 .49503 L
.50264 .49614 L
.50323 .49723 L
.5036 .49825 L
.50376 .49918 L
.50375 .5 L
.50358 .50068 L
.5033 .50122 L
.50294 .50163 L
.50251 .50191 L
.50206 .50207 L
.50159 .50212 L
.50114 .50208 L
.50071 .50196 L
.50032 .50178 L
.49998 .50156 L
.4997 .50131 L
.49948 .50105 L
.49931 .50079 L
.49919 .50054 L
.49913 .50031 L
.49911 .5001 L
.49913 .49992 L
.49918 .49978 L
.49926 .49966 L
.49935 .49958 L
.49946 .49953 L
.49957 .4995 L
.49968 .4995 L
.49978 .49952 L
.49988 .49956 L
.49996 .4996 L
.50004 .49966 L
.5001 .49972 L
.50014 .49978 L
.50018 .49984 L
.5002 .4999 L
.50021 .49995 L
.50021 .5 L
.5002 .50004 L
.50018 .50007 L
.50016 .50009 L
.50014 .5001 L
.50012 .50011 L
.50009 .50012 L
.50006 .50012 L
.50004 .50011 L
.50002 .5001 L
Mistroke
.5 .50009 L
.49998 .50007 L
.49997 .50006 L
.49996 .50004 L
.49996 .50003 L
.49995 .50002 L
.49995 .50001 L
.49995 .5 L
.49995 .49999 L
.49996 .49998 L
.49996 .49998 L
.49997 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-0.23728961 -4.5223419 0.59671096 -3.8547131 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
1.2729563 -3.1401185 1.7897301 -2.4146747 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.8792864 1.0975358 1.5979169 1.2673181 MAarrowhead1
% End of user PostScript
1 .788 0 r
.39055 .91492 m
.31972 .82976 L
s
% Start of user PostScript
-0.21889374 0.82983318 -0.36055413 0.65952482 MAarrowhead1
% End of user PostScript
.897 1 0 r
.26275 .38565 m
.29386 .36041 L
s
% Start of user PostScript
-0.4744932 -0.2286941 -0.41227044 -0.27917237 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51499 .3919 m
.53403 .41162 L
s
% Start of user PostScript
0.02998899 -0.21619671 0.068067884 -0.17675128 MAarrowhead1
% End of user PostScript
.266 1 0 r
.55926 .52273 m
.55255 .52995 L
s
% Start of user PostScript
0.11852477 0.045464745 0.10510603 0.059906825 MAarrowhead1
% End of user PostScript
0 1 .049 r
.4993 .52781 m
.49426 .52331 L
s
% Start of user PostScript
-0.0014027895 0.055612071 -0.011471357 0.046615114 MAarrowhead1
% End of user PostScript
0 1 .364 r
.48535 .4958 m
.48675 .49379 L
s
% Start of user PostScript
-0.029298772 -0.0083998194 -0.0264988 -0.012416063 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49943 .49293 m
.50074 .49394 L
s
% Start of user PostScript
-0.0011353708 -0.014138448 0.0014890691 -0.01212288 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50358 .50068 m
.5033 .50122 L
s
% Start of user PostScript
0.0071675858 0.0013565549 0.0066098083 0.0024488519 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50032 .50178 m
.49998 .50156 L
s
% Start of user PostScript
0.00064235953 0.0035550834 -0.000033019617 0.003113275 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49913 .49992 m
.49918 .49978 L
s
% Start of user PostScript
-0.0017350283 -0.00015478354 -0.0016316281 -0.00044647773 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49988 .49956 m
.49996 .4996 L
s
% Start of user PostScript
-0.00024612389 -0.00088449835 -0.000074349712 -0.0007902973 MAarrowhead1
% End of user PostScript
1 .209 0 r
.2052 1 m
.15019 .9172 L
.08936 .7879 L
.05472 .66785 L
.04345 .56036 L
.05224 .46772 L
.07753 .39124 L
.11565 .33138 L
.16303 .28788 L
.21627 .25984 L
.27231 .24591 L
.32846 .24438 L
.38246 .25332 L
.43248 .27068 L
.47718 .29443 L
.51561 .32258 L
.54725 .35332 L
.57192 .38498 L
.58975 .41616 L
.60113 .44568 L
.60664 .47264 L
.607 .49637 L
.60303 .51643 L
.59557 .53261 L
.58549 .54489 L
.5736 .55341 L
.56069 .55842 L
.54741 .56029 L
.53438 .55945 L
.52206 .55637 L
.51084 .55152 L
.50098 .5454 L
.49267 .53844 L
.48599 .53106 L
.48094 .52363 L
.47746 .51644 L
.47544 .50975 L
.47473 .50375 L
.47514 .49855 L
.47648 .49425 L
.47855 .49087 L
.48114 .4884 L
.48407 .48679 L
.48717 .48596 L
.49028 .48583 L
.49328 .48629 L
.49607 .48722 L
.49857 .48851 L
.50072 .49006 L
.5025 .49175 L
Mistroke
.5039 .49351 L
.50491 .49524 L
.50556 .49688 L
.50589 .49838 L
.50593 .49971 L
.50573 .50084 L
.50533 .50175 L
.50478 .50244 L
.50412 .50293 L
.50341 .50322 L
.50268 .50334 L
.50195 .5033 L
.50127 .50314 L
.50064 .50287 L
.50009 .50254 L
.49962 .50216 L
.49925 .50175 L
.49896 .50134 L
.49876 .50094 L
.49865 .50057 L
.4986 .50023 L
.49862 .49994 L
.49869 .4997 L
.4988 .49951 L
.49894 .49937 L
.49911 .49927 L
.49928 .49922 L
.49945 .49922 L
.49962 .49924 L
.49977 .49929 L
.49991 .49936 L
.50003 .49944 L
.50013 .49954 L
.50021 .49963 L
.50027 .49973 L
.50031 .49982 L
.50033 .4999 L
.50033 .49998 L
.50032 .50004 L
.5003 .50009 L
.50027 .50013 L
.50023 .50016 L
.50019 .50018 L
.50015 .50018 L
.50011 .50018 L
.50007 .50017 L
.50004 .50016 L
.50001 .50014 L
.49998 .50012 L
.49996 .5001 L
Mistroke
.49994 .50008 L
.49993 .50005 L
.49993 .50003 L
.49992 .50001 L
.49992 .5 L
.49993 .49998 L
.49993 .49997 L
.49994 .49997 L
.49995 .49996 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49999 .49996 L
.49999 .49996 L
.5 .49997 L
.50001 .49997 L
.50001 .49998 L
.50001 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
3.6745532 -1.8883153 3.8592184 -0.92220249 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
3.8599078 -0.074313722 3.70613 0.64042424 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
0.76612807 2.0254607 0.36399471 1.8466315 MAarrowhead1
% End of user PostScript
1 .788 0 r
.04345 .56036 m
.05224 .46772 L
s
% Start of user PostScript
-0.91310746 0.12072927 -0.89551748 -0.06456423 MAarrowhead1
% End of user PostScript
.897 1 0 r
.38246 .25332 m
.43248 .27068 L
s
% Start of user PostScript
-0.23508996 -0.4933686 -0.13503578 -0.45863797 MAarrowhead1
% End of user PostScript
.581 1 0 r
.60664 .47264 m
.607 .49637 L
s
% Start of user PostScript
0.21328379 -0.054715322 0.21400472 -0.007266587 MAarrowhead1
% End of user PostScript
.266 1 0 r
.53438 .55945 m
.52206 .55637 L
s
% Start of user PostScript
0.068755725 0.11889689 0.044119116 0.11273135 MAarrowhead1
% End of user PostScript
0 1 .049 r
.47544 .50975 m
.47473 .50375 L
s
% Start of user PostScript
-0.049118967 0.01950385 -0.050542329 0.0074914171 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49028 .48583 m
.49328 .48629 L
s
% Start of user PostScript
-0.019438322 -0.028333531 -0.013434972 -0.027420455 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50556 .49688 m
.50589 .49838 L
s
% Start of user PostScript
0.011129821 -0.0062420837 0.011784336 -0.0032336907 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50268 .50334 m
.50195 .5033 L
s
% Start of user PostScript
0.0053561353 0.006671374 0.0039088185 0.0065983112 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49876 .50094 m
.49865 .50057 L
s
% Start of user PostScript
-0.0024737832 0.0018765718 -0.0027083586 0.0011310173 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49928 .49922 m
.49945 .49922 L
s
% Start of user PostScript
-0.0014458768 -0.0015502644 -0.0011008326 -0.0015699413 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50027 .49973 m
.50031 .49982 L
s
% Start of user PostScript
0.00053692644 -0.00054113556 0.00061221684 -0.00035827891 MAarrowhead1
% End of user PostScript
1 .779 0 r
.59466 1 m
.53284 .96464 L
.44679 .89759 L
.37668 .8254 L
.32275 .75179 L
.28457 .67993 L
.26114 .61241 L
.25102 .55123 L
.25248 .49783 L
.26361 .45308 L
.2824 .4174 L
.30687 .39075 L
.33514 .37275 L
.36547 .36272 L
.39631 .3598 L
.42634 .36295 L
.45449 .37107 L
.47995 .38305 L
.50212 .39778 L
.52065 .41423 L
.53537 .43148 L
.54632 .44869 L
.55366 .46519 L
.55767 .48044 L
.55874 .49402 L
.55728 .50566 L
.55377 .5152 L
.54867 .5226 L
.54244 .52792 L
.53552 .53126 L
.52828 .53281 L
.52108 .53281 L
.51419 .53149 L
.50784 .52913 L
.5022 .52598 L
.49737 .52229 L
.49342 .51831 L
.49037 .51423 L
.4882 .51024 L
.48684 .50648 L
.48623 .50307 L
.48627 .50008 L
.48685 .49756 L
.48787 .49555 L
.4892 .49404 L
.49075 .49301 L
.49243 .49243 L
.49414 .49224 L
.4958 .49239 L
.49737 .49282 L
Mistroke
.49879 .49347 L
.50004 .49428 L
.50108 .49518 L
.50191 .49614 L
.50253 .49709 L
.50295 .49801 L
.50318 .49886 L
.50325 .49962 L
.50318 .50027 L
.50299 .50081 L
.50272 .50123 L
.50238 .50153 L
.50199 .50172 L
.50159 .50181 L
.5012 .50182 L
.50081 .50175 L
.50046 .50162 L
.50014 .50145 L
.49987 .50125 L
.49965 .50103 L
.49948 .5008 L
.49935 .50058 L
.49928 .50037 L
.49924 .50018 L
.49924 .50002 L
.49927 .49987 L
.49932 .49976 L
.4994 .49968 L
.49948 .49962 L
.49957 .49958 L
.49967 .49957 L
.49976 .49958 L
.49985 .4996 L
.49993 .49964 L
.5 .49968 L
.50006 .49973 L
.5001 .49978 L
.50014 .49984 L
.50016 .49989 L
.50018 .49993 L
.50018 .49998 L
.50018 .50001 L
.50017 .50004 L
.50015 .50007 L
.50013 .50008 L
.50011 .50009 L
.50009 .5001 L
.50007 .5001 L
.50005 .5001 L
.50003 .50009 L
Mistroke
.50001 .50008 L
.49999 .50007 L
.49998 .50006 L
.49997 .50005 L
.49996 .50003 L
.49996 .50002 L
.49996 .50001 L
.49996 .5 L
.49996 .49999 L
.49996 .49999 L
.49997 .49998 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-3.666035 -5.0634722 -2.5848469 -4.9353086 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-1.5738687 -4.6303593 -0.66225745 -4.1892007 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.1208918 -0.1832948 2.0623445 0.23182313 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
0.49533982 1.1325655 0.26757919 1.0447648 MAarrowhead1
% End of user PostScript
.897 1 0 r
.25102 .55123 m
.25248 .49783 L
s
% Start of user PostScript
-0.49796198 0.10246046 -0.49503956 -0.0043454103 MAarrowhead1
% End of user PostScript
.581 1 0 r
.42634 .36295 m
.45449 .37107 L
s
% Start of user PostScript
-0.14732538 -0.27410699 -0.091012547 -0.25785551 MAarrowhead1
% End of user PostScript
.266 1 0 r
.55767 .48044 m
.55874 .49402 L
s
% Start of user PostScript
0.1153474 -0.039124807 0.11747382 -0.011965157 MAarrowhead1
% End of user PostScript
0 1 .049 r
.52108 .53281 m
.51419 .53149 L
s
% Start of user PostScript
0.042161753 0.06561587 0.028382688 0.062981449 MAarrowhead1
% End of user PostScript
0 1 .364 r
.48684 .50648 m
.48623 .50307 L
s
% Start of user PostScript
-0.026312695 0.012965482 -0.027533708 0.0061348027 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49414 .49224 m
.4958 .49239 L
s
% Start of user PostScript
-0.011727284 -0.015525162 -0.0083911405 -0.015220869 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50295 .49801 m
.50318 .49886 L
s
% Start of user PostScript
0.0058957197 -0.0039821733 0.0063654875 -0.0022823641 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50159 .50181 m
.5012 .50182 L
s
% Start of user PostScript
0.0031899898 0.0036271262 0.0023910576 0.0036380278 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49935 .50058 m
.49928 .50037 L
s
% Start of user PostScript
-0.0012925863 0.001165373 -0.0014488222 0.00074675636 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49957 .49958 m
.49967 .49957 L
s
% Start of user PostScript
-0.0008519927 -0.00083551909 -0.00066287746 -0.00085937193 MAarrowhead1
% End of user PostScript
0 1 .545 r
.63417 0 m
.70365 .07903 L
.7715 .18229 L
.8176 .28168 L
.8436 .37385 L
.85168 .45626 L
.84441 .52719 L
.82452 .58565 L
.79486 .6313 L
.75816 .66437 L
.71703 .68555 L
.67383 .69592 L
.63061 .69678 L
.5891 .68964 L
.5507 .67606 L
.51643 .65762 L
.48701 .63584 L
.46283 .61212 L
.44402 .58773 L
.43047 .56374 L
.42187 .54106 L
.41778 .52037 L
.41763 .5022 L
.4208 .48685 L
.42663 .47449 L
.43446 .46514 L
.44365 .45868 L
.45362 .45491 L
.46384 .45355 L
.47387 .45427 L
.48333 .45669 L
.49194 .46047 L
.49949 .46521 L
.50585 .47059 L
.51096 .47628 L
.5148 .482 L
.51744 .48753 L
.51895 .49266 L
.51947 .49727 L
.51912 .50124 L
.51807 .50453 L
.51646 .50711 L
.51445 .50899 L
.51219 .51021 L
.5098 .51082 L
.5074 .51091 L
.50509 .51054 L
.50295 .50981 L
.50104 .50881 L
.49939 .50761 L
Mistroke
.49803 .5063 L
.49697 .50495 L
.4962 .50362 L
.4957 .50236 L
.49546 .50121 L
.49543 .50019 L
.4956 .49933 L
.49591 .49863 L
.49634 .4981 L
.49684 .49773 L
.49739 .49751 L
.49796 .49743 L
.49851 .49746 L
.49904 .49759 L
.49952 .49779 L
.49994 .49805 L
.5003 .49835 L
.50059 .49866 L
.50081 .49898 L
.50096 .49929 L
.50105 .49957 L
.50108 .49983 L
.50106 .50005 L
.50101 .50024 L
.50092 .50038 L
.50081 .50049 L
.50068 .50056 L
.50055 .5006 L
.50042 .5006 L
.50029 .50059 L
.50017 .50055 L
.50006 .50049 L
.49997 .50043 L
.4999 .50035 L
.49984 .50028 L
.49979 .50021 L
.49976 .50014 L
.49975 .50007 L
.49975 .50001 L
.49976 .49997 L
.49977 .49993 L
.4998 .4999 L
.49982 .49988 L
.49985 .49986 L
.49988 .49986 L
.49992 .49986 L
.49994 .49987 L
.49997 .49988 L
.5 .49989 L
.50002 .49991 L
Mistroke
.50003 .49992 L
.50004 .49994 L
.50005 .49996 L
.50006 .49998 L
.50006 .49999 L
.50006 .5 L
.50006 .50001 L
.50005 .50002 L
.50005 .50003 L
.50004 .50003 L
.50003 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.5 .50003 L
.5 .50002 L
.49999 .50002 L
.49999 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
9.2228065 6.0068946 7.7289136 6.7425676 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
6.1657776 7.0905001 4.6070246 7.0990275 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.5400419 2.2414906 -2.8382127 1.4265074 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.6488821 -1.63517 -1.2795733 -1.6784769 MAarrowhead1
% End of user PostScript
.897 1 0 r
.7715 .18229 m
.8176 .28168 L
s
% Start of user PostScript
0.54300203 -0.6354161 0.63520165 -0.43663323 MAarrowhead1
% End of user PostScript
.581 1 0 r
.71703 .68555 m
.67383 .69592 L
s
% Start of user PostScript
0.43406255 0.37110243 0.34765358 0.3918319 MAarrowhead1
% End of user PostScript
.266 1 0 r
.44402 .58773 m
.43047 .56374 L
s
% Start of user PostScript
-0.11195721 0.17545397 -0.13906204 0.12748276 MAarrowhead1
% End of user PostScript
0 1 .049 r
.44365 .45868 m
.45362 .45491 L
s
% Start of user PostScript
-0.11269887 -0.082642088 -0.092761049 -0.090179254 MAarrowhead1
% End of user PostScript
0 1 .364 r
.51096 .47628 m
.5148 .482 L
s
% Start of user PostScript
0.021910452 -0.047444655 0.029602442 -0.035996166 MAarrowhead1
% End of user PostScript
0 1 .679 r
.51445 .50899 m
.51219 .51021 L
s
% Start of user PostScript
0.028898952 0.01798057 0.024371241 0.020418027 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49803 .5063 m
.49697 .50495 L
s
% Start of user PostScript
-0.0039419706 0.012608774 -0.0060677053 0.0099088449 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49634 .4981 m
.49684 .49773 L
s
% Start of user PostScript
-0.007325693 -0.0037964764 -0.0063166465 -0.0045340497 MAarrowhead1
% End of user PostScript
0 .375 1 r
.5003 .49835 m
.50059 .49866 L
s
% Start of user PostScript
0.00060170382 -0.0033012285 0.0011769192 -0.0026727247 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50092 .50038 m
.50081 .50049 L
s
% Start of user PostScript
0.0018369147 0.00076929524 0.0016171688 0.00098295463 MAarrowhead1
% End of user PostScript
.474 0 1 r
1 .80041 m
.96724 .82567 L
.88767 .85958 L
.80537 .87367 L
.72407 .87056 L
.64686 .85312 L
.57618 .82437 L
.51379 .78726 L
.46087 .74462 L
.41801 .69904 L
.38531 .65282 L
.36245 .60791 L
.34876 .56589 L
.34331 .52799 L
.34501 .49505 L
.35263 .4676 L
.36492 .44585 L
.38064 .42975 L
.3986 .41905 L
.41774 .41331 L
.4371 .41195 L
.45586 .41434 L
.47338 .41976 L
.48915 .42753 L
.50282 .43694 L
.51418 .44737 L
.52315 .45822 L
.52976 .46901 L
.53412 .4793 L
.53641 .48877 L
.53688 .49716 L
.53579 .50433 L
.53345 .51017 L
.53015 .51466 L
.52617 .51785 L
.52179 .51981 L
.51724 .52067 L
.51272 .52056 L
.50843 .51964 L
.50449 .51809 L
.501 .51606 L
.49803 .51372 L
.49561 .5112 L
.49376 .50864 L
.49246 .50615 L
.49167 .50381 L
.49133 .50169 L
.4914 .49985 L
.4918 .49831 L
.49246 .49708 L
Mistroke
.49332 .49617 L
.49431 .49555 L
.49537 .49521 L
.49644 .49512 L
.49748 .49524 L
.49846 .49553 L
.49934 .49595 L
.50011 .49647 L
.50074 .49704 L
.50125 .49764 L
.50163 .49824 L
.50188 .49881 L
.50201 .49934 L
.50204 .49981 L
.50199 .50021 L
.50186 .50054 L
.50168 .5008 L
.50147 .50098 L
.50122 .50109 L
.50097 .50114 L
.50072 .50114 L
.50048 .50109 L
.50026 .50101 L
.50007 .5009 L
.4999 .50077 L
.49977 .50063 L
.49966 .50049 L
.49959 .50035 L
.49954 .50022 L
.49952 .5001 L
.49952 .5 L
.49954 .49991 L
.49958 .49984 L
.49963 .49979 L
.49968 .49976 L
.49974 .49974 L
.4998 .49973 L
.49986 .49974 L
.49991 .49975 L
.49996 .49977 L
.5 .4998 L
.50004 .49983 L
.50007 .49987 L
.50009 .4999 L
.5001 .49993 L
.50011 .49996 L
.50011 .49999 L
.50011 .50001 L
.5001 .50003 L
.50009 .50004 L
Mistroke
.50008 .50005 L
.50007 .50006 L
.50005 .50006 L
.50004 .50006 L
.50003 .50006 L
.50002 .50006 L
.5 .50005 L
.5 .50004 L
.49999 .50004 L
.49998 .50003 L
.49998 .50002 L
.49997 .50001 L
.49997 .50001 L
.49997 .5 L
.49997 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-5.296836 -1.2342924 -4.8424183 -2.0050626 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-4.2673074 -2.5719092 -3.6138781 -2.9449027 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
0.53866834 -1.873315 0.85653098 -1.4807409 MAarrowhead1
% End of user PostScript
1 .788 0 r
1 .80041 m
.96724 .82567 L
s
% Start of user PostScript
1.0795392 0.53951349 0.93447606 0.65134041 MAarrowhead1
% End of user PostScript
.897 1 0 r
.46087 .74462 m
.41801 .69904 L
s
% Start of user PostScript
-0.078254373 0.48923066 -0.16397247 0.39807685 MAarrowhead1
% End of user PostScript
.581 1 0 r
.36492 .44585 m
.38064 .42975 L
s
% Start of user PostScript
-0.27016748 -0.10830775 -0.23872912 -0.1404925 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50282 .43694 m
.51418 .44737 L
s
% Start of user PostScript
0.0056380976 -0.12611864 0.028365389 -0.1052676 MAarrowhead1
% End of user PostScript
0 1 .049 r
.53345 .51017 m
.53015 .51466 L
s
% Start of user PostScript
0.066907534 0.020332024 0.06030398 0.029322879 MAarrowhead1
% End of user PostScript
0 1 .364 r
.501 .51606 m
.49803 .51372 L
s
% Start of user PostScript
0.0019923896 0.032128426 -0.0039459555 0.027441183 MAarrowhead1
% End of user PostScript
0 1 .679 r
.4918 .49831 m
.49246 .49708 L
s
% Start of user PostScript
-0.016398463 -0.0033894587 -0.015070279 -0.0058435551 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49934 .49595 m
.50011 .49647 L
s
% Start of user PostScript
-0.0013203947 -0.0080941374 0.00021113382 -0.0070623522 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50199 .50021 m
.50186 .50054 L
s
% Start of user PostScript
0.0039770543 0.00042660486 0.0037269596 0.0010839428 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50026 .50101 m
.50007 .5009 L
s
% Start of user PostScript
0.0005266782 0.0020175581 0.00013636357 0.0017963569 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49952 .5 m
.49954 .49991 L
s
% Start of user PostScript
-0.0009541016 -0.0000031952694 -0.00091216262 -0.00017647636 MAarrowhead1
% End of user PostScript
.164 0 1 r
.14233 1 m
.1174 .96279 L
.04969 .82036 L
.01086 .68798 L
s
.01086 .68798 m
0 .58915 L
s
0 .54495 m
.00696 .46697 L
.03435 .38236 L
.07596 .31604 L
.12785 .26772 L
.18629 .23644 L
.24789 .22073 L
.30969 .21871 L
.36917 .22826 L
.42434 .24714 L
.47368 .27311 L
.51614 .30398 L
.55115 .33773 L
.57849 .37255 L
.5983 .40688 L
.611 .43942 L
.61722 .46916 L
.61776 .49536 L
.6135 .51754 L
.60538 .53545 L
.59436 .54908 L
.58133 .55855 L
.56714 .56416 L
.55254 .5663 L
.53819 .56545 L
.52461 .56212 L
.51223 .55684 L
.50135 .55013 L
.49216 .5425 L
.48476 .53439 L
.47915 .52621 L
.47528 .51829 L
.47302 .51091 L
.47221 .50428 L
.47263 .49855 L
.47408 .49379 L
.47634 .49005 L
.47917 .4873 L
.48239 .4855 L
.48579 .48457 L
.48922 .48441 L
.49253 .4849 L
.4956 .48591 L
.49836 .48732 L
.50074 .48902 L
.50271 .49088 L
.50425 .4928 L
.50538 .49471 L
.50611 .49652 L
.50648 .49818 L
Mistroke
.50653 .49965 L
.50631 .50089 L
.50587 .5019 L
.50527 .50267 L
.50456 .50321 L
.50378 .50354 L
.50297 .50367 L
.50217 .50363 L
.50141 .50346 L
.50072 .50317 L
.50012 .5028 L
.4996 .50238 L
.49918 .50194 L
.49887 .50148 L
.49864 .50104 L
.49851 .50063 L
.49846 .50026 L
.49848 .49994 L
.49856 .49967 L
.49868 .49946 L
.49883 .49931 L
.49901 .4992 L
.4992 .49915 L
.49939 .49914 L
.49957 .49916 L
.49974 .49922 L
.4999 .49929 L
.50003 .49938 L
.50014 .49949 L
.50023 .49959 L
.50029 .4997 L
.50034 .4998 L
.50036 .49989 L
.50036 .49997 L
.50035 .50004 L
.50033 .5001 L
.50029 .50015 L
.50026 .50018 L
.50021 .50019 L
.50017 .5002 L
.50012 .5002 L
.50008 .50019 L
.50004 .50018 L
.50001 .50016 L
.49998 .50013 L
.49996 .50011 L
.49994 .50008 L
.49993 .50006 L
.49992 .50004 L
.49991 .50002 L
Mistroke
.49992 .5 L
.49992 .49998 L
.49993 .49997 L
.49993 .49996 L
.49994 .49996 L
.49995 .49995 L
.49997 .49995 L
.49998 .49995 L
.49999 .49996 L
.49999 .49996 L
.5 .49997 L
.50001 .49997 L
.50001 .49998 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-4.5760795 -9.7775267 -2.5968101 -9.0741376 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-0.83145285 -8.1208006 0.68373827 -6.9957668 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
4.0831071 0.68555209 3.7812498 1.3215039 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
0.41146847 2.0372251 0.022565567 1.7919478 MAarrowhead1
% End of user PostScript
.897 1 0 r
.00696 .46697 m
.03435 .38236 L
s
% Start of user PostScript
-0.9860787 -0.066056543 -0.93130385 -0.23528113 MAarrowhead1
% End of user PostScript
.581 1 0 r
.42434 .24714 m
.47368 .27311 L
s
% Start of user PostScript
-0.15132128 -0.50571322 -0.052649687 -0.45378428 MAarrowhead1
% End of user PostScript
.266 1 0 r
.61776 .49536 m
.6135 .51754 L
s
% Start of user PostScript
0.23551347 -0.0092786291 0.22699483 0.035077077 MAarrowhead1
% End of user PostScript
0 1 .049 r
.52461 .56212 m
.51223 .55684 L
s
% Start of user PostScript
0.049222516 0.12423823 0.024459713 0.11367526 MAarrowhead1
% End of user PostScript
0 1 .364 r
.47221 .50428 m
.47263 .49855 L
s
% Start of user PostScript
-0.055588304 0.0085693486 -0.054739595 -0.0029026791 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49253 .4849 m
.4956 .48591 L
s
% Start of user PostScript
-0.01494857 -0.03020352 -0.0087992286 -0.028178729 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50648 .49818 m
.50653 .49965 L
s
% Start of user PostScript
0.012952134 -0.0036402123 0.013053744 -0.00070887515 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50217 .50363 m
.50141 .50346 L
s
% Start of user PostScript
0.0043411091 0.0072640537 0.0028298374 0.0069129494 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49851 .50063 m
.49846 .50026 L
s
% Start of user PostScript
-0.002974478 0.0012649231 -0.0030759421 0.00052431304 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49939 .49914 m
.49957 .49916 L
s
% Start of user PostScript
-0.0012208887 -0.0017273413 -0.00085334355 -0.001678204 MAarrowhead1
% End of user PostScript
1 .889 0 r
.03187 1 m
0 .92982 L
s
0 .29313 m
.01058 .27733 L
.07235 .22318 L
.14131 .1888 L
.21354 .17238 L
.28563 .1717 L
.35472 .18426 L
.41853 .20743 L
.47535 .23858 L
.52403 .27518 L
.56394 .31489 L
.59488 .35564 L
.61707 .39561 L
.63101 .43334 L
.63747 .46768 L
.6374 .4978 L
.63184 .52317 L
.62191 .54354 L
.60869 .5589 L
.59325 .56944 L
.57656 .57551 L
.55949 .57759 L
.54278 .57623 L
.52704 .57204 L
.51275 .56564 L
.50024 .55764 L
.48973 .54862 L
.48132 .53911 L
.475 .52956 L
.4707 .52036 L
.46826 .51182 L
.46749 .50418 L
.46813 .4976 L
.46995 .49218 L
.47268 .48793 L
.47606 .48485 L
.47986 .48287 L
.48385 .4819 L
.48785 .4818 L
.49169 .48245 L
.49525 .48369 L
.49842 .48539 L
.50115 .4874 L
.5034 .48959 L
.50515 .49184 L
.50641 .49406 L
.50721 .49616 L
.5076 .49808 L
.50762 .49977 L
.50733 .50119 L
Mistroke
.5068 .50234 L
.50608 .50321 L
.50523 .50381 L
.50431 .50416 L
.50336 .50429 L
.50243 .50423 L
.50156 .50401 L
.50076 .50366 L
.50006 .50323 L
.49947 .50273 L
.499 .5022 L
.49864 .50167 L
.49839 .50116 L
.49825 .50069 L
.4982 .50026 L
.49823 .49989 L
.49833 .49959 L
.49848 .49935 L
.49866 .49917 L
.49887 .49906 L
.49909 .499 L
.49931 .49899 L
.49952 .49902 L
.49972 .49909 L
.4999 .49918 L
.50005 .49929 L
.50018 .49941 L
.50028 .49954 L
.50035 .49966 L
.5004 .49978 L
.50042 .49989 L
.50042 .49998 L
.50041 .50006 L
.50038 .50013 L
.50034 .50017 L
.50029 .50021 L
.50024 .50023 L
.50019 .50024 L
.50014 .50023 L
.50009 .50022 L
.50005 .5002 L
.50001 .50018 L
.49997 .50015 L
.49995 .50012 L
.49993 .50009 L
.49991 .50007 L
.4999 .50004 L
.4999 .50002 L
.4999 .5 L
.49991 .49998 L
Mistroke
.49991 .49996 L
.49993 .49995 L
.49994 .49995 L
.49995 .49994 L
.49996 .49994 L
.49997 .49995 L
.49998 .49995 L
.49999 .49995 L
.5 .49996 L
.50001 .49997 L
.50002 .49997 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
4.9550066 -0.0073074024 4.7415553 0.89636314 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
4.3727587 1.6191104 3.8883045 2.161078 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-0.021352323 2.0597359 -0.39559414 1.7320847 MAarrowhead1
% End of user PostScript
1 .788 0 r
0 .29313 m
.01058 .27733 L
s
% Start of user PostScript
-1.0793886 -0.29513109 -0.97884463 -0.44534411 MAarrowhead1
% End of user PostScript
.897 1 0 r
.47535 .23858 m
.52403 .27518 L
s
% Start of user PostScript
-0.049306571 -0.52284592 0.048063649 -0.44964264 MAarrowhead1
% End of user PostScript
.581 1 0 r
.63184 .52317 m
.62191 .54354 L
s
% Start of user PostScript
0.26368109 0.04634426 0.24381013 0.087087362 MAarrowhead1
% End of user PostScript
.266 1 0 r
.51275 .56564 m
.50024 .55764 L
s
% Start of user PostScript
0.025490103 0.1312753 0.00047426168 0.11528349 MAarrowhead1
% End of user PostScript
0 1 .049 r
.46813 .4976 m
.46995 .49218 L
s
% Start of user PostScript
-0.063734221 -0.0047913052 -0.060098859 -0.015646948 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49525 .48369 m
.49842 .48539 L
s
% Start of user PostScript
-0.0095080723 -0.03261433 -0.0031554442 -0.029219642 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50762 .49977 m
.50733 .50119 L
s
% Start of user PostScript
0.015235954 -0.00046740194 0.014660663 0.0023811962 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50156 .50401 m
.50076 .50366 L
s
% Start of user PostScript
0.0031149648 0.0080189639 0.0015193403 0.0073258641 MAarrowhead1
% End of user PostScript
0 .69 1 r
.4982 .50026 m
.49823 .49989 L
s
% Start of user PostScript
-0.0035996528 0.00052068462 -0.0035384597 -0.00021681293 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49952 .49902 m
.49972 .49909 L
s
% Start of user PostScript
-0.00095013299 -0.0019511272 -0.00055356301 -0.0018174975 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50042 .49989 m
.50042 .49998 L
s
% Start of user PostScript
0.0008396264 -0.00022704481 0.00084458624 -0.000038424071 MAarrowhead1
% End of user PostScript
0 1 .465 r
0 .08367 m
.05332 .06376 L
.15214 .05097 L
.24901 .05819 L
.34036 .08192 L
.42343 .11856 L
.49623 .16457 L
.55749 .21661 L
.60661 .27162 L
.64359 .32694 L
.66889 .3803 L
.68337 .42987 L
.68819 .4743 L
.68472 .51261 L
.67441 .54428 L
.65879 .56909 L
.63932 .58715 L
.61741 .59883 L
.59432 .60468 L
.57116 .6054 L
.54888 .6018 L
.52822 .5947 L
.50975 .58495 L
.49385 .57338 L
.48075 .56072 L
.47053 .54767 L
.46312 .53481 L
.45838 .52262 L
.45606 .51149 L
.45588 .50168 L
.45748 .49338 L
.46053 .48667 L
.46467 .48158 L
.46956 .47804 L
.47488 .47595 L
.48035 .47515 L
.48572 .47548 L
.49081 .47673 L
.49545 .47872 L
.49952 .48123 L
.50296 .48409 L
.50573 .48713 L
.50782 .4902 L
.50927 .49317 L
.51011 .49593 L
.51042 .49841 L
.51025 .50056 L
.50971 .50234 L
.50886 .50374 L
.5078 .50476 L
Mistroke
.50659 .50544 L
.50532 .50578 L
.50403 .50584 L
.50279 .50566 L
.50164 .50528 L
.50061 .50475 L
.49972 .50411 L
.49898 .50341 L
.4984 .50269 L
.49798 .50198 L
.49771 .5013 L
.49757 .50068 L
.49755 .50013 L
.49764 .49966 L
.4978 .49929 L
.49803 .499 L
.49829 .4988 L
.49859 .49867 L
.49889 .49863 L
.49919 .49864 L
.49947 .49871 L
.49973 .49881 L
.49996 .49895 L
.50015 .49911 L
.50031 .49928 L
.50043 .49945 L
.50051 .49961 L
.50056 .49976 L
.50058 .4999 L
.50057 .50002 L
.50054 .50012 L
.50049 .5002 L
.50044 .50026 L
.50037 .5003 L
.5003 .50032 L
.50023 .50032 L
.50016 .50031 L
.5001 .50029 L
.50004 .50027 L
.49999 .50023 L
.49995 .50019 L
.49991 .50015 L
.49989 .50011 L
.49987 .50007 L
.49987 .50004 L
.49986 .50001 L
.49987 .49998 L
.49988 .49996 L
.49989 .49995 L
.4999 .49993 L
Mistroke
.49992 .49993 L
.49994 .49992 L
.49995 .49992 L
.49997 .49993 L
.49998 .49993 L
.5 .49994 L
.50001 .49995 L
.50002 .49996 L
.50002 .49997 L
.50003 .49998 L
.50003 .49999 L
.50003 .49999 L
.50003 .5 L
.50003 .50001 L
.50003 .50001 L
.50002 .50001 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
3.9624417 -8.104845 5.2669279 -6.1091428 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
6.1513652 -4.1895337 6.647821 -2.4105662 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.3464221 3.7891854 2.5111911 3.8031067 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.3477188 1.2247008 -1.5123711 0.78671669 MAarrowhead1
% End of user PostScript
.897 1 0 r
.05332 .06376 m
.15214 .05097 L
s
% Start of user PostScript
-0.89335582 -0.87248288 -0.69571493 -0.89805954 MAarrowhead1
% End of user PostScript
.581 1 0 r
.64359 .32694 m
.66889 .3803 L
s
% Start of user PostScript
0.28717685 -0.34611871 0.33777199 -0.23940626 MAarrowhead1
% End of user PostScript
.266 1 0 r
.61741 .59883 m
.59432 .60468 L
s
% Start of user PostScript
0.23481799 0.19765248 0.18863835 0.2093548 MAarrowhead1
% End of user PostScript
0 1 .049 r
.47053 .54767 m
.46312 .53481 L
s
% Start of user PostScript
-0.058944955 0.095344785 -0.073756323 0.069621467 MAarrowhead1
% End of user PostScript
0 1 .364 r
.46956 .47804 m
.47488 .47595 L
s
% Start of user PostScript
-0.060885557 -0.043920036 -0.050246634 -0.048106318 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50573 .48713 m
.50782 .4902 L
s
% Start of user PostScript
0.01145738 -0.025732254 0.015647704 -0.019600613 MAarrowhead1
% End of user PostScript
0 1 .995 r
.5078 .50476 m
.50659 .50544 L
s
% Start of user PostScript
0.015593459 0.0095295699 0.013181788 0.010871899 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49898 .50341 m
.4984 .50269 L
s
% Start of user PostScript
-0.0020369773 0.0068272941 -0.0031922282 0.0053831159 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49803 .499 m
.49829 .4988 L
s
% Start of user PostScript
-0.0039482855 -0.002004787 -0.0034119823 -0.0024088165 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50015 .49911 m
.50031 .49928 L
s
% Start of user PostScript
0.00030269404 -0.0017849485 0.00061468996 -0.0014492456 MAarrowhead1
% End of user PostScript
.165 0 1 r
.40608 0 m
.49499 .0562 L
.57605 .12504 L
.64105 .19783 L
.68997 .27102 L
.72344 .34161 L
.74261 .40721 L
.74899 .46598 L
.74439 .51668 L
.73076 .55857 L
.71009 .5914 L
.68434 .6153 L
.65534 .63075 L
.6248 .63849 L
.59416 .63946 L
.56468 .63469 L
.53734 .6253 L
.5129 .6124 L
.49187 .59708 L
.47454 .58034 L
.46101 .56308 L
.45121 .54606 L
.44493 .52993 L
.44187 .5152 L
.44162 .50222 L
.44375 .49124 L
.44778 .48237 L
.45326 .47563 L
.45972 .47095 L
.46676 .46818 L
.474 .46712 L
.48111 .46756 L
.48784 .46921 L
.49397 .47184 L
.49936 .47517 L
.50392 .47896 L
.50758 .48298 L
.51035 .48703 L
.51226 .49096 L
.51338 .49461 L
.51378 .4979 L
.51357 .50074 L
.51284 .50309 L
.51172 .50495 L
.51032 .5063 L
.50872 .50719 L
.50703 .50765 L
.50533 .50773 L
.5037 .50749 L
.50217 .50698 L
Mistroke
.50081 .50628 L
.49963 .50544 L
.49865 .50452 L
.49789 .50356 L
.49733 .50262 L
.49697 .50172 L
.49679 .5009 L
.49676 .50017 L
.49687 .49955 L
.49709 .49906 L
.49739 .49867 L
.49774 .49841 L
.49813 .49825 L
.49853 .49818 L
.49893 .4982 L
.4993 .49829 L
.49964 .49843 L
.49994 .49861 L
.5002 .49882 L
.50041 .49904 L
.50056 .49927 L
.50067 .49948 L
.50074 .49969 L
.50076 .49987 L
.50075 .50003 L
.50071 .50016 L
.50065 .50027 L
.50058 .50034 L
.50049 .5004 L
.5004 .50042 L
.5003 .50043 L
.50021 .50042 L
.50013 .50039 L
.50005 .50035 L
.49998 .5003 L
.49993 .50025 L
.49989 .5002 L
.49985 .50015 L
.49983 .5001 L
.49982 .50005 L
.49982 .50001 L
.49983 .49998 L
.49984 .49995 L
.49985 .49993 L
.49987 .49991 L
.49989 .4999 L
.49992 .4999 L
.49994 .4999 L
.49996 .4999 L
.49998 .49991 L
Mistroke
.5 .49992 L
.50001 .49993 L
.50002 .49995 L
.50003 .49996 L
.50004 .49997 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50004 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
8.99513 -1.0862986 8.8030846 0.72285638 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
8.2898379 2.2126574 7.5274813 3.3747979 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
0.40686603 4.0229647 -0.34352681 3.4647183 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-2.0236784 -0.34224058 -1.8736221 -0.65704484 MAarrowhead1
% End of user PostScript
.897 1 0 r
.40608 0 m
.49499 .0562 L
s
% Start of user PostScript
-0.20264555 -1.009354 -0.010014376 -0.88760805 MAarrowhead1
% End of user PostScript
.581 1 0 r
.74439 .51668 m
.73076 .55857 L
s
% Start of user PostScript
0.48878756 0.033364324 0.46152322 0.11714936 MAarrowhead1
% End of user PostScript
.266 1 0 r
.53734 .6253 m
.5129 .6124 L
s
% Start of user PostScript
0.074684019 0.25059047 0.025803318 0.22480431 MAarrowhead1
% End of user PostScript
0 1 .049 r
.44162 .50222 m
.44375 .49124 L
s
% Start of user PostScript
-0.11675763 0.0044418727 -0.11250566 -0.017522965 MAarrowhead1
% End of user PostScript
0 1 .364 r
.48784 .46921 m
.49397 .47184 L
s
% Start of user PostScript
-0.024319913 -0.061570275 -0.012051108 -0.056321992 MAarrowhead1
% End of user PostScript
0 1 .679 r
.51378 .4979 m
.51357 .50074 L
s
% Start of user PostScript
0.027562506 -0.0042082372 0.02713427 0.001473569 MAarrowhead1
% End of user PostScript
0 1 .995 r
.5037 .50749 m
.50217 .50698 L
s
% Start of user PostScript
0.0073907286 0.014970282 0.0043436277 0.013963333 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49679 .5009 m
.49676 .50017 L
s
% Start of user PostScript
-0.0064231681 0.0017946097 -0.0064716225 0.00034258396 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49893 .4982 m
.4993 .49829 L
s
% Start of user PostScript
-0.0021472753 -0.0036008937 -0.0013983193 -0.0034259951 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50074 .49969 m
.50076 .49987 L
s
% Start of user PostScript
0.0014753713 -0.00062460016 0.0015251859 -0.00025769246 MAarrowhead1
% End of user PostScript
1 0 .704 r
.41289 1 m
.33319 .91615 L
.26462 .82035 L
.21647 .72712 L
.18739 .63978 L
.17548 .56087 L
.17846 .49219 L
.19382 .43485 L
.21896 .38933 L
.2513 .35553 L
.28839 .33294 L
.32799 .32066 L
.36812 .31752 L
.40707 .32218 L
.44349 .3332 L
.47632 .34913 L
.50482 .36853 L
.52856 .39007 L
.54735 .41256 L
.56122 .43492 L
.57042 .4563 L
.57533 .476 L
.57643 .49349 L
.57431 .50844 L
.56955 .52065 L
.56277 .53007 L
.55458 .53678 L
.54551 .54094 L
.53608 .54279 L
.52672 .54264 L
.5178 .5408 L
.5096 .53763 L
.50233 .53346 L
.49613 .52863 L
.49108 .52342 L
.4872 .51812 L
.48446 .51294 L
.48278 .50807 L
.48205 .50367 L
.48216 .49982 L
.48297 .4966 L
.48432 .49403 L
.48609 .49212 L
.48813 .49082 L
.49032 .4901 L
.49254 .48989 L
.4947 .49012 L
.49673 .49071 L
.49857 .49158 L
.50016 .49264 L
Mistroke
.5015 .49383 L
.50256 .49507 L
.50334 .49631 L
.50387 .4975 L
.50416 .4986 L
.50423 .49957 L
.50413 .50041 L
.50387 .5011 L
.50351 .50163 L
.50306 .50201 L
.50256 .50225 L
.50204 .50237 L
.50152 .50236 L
.50102 .50227 L
.50056 .5021 L
.50016 .50187 L
.49981 .50161 L
.49952 .50132 L
.4993 .50102 L
.49915 .50074 L
.49905 .50047 L
.49901 .50022 L
.49901 .5 L
.49905 .49982 L
.49913 .49968 L
.49922 .49957 L
.49933 .4995 L
.49945 .49945 L
.49958 .49944 L
.4997 .49945 L
.49981 .49948 L
.49991 .49953 L
.5 .49959 L
.50008 .49965 L
.50014 .49972 L
.50018 .49979 L
.50021 .49986 L
.50023 .49992 L
.50023 .49997 L
.50023 .50002 L
.50022 .50006 L
.5002 .50009 L
.50017 .50011 L
.50014 .50012 L
.50011 .50013 L
.50009 .50013 L
.50006 .50013 L
.50003 .50012 L
.50001 .5001 L
.49999 .50009 L
Mistroke
.49997 .50007 L
.49996 .50006 L
.49995 .50004 L
.49995 .50003 L
.49995 .50001 L
.49995 .5 L
.49995 .49999 L
.49995 .49998 L
.49996 .49998 L
.49996 .49997 L
.49997 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49998 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
1.6196915 1.4862725 1.2787688 1.5476672 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
0.94144119 1.5373147 0.62062122 1.4671474 MAarrowhead1
% End of user PostScript
1 .473 0 r
.18739 .63978 m
.17548 .56087 L
s
% Start of user PostScript
-0.62521728 0.27956077 -0.64903645 0.12173846 MAarrowhead1
% End of user PostScript
1 .788 0 r
.36812 .31752 m
.40707 .32218 L
s
% Start of user PostScript
-0.26376643 -0.36496303 -0.18585745 -0.35563921 MAarrowhead1
% End of user PostScript
.897 1 0 r
.57042 .4563 m
.57533 .476 L
s
% Start of user PostScript
0.14084112 -0.087390726 0.15065379 -0.048000828 MAarrowhead1
% End of user PostScript
.581 1 0 r
.53608 .54279 m
.52672 .54264 L
s
% Start of user PostScript
0.072164679 0.085580452 0.053448674 0.085272712 MAarrowhead1
% End of user PostScript
.266 1 0 r
.48446 .51294 m
.48278 .50807 L
s
% Start of user PostScript
-0.031082472 0.025877085 -0.034448497 0.016148097 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49032 .4901 m
.49254 .48989 L
s
% Start of user PostScript
-0.019367066 -0.01979558 -0.014921936 -0.020211572 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50334 .49631 m
.50387 .4975 L
s
% Start of user PostScript
0.0066856785 -0.0073820403 0.0077404678 -0.0050039333 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50256 .50225 m
.50204 .50237 L
s
% Start of user PostScript
0.0051138758 0.0045083069 0.0040710486 0.0047311223 MAarrowhead1
% End of user PostScript
0 1 .995 r
.4993 .50102 m
.49915 .50074 L
s
% Start of user PostScript
-0.0013901194 0.0020483208 -0.0017029508 0.001473152 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49933 .4995 m
.49945 .49945 L
s
% Start of user PostScript
-0.0013313483 -0.0010081753 -0.0010900064 -0.0010922004 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50014 .49972 m
.50018 .49979 L
s
% Start of user PostScript
0.00027548861 -0.00055608126 0.00036483369 -0.00041849454 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50017 .50011 m
.50014 .50012 L
s
% Start of user PostScript
0.00034223466 0.00022049847 0.00028723763 0.00024817496 MAarrowhead1
% End of user PostScript
0 .981 1 r
.52804 1 m
.45058 .94137 L
.37233 .86299 L
.31175 .78268 L
.26842 .70395 L
.24131 .62971 L
.22889 .56221 L
.22932 .50305 L
.24049 .45327 L
.26025 .41334 L
.28643 .3833 L
.31694 .36274 L
.34988 .35097 L
.38353 .34706 L
.41644 .34988 L
.4474 .35826 L
.4755 .37096 L
.50007 .38678 L
.52069 .40459 L
.53717 .42335 L
.54952 .44217 L
.5579 .46028 L
.56263 .47707 L
.56409 .49208 L
.56275 .505 L
.55912 .51564 L
.55371 .52395 L
.54702 .52997 L
.53952 .53383 L
.53165 .53571 L
.52377 .53586 L
.51621 .53455 L
.50921 .53207 L
.50297 .52871 L
.49761 .52474 L
.49321 .52042 L
.48979 .51597 L
.48732 .5116 L
.48576 .50747 L
.48501 .5037 L
.48499 .50039 L
.48557 .49759 L
.48663 .49534 L
.48806 .49364 L
.48974 .49247 L
.49155 .49178 L
.49342 .49153 L
.49524 .49167 L
.49697 .49211 L
.49854 .4928 L
Mistroke
.49991 .49366 L
.50107 .49464 L
.502 .49568 L
.5027 .49672 L
.50318 .49773 L
.50345 .49867 L
.50355 .49951 L
.50348 .50023 L
.50329 .50083 L
.503 .5013 L
.50263 .50164 L
.50222 .50186 L
.50178 .50197 L
.50135 .50199 L
.50093 .50192 L
.50054 .50179 L
.50019 .5016 L
.49989 .50139 L
.49964 .50115 L
.49945 .5009 L
.49931 .50066 L
.49922 .50043 L
.49917 .50022 L
.49917 .50003 L
.4992 .49988 L
.49926 .49975 L
.49933 .49965 L
.49942 .49959 L
.49953 .49955 L
.49963 .49953 L
.49973 .49954 L
.49983 .49956 L
.49991 .4996 L
.49999 .49965 L
.50006 .4997 L
.50011 .49976 L
.50015 .49981 L
.50017 .49987 L
.50019 .49992 L
.5002 .49997 L
.50019 .50001 L
.50018 .50004 L
.50017 .50007 L
.50015 .50009 L
.50012 .5001 L
.5001 .50011 L
.50008 .50011 L
.50005 .50011 L
.50003 .5001 L
.50001 .50009 L
Mistroke
.49999 .50008 L
.49998 .50006 L
.49997 .50005 L
.49996 .50004 L
.49996 .50002 L
.49995 .50001 L
.49995 .5 L
.49996 .49999 L
.49996 .49999 L
.49996 .49998 L
.49997 .49998 L
.49997 .49998 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-9.3945646 4.5006658 -9.8071096 2.0820652 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-9.7612401 -0.03150733 -9.3323855 -1.8045006 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.8228792 -5.0918905 -0.81640933 -4.6235412 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
2.3149306 -0.24966742 2.2600617 0.21122626 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
0.56655531 1.243022 0.31558881 1.1508305 MAarrowhead1
% End of user PostScript
.581 1 0 r
.22889 .56221 m
.22932 .50305 L
s
% Start of user PostScript
-0.54221082 0.12441224 -0.54136874 0.0060962124 MAarrowhead1
% End of user PostScript
.266 1 0 r
.41644 .34988 m
.4474 .35826 L
s
% Start of user PostScript
-0.16712404 -0.30023538 -0.1051939 -0.28348308 MAarrowhead1
% End of user PostScript
0 1 .049 r
.56263 .47707 m
.56409 .49208 L
s
% Start of user PostScript
0.12525804 -0.045859053 0.12818147 -0.015835714 MAarrowhead1
% End of user PostScript
0 1 .364 r
.52377 .53586 m
.51621 .53455 L
s
% Start of user PostScript
0.047545109 0.071718581 0.032421125 0.069105441 MAarrowhead1
% End of user PostScript
0 1 .679 r
.48576 .50747 m
.48501 .5037 L
s
% Start of user PostScript
-0.028484456 0.014934669 -0.029970006 0.0073988887 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49342 .49153 m
.49524 .49167 L
s
% Start of user PostScript
-0.013164603 -0.016930514 -0.0095101818 -0.016667117 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50318 .49773 m
.50345 .49867 L
s
% Start of user PostScript
0.0063586011 -0.004538821 0.0069096944 -0.0026672037 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50178 .50197 m
.50135 .50199 L
s
% Start of user PostScript
0.003567831 0.0039455384 0.002694524 0.0039752114 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49931 .50066 m
.49922 .50043 L
s
% Start of user PostScript
-0.0013876285 0.001318739 -0.0015676793 0.00085870403 MAarrowhead1
% End of user PostScript
1 0 .627 r
.35603 0 m
.43466 .03934 L
.52139 .09984 L
.59335 .16664 L
.65003 .23604 L
.6916 .30486 L
.71884 .37043 L
.73295 .43066 L
.73549 .48399 L
.72819 .5294 L
.71295 .56634 L
.69163 .5947 L
.66608 .61472 L
.63798 .62694 L
.60888 .63212 L
.5801 .63118 L
.55273 .62515 L
.52765 .61508 L
.50549 .60203 L
.48667 .58699 L
.4714 .57089 L
.45973 .55454 L
.45154 .53863 L
.4466 .52373 L
.4446 .51028 L
.44513 .49857 L
.44777 .4888 L
.45207 .48105 L
.4576 .47529 L
.46394 .47145 L
.4707 .46937 L
.47755 .46885 L
.4842 .46966 L
.49041 .47155 L
.49601 .47427 L
.50086 .47759 L
.50491 .48127 L
.50811 .48511 L
.51047 .48893 L
.51203 .49257 L
.51286 .49593 L
.51305 .49891 L
.51268 .50146 L
.51186 .50354 L
.5107 .50515 L
.5093 .50629 L
.50775 .50699 L
.50614 .50731 L
.50455 .50728 L
.50303 .50696 L
Mistroke
.50163 .50642 L
.50039 .50571 L
.49933 .50488 L
.49847 .50399 L
.49781 .50308 L
.49734 .5022 L
.49706 .50137 L
.49694 .50062 L
.49696 .49996 L
.49709 .49942 L
.49733 .49898 L
.49763 .49865 L
.49798 .49843 L
.49835 .49831 L
.49873 .49827 L
.4991 .49831 L
.49945 .49842 L
.49976 .49856 L
.50003 .49875 L
.50026 .49895 L
.50044 .49916 L
.50057 .49937 L
.50066 .49957 L
.50071 .49976 L
.50072 .49993 L
.5007 .50007 L
.50066 .50019 L
.5006 .50028 L
.50052 .50034 L
.50044 .50039 L
.50035 .5004 L
.50026 .5004 L
.50017 .50039 L
.5001 .50036 L
.50003 .50032 L
.49997 .50027 L
.49992 .50022 L
.49988 .50017 L
.49985 .50013 L
.49984 .50008 L
.49983 .50004 L
.49983 .5 L
.49984 .49997 L
.49985 .49994 L
.49987 .49993 L
.49989 .49991 L
.49991 .49991 L
.49993 .4999 L
.49995 .49991 L
.49997 .49991 L
Mistroke
.49999 .49992 L
.5 .49993 L
.50001 .49994 L
.50002 .49995 L
.50003 .49996 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .5 L
.50004 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
7.0095054 -6.873225 7.9575806 -4.5161137 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
8.4352276 -2.356822 8.4988695 -0.44994088 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.8199363 4.7288818 1.8363671 4.4991999 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.9375305 0.82026912 -2.0029519 0.3384257 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-0.79334587 -1.1246565 -0.55410828 -1.0923788 MAarrowhead1
% End of user PostScript
.581 1 0 r
.71884 .37043 m
.73295 .43066 L
s
% Start of user PostScript
0.43767896 -0.25913653 0.46590712 -0.1386835 MAarrowhead1
% End of user PostScript
.266 1 0 r
.60888 .63212 m
.5801 .63118 L
s
% Start of user PostScript
0.21776496 0.2642354 0.16019687 0.26236571 MAarrowhead1
% End of user PostScript
0 1 .049 r
.45154 .53863 m
.4466 .52373 L
s
% Start of user PostScript
-0.09692049 0.07726156 -0.10679201 0.04746368 MAarrowhead1
% End of user PostScript
0 1 .364 r
.4707 .46937 m
.47755 .46885 L
s
% Start of user PostScript
-0.058600308 -0.061253438 -0.044903277 -0.062298907 MAarrowhead1
% End of user PostScript
0 1 .679 r
.51047 .48893 m
.51203 .49257 L
s
% Start of user PostScript
0.02093757 -0.022149332 0.024064355 -0.014854123 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50775 .50699 m
.50614 .50731 L
s
% Start of user PostScript
0.015509225 0.013985081 0.012289663 0.014611723 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49781 .50308 m
.49734 .5022 L
s
% Start of user PostScript
-0.004379022 0.0061690192 -0.005312853 0.0044017246 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49798 .49843 m
.49835 .49831 L
s
% Start of user PostScript
-0.0040459234 -0.0031367836 -0.0032992022 -0.003380663 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50044 .49916 m
.50057 .49937 L
s
% Start of user PostScript
0.00087529876 -0.0016798517 0.0011433316 -0.0012563723 MAarrowhead1
% End of user PostScript
.168 0 1 r
.80932 0 m
.84307 .04801 L
.91053 .18154 L
.95074 .30637 L
.96647 .41891 L
.96102 .51662 L
.93801 .59798 L
.90118 .66236 L
.85421 .70991 L
.80063 .74143 L
.74362 .75824 L
.68602 .76202 L
.63023 .75472 L
.57819 .7384 L
.53138 .71517 L
.49083 .68706 L
.45715 .65599 L
.4306 .62367 L
.41108 .59159 L
.39825 .561 L
.39155 .53288 L
.39027 .50796 L
.39357 .48672 L
.40061 .46942 L
.41049 .45612 L
.42236 .44672 L
.43543 .44095 L
.44898 .43847 L
.4624 .43885 L
.47517 .44161 L
.48688 .44627 L
.49724 .45232 L
.50604 .45931 L
.51319 .46681 L
.51866 .47443 L
.52251 .48185 L
.52484 .4888 L
.5258 .49509 L
.52558 .50056 L
.52437 .50513 L
.52238 .50876 L
.51981 .51146 L
.51687 .51327 L
.51372 .51426 L
.51053 .51451 L
.50743 .51415 L
.50453 .51328 L
.50191 .51202 L
.49964 .51048 L
.49775 .50876 L
Mistroke
.49625 .50698 L
.49514 .5052 L
.49441 .5035 L
.49401 .50193 L
.49392 .50053 L
.49409 .49934 L
.49446 .49837 L
.495 .49762 L
.49565 .49708 L
.49637 .49675 L
.49712 .4966 L
.49787 .49661 L
.49858 .49675 L
.49923 .497 L
.49981 .49733 L
.5003 .49772 L
.5007 .49813 L
.50101 .49855 L
.50123 .49897 L
.50137 .49935 L
.50143 .4997 L
.50142 .50001 L
.50136 .50027 L
.50125 .50047 L
.50111 .50063 L
.50095 .50073 L
.50077 .50079 L
.5006 .5008 L
.50042 .50079 L
.50026 .50074 L
.50012 .50067 L
.49999 .50059 L
.49988 .50049 L
.4998 .50039 L
.49973 .50029 L
.49969 .5002 L
.49967 .50011 L
.49966 .50003 L
.49967 .49997 L
.49969 .49991 L
.49972 .49987 L
.49976 .49984 L
.4998 .49982 L
.49984 .49981 L
.49988 .49981 L
.49992 .49982 L
.49995 .49983 L
.49999 .49985 L
.50001 .49987 L
.50004 .49989 L
Mistroke
.50006 .49992 L
.50007 .49994 L
.50008 .49996 L
.50008 .49998 L
.50008 .5 L
.50008 .50001 L
.50007 .50003 L
.50006 .50003 L
.50005 .50004 L
.50004 .50004 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50001 .50004 L
.5 .50003 L
.49999 .50003 L
.49999 .50002 L
.49999 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
6.5712546 9.4588697 4.5635426 9.1689771 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
2.6956599 8.5589601 1.019854 7.7046067 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-3.9605893 0.22731896 -3.8303162 -0.52980777 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.86498198 -2.0991207 -0.44514696 -1.9267188 MAarrowhead1
% End of user PostScript
.897 1 0 r
.96647 .41891 m
.96102 .51662 L
s
% Start of user PostScript
0.93293732 -0.16218402 0.92203849 0.033237472 MAarrowhead1
% End of user PostScript
.581 1 0 r
.63023 .75472 m
.57819 .7384 L
s
% Start of user PostScript
0.2604696 0.50943706 0.15638854 0.47680343 MAarrowhead1
% End of user PostScript
.266 1 0 r
.39155 .53288 m
.39027 .50796 L
s
% Start of user PostScript
-0.21689062 0.06575033 -0.21946516 0.015910084 MAarrowhead1
% End of user PostScript
0 1 .049 r
.4624 .43885 m
.47517 .44161 L
s
% Start of user PostScript
-0.075196622 -0.12230141 -0.049660711 -0.11677389 MAarrowhead1
% End of user PostScript
0 1 .364 r
.52484 .4888 m
.5258 .49509 L
s
% Start of user PostScript
0.04968276 -0.022397176 0.051608684 -0.0098272613 MAarrowhead1
% End of user PostScript
0 1 .679 r
.51053 .51451 m
.50743 .51415 L
s
% Start of user PostScript
0.021055132 0.029026795 0.014855425 0.028299238 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49441 .5035 m
.49401 .50193 L
s
% Start of user PostScript
-0.011187107 0.0069906194 -0.011975481 0.0038541326 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49712 .4966 m
.49787 .49661 L
s
% Start of user PostScript
-0.0057577321 -0.006804486 -0.004268762 -0.0067836481 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50123 .49897 m
.50137 .49935 L
s
% Start of user PostScript
0.0024676059 -0.0020678884 0.0027372961 -0.0012933867 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50077 .50079 m
.5006 .5008 L
s
% Start of user PostScript
0.0015445971 0.0015734168 0.0011910566 0.0016074357 MAarrowhead1
% End of user PostScript
1 0 .735 r
1 .76937 m
.99349 .77656 L
.92172 .82298 L
.84461 .84902 L
.7661 .85693 L
.68956 .84929 L
.61772 .82892 L
.5527 .79866 L
.49602 .76131 L
.4486 .71951 L
.41084 .67565 L
.38271 .6318 L
.36379 .58972 L
.35336 .55081 L
.35046 .51611 L
.35401 .48634 L
.36282 .46189 L
.37571 .4429 L
.3915 .42924 L
.40909 .4206 L
.42749 .41652 L
.44584 .41643 L
.46341 .4197 L
.47962 .42566 L
.49405 .43363 L
.50639 .44298 L
.5165 .45311 L
.52433 .46348 L
.52992 .47366 L
.53342 .48325 L
.53503 .49197 L
.53497 .49961 L
.53353 .50604 L
.53097 .5112 L
.52759 .51508 L
.52365 .51773 L
.51939 .51925 L
.51505 .51976 L
.51079 .51939 L
.50679 .51831 L
.50316 .51667 L
.49999 .51463 L
.49733 .51233 L
.4952 .5099 L
.4936 .50747 L
.49252 .50513 L
.49191 .50296 L
.49172 .50102 L
.49189 .49935 L
.49236 .49798 L
Mistroke
.49306 .4969 L
.49393 .49613 L
.49489 .49563 L
.49591 .49539 L
.49693 .49537 L
.49791 .49554 L
.49881 .49586 L
.49962 .49629 L
.50031 .4968 L
.50088 .49736 L
.50132 .49794 L
.50164 .4985 L
.50184 .49904 L
.50194 .49952 L
.50194 .49995 L
.50186 .50031 L
.50173 .5006 L
.50154 .50082 L
.50133 .50097 L
.50109 .50106 L
.50085 .50109 L
.50061 .50108 L
.50039 .50102 L
.50019 .50093 L
.50001 .50082 L
.49986 .50069 L
.49974 .50056 L
.49965 .50042 L
.49959 .50029 L
.49955 .50017 L
.49954 .50006 L
.49955 .49997 L
.49957 .49989 L
.49961 .49983 L
.49966 .49979 L
.49971 .49976 L
.49977 .49975 L
.49983 .49974 L
.49988 .49975 L
.49993 .49977 L
.49998 .49979 L
.50001 .49982 L
.50005 .49985 L
.50007 .49988 L
.50009 .49991 L
.5001 .49994 L
.50011 .49997 L
.50011 .5 L
.5001 .50002 L
.5001 .50003 L
Mistroke
.50009 .50004 L
.50007 .50005 L
.50006 .50006 L
.50005 .50006 L
.50003 .50006 L
.50002 .50006 L
.50001 .50005 L
.5 .50005 L
.49999 .50004 L
.49999 .50003 L
.49998 .50002 L
.49998 .50002 L
.49998 .50001 L
.49997 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-4.4517467 -2.1047901 -3.8754053 -2.5848027 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-3.2366151 -2.8843871 -2.570947 -3.0205295 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
0.89602481 -1.2921197 1.0925364 -0.9258113 MAarrowhead1
% End of user PostScript
1 .788 0 r
.92172 .82298 m
.84461 .84902 L
s
% Start of user PostScript
0.8434409 0.64595379 0.68922443 0.69804602 MAarrowhead1
% End of user PostScript
.897 1 0 r
.41084 .67565 m
.38271 .6318 L
s
% Start of user PostScript
-0.17831411 0.35129108 -0.23457018 0.26359424 MAarrowhead1
% End of user PostScript
.581 1 0 r
.3915 .42924 m
.40909 .4206 L
s
% Start of user PostScript
-0.21700521 -0.14152958 -0.18182011 -0.15880917 MAarrowhead1
% End of user PostScript
.266 1 0 r
.5165 .45311 m
.52433 .46348 L
s
% Start of user PostScript
0.033000315 -0.093782801 0.048651788 -0.073030651 MAarrowhead1
% End of user PostScript
0 1 .049 r
.52759 .51508 m
.52365 .51773 L
s
% Start of user PostScript
0.055181265 0.030159272 0.047296036 0.035469557 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49733 .51233 m
.4952 .5099 L
s
% Start of user PostScript
-0.0053479097 0.024651354 -0.0096061787 0.019802415 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49306 .4969 m
.49393 .49613 L
s
% Start of user PostScript
-0.013877913 -0.0061908558 -0.01214873 -0.0077455098 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50031 .4968 m
.50088 .49736 L
s
% Start of user PostScript
0.00061713539 -0.0063919478 0.0017546361 -0.0052748149 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50173 .5006 m
.50154 .50082 L
s
% Start of user PostScript
0.0034534526 0.0012034806 0.0030845513 0.0016433338 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50001 .50082 m
.49986 .50069 L
s
% Start of user PostScript
0.000022416781 0.0016370808 -0.00027673843 0.0013838374 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49957 .49989 m
.49961 .49983 L
s
% Start of user PostScript
-0.00085047757 -0.00021400674 -0.0007746324 -0.00033527674 MAarrowhead1
% End of user PostScript
.484 1 0 r
.43801 0 m
.48118 .02604 L
.56832 .09711 L
.63874 .17289 L
.69231 .24957 L
.72959 .32397 L
.7517 .39345 L
.7602 .45605 L
.75692 .51035 L
.7439 .55552 L
.72322 .59122 L
.69693 .61754 L
.66698 .63493 L
.63517 .64414 L
.60305 .6461 L
.57198 .64191 L
.54301 .63271 L
.51697 .61968 L
.49444 .60396 L
.47574 .58661 L
.46102 .56858 L
.45022 .5507 L
.44314 .53366 L
.43948 .51801 L
.43882 .50416 L
.44071 .49236 L
.44467 .48276 L
.45021 .47539 L
.45685 .47019 L
.46415 .46702 L
.47171 .46567 L
.47919 .46592 L
.4863 .46748 L
.49282 .4701 L
.49857 .47349 L
.50346 .4774 L
.50743 .48158 L
.51046 .48583 L
.51259 .48996 L
.51387 .49383 L
.51439 .49733 L
.51426 .50037 L
.51357 .50291 L
.51245 .50492 L
.51102 .50642 L
.50937 .50742 L
.50761 .50796 L
.50583 .50809 L
.50411 .50788 L
.50249 .50739 L
Mistroke
.50104 .50668 L
.49978 .50582 L
.49872 .50487 L
.49789 .50387 L
.49728 .50288 L
.49687 .50193 L
.49666 .50106 L
.49661 .50028 L
.49671 .49962 L
.49692 .49908 L
.49722 .49866 L
.49758 .49837 L
.49799 .49818 L
.4984 .4981 L
.49882 .49811 L
.49921 .49819 L
.49958 .49833 L
.4999 .49852 L
.50017 .49873 L
.5004 .49896 L
.50057 .4992 L
.50069 .49943 L
.50076 .49964 L
.5008 .49984 L
.50079 .50001 L
.50075 .50015 L
.50069 .50027 L
.50062 .50035 L
.50053 .50041 L
.50043 .50044 L
.50033 .50045 L
.50023 .50044 L
.50014 .50041 L
.50006 .50037 L
.49999 .50033 L
.49993 .50027 L
.49989 .50022 L
.49985 .50016 L
.49983 .50011 L
.49982 .50006 L
.49981 .50002 L
.49982 .49998 L
.49983 .49995 L
.49984 .49993 L
.49986 .49991 L
.49989 .4999 L
.49991 .4999 L
.49993 .4999 L
.49995 .4999 L
.49998 .49991 L
Mistroke
.49999 .49992 L
.50001 .49993 L
.50002 .49994 L
.50003 .49995 L
.50004 .49997 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50004 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
8.369199 -6.1708202 9.1303978 -3.676458 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
9.4042695 -1.4355276 9.2580991 0.50304343 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.5215372 5.1077855 1.4818877 4.7641938 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-2.1915798 0.61223742 -2.2080975 0.11682028 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-0.73260583 -1.2286108 -0.47706654 -1.1689295 MAarrowhead1
% End of user PostScript
.581 1 0 r
.7517 .39345 m
.7602 .45605 L
s
% Start of user PostScript
0.50339767 -0.21309229 0.52039049 -0.087906549 MAarrowhead1
% End of user PostScript
.266 1 0 r
.60305 .6461 m
.57198 .64191 L
s
% Start of user PostScript
0.20610928 0.29219811 0.14395319 0.28381006 MAarrowhead1
% End of user PostScript
0 1 .049 r
.44314 .53366 m
.43948 .51801 L
s
% Start of user PostScript
-0.11371581 0.067320935 -0.1210487 0.036026426 MAarrowhead1
% End of user PostScript
0 1 .364 r
.47171 .46567 m
.47919 .46592 L
s
% Start of user PostScript
-0.056575193 -0.068651539 -0.041618428 -0.068165267 MAarrowhead1
% End of user PostScript
0 1 .679 r
.51259 .48996 m
.51387 .49383 L
s
% Start of user PostScript
0.025181632 -0.020072039 0.027746086 -0.012330323 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50761 .50796 m
.50583 .50809 L
s
% Start of user PostScript
0.01522441 0.015914454 0.011665771 0.016185948 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49728 .50288 m
.49687 .50193 L
s
% Start of user PostScript
-0.0054399946 0.0057543108 -0.0062522997 0.0038589534 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49799 .49818 m
.4984 .4981 L
s
% Start of user PostScript
-0.0040293298 -0.0036335282 -0.0031928491 -0.0037963038 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50057 .4992 m
.50069 .49943 L
s
% Start of user PostScript
0.0011377703 -0.0016027004 0.0013803733 -0.0011435407 MAarrowhead1
% End of user PostScript
1 0 .31 r
.49339 1 m
.41108 .92974 L
.33666 .84599 L
.28072 .76186 L
.24253 .68075 L
.22077 .60545 L
.21366 .53801 L
.21915 .47988 L
.23499 .43189 L
.25888 .39433 L
.28858 .36702 L
.32197 .34941 L
.35711 .34066 L
.39233 .33968 L
.4262 .34527 L
.45758 .35615 L
.48562 .37103 L
.50974 .38869 L
.52959 .40796 L
.54507 .42781 L
.55627 .44737 L
.56341 .46589 L
.56688 .4828 L
.56711 .49769 L
.56462 .51028 L
.55995 .52043 L
.55363 .52814 L
.54618 .53348 L
.53808 .53663 L
.52976 .53781 L
.52158 .53729 L
.51385 .53536 L
.50681 .53232 L
.50063 .52848 L
.49541 .52412 L
.49122 .51949 L
.48805 .51483 L
.48587 .51032 L
.4846 .50613 L
.48415 .50236 L
.48441 .4991 L
.48525 .4964 L
.48654 .49428 L
.48817 .49273 L
.49001 .49172 L
.49195 .4912 L
.4939 .49111 L
.49578 .4914 L
.49753 .49198 L
.4991 .49279 L
Mistroke
.50045 .49376 L
.50157 .49483 L
.50244 .49592 L
.50308 .49701 L
.50349 .49804 L
.5037 .49898 L
.50372 .49982 L
.50359 .50052 L
.50334 .5011 L
.503 .50153 L
.50259 .50184 L
.50214 .50202 L
.50168 .50209 L
.50123 .50207 L
.5008 .50197 L
.5004 .5018 L
.50006 .50159 L
.49977 .50135 L
.49953 .5011 L
.49935 .50084 L
.49922 .50059 L
.49915 .50036 L
.49912 .50014 L
.49913 .49996 L
.49918 .49981 L
.49925 .49969 L
.49934 .4996 L
.49944 .49954 L
.49955 .49951 L
.49965 .49951 L
.49976 .49952 L
.49986 .49955 L
.49994 .4996 L
.50002 .49965 L
.50008 .49971 L
.50013 .49977 L
.50017 .49983 L
.50019 .49989 L
.5002 .49994 L
.50021 .49999 L
.5002 .50003 L
.50019 .50006 L
.50017 .50008 L
.50015 .5001 L
.50012 .50011 L
.50009 .50012 L
.50007 .50011 L
.50005 .50011 L
.50002 .5001 L
.5 .50009 L
Mistroke
.49999 .50008 L
.49997 .50006 L
.49996 .50005 L
.49996 .50003 L
.49995 .50002 L
.49995 .50001 L
.49995 .5 L
.49995 .49999 L
.49996 .49998 L
.49996 .49998 L
.49997 .49997 L
.49997 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-3.7988861 -5.7844213 -2.5806232 -5.5671324 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-1.4547456 -5.1620998 -0.45144481 -4.6156615 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.4209542 -0.047788926 2.3247188 0.40068376 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
0.48113503 1.270542 0.22885861 1.158466 MAarrowhead1
% End of user PostScript
.897 1 0 r
.21366 .53801 m
.21915 .47988 L
s
% Start of user PostScript
-0.57267463 0.076020976 -0.5616979 -0.040237394 MAarrowhead1
% End of user PostScript
.581 1 0 r
.4262 .34527 m
.45758 .35615 L
s
% Start of user PostScript
-0.14759986 -0.30946832 -0.084834298 -0.28770853 MAarrowhead1
% End of user PostScript
.266 1 0 r
.56688 .4828 m
.56711 .49769 L
s
% Start of user PostScript
0.13375743 -0.034392716 0.13422392 -0.0046236185 MAarrowhead1
% End of user PostScript
0 1 .049 r
.52158 .53729 m
.51385 .53536 L
s
% Start of user PostScript
0.043160219 0.074575112 0.027706006 0.070714287 MAarrowhead1
% End of user PostScript
0 1 .364 r
.4846 .50613 m
.48415 .50236 L
s
% Start of user PostScript
-0.030802072 0.012251526 -0.031698445 0.0047153604 MAarrowhead1
% End of user PostScript
0 1 .679 r
.4939 .49111 m
.49578 .4914 L
s
% Start of user PostScript
-0.012200478 -0.017770581 -0.0084348347 -0.017199528 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50349 .49804 m
.5037 .49898 L
s
% Start of user PostScript
0.0069788628 -0.0039196385 0.0073902898 -0.0020323715 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50168 .50209 m
.50123 .50207 L
s
% Start of user PostScript
0.0033614398 0.0041840012 0.0024536447 0.0041385983 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49922 .50059 m
.49915 .50036 L
s
% Start of user PostScript
-0.0015510179 0.0011781067 -0.0016983711 0.00071041689 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49955 .49951 m
.49965 .49951 L
s
% Start of user PostScript
-0.00090733758 -0.00097219899 -0.00069092799 -0.00098464834 MAarrowhead1
% End of user PostScript
.424 0 1 r
.02212 1 m
0 .95886 L
s
0 .28082 m
.03627 .24063 L
.10361 .19694 L
.176 .17237 L
.24972 .16486 L
.32161 .17195 L
.38909 .19102 L
.45018 .21939 L
.50345 .25442 L
.54803 .29365 L
.58354 .33484 L
.61 .37601 L
.62781 .41554 L
.63766 .45209 L
.64042 .4847 L
.63712 .51268 L
.62886 .53566 L
.61678 .55353 L
.60197 .56638 L
.58546 .57452 L
.56818 .57837 L
.55095 .57847 L
.53445 .57542 L
.51922 .56984 L
.50566 .56236 L
.49406 .55359 L
.48456 .54409 L
.4772 .53434 L
.47193 .52479 L
.46863 .51578 L
.46712 .50759 L
.46716 .5004 L
.46851 .49436 L
.4709 .48951 L
.47407 .48586 L
.47777 .48336 L
.48177 .48193 L
.48585 .48145 L
.48984 .48179 L
.4936 .4828 L
.49701 .48434 L
.49999 .48625 L
.5025 .48841 L
.5045 .49069 L
.506 .49297 L
.50702 .49517 L
.5076 .49721 L
.50777 .49903 L
.50761 .5006 L
.50718 .50189 L
Mistroke
.50652 .5029 L
.50571 .50363 L
.5048 .5041 L
.50384 .50433 L
.50289 .50435 L
.50197 .50419 L
.50112 .50389 L
.50036 .50349 L
.49971 .503 L
.49918 .50248 L
.49876 .50194 L
.49846 .50141 L
.49827 .50091 L
.49818 .50045 L
.49818 .50005 L
.49825 .49971 L
.49838 .49944 L
.49855 .49923 L
.49875 .49909 L
.49897 .499 L
.4992 .49897 L
.49942 .49899 L
.49963 .49904 L
.49982 .49913 L
.49999 .49923 L
.50013 .49935 L
.50024 .49948 L
.50033 .4996 L
.50039 .49972 L
.50042 .49984 L
.50043 .49994 L
.50042 .50003 L
.5004 .5001 L
.50036 .50016 L
.50032 .5002 L
.50027 .50023 L
.50022 .50024 L
.50016 .50024 L
.50011 .50023 L
.50007 .50022 L
.50002 .50019 L
.49999 .50017 L
.49996 .50014 L
.49993 .50011 L
.49992 .50008 L
.4999 .50005 L
.4999 .50003 L
.4999 .5 L
.4999 .49999 L
.49991 .49997 L
Mistroke
.49992 .49996 L
.49993 .49995 L
.49994 .49995 L
.49995 .49994 L
.49997 .49994 L
.49998 .49995 L
.49999 .49995 L
.5 .49996 L
.50001 .49996 L
.50001 .49997 L
.50002 .49998 L
.50002 .49998 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
0.25184254 -8.773015 1.8388731 -7.3481469 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
3.0975811 -5.8581812 4.030341 -4.3731521 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.6421741 2.4249013 3.0426186 2.7071385 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.57971218 1.5672085 -0.84004041 1.2152742 MAarrowhead1
% End of user PostScript
.897 1 0 r
.03627 .24063 m
.10361 .19694 L
s
% Start of user PostScript
-0.9274583 -0.51873799 -0.79277149 -0.60613 MAarrowhead1
% End of user PostScript
.581 1 0 r
.54803 .29365 m
.58354 .33484 L
s
% Start of user PostScript
0.096064601 -0.41269533 0.16707028 -0.3303278 MAarrowhead1
% End of user PostScript
.266 1 0 r
.61678 .55353 m
.60197 .56638 L
s
% Start of user PostScript
0.23356526 0.10705406 0.20394182 0.13276902 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49406 .55359 m
.48456 .54409 L
s
% Start of user PostScript
-0.01188059 0.10718188 -0.030888084 0.0881704 MAarrowhead1
% End of user PostScript
0 1 .364 r
.4709 .48951 m
.47407 .48586 L
s
% Start of user PostScript
-0.058197145 -0.020980279 -0.051853081 -0.028282698 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49999 .48625 m
.5025 .48841 L
s
% Start of user PostScript
-0.000012627991 -0.027491452 0.004995307 -0.023172476 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50718 .50189 m
.50652 .5029 L
s
% Start of user PostScript
0.014350601 0.0037837537 0.013039366 0.0058028677 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50036 .50349 m
.49971 .503 L
s
% Start of user PostScript
0.00072865519 0.0069706086 -0.00057258008 0.0060076451 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49825 .49971 m
.49838 .49944 L
s
% Start of user PostScript
-0.0035019751 -0.00058064044 -0.0032444168 -0.0011272336 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49982 .49913 m
.49999 .49923 L
s
% Start of user PostScript
-0.00035673786 -0.0017482871 -0.000022835504 -0.001538458 MAarrowhead1
% End of user PostScript
0 1 .938 r
.15544 1 m
.08226 .86677 L
.03356 .73303 L
.01133 .61145 L
.01222 .50492 L
.03247 .4153 L
.06816 .34346 L
.11539 .28941 L
.17042 .25245 L
.2298 .23133 L
.29044 .22435 L
.34974 .22951 L
.40552 .24466 L
.45612 .26758 L
.50036 .29612 L
.53748 .32824 L
.56714 .36206 L
.58935 .39597 L
.60443 .4286 L
.61291 .45884 L
.61551 .48588 L
.61307 .50914 L
.60651 .5283 L
.59674 .54325 L
.58467 .55407 L
.57115 .56099 L
.55696 .56436 L
.54276 .56462 L
.52914 .56225 L
.51654 .55778 L
.5053 .55171 L
.49565 .54454 L
.48772 .53675 L
.48156 .52874 L
.47713 .52086 L
.47432 .51342 L
.47299 .50663 L
.47295 .50067 L
.474 .49564 L
.47592 .49159 L
.4785 .48852 L
.48152 .48641 L
.4848 .48518 L
.48816 .48474 L
.49145 .48498 L
.49455 .48579 L
.49738 .48703 L
.49986 .48859 L
.50194 .49036 L
.50361 .49223 L
Mistroke
.50487 .49411 L
.50573 .49592 L
.50623 .49761 L
.50639 .49912 L
.50628 .50042 L
.50593 .5015 L
.5054 .50234 L
.50474 .50296 L
.50399 .50336 L
.50321 .50356 L
.50242 .50358 L
.50167 .50346 L
.50096 .50322 L
.50034 .50289 L
.49979 .5025 L
.49935 .50207 L
.499 .50162 L
.49875 .50119 L
.49859 .50077 L
.49851 .50039 L
.4985 .50006 L
.49855 .49978 L
.49866 .49955 L
.4988 .49938 L
.49896 .49925 L
.49915 .49918 L
.49933 .49916 L
.49951 .49917 L
.49969 .49921 L
.49984 .49928 L
.49998 .49936 L
.5001 .49946 L
.50019 .49956 L
.50027 .49967 L
.50031 .49977 L
.50034 .49986 L
.50035 .49995 L
.50035 .50002 L
.50033 .50008 L
.5003 .50013 L
.50027 .50016 L
.50022 .50018 L
.50018 .5002 L
.50014 .5002 L
.5001 .50019 L
.50006 .50018 L
.50002 .50016 L
.49999 .50014 L
.49997 .50012 L
.49995 .50009 L
Mistroke
.49993 .50007 L
.49992 .50004 L
.49992 .50002 L
.49992 .5 L
.49992 .49999 L
.49993 .49998 L
.49993 .49997 L
.49994 .49996 L
.49995 .49995 L
.49996 .49995 L
.49997 .49995 L
.49998 .49996 L
.49999 .49996 L
.5 .49996 L
.50001 .49997 L
.50001 .49998 L
.50001 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-1.4614788 -8.3273184 0.1186376 -7.2845779 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
1.4403331 -6.117934 2.4922412 -4.8939322 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.4655097 1.5954837 3.024685 1.9759156 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.17997169 1.5893288 -0.46165635 1.3067276 MAarrowhead1
% End of user PostScript
.897 1 0 r
.06816 .34346 m
.11539 .28941 L
s
% Start of user PostScript
-0.86368322 -0.31308776 -0.76921868 -0.42118892 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50036 .29612 m
.53748 .32824 L
s
% Start of user PostScript
0.00071416631 -0.40775282 0.07495271 -0.34352964 MAarrowhead1
% End of user PostScript
.266 1 0 r
.60651 .5283 m
.59674 .54325 L
s
% Start of user PostScript
0.21301777 0.056591224 0.19347647 0.086495655 MAarrowhead1
% End of user PostScript
0 1 .049 r
.5053 .55171 m
.49565 .54454 L
s
% Start of user PostScript
0.010593693 0.10341176 -0.0087012803 0.089086434 MAarrowhead1
% End of user PostScript
0 1 .364 r
.474 .49564 m
.47592 .49159 L
s
% Start of user PostScript
-0.051993936 -0.0087269071 -0.048150631 -0.016825512 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49738 .48703 m
.49986 .48859 L
s
% Start of user PostScript
-0.0052410946 -0.025942243 -0.00028870203 -0.022819113 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50628 .50042 m
.50593 .5015 L
s
% Start of user PostScript
0.012556566 0.00084043455 0.011859203 0.002995426 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50096 .50322 m
.50034 .50289 L
s
% Start of user PostScript
0.0019272759 0.0064397693 0.00067077352 0.0057785673 MAarrowhead1
% End of user PostScript
0 .375 1 r
.4985 .50006 m
.49855 .49978 L
s
% Start of user PostScript
-0.0029989714 0.00011833481 -0.0028905304 -0.00044650874 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49969 .49921 m
.49984 .49928 L
s
% Start of user PostScript
-0.00062688312 -0.0015820448 -0.00031155085 -0.0014475519 MAarrowhead1
% End of user PostScript
1 .657 0 r
.6327 1 m
.54647 .95344 L
.46186 .89063 L
.39236 .82228 L
.33833 .75202 L
.29943 .68296 L
.2748 .61767 L
.26313 .55815 L
.26281 .50587 L
.27202 .46174 L
.28887 .42623 L
.31146 .39937 L
.33796 .38085 L
.36669 .37006 L
.39613 .3662 L
.42501 .36832 L
.45224 .37536 L
.47702 .38625 L
.49873 .39994 L
.51701 .41544 L
.53168 .43183 L
.54272 .44831 L
.55028 .46422 L
.55462 .479 L
.55608 .49225 L
.55506 .50368 L
.552 .51313 L
.54735 .52054 L
.54156 .52594 L
.53503 .52943 L
.52816 .53118 L
.52125 .53141 L
.51461 .53035 L
.50845 .52824 L
.50294 .52534 L
.4982 .52189 L
.49429 .51812 L
.49124 .51423 L
.48902 .5104 L
.48761 .50677 L
.48691 .50345 L
.48685 .50052 L
.48733 .49804 L
.48823 .49604 L
.48946 .49452 L
.49092 .49346 L
.4925 .49284 L
.49413 .4926 L
.49573 .49269 L
.49725 .49306 L
Mistroke
.49863 .49365 L
.49985 .4944 L
.50088 .49525 L
.5017 .49616 L
.50233 .49707 L
.50276 .49796 L
.50301 .49878 L
.5031 .49952 L
.50306 .50016 L
.50289 .50069 L
.50264 .50111 L
.50233 .50142 L
.50197 .50162 L
.50159 .50172 L
.5012 .50174 L
.50083 .50169 L
.50049 .50157 L
.50018 .50142 L
.49992 .50123 L
.4997 .50102 L
.49953 .5008 L
.4994 .50059 L
.49932 .50039 L
.49928 .5002 L
.49927 .50004 L
.4993 .4999 L
.49934 .49979 L
.49941 .4997 L
.49949 .49964 L
.49958 .49961 L
.49967 .49959 L
.49976 .49959 L
.49984 .49961 L
.49992 .49965 L
.49999 .49969 L
.50004 .49973 L
.50009 .49978 L
.50013 .49983 L
.50015 .49988 L
.50017 .49993 L
.50017 .49997 L
.50017 .50001 L
.50016 .50004 L
.50015 .50006 L
.50013 .50008 L
.50011 .50009 L
.50009 .5001 L
.50007 .5001 L
.50005 .50009 L
.50003 .50009 L
Mistroke
.50001 .50008 L
.5 .50007 L
.49998 .50006 L
.49997 .50005 L
.49997 .50003 L
.49996 .50002 L
.49996 .50001 L
.49996 .5 L
.49996 .5 L
.49996 .49999 L
.49997 .49998 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-5.9598766 8.9210088 -7.3264399 6.4331972 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-8.1806289 4.0875247 -8.5705429 1.9549745 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-3.6755423 -4.8345769 -2.6356339 -4.7441242 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.8314893 -1.2523989 1.9802168 -0.72194536 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
0.99897446 1.1288729 0.7500556 1.1333863 MAarrowhead1
% End of user PostScript
.581 1 0 r
.29943 .68296 m
.2748 .61767 L
s
% Start of user PostScript
-0.4011333 0.36591159 -0.45039397 0.23533156 MAarrowhead1
% End of user PostScript
.266 1 0 r
.36669 .37006 m
.39613 .3662 L
s
% Start of user PostScript
-0.26662466 -0.25987678 -0.20773256 -0.26759168 MAarrowhead1
% End of user PostScript
0 1 .049 r
.54272 .44831 m
.55028 .46422 L
s
% Start of user PostScript
0.08543818 -0.1033716 0.10056319 -0.071561012 MAarrowhead1
% End of user PostScript
0 1 .364 r
.53503 .52943 m
.52816 .53118 L
s
% Start of user PostScript
0.070068437 0.058858539 0.056310517 0.062369297 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49124 .51423 m
.48902 .5104 L
s
% Start of user PostScript
-0.017526259 0.028466908 -0.021951617 0.02080001 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49092 .49346 m
.4925 .49284 L
s
% Start of user PostScript
-0.018164761 -0.0130751 -0.014995838 -0.014328467 MAarrowhead1
% End of user PostScript
0 .69 1 r
.5017 .49616 m
.50233 .49707 L
s
% Start of user PostScript
0.0034035438 -0.0076809071 0.0046550389 -0.0058536416 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50233 .50142 m
.50197 .50162 L
s
% Start of user PostScript
0.004651452 0.0028359469 0.0039332787 0.0032374067 MAarrowhead1
% End of user PostScript
0 .06 1 r
.4997 .50102 m
.49953 .5008 L
s
% Start of user PostScript
-0.00060413434 0.0020374689 -0.00094905879 0.0016071678 MAarrowhead1
% End of user PostScript
0 1 .636 r
0 .00922 m
.03102 .00023 L
s
.03102 .00023 m
.03473 0 L
s
.19171 0 m
.25016 .00786 L
.35063 .03971 L
.44094 .08486 L
.51912 .13935 L
.58398 .19952 L
.63507 .26205 L
.67255 .32405 L
.69712 .38314 L
.70986 .43741 L
.71217 .48548 L
.70561 .5264 L
.69189 .5597 L
.6727 .58527 L
.64968 .60332 L
.62437 .61435 L
.59815 .61903 L
.57222 .6182 L
.54756 .61277 L
.52496 .60371 L
.50499 .59195 L
.48802 .57841 L
.47426 .5639 L
.46374 .54917 L
.45635 .53483 L
.4519 .52141 L
.45009 .50928 L
.45056 .49873 L
.45293 .48993 L
.45681 .48294 L
.46179 .47775 L
.4675 .47429 L
.47359 .47241 L
.47976 .47194 L
.48575 .47266 L
.49135 .47436 L
.49639 .47682 L
.50077 .4798 L
.50442 .48312 L
.5073 .48658 L
.50943 .49001 L
.51084 .4933 L
.51159 .49633 L
.51175 .49902 L
.51142 .50131 L
.51069 .50319 L
.50965 .50463 L
.50838 .50566 L
.50699 .5063 L
.50554 .50658 L
Mistroke
.5041 .50656 L
.50273 .50627 L
.50147 .50578 L
.50035 .50514 L
.4994 .5044 L
.49862 .5036 L
.49803 .50278 L
.49761 .50198 L
.49735 .50124 L
.49724 .50056 L
.49726 .49997 L
.49738 .49947 L
.49759 .49908 L
.49786 .49879 L
.49818 .49859 L
.49851 .49848 L
.49885 .49845 L
.49919 .49848 L
.4995 .49857 L
.49978 .49871 L
.50003 .49887 L
.50023 .49905 L
.50039 .49924 L
.50051 .49943 L
.5006 .49962 L
.50064 .49979 L
.50065 .49994 L
.50063 .50006 L
.5006 .50017 L
.50054 .50025 L
.50047 .50031 L
.50039 .50035 L
.50031 .50036 L
.50023 .50036 L
.50016 .50035 L
.50009 .50032 L
.50002 .50029 L
.49997 .50025 L
.49993 .5002 L
.49989 .50016 L
.49987 .50011 L
.49985 .50007 L
.49985 .50003 L
.49985 .5 L
.49985 .49997 L
.49987 .49995 L
.49988 .49993 L
.4999 .49992 L
.49992 .49992 L
.49994 .49991 L
Mistroke
.49995 .49992 L
.49997 .49992 L
.49999 .49993 L
.5 .49994 L
.50001 .49995 L
.50002 .49996 L
.50003 .49997 L
.50003 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .5 L
.50003 .50001 L
.50003 .50001 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
7.6572499 -0.4088825 7.39981 1.050106 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
6.8877841 2.2328707 6.1825199 3.136459 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
0.13212128 3.2881812 -0.47252634 2.7953896 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.6918268 -0.38437446 -1.5484807 -0.63211127 MAarrowhead1
% End of user PostScript
.897 1 0 r
.44094 .08486 m
.51912 .13935 L
s
% Start of user PostScript
-0.1181165 -0.8302888 0.038235094 -0.72129303 MAarrowhead1
% End of user PostScript
.581 1 0 r
.70561 .5264 m
.69189 .5597 L
s
% Start of user PostScript
0.4112276 0.052807633 0.38378375 0.11940941 MAarrowhead1
% End of user PostScript
.266 1 0 r
.52496 .60371 m
.50499 .59195 L
s
% Start of user PostScript
0.049918115 0.20741656 0.0099747739 0.1839058 MAarrowhead1
% End of user PostScript
0 1 .049 r
.45056 .49873 m
.45293 .48993 L
s
% Start of user PostScript
-0.098883705 -0.0025355852 -0.094135601 -0.020148044 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49135 .47436 m
.49639 .47682 L
s
% Start of user PostScript
-0.017309042 -0.051276488 -0.0072190795 -0.046369262 MAarrowhead1
% End of user PostScript
0 1 .679 r
.51175 .49902 m
.51142 .50131 L
s
% Start of user PostScript
0.023509307 -0.0019671815 0.022848569 0.0026240981 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50273 .50627 m
.50147 .50578 L
s
% Start of user PostScript
0.0054569464 0.012545169 0.0029353866 0.011567189 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49724 .50056 m
.49726 .49997 L
s
% Start of user PostScript
-0.00552143 0.0011193627 -0.0054859798 -0.00006227787 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49919 .49848 m
.4995 .49857 L
s
% Start of user PostScript
-0.0016248202 -0.0030370076 -0.0010012189 -0.0028555824 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50064 .49979 m
.50065 .49994 L
s
% Start of user PostScript
0.0012794198 -0.00042957721 0.0013022061 -0.00012901569 MAarrowhead1
% End of user PostScript
.488 0 1 r
.48114 1 m
.46407 .98774 L
.37678 .90453 L
.30844 .8185 L
.25873 .73354 L
.22665 .65289 L
.21066 .57907 L
.2088 .51394 L
.21888 .45871 L
.23859 .41399 L
.26558 .3799 L
.29762 .35608 L
.33261 .34184 L
.36867 .33621 L
.4042 .33803 L
.43785 .34604 L
.46859 .35892 L
.49564 .37538 L
.51853 .39417 L
.53701 .41418 L
.55103 .43441 L
.56077 .45402 L
.56651 .47231 L
.56867 .48878 L
.56774 .50305 L
.56424 .51491 L
.55874 .52427 L
.55178 .53115 L
.54386 .53569 L
.53546 .53807 L
.52699 .53854 L
.5188 .5374 L
.51117 .53494 L
.50432 .53149 L
.4984 .52732 L
.49349 .52274 L
.48963 .51798 L
.48681 .51326 L
.48496 .50878 L
.48402 .50466 L
.48386 .50101 L
.48438 .49792 L
.48543 .4954 L
.4869 .49347 L
.48866 .49211 L
.49059 .49128 L
.49258 .49094 L
.49456 .49101 L
.49643 .49143 L
.49814 .49213 L
Mistroke
.49966 .49303 L
.50094 .49406 L
.50198 .49517 L
.50278 .49629 L
.50333 .49738 L
.50367 .4984 L
.5038 .49932 L
.50376 .50012 L
.50357 .50078 L
.50328 .50131 L
.5029 .5017 L
.50246 .50196 L
.502 .5021 L
.50153 .50214 L
.50107 .50208 L
.50065 .50195 L
.50027 .50176 L
.49993 .50153 L
.49966 .50128 L
.49944 .50101 L
.49928 .50075 L
.49917 .5005 L
.49912 .50027 L
.49911 .50007 L
.49913 .4999 L
.49919 .49975 L
.49927 .49964 L
.49936 .49957 L
.49947 .49952 L
.49958 .4995 L
.49969 .4995 L
.4998 .49952 L
.49989 .49956 L
.49998 .49961 L
.50005 .49967 L
.50011 .49973 L
.50015 .49979 L
.50018 .49985 L
.5002 .49991 L
.50021 .49996 L
.50021 .5 L
.5002 .50004 L
.50018 .50007 L
.50016 .50009 L
.50014 .50011 L
.50011 .50012 L
.50009 .50012 L
.50006 .50012 L
.50004 .50011 L
.50002 .5001 L
Mistroke
.5 .50009 L
.49998 .50007 L
.49997 .50006 L
.49996 .50004 L
.49995 .50003 L
.49995 .50002 L
.49995 .5 L
.49995 .49999 L
.49995 .49999 L
.49996 .49998 L
.49996 .49998 L
.49997 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-8.3896945 -4.4130356 -7.222225 -5.2474952 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-5.9533699 -5.7381424 -4.6501471 -5.9205531 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.8740154 -2.3170494 2.2148187 -1.6115017 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.5628299 1.2978626 1.2586895 1.3785157 MAarrowhead1
% End of user PostScript
.897 1 0 r
.30844 .8185 m
.25873 .73354 L
s
% Start of user PostScript
-0.38311258 0.63699499 -0.48253044 0.46708675 MAarrowhead1
% End of user PostScript
.581 1 0 r
.29762 .35608 m
.33261 .34184 L
s
% Start of user PostScript
-0.4047586 -0.28784362 -0.3347849 -0.31632271 MAarrowhead1
% End of user PostScript
.266 1 0 r
.53701 .41418 m
.55103 .43441 L
s
% Start of user PostScript
0.074010515 -0.1716339 0.10206441 -0.13117489 MAarrowhead1
% End of user PostScript
0 1 .049 r
.55178 .53115 m
.54386 .53569 L
s
% Start of user PostScript
0.10355408 0.062303854 0.087717136 0.071372247 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49349 .52274 m
.48963 .51798 L
s
% Start of user PostScript
-0.013015256 0.045474372 -0.020733948 0.035955786 MAarrowhead1
% End of user PostScript
0 1 .679 r
.4869 .49347 m
.48866 .49211 L
s
% Start of user PostScript
-0.026194151 -0.013064837 -0.022679051 -0.015782318 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50094 .49406 m
.50198 .49517 L
s
% Start of user PostScript
0.0018851923 -0.011874377 0.0039663157 -0.009664514 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50328 .50131 m
.5029 .5017 L
s
% Start of user PostScript
0.0065547101 0.0026214015 0.0057931152 0.0034032508 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49993 .50153 m
.49966 .50128 L
s
% Start of user PostScript
-0.00013348807 0.0030607188 -0.00068519167 0.0025553022 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49919 .49975 m
.49927 .49964 L
s
% Start of user PostScript
-0.0016231205 -0.00049168508 -0.0014632067 -0.00071003974 MAarrowhead1
% End of user PostScript
.929 0 1 r
.92416 0 m
.96859 .07976 L
s
.96859 .07976 m
1 .16434 L
s
1 .65168 m
.98928 .67381 L
.93641 .73561 L
.87458 .77806 L
.8077 .80258 L
.73925 .81107 L
.67222 .80575 L
.60906 .78906 L
.55169 .76349 L
.50145 .73148 L
.45923 .69536 L
.42541 .65723 L
.40001 .61893 L
.38268 .58202 L
.37282 .54776 L
.36964 .51709 L
.37218 .49066 L
.37942 .46884 L
.39032 .45178 L
.40386 .43938 L
.41907 .4314 L
.43507 .42744 L
.4511 .42702 L
.46651 .42958 L
.48079 .43455 L
.49355 .44134 L
.50451 .44939 L
.51353 .45816 L
.52057 .4672 L
.52565 .47611 L
.52889 .48453 L
.53045 .49223 L
.53055 .499 L
.52941 .50472 L
.52727 .50933 L
.52439 .51283 L
.521 .51526 L
.51731 .51669 L
.51352 .51722 L
.5098 .51697 L
.50628 .51609 L
.50308 .5147 L
.50027 .51295 L
.4979 .51097 L
.49599 .50886 L
.49455 .50674 L
.49356 .50468 L
.49299 .50278 L
.49278 .50106 L
.4929 .49958 L
Mistroke
.49329 .49835 L
.49388 .49739 L
.49462 .49668 L
.49546 .49623 L
.49634 .49599 L
.49723 .49596 L
.49809 .49609 L
.49888 .49635 L
.49959 .49672 L
.50021 .49716 L
.50072 .49765 L
.50111 .49815 L
.5014 .49864 L
.50159 .49911 L
.50168 .49954 L
.50169 .49992 L
.50163 .50024 L
.50152 .5005 L
.50136 .5007 L
.50118 .50084 L
.50097 .50092 L
.50076 .50095 L
.50056 .50094 L
.50036 .5009 L
.50018 .50082 L
.50003 .50072 L
.49989 .50062 L
.49978 .5005 L
.4997 .50038 L
.49965 .50027 L
.49961 .50016 L
.4996 .50007 L
.49961 .49998 L
.49963 .49991 L
.49966 .49986 L
.4997 .49982 L
.49974 .49979 L
.49979 .49978 L
.49984 .49978 L
.49989 .49978 L
.49994 .4998 L
.49997 .49982 L
.50001 .49984 L
.50004 .49987 L
.50006 .4999 L
.50008 .49992 L
.50009 .49995 L
.50009 .49997 L
.50009 .49999 L
.50009 .50001 L
Mistroke
.50008 .50003 L
.50008 .50004 L
.50007 .50005 L
.50005 .50005 L
.50004 .50005 L
.50003 .50005 L
.50002 .50005 L
.50001 .50005 L
.5 .50004 L
.49999 .50003 L
.49999 .50003 L
.49998 .50002 L
.49998 .50002 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-4.6101862 1.6405025 -4.7091574 0.54292308 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-4.6039217 -0.40015902 -4.3314714 -1.1758337 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-0.65860708 -2.3484847 -0.20229767 -2.0992964 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.1020151 -0.020057262 1.0578999 0.18382028 MAarrowhead1
% End of user PostScript
.897 1 0 r
.60906 .78906 m
.55169 .76349 L
s
% Start of user PostScript
0.21812645 0.57811515 0.10337155 0.52697375 MAarrowhead1
% End of user PostScript
.581 1 0 r
.36964 .51709 m
.37218 .49066 L
s
% Start of user PostScript
-0.26072549 0.034174546 -0.25564861 -0.018686656 MAarrowhead1
% End of user PostScript
.266 1 0 r
.46651 .42958 m
.48079 .43455 L
s
% Start of user PostScript
-0.066971144 -0.14083364 -0.038416255 -0.13089489 MAarrowhead1
% End of user PostScript
0 1 .049 r
.53045 .49223 m
.53055 .499 L
s
% Start of user PostScript
0.06090817 -0.01554764 0.061099914 -0.0020097431 MAarrowhead1
% End of user PostScript
0 1 .364 r
.5098 .51697 m
.50628 .51609 L
s
% Start of user PostScript
0.019594291 0.033943086 0.012562436 0.032176674 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49299 .50278 m
.49278 .50106 L
s
% Start of user PostScript
-0.014029117 0.0055501037 -0.014431919 0.0021223926 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49723 .49596 m
.49809 .49609 L
s
% Start of user PostScript
-0.0055411801 -0.0080896583 -0.0038275111 -0.0078273656 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50159 .49911 m
.50168 .49954 L
s
% Start of user PostScript
0.0031793853 -0.0017776376 0.0033653551 -0.00091911343 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50076 .50095 m
.50056 .50094 L
s
% Start of user PostScript
0.0015271823 0.001905011 0.0011139991 0.0018837358 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49965 .50027 m
.49961 .50016 L
s
% Start of user PostScript
-0.00070681511 0.00053467405 -0.0007735645 0.00032188895 MAarrowhead1
% End of user PostScript
.476 0 1 r
0 .06873 m
.00445 .06655 L
.10488 .04442 L
.20499 .04407 L
.30082 .062 L
.38923 .09457 L
.46788 .13812 L
.53519 .18915 L
.59028 .24442 L
.63292 .30104 L
.6634 .35652 L
.68245 .40884 L
.69114 .4564 L
.6908 .49807 L
.68288 .53313 L
.66892 .56123 L
.65045 .58237 L
.62892 .59683 L
.6057 .60509 L
.58197 .60782 L
.55878 .60581 L
.53696 .59988 L
.51717 .59091 L
.49986 .57975 L
.48534 .56719 L
.47374 .55396 L
.46505 .54069 L
.45915 .52793 L
.45584 .5161 L
.45482 .50553 L
.45577 .49643 L
.45834 .48893 L
.46216 .48308 L
.46688 .47885 L
.47217 .47614 L
.47772 .47482 L
.48327 .47472 L
.4886 .47565 L
.49353 .4774 L
.49793 .47977 L
.5017 .48258 L
.5048 .48562 L
.50721 .48876 L
.50895 .49184 L
.51004 .49475 L
.51057 .49741 L
.51058 .49974 L
.51017 .50171 L
.50942 .50329 L
.50841 .50449 L
Mistroke
.50723 .50531 L
.50595 .5058 L
.50463 .50597 L
.50335 .50587 L
.50213 .50556 L
.50103 .50507 L
.50006 .50446 L
.49924 .50377 L
.49859 .50304 L
.49809 .50231 L
.49776 .5016 L
.49756 .50094 L
.4975 .50035 L
.49754 .49984 L
.49768 .49941 L
.49789 .49908 L
.49815 .49884 L
.49844 .49869 L
.49874 .49861 L
.49905 .4986 L
.49935 .49865 L
.49962 .49874 L
.49987 .49887 L
.50008 .49902 L
.50025 .49919 L
.50039 .49937 L
.50049 .49954 L
.50055 .4997 L
.50058 .49985 L
.50059 .49998 L
.50057 .50009 L
.50052 .50018 L
.50047 .50024 L
.50041 .50029 L
.50033 .50032 L
.50026 .50033 L
.50019 .50033 L
.50012 .50031 L
.50006 .50028 L
.50001 .50025 L
.49996 .50021 L
.49992 .50017 L
.4999 .50013 L
.49988 .50009 L
.49987 .50005 L
.49986 .50002 L
.49986 .49999 L
.49987 .49997 L
.49988 .49995 L
.4999 .49994 L
Mistroke
.49991 .49993 L
.49993 .49992 L
.49995 .49992 L
.49996 .49992 L
.49998 .49993 L
.49999 .49994 L
.5 .49995 L
.50001 .49995 L
.50002 .49996 L
.50003 .49997 L
.50003 .49998 L
.50003 .49999 L
.50003 .5 L
.50003 .5 L
.50003 .50001 L
.50003 .50001 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
5.9658192 -5.0417961 6.6255518 -3.1626607 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
6.9144151 -1.4587334 6.880398 0.029974587 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.0644847 3.8110598 1.2808369 3.5880463 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.600697 0.55239973 -1.6319284 0.17401367 MAarrowhead1
% End of user PostScript
.897 1 0 r
.20499 .04407 m
.30082 .062 L
s
% Start of user PostScript
-0.59002409 -0.91186742 -0.39835793 -0.87600349 MAarrowhead1
% End of user PostScript
.581 1 0 r
.68245 .40884 m
.69114 .4564 L
s
% Start of user PostScript
0.36489645 -0.18232251 0.38228831 -0.087200441 MAarrowhead1
% End of user PostScript
.266 1 0 r
.58197 .60782 m
.55878 .60581 L
s
% Start of user PostScript
0.16394667 0.21564583 0.11756168 0.2116111 MAarrowhead1
% End of user PostScript
0 1 .049 r
.45915 .52793 m
.45584 .5161 L
s
% Start of user PostScript
-0.081693501 0.055862852 -0.088327424 0.032202049 MAarrowhead1
% End of user PostScript
0 1 .364 r
.47772 .47482 m
.48327 .47472 L
s
% Start of user PostScript
-0.044559032 -0.05035328 -0.033456033 -0.050554576 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50895 .49184 m
.51004 .49475 L
s
% Start of user PostScript
0.017892543 -0.016321383 0.020089796 -0.010496878 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50595 .5058 m
.50463 .50597 L
s
% Start of user PostScript
0.011892737 0.011591785 0.009265861 0.011935901 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49809 .50231 m
.49776 .5016 L
s
% Start of user PostScript
-0.0038109709 0.0046108638 -0.0044856171 0.0031919565 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49844 .49869 m
.49874 .49861 L
s
% Start of user PostScript
-0.0031253889 -0.0026253819 -0.0025117181 -0.0027819773 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50039 .49937 m
.50049 .49954 L
s
% Start of user PostScript
0.00078175967 -0.0012697597 0.00097915151 -0.00092777866 MAarrowhead1
% End of user PostScript
.205 1 0 r
.48452 1 m
.40859 .93493 L
.33333 .84992 L
.27682 .76456 L
.23831 .68232 L
.21644 .606 L
.20943 .53769 L
.21516 .47884 L
.23136 .43028 L
.2557 .39231 L
.28591 .36474 L
.31982 .34701 L
.3555 .33824 L
.39123 .33734 L
.42557 .3431 L
.45737 .3542 L
.48578 .36936 L
.51019 .3873 L
.53028 .40687 L
.54593 .42703 L
.55723 .44686 L
.56442 .46564 L
.56789 .48277 L
.56809 .49785 L
.56553 .51059 L
.56076 .52086 L
.55433 .52865 L
.54675 .53404 L
.53853 .5372 L
.53008 .53837 L
.52179 .53782 L
.51395 .53584 L
.50682 .53275 L
.50056 .52885 L
.49528 .52441 L
.49104 .51972 L
.48784 .51498 L
.48563 .51041 L
.48436 .50616 L
.48392 .50234 L
.48419 .49905 L
.48505 .49631 L
.48636 .49417 L
.48802 .4926 L
.48988 .49158 L
.49186 .49106 L
.49384 .49099 L
.49575 .49128 L
.49752 .49188 L
.49911 .4927 L
Mistroke
.50047 .49369 L
.5016 .49476 L
.50249 .49588 L
.50313 .49698 L
.50355 .49803 L
.50375 .49898 L
.50377 .49982 L
.50364 .50054 L
.50339 .50112 L
.50304 .50156 L
.50262 .50187 L
.50217 .50205 L
.5017 .50212 L
.50124 .5021 L
.5008 .50199 L
.5004 .50183 L
.50005 .50161 L
.49976 .50137 L
.49952 .50111 L
.49934 .50085 L
.49921 .50059 L
.49914 .50036 L
.49911 .50014 L
.49912 .49996 L
.49917 .49981 L
.49924 .49968 L
.49933 .4996 L
.49943 .49954 L
.49954 .49951 L
.49965 .4995 L
.49976 .49952 L
.49986 .49955 L
.49994 .49959 L
.50002 .49965 L
.50008 .49971 L
.50013 .49977 L
.50017 .49983 L
.5002 .49989 L
.50021 .49994 L
.50021 .49999 L
.5002 .50003 L
.50019 .50006 L
.50017 .50008 L
.50015 .5001 L
.50012 .50011 L
.5001 .50012 L
.50007 .50012 L
.50005 .50011 L
.50002 .5001 L
.5 .50009 L
Mistroke
.49999 .50008 L
.49997 .50006 L
.49996 .50005 L
.49996 .50003 L
.49995 .50002 L
.49995 .50001 L
.49995 .5 L
.49995 .49999 L
.49996 .49998 L
.49996 .49998 L
.49997 .49997 L
.49997 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-1.4612521 -5.2315651 -0.44501666 -4.6753929 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
0.42586539 -4.0215427 1.1399032 -3.3118432 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.1798492 0.7768043 1.9438705 1.0517466 MAarrowhead1
% End of user PostScript
1 .788 0 r
.48452 1 m
.40859 .93493 L
s
% Start of user PostScript
0.0051922316 1.0309741 -0.182818 0.86986495 MAarrowhead1
% End of user PostScript
.897 1 0 r
.23136 .43028 m
.2557 .39231 L
s
% Start of user PostScript
-0.53728168 -0.13943334 -0.48859552 -0.21537868 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48578 .36936 m
.51019 .3873 L
s
% Start of user PostScript
-0.028444406 -0.26128458 0.020379832 -0.22539522 MAarrowhead1
% End of user PostScript
.266 1 0 r
.56553 .51059 m
.56076 .52086 L
s
% Start of user PostScript
0.13105393 0.02117375 0.12151654 0.041716142 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50682 .53275 m
.50056 .52885 L
s
% Start of user PostScript
0.013640161 0.065502493 0.0011180582 0.057690873 MAarrowhead1
% End of user PostScript
0 1 .364 r
.48419 .49905 m
.48505 .49631 L
s
% Start of user PostScript
-0.031627879 -0.0019096914 -0.029909083 -0.0073703249 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49752 .49188 m
.49911 .4927 L
s
% Start of user PostScript
-0.0049626722 -0.016249266 -0.0017878604 -0.014599025 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50377 .49982 m
.50364 .50054 L
s
% Start of user PostScript
0.0075484349 -0.00035061025 0.0072850979 0.0010793987 MAarrowhead1
% End of user PostScript
0 .69 1 r
.5008 .50199 m
.5004 .50183 L
s
% Start of user PostScript
0.0016054155 0.0039892935 0.0008092027 0.0036546477 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49911 .50014 m
.49912 .49996 L
s
% Start of user PostScript
-0.0017802542 0.0002881511 -0.0017555712 -0.000081403879 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49976 .49952 m
.49986 .49955 L
s
% Start of user PostScript
-0.00048589711 -0.00096917926 -0.00028830552 -0.00090534066 MAarrowhead1
% End of user PostScript
1 .653 0 r
.42209 1 m
.38107 .9629 L
.30191 .86848 L
.24339 .77448 L
.20451 .68459 L
.1837 .60176 L
.17888 .52815 L
.18767 .46523 L
.20754 .41381 L
.23592 .37409 L
.2703 .34578 L
.30834 .32818 L
.34795 .32028 L
.38727 .32083 L
.42479 .32846 L
.4593 .34173 L
.48989 .35919 L
.51598 .37948 L
.53723 .40134 L
.55359 .42363 L
.56518 .44539 L
.5723 .46585 L
.57539 .48439 L
.57496 .50057 L
.57161 .51414 L
.56593 .52496 L
.55853 .53304 L
.54997 .53851 L
.54079 .54156 L
.53145 .54246 L
.52236 .54151 L
.51383 .53906 L
.50611 .53544 L
.49939 .53098 L
.49378 .526 L
.48931 .52078 L
.48599 .51557 L
.48376 .51057 L
.48254 .50595 L
.48221 .50183 L
.48265 .49831 L
.48371 .49541 L
.48525 .49317 L
.48714 .49155 L
.48923 .49054 L
.49142 .49006 L
.4936 .49006 L
.49569 .49046 L
.49762 .49118 L
.49933 .49213 L
Mistroke
.50079 .49324 L
.50199 .49445 L
.50291 .49568 L
.50357 .49689 L
.50398 .49803 L
.50417 .49907 L
.50416 .49997 L
.50398 .50073 L
.50368 .50134 L
.50327 .5018 L
.5028 .50211 L
.5023 .50229 L
.50178 .50235 L
.50127 .50231 L
.5008 .50217 L
.50037 .50198 L
.49999 .50173 L
.49968 .50146 L
.49942 .50117 L
.49924 .50088 L
.49911 .5006 L
.49904 .50035 L
.49902 .50012 L
.49904 .49992 L
.49909 .49976 L
.49918 .49963 L
.49928 .49954 L
.4994 .49948 L
.49952 .49945 L
.49964 .49945 L
.49975 .49947 L
.49986 .49951 L
.49996 .49956 L
.50004 .49962 L
.50011 .49969 L
.50016 .49976 L
.5002 .49982 L
.50022 .49989 L
.50023 .49994 L
.50023 .5 L
.50022 .50004 L
.5002 .50007 L
.50018 .5001 L
.50016 .50012 L
.50013 .50013 L
.5001 .50013 L
.50007 .50013 L
.50005 .50012 L
.50002 .50011 L
.5 .5001 L
Mistroke
.49998 .50008 L
.49997 .50007 L
.49996 .50005 L
.49995 .50003 L
.49995 .50002 L
.49995 .50001 L
.49995 .5 L
.49995 .49999 L
.49995 .49998 L
.49996 .49997 L
.49997 .49997 L
.49997 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49998 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-8.2020556 -5.6296899 -6.821114 -6.2387311 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-5.3890985 -6.50051 -3.9714746 -6.4603087 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.3783657 -1.9173392 2.6245026 -1.1827563 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.4491813 1.5060687 1.1120438 1.5332944 MAarrowhead1
% End of user PostScript
.897 1 0 r
.24339 .77448 m
.20451 .68459 L
s
% Start of user PostScript
-0.51322971 0.54895422 -0.5909714 0.36918478 MAarrowhead1
% End of user PostScript
.581 1 0 r
.30834 .32818 m
.34795 .32028 L
s
% Start of user PostScript
-0.38331171 -0.34363782 -0.30410511 -0.35944042 MAarrowhead1
% End of user PostScript
.266 1 0 r
.55359 .42363 m
.56518 .44539 L
s
% Start of user PostScript
0.10718132 -0.15274417 0.13035673 -0.10921252 MAarrowhead1
% End of user PostScript
0 1 .049 r
.54997 .53851 m
.54079 .54156 L
s
% Start of user PostScript
0.099942403 0.077017566 0.081582004 0.083115323 MAarrowhead1
% End of user PostScript
0 1 .364 r
.48931 .52078 m
.48599 .51557 L
s
% Start of user PostScript
-0.021377676 0.041560121 -0.028020932 0.031133641 MAarrowhead1
% End of user PostScript
0 1 .679 r
.48714 .49155 m
.48923 .49054 L
s
% Start of user PostScript
-0.025726311 -0.016891091 -0.021534563 -0.018921924 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50199 .49445 m
.50291 .49568 L
s
% Start of user PostScript
0.003970993 -0.011102583 0.005821127 -0.0086341206 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50327 .5018 m
.5028 .50211 L
s
% Start of user PostScript
0.0065447966 0.0036039647 0.0056046639 0.004229563 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49968 .50146 m
.49942 .50117 L
s
% Start of user PostScript
-0.0006483414 0.0029200735 -0.0011521103 0.0023429872 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49918 .49963 m
.49928 .49954 L
s
% Start of user PostScript
-0.001646706 -0.00074109297 -0.0014403418 -0.00092454009 MAarrowhead1
% End of user PostScript
0 .045 1 r
.49504 1 m
.41169 .92894 L
.33739 .84543 L
.28152 .76151 L
.24336 .68061 L
.22158 .60548 L
.21444 .53819 L
.21986 .48017 L
.23562 .43226 L
.25942 .39475 L
.28901 .36748 L
.3223 .34988 L
.35734 .34111 L
.39247 .3401 L
.42626 .34565 L
.45757 .35648 L
.48555 .37131 L
.50961 .3889 L
.52943 .40812 L
.54489 .42792 L
.55608 .44743 L
.56322 .46591 L
.56669 .48278 L
.56694 .49763 L
.56447 .5102 L
.55981 .52034 L
.55352 .52803 L
.54609 .53338 L
.53801 .53652 L
.52971 .53771 L
.52156 .53719 L
.51385 .53527 L
.50682 .53225 L
.50065 .52842 L
.49545 .52408 L
.49126 .51946 L
.48809 .51481 L
.48591 .51031 L
.48464 .50613 L
.48419 .50237 L
.48445 .49912 L
.48528 .49642 L
.48657 .4943 L
.48819 .49275 L
.49002 .49174 L
.49196 .49122 L
.49391 .49114 L
.49579 .49142 L
.49753 .492 L
.49909 .49281 L
Mistroke
.50044 .49378 L
.50156 .49483 L
.50243 .49593 L
.50307 .49701 L
.50348 .49804 L
.50368 .49898 L
.50371 .49981 L
.50358 .50052 L
.50333 .50109 L
.50299 .50153 L
.50258 .50183 L
.50214 .50201 L
.50168 .50209 L
.50123 .50206 L
.5008 .50196 L
.5004 .5018 L
.50006 .50159 L
.49977 .50135 L
.49953 .5011 L
.49935 .50084 L
.49923 .50059 L
.49915 .50036 L
.49913 .50015 L
.49914 .49996 L
.49918 .49981 L
.49925 .49969 L
.49934 .4996 L
.49944 .49955 L
.49955 .49952 L
.49965 .49951 L
.49976 .49952 L
.49986 .49955 L
.49994 .4996 L
.50002 .49965 L
.50008 .49971 L
.50013 .49977 L
.50017 .49983 L
.50019 .49989 L
.5002 .49994 L
.50021 .49999 L
.5002 .50003 L
.50019 .50006 L
.50017 .50008 L
.50014 .5001 L
.50012 .50011 L
.50009 .50012 L
.50007 .50011 L
.50005 .50011 L
.50002 .5001 L
.5 .50009 L
Mistroke
.49999 .50008 L
.49997 .50006 L
.49996 .50005 L
.49996 .50003 L
.49995 .50002 L
.49995 .50001 L
.49995 .5 L
.49995 .49999 L
.49996 .49998 L
.49996 .49998 L
.49997 .49998 L
.49997 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-9.3471394 6.3203688 -10.093187 3.6243742 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-10.315839 1.2162649 -10.090218 -0.85387738 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.5788312 -5.553475 -1.4555188 -5.1502628 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
2.4134733 -0.58070118 2.4146285 -0.049824667 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
0.75795292 1.3401109 0.48100591 1.2675201 MAarrowhead1
% End of user PostScript
.581 1 0 r
.22158 .60548 m
.21444 .53819 L
s
% Start of user PostScript
-0.55683442 0.2109528 -0.57112125 0.076370202 MAarrowhead1
% End of user PostScript
.266 1 0 r
.39247 .3401 m
.42626 .34565 L
s
% Start of user PostScript
-0.21506146 -0.31980186 -0.14748948 -0.30870547 MAarrowhead1
% End of user PostScript
0 1 .049 r
.56322 .46591 m
.56669 .48278 L
s
% Start of user PostScript
0.12644055 -0.06818894 0.13337996 -0.034440266 MAarrowhead1
% End of user PostScript
0 1 .364 r
.52971 .53771 m
.52156 .53719 L
s
% Start of user PostScript
0.059426115 0.075414656 0.043113915 0.074384592 MAarrowhead1
% End of user PostScript
0 1 .679 r
.48591 .51031 m
.48464 .50613 L
s
% Start of user PostScript
-0.028175375 0.020628018 -0.030711329 0.012253619 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49196 .49122 m
.49391 .49114 L
s
% Start of user PostScript
-0.016078797 -0.017554109 -0.012184471 -0.017723493 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50307 .49701 m
.50348 .49804 L
s
% Start of user PostScript
0.0061350463 -0.0059743115 0.006957295 -0.003917774 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50214 .50201 m
.50168 .50209 L
s
% Start of user PostScript
0.0042751597 0.0040267392 0.0033564023 0.0041724838 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49935 .50084 m
.49923 .50059 L
s
% Start of user PostScript
-0.0012967392 0.0016768319 -0.001545954 0.0011770646 MAarrowhead1
% End of user PostScript
1 .11 0 r
.73834 0 m
.75152 .01547 L
.82887 .13744 L
.88065 .25433 L
.9089 .36228 L
.91626 .45841 L
.90579 .54076 L
.88078 .60827 L
.84455 .66061 L
.80036 .69812 L
.75126 .72169 L
.69999 .7326 L
.64895 .73247 L
.60015 .72306 L
.55518 .70624 L
.51523 .68387 L
.48107 .65774 L
.45316 .6295 L
.43161 .60061 L
.41624 .57234 L
.4067 .54571 L
.40242 .52153 L
.40272 .50038 L
.40687 .4826 L
.41408 .46837 L
.42356 .45769 L
.43458 .45042 L
.44645 .4463 L
.45855 .44499 L
.47037 .44608 L
.48147 .44916 L
.49154 .45378 L
.50032 .4595 L
.50769 .46593 L
.51356 .47268 L
.51795 .47945 L
.52091 .48595 L
.52257 .49196 L
.52305 .49734 L
.52254 .50195 L
.5212 .50575 L
.51924 .50871 L
.51682 .51085 L
.51411 .5122 L
.51128 .51286 L
.50845 .51289 L
.50573 .5124 L
.50323 .5115 L
.50099 .51028 L
.49908 .50884 L
Mistroke
.49751 .50728 L
.49629 .50569 L
.49541 .50412 L
.49486 .50263 L
.49461 .50128 L
.49461 .5001 L
.49482 .4991 L
.49521 .4983 L
.49573 .49769 L
.49633 .49728 L
.49699 .49704 L
.49766 .49695 L
.49831 .49701 L
.49893 .49717 L
.49949 .49742 L
.49999 .49773 L
.5004 .49809 L
.50073 .49846 L
.50098 .49884 L
.50115 .4992 L
.50125 .49953 L
.50128 .49983 L
.50125 .50009 L
.50118 .5003 L
.50107 .50047 L
.50094 .50059 L
.50079 .50067 L
.50064 .50071 L
.50048 .50071 L
.50033 .50069 L
.50019 .50064 L
.50006 .50057 L
.49996 .5005 L
.49987 .50041 L
.4998 .50032 L
.49975 .50023 L
.49972 .50015 L
.4997 .50008 L
.4997 .50001 L
.49971 .49995 L
.49973 .49991 L
.49976 .49987 L
.49979 .49985 L
.49983 .49984 L
.49987 .49983 L
.4999 .49983 L
.49994 .49984 L
.49997 .49986 L
.5 .49987 L
.50002 .49989 L
Mistroke
.50004 .49991 L
.50005 .49993 L
.50006 .49995 L
.50007 .49997 L
.50007 .49999 L
.50007 .5 L
.50007 .50002 L
.50006 .50003 L
.50005 .50003 L
.50004 .50004 L
.50004 .50004 L
.50003 .50004 L
.50002 .50004 L
.50001 .50004 L
.5 .50003 L
.5 .50003 L
.49999 .50002 L
.49999 .50002 L
.49999 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
1.8826435 7.3978052 0.45357582 6.5778837 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-0.76420346 5.6265473 -1.7559166 4.6029372 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-3.0815578 -1.1747346 -2.7340128 -1.5513681 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
0.032652103 -1.446882 0.29477681 -1.2135048 MAarrowhead1
% End of user PostScript
.897 1 0 r
.88078 .60827 m
.84455 .66061 L
s
% Start of user PostScript
0.76155364 0.21653419 0.68910266 0.32121 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51523 .68387 m
.48107 .65774 L
s
% Start of user PostScript
0.030450904 0.3677443 -0.037851246 0.31548641 MAarrowhead1
% End of user PostScript
.266 1 0 r
.40687 .4826 m
.41408 .46837 L
s
% Start of user PostScript
-0.18625727 -0.034804167 -0.17184432 -0.063258973 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49154 .45378 m
.50032 .4595 L
s
% Start of user PostScript
-0.016925941 -0.092444264 0.00064585565 -0.080996254 MAarrowhead1
% End of user PostScript
0 1 .364 r
.52254 .50195 m
.5212 .50575 L
s
% Start of user PostScript
0.045074731 0.0039087824 0.04240894 0.011504442 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50323 .5115 m
.50099 .51028 L
s
% Start of user PostScript
0.0064527849 0.022994096 0.0019848554 0.020555075 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49461 .5001 m
.49482 .4991 L
s
% Start of user PostScript
-0.01078905 0.00019864722 -0.010357565 -0.0017977321 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49893 .49717 m
.49949 .49742 L
s
% Start of user PostScript
-0.0021367126 -0.005660231 -0.0010131196 -0.0051597092 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50128 .49983 m
.50125 .50009 L
s
% Start of user PostScript
0.0025525187 -0.00033515714 0.0025029225 0.00018244945 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50033 .50069 m
.50019 .50064 L
s
% Start of user PostScript
0.0006559577 0.0013788508 0.00037637559 0.0012815929 MAarrowhead1
% End of user PostScript
1 0 .08 r
.56769 1 m
.47542 .93536 L
.39719 .86245 L
.33563 .78675 L
.29052 .71174 L
.26104 .6403 L
.24584 .57472 L
.24325 .51669 L
.25134 .4673 L
.26807 .42714 L
.2914 .39635 L
.31932 .37465 L
.34998 .36144 L
.38172 .3559 L
.4131 .357 L
.44291 .36365 L
.47022 .37468 L
.49433 .38896 L
.51481 .40538 L
.5314 .42295 L
.54407 .44078 L
.55295 .45812 L
.55828 .47434 L
.56043 .48899 L
.55981 .50173 L
.55691 .51235 L
.55219 .52078 L
.54614 .52702 L
.53922 .53117 L
.53184 .53342 L
.52438 .53397 L
.51713 .53307 L
.51037 .53099 L
.50427 .52801 L
.49899 .52438 L
.49459 .52037 L
.49112 .51618 L
.48855 .51202 L
.48686 .50804 L
.48596 .50439 L
.48577 .50114 L
.48618 .49837 L
.48708 .49611 L
.48835 .49437 L
.48988 .49313 L
.49157 .49237 L
.49332 .49203 L
.49507 .49207 L
.49672 .49242 L
.49825 .49301 L
Mistroke
.4996 .49379 L
.50074 .49469 L
.50168 .49566 L
.5024 .49665 L
.5029 .49761 L
.50321 .49852 L
.50334 .49934 L
.50332 .50005 L
.50317 .50065 L
.50291 .50112 L
.50258 .50147 L
.5022 .50171 L
.50179 .50184 L
.50138 .50188 L
.50098 .50184 L
.5006 .50173 L
.50026 .50156 L
.49996 .50137 L
.49972 .50114 L
.49952 .50091 L
.49937 .50068 L
.49928 .50046 L
.49923 .50026 L
.49921 .50008 L
.49923 .49992 L
.49928 .49979 L
.49935 .49969 L
.49943 .49962 L
.49953 .49958 L
.49962 .49956 L
.49972 .49956 L
.49981 .49958 L
.4999 .49961 L
.49997 .49965 L
.50004 .4997 L
.50009 .49976 L
.50013 .49981 L
.50016 .49986 L
.50018 .49991 L
.50018 .49996 L
.50018 .5 L
.50018 .50003 L
.50016 .50006 L
.50014 .50008 L
.50012 .50009 L
.5001 .5001 L
.50008 .5001 L
.50006 .5001 L
.50003 .5001 L
.50002 .50009 L
Mistroke
.5 .50008 L
.49999 .50006 L
.49997 .50005 L
.49997 .50004 L
.49996 .50003 L
.49996 .50001 L
.49996 .5 L
.49996 .5 L
.49996 .49999 L
.49996 .49998 L
.49997 .49998 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-7.6625927 7.4571029 -8.6887084 4.8892585 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-9.2026295 2.5381435 -9.2660337 0.46298395 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-3.0592052 -5.1545332 -1.9877349 -4.901526 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
2.1146724 -0.88650264 2.1844794 -0.36198298 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
0.86130484 1.2262722 0.60061284 1.1904002 MAarrowhead1
% End of user PostScript
.581 1 0 r
.26104 .6403 m
.24584 .57472 L
s
% Start of user PostScript
-0.47792574 0.28060703 -0.50832006 0.14944845 MAarrowhead1
% End of user PostScript
.266 1 0 r
.38172 .3559 m
.4131 .357 L
s
% Start of user PostScript
-0.23655824 -0.28820801 -0.17380907 -0.28599323 MAarrowhead1
% End of user PostScript
0 1 .049 r
.55295 .45812 m
.55828 .47434 L
s
% Start of user PostScript
0.10589507 -0.083768132 0.1165627 -0.051312849 MAarrowhead1
% End of user PostScript
0 1 .364 r
.53184 .53342 m
.52438 .53397 L
s
% Start of user PostScript
0.063688414 0.06683605 0.048753995 0.067930774 MAarrowhead1
% End of user PostScript
0 1 .679 r
.48855 .51202 m
.48686 .50804 L
s
% Start of user PostScript
-0.022893428 0.02403608 -0.026279092 0.016088053 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49157 .49237 m
.49332 .49203 L
s
% Start of user PostScript
-0.016862821 -0.015266345 -0.013351212 -0.015938139 MAarrowhead1
% End of user PostScript
0 .69 1 r
.5024 .49665 m
.5029 .49761 L
s
% Start of user PostScript
0.0047928953 -0.006699064 0.0058053305 -0.0047730694 MAarrowhead1
% End of user PostScript
0 .375 1 r
.5022 .50171 m
.50179 .50184 L
s
% Start of user PostScript
0.0044006408 0.0034259414 0.0035858756 0.0036889787 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49952 .50091 m
.49937 .50068 L
s
% Start of user PostScript
-0.00095942475 0.0018251784 -0.0012502813 0.0013635327 MAarrowhead1
% End of user PostScript
1 0 .31 r
.7024 0 m
.70971 .00789 L
.79026 .12344 L
.84627 .2355 L
.87943 .34014 L
.8921 .43438 L
.88706 .51611 L
.86735 .58408 L
.83611 .63778 L
.79644 .67734 L
.75129 .70346 L
.70334 .71725 L
.65496 .72014 L
.60814 .71376 L
.56452 .69986 L
.52532 .68019 L
.4914 .65648 L
.46327 .63032 L
.44113 .60315 L
.42489 .57621 L
.41427 .55055 L
.40878 .52699 L
.40781 .50613 L
.41069 .48838 L
.41668 .47394 L
.42504 .46286 L
.43506 .45504 L
.44606 .45028 L
.45745 .44827 L
.46872 .44865 L
.47943 .45103 L
.48924 .45498 L
.49791 .46009 L
.50527 .46599 L
.51123 .47229 L
.51579 .47869 L
.51899 .48492 L
.52091 .49075 L
.52169 .49601 L
.52148 .50059 L
.52044 .50441 L
.51875 .50744 L
.51658 .50969 L
.5141 .51118 L
.51145 .51199 L
.50877 .51219 L
.50617 .51188 L
.50374 .51113 L
.50155 .51006 L
.49965 .50876 L
Mistroke
.49807 .50732 L
.49682 .50582 L
.4959 .50433 L
.49529 .5029 L
.49496 .50158 L
.49489 .50042 L
.49504 .49942 L
.49536 .49861 L
.49581 .49798 L
.49636 .49754 L
.49697 .49726 L
.4976 .49714 L
.49822 .49715 L
.49882 .49728 L
.49937 .49749 L
.49985 .49777 L
.50026 .49809 L
.5006 .49844 L
.50086 .49879 L
.50104 .49914 L
.50115 .49947 L
.5012 .49976 L
.50119 .50002 L
.50114 .50023 L
.50105 .5004 L
.50093 .50053 L
.50079 .50061 L
.50064 .50066 L
.5005 .50068 L
.50035 .50066 L
.50022 .50062 L
.50009 .50056 L
.49999 .50049 L
.4999 .50041 L
.49983 .50033 L
.49978 .50025 L
.49974 .50017 L
.49972 .50009 L
.49972 .50003 L
.49972 .49997 L
.49974 .49993 L
.49977 .49989 L
.4998 .49987 L
.49983 .49985 L
.49986 .49984 L
.4999 .49984 L
.49993 .49985 L
.49996 .49986 L
.49999 .49988 L
.50001 .49989 L
Mistroke
.50003 .49991 L
.50005 .49993 L
.50006 .49995 L
.50006 .49997 L
.50007 .49999 L
.50007 .5 L
.50006 .50001 L
.50006 .50002 L
.50005 .50003 L
.50004 .50003 L
.50004 .50004 L
.50003 .50004 L
.50002 .50004 L
.50001 .50003 L
.50001 .50003 L
.5 .50003 L
.49999 .50002 L
.49999 .50002 L
.49999 .50001 L
.49999 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
3.7882809 7.6940238 2.2226561 7.1746402 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
0.81949812 6.4517282 -0.39116422 5.586872 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-3.2139557 -0.46167243 -2.9905513 -0.97450485 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.3645777 -1.6143179 -0.054737112 -1.4269749 MAarrowhead1
% End of user PostScript
.897 1 0 r
.88706 .51611 m
.86735 .58408 L
s
% Start of user PostScript
0.77411931 0.032229942 0.73469346 0.16816459 MAarrowhead1
% End of user PostScript
.581 1 0 r
.56452 .69986 m
.52532 .68019 L
s
% Start of user PostScript
0.12904187 0.39971539 0.050642816 0.36038979 MAarrowhead1
% End of user PostScript
.266 1 0 r
.40781 .50613 m
.41069 .48838 L
s
% Start of user PostScript
-0.18437134 0.012261102 -0.17861277 -0.023248203 MAarrowhead1
% End of user PostScript
0 1 .049 r
.47943 .45103 m
.48924 .45498 L
s
% Start of user PostScript
-0.041142824 -0.097948702 -0.021518712 -0.090046417 MAarrowhead1
% End of user PostScript
0 1 .364 r
.52169 .49601 m
.52148 .50059 L
s
% Start of user PostScript
0.043385304 -0.0079756649 0.042957417 0.0011803477 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50617 .51188 m
.50374 .51113 L
s
% Start of user PostScript
0.01233918 0.023750617 0.0074783007 0.022264849 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49496 .50158 m
.49489 .50042 L
s
% Start of user PostScript
-0.010074837 0.0031675642 -0.010215079 0.00083460149 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49822 .49715 m
.49882 .49728 L
s
% Start of user PostScript
-0.0035521704 -0.0056966836 -0.0023605827 -0.0054482482 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50115 .49947 m
.5012 .49976 L
s
% Start of user PostScript
0.0023048327 -0.001069126 0.0023996605 -0.00048126405 MAarrowhead1
% End of user PostScript
0 .06 1 r
.5005 .50068 m
.50035 .50066 L
s
% Start of user PostScript
0.00099248274 0.0013507317 0.00070343515 0.0013191896 MAarrowhead1
% End of user PostScript
.867 1 0 r
.80132 0 m
.83375 .04528 L
.90211 .17755 L
.94341 .30148 L
.96035 .41345 L
.95616 .5109 L
.9344 .59227 L
.89877 .65689 L
.8529 .70486 L
.80029 .73694 L
.74412 .75439 L
.6872 .75887 L
.63193 .75228 L
.58026 .73665 L
.53368 .71407 L
.49323 .68656 L
.45954 .656 L
.43288 .62411 L
.41318 .59238 L
.40012 .56204 L
.39315 .5341 L
.39157 .50928 L
.39458 .48807 L
.40132 .47074 L
.41093 .45737 L
.42256 .44785 L
.43541 .44194 L
.44879 .4393 L
.46206 .43951 L
.47473 .44211 L
.48636 .44661 L
.49668 .45252 L
.50547 .45938 L
.51264 .46676 L
.51814 .47428 L
.52204 .48163 L
.52443 .48853 L
.52546 .49479 L
.52531 .50024 L
.52417 .50481 L
.52224 .50846 L
.51974 .51118 L
.51684 .51302 L
.51374 .51404 L
.51059 .51434 L
.50752 .51401 L
.50464 .51318 L
.50204 .51195 L
.49977 .51045 L
.49788 .50876 L
Mistroke
.49638 .507 L
.49526 .50524 L
.49451 .50355 L
.4941 .50199 L
.49399 .50061 L
.49414 .49942 L
.4945 .49844 L
.49503 .49769 L
.49566 .49714 L
.49637 .4968 L
.49711 .49664 L
.49785 .49665 L
.49855 .49678 L
.4992 .49702 L
.49978 .49735 L
.50027 .49772 L
.50067 .49813 L
.50099 .49855 L
.50121 .49895 L
.50135 .49934 L
.50141 .49969 L
.5014 .49999 L
.50134 .50025 L
.50124 .50046 L
.5011 .50061 L
.50094 .50071 L
.50077 .50077 L
.5006 .50079 L
.50043 .50078 L
.50027 .50073 L
.50012 .50067 L
.5 .50058 L
.49989 .50049 L
.4998 .50039 L
.49974 .5003 L
.4997 .5002 L
.49967 .50012 L
.49967 .50004 L
.49967 .49997 L
.49969 .49992 L
.49972 .49987 L
.49976 .49984 L
.4998 .49982 L
.49984 .49981 L
.49988 .49981 L
.49992 .49982 L
.49995 .49983 L
.49999 .49985 L
.50001 .49987 L
.50004 .49989 L
Mistroke
.50005 .49992 L
.50007 .49994 L
.50007 .49996 L
.50008 .49998 L
.50008 .5 L
.50007 .50001 L
.50007 .50002 L
.50006 .50003 L
.50005 .50004 L
.50004 .50004 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50001 .50004 L
.5 .50003 L
.49999 .50003 L
.49999 .50002 L
.49999 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-0.88127131 -2.0815642 -0.46392802 -1.9148888 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-0.095033918 -1.6983963 0.2184372 -1.4487417 MAarrowhead1
% End of user PostScript
1 .473 0 r
.9344 .59227 m
.89877 .65689 L
s
% Start of user PostScript
0.86880631 0.18454793 0.79753238 0.31378691 MAarrowhead1
% End of user PostScript
1 .788 0 r
.53368 .71407 m
.49323 .68656 L
s
% Start of user PostScript
0.067360396 0.42814978 -0.013544115 0.37311981 MAarrowhead1
% End of user PostScript
.897 1 0 r
.39458 .48807 m
.40132 .47074 L
s
% Start of user PostScript
-0.21083937 -0.023862458 -0.19735383 -0.058514618 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48636 .44661 m
.49668 .45252 L
s
% Start of user PostScript
-0.027270537 -0.10678688 -0.0066379254 -0.094968609 MAarrowhead1
% End of user PostScript
.266 1 0 r
.52531 .50024 m
.52417 .50481 L
s
% Start of user PostScript
0.050613599 0.00048545262 0.048331254 0.009628081 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50464 .51318 m
.50204 .51195 L
s
% Start of user PostScript
0.0092837664 0.026357864 0.0040804355 0.023905749 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49399 .50061 m
.49414 .49942 L
s
% Start of user PostScript
-0.012011789 0.0012128961 -0.011712041 -0.0011656229 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49855 .49678 m
.4992 .49702 L
s
% Start of user PostScript
-0.0028966435 -0.0064384473 -0.0015983632 -0.0059540171 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50141 .49969 m
.5014 .49999 L
s
% Start of user PostScript
0.0028156215 -0.00062461309 0.0028073433 -0.000013585585 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50043 .50078 m
.50027 .50073 L
s
% Start of user PostScript
0.00085665638 0.0015561222 0.00053608586 0.0014675557 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49967 .50012 m
.49967 .50004 L
s
% Start of user PostScript
-0.00065101267 0.0002327025 -0.00066517877 0.0000775472 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49988 .49981 m
.49992 .49982 L
s
% Start of user PostScript
-0.00024416292 -0.00037196999 -0.00016582742 -0.00035797412 MAarrowhead1
% End of user PostScript
0 1 .13 r
.25191 0 m
.28716 .00739 L
.38611 .04606 L
.47373 .09667 L
.54833 .15528 L
.60903 .21827 L
.65562 .28241 L
.6885 .34496 L
.70857 .40366 L
.71708 .4568 L
.71554 .50313 L
.70563 .54189 L
.68908 .57276 L
.66763 .59577 L
.64292 .61125 L
.61647 .61979 L
.5896 .62218 L
.56346 .61929 L
.53898 .6121 L
.51687 .60158 L
.49764 .58869 L
.48159 .57432 L
.46885 .55928 L
.4594 .54429 L
.4531 .52993 L
.44968 .51669 L
.44882 .5049 L
.45015 .4948 L
.45325 .48654 L
.45773 .48014 L
.46318 .47556 L
.46923 .4727 L
.47553 .47139 L
.48181 .47143 L
.4878 .4726 L
.49332 .47469 L
.49822 .47745 L
.5024 .48067 L
.50582 .48415 L
.50846 .4877 L
.51033 .49117 L
.51149 .49444 L
.512 .49741 L
.51196 .5 L
.51144 .50218 L
.51054 .50392 L
.50937 .50522 L
.50802 .50611 L
.50656 .50661 L
.50507 .50677 L
Mistroke
.50362 .50662 L
.50225 .50624 L
.50102 .50567 L
.49994 .50496 L
.49904 .50417 L
.49832 .50334 L
.49778 .50251 L
.49742 .50171 L
.49722 .50097 L
.49717 .50032 L
.49723 .49975 L
.4974 .49928 L
.49764 .49892 L
.49794 .49866 L
.49827 .4985 L
.49862 .49842 L
.49897 .49842 L
.4993 .49848 L
.49961 .49859 L
.49988 .49874 L
.50012 .49892 L
.50031 .49911 L
.50046 .4993 L
.50057 .4995 L
.50063 .49968 L
.50066 .49985 L
.50066 .49999 L
.50064 .50011 L
.50059 .50021 L
.50052 .50028 L
.50045 .50034 L
.50037 .50036 L
.50029 .50037 L
.50021 .50037 L
.50013 .50035 L
.50006 .50032 L
.5 .50028 L
.49995 .50023 L
.49991 .50019 L
.49988 .50014 L
.49986 .5001 L
.49985 .50006 L
.49984 .50002 L
.49985 .49999 L
.49986 .49996 L
.49987 .49994 L
.49988 .49993 L
.4999 .49992 L
.49992 .49991 L
.49994 .49991 L
Mistroke
.49996 .49992 L
.49998 .49992 L
.49999 .49993 L
.50001 .49994 L
.50002 .49995 L
.50002 .49996 L
.50003 .49997 L
.50003 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50003 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
7.5701821 -3.3340443 7.8493154 -1.4311197 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
7.7697439 0.22353377 7.3922374 1.6036052 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.347363 4.0256772 0.55570883 3.6383097 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.847875 0.14840841 -1.7948076 -0.21149763 MAarrowhead1
% End of user PostScript
.897 1 0 r
.28716 .00739 m
.38611 .04606 L
s
% Start of user PostScript
-0.42568093 -0.9852165 -0.22777843 -0.90788908 MAarrowhead1
% End of user PostScript
.581 1 0 r
.71708 .4568 m
.71554 .50313 L
s
% Start of user PostScript
0.43415867 -0.08640788 0.43107804 0.0062533965 MAarrowhead1
% End of user PostScript
.266 1 0 r
.56346 .61929 m
.53898 .6121 L
s
% Start of user PostScript
0.12692193 0.23858277 0.077964018 0.22419885 MAarrowhead1
% End of user PostScript
0 1 .049 r
.44968 .51669 m
.44882 .5049 L
s
% Start of user PostScript
-0.10064526 0.033370246 -0.10236081 0.0097930315 MAarrowhead1
% End of user PostScript
0 1 .364 r
.48181 .47143 m
.4878 .4726 L
s
% Start of user PostScript
-0.036387009 -0.057146645 -0.024400873 -0.054791638 MAarrowhead1
% End of user PostScript
0 1 .679 r
.51149 .49444 m
.512 .49741 L
s
% Start of user PostScript
0.022979153 -0.011118235 0.0240082 -0.0051851008 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50507 .50677 m
.50362 .50662 L
s
% Start of user PostScript
0.010134712 0.013530071 0.0072309936 0.013249302 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49742 .50171 m
.49722 .50097 L
s
% Start of user PostScript
-0.0051541961 0.0034257797 -0.0055547629 0.0019484915 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49862 .49842 m
.49897 .49842 L
s
% Start of user PostScript
-0.0027597762 -0.0031632729 -0.0020639801 -0.0031687253 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50057 .4995 m
.50063 .49968 L
s
% Start of user PostScript
0.0011314797 -0.0010047164 0.0012654365 -0.00064069728 MAarrowhead1
% End of user PostScript
0 1 .908 r
.22774 1 m
.16421 .905 L
.10499 .78017 L
.07108 .66419 L
.05977 .56025 L
.06788 .4706 L
.09196 .39651 L
.1285 .33846 L
.17403 .29618 L
.22528 .26885 L
.27929 .25514 L
.33346 .25343 L
.38559 .26185 L
.43392 .27845 L
.47714 .30124 L
.51434 .32832 L
.54499 .35791 L
.56892 .38844 L
.58625 .41853 L
.59735 .44705 L
.60277 .4731 L
.60322 .49605 L
.59946 .51547 L
.59234 .53116 L
.58266 .54308 L
.57123 .55136 L
.55879 .55626 L
.54599 .55813 L
.53341 .55737 L
.52151 .55443 L
.51067 .5498 L
.50113 .54391 L
.49309 .53722 L
.48661 .53011 L
.4817 .52293 L
.47832 .516 L
.47635 .50953 L
.47563 .50373 L
.47601 .4987 L
.47729 .49454 L
.47927 .49126 L
.48176 .48886 L
.48458 .48729 L
.48756 .48648 L
.49057 .48634 L
.49346 .48677 L
.49616 .48765 L
.49857 .4889 L
.50066 .49038 L
.50238 .49201 L
Mistroke
.50373 .4937 L
.50472 .49537 L
.50536 .49696 L
.50568 .49841 L
.50572 .4997 L
.50553 .50079 L
.50515 .50167 L
.50462 .50234 L
.50399 .50282 L
.50331 .5031 L
.5026 .50322 L
.5019 .50318 L
.50124 .50303 L
.50063 .50278 L
.5001 .50246 L
.49965 .50209 L
.49928 .5017 L
.499 .5013 L
.49881 .50091 L
.4987 .50055 L
.49865 .50023 L
.49867 .49995 L
.49874 .49971 L
.49884 .49953 L
.49898 .49939 L
.49913 .4993 L
.4993 .49925 L
.49947 .49924 L
.49963 .49926 L
.49978 .49931 L
.49991 .49938 L
.50003 .49946 L
.50013 .49955 L
.5002 .49964 L
.50026 .49974 L
.50029 .49983 L
.50031 .49991 L
.50032 .49998 L
.50031 .50004 L
.50029 .50009 L
.50026 .50013 L
.50022 .50015 L
.50019 .50017 L
.50015 .50018 L
.50011 .50018 L
.50007 .50017 L
.50004 .50015 L
.50001 .50014 L
.49998 .50012 L
.49996 .5001 L
Mistroke
.49995 .50007 L
.49993 .50005 L
.49993 .50003 L
.49993 .50001 L
.49993 .5 L
.49993 .49998 L
.49994 .49997 L
.49994 .49997 L
.49995 .49996 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49999 .49996 L
.49999 .49997 L
.5 .49997 L
.50001 .49997 L
.50001 .49998 L
.50001 .49999 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-2.267436 -7.950615 -0.72099826 -7.1138869 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
0.6060023 -6.1270074 1.6957284 -5.0535472 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.3130323 1.1611398 2.9579299 1.5820718 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
0.018062764 1.5696066 -0.26861373 1.3261762 MAarrowhead1
% End of user PostScript
.897 1 0 r
.09196 .39651 m
.1285 .33846 L
s
% Start of user PostScript
-0.81607049 -0.20697701 -0.74299717 -0.32308497 MAarrowhead1
% End of user PostScript
.581 1 0 r
.47714 .30124 m
.51434 .32832 L
s
% Start of user PostScript
-0.045713313 -0.39752462 0.0286747 -0.34336563 MAarrowhead1
% End of user PostScript
.266 1 0 r
.59946 .51547 m
.59234 .53116 L
s
% Start of user PostScript
0.19892932 0.030941756 0.18467059 0.06231181 MAarrowhead1
% End of user PostScript
0 1 .049 r
.51067 .5498 m
.50113 .54391 L
s
% Start of user PostScript
0.021330281 0.099592725 0.0022655266 0.087823297 MAarrowhead1
% End of user PostScript
0 1 .364 r
.47601 .4987 m
.47729 .49454 L
s
% Start of user PostScript
-0.047976945 -0.0025949098 -0.045424665 -0.010925711 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49616 .48765 m
.49857 .4889 L
s
% Start of user PostScript
-0.0076856126 -0.024690458 -0.0028552633 -0.022209343 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50572 .4997 m
.50553 .50079 L
s
% Start of user PostScript
0.011442398 -0.00060840927 0.011057227 0.0015713819 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50124 .50303 m
.50063 .50278 L
s
% Start of user PostScript
0.0024737563 0.0060578318 0.0012631332 0.0055562029 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49865 .50023 m
.49867 .49995 L
s
% Start of user PostScript
-0.0026965918 0.00045630521 -0.0026628169 -0.00010658615 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49963 .49926 m
.49978 .49931 L
s
% Start of user PostScript
-0.00074635573 -0.0014707729 -0.00044611217 -0.0013755316 MAarrowhead1
% End of user PostScript
1 .003 0 r
.82951 0 m
.86846 .05845 L
.93291 .19497 L
.9697 .32177 L
.98181 .43534 L
.9727 .53326 L
.94615 .61413 L
.90603 .67745 L
.8561 .72352 L
.79996 .75324 L
.74083 .76807 L
.68156 .7698 L
.62455 .76046 L
.57171 .74221 L
.52448 .7172 L
.48386 .68752 L
.45041 .6551 L
.42431 .62169 L
.40542 .58877 L
.39335 .55759 L
.38748 .52911 L
.38706 .50404 L
.39122 .48284 L
.39906 .46572 L
.40968 .45272 L
.4222 .4437 L
.43583 .43838 L
.44984 .43638 L
.4636 .43724 L
.47661 .44048 L
.48846 .44557 L
.49888 .45203 L
.50766 .45936 L
.51473 .46715 L
.52008 .47499 L
.52376 .48258 L
.52591 .48965 L
.52667 .49599 L
.52624 .50148 L
.52483 .50603 L
.52266 .5096 L
.51993 .51222 L
.51684 .51393 L
.51357 .51481 L
.51029 .51495 L
.50712 .51448 L
.50417 .5135 L
.50153 .51213 L
.49926 .51051 L
.49737 .50872 L
Mistroke
.4959 .50687 L
.49483 .50504 L
.49413 .50331 L
.49378 .50172 L
.49374 .50032 L
.49395 .49913 L
.49437 .49816 L
.49495 .49743 L
.49564 .49691 L
.49639 .4966 L
.49717 .49648 L
.49793 .49652 L
.49865 .49669 L
.49932 .49696 L
.4999 .49732 L
.50039 .49772 L
.50079 .49815 L
.50109 .49858 L
.5013 .49901 L
.50143 .4994 L
.50148 .49975 L
.50146 .50006 L
.50138 .50032 L
.50126 .50052 L
.50112 .50067 L
.50095 .50077 L
.50076 .50082 L
.50058 .50083 L
.50041 .5008 L
.50024 .50075 L
.50009 .50068 L
.49997 .50059 L
.49986 .50049 L
.49978 .50039 L
.49972 .50029 L
.49968 .50019 L
.49966 .5001 L
.49965 .50002 L
.49966 .49996 L
.49969 .4999 L
.49972 .49986 L
.49976 .49983 L
.4998 .49981 L
.49984 .49981 L
.49988 .49981 L
.49992 .49982 L
.49996 .49983 L
.49999 .49985 L
.50002 .49987 L
.50004 .4999 L
Mistroke
.50006 .49992 L
.50007 .49994 L
.50008 .49997 L
.50008 .49999 L
.50008 .5 L
.50008 .50002 L
.50007 .50003 L
.50006 .50004 L
.50005 .50004 L
.50004 .50005 L
.50003 .50005 L
.50002 .50004 L
.50001 .50004 L
.50001 .50004 L
.5 .50003 L
.49999 .50003 L
.49999 .50002 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
4.3555137 9.3712394 2.4598076 8.6915385 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
0.77007681 7.7733867 -0.6791747 6.6917823 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-3.9132914 -0.66969661 -3.621683 -1.2772099 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.38774774 -1.9507522 -0.01562351 -1.7147467 MAarrowhead1
% End of user PostScript
.897 1 0 r
.9727 .53326 m
.94615 .61413 L
s
% Start of user PostScript
0.94540193 0.066518545 0.89230613 0.22826151 MAarrowhead1
% End of user PostScript
.581 1 0 r
.57171 .74221 m
.52448 .7172 L
s
% Start of user PostScript
0.14341528 0.48441264 0.04896614 0.43439183 MAarrowhead1
% End of user PostScript
.266 1 0 r
.38706 .50404 m
.39122 .48284 L
s
% Start of user PostScript
-0.22588242 0.0080877807 -0.21756434 -0.034326507 MAarrowhead1
% End of user PostScript
0 1 .049 r
.47661 .44048 m
.48846 .44557 L
s
% Start of user PostScript
-0.04678599 -0.11904578 -0.023074572 -0.10885519 MAarrowhead1
% End of user PostScript
0 1 .364 r
.52667 .49599 m
.52624 .50148 L
s
% Start of user PostScript
0.053336502 -0.0080131678 0.052484096 0.0029612851 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50712 .51448 m
.50417 .5135 L
s
% Start of user PostScript
0.014233883 0.028951197 0.0083436232 0.026993078 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49378 .50172 m
.49374 .50032 L
s
% Start of user PostScript
-0.012432979 0.0034397445 -0.01252058 0.00063447867 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49793 .49652 m
.49865 .49669 L
s
% Start of user PostScript
-0.0041386219 -0.0069653698 -0.0026905307 -0.0066243328 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50143 .4994 m
.50148 .49975 L
s
% Start of user PostScript
0.0028566935 -0.0012003874 0.0029515085 -0.00049137514 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50058 .50083 m
.50041 .5008 L
s
% Start of user PostScript
0.001165001 0.0016569496 0.00081269977 0.0016086973 MAarrowhead1
% End of user PostScript
1 0 .031 r
1 .94906 m
.8995 .96957 L
.79665 .96853 L
.69845 .94892 L
.60808 .9145 L
.5279 .86903 L
.45947 .81611 L
.40365 .75904 L
.36065 .70077 L
.33012 .64383 L
.31128 .59028 L
.30302 .54172 L
.30396 .49928 L
.31259 .46369 L
.32733 .43526 L
.3466 .41398 L
.36892 .39956 L
.3929 .39148 L
.41731 .38903 L
.4411 .39141 L
.46344 .39775 L
.48364 .40716 L
.50126 .41878 L
.516 .43177 L
.52774 .44541 L
.53648 .45904 L
.54236 .47213 L
.5456 .48422 L
.54649 .49501 L
.54539 .50426 L
.54264 .51186 L
.53864 .51776 L
.53373 .52201 L
.52826 .52469 L
.52253 .52596 L
.51683 .52598 L
.51137 .52496 L
.50633 .52311 L
.50184 .52063 L
.49801 .51772 L
.49487 .51457 L
.49243 .51135 L
.49069 .50819 L
.48961 .5052 L
.48911 .50249 L
.48913 .50012 L
.48958 .49812 L
.49037 .49652 L
.49142 .49531 L
.49265 .49448 L
Mistroke
.49397 .49401 L
.49532 .49386 L
.49665 .49397 L
.49789 .49431 L
.49902 .49482 L
.5 .49545 L
.50083 .49617 L
.50149 .49692 L
.50199 .49768 L
.50233 .49841 L
.50252 .49908 L
.50257 .49968 L
.50252 .5002 L
.50237 .50063 L
.50216 .50096 L
.50189 .5012 L
.50159 .50136 L
.50127 .50143 L
.50095 .50144 L
.50065 .50139 L
.50037 .50129 L
.50012 .50115 L
.4999 .50099 L
.49973 .50082 L
.49959 .50064 L
.49949 .50047 L
.49943 .5003 L
.4994 .50015 L
.4994 .50002 L
.49942 .4999 L
.49946 .49981 L
.49952 .49974 L
.49959 .4997 L
.49966 .49967 L
.49974 .49966 L
.49981 .49967 L
.49988 .49968 L
.49994 .49971 L
.5 .49975 L
.50004 .49978 L
.50008 .49983 L
.50011 .49987 L
.50013 .49991 L
.50014 .49995 L
.50014 .49998 L
.50014 .50001 L
.50013 .50003 L
.50012 .50005 L
.50011 .50007 L
.50009 .50007 L
Mistroke
.50007 .50008 L
.50005 .50008 L
.50004 .50008 L
.50002 .50007 L
.50001 .50006 L
.5 .50006 L
.49999 .50005 L
.49998 .50004 L
.49997 .50003 L
.49997 .50002 L
.49997 .50001 L
.49997 .5 L
.49997 .5 L
.49997 .49999 L
.49997 .49999 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 0 r
% Start of user PostScript
-6.8510659 3.1279324 -7.1238284 1.388388 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-7.067921 -0.127406 -6.7383451 -1.394755 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.2653044 -3.6725167 -0.54153306 -3.3257148 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.6789563 -0.15425806 1.6342765 0.17580004 MAarrowhead1
% End of user PostScript
.897 1 0 r
.69845 .94892 m
.60808 .9145 L
s
% Start of user PostScript
0.39690531 0.89783246 0.21616656 0.82899932 MAarrowhead1
% End of user PostScript
.581 1 0 r
.30302 .54172 m
.30396 .49928 L
s
% Start of user PostScript
-0.39395869 0.083432401 -0.39207862 -0.0014390076 MAarrowhead1
% End of user PostScript
.266 1 0 r
.4411 .39141 m
.46344 .39775 L
s
% Start of user PostScript
-0.1177935 -0.21718456 -0.073128823 -0.20450147 MAarrowhead1
% End of user PostScript
0 1 .049 r
.5456 .48422 m
.54649 .49501 L
s
% Start of user PostScript
0.091193585 -0.031554647 0.092988132 -0.0099843801 MAarrowhead1
% End of user PostScript
0 1 .364 r
.51683 .52598 m
.51137 .52496 L
s
% Start of user PostScript
0.033658108 0.051961707 0.022734662 0.049924649 MAarrowhead1
% End of user PostScript
0 1 .679 r
.48961 .5052 m
.48911 .50249 L
s
% Start of user PostScript
-0.020786366 0.010408373 -0.021781166 0.0049862203 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49532 .49386 m
.49665 .49397 L
s
% Start of user PostScript
-0.0093509093 -0.01228737 -0.0067075162 -0.012059172 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50233 .49841 m
.50252 .49908 L
s
% Start of user PostScript
0.0046530893 -0.0031879009 0.0050320493 -0.0018392774 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50127 .50143 m
.50095 .50144 L
s
% Start of user PostScript
0.0025411579 0.0028688535 0.0019084647 0.0028807646 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49949 .50047 m
.49943 .5003 L
s
% Start of user PostScript
-0.0010189612 0.00093117089 -0.0011443995 0.00059920661 MAarrowhead1
% End of user PostScript
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -13.4688 -20 ]
[0 .4875 13.4688 0 ]
[.125 .4875 -25.9688 -20 ]
[.125 .4875 25.9688 0 ]
[.25 .4875 -20.9688 -20 ]
[.25 .4875 20.9688 0 ]
[.375 .4875 -25.9688 -20 ]
[.375 .4875 25.9688 0 ]
[.625 .4875 -19.5 -20 ]
[.625 .4875 19.5 0 ]
[.75 .4875 -14.5 -20 ]
[.75 .4875 14.5 0 ]
[.875 .4875 -19.5 -20 ]
[.875 .4875 19.5 0 ]
[1 .4875 -7 -20 ]
[1 .4875 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .125 -51.9375 -10 ]
[.4875 .125 0 10 ]
[.4875 .25 -41.9375 -10 ]
[.4875 .25 0 10 ]
[.4875 .375 -51.9375 -10 ]
[.4875 .375 0 10 ]
[.4875 .625 -39 -10 ]
[.4875 .625 0 10 ]
[.4875 .75 -29 -10 ]
[.4875 .75 0 10 ]
[.4875 .875 -39 -10 ]
[.4875 .875 0 10 ]
[.4875 1 -14 -10 ]
[.4875 1 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 .5 m
.125 .50625 L
s
gsave
.125 .4875 -86.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.25 .5 m
.25 .50625 L
s
gsave
.25 .4875 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.375 .5 m
.375 .50625 L
s
gsave
.375 .4875 -86.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.625 .5 m
.625 .50625 L
s
gsave
.625 .4875 -80.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.75 .5 m
.75 .50625 L
s
gsave
.75 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.875 .5 m
.875 .50625 L
s
gsave
.875 .4875 -80.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .125 m
.50625 .125 L
s
gsave
.4875 .125 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.5 .25 m
.50625 .25 L
s
gsave
.4875 .25 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .375 m
.50625 .375 L
s
gsave
.4875 .375 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.5 .625 m
.50625 .625 L
s
gsave
.4875 .625 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.5 .75 m
.50625 .75 L
s
gsave
.4875 .75 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .875 m
.50625 .875 L
s
gsave
.4875 .875 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.01 w
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.305 0 1 r
.5 Mabswid
.54941 1 m
.47351 .9466 L
.39332 .87158 L
.33026 .79374 L
.28411 .71665 L
.25401 .64328 L
.23858 .57595 L
.23607 .51639 L
.24453 .46575 L
.26184 .4246 L
.2859 .39307 L
.31466 .37088 L
.34621 .35742 L
.37885 .35182 L
.41109 .35304 L
.44171 .35995 L
.46975 .37134 L
.49449 .38606 L
.51548 .40296 L
.53249 .42104 L
.54546 .43937 L
.55453 .45718 L
.55997 .47384 L
.56214 .48888 L
.56147 .50194 L
.55845 .51283 L
.55358 .52146 L
.54735 .52785 L
.54022 .53209 L
.53263 .53438 L
.52496 .53492 L
.51752 .53397 L
.51057 .53182 L
.50431 .52875 L
.49889 .52501 L
.49438 .52088 L
.49082 .51657 L
.4882 .5123 L
.48647 .50822 L
.48556 .50446 L
.48538 .50113 L
.4858 .49829 L
.48673 .49597 L
.48804 .49419 L
.48962 .49292 L
.49136 .49214 L
.49316 .49181 L
.49495 .49185 L
.49665 .49221 L
.49822 .49282 L
Mistroke
.4996 .49363 L
.50078 .49456 L
.50174 .49555 L
.50247 .49657 L
.50299 .49756 L
.5033 .49849 L
.50344 .49933 L
.50341 .50006 L
.50325 .50067 L
.50299 .50116 L
.50265 .50152 L
.50226 .50176 L
.50184 .5019 L
.50141 .50193 L
.501 .50189 L
.50061 .50177 L
.50026 .50161 L
.49996 .5014 L
.49971 .50117 L
.4995 .50093 L
.49936 .5007 L
.49926 .50047 L
.4992 .50026 L
.49919 .50008 L
.49921 .49992 L
.49926 .49979 L
.49933 .49968 L
.49942 .49961 L
.49951 .49957 L
.49961 .49955 L
.49971 .49955 L
.49981 .49957 L
.4999 .4996 L
.49997 .49964 L
.50004 .49969 L
.50009 .49975 L
.50013 .49981 L
.50016 .49986 L
.50018 .49991 L
.50019 .49996 L
.50019 .5 L
.50018 .50003 L
.50017 .50006 L
.50015 .50008 L
.50013 .5001 L
.5001 .5001 L
.50008 .50011 L
.50006 .5001 L
.50004 .5001 L
.50002 .50009 L
Mistroke
.5 .50008 L
.49998 .50007 L
.49997 .50005 L
.49996 .50004 L
.49996 .50003 L
.49996 .50002 L
.49996 .5 L
.49996 .5 L
.49996 .49999 L
.49996 .49998 L
.49997 .49998 L
.49997 .49998 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 .962 r
0 .1296 m
.00685 .12511 L
.09651 .09421 L
.18791 .0845 L
.27712 .09297 L
.36092 .11635 L
.43682 .15132 L
.50307 .19462 L
.55856 .24318 L
.6028 .29422 L
.63583 .34529 L
.65812 .39435 L
.67051 .43975 L
.67409 .48028 L
.67014 .51509 L
.66001 .54371 L
.64512 .56598 L
.62681 .58204 L
.60637 .59224 L
.58496 .59712 L
.56358 .59733 L
.5431 .59361 L
.52418 .58675 L
.50733 .57752 L
.4929 .56667 L
.48106 .55489 L
.47188 .54282 L
.4653 .53096 L
.46117 .51978 L
.45925 .5096 L
.45927 .50066 L
.46091 .49314 L
.46386 .4871 L
.46777 .48254 L
.47235 .47942 L
.4773 .47762 L
.48236 .477 L
.48731 .4774 L
.49198 .47864 L
.49622 .48054 L
.49992 .48291 L
.50304 .48558 L
.50554 .4884 L
.50741 .49123 L
.50868 .49396 L
.50941 .49649 L
.50964 .49876 L
.50945 .50071 L
.50891 .50232 L
.5081 .50358 L
Mistroke
.5071 .50449 L
.50597 .50508 L
.50479 .50537 L
.5036 .5054 L
.50247 .5052 L
.50141 .50483 L
.50047 .50433 L
.49966 .50374 L
.49899 .50309 L
.49848 .50242 L
.4981 .50176 L
.49786 .50114 L
.49775 .50057 L
.49774 .50007 L
.49783 .49965 L
.49799 .49931 L
.4982 .49905 L
.49845 .49887 L
.49872 .49877 L
.499 .49873 L
.49928 .49875 L
.49954 .49881 L
.49977 .49891 L
.49998 .49904 L
.50016 .49919 L
.5003 .49935 L
.5004 .4995 L
.50048 .49966 L
.50052 .4998 L
.50053 .49992 L
.50052 .50003 L
.5005 .50012 L
.50045 .50019 L
.5004 .50025 L
.50034 .50028 L
.50027 .5003 L
.5002 .5003 L
.50014 .50029 L
.50008 .50027 L
.50003 .50024 L
.49998 .50021 L
.49995 .50017 L
.49992 .50014 L
.4999 .5001 L
.49988 .50007 L
.49988 .50003 L
.49987 .50001 L
.49988 .49998 L
.49989 .49996 L
.4999 .49995 L
Mistroke
.49991 .49994 L
.49993 .49993 L
.49994 .49993 L
.49996 .49993 L
.49997 .49993 L
.49999 .49994 L
.5 .49995 L
.50001 .49995 L
.50002 .49996 L
.50002 .49997 L
.50003 .49998 L
.50003 .49999 L
.50003 .5 L
.50003 .5 L
.50003 .50001 L
.50003 .50001 L
.50002 .50001 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 .664 r
.8357 0 m
.83904 .00448 L
.9146 .14412 L
.96145 .27558 L
.98232 .3949 L
.98056 .49927 L
.95986 .58692 L
.92409 .65702 L
.87711 .70958 L
.82259 .74533 L
.76392 .76552 L
.70412 .77186 L
.64576 .7663 L
.59093 .75099 L
.54127 .7281 L
.49794 .69977 L
.46164 .66799 L
.4327 .6346 L
.41111 .60118 L
.39653 .56909 L
.38843 .53938 L
.38609 .51287 L
.38869 .4901 L
.39532 .47138 L
.40507 .45681 L
.41705 .44631 L
.43042 .43964 L
.44443 .43645 L
.45842 .43632 L
.47182 .43876 L
.48419 .44325 L
.49522 .44929 L
.50466 .45639 L
.5124 .46409 L
.5184 .472 L
.52271 .47975 L
.52541 .48707 L
.52666 .49373 L
.52665 .49957 L
.52557 .50449 L
.52365 .50845 L
.52108 .51142 L
.51809 .51347 L
.51485 .51465 L
.51154 .51505 L
.5083 .51479 L
.50525 .51397 L
.50247 .51273 L
.50005 .51118 L
.49801 .50943 L
Mistroke
.49638 .50759 L
.49515 .50573 L
.49432 .50395 L
.49384 .50229 L
.49369 .50081 L
.49382 .49954 L
.49417 .49848 L
.4947 .49766 L
.49536 .49706 L
.49609 .49668 L
.49687 .49649 L
.49764 .49647 L
.49839 .4966 L
.49908 .49684 L
.49969 .49717 L
.50022 .49756 L
.50066 .49798 L
.501 .49842 L
.50124 .49885 L
.5014 .49926 L
.50147 .49963 L
.50148 .49995 L
.50142 .50023 L
.50132 .50045 L
.50118 .50062 L
.50101 .50074 L
.50084 .50081 L
.50065 .50083 L
.50047 .50082 L
.5003 .50078 L
.50015 .50071 L
.50001 .50063 L
.4999 .50053 L
.49981 .50043 L
.49974 .50032 L
.49969 .50023 L
.49966 .50013 L
.49965 .50005 L
.49966 .49998 L
.49968 .49992 L
.4997 .49987 L
.49974 .49984 L
.49978 .49982 L
.49982 .49981 L
.49987 .4998 L
.49991 .49981 L
.49995 .49982 L
.49998 .49984 L
.50001 .49986 L
.50003 .49989 L
Mistroke
.50005 .49991 L
.50007 .49993 L
.50008 .49996 L
.50008 .49998 L
.50008 .5 L
.50008 .50001 L
.50007 .50002 L
.50007 .50003 L
.50006 .50004 L
.50005 .50004 L
.50004 .50005 L
.50003 .50005 L
.50002 .50004 L
.50001 .50004 L
.5 .50004 L
.49999 .50003 L
.49999 .50002 L
.49999 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.35 0 1 r
.10956 1 m
.04684 .88285 L
s
.04684 .88285 m
0 .74939 L
s
0 .4049 m
.0005 .40285 L
.03985 .32714 L
.09128 .27049 L
.1508 .23212 L
.21473 .21063 L
.2798 .20415 L
.34323 .21055 L
.40275 .22749 L
.4566 .25261 L
.50354 .28359 L
.54281 .31825 L
.57405 .35462 L
.59732 .39096 L
.61297 .42583 L
.62158 .45806 L
.62395 .4868 L
.62098 .51145 L
.61365 .53169 L
.60295 .54741 L
.58986 .55871 L
.57527 .56585 L
.56001 .56921 L
.54481 .56926 L
.53025 .56653 L
.51682 .56158 L
.50487 .55497 L
.49465 .54721 L
.48628 .53882 L
.47981 .53022 L
.47518 .52179 L
.47228 .51384 L
.47096 .50662 L
.47102 .50029 L
.47222 .49497 L
.47434 .4907 L
.47715 .48749 L
.48042 .48529 L
.48395 .48404 L
.48755 .48362 L
.49107 .48393 L
.49439 .48483 L
.49739 .48619 L
.50002 .48789 L
.50223 .48979 L
.50399 .4918 L
.50531 .49382 L
.50621 .49576 L
.50671 .49756 L
.50686 .49916 L
Mistroke
.50672 .50054 L
.50633 .50168 L
.50575 .50257 L
.50503 .50321 L
.50423 .50362 L
.50338 .50382 L
.50254 .50384 L
.50173 .5037 L
.50098 .50343 L
.50031 .50307 L
.49974 .50265 L
.49927 .50218 L
.4989 .50171 L
.49864 .50124 L
.49847 .5008 L
.4984 .50039 L
.49839 .50004 L
.49846 .49974 L
.49857 .4995 L
.49872 .49932 L
.4989 .49919 L
.4991 .49912 L
.4993 .49909 L
.49949 .49911 L
.49968 .49916 L
.49984 .49923 L
.49999 .49932 L
.50012 .49943 L
.50021 .49954 L
.50029 .49965 L
.50034 .49976 L
.50037 .49986 L
.50038 .49995 L
.50037 .50002 L
.50035 .50009 L
.50032 .50014 L
.50028 .50018 L
.50024 .5002 L
.50019 .50021 L
.50014 .50021 L
.5001 .50021 L
.50006 .50019 L
.50002 .50017 L
.49999 .50015 L
.49996 .50012 L
.49994 .5001 L
.49993 .50007 L
.49992 .50005 L
.49991 .50002 L
.49991 .5 L
Mistroke
.49991 .49999 L
.49992 .49997 L
.49993 .49996 L
.49994 .49996 L
.49995 .49995 L
.49996 .49995 L
.49997 .49995 L
.49998 .49995 L
.49999 .49996 L
.5 .49996 L
.50001 .49997 L
.50001 .49997 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 1 .338 r
.32053 0 m
.37041 .01858 L
.46371 .07065 L
.54349 .13152 L
.60872 .19737 L
.65913 .26474 L
.69508 .3307 L
.71746 .39285 L
.72756 .4493 L
.72693 .49872 L
.71732 .54025 L
.70057 .57351 L
.67849 .59849 L
.65281 .61552 L
.62515 .62519 L
.59692 .62831 L
.56935 .62579 L
.54343 .61865 L
.51994 .60791 L
.49942 .59458 L
.48221 .57961 L
.46848 .56386 L
.45822 .54808 L
.45127 .53291 L
.44739 .51886 L
.44624 .50632 L
.44742 .49553 L
.45051 .48665 L
.45509 .47974 L
.46072 .47474 L
.46703 .47156 L
.47364 .47002 L
.48024 .46993 L
.48657 .47106 L
.49243 .47316 L
.49764 .476 L
.50212 .47934 L
.50579 .48298 L
.50864 .48671 L
.51068 .49037 L
.51197 .49383 L
.51258 .49698 L
.51258 .49975 L
.51208 .50208 L
.51118 .50395 L
.50998 .50537 L
.50857 .50634 L
.50704 .50691 L
.50548 .5071 L
.50395 .50698 L
Mistroke
.5025 .50661 L
.50119 .50602 L
.50004 .50529 L
.49908 .50447 L
.4983 .5036 L
.49772 .50272 L
.49732 .50188 L
.4971 .5011 L
.49702 .5004 L
.49708 .49979 L
.49724 .49929 L
.49749 .4989 L
.4978 .49862 L
.49815 .49843 L
.49851 .49834 L
.49888 .49833 L
.49923 .49839 L
.49956 .4985 L
.49985 .49866 L
.5001 .49884 L
.50031 .49904 L
.50047 .49925 L
.50058 .49945 L
.50066 .49964 L
.5007 .49982 L
.5007 .49998 L
.50067 .50011 L
.50062 .50021 L
.50056 .50029 L
.50048 .50035 L
.5004 .50038 L
.50031 .50039 L
.50022 .50039 L
.50014 .50037 L
.50007 .50034 L
.50001 .5003 L
.49995 .50025 L
.49991 .5002 L
.49988 .50015 L
.49985 .50011 L
.49984 .50006 L
.49984 .50002 L
.49984 .49999 L
.49985 .49996 L
.49986 .49994 L
.49988 .49992 L
.4999 .49991 L
.49992 .49991 L
.49994 .49991 L
.49996 .49991 L
Mistroke
.49997 .49992 L
.49999 .49993 L
.5 .49994 L
.50002 .49995 L
.50003 .49996 L
.50003 .49997 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50003 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 .153 0 r
0 .06766 m
.02409 .05746 L
.12533 .04034 L
.22529 .04435 L
.32019 .06593 L
.40705 .10141 L
.48368 .14713 L
.54866 .19963 L
.60126 .2557 L
.64137 .31255 L
.66938 .36776 L
.68613 .4194 L
.69274 .46597 L
.69058 .50643 L
.68115 .54013 L
.66599 .56682 L
.64662 .58655 L
.6245 .59965 L
.60096 .60667 L
.57715 .60829 L
.55408 .60532 L
.53256 .59862 L
.51318 .58904 L
.49639 .57745 L
.48244 .56462 L
.47143 .55126 L
.46333 .538 L
.458 .52535 L
.45521 .51372 L
.45465 .5034 L
.45599 .49461 L
.45888 .48744 L
.46296 .48192 L
.46785 .47802 L
.47325 .47562 L
.47885 .47458 L
.4844 .47472 L
.48968 .47585 L
.49452 .47777 L
.49881 .48027 L
.50246 .48315 L
.50542 .48625 L
.50769 .4894 L
.50929 .49246 L
.51026 .49534 L
.51066 .49794 L
.51057 .50021 L
.51008 .5021 L
.50926 .50361 L
.5082 .50473 L
Mistroke
.50699 .50548 L
.50568 .50589 L
.50437 .506 L
.50308 .50585 L
.50188 .50549 L
.5008 .50497 L
.49986 .50434 L
.49908 .50363 L
.49846 .50289 L
.498 .50216 L
.49769 .50145 L
.49753 .5008 L
.49749 .50023 L
.49756 .49973 L
.49771 .49933 L
.49793 .49902 L
.4982 .4988 L
.4985 .49866 L
.49881 .49859 L
.49911 .4986 L
.49941 .49866 L
.49968 .49876 L
.49992 .4989 L
.50012 .49906 L
.50029 .49923 L
.50042 .4994 L
.50051 .49957 L
.50057 .49973 L
.50059 .49988 L
.50059 .5 L
.50056 .50011 L
.50052 .50019 L
.50046 .50026 L
.50039 .5003 L
.50032 .50032 L
.50025 .50033 L
.50018 .50032 L
.50011 .50031 L
.50005 .50028 L
.5 .50024 L
.49995 .5002 L
.49992 .50016 L
.49989 .50012 L
.49987 .50008 L
.49986 .50005 L
.49986 .50001 L
.49986 .49999 L
.49987 .49996 L
.49988 .49995 L
.4999 .49993 L
Mistroke
.49992 .49993 L
.49993 .49992 L
.49995 .49992 L
.49997 .49993 L
.49998 .49993 L
.49999 .49994 L
.50001 .49995 L
.50002 .49996 L
.50002 .49997 L
.50003 .49998 L
.50003 .49998 L
.50003 .49999 L
.50003 .5 L
.50003 .50001 L
.50003 .50001 L
.50003 .50001 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 .052 0 r
.0419 1 m
.01783 .9584 L
s
.01783 .9584 m
0 .91285 L
s
0 .30432 m
.03624 .25939 L
.10017 .21274 L
.16982 .18507 L
.2415 .17443 L
.312 .17852 L
.37871 .19481 L
.43955 .22069 L
.49305 .25358 L
.53823 .29105 L
.57463 .33086 L
.60221 .37104 L
.62127 .40993 L
.63242 .44617 L
.63648 .47875 L
.63444 .50695 L
.62734 .53035 L
.6163 .54877 L
.60237 .56229 L
.58659 .57114 L
.56988 .57573 L
.55305 .57655 L
.53681 .57418 L
.5217 .56923 L
.50815 .5623 L
.49645 .55399 L
.48677 .54486 L
.47917 .5354 L
.47363 .52604 L
.47003 .51714 L
.46821 .50899 L
.46795 .50179 L
.46901 .49567 L
.47114 .4907 L
.47409 .48691 L
.47759 .48425 L
.48144 .48264 L
.4854 .48199 L
.48932 .48216 L
.49303 .48302 L
.49642 .48442 L
.49942 .48622 L
.50195 .48828 L
.504 .49047 L
.50556 .4927 L
.50665 .49486 L
.5073 .49688 L
.50755 .4987 L
.50746 .50028 L
.50709 .5016 L
Mistroke
.50649 .50264 L
.50573 .5034 L
.50486 .50391 L
.50394 .50418 L
.503 .50424 L
.5021 .50412 L
.50126 .50386 L
.5005 .50348 L
.49985 .50302 L
.4993 .50252 L
.49887 .502 L
.49856 .50148 L
.49835 .50098 L
.49824 .50053 L
.49822 .50013 L
.49828 .49978 L
.49839 .4995 L
.49855 .49929 L
.49874 .49914 L
.49896 .49904 L
.49918 .499 L
.49939 .49901 L
.4996 .49906 L
.49979 .49913 L
.49996 .49923 L
.5001 .49934 L
.50021 .49946 L
.5003 .49959 L
.50036 .49971 L
.5004 .49982 L
.50042 .49992 L
.50041 .50001 L
.50039 .50008 L
.50036 .50014 L
.50032 .50019 L
.50027 .50021 L
.50022 .50023 L
.50017 .50023 L
.50012 .50023 L
.50007 .50021 L
.50003 .50019 L
.49999 .50017 L
.49996 .50014 L
.49994 .50011 L
.49992 .50008 L
.49991 .50006 L
.4999 .50003 L
.4999 .50001 L
.4999 .49999 L
.49991 .49997 L
Mistroke
.49992 .49996 L
.49993 .49995 L
.49994 .49995 L
.49995 .49994 L
.49997 .49995 L
.49998 .49995 L
.49999 .49995 L
.5 .49996 L
.5 .49996 L
.50001 .49997 L
.50002 .49998 L
.50002 .49998 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.721 1 0 r
.7513 0 m
.82883 .11862 L
.88404 .23846 L
.91503 .34952 L
.92445 .44877 L
.91538 .53413 L
.89116 .60443 L
.85519 .65926 L
.81078 .69892 L
.76108 .72426 L
.70891 .73656 L
.65677 .73743 L
.60673 .72866 L
.56045 .71216 L
.51919 .68982 L
.48378 .66348 L
.45471 .63483 L
.43211 .60539 L
.41586 .57646 L
.40558 .54911 L
.40073 .52419 L
.40062 .50231 L
.40451 .48385 L
.41159 .46899 L
.42107 .45776 L
.43219 .45003 L
.44423 .44553 L
.45657 .44393 L
.46866 .44484 L
.48007 .4478 L
.49044 .45237 L
.49953 .45812 L
.50718 .46462 L
.51331 .47149 L
.51793 .47839 L
.52109 .48505 L
.5229 .49124 L
.5235 .49679 L
.52306 .50158 L
.52178 .50553 L
.51983 .50863 L
.5174 .51088 L
.51466 .51234 L
.51178 .51307 L
.50889 .51316 L
.5061 .51271 L
.50352 .51182 L
.50122 .51061 L
.49923 .50916 L
.4976 .50758 L
Mistroke
.49632 .50595 L
.4954 .50435 L
.4948 .50282 L
.49451 .50143 L
.49449 .50021 L
.49469 .49917 L
.49507 .49834 L
.49559 .4977 L
.4962 .49726 L
.49686 .497 L
.49755 .4969 L
.49822 .49694 L
.49885 .49709 L
.49943 .49734 L
.49994 .49766 L
.50037 .49801 L
.50072 .49839 L
.50098 .49878 L
.50116 .49915 L
.50126 .49949 L
.5013 .4998 L
.50128 .50007 L
.50121 .50029 L
.50111 .50047 L
.50097 .50059 L
.50082 .50068 L
.50066 .50072 L
.5005 .50073 L
.50035 .50071 L
.5002 .50066 L
.50008 .50059 L
.49996 .50051 L
.49987 .50043 L
.4998 .50034 L
.49975 .50025 L
.49971 .50016 L
.4997 .50008 L
.49969 .50002 L
.4997 .49996 L
.49973 .49991 L
.49975 .49987 L
.49979 .49985 L
.49982 .49983 L
.49986 .49983 L
.4999 .49983 L
.49993 .49984 L
.49997 .49985 L
.49999 .49987 L
.50002 .49989 L
.50004 .49991 L
Mistroke
.50005 .49993 L
.50006 .49995 L
.50007 .49997 L
.50007 .49999 L
.50007 .5 L
.50007 .50002 L
.50006 .50003 L
.50005 .50003 L
.50005 .50004 L
.50004 .50004 L
.50003 .50004 L
.50002 .50004 L
.50001 .50004 L
.5 .50003 L
.5 .50003 L
.49999 .50002 L
.49999 .50002 L
.49999 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 1 .592 r
1 .99908 m
.99638 1 L
s
.766 1 m
.73859 .9956 L
.63798 .96116 L
.548 .9138 L
.47055 .8575 L
.40671 .79594 L
.35685 .73243 L
.32072 .66982 L
.29756 .61048 L
.28621 .55624 L
.28524 .50846 L
.293 .46801 L
.3078 .43534 L
.32791 .41049 L
.35168 .39322 L
.37755 .38299 L
.40418 .37908 L
.43035 .38063 L
.45512 .38671 L
.4777 .39634 L
.49754 .40857 L
.5143 .4225 L
.5278 .43728 L
.53802 .45221 L
.54508 .46664 L
.5492 .4801 L
.55069 .49219 L
.54992 .50265 L
.54727 .51132 L
.54316 .51815 L
.53798 .52316 L
.53212 .52644 L
.52591 .52813 L
.51966 .52843 L
.51363 .52754 L
.50802 .5257 L
.503 .52312 L
.49865 .52003 L
.49506 .51664 L
.49225 .51312 L
.49019 .50965 L
.48886 .50635 L
.48819 .50332 L
.4881 .50065 L
.48849 .49838 L
.48929 .49654 L
.49038 .49513 L
.49169 .49414 L
.49312 .49355 L
.49459 .49331 L
Mistroke
.49604 .49338 L
.49742 .4937 L
.49868 .49422 L
.49979 .49489 L
.50073 .49565 L
.50149 .49647 L
.50207 .49729 L
.50247 .4981 L
.50271 .49885 L
.5028 .49952 L
.50277 .50011 L
.50263 .5006 L
.50241 .50098 L
.50213 .50127 L
.5018 .50145 L
.50146 .50155 L
.50111 .50158 L
.50078 .50153 L
.50047 .50143 L
.50018 .50129 L
.49994 .50112 L
.49974 .50093 L
.49958 .50074 L
.49946 .50055 L
.49939 .50036 L
.49935 .5002 L
.49934 .50005 L
.49936 .49992 L
.4994 .49981 L
.49946 .49974 L
.49953 .49968 L
.49961 .49964 L
.49969 .49963 L
.49978 .49963 L
.49985 .49965 L
.49992 .49968 L
.49998 .49971 L
.50004 .49976 L
.50008 .4998 L
.50011 .49985 L
.50014 .49989 L
.50015 .49993 L
.50016 .49997 L
.50015 .5 L
.50015 .50003 L
.50013 .50005 L
.50012 .50007 L
.5001 .50008 L
.50008 .50009 L
.50006 .50009 L
Mistroke
.50004 .50009 L
.50003 .50008 L
.50001 .50007 L
.5 .50006 L
.49999 .50005 L
.49998 .50004 L
.49997 .50003 L
.49997 .50002 L
.49996 .50001 L
.49996 .5 L
.49996 .5 L
.49997 .49999 L
.49997 .49999 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 .145 1 r
.38019 0 m
.45655 .04182 L
.54189 .10592 L
.61185 .1755 L
.66611 .24688 L
.70501 .31692 L
.72947 .38304 L
.74083 .44322 L
.74073 .49601 L
.73102 .54049 L
.71364 .5762 L
.6905 .60314 L
.66345 .62162 L
.63422 .63228 L
.6043 .63593 L
.57502 .63356 L
.54744 .62623 L
.5224 .61503 L
.50047 .60103 L
.48205 .58524 L
.4673 .56857 L
.45623 .55183 L
.44869 .53571 L
.44441 .52075 L
.44303 .50737 L
.44416 .49583 L
.44734 .48632 L
.45212 .47888 L
.45804 .47348 L
.46469 .47 L
.47168 .46829 L
.47869 .46811 L
.48542 .46924 L
.49165 .47142 L
.49722 .47439 L
.50201 .47791 L
.50594 .48175 L
.50901 .4857 L
.51122 .48959 L
.51263 .49327 L
.51331 .49663 L
.51335 .49958 L
.51284 .50208 L
.51191 .50409 L
.51065 .50562 L
.50916 .50667 L
.50755 .50729 L
.50589 .50752 L
.50427 .50741 L
.50273 .50703 L
Mistroke
.50133 .50642 L
.50011 .50565 L
.49907 .50478 L
.49824 .50386 L
.49761 .50294 L
.49718 .50204 L
.49693 .50121 L
.49685 .50046 L
.4969 .49981 L
.49707 .49928 L
.49733 .49886 L
.49765 .49855 L
.49802 .49835 L
.4984 .49825 L
.49879 .49823 L
.49917 .49829 L
.49951 .49841 L
.49983 .49857 L
.50009 .49876 L
.50031 .49897 L
.50049 .49919 L
.50061 .49941 L
.5007 .49961 L
.50074 .4998 L
.50074 .49997 L
.50071 .50011 L
.50066 .50022 L
.5006 .50031 L
.50051 .50037 L
.50042 .5004 L
.50033 .50042 L
.50024 .50041 L
.50016 .50039 L
.50008 .50036 L
.50001 .50032 L
.49995 .50027 L
.49991 .50022 L
.49987 .50017 L
.49985 .50012 L
.49983 .50007 L
.49983 .50003 L
.49983 .49999 L
.49984 .49996 L
.49985 .49994 L
.49987 .49992 L
.49989 .49991 L
.49991 .4999 L
.49993 .4999 L
.49995 .49991 L
.49997 .49991 L
Mistroke
.49999 .49992 L
.5 .49993 L
.50002 .49994 L
.50003 .49995 L
.50003 .49997 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50004 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 .654 r
.64754 1 m
.59495 .97672 L
.504 .91908 L
.42749 .85394 L
.36617 .7851 L
.32004 .71591 L
.28852 .64919 L
.27051 .58722 L
.26457 .53171 L
.269 .48384 L
.28196 .44431 L
.30155 .41335 L
.32594 .39082 L
.35337 .37628 L
.38226 .36902 L
.41122 .36816 L
.43908 .37271 L
.46491 .38162 L
.48799 .39384 L
.50785 .40834 L
.5242 .42418 L
.53696 .4405 L
.5462 .45659 L
.5521 .47183 L
.55498 .48574 L
.55519 .498 L
.55316 .50837 L
.54933 .51673 L
.54415 .52309 L
.53803 .5275 L
.53137 .53011 L
.52453 .53109 L
.5178 .53067 L
.51144 .52909 L
.50565 .5266 L
.50056 .52345 L
.49626 .51987 L
.49281 .51606 L
.49019 .51223 L
.48839 .50852 L
.48734 .50507 L
.48697 .50196 L
.48718 .49928 L
.48786 .49706 L
.48892 .49531 L
.49026 .49403 L
.49177 .49319 L
.49336 .49276 L
.49497 .49269 L
.49652 .49293 L
Mistroke
.49796 .4934 L
.49925 .49407 L
.50036 .49486 L
.50128 .49574 L
.502 .49664 L
.50253 .49753 L
.50287 .49838 L
.50304 .49916 L
.50306 .49984 L
.50296 .50043 L
.50275 .5009 L
.50247 .50126 L
.50213 .50151 L
.50176 .50166 L
.50139 .50172 L
.50101 .5017 L
.50066 .50162 L
.50033 .50148 L
.50005 .50131 L
.49981 .50111 L
.49961 .5009 L
.49947 .50069 L
.49936 .50049 L
.4993 .50029 L
.49928 .50012 L
.49929 .49997 L
.49932 .49985 L
.49938 .49975 L
.49945 .49967 L
.49954 .49963 L
.49963 .4996 L
.49972 .4996 L
.4998 .49961 L
.49988 .49963 L
.49995 .49967 L
.50002 .49971 L
.50007 .49976 L
.50011 .49981 L
.50014 .49986 L
.50016 .49991 L
.50017 .49995 L
.50017 .49999 L
.50016 .50002 L
.50015 .50005 L
.50014 .50007 L
.50012 .50008 L
.5001 .50009 L
.50008 .5001 L
.50006 .50009 L
.50004 .50009 L
Mistroke
.50002 .50008 L
.5 .50007 L
.49999 .50006 L
.49998 .50005 L
.49997 .50004 L
.49997 .50003 L
.49996 .50002 L
.49996 .50001 L
.49996 .5 L
.49996 .49999 L
.49997 .49999 L
.49997 .49998 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 .012 1 r
0 .12308 m
.00583 .11935 L
.09659 .08917 L
.1889 .08027 L
.27884 .08958 L
.36318 .11381 L
.43945 .14959 L
.5059 .19364 L
.56145 .24287 L
.60562 .29448 L
.63847 .34602 L
.66052 .39545 L
.6726 .44112 L
.67584 .48181 L
.67153 .5167 L
.66106 .54532 L
.64582 .56753 L
.6272 .58348 L
.60648 .59352 L
.58483 .59822 L
.56326 .59823 L
.54263 .59431 L
.5236 .58725 L
.50669 .57784 L
.49222 .56682 L
.48039 .5549 L
.47124 .5427 L
.46471 .53075 L
.46064 .51949 L
.45879 .50925 L
.45889 .50029 L
.46062 .49276 L
.46365 .48673 L
.46764 .48219 L
.47229 .4791 L
.4773 .47733 L
.48241 .47676 L
.4874 .47721 L
.4921 .4785 L
.49636 .48044 L
.50008 .48285 L
.5032 .48556 L
.50569 .48841 L
.50756 .49127 L
.50882 .49402 L
.50952 .49657 L
.50974 .49884 L
.50953 .5008 L
.50897 .50241 L
.50814 .50366 L
Mistroke
.50712 .50457 L
.50598 .50515 L
.50478 .50543 L
.50359 .50545 L
.50244 .50524 L
.50138 .50486 L
.50043 .50435 L
.49962 .50375 L
.49896 .50309 L
.49844 .50241 L
.49807 .50175 L
.49783 .50112 L
.49772 .50055 L
.49772 .50005 L
.49781 .49963 L
.49797 .49929 L
.49819 .49903 L
.49845 .49885 L
.49872 .49875 L
.49901 .49871 L
.49928 .49873 L
.49954 .4988 L
.49978 .49891 L
.49999 .49904 L
.50017 .49919 L
.50031 .49935 L
.50041 .49951 L
.50048 .49966 L
.50053 .4998 L
.50054 .49993 L
.50053 .50004 L
.5005 .50013 L
.50045 .5002 L
.5004 .50025 L
.50034 .50028 L
.50027 .5003 L
.5002 .5003 L
.50014 .50029 L
.50008 .50027 L
.50003 .50024 L
.49998 .50021 L
.49994 .50017 L
.49992 .50014 L
.49989 .5001 L
.49988 .50006 L
.49987 .50003 L
.49987 .5 L
.49988 .49998 L
.49989 .49996 L
.4999 .49995 L
Mistroke
.49991 .49994 L
.49993 .49993 L
.49994 .49993 L
.49996 .49993 L
.49997 .49993 L
.49999 .49994 L
.5 .49995 L
.50001 .49995 L
.50002 .49996 L
.50002 .49997 L
.50003 .49998 L
.50003 .49999 L
.50003 .5 L
.50003 .5 L
.50003 .50001 L
.50003 .50001 L
.50002 .50001 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 .043 r
.18771 1 m
.16702 .9717 L
.09553 .83691 L
.0517 .71028 L
.03283 .59557 L
.03567 .49546 L
.05663 .4116 L
.09195 .34474 L
.13792 .29482 L
.19098 .26112 L
.24789 .24238 L
.30574 .23696 L
.36207 .24292 L
.41488 .25821 L
.46261 .28071 L
.50417 .30837 L
.5389 .33925 L
.56649 .3716 L
.58699 .40389 L
.60073 .43485 L
.60823 .46343 L
.6102 .4889 L
.60744 .51071 L
.60084 .5286 L
.59126 .54247 L
.57956 .55242 L
.56657 .55867 L
.553 .56157 L
.53948 .56155 L
.52656 .55906 L
.51465 .55462 L
.50407 .5487 L
.49502 .54179 L
.48763 .53431 L
.48191 .52667 L
.47784 .51918 L
.47531 .51213 L
.47417 .50572 L
.47425 .50012 L
.47534 .49541 L
.47725 .49164 L
.47975 .48881 L
.48267 .48688 L
.48581 .48579 L
.48901 .48544 L
.49214 .48572 L
.49508 .48654 L
.49775 .48776 L
.50008 .48927 L
.50203 .49097 L
Mistroke
.50358 .49276 L
.50475 .49455 L
.50553 .49627 L
.50597 .49787 L
.5061 .49929 L
.50597 .50051 L
.50562 .50152 L
.5051 .5023 L
.50445 .50287 L
.50374 .50323 L
.50299 .5034 L
.50224 .50341 L
.50152 .50328 L
.50086 .50304 L
.50026 .50272 L
.49976 .50234 L
.49934 .50193 L
.49902 .50151 L
.49879 .50109 L
.49864 .5007 L
.49857 .50034 L
.49857 .50003 L
.49863 .49976 L
.49873 .49955 L
.49887 .49939 L
.49903 .49928 L
.4992 .49922 L
.49938 .49919 L
.49955 .49921 L
.49972 .49925 L
.49987 .49932 L
.5 .4994 L
.50011 .49949 L
.50019 .49959 L
.50026 .49969 L
.5003 .49979 L
.50033 .49988 L
.50034 .49996 L
.50033 .50002 L
.50031 .50008 L
.50028 .50012 L
.50025 .50016 L
.50021 .50018 L
.50017 .50019 L
.50013 .50019 L
.50009 .50018 L
.50005 .50017 L
.50002 .50015 L
.49999 .50013 L
.49997 .50011 L
Mistroke
.49995 .50009 L
.49993 .50006 L
.49993 .50004 L
.49992 .50002 L
.49992 .5 L
.49992 .49999 L
.49993 .49998 L
.49994 .49997 L
.49995 .49996 L
.49996 .49996 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49999 .49996 L
.5 .49997 L
.50001 .49997 L
.50001 .49998 L
.50001 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 .607 0 r
.82778 0 m
.8656 .05636 L
.93056 .19269 L
.96787 .31942 L
.98049 .43302 L
.97186 .53107 L
.94575 .61213 L
.906 .67569 L
.8564 .72203 L
.80051 .75204 L
.74158 .76716 L
.68244 .76917 L
.62551 .76009 L
.57269 .74207 L
.52545 .71726 L
.48478 .68774 L
.45124 .65546 L
.42504 .62214 L
.40604 .58929 L
.39385 .55814 L
.38786 .52967 L
.38732 .50458 L
.39137 .48333 L
.39911 .46617 L
.40965 .45311 L
.4221 .44402 L
.43568 .43863 L
.44964 .43656 L
.46338 .43736 L
.47638 .44054 L
.48823 .44558 L
.49865 .45199 L
.50746 .45929 L
.51455 .46705 L
.51992 .47488 L
.52363 .48246 L
.5258 .48952 L
.52659 .49586 L
.52619 .50136 L
.52481 .50592 L
.52266 .50951 L
.51994 .51214 L
.51687 .51386 L
.51361 .51476 L
.51033 .51492 L
.50717 .51445 L
.50423 .51349 L
.50159 .51214 L
.49931 .51052 L
.49742 .50874 L
Mistroke
.49594 .5069 L
.49486 .50507 L
.49416 .50334 L
.4938 .50175 L
.49375 .50035 L
.49396 .49915 L
.49438 .49819 L
.49495 .49745 L
.49563 .49693 L
.49638 .49662 L
.49716 .49649 L
.49792 .49652 L
.49864 .49669 L
.4993 .49696 L
.49989 .49731 L
.50038 .49772 L
.50078 .49814 L
.50108 .49858 L
.5013 .499 L
.50142 .49939 L
.50147 .49975 L
.50145 .50005 L
.50138 .50031 L
.50126 .50051 L
.50112 .50066 L
.50095 .50076 L
.50077 .50081 L
.50059 .50083 L
.50041 .5008 L
.50025 .50075 L
.5001 .50068 L
.49997 .50059 L
.49986 .50049 L
.49978 .50039 L
.49972 .50029 L
.49968 .50019 L
.49966 .5001 L
.49965 .50002 L
.49966 .49996 L
.49969 .4999 L
.49972 .49986 L
.49976 .49983 L
.4998 .49981 L
.49984 .49981 L
.49988 .49981 L
.49992 .49982 L
.49996 .49983 L
.49999 .49985 L
.50002 .49987 L
.50004 .4999 L
Mistroke
.50006 .49992 L
.50007 .49994 L
.50008 .49996 L
.50008 .49998 L
.50008 .5 L
.50008 .50002 L
.50007 .50003 L
.50006 .50004 L
.50005 .50004 L
.50004 .50004 L
.50003 .50005 L
.50002 .50004 L
.50001 .50004 L
.50001 .50004 L
.5 .50003 L
.49999 .50003 L
.49999 .50002 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.617 1 0 r
.91093 0 m
.9535 .07419 L
s
.9535 .07419 m
1 .19428 L
s
1 .62959 m
.98409 .66434 L
.93317 .72668 L
.87311 .76995 L
.80777 .79547 L
.74061 .80509 L
.67461 .80096 L
.61222 .78545 L
.55536 .76103 L
.50542 .73008 L
.46328 .6949 L
.42937 .65758 L
.40373 .61994 L
.38606 .58355 L
.37578 .54967 L
.37211 .51923 L
.37415 .49292 L
.3809 .47111 L
.39132 .45396 L
.40442 .4414 L
.41924 .4332 L
.43491 .42899 L
.45066 .4283 L
.46586 .43058 L
.47998 .43527 L
.49264 .4418 L
.50356 .44961 L
.51259 .45818 L
.51966 .46705 L
.52481 .47581 L
.52814 .48413 L
.52981 .49175 L
.53002 .49847 L
.529 .50418 L
.52698 .50881 L
.52421 .51234 L
.52091 .51481 L
.51731 .51629 L
.51359 .51688 L
.50993 .5167 L
.50645 .51588 L
.50328 .51456 L
.50049 .51287 L
.49812 .51094 L
.49621 .50888 L
.49476 .50679 L
.49375 .50477 L
.49315 .50288 L
.49292 .50118 L
.49302 .4997 L
Mistroke
.49337 .49848 L
.49394 .49751 L
.49465 .4968 L
.49547 .49633 L
.49633 .49608 L
.49721 .49603 L
.49805 .49614 L
.49884 .49639 L
.49955 .49675 L
.50016 .49718 L
.50066 .49765 L
.50106 .49814 L
.50136 .49863 L
.50155 .49909 L
.50165 .49951 L
.50166 .49989 L
.50161 .50021 L
.5015 .50047 L
.50135 .50067 L
.50117 .50081 L
.50097 .5009 L
.50077 .50093 L
.50056 .50093 L
.50037 .50088 L
.50019 .50081 L
.50004 .50072 L
.4999 .50061 L
.4998 .5005 L
.49971 .50038 L
.49966 .50027 L
.49962 .50017 L
.49961 .50007 L
.49961 .49999 L
.49963 .49992 L
.49966 .49987 L
.4997 .49983 L
.49975 .4998 L
.49979 .49978 L
.49984 .49978 L
.49989 .49979 L
.49993 .4998 L
.49997 .49982 L
.50001 .49984 L
.50003 .49987 L
.50006 .4999 L
.50007 .49992 L
.50009 .49995 L
.50009 .49997 L
.50009 .49999 L
.50009 .50001 L
Mistroke
.50008 .50003 L
.50008 .50004 L
.50007 .50004 L
.50005 .50005 L
.50004 .50005 L
.50003 .50005 L
.50002 .50005 L
.50001 .50005 L
.5 .50004 L
.5 .50003 L
.49999 .50003 L
.49998 .50002 L
.49998 .50002 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 .225 r
1 .97129 m
.91056 .98863 L
.80376 .9866 L
.70196 .96544 L
.60843 .92907 L
.52558 .88137 L
.45501 .82609 L
.39756 .76663 L
.35344 .70606 L
.32226 .64698 L
.30319 .5915 L
.29505 .54127 L
.29642 .49745 L
.30571 .46077 L
.32128 .43155 L
.34149 .40976 L
.3648 .39507 L
.38977 .38694 L
.41514 .38463 L
.43983 .38731 L
.46297 .39406 L
.48387 .40397 L
.50206 .41613 L
.51725 .42969 L
.52931 .44388 L
.53826 .45804 L
.54424 .4716 L
.5475 .48413 L
.54833 .49527 L
.5471 .50482 L
.54418 .51264 L
.53996 .5187 L
.53482 .52304 L
.52912 .52576 L
.52316 .52701 L
.51724 .52699 L
.51158 .52588 L
.50636 .52392 L
.50173 .52132 L
.49777 .51828 L
.49453 .515 L
.49204 .51165 L
.49026 .50837 L
.48916 .50528 L
.48867 .50247 L
.48871 .50002 L
.48919 .49796 L
.49003 .49631 L
.49114 .49508 L
.49242 .49424 L
Mistroke
.4938 .49376 L
.4952 .49361 L
.49657 .49374 L
.49786 .4941 L
.49903 .49464 L
.50005 .4953 L
.5009 .49605 L
.50158 .49684 L
.50209 .49762 L
.50243 .49838 L
.50262 .49907 L
.50268 .4997 L
.50262 .50023 L
.50246 .50067 L
.50223 .50101 L
.50195 .50126 L
.50164 .50142 L
.50131 .50149 L
.50098 .5015 L
.50066 .50144 L
.50037 .50133 L
.50011 .50119 L
.49989 .50103 L
.49971 .50084 L
.49957 .50066 L
.49947 .50048 L
.4994 .5003 L
.49937 .50015 L
.49937 .50001 L
.4994 .49989 L
.49944 .4998 L
.4995 .49973 L
.49957 .49968 L
.49965 .49966 L
.49973 .49965 L
.4998 .49965 L
.49988 .49967 L
.49994 .4997 L
.5 .49974 L
.50005 .49978 L
.50009 .49982 L
.50011 .49987 L
.50013 .49991 L
.50014 .49995 L
.50015 .49998 L
.50015 .50001 L
.50014 .50004 L
.50012 .50005 L
.50011 .50007 L
.50009 .50008 L
Mistroke
.50007 .50008 L
.50006 .50008 L
.50004 .50008 L
.50002 .50007 L
.50001 .50007 L
.49999 .50006 L
.49998 .50005 L
.49998 .50004 L
.49997 .50003 L
.49997 .50002 L
.49997 .50001 L
.49997 .5 L
.49997 .49999 L
.49997 .49999 L
.49997 .49999 L
.49998 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 .548 1 r
0 .00877 m
.05115 0 L
s
.20459 0 m
.30102 .02176 L
.39675 .06069 L
.48125 .11094 L
.55292 .16867 L
.61098 .23039 L
.65528 .29299 L
.68625 .35381 L
.70481 .41071 L
.71219 .46205 L
.70991 .50667 L
.69959 .54385 L
.68295 .57331 L
.66167 .59511 L
.63734 .60961 L
.61142 .6174 L
.58521 .61924 L
.5598 .61601 L
.53607 .60867 L
.51472 .59816 L
.4962 .58541 L
.48081 .57129 L
.46865 .55659 L
.4597 .54199 L
.4538 .52805 L
.4507 .51522 L
.45006 .50385 L
.45153 .49415 L
.45469 .48624 L
.45916 .48015 L
.46455 .47583 L
.47049 .47317 L
.47665 .47201 L
.48276 .47216 L
.48858 .4734 L
.49392 .4755 L
.49865 .47824 L
.50267 .48142 L
.50594 .48482 L
.50844 .48829 L
.51021 .49167 L
.51129 .49484 L
.51174 .49771 L
.51165 .5002 L
.5111 .50229 L
.51021 .50396 L
.50904 .50519 L
.5077 .50602 L
.50627 .50648 L
.50482 .5066 L
Mistroke
.50341 .50644 L
.50209 .50605 L
.5009 .50548 L
.49986 .50478 L
.49899 .50401 L
.49831 .50319 L
.4978 .50238 L
.49746 .50161 L
.49728 .50089 L
.49723 .50026 L
.49731 .49971 L
.49748 .49927 L
.49772 .49892 L
.49801 .49868 L
.49834 .49852 L
.49868 .49845 L
.49902 .49846 L
.49935 .49852 L
.49964 .49863 L
.49991 .49878 L
.50013 .49896 L
.50032 .49915 L
.50046 .49934 L
.50056 .49953 L
.50062 .4997 L
.50065 .49986 L
.50065 .5 L
.50062 .50012 L
.50057 .50021 L
.50051 .50028 L
.50043 .50033 L
.50035 .50036 L
.50027 .50037 L
.50019 .50036 L
.50012 .50034 L
.50005 .50031 L
.5 .50027 L
.49995 .50022 L
.49991 .50018 L
.49988 .50014 L
.49986 .50009 L
.49985 .50005 L
.49985 .50002 L
.49985 .49999 L
.49986 .49996 L
.49987 .49994 L
.49989 .49993 L
.49991 .49992 L
.49993 .49991 L
.49994 .49991 L
Mistroke
.49996 .49992 L
.49998 .49992 L
.49999 .49993 L
.50001 .49994 L
.50002 .49995 L
.50002 .49996 L
.50003 .49997 L
.50003 .49998 L
.50004 .49999 L
.50004 .5 L
.50003 .50001 L
.50003 .50001 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.216 1 0 r
.21102 1 m
.18871 .97053 L
.1165 .83987 L
.07122 .7166 L
.05035 .60445 L
.05082 .50613 L
.06917 .42335 L
.10181 .35693 L
.14513 .30689 L
.19568 .27261 L
.25029 .25292 L
.30612 .24627 L
.36074 .25084 L
.41216 .26464 L
.45884 .28564 L
.49966 .31183 L
.53395 .34135 L
.56138 .37247 L
.58195 .4037 L
.59593 .43376 L
.60384 .46165 L
.60633 .48659 L
.60416 .50806 L
.59818 .52577 L
.58923 .5396 L
.57815 .54963 L
.56572 .55606 L
.55266 .55922 L
.53959 .5595 L
.52704 .55736 L
.51542 .55327 L
.50505 .5477 L
.49614 .54112 L
.48882 .53396 L
.48312 .52658 L
.47901 .51933 L
.47639 .51247 L
.47515 .50621 L
.47509 .5007 L
.47605 .49606 L
.4778 .49231 L
.48016 .48948 L
.48294 .48752 L
.48595 .48637 L
.48904 .48596 L
.49208 .48617 L
.49494 .4869 L
.49754 .48804 L
.49983 .48947 L
.50176 .49109 L
Mistroke
.5033 .49281 L
.50447 .49454 L
.50527 .49622 L
.50573 .49777 L
.50589 .49916 L
.50578 .50037 L
.50547 .50136 L
.50498 .50214 L
.50437 .50271 L
.50369 .50308 L
.50297 .50327 L
.50224 .5033 L
.50155 .50319 L
.5009 .50297 L
.50032 .50267 L
.49982 .5023 L
.49941 .50191 L
.49909 .5015 L
.49885 .5011 L
.4987 .50072 L
.49863 .50037 L
.49862 .50006 L
.49867 .4998 L
.49876 .49959 L
.49889 .49943 L
.49904 .49932 L
.49921 .49925 L
.49938 .49922 L
.49955 .49923 L
.49971 .49927 L
.49985 .49933 L
.49998 .49941 L
.50009 .4995 L
.50018 .4996 L
.50024 .49969 L
.50029 .49978 L
.50032 .49987 L
.50033 .49995 L
.50032 .50002 L
.5003 .50007 L
.50028 .50012 L
.50024 .50015 L
.50021 .50017 L
.50017 .50018 L
.50013 .50018 L
.50009 .50018 L
.50005 .50017 L
.50002 .50015 L
.49999 .50013 L
.49997 .50011 L
Mistroke
.49995 .50008 L
.49994 .50006 L
.49993 .50004 L
.49992 .50002 L
.49992 .5 L
.49993 .49999 L
.49993 .49998 L
.49994 .49997 L
.49995 .49996 L
.49996 .49996 L
.49997 .49996 L
.49997 .49996 L
.49998 .49996 L
.49999 .49996 L
.5 .49997 L
.5 .49997 L
.50001 .49998 L
.50001 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.331 0 1 r
.37655 0 m
.46374 .04902 L
.54746 .1133 L
.61584 .18273 L
.6686 .2537 L
.70616 .32312 L
.72944 .38848 L
.73981 .4478 L
.73892 .49968 L
.72862 .54325 L
.71083 .57809 L
.68747 .60422 L
.66036 .62198 L
.63119 .63202 L
.60146 .63516 L
.57244 .6324 L
.54519 .62478 L
.5205 .6134 L
.49896 .59931 L
.48091 .58351 L
.46653 .5669 L
.4558 .55029 L
.44855 .53433 L
.44453 .51957 L
.44337 .50639 L
.44466 .49507 L
.44796 .48576 L
.45281 .47852 L
.45876 .4733 L
.46541 .46999 L
.47238 .46841 L
.47933 .46834 L
.48599 .46955 L
.49215 .47179 L
.49763 .47479 L
.50232 .47832 L
.50617 .48215 L
.50915 .48608 L
.51129 .48994 L
.51263 .49357 L
.51326 .49689 L
.51325 .49979 L
.51271 .50224 L
.51176 .5042 L
.51048 .50568 L
.50899 .5067 L
.50738 .50728 L
.50574 .50748 L
.50412 .50735 L
.50261 .50695 L
Mistroke
.50123 .50633 L
.50002 .50556 L
.49901 .50469 L
.4982 .50377 L
.49759 .50285 L
.49717 .50196 L
.49694 .50114 L
.49686 .5004 L
.49693 .49977 L
.4971 .49925 L
.49737 .49884 L
.49769 .49854 L
.49806 .49835 L
.49844 .49825 L
.49883 .49824 L
.4992 .49831 L
.49954 .49843 L
.49985 .49859 L
.50011 .49878 L
.50033 .499 L
.5005 .49921 L
.50062 .49943 L
.5007 .49963 L
.50073 .49982 L
.50073 .49998 L
.50071 .50011 L
.50066 .50023 L
.50059 .50031 L
.5005 .50037 L
.50042 .5004 L
.50032 .50041 L
.50023 .50041 L
.50015 .50039 L
.50007 .50035 L
.50001 .50031 L
.49995 .50026 L
.4999 .50021 L
.49987 .50016 L
.49984 .50011 L
.49983 .50007 L
.49983 .50003 L
.49983 .49999 L
.49984 .49996 L
.49985 .49994 L
.49987 .49992 L
.49989 .49991 L
.49991 .4999 L
.49993 .4999 L
.49995 .49991 L
.49997 .49991 L
Mistroke
.49999 .49992 L
.50001 .49993 L
.50002 .49994 L
.50003 .49996 L
.50003 .49997 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50004 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 .097 r
.50191 1 m
.46192 .971 L
.37778 .89002 L
.31204 .80646 L
.26437 .72405 L
.23377 .64591 L
.21873 .57449 L
.21736 .51155 L
.22751 .45825 L
.24692 .41518 L
.27334 .38242 L
.30458 .35961 L
.33863 .34609 L
.37365 .34089 L
.40811 .34288 L
.44071 .35084 L
.47045 .36349 L
.4966 .37957 L
.51868 .39788 L
.53647 .41733 L
.54995 .43697 L
.55926 .45597 L
.56471 .47369 L
.5667 .48961 L
.5657 .50339 L
.56224 .51483 L
.55684 .52383 L
.55003 .53044 L
.54232 .53477 L
.53415 .53701 L
.52593 .53741 L
.51799 .53626 L
.51061 .53383 L
.50399 .53045 L
.49827 .52639 L
.49354 .52192 L
.48982 .5173 L
.48711 .51273 L
.48535 .50838 L
.48446 .50439 L
.48433 .50087 L
.48485 .49788 L
.4859 .49546 L
.48734 .4936 L
.48905 .4923 L
.49093 .49152 L
.49286 .4912 L
.49478 .49128 L
.49659 .4917 L
.49825 .49238 L
Mistroke
.49971 .49326 L
.50095 .49427 L
.50196 .49534 L
.50272 .49643 L
.50325 .49749 L
.50357 .49848 L
.50369 .49936 L
.50365 .50014 L
.50346 .50078 L
.50317 .50129 L
.5028 .50166 L
.50237 .50191 L
.50192 .50204 L
.50147 .50207 L
.50103 .50201 L
.50062 .50188 L
.50025 .5017 L
.49993 .50148 L
.49966 .50123 L
.49945 .50098 L
.4993 .50072 L
.49919 .50048 L
.49914 .50026 L
.49913 .50006 L
.49916 .49989 L
.49921 .49976 L
.49929 .49965 L
.49939 .49958 L
.49949 .49953 L
.4996 .49951 L
.4997 .49952 L
.4998 .49954 L
.4999 .49958 L
.49998 .49962 L
.50005 .49968 L
.5001 .49974 L
.50015 .4998 L
.50018 .49986 L
.5002 .49991 L
.5002 .49996 L
.5002 .5 L
.50019 .50004 L
.50018 .50007 L
.50016 .50009 L
.50013 .50011 L
.50011 .50011 L
.50008 .50011 L
.50006 .50011 L
.50004 .5001 L
.50001 .50009 L
Mistroke
.5 .50008 L
.49998 .50007 L
.49997 .50006 L
.49996 .50004 L
.49996 .50003 L
.49995 .50002 L
.49995 .5 L
.49995 .49999 L
.49996 .49999 L
.49996 .49998 L
.49997 .49998 L
.49997 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 1 .591 r
.2223 1 m
.18814 .95397 L
.11897 .82581 L
.07614 .70519 L
.05714 .59574 L
.0589 .50003 L
.07801 .41968 L
.11094 .35544 L
.15413 .3073 L
.20422 .27459 L
.2581 .25615 L
.313 .25042 L
.36657 .25559 L
.41687 .2697 L
.46242 .29076 L
.50216 .3168 L
.53543 .34599 L
.56195 .37666 L
.58173 .40733 L
.59507 .43678 L
.60246 .46403 L
.60457 .48835 L
.60216 .50923 L
.59605 .52639 L
.58708 .53973 L
.57607 .54935 L
.56378 .55545 L
.55092 .55835 L
.53808 .55845 L
.52579 .5562 L
.51443 .55206 L
.50432 .54651 L
.49566 .53999 L
.48857 .53291 L
.48307 .52566 L
.47913 .51854 L
.47666 .51182 L
.47552 .50571 L
.47554 .50036 L
.47653 .49584 L
.47831 .49222 L
.48066 .48949 L
.48342 .48762 L
.48639 .48655 L
.48943 .48618 L
.4924 .48643 L
.4952 .48718 L
.49775 .48832 L
.49997 .48975 L
.50184 .49135 L
Mistroke
.50334 .49305 L
.50446 .49475 L
.50522 .49639 L
.50565 .4979 L
.50579 .49926 L
.50567 .50043 L
.50535 .5014 L
.50486 .50215 L
.50426 .5027 L
.50358 .50305 L
.50287 .50322 L
.50216 .50324 L
.50148 .50312 L
.50084 .5029 L
.50028 .5026 L
.49979 .50224 L
.49939 .50185 L
.49908 .50145 L
.49886 .50105 L
.49872 .50068 L
.49865 .50034 L
.49864 .50004 L
.4987 .49979 L
.49879 .49958 L
.49892 .49943 L
.49907 .49932 L
.49923 .49926 L
.4994 .49924 L
.49957 .49925 L
.49972 .49929 L
.49987 .49935 L
.49999 .49943 L
.5001 .49951 L
.50018 .49961 L
.50024 .4997 L
.50029 .49979 L
.50031 .49988 L
.50032 .49995 L
.50031 .50002 L
.5003 .50007 L
.50027 .50012 L
.50024 .50015 L
.5002 .50017 L
.50016 .50018 L
.50012 .50018 L
.50008 .50017 L
.50005 .50016 L
.50002 .50015 L
.49999 .50013 L
.49997 .5001 L
Mistroke
.49995 .50008 L
.49994 .50006 L
.49993 .50004 L
.49993 .50002 L
.49992 .5 L
.49993 .49999 L
.49993 .49998 L
.49994 .49997 L
.49995 .49996 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49999 .49996 L
.5 .49997 L
.5 .49997 L
.50001 .49998 L
.50001 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.925 1 0 r
.83554 0 m
.88065 .07011 L
.94245 .20702 L
.97664 .33366 L
.98627 .44662 L
.97492 .54358 L
.94639 .62324 L
.9046 .68517 L
.85333 .72976 L
.79617 .758 L
.73633 .77139 L
.67666 .77178 L
.6195 .76124 L
.56673 .74194 L
.51977 .71607 L
.47956 .6857 L
.44662 .65279 L
.42111 .61905 L
.40284 .58597 L
.39139 .55476 L
.38613 .52637 L
.38626 .50148 L
.39092 .48053 L
.39919 .46373 L
.41017 .45107 L
.42298 .4424 L
.43681 .43742 L
.45095 .43575 L
.46478 .43691 L
.47779 .44041 L
.48961 .44573 L
.49994 .45237 L
.50862 .45985 L
.51556 .46773 L
.52076 .47564 L
.5243 .48325 L
.5263 .49031 L
.52692 .49662 L
.52637 .50206 L
.52486 .50654 L
.52259 .51004 L
.51978 .51257 L
.51663 .5142 L
.51333 .515 L
.51002 .51507 L
.50684 .51452 L
.5039 .51349 L
.50127 .51208 L
.49902 .51041 L
.49716 .50859 L
Mistroke
.49572 .50673 L
.49468 .50489 L
.49402 .50315 L
.49371 .50157 L
.49369 .50017 L
.49393 .499 L
.49438 .49805 L
.49498 .49733 L
.49568 .49684 L
.49645 .49655 L
.49723 .49644 L
.498 .4965 L
.49872 .49668 L
.49938 .49697 L
.49996 .49733 L
.50045 .49775 L
.50084 .49818 L
.50113 .49862 L
.50133 .49904 L
.50145 .49944 L
.50149 .49979 L
.50146 .50009 L
.50138 .50035 L
.50126 .50054 L
.50111 .50069 L
.50093 .50078 L
.50075 .50083 L
.50057 .50084 L
.50039 .50081 L
.50023 .50075 L
.50008 .50067 L
.49995 .50058 L
.49985 .50048 L
.49977 .50038 L
.49971 .50028 L
.49967 .50018 L
.49965 .50009 L
.49965 .50001 L
.49966 .49995 L
.49969 .4999 L
.49972 .49985 L
.49976 .49983 L
.4998 .49981 L
.49984 .4998 L
.49989 .49981 L
.49993 .49982 L
.49996 .49983 L
.5 .49985 L
.50002 .49987 L
.50004 .4999 L
Mistroke
.50006 .49992 L
.50007 .49995 L
.50008 .49997 L
.50008 .49999 L
.50008 .5 L
.50008 .50002 L
.50007 .50003 L
.50006 .50004 L
.50005 .50004 L
.50004 .50005 L
.50003 .50005 L
.50002 .50004 L
.50001 .50004 L
.5 .50004 L
.5 .50003 L
.49999 .50003 L
.49999 .50002 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 .612 0 r
.4585 0 m
.4622 .0021 L
.55453 .07348 L
.62985 .15045 L
.68789 .22905 L
.7291 .30586 L
.75453 .37811 L
.7657 .44363 L
.76445 .50088 L
.75283 .54891 L
.73296 .58728 L
.70696 .61599 L
.67687 .63545 L
.64453 .64638 L
.6116 .64969 L
.5795 .64649 L
.54937 .63794 L
.5221 .62525 L
.49833 .60959 L
.47844 .59206 L
.46261 .57366 L
.45081 .55527 L
.44288 .53763 L
.4385 .52131 L
.43728 .50676 L
.43877 .49427 L
.44247 .48402 L
.44787 .47605 L
.4545 .47032 L
.46187 .4667 L
.46959 .46499 L
.47729 .46495 L
.48465 .46632 L
.49145 .46882 L
.4975 .47217 L
.50268 .47609 L
.50692 .48033 L
.5102 .48469 L
.51255 .48895 L
.51402 .49297 L
.51469 .49663 L
.51467 .49984 L
.51406 .50253 L
.51299 .5047 L
.51157 .50632 L
.50992 .50744 L
.50813 .50808 L
.50631 .50829 L
.50453 .50813 L
.50285 .50768 L
Mistroke
.50133 .50699 L
.5 .50613 L
.49888 .50517 L
.49799 .50415 L
.49732 .50313 L
.49686 .50215 L
.49661 .50124 L
.49653 .50043 L
.4966 .49973 L
.4968 .49915 L
.49709 .4987 L
.49745 .49838 L
.49786 .49817 L
.49829 .49807 L
.49871 .49806 L
.49912 .49813 L
.4995 .49826 L
.49984 .49844 L
.50013 .49866 L
.50037 .49889 L
.50055 .49913 L
.50069 .49937 L
.50077 .4996 L
.50081 .4998 L
.50081 .49998 L
.50078 .50013 L
.50072 .50025 L
.50065 .50034 L
.50056 .50041 L
.50046 .50045 L
.50036 .50046 L
.50026 .50045 L
.50016 .50043 L
.50008 .50039 L
.5 .50034 L
.49994 .50029 L
.49989 .50023 L
.49985 .50018 L
.49983 .50012 L
.49981 .50007 L
.49981 .50003 L
.49981 .49999 L
.49982 .49996 L
.49984 .49993 L
.49986 .49991 L
.49988 .4999 L
.4999 .49989 L
.49993 .49989 L
.49995 .4999 L
.49997 .4999 L
Mistroke
.49999 .49991 L
.50001 .49992 L
.50002 .49994 L
.50003 .49995 L
.50004 .49996 L
.50004 .49998 L
.50004 .49999 L
.50005 .5 L
.50004 .50001 L
.50004 .50001 L
.50004 .50002 L
.50003 .50002 L
.50003 .50002 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.689 1 0 r
.52009 1 m
.49063 .98047 L
.40352 .90324 L
.33426 .82228 L
.28274 .74143 L
.24818 .66391 L
.22924 .59228 L
.22417 .52846 L
.23094 .47375 L
.24739 .42887 L
.2713 .39404 L
.30051 .36903 L
.33301 .35328 L
.36697 .34593 L
.4008 .34592 L
.43317 .35207 L
.46301 .36315 L
.48954 .37792 L
.51223 .39521 L
.53079 .41391 L
.54513 .43305 L
.55537 .45179 L
.56175 .46945 L
.56464 .4855 L
.56448 .49956 L
.56176 .51137 L
.55702 .52083 L
.55075 .52794 L
.54346 .53279 L
.5356 .53556 L
.52758 .53645 L
.51975 .53575 L
.51238 .53372 L
.5057 .53068 L
.49987 .5269 L
.49497 .52264 L
.49107 .51817 L
.48815 .51369 L
.48617 .50938 L
.48506 .50538 L
.48473 .50181 L
.48506 .49875 L
.48593 .49622 L
.48723 .49425 L
.48883 .49283 L
.49062 .49192 L
.4925 .49149 L
.49437 .49146 L
.49617 .49178 L
.49784 .49237 L
Mistroke
.49932 .49318 L
.50059 .49413 L
.50164 .49516 L
.50245 .49622 L
.50303 .49726 L
.5034 .49824 L
.50357 .49914 L
.50358 .49992 L
.50343 .50059 L
.50318 .50112 L
.50284 .50152 L
.50244 .5018 L
.502 .50196 L
.50156 .50202 L
.50112 .50198 L
.50071 .50188 L
.50034 .50171 L
.50001 .50151 L
.49974 .50127 L
.49952 .50102 L
.49935 .50078 L
.49924 .50054 L
.49918 .50031 L
.49915 .50011 L
.49917 .49994 L
.49922 .4998 L
.49929 .49969 L
.49937 .49961 L
.49947 .49956 L
.49958 .49953 L
.49968 .49953 L
.49978 .49954 L
.49987 .49957 L
.49996 .49962 L
.50003 .49967 L
.50009 .49973 L
.50013 .49979 L
.50017 .49984 L
.50019 .4999 L
.5002 .49995 L
.5002 .49999 L
.50019 .50003 L
.50018 .50006 L
.50016 .50008 L
.50014 .5001 L
.50011 .50011 L
.50009 .50011 L
.50006 .50011 L
.50004 .5001 L
.50002 .5001 L
Mistroke
.5 .50008 L
.49999 .50007 L
.49997 .50006 L
.49996 .50004 L
.49996 .50003 L
.49995 .50002 L
.49995 .50001 L
.49995 .5 L
.49996 .49999 L
.49996 .49998 L
.49997 .49998 L
.49997 .49998 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.033 0 1 r
.48305 0 m
.56277 .06291 L
.63966 .14305 L
.69862 .22459 L
.74018 .30406 L
.76546 .37861 L
.77606 .44604 L
.77392 .5048 L
.76117 .55394 L
.74003 .59303 L
.71268 .62213 L
.68121 .64167 L
.64755 .65241 L
.6134 .65533 L
.58019 .65157 L
.54911 .64235 L
.52105 .62892 L
.49666 .61249 L
.47631 .5942 L
.46018 .57508 L
.44823 .55602 L
.44027 .53779 L
.43598 .52097 L
.43493 .50601 L
.43666 .49322 L
.44064 .48275 L
.44636 .47465 L
.4533 .46886 L
.461 .46525 L
.46902 .46361 L
.47699 .46368 L
.4846 .4652 L
.49161 .46787 L
.49782 .47139 L
.50313 .47549 L
.50746 .47991 L
.51079 .48443 L
.51316 .48884 L
.51462 .49299 L
.51527 .49676 L
.5152 .50005 L
.51453 .50281 L
.51339 .50501 L
.51189 .50666 L
.51016 .50778 L
.50831 .50841 L
.50641 .5086 L
.50457 .50842 L
.50284 .50793 L
.50127 .5072 L
Mistroke
.49991 .5063 L
.49876 .50529 L
.49785 .50423 L
.49717 .50318 L
.49672 .50216 L
.49647 .50123 L
.4964 .50039 L
.49648 .49967 L
.49669 .49908 L
.497 .49862 L
.49739 .49829 L
.49781 .49809 L
.49825 .49799 L
.49869 .49799 L
.49912 .49806 L
.49951 .49821 L
.49986 .4984 L
.50015 .49863 L
.5004 .49887 L
.50059 .49912 L
.50072 .49936 L
.50081 .4996 L
.50084 .49981 L
.50084 .49999 L
.50081 .50015 L
.50075 .50027 L
.50066 .50036 L
.50057 .50043 L
.50047 .50046 L
.50036 .50048 L
.50026 .50047 L
.50016 .50044 L
.50008 .5004 L
.5 .50035 L
.49994 .5003 L
.49988 .50024 L
.49985 .50018 L
.49982 .50012 L
.49981 .50007 L
.4998 .50002 L
.4998 .49998 L
.49982 .49995 L
.49983 .49993 L
.49985 .49991 L
.49988 .49989 L
.4999 .49989 L
.49993 .49989 L
.49995 .49989 L
.49997 .4999 L
.49999 .49991 L
Mistroke
.50001 .49992 L
.50002 .49994 L
.50003 .49995 L
.50004 .49996 L
.50004 .49998 L
.50005 .49999 L
.50005 .5 L
.50004 .50001 L
.50004 .50001 L
.50004 .50002 L
.50003 .50002 L
.50003 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.884 1 0 r
0 .17023 m
.01372 .15973 L
.09678 .12464 L
.18263 .1102 L
.26738 .11366 L
.34784 .13202 L
.42146 .16215 L
.4864 .20095 L
.54146 .24548 L
.58602 .29303 L
.61999 .34124 L
.64371 .38805 L
.65787 .43182 L
.66345 .47129 L
.66159 .50557 L
.65357 .53413 L
.6407 .55674 L
.62426 .57345 L
.6055 .58454 L
.58553 .59046 L
.56534 .59182 L
.54579 .58929 L
.52754 .5836 L
.51112 .57547 L
.49689 .56563 L
.48507 .55475 L
.47574 .54342 L
.46889 .53218 L
.46437 .52146 L
.46201 .51159 L
.46154 .50285 L
.46269 .4954 L
.46515 .48933 L
.4686 .48466 L
.47276 .48135 L
.47734 .47932 L
.48209 .47844 L
.48679 .47857 L
.49126 .47953 L
.49537 .48116 L
.499 .48328 L
.50209 .48572 L
.5046 .48835 L
.50653 .49102 L
.50788 .49362 L
.5087 .49606 L
.50904 .49826 L
.50897 .50018 L
.50854 .50179 L
.50785 .50306 L
Mistroke
.50695 .50401 L
.50592 .50465 L
.50482 .50499 L
.5037 .50509 L
.50261 .50496 L
.50159 .50466 L
.50068 .50421 L
.49988 .50368 L
.49922 .50308 L
.49869 .50245 L
.4983 .50183 L
.49804 .50123 L
.4979 .50068 L
.49787 .50019 L
.49793 .49977 L
.49806 .49943 L
.49825 .49917 L
.49847 .49898 L
.49873 .49886 L
.49899 .49881 L
.49925 .49881 L
.4995 .49886 L
.49973 .49895 L
.49993 .49906 L
.5001 .4992 L
.50025 .49934 L
.50035 .49949 L
.50043 .49964 L
.50048 .49977 L
.5005 .4999 L
.5005 .5 L
.50048 .50009 L
.50044 .50017 L
.50039 .50022 L
.50033 .50026 L
.50027 .50028 L
.50021 .50028 L
.50015 .50028 L
.50009 .50026 L
.50004 .50024 L
.5 .50021 L
.49996 .50017 L
.49993 .50014 L
.49991 .5001 L
.49989 .50007 L
.49988 .50004 L
.49988 .50001 L
.49988 .49999 L
.49989 .49997 L
.4999 .49995 L
Mistroke
.49991 .49994 L
.49993 .49994 L
.49994 .49993 L
.49996 .49993 L
.49997 .49994 L
.49998 .49994 L
.5 .49995 L
.50001 .49996 L
.50001 .49996 L
.50002 .49997 L
.50002 .49998 L
.50003 .49999 L
.50003 .49999 L
.50003 .5 L
.50003 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 .716 0 r
.87861 0 m
.901 .03423 L
.96845 .18048 L
s
.96845 .18048 m
1 .29333 L
s
1 .56145 m
.97739 .62721 L
.93353 .69417 L
.87937 .74261 L
.81874 .77357 L
.75509 .78863 L
.69146 .78972 L
.63039 .77906 L
.57391 .75894 L
.52354 .7317 L
.48032 .69957 L
.44482 .66461 L
.41723 .62869 L
.39738 .59339 L
.38482 .56001 L
.37888 .5296 L
.37874 .50289 L
.38347 .48035 L
.3921 .46221 L
.40366 .4485 L
.41722 .43904 L
.43191 .43355 L
.44696 .43159 L
.46172 .43268 L
.47564 .43629 L
.4883 .44187 L
.4994 .44888 L
.50874 .4568 L
.51623 .46518 L
.52186 .47361 L
.52572 .48174 L
.52793 .4893 L
.52867 .49607 L
.52815 .50191 L
.52658 .50673 L
.5242 .51052 L
.52123 .51327 L
.5179 .51505 L
.51438 .51595 L
.51085 .51606 L
.50746 .51551 L
.50431 .51443 L
.50149 .51295 L
.49907 .51118 L
.49707 .50926 L
.49551 .50727 L
.49438 .50531 L
.49366 .50345 L
.49331 .50175 L
.49328 .50026 L
Mistroke
.49352 .49899 L
.49399 .49797 L
.49462 .4972 L
.49536 .49666 L
.49617 .49634 L
.497 .49621 L
.49782 .49626 L
.4986 .49645 L
.4993 .49676 L
.49993 .49714 L
.50045 .49758 L
.50087 .49804 L
.50119 .49851 L
.50141 .49896 L
.50154 .49938 L
.50159 .49976 L
.50156 .50008 L
.50148 .50036 L
.50135 .50057 L
.50119 .50073 L
.501 .50083 L
.50081 .50088 L
.50061 .50089 L
.50043 .50086 L
.50025 .5008 L
.50009 .50072 L
.49996 .50063 L
.49985 .50052 L
.49976 .50041 L
.49969 .5003 L
.49965 .5002 L
.49963 .5001 L
.49963 .50002 L
.49964 .49995 L
.49966 .49989 L
.4997 .49985 L
.49974 .49982 L
.49978 .4998 L
.49983 .49979 L
.49988 .49979 L
.49992 .4998 L
.49996 .49982 L
.49999 .49984 L
.50002 .49986 L
.50005 .49989 L
.50006 .49992 L
.50008 .49994 L
.50008 .49996 L
.50009 .49999 L
.50009 .5 L
Mistroke
.50008 .50002 L
.50008 .50003 L
.50007 .50004 L
.50006 .50005 L
.50005 .50005 L
.50003 .50005 L
.50002 .50005 L
.50001 .50004 L
.50001 .50004 L
.5 .50004 L
.49999 .50003 L
.49999 .50002 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 1 .928 r
.33949 1 m
.27878 .92895 L
.21024 .82123 L
.16429 .71796 L
.13914 .62255 L
.13246 .53756 L
.14155 .46471 L
.16352 .40497 L
.19541 .35862 L
.23437 .32536 L
.27769 .30443 L
.32295 .29468 L
.36802 .2947 L
.41113 .30293 L
.45088 .31772 L
.48621 .33743 L
.51642 .36047 L
.54112 .38539 L
.56021 .4109 L
.57383 .43587 L
.58231 .4594 L
.58614 .48077 L
.58591 .49949 L
.58228 .51522 L
.57594 .52781 L
.56758 .53727 L
.55787 .54372 L
.54739 .54739 L
.53671 .54857 L
.52627 .54762 L
.51646 .54492 L
.50756 .54086 L
.49979 .53581 L
.49328 .53015 L
.48808 .52418 L
.48419 .51821 L
.48156 .51247 L
.48009 .50715 L
.47965 .5024 L
.48009 .49831 L
.48126 .49495 L
.48299 .49233 L
.48513 .49044 L
.48751 .48923 L
.49002 .48865 L
.49252 .48862 L
.49491 .48904 L
.49713 .48984 L
.4991 .49091 L
.5008 .49218 L
Mistroke
.50219 .49355 L
.50327 .49497 L
.50404 .49635 L
.50453 .49766 L
.50476 .49885 L
.50476 .4999 L
.50458 .50079 L
.50423 .5015 L
.50378 .50203 L
.50324 .5024 L
.50267 .50261 L
.50207 .50269 L
.5015 .50264 L
.50095 .5025 L
.50045 .50228 L
.50002 .502 L
.49965 .50169 L
.49936 .50136 L
.49914 .50103 L
.49899 .50071 L
.4989 .50042 L
.49887 .50015 L
.49889 .49992 L
.49896 .49973 L
.49905 .49958 L
.49917 .49948 L
.4993 .49941 L
.49944 .49937 L
.49958 .49937 L
.49971 .49939 L
.49983 .49943 L
.49994 .49949 L
.50004 .49956 L
.50012 .49964 L
.50018 .49972 L
.50022 .49979 L
.50025 .49987 L
.50026 .49993 L
.50026 .49999 L
.50025 .50004 L
.50024 .50008 L
.50021 .50011 L
.50018 .50013 L
.50015 .50014 L
.50012 .50015 L
.50009 .50015 L
.50005 .50014 L
.50003 .50013 L
.5 .50011 L
.49998 .50009 L
Mistroke
.49997 .50008 L
.49995 .50006 L
.49994 .50004 L
.49994 .50002 L
.49994 .50001 L
.49994 .5 L
.49994 .49999 L
.49995 .49998 L
.49995 .49997 L
.49996 .49997 L
.49997 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.5 .49997 L
.5 .49998 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 .255 0 r
.45764 0 m
.48274 .01524 L
.57178 .08829 L
.64366 .16608 L
.69825 .24474 L
.73615 .32097 L
.75853 .39212 L
.76697 .45617 L
.76338 .51169 L
.74983 .55782 L
.72847 .59424 L
.7014 .62104 L
.67063 .6387 L
.63797 .64798 L
.60503 .64985 L
.57319 .64542 L
.54353 .6359 L
.51689 .62246 L
.49385 .60629 L
.47476 .58846 L
.45974 .56996 L
.44874 .55163 L
.44156 .53418 L
.43787 .51816 L
.43725 .50399 L
.43925 .49193 L
.44335 .48213 L
.44906 .47462 L
.45589 .46933 L
.46339 .46612 L
.47114 .46478 L
.47881 .46506 L
.48609 .46669 L
.49276 .46939 L
.49865 .47289 L
.50365 .4769 L
.5077 .4812 L
.51079 .48556 L
.51295 .48979 L
.51425 .49375 L
.51477 .49733 L
.51462 .50044 L
.5139 .50303 L
.51275 .50509 L
.51127 .50661 L
.50957 .50762 L
.50777 .50817 L
.50595 .5083 L
.50418 .50808 L
.50252 .50757 L
Mistroke
.50104 .50684 L
.49974 .50595 L
.49867 .50497 L
.49782 .50395 L
.4972 .50293 L
.49679 .50196 L
.49657 .50107 L
.49652 .50027 L
.49662 .4996 L
.49684 .49905 L
.49715 .49862 L
.49753 .49832 L
.49794 .49813 L
.49837 .49805 L
.4988 .49806 L
.4992 .49815 L
.49957 .49829 L
.4999 .49848 L
.50018 .4987 L
.50041 .49894 L
.50059 .49918 L
.50071 .49942 L
.50079 .49964 L
.50082 .49984 L
.50081 .50001 L
.50077 .50016 L
.50071 .50027 L
.50063 .50036 L
.50054 .50042 L
.50044 .50045 L
.50034 .50046 L
.50024 .50045 L
.50015 .50042 L
.50006 .50038 L
.49999 .50033 L
.49993 .50028 L
.49988 .50022 L
.49985 .50017 L
.49982 .50011 L
.49981 .50006 L
.49981 .50002 L
.49981 .49998 L
.49982 .49995 L
.49984 .49993 L
.49986 .49991 L
.49988 .4999 L
.49991 .49989 L
.49993 .49989 L
.49995 .4999 L
.49998 .4999 L
Mistroke
.49999 .49992 L
.50001 .49993 L
.50002 .49994 L
.50003 .49995 L
.50004 .49997 L
.50004 .49998 L
.50005 .49999 L
.50004 .5 L
.50004 .50001 L
.50004 .50001 L
.50004 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 .298 1 r
.405 0 m
.45618 .02813 L
.54403 .09432 L
.61601 .1661 L
.6718 .23972 L
.71176 .31192 L
.73684 .38006 L
.74842 .44205 L
.74821 .49641 L
.7381 .54218 L
.7201 .57892 L
.69618 .6066 L
.66826 .62558 L
.6381 .63649 L
.60725 .64019 L
.57707 .63769 L
.54865 .63008 L
.52284 .61849 L
.50027 .60403 L
.48131 .58773 L
.46614 .57053 L
.45476 .55328 L
.44702 .53667 L
.44264 .52125 L
.44125 .50746 L
.44244 .49559 L
.44574 .4858 L
.45068 .47815 L
.4568 .4726 L
.46366 .46904 L
.47087 .46728 L
.4781 .46712 L
.48503 .4683 L
.49146 .47056 L
.49719 .47363 L
.50211 .47726 L
.50616 .48122 L
.50932 .4853 L
.51159 .4893 L
.51304 .4931 L
.51373 .49656 L
.51376 .4996 L
.51324 .50217 L
.51227 .50424 L
.51097 .50581 L
.50943 .50689 L
.50777 .50753 L
.50606 .50776 L
.50438 .50764 L
.5028 .50724 L
Mistroke
.50136 .50661 L
.5001 .50582 L
.49903 .50492 L
.49818 .50397 L
.49753 .50302 L
.49709 .50209 L
.49684 .50124 L
.49675 .50046 L
.4968 .4998 L
.49698 .49925 L
.49725 .49882 L
.49758 .4985 L
.49796 .4983 L
.49836 .49819 L
.49876 .49818 L
.49914 .49824 L
.4995 .49836 L
.49982 .49853 L
.5001 .49873 L
.50033 .49894 L
.5005 .49917 L
.50063 .49939 L
.50072 .4996 L
.50076 .4998 L
.50076 .49997 L
.50074 .50011 L
.50068 .50023 L
.50061 .50032 L
.50053 .50038 L
.50044 .50041 L
.50034 .50043 L
.50025 .50042 L
.50016 .5004 L
.50008 .50037 L
.50001 .50033 L
.49995 .50028 L
.4999 .50022 L
.49987 .50017 L
.49984 .50012 L
.49983 .50007 L
.49982 .50003 L
.49982 .49999 L
.49983 .49996 L
.49985 .49994 L
.49986 .49992 L
.49989 .49991 L
.49991 .4999 L
.49993 .4999 L
.49995 .4999 L
.49997 .49991 L
Mistroke
.49999 .49992 L
.5 .49993 L
.50002 .49994 L
.50003 .49995 L
.50003 .49997 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50004 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 .706 r
.67536 1 m
.59389 .96419 L
.50527 .90833 L
.43067 .84511 L
.37081 .77823 L
.32574 .71097 L
.29486 .64606 L
.27715 .58574 L
.27119 .53167 L
.27534 .48502 L
.28781 .44645 L
.30676 .41622 L
.3304 .39419 L
.35702 .37993 L
.38509 .37276 L
.41324 .37183 L
.44035 .37618 L
.46549 .38477 L
.48797 .3966 L
.50733 .41066 L
.52328 .42604 L
.53574 .44191 L
.54478 .45755 L
.55057 .47238 L
.55341 .48593 L
.55366 .49787 L
.55172 .50798 L
.54802 .51614 L
.543 .52235 L
.53707 .52667 L
.5306 .52923 L
.52395 .53021 L
.51741 .52982 L
.51122 .52831 L
.50558 .5259 L
.50062 .52285 L
.49643 .51937 L
.49306 .51567 L
.49051 .51195 L
.48874 .50834 L
.48771 .50498 L
.48734 .50196 L
.48753 .49934 L
.48819 .49717 L
.48922 .49547 L
.49051 .49422 L
.49197 .4934 L
.49352 .49297 L
.49509 .4929 L
.49659 .49312 L
Mistroke
.49799 .49358 L
.49925 .49422 L
.50033 .49499 L
.50123 .49584 L
.50194 .49672 L
.50245 .49759 L
.50278 .49841 L
.50295 .49917 L
.50297 .49984 L
.50287 .5004 L
.50268 .50086 L
.5024 .50122 L
.50208 .50146 L
.50172 .50161 L
.50135 .50167 L
.50099 .50165 L
.50065 .50158 L
.50033 .50144 L
.50005 .50128 L
.49982 .50109 L
.49963 .50088 L
.49948 .50068 L
.49938 .50048 L
.49932 .50029 L
.4993 .50012 L
.49931 .49997 L
.49934 .49985 L
.4994 .49976 L
.49947 .49968 L
.49955 .49964 L
.49964 .49961 L
.49972 .49961 L
.49981 .49962 L
.49988 .49964 L
.49995 .49968 L
.50001 .49972 L
.50006 .49977 L
.5001 .49981 L
.50013 .49986 L
.50015 .49991 L
.50016 .49995 L
.50016 .49999 L
.50016 .50002 L
.50015 .50005 L
.50013 .50007 L
.50012 .50008 L
.5001 .50009 L
.50008 .50009 L
.50006 .50009 L
.50004 .50009 L
Mistroke
.50002 .50008 L
.5 .50007 L
.49999 .50006 L
.49998 .50005 L
.49997 .50004 L
.49997 .50003 L
.49996 .50002 L
.49996 .50001 L
.49996 .5 L
.49996 .49999 L
.49997 .49999 L
.49997 .49998 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 1 .709 r
.60995 0 m
.68091 .07658 L
.75019 .17609 L
.79835 .27257 L
.82684 .36266 L
.83769 .44378 L
.83329 .51413 L
.81627 .57261 L
.78934 .61881 L
.75515 .65283 L
.71626 .67528 L
.67496 .68712 L
.63329 .68958 L
.59298 .68405 L
.55543 .67206 L
.52169 .65511 L
.49249 .63468 L
.46829 .61214 L
.44924 .58874 L
.43527 .56554 L
.42614 .54345 L
.42143 .52317 L
.42061 .50522 L
.4231 .48994 L
.42827 .47751 L
.43548 .46798 L
.44411 .46126 L
.45358 .45717 L
.4634 .45545 L
.4731 .45578 L
.48232 .45783 L
.49076 .46124 L
.49822 .46565 L
.50456 .47073 L
.50969 .47616 L
.51361 .48167 L
.51636 .48703 L
.51802 .49205 L
.51868 .49658 L
.5185 .50052 L
.5176 .50381 L
.51614 .50642 L
.51427 .50835 L
.51213 .50964 L
.50985 .51033 L
.50754 .5105 L
.5053 .51023 L
.50321 .50958 L
.50133 .50866 L
.49969 .50754 L
Mistroke
.49833 .5063 L
.49726 .50501 L
.49646 .50372 L
.49594 .50249 L
.49566 .50136 L
.4956 .50036 L
.49573 .4995 L
.496 .4988 L
.4964 .49826 L
.49687 .49788 L
.49739 .49764 L
.49793 .49754 L
.49847 .49755 L
.49899 .49765 L
.49946 .49784 L
.49987 .49808 L
.50023 .49836 L
.50052 .49866 L
.50074 .49896 L
.5009 .49926 L
.50099 .49954 L
.50103 .49979 L
.50103 .50001 L
.50098 .5002 L
.5009 .50035 L
.5008 .50046 L
.50068 .50053 L
.50055 .50057 L
.50043 .50058 L
.5003 .50057 L
.50019 .50053 L
.50008 .50048 L
.49999 .50042 L
.49991 .50035 L
.49985 .50028 L
.49981 .50021 L
.49978 .50014 L
.49976 .50008 L
.49976 .50002 L
.49976 .49998 L
.49978 .49994 L
.4998 .49991 L
.49982 .49988 L
.49985 .49987 L
.49988 .49986 L
.49991 .49986 L
.49994 .49987 L
.49997 .49988 L
.49999 .49989 L
.50001 .49991 L
Mistroke
.50003 .49992 L
.50004 .49994 L
.50005 .49996 L
.50005 .49997 L
.50006 .49999 L
.50006 .5 L
.50005 .50001 L
.50005 .50002 L
.50004 .50002 L
.50004 .50003 L
.50003 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.5 .50003 L
.5 .50002 L
.5 .50002 L
.49999 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 .635 1 r
0 .02501 m
.04723 .01182 L
.15577 .00609 L
.26066 .02102 L
.35827 .05272 L
.44589 .09721 L
.5216 .15067 L
.58429 .20951 L
.63355 .27052 L
.66956 .33092 L
.693 .38838 L
.70497 .44108 L
.70682 .48767 L
.7001 .52728 L
.68645 .55944 L
.66754 .58406 L
.64497 .60136 L
.62022 .61183 L
.59464 .61615 L
.56938 .61514 L
.54541 .60968 L
.52346 .60071 L
.5041 .58915 L
.48769 .57588 L
.4744 .56171 L
.46427 .54735 L
.45719 .5334 L
.45296 .52035 L
.4513 .50858 L
.45184 .49836 L
.45423 .48985 L
.45806 .48311 L
.46296 .47812 L
.46855 .47482 L
.4745 .47305 L
.48051 .47264 L
.48634 .47339 L
.49178 .47508 L
.49667 .4775 L
.50092 .48043 L
.50444 .48368 L
.50722 .48705 L
.50927 .4904 L
.51061 .4936 L
.51132 .49654 L
.51146 .49914 L
.51112 .50137 L
.51039 .50318 L
.50936 .50457 L
.50812 .50556 L
Mistroke
.50676 .50616 L
.50534 .50642 L
.50394 .50639 L
.50261 .5061 L
.50138 .50562 L
.5003 .50499 L
.49938 .50426 L
.49863 .50347 L
.49806 .50268 L
.49765 .5019 L
.49741 .50118 L
.49731 .50052 L
.49733 .49995 L
.49745 .49947 L
.49766 .49909 L
.49793 .49881 L
.49824 .49862 L
.49856 .49851 L
.4989 .49848 L
.49922 .49852 L
.49952 .49861 L
.4998 .49874 L
.50004 .4989 L
.50023 .49908 L
.50039 .49927 L
.50051 .49946 L
.50058 .49963 L
.50062 .4998 L
.50063 .49994 L
.50062 .50007 L
.50058 .50017 L
.50052 .50025 L
.50045 .5003 L
.50038 .50034 L
.5003 .50036 L
.50022 .50035 L
.50015 .50034 L
.50008 .50031 L
.50002 .50028 L
.49997 .50024 L
.49993 .5002 L
.49989 .50015 L
.49987 .50011 L
.49986 .50007 L
.49985 .50003 L
.49985 .5 L
.49986 .49997 L
.49987 .49995 L
.49988 .49993 L
.4999 .49992 L
Mistroke
.49992 .49992 L
.49994 .49992 L
.49996 .49992 L
.49997 .49992 L
.49999 .49993 L
.5 .49994 L
.50001 .49995 L
.50002 .49996 L
.50003 .49997 L
.50003 .49998 L
.50003 .49999 L
.50004 .5 L
.50003 .5 L
.50003 .50001 L
.50003 .50001 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 1 .753 r
1 .95739 m
.97975 .9651 L
.87424 .97938 L
.77071 .97219 L
.67297 .94728 L
.584 .90847 L
.50596 .85957 L
.44021 .80413 L
.3874 .74544 L
.34758 .68635 L
.32024 .62929 L
.30448 .57623 L
.29907 .52864 L
.30257 .48754 L
.3134 .45354 L
.32995 .42685 L
.35064 .40737 L
.37399 .39473 L
.39862 .38832 L
.42336 .38741 L
.44719 .39115 L
.4693 .39864 L
.4891 .40898 L
.50615 .4213 L
.52022 .43479 L
.53122 .44872 L
.5392 .46247 L
.54434 .47551 L
.54688 .48744 L
.54713 .49795 L
.54546 .50686 L
.54225 .51406 L
.53785 .51954 L
.53265 .52337 L
.52698 .52564 L
.52114 .52653 L
.51539 .52621 L
.50995 .52489 L
.50499 .52279 L
.50062 .52012 L
.49693 .51707 L
.49395 .51383 L
.4917 .51055 L
.49014 .50738 L
.48922 .50442 L
.48888 .50176 L
.48904 .49946 L
.48961 .49755 L
.49051 .49604 L
.49164 .49494 L
Mistroke
.49293 .49421 L
.49429 .49383 L
.49566 .49376 L
.49698 .49395 L
.49822 .49435 L
.49932 .49492 L
.50028 .49559 L
.50107 .49633 L
.50169 .49711 L
.50214 .49787 L
.50244 .49859 L
.50259 .49926 L
.50261 .49985 L
.50253 .50035 L
.50235 .50075 L
.50212 .50106 L
.50183 .50128 L
.50152 .50141 L
.50119 .50147 L
.50087 .50145 L
.50057 .50138 L
.50029 .50127 L
.50005 .50113 L
.49984 .50096 L
.49968 .50078 L
.49955 .5006 L
.49946 .50042 L
.49941 .50026 L
.49938 .50011 L
.49939 .49998 L
.49942 .49987 L
.49947 .49979 L
.49953 .49972 L
.4996 .49968 L
.49968 .49966 L
.49975 .49965 L
.49983 .49966 L
.4999 .49969 L
.49996 .49972 L
.50001 .49975 L
.50006 .49979 L
.50009 .49984 L
.50012 .49988 L
.50013 .49992 L
.50014 .49996 L
.50014 .49999 L
.50014 .50002 L
.50013 .50004 L
.50012 .50006 L
.5001 .50007 L
Mistroke
.50009 .50008 L
.50007 .50008 L
.50005 .50008 L
.50003 .50008 L
.50002 .50007 L
.5 .50006 L
.49999 .50005 L
.49998 .50004 L
.49998 .50003 L
.49997 .50002 L
.49997 .50001 L
.49997 .50001 L
.49997 .5 L
.49997 .49999 L
.49997 .49999 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 1 .037 r
.45934 1 m
.39052 .93825 L
.31544 .84942 L
.2598 .76088 L
.22269 .67612 L
.20263 .59793 L
.19769 .52837 L
.20562 .46885 L
.22406 .42013 L
.25057 .38242 L
.2828 .35547 L
.31854 .33862 L
.35579 .33094 L
.39284 .33125 L
.42822 .33825 L
.46079 .3506 L
.48971 .36695 L
.51439 .38598 L
.53453 .40653 L
.55006 .42751 L
.56109 .44802 L
.56791 .46732 L
.57092 .48483 L
.57061 .50013 L
.56753 .51297 L
.56224 .52323 L
.55531 .53092 L
.54728 .53613 L
.53865 .53906 L
.52986 .53996 L
.52129 .53912 L
.51324 .53685 L
.50595 .53347 L
.4996 .52929 L
.49428 .52461 L
.49005 .5197 L
.48689 .51479 L
.48476 .51008 L
.48359 .50572 L
.48326 .50183 L
.48365 .49849 L
.48463 .49575 L
.48607 .49362 L
.48784 .49209 L
.48981 .49112 L
.49187 .49066 L
.49392 .49064 L
.49589 .49101 L
.49771 .49167 L
.49932 .49256 L
Mistroke
.50071 .49361 L
.50184 .49474 L
.50272 .4959 L
.50335 .49704 L
.50374 .49812 L
.50392 .49909 L
.50392 .49995 L
.50376 .50067 L
.50347 .50125 L
.50309 .50169 L
.50265 .50198 L
.50217 .50215 L
.50169 .50221 L
.50121 .50217 L
.50076 .50205 L
.50036 .50187 L
.5 .50164 L
.4997 .50138 L
.49946 .50111 L
.49928 .50084 L
.49916 .50058 L
.49909 .50033 L
.49907 .50012 L
.49909 .49993 L
.49914 .49977 L
.49922 .49965 L
.49932 .49957 L
.49943 .49951 L
.49954 .49948 L
.49966 .49948 L
.49976 .4995 L
.49987 .49954 L
.49996 .49958 L
.50003 .49964 L
.5001 .4997 L
.50015 .49977 L
.50018 .49983 L
.50021 .49989 L
.50022 .49995 L
.50022 .49999 L
.50021 .50003 L
.50019 .50007 L
.50017 .50009 L
.50015 .50011 L
.50012 .50012 L
.5001 .50012 L
.50007 .50012 L
.50004 .50011 L
.50002 .5001 L
.5 .50009 L
Mistroke
.49998 .50008 L
.49997 .50006 L
.49996 .50005 L
.49995 .50003 L
.49995 .50002 L
.49995 .50001 L
.49995 .5 L
.49995 .49999 L
.49996 .49998 L
.49996 .49998 L
.49997 .49997 L
.49997 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49998 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.214 1 0 r
.2334 1 m
.16499 .89658 L
.10728 .77322 L
.07453 .65874 L
.06406 .55629 L
.07271 .46804 L
.09705 .39524 L
.1336 .33831 L
.17893 .29699 L
.22983 .27042 L
.28335 .25729 L
.33695 .25598 L
.38847 .26464 L
.43617 .28132 L
.47877 .30407 L
.51538 .331 L
.54549 .36036 L
.56895 .3906 L
.58589 .42035 L
.59668 .44852 L
.60186 .47422 L
.60214 .49682 L
.59829 .51593 L
.59113 .53133 L
.58147 .543 L
.57011 .55108 L
.55777 .55582 L
.54509 .55757 L
.53265 .55674 L
.5209 .55377 L
.51021 .54912 L
.50082 .54326 L
.4929 .53661 L
.48654 .52956 L
.48174 .52246 L
.47844 .51561 L
.47653 .50923 L
.47587 .5035 L
.47628 .49856 L
.47757 .49446 L
.47955 .49125 L
.48203 .4889 L
.48483 .48737 L
.48779 .48659 L
.49076 .48648 L
.49362 .48692 L
.49628 .48781 L
.49866 .48905 L
.50072 .49053 L
.50241 .49215 L
Mistroke
.50374 .49382 L
.5047 .49547 L
.50532 .49704 L
.50563 .49848 L
.50566 .49974 L
.50546 .50081 L
.50508 .50168 L
.50455 .50234 L
.50393 .5028 L
.50325 .50308 L
.50255 .50319 L
.50186 .50315 L
.5012 .50299 L
.50061 .50274 L
.50008 .50242 L
.49964 .50205 L
.49928 .50167 L
.49901 .50127 L
.49882 .50089 L
.49871 .50054 L
.49866 .50022 L
.49868 .49994 L
.49875 .49971 L
.49886 .49953 L
.49899 .49939 L
.49915 .49931 L
.49931 .49926 L
.49948 .49925 L
.49964 .49927 L
.49978 .49932 L
.49992 .49939 L
.50003 .49947 L
.50013 .49956 L
.5002 .49965 L
.50026 .49974 L
.50029 .49983 L
.50031 .49991 L
.50031 .49998 L
.5003 .50004 L
.50028 .50009 L
.50025 .50013 L
.50022 .50015 L
.50018 .50017 L
.50014 .50018 L
.50011 .50017 L
.50007 .50017 L
.50004 .50015 L
.50001 .50014 L
.49998 .50012 L
.49996 .50009 L
Mistroke
.49995 .50007 L
.49994 .50005 L
.49993 .50003 L
.49993 .50001 L
.49993 .5 L
.49993 .49998 L
.49994 .49997 L
.49994 .49997 L
.49995 .49996 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49999 .49996 L
.49999 .49997 L
.5 .49997 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 .506 1 r
.21147 1 m
.15763 .92032 L
.09592 .79189 L
.06027 .67241 L
.04792 .56521 L
.05564 .47262 L
.07989 .39599 L
.11705 .33582 L
.16355 .29187 L
.21604 .2633 L
.27147 .24879 L
.32713 .24665 L
.38077 .25499 L
.43056 .27178 L
.47514 .29501 L
.51356 .3227 L
.54526 .35304 L
.57007 .38438 L
.58809 .41532 L
.5997 .44468 L
.60545 .47153 L
.60607 .49521 L
.60234 .51529 L
.59512 .53152 L
.58526 .54389 L
.57357 .55252 L
.56081 .55767 L
.54767 .55968 L
.53473 .55898 L
.52249 .55604 L
.5113 .55132 L
.50147 .54532 L
.49315 .53846 L
.48644 .53117 L
.48135 .5238 L
.47783 .51666 L
.47575 .51 L
.47498 .50401 L
.47533 .49883 L
.47662 .49452 L
.47863 .49112 L
.48117 .48862 L
.48406 .48698 L
.48712 .48613 L
.49021 .48596 L
.49319 .48638 L
.49597 .48728 L
.49846 .48855 L
.50061 .49007 L
.50239 .49174 L
Mistroke
.50379 .49347 L
.50482 .49519 L
.50548 .49682 L
.50583 .49832 L
.50588 .49965 L
.50569 .50077 L
.5053 .50169 L
.50476 .50239 L
.50412 .50288 L
.50342 .50318 L
.50269 .5033 L
.50197 .50327 L
.50129 .50312 L
.50067 .50286 L
.50012 .50253 L
.49965 .50216 L
.49927 .50176 L
.49898 .50135 L
.49878 .50095 L
.49866 .50058 L
.49862 .50024 L
.49863 .49995 L
.4987 .49971 L
.49881 .49952 L
.49895 .49938 L
.49911 .49928 L
.49927 .49923 L
.49945 .49922 L
.49961 .49924 L
.49977 .49929 L
.49991 .49936 L
.50003 .49944 L
.50013 .49954 L
.50021 .49963 L
.50026 .49973 L
.5003 .49982 L
.50032 .4999 L
.50033 .49998 L
.50032 .50004 L
.5003 .50009 L
.50027 .50013 L
.50023 .50016 L
.50019 .50018 L
.50015 .50018 L
.50011 .50018 L
.50007 .50017 L
.50004 .50016 L
.50001 .50014 L
.49998 .50012 L
.49996 .5001 L
Mistroke
.49994 .50008 L
.49993 .50005 L
.49993 .50003 L
.49992 .50001 L
.49992 .5 L
.49993 .49998 L
.49993 .49997 L
.49994 .49997 L
.49995 .49996 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49999 .49996 L
.49999 .49996 L
.5 .49997 L
.50001 .49997 L
.50001 .49998 L
.50001 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.823 1 0 r
.79431 0 m
.86561 .11574 L
.91975 .24274 L
.94842 .35963 L
.95455 .46337 L
.94152 .55192 L
.91292 .62418 L
.8724 .67987 L
.8235 .71943 L
.76951 .74386 L
.71341 .75462 L
.65778 .75347 L
.60477 .74236 L
.55609 .72335 L
.51297 .69846 L
.47626 .66963 L
.4464 .63864 L
.42347 .60709 L
.40728 .57631 L
.3974 .54743 L
.39321 .52129 L
.39396 .49849 L
.39883 .47941 L
.40697 .46422 L
.41752 .4529 L
.42967 .44528 L
.44269 .44107 L
.4559 .43989 L
.46876 .44131 L
.48081 .44485 L
.49169 .45002 L
.50115 .45636 L
.50905 .46343 L
.51532 .47083 L
.51997 .4782 L
.52307 .48527 L
.52476 .49178 L
.52518 .49758 L
.52453 .50255 L
.523 .50662 L
.5208 .50977 L
.51812 .51202 L
.51514 .51343 L
.51204 .51408 L
.50895 .51406 L
.50601 .51348 L
.50329 .51245 L
.50088 .5111 L
.49882 .50951 L
.49714 .5078 L
Mistroke
.49584 .50605 L
.49492 .50435 L
.49435 .50274 L
.49409 .50128 L
.49412 .5 L
.49437 .49893 L
.49481 .49807 L
.49539 .49743 L
.49606 .49699 L
.49677 .49675 L
.49751 .49667 L
.49822 .49674 L
.49889 .49693 L
.4995 .49721 L
.50003 .49756 L
.50047 .49795 L
.50083 .49836 L
.50109 .49876 L
.50127 .49916 L
.50137 .49952 L
.50139 .49984 L
.50136 .50012 L
.50128 .50035 L
.50116 .50053 L
.50101 .50066 L
.50085 .50074 L
.50068 .50078 L
.50051 .50078 L
.50034 .50075 L
.50019 .50069 L
.50006 .50062 L
.49994 .50053 L
.49985 .50044 L
.49977 .50034 L
.49972 .50025 L
.49969 .50016 L
.49967 .50008 L
.49967 .5 L
.49969 .49994 L
.49971 .4999 L
.49974 .49986 L
.49978 .49983 L
.49982 .49982 L
.49986 .49982 L
.4999 .49982 L
.49994 .49983 L
.49997 .49984 L
.5 .49986 L
.50002 .49988 L
.50004 .49991 L
Mistroke
.50006 .49993 L
.50007 .49995 L
.50008 .49997 L
.50008 .49999 L
.50008 .50001 L
.50007 .50002 L
.50006 .50003 L
.50006 .50004 L
.50005 .50004 L
.50004 .50004 L
.50003 .50004 L
.50002 .50004 L
.50001 .50004 L
.5 .50003 L
.5 .50003 L
.49999 .50002 L
.49999 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 1 .947 r
.39396 1 m
.36382 .97176 L
.2838 .8728 L
.22527 .77482 L
.18712 .68158 L
.16761 .59605 L
.16452 .52041 L
.17534 .4561 L
.19741 .40386 L
.22804 .36386 L
.26463 .33572 L
.30475 .31867 L
.34624 .31161 L
.38722 .31322 L
.42613 .32204 L
.46175 .33655 L
.49318 .35528 L
.51983 .37678 L
.54141 .39976 L
.55788 .42306 L
.56938 .4457 L
.57627 .46687 L
.57899 .48597 L
.57813 .50256 L
.57427 .51639 L
.56807 .52734 L
.56014 .53544 L
.55107 .54082 L
.54142 .54371 L
.53167 .54438 L
.52221 .54318 L
.51338 .54043 L
.50544 .53652 L
.49855 .53177 L
.49283 .52651 L
.48831 .52104 L
.48498 .5156 L
.48279 .51041 L
.48164 .50564 L
.48141 .50141 L
.48196 .4978 L
.48314 .49486 L
.48481 .4926 L
.48681 .491 L
.48903 .49001 L
.49132 .48958 L
.4936 .48964 L
.49576 .4901 L
.49775 .49088 L
.4995 .49191 L
Mistroke
.501 .49309 L
.50222 .49436 L
.50315 .49565 L
.5038 .49691 L
.5042 .49808 L
.50437 .49915 L
.50433 .50008 L
.50413 .50086 L
.5038 .50148 L
.50336 .50193 L
.50287 .50224 L
.50233 .50241 L
.50179 .50246 L
.50127 .5024 L
.50077 .50225 L
.50033 .50204 L
.49995 .50178 L
.49962 .50149 L
.49937 .50119 L
.49918 .50089 L
.49905 .5006 L
.49899 .50033 L
.49897 .50009 L
.499 .49989 L
.49906 .49973 L
.49915 .4996 L
.49926 .49951 L
.49938 .49945 L
.49951 .49942 L
.49964 .49943 L
.49976 .49945 L
.49987 .49949 L
.49997 .49955 L
.50005 .49961 L
.50012 .49968 L
.50017 .49975 L
.50021 .49982 L
.50023 .49989 L
.50024 .49995 L
.50024 .5 L
.50023 .50004 L
.50021 .50008 L
.50019 .50011 L
.50016 .50012 L
.50013 .50013 L
.5001 .50014 L
.50007 .50013 L
.50004 .50013 L
.50002 .50011 L
.5 .5001 L
Mistroke
.49998 .50008 L
.49997 .50007 L
.49996 .50005 L
.49995 .50003 L
.49994 .50002 L
.49994 .50001 L
.49994 .49999 L
.49995 .49999 L
.49995 .49998 L
.49996 .49997 L
.49997 .49997 L
.49997 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49997 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 .128 0 r
.52661 0 m
.56887 .03352 L
.65085 .11939 L
.71364 .2067 L
.7578 .29171 L
.78457 .37141 L
.79565 .44345 L
.79314 .50619 L
.7793 .55861 L
.75652 .60027 L
.72714 .63124 L
.69339 .65198 L
.65732 .66331 L
.62076 .6663 L
.58523 .66215 L
.552 .65219 L
.52203 .63774 L
.49599 .6201 L
.47428 .60049 L
.45709 .58001 L
.44438 .55962 L
.43593 .54012 L
.4314 .52214 L
.43034 .50617 L
.43224 .49251 L
.43654 .48135 L
.44269 .47272 L
.45014 .46657 L
.45839 .46274 L
.46698 .46102 L
.47551 .46113 L
.48365 .46278 L
.49114 .46566 L
.49778 .46944 L
.50344 .47384 L
.50806 .47858 L
.51161 .48341 L
.51413 .48814 L
.51568 .49257 L
.51635 .4966 L
.51626 .50011 L
.51554 .50306 L
.51431 .5054 L
.5127 .50716 L
.51085 .50835 L
.50886 .50901 L
.50683 .50921 L
.50486 .50901 L
.50301 .50847 L
.50133 .50769 L
Mistroke
.49987 .50672 L
.49865 .50564 L
.49768 .50451 L
.49696 .50338 L
.49648 .5023 L
.49621 .50129 L
.49614 .5004 L
.49624 .49964 L
.49647 .49901 L
.4968 .49852 L
.49721 .49817 L
.49766 .49795 L
.49814 .49785 L
.49861 .49784 L
.49906 .49793 L
.49948 .49809 L
.49985 .49829 L
.50017 .49853 L
.50043 .49879 L
.50063 .49906 L
.50077 .49932 L
.50086 .49957 L
.5009 .4998 L
.5009 .49999 L
.50086 .50016 L
.5008 .50029 L
.50071 .50039 L
.50061 .50046 L
.5005 .5005 L
.50039 .50051 L
.50028 .5005 L
.50017 .50047 L
.50008 .50043 L
.5 .50038 L
.49993 .50032 L
.49988 .50025 L
.49983 .50019 L
.49981 .50013 L
.49979 .50008 L
.49979 .50003 L
.49979 .49998 L
.4998 .49995 L
.49982 .49992 L
.49984 .4999 L
.49987 .49989 L
.49989 .49988 L
.49992 .49988 L
.49995 .49988 L
.49997 .49989 L
.49999 .4999 L
Mistroke
.50001 .49992 L
.50002 .49993 L
.50003 .49995 L
.50004 .49996 L
.50005 .49998 L
.50005 .49999 L
.50005 .5 L
.50005 .50001 L
.50004 .50002 L
.50004 .50002 L
.50003 .50003 L
.50003 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 .861 r
.89528 0 m
.96384 .13418 L
s
.96384 .13418 m
1 .24455 L
s
1 .60116 m
.99795 .60859 L
.95659 .68222 L
.90361 .73674 L
.84299 .77305 L
.77839 .7926 L
.71303 .79731 L
.64964 .78938 L
.59044 .77115 L
.53714 .745 L
.4909 .71326 L
.45245 .67808 L
.42208 .64143 L
.39969 .605 L
.38492 .57023 L
.37711 .53823 L
.37548 .50984 L
.37908 .48561 L
.38695 .46585 L
.39807 .45062 L
.41148 .43982 L
.42628 .43315 L
.44165 .43023 L
.45689 .43057 L
.4714 .43363 L
.48473 .43886 L
.49653 .44568 L
.50657 .45359 L
.51474 .46208 L
.52101 .47073 L
.52543 .47915 L
.52812 .48706 L
.52926 .49422 L
.52905 .50046 L
.5277 .50568 L
.52547 .50983 L
.52257 .51292 L
.51924 .515 L
.51567 .51615 L
.51205 .51647 L
.50853 .51607 L
.50523 .5151 L
.50226 .51368 L
.49967 .51194 L
.49751 .51 L
.49579 .50798 L
.49452 .50596 L
.49367 .50402 L
.49322 .50224 L
.4931 .50065 L
Mistroke
.49328 .49929 L
.4937 .49818 L
.49431 .49732 L
.49504 .4967 L
.49586 .49632 L
.49671 .49614 L
.49755 .49615 L
.49836 .49631 L
.4991 .49659 L
.49976 .49696 L
.50033 .4974 L
.50079 .49787 L
.50114 .49834 L
.50139 .49881 L
.50155 .49925 L
.50162 .49965 L
.50161 .5 L
.50154 .5003 L
.50142 .50053 L
.50126 .50071 L
.50108 .50082 L
.50088 .50089 L
.50068 .50091 L
.50049 .50089 L
.5003 .50084 L
.50014 .50076 L
.49999 .50067 L
.49987 .50056 L
.49977 .50045 L
.4997 .50034 L
.49965 .50023 L
.49963 .50013 L
.49962 .50004 L
.49963 .49997 L
.49965 .4999 L
.49968 .49985 L
.49972 .49982 L
.49977 .4998 L
.49981 .49979 L
.49986 .49979 L
.49991 .49979 L
.49995 .49981 L
.49998 .49983 L
.50002 .49985 L
.50004 .49988 L
.50006 .49991 L
.50008 .49993 L
.50009 .49996 L
.50009 .49998 L
.50009 .5 L
Mistroke
.50009 .50002 L
.50008 .50003 L
.50007 .50004 L
.50006 .50005 L
.50005 .50005 L
.50004 .50005 L
.50003 .50005 L
.50002 .50005 L
.50001 .50004 L
.5 .50004 L
.49999 .50003 L
.49999 .50003 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 .709 r
.54895 0 m
.61631 .06151 L
.69114 .15162 L
.74631 .24119 L
.78277 .32674 L
.80207 .40548 L
.80619 .47535 L
.79741 .535 L
.77814 .58367 L
.75085 .62118 L
.7179 .64782 L
.68153 .66428 L
.64374 .67152 L
.60627 .67074 L
.57056 .66326 L
.53777 .65045 L
.50873 .63368 L
.484 .61426 L
.46388 .59338 L
.44844 .57213 L
.43754 .5514 L
.43088 .53194 L
.42806 .51433 L
.42857 .49898 L
.43185 .48613 L
.43733 .47589 L
.44444 .46827 L
.45263 .46314 L
.4614 .4603 L
.4703 .45951 L
.47896 .46047 L
.48707 .46285 L
.4944 .46633 L
.50078 .47061 L
.5061 .47537 L
.51032 .48035 L
.51345 .48532 L
.51554 .49008 L
.51668 .49447 L
.51696 .49837 L
.51652 .50172 L
.51549 .50446 L
.51401 .50658 L
.5122 .5081 L
.5102 .50905 L
.50811 .50948 L
.50603 .50947 L
.50404 .50908 L
.50222 .50839 L
.50059 .50747 L
Mistroke
.4992 .50641 L
.49807 .50525 L
.4972 .50408 L
.49658 .50293 L
.49619 .50184 L
.49602 .50086 L
.49604 .5 L
.49621 .49928 L
.49651 .4987 L
.49689 .49827 L
.49734 .49798 L
.49783 .49781 L
.49832 .49776 L
.4988 .4978 L
.49925 .49793 L
.49966 .49812 L
.50002 .49835 L
.50032 .49862 L
.50056 .49889 L
.50073 .49917 L
.50085 .49943 L
.50092 .49968 L
.50094 .4999 L
.50092 .50008 L
.50086 .50024 L
.50078 .50036 L
.50068 .50044 L
.50057 .5005 L
.50046 .50052 L
.50034 .50053 L
.50023 .5005 L
.50013 .50047 L
.50004 .50042 L
.49996 .50036 L
.4999 .5003 L
.49985 .50023 L
.49981 .50017 L
.49979 .50011 L
.49978 .50005 L
.49978 .5 L
.49979 .49996 L
.49981 .49993 L
.49983 .49991 L
.49985 .49989 L
.49988 .49988 L
.49991 .49988 L
.49993 .49988 L
.49996 .49988 L
.49998 .4999 L
.5 .49991 L
Mistroke
.50002 .49992 L
.50003 .49994 L
.50004 .49995 L
.50005 .49997 L
.50005 .49998 L
.50005 .49999 L
.50005 .5 L
.50005 .50001 L
.50004 .50002 L
.50004 .50002 L
.50003 .50003 L
.50003 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50003 L
.5 .50002 L
.5 .50002 L
.49999 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 1 .282 r
0 .10309 m
.08814 .07491 L
.18342 .06671 L
.27607 .07715 L
.36279 .10283 L
.44108 .14027 L
.50916 .18608 L
.56594 .23709 L
.61097 .29043 L
.64433 .34358 L
.66656 .39446 L
.67857 .44139 L
.6815 .48313 L
.67671 .51884 L
.66562 .54806 L
.64969 .57067 L
.63032 .58683 L
.60886 .59692 L
.58649 .60151 L
.56425 .60131 L
.54301 .59709 L
.52346 .58966 L
.50611 .57984 L
.49131 .5684 L
.47922 .55607 L
.46991 .54347 L
.4633 .53116 L
.45921 .51958 L
.45742 .50907 L
.45761 .49989 L
.45947 .49218 L
.46265 .48603 L
.46681 .48142 L
.47163 .4783 L
.47682 .47654 L
.48209 .47601 L
.48724 .47652 L
.49207 .47788 L
.49644 .47992 L
.50026 .48243 L
.50345 .48523 L
.50599 .48818 L
.50788 .49113 L
.50915 .49396 L
.50986 .49658 L
.51005 .49891 L
.50982 .50091 L
.50922 .50256 L
.50836 .50383 L
.5073 .50475 L
Mistroke
.50612 .50534 L
.50488 .50561 L
.50364 .50562 L
.50246 .5054 L
.50137 .505 L
.5004 .50446 L
.49957 .50384 L
.49889 .50315 L
.49837 .50246 L
.49799 .50177 L
.49775 .50113 L
.49765 .50054 L
.49765 .50003 L
.49775 .4996 L
.49792 .49925 L
.49814 .49899 L
.49841 .49881 L
.4987 .49871 L
.49899 .49867 L
.49927 .4987 L
.49954 .49877 L
.49979 .49888 L
.5 .49902 L
.50018 .49917 L
.50032 .49933 L
.50043 .4995 L
.5005 .49965 L
.50054 .4998 L
.50056 .49993 L
.50055 .50004 L
.50051 .50014 L
.50047 .50021 L
.50041 .50026 L
.50034 .50029 L
.50028 .50031 L
.50021 .50031 L
.50014 .5003 L
.50008 .50028 L
.50003 .50025 L
.49998 .50021 L
.49994 .50018 L
.49991 .50014 L
.49989 .5001 L
.49988 .50006 L
.49987 .50003 L
.49987 .5 L
.49987 .49998 L
.49988 .49996 L
.4999 .49994 L
.49991 .49993 L
Mistroke
.49993 .49993 L
.49994 .49993 L
.49996 .49993 L
.49997 .49993 L
.49999 .49994 L
.5 .49994 L
.50001 .49995 L
.50002 .49996 L
.50002 .49997 L
.50003 .49998 L
.50003 .49999 L
.50003 .5 L
.50003 .5 L
.50003 .50001 L
.50003 .50001 L
.50002 .50001 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.592 1 0 r
0 .06355 m
.01261 .05788 L
.11426 .0386 L
.21502 .04087 L
.311 .06113 L
.39913 .09569 L
.47715 .14087 L
.54355 .19316 L
.59755 .24932 L
.63898 .30649 L
.66821 .36222 L
.68601 .41452 L
.69352 .46184 L
.69208 .50308 L
.68319 .53758 L
.66841 .56504 L
.64926 .58549 L
.62722 .59924 L
.60363 .60681 L
.57968 .6089 L
.55639 .60629 L
.53458 .59986 L
.5149 .59046 L
.49777 .57895 L
.48349 .56614 L
.47216 .55274 L
.46376 .53938 L
.45816 .52659 L
.45513 .51479 L
.45438 .50429 L
.45558 .49531 L
.45836 .48795 L
.46236 .48226 L
.46722 .47819 L
.47261 .47565 L
.47824 .47449 L
.48383 .47454 L
.48917 .47559 L
.49408 .47746 L
.49844 .47992 L
.50217 .48279 L
.50521 .48589 L
.50755 .48906 L
.50922 .49215 L
.51025 .49507 L
.5107 .49771 L
.51065 .50002 L
.51019 .50196 L
.50939 .5035 L
.50835 .50466 L
Mistroke
.50714 .50545 L
.50583 .50589 L
.50451 .50603 L
.50321 .5059 L
.502 .50556 L
.5009 .50505 L
.49994 .50442 L
.49914 .50371 L
.4985 .50297 L
.49802 .50223 L
.4977 .50152 L
.49752 .50086 L
.49747 .50028 L
.49753 .49977 L
.49768 .49936 L
.4979 .49904 L
.49816 .49881 L
.49846 .49866 L
.49877 .49859 L
.49908 .49859 L
.49938 .49864 L
.49965 .49874 L
.4999 .49888 L
.50011 .49904 L
.50028 .49921 L
.50041 .49938 L
.5005 .49955 L
.50056 .49972 L
.50059 .49986 L
.50059 .49999 L
.50057 .5001 L
.50052 .50019 L
.50047 .50025 L
.5004 .5003 L
.50033 .50033 L
.50025 .50033 L
.50018 .50033 L
.50012 .50031 L
.50005 .50028 L
.5 .50025 L
.49996 .50021 L
.49992 .50017 L
.49989 .50013 L
.49987 .50009 L
.49986 .50005 L
.49986 .50002 L
.49986 .49999 L
.49987 .49997 L
.49988 .49995 L
.4999 .49993 L
Mistroke
.49991 .49993 L
.49993 .49992 L
.49995 .49992 L
.49996 .49992 L
.49998 .49993 L
.49999 .49994 L
.50001 .49995 L
.50001 .49996 L
.50002 .49997 L
.50003 .49997 L
.50003 .49998 L
.50003 .49999 L
.50003 .5 L
.50003 .50001 L
.50003 .50001 L
.50003 .50001 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.558 1 0 r
1 .97805 m
.9054 .99449 L
.79775 .9906 L
.69549 .96772 L
.60182 .92981 L
.51912 .88079 L
.44893 .82442 L
.39206 .76413 L
.34863 .70295 L
.31822 .64348 L
.29997 .58781 L
.29264 .53758 L
.29479 .4939 L
.30479 .45748 L
.321 .42861 L
.34176 .40723 L
.36552 .39299 L
.39084 .38531 L
.41646 .38346 L
.44131 .38656 L
.46452 .3937 L
.48542 .40395 L
.50354 .41639 L
.51862 .43018 L
.53053 .44454 L
.53931 .45882 L
.5451 .47245 L
.54817 .485 L
.54881 .49613 L
.5474 .50563 L
.54432 .51338 L
.53996 .51935 L
.53471 .52358 L
.52891 .5262 L
.52288 .52735 L
.51691 .52722 L
.51122 .52602 L
.50599 .52397 L
.50137 .52129 L
.49743 .5182 L
.49423 .51487 L
.49177 .51148 L
.49003 .50818 L
.48898 .50508 L
.48853 .50227 L
.48861 .49982 L
.48914 .49778 L
.49002 .49615 L
.49115 .49494 L
.49246 .49412 L
Mistroke
.49385 .49367 L
.49527 .49355 L
.49665 .4937 L
.49795 .49408 L
.49911 .49464 L
.50013 .49532 L
.50098 .49608 L
.50165 .49687 L
.50215 .49766 L
.50248 .49842 L
.50266 .49912 L
.5027 .49974 L
.50263 .50028 L
.50247 .50071 L
.50223 .50105 L
.50194 .50129 L
.50162 .50144 L
.50129 .50151 L
.50096 .50151 L
.50064 .50145 L
.50035 .50134 L
.50009 .50119 L
.49987 .50102 L
.49969 .50084 L
.49955 .50065 L
.49945 .50047 L
.49939 .50029 L
.49937 .50014 L
.49937 .5 L
.4994 .49988 L
.49944 .49979 L
.49951 .49972 L
.49958 .49968 L
.49965 .49965 L
.49973 .49964 L
.49981 .49965 L
.49988 .49967 L
.49995 .4997 L
.5 .49974 L
.50005 .49978 L
.50009 .49982 L
.50012 .49987 L
.50014 .49991 L
.50015 .49995 L
.50015 .49998 L
.50015 .50001 L
.50014 .50004 L
.50012 .50006 L
.50011 .50007 L
.50009 .50008 L
Mistroke
.50007 .50008 L
.50005 .50008 L
.50004 .50008 L
.50002 .50007 L
.50001 .50007 L
.49999 .50006 L
.49998 .50005 L
.49998 .50004 L
.49997 .50003 L
.49997 .50002 L
.49996 .50001 L
.49996 .5 L
.49997 .49999 L
.49997 .49999 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 .041 0 r
.41213 0 m
.41796 .00278 L
.51209 .06599 L
.59061 .13642 L
.65291 .21007 L
.69909 .28349 L
.7299 .35379 L
.74656 .41865 L
.75069 .47634 L
.74413 .52572 L
.72887 .56615 L
.7069 .59744 L
.68018 .61981 L
.65055 .63379 L
.61965 .64018 L
.58893 .63994 L
.55959 .63415 L
.53257 .62391 L
.50859 .61037 L
.48812 .59459 L
.4714 .57755 L
.45852 .56015 L
.44936 .54314 L
.4437 .52714 L
.44119 .51262 L
.44144 .49992 L
.444 .48927 L
.44838 .48075 L
.45412 .47438 L
.46078 .47005 L
.46793 .46761 L
.47522 .46686 L
.48233 .46756 L
.48901 .46944 L
.49505 .47224 L
.50032 .4757 L
.50473 .47958 L
.50825 .48365 L
.51087 .48772 L
.51263 .49163 L
.51361 .49525 L
.51388 .49847 L
.51356 .50124 L
.51275 .50352 L
.51155 .50529 L
.51009 .50656 L
.50846 .50737 L
.50675 .50775 L
.50504 .50776 L
.50341 .50746 L
Mistroke
.50191 .50691 L
.50057 .50617 L
.49942 .5053 L
.49848 .50436 L
.49775 .5034 L
.49723 .50246 L
.4969 .50156 L
.49675 .50075 L
.49675 .50004 L
.49689 .49944 L
.49712 .49896 L
.49744 .4986 L
.4978 .49836 L
.4982 .49821 L
.4986 .49817 L
.49899 .4982 L
.49937 .4983 L
.4997 .49845 L
.5 .49864 L
.50025 .49885 L
.50044 .49908 L
.50059 .4993 L
.50069 .49952 L
.50075 .49972 L
.50077 .4999 L
.50075 .50006 L
.50071 .50019 L
.50064 .50029 L
.50056 .50036 L
.50047 .50041 L
.50038 .50043 L
.50029 .50043 L
.5002 .50041 L
.50011 .50039 L
.50004 .50034 L
.49997 .5003 L
.49992 .50025 L
.49988 .50019 L
.49985 .50014 L
.49983 .50009 L
.49982 .50004 L
.49982 .50001 L
.49983 .49997 L
.49984 .49994 L
.49986 .49992 L
.49988 .49991 L
.4999 .4999 L
.49992 .4999 L
.49994 .4999 L
.49996 .49991 L
Mistroke
.49998 .49991 L
.5 .49992 L
.50001 .49994 L
.50002 .49995 L
.50003 .49996 L
.50004 .49997 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50004 .50002 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 .104 0 r
.38724 1 m
.31265 .91789 L
.24466 .81808 L
.19779 .72158 L
.17053 .6317 L
.16082 .55099 L
.16624 .48119 L
.18413 .42336 L
.21178 .37787 L
.24652 .34457 L
.28582 .32283 L
.32737 .31167 L
.36916 .30983 L
.40947 .31589 L
.44693 .32834 L
.48049 .34565 L
.50945 .36636 L
.53338 .38909 L
.55214 .4126 L
.5658 .43584 L
.57463 .45791 L
.57906 .47812 L
.57962 .49596 L
.57691 .5111 L
.57155 .52336 L
.5642 .53272 L
.55545 .53927 L
.5459 .5432 L
.53604 .54477 L
.52632 .54429 L
.51711 .54213 L
.5087 .53862 L
.50129 .53414 L
.49501 .529 L
.48995 .52354 L
.4861 .51801 L
.48342 .51264 L
.48183 .50764 L
.48123 .50313 L
.48147 .49922 L
.48242 .49597 L
.48392 .4934 L
.48582 .49151 L
.48798 .49026 L
.49027 .4896 L
.49259 .48946 L
.49483 .48977 L
.49692 .49044 L
.49879 .49138 L
.50042 .49251 L
Mistroke
.50176 .49377 L
.50282 .49507 L
.5036 .49636 L
.50411 .49758 L
.50437 .49871 L
.50441 .49971 L
.50427 .50056 L
.50399 .50125 L
.50359 .50178 L
.50311 .50215 L
.50258 .50238 L
.50203 .50248 L
.5015 .50246 L
.50098 .50234 L
.50051 .50215 L
.5001 .50191 L
.49975 .50163 L
.49946 .50133 L
.49924 .50102 L
.49909 .50072 L
.499 .50044 L
.49896 .50019 L
.49897 .49997 L
.49902 .49979 L
.4991 .49964 L
.49921 .49954 L
.49933 .49946 L
.49945 .49943 L
.49958 .49942 L
.49971 .49943 L
.49982 .49947 L
.49993 .49952 L
.50002 .49958 L
.50009 .49965 L
.50015 .49972 L
.5002 .49979 L
.50023 .49986 L
.50024 .49992 L
.50024 .49998 L
.50024 .50003 L
.50022 .50007 L
.5002 .5001 L
.50017 .50012 L
.50015 .50013 L
.50011 .50014 L
.50008 .50014 L
.50006 .50013 L
.50003 .50012 L
.50001 .50011 L
.49999 .50009 L
Mistroke
.49997 .50007 L
.49996 .50006 L
.49995 .50004 L
.49994 .50003 L
.49994 .50001 L
.49994 .5 L
.49995 .49999 L
.49995 .49998 L
.49996 .49997 L
.49996 .49997 L
.49997 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.5 .49997 L
.5 .49998 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.383 1 0 r
0 .25706 m
.03533 .22185 L
.10613 .18094 L
.18132 .15935 L
.25718 .15485 L
.33058 .16487 L
.39896 .18669 L
.46041 .21754 L
.51357 .25472 L
.55766 .29575 L
.59236 .33836 L
.6178 .38059 L
.63444 .42082 L
.64304 .45775 L
.64454 .49045 L
.64001 .51827 L
.63061 .5409 L
.6175 .55826 L
.6018 .57051 L
.58454 .57797 L
.56668 .58111 L
.54901 .5805 L
.53222 .57678 L
.51684 .57058 L
.50326 .56255 L
.49172 .55331 L
.48237 .54343 L
.47522 .53339 L
.47022 .52363 L
.4672 .51449 L
.46599 .50624 L
.46633 .49906 L
.46796 .49308 L
.47061 .48833 L
.47401 .48481 L
.4779 .48246 L
.48205 .48119 L
.48626 .48088 L
.49033 .48138 L
.49414 .48255 L
.49758 .48422 L
.50056 .48626 L
.50303 .48852 L
.50499 .49088 L
.50644 .49322 L
.50739 .49546 L
.5079 .49752 L
.50801 .49935 L
.50778 .50091 L
.50728 .50218 L
Mistroke
.50656 .50317 L
.5057 .50386 L
.50475 .5043 L
.50376 .50449 L
.50278 .50447 L
.50185 .50427 L
.50099 .50394 L
.50023 .5035 L
.49958 .50299 L
.49906 .50244 L
.49865 .50189 L
.49837 .50135 L
.49819 .50084 L
.49812 .50038 L
.49813 .49997 L
.49822 .49964 L
.49836 .49937 L
.49855 .49917 L
.49876 .49904 L
.49899 .49896 L
.49922 .49894 L
.49945 .49897 L
.49966 .49903 L
.49985 .49912 L
.50002 .49923 L
.50016 .49936 L
.50027 .49949 L
.50035 .49962 L
.50041 .49974 L
.50044 .49985 L
.50044 .49996 L
.50043 .50004 L
.50041 .50012 L
.50037 .50017 L
.50032 .50021 L
.50027 .50024 L
.50021 .50025 L
.50016 .50025 L
.50011 .50024 L
.50006 .50022 L
.50002 .5002 L
.49998 .50017 L
.49995 .50014 L
.49993 .50011 L
.49991 .50008 L
.4999 .50005 L
.4999 .50002 L
.4999 .5 L
.4999 .49998 L
.49991 .49997 L
Mistroke
.49992 .49995 L
.49993 .49995 L
.49994 .49994 L
.49996 .49994 L
.49997 .49994 L
.49998 .49995 L
.49999 .49995 L
.5 .49996 L
.50001 .49996 L
.50001 .49997 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 1 .221 r
.47698 0 m
.54522 .05088 L
.62507 .12971 L
.68709 .2107 L
.73168 .29025 L
.75984 .36542 L
.77309 .4339 L
.77329 .49403 L
.76253 .54475 L
.743 .58553 L
.71689 .61635 L
.6863 .63757 L
.65316 .64988 L
.61923 .65422 L
.58597 .65169 L
.55461 .64351 L
.52611 .6309 L
.50113 .61508 L
.48012 .59719 L
.46328 .5783 L
.45061 .5593 L
.44195 .54098 L
.437 .52397 L
.43537 .50873 L
.43658 .49558 L
.44013 .48473 L
.44551 .47622 L
.4522 .47003 L
.45973 .46604 L
.46766 .46404 L
.47562 .46381 L
.48326 .46505 L
.49036 .4675 L
.49669 .47085 L
.50215 .47483 L
.50664 .47918 L
.51014 .48366 L
.51268 .48808 L
.5143 .49226 L
.51509 .49608 L
.51515 .49945 L
.5146 .50229 L
.51355 .50459 L
.51212 .50634 L
.51044 .50755 L
.50861 .50826 L
.50674 .50853 L
.50489 .50842 L
.50314 .50799 L
.50155 .5073 L
Mistroke
.50016 .50644 L
.49898 .50546 L
.49803 .50441 L
.49731 .50336 L
.49681 .50234 L
.49653 .50139 L
.49642 .50054 L
.49648 .4998 L
.49667 .49919 L
.49696 .49871 L
.49733 .49836 L
.49774 .49813 L
.49818 .49801 L
.49862 .49799 L
.49904 .49806 L
.49944 .49819 L
.49979 .49837 L
.5001 .49859 L
.50035 .49883 L
.50055 .49908 L
.50069 .49932 L
.50079 .49956 L
.50083 .49977 L
.50084 .49996 L
.50081 .50012 L
.50075 .50025 L
.50068 .50034 L
.50059 .50041 L
.50048 .50046 L
.50038 .50047 L
.50028 .50047 L
.50018 .50044 L
.50009 .50041 L
.50001 .50036 L
.49995 .50031 L
.49989 .50025 L
.49985 .50019 L
.49983 .50013 L
.49981 .50008 L
.4998 .50003 L
.4998 .49999 L
.49981 .49996 L
.49983 .49993 L
.49985 .49991 L
.49987 .4999 L
.4999 .49989 L
.49992 .49989 L
.49995 .49989 L
.49997 .4999 L
.49999 .49991 L
Mistroke
.5 .49992 L
.50002 .49993 L
.50003 .49995 L
.50004 .49996 L
.50004 .49997 L
.50005 .49999 L
.50005 .5 L
.50005 .50001 L
.50004 .50001 L
.50004 .50002 L
.50003 .50002 L
.50003 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 1 .586 r
.71311 0 m
.76042 .05902 L
.82945 .17577 L
.87423 .28674 L
.89685 .38842 L
.89997 .47825 L
.8866 .55452 L
.85991 .61636 L
.82311 .66363 L
.7793 .69676 L
.73136 .71671 L
.68186 .72478 L
.63303 .72257 L
.58672 .71182 L
.54438 .69432 L
.50707 .67186 L
.47546 .64613 L
.4499 .61869 L
.43046 .59091 L
.41691 .56395 L
.40886 .53877 L
.40575 .51607 L
.40691 .49638 L
.41161 .47999 L
.41908 .46704 L
.42859 .45748 L
.43943 .45116 L
.45095 .4478 L
.46259 .44707 L
.47385 .44858 L
.48435 .4519 L
.49379 .45661 L
.50196 .4623 L
.50874 .46858 L
.51409 .47511 L
.51801 .48159 L
.52058 .48776 L
.52192 .49344 L
.52216 .49846 L
.52148 .50274 L
.52005 .50622 L
.51805 .5089 L
.51565 .51079 L
.51301 .51194 L
.51027 .51243 L
.50756 .51235 L
.50498 .51178 L
.50262 .51084 L
.50053 .50961 L
.49876 .5082 L
Mistroke
.49732 .50668 L
.49622 .50514 L
.49544 .50365 L
.49498 .50224 L
.49479 .50098 L
.49483 .49987 L
.49508 .49895 L
.49549 .49822 L
.49601 .49768 L
.4966 .49732 L
.49724 .49712 L
.49788 .49707 L
.49851 .49714 L
.49909 .49732 L
.49962 .49758 L
.50008 .49789 L
.50046 .49823 L
.50076 .4986 L
.50098 .49896 L
.50113 .4993 L
.50121 .49962 L
.50123 .4999 L
.50119 .50014 L
.50112 .50033 L
.50101 .50048 L
.50088 .50059 L
.50073 .50066 L
.50058 .50069 L
.50043 .50068 L
.50029 .50066 L
.50015 .5006 L
.50004 .50054 L
.49994 .50046 L
.49986 .50038 L
.49979 .50029 L
.49975 .50021 L
.49972 .50013 L
.49971 .50006 L
.49971 .5 L
.49973 .49995 L
.49975 .4999 L
.49978 .49987 L
.49981 .49985 L
.49984 .49984 L
.49988 .49984 L
.49991 .49984 L
.49995 .49985 L
.49998 .49986 L
.5 .49988 L
.50002 .4999 L
Mistroke
.50004 .49992 L
.50005 .49994 L
.50006 .49996 L
.50007 .49998 L
.50007 .49999 L
.50007 .50001 L
.50006 .50002 L
.50006 .50003 L
.50005 .50003 L
.50004 .50004 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50001 .50003 L
.5 .50003 L
.5 .50003 L
.49999 .50002 L
.49999 .50002 L
.49999 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.578 0 1 r
.85631 0 m
.85788 .00217 L
.93305 .1456 L
.97883 .28019 L
.99811 .40195 L
.99438 .50809 L
.97147 .59687 L
.93339 .66752 L
.88409 .72012 L
.82735 .75548 L
.76663 .77495 L
.70499 .7803 L
.64505 .77357 L
.58893 .75699 L
.53827 .73279 L
.49421 .70317 L
.45745 .67018 L
.4283 .63568 L
.40669 .60129 L
.39229 .56838 L
.3845 .53801 L
.38258 .511 L
.38567 .48788 L
.39283 .46896 L
.40313 .45432 L
.41565 .44386 L
.42953 .43732 L
.444 .43434 L
.45839 .43446 L
.47213 .43718 L
.48478 .44198 L
.49601 .44833 L
.5056 .45572 L
.51342 .4637 L
.51945 .47185 L
.52373 .47982 L
.52638 .48731 L
.52755 .49411 L
.52742 .50005 L
.52623 .50504 L
.52417 .50903 L
.52148 .51201 L
.51836 .51403 L
.51501 .51517 L
.51159 .51552 L
.50826 .51519 L
.50514 .51431 L
.50231 .513 L
.49984 .51137 L
.49778 .50956 L
Mistroke
.49613 .50765 L
.49491 .50574 L
.49408 .50391 L
.49363 .50222 L
.4935 .50071 L
.49365 .49941 L
.49403 .49835 L
.49459 .49752 L
.49528 .49693 L
.49604 .49655 L
.49684 .49637 L
.49764 .49637 L
.4984 .49651 L
.49911 .49677 L
.49974 .49711 L
.50027 .49752 L
.50071 .49796 L
.50106 .49841 L
.5013 .49885 L
.50145 .49927 L
.50152 .49965 L
.50152 .49998 L
.50146 .50026 L
.50135 .50049 L
.5012 .50065 L
.50103 .50077 L
.50084 .50084 L
.50066 .50086 L
.50047 .50084 L
.5003 .5008 L
.50014 .50073 L
.5 .50064 L
.49988 .50054 L
.49979 .50043 L
.49972 .50033 L
.49967 .50022 L
.49965 .50013 L
.49964 .50004 L
.49965 .49997 L
.49967 .49991 L
.4997 .49987 L
.49974 .49983 L
.49978 .49981 L
.49982 .4998 L
.49987 .4998 L
.49991 .49981 L
.49995 .49982 L
.49998 .49984 L
.50001 .49986 L
.50004 .49989 L
Mistroke
.50006 .49991 L
.50007 .49993 L
.50008 .49996 L
.50008 .49998 L
.50008 .5 L
.50008 .50001 L
.50008 .50003 L
.50007 .50004 L
.50006 .50004 L
.50005 .50005 L
.50004 .50005 L
.50003 .50005 L
.50002 .50004 L
.50001 .50004 L
.5 .50004 L
.49999 .50003 L
.49999 .50002 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 .219 r
1 .81558 m
.99729 .81801 L
.91781 .8586 L
.83438 .87833 L
.75098 .87977 L
.67093 .86579 L
.59689 .83942 L
.53087 .80372 L
.47421 .7616 L
.42768 .71578 L
.39151 .66869 L
.36549 .62241 L
.34902 .57867 L
.34123 .53881 L
.34105 .50379 L
.34725 .47424 L
.35856 .45047 L
.37371 .43249 L
.39148 .4201 L
.41074 .41289 L
.43048 .41033 L
.44982 .41176 L
.46807 .41649 L
.48467 .4238 L
.49921 .43299 L
.51145 .44338 L
.52127 .45436 L
.52866 .46541 L
.53372 .47607 L
.53661 .48597 L
.53758 .49484 L
.53689 .5025 L
.53484 .50883 L
.53172 .51378 L
.52783 .5174 L
.52346 .51973 L
.51885 .5209 L
.51422 .52105 L
.50977 .52033 L
.50565 .51892 L
.50196 .51697 L
.49878 .51466 L
.49616 .51213 L
.49412 .50953 L
.49264 .50696 L
.49169 .50452 L
.49123 .5023 L
.49119 .50034 L
.49151 .49868 L
.49212 .49734 L
Mistroke
.49294 .49632 L
.49392 .49562 L
.49498 .4952 L
.49607 .49504 L
.49715 .4951 L
.49816 .49535 L
.49909 .49575 L
.4999 .49625 L
.50059 .49682 L
.50114 .49743 L
.50156 .49804 L
.50185 .49863 L
.50202 .49919 L
.50208 .49968 L
.50205 .50011 L
.50194 .50047 L
.50177 .50075 L
.50156 .50095 L
.50132 .50109 L
.50106 .50115 L
.50081 .50117 L
.50056 .50113 L
.50033 .50105 L
.50012 .50095 L
.49994 .50082 L
.4998 .50068 L
.49968 .50054 L
.4996 .5004 L
.49954 .50026 L
.49952 .50014 L
.49951 .50003 L
.49953 .49993 L
.49956 .49986 L
.49961 .4998 L
.49966 .49976 L
.49972 .49974 L
.49978 .49973 L
.49984 .49973 L
.49989 .49974 L
.49995 .49976 L
.49999 .49979 L
.50003 .49982 L
.50006 .49986 L
.50009 .49989 L
.5001 .49992 L
.50011 .49995 L
.50012 .49998 L
.50011 .5 L
.50011 .50002 L
.5001 .50004 L
Mistroke
.50009 .50005 L
.50007 .50006 L
.50006 .50006 L
.50005 .50006 L
.50003 .50006 L
.50002 .50006 L
.50001 .50005 L
.5 .50005 L
.49999 .50004 L
.49998 .50003 L
.49998 .50002 L
.49997 .50001 L
.49997 .50001 L
.49997 .5 L
.49997 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49998 L
.49999 .49998 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 .89 1 r
.28235 1 m
.2393 .9466 L
.16926 .82891 L
.12368 .71697 L
.10048 .61432 L
.09697 .52358 L
.11015 .44646 L
.1368 .38387 L
.17369 .33597 L
.21771 .30232 L
.26596 .28197 L
.31581 .27361 L
.36503 .27565 L
.41175 .28633 L
.45449 .30384 L
.49219 .32639 L
.52415 .35225 L
.55002 .37988 L
.56973 .40787 L
.58349 .43505 L
.5917 .46047 L
.59492 .48338 L
.59384 .50328 L
.58917 .51986 L
.58169 .53298 L
.57214 .54267 L
.56124 .54911 L
.54964 .55254 L
.53792 .55332 L
.52656 .55185 L
.51597 .54854 L
.50643 .54382 L
.49817 .5381 L
.49131 .53178 L
.4859 .5252 L
.48192 .51867 L
.4793 .51244 L
.47794 .50672 L
.47767 .50164 L
.47834 .49732 L
.47976 .49379 L
.48177 .49108 L
.48419 .48916 L
.48684 .48799 L
.4896 .48748 L
.49233 .48755 L
.49493 .48811 L
.49732 .48906 L
.49943 .49029 L
.50122 .49171 L
Mistroke
.50268 .49324 L
.50379 .49479 L
.50458 .4963 L
.50505 .49771 L
.50525 .49899 L
.50521 .50011 L
.50496 .50104 L
.50456 .50178 L
.50404 .50233 L
.50344 .5027 L
.5028 .5029 L
.50215 .50295 L
.50151 .50288 L
.50092 .5027 L
.50039 .50245 L
.49993 .50213 L
.49954 .50179 L
.49924 .50142 L
.49901 .50106 L
.49886 .50071 L
.49878 .50039 L
.49876 .50011 L
.4988 .49987 L
.49887 .49967 L
.49898 .49952 L
.49911 .49941 L
.49926 .49934 L
.49941 .49931 L
.49956 .49931 L
.49971 .49934 L
.49984 .49939 L
.49996 .49946 L
.50006 .49954 L
.50014 .49962 L
.50021 .49971 L
.50025 .49979 L
.50028 .49987 L
.50029 .49994 L
.50029 .5 L
.50028 .50005 L
.50025 .5001 L
.50023 .50013 L
.50019 .50015 L
.50016 .50016 L
.50012 .50016 L
.50009 .50016 L
.50005 .50015 L
.50002 .50014 L
.5 .50012 L
.49998 .5001 L
Mistroke
.49996 .50008 L
.49995 .50006 L
.49994 .50004 L
.49993 .50002 L
.49993 .50001 L
.49993 .49999 L
.49994 .49998 L
.49994 .49997 L
.49995 .49997 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49999 .49997 L
.5 .49997 L
.5 .49997 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 .949 r
.30931 0 m
.39244 .03415 L
.48195 .08778 L
.55782 .14929 L
.61919 .21495 L
.66594 .28146 L
.69856 .34604 L
.71799 .40641 L
.72559 .46082 L
.72295 .50807 L
.71181 .54741 L
.694 .57854 L
.67128 .60153 L
.64536 .61677 L
.61779 .62489 L
.58994 .62672 L
.56296 .62318 L
.5378 .61529 L
.51516 .60405 L
.49555 .59045 L
.47927 .57543 L
.46643 .55979 L
.45699 .54428 L
.45079 .52949 L
.44755 .51589 L
.44693 .50384 L
.44853 .49357 L
.45194 .48521 L
.45671 .47878 L
.46246 .47423 L
.46878 .47144 L
.47533 .47024 L
.48182 .47043 L
.488 .47176 L
.49366 .47402 L
.49867 .47695 L
.50292 .48033 L
.50638 .48395 L
.50903 .48764 L
.51089 .49122 L
.51201 .49459 L
.51248 .49763 L
.51237 .50027 L
.51179 .50248 L
.51082 .50424 L
.50958 .50554 L
.50816 .50642 L
.50663 .50689 L
.50509 .50702 L
.50359 .50684 L
Mistroke
.50219 .50642 L
.50092 .50581 L
.49983 .50507 L
.49891 .50424 L
.49819 .50337 L
.49765 .50251 L
.49729 .50169 L
.4971 .50093 L
.49706 .50026 L
.49714 .49968 L
.49732 .49921 L
.49758 .49885 L
.4979 .49859 L
.49825 .49843 L
.49861 .49835 L
.49897 .49836 L
.49931 .49843 L
.49963 .49855 L
.49991 .49871 L
.50015 .4989 L
.50034 .4991 L
.50049 .4993 L
.5006 .4995 L
.50066 .49969 L
.50069 .49986 L
.50069 .50001 L
.50066 .50013 L
.5006 .50023 L
.50054 .5003 L
.50046 .50035 L
.50037 .50038 L
.50029 .50039 L
.5002 .50038 L
.50013 .50036 L
.50006 .50032 L
.49999 .50028 L
.49994 .50024 L
.4999 .50019 L
.49987 .50014 L
.49985 .5001 L
.49984 .50005 L
.49984 .50002 L
.49984 .49998 L
.49985 .49996 L
.49986 .49994 L
.49988 .49992 L
.4999 .49991 L
.49992 .49991 L
.49994 .49991 L
.49996 .49991 L
Mistroke
.49998 .49992 L
.49999 .49993 L
.50001 .49994 L
.50002 .49995 L
.50003 .49996 L
.50003 .49997 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50003 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 1 .743 r
0 .15129 m
.01989 .13803 L
.10663 .10748 L
.19517 .09753 L
.2817 .10527 L
.36306 .12755 L
.43683 .16115 L
.50129 .20291 L
.55534 .24984 L
.59851 .29924 L
.63081 .34874 L
.65269 .39634 L
.66495 .44045 L
.66865 .47985 L
.66501 .51374 L
.65535 .54163 L
.64103 .56339 L
.62337 .57911 L
.60362 .58915 L
.58289 .59401 L
.56217 .59433 L
.5423 .59083 L
.52392 .58425 L
.50754 .57537 L
.49348 .56489 L
.48195 .55351 L
.47298 .54181 L
.46654 .53031 L
.46247 .51945 L
.46055 .50956 L
.46052 .50087 L
.46207 .49354 L
.46489 .48765 L
.46866 .4832 L
.47308 .48013 L
.47787 .47835 L
.48277 .47772 L
.48758 .47809 L
.49211 .47927 L
.49622 .48109 L
.49983 .48337 L
.50287 .48596 L
.5053 .48869 L
.50713 .49143 L
.50838 .49408 L
.5091 .49653 L
.50934 .49874 L
.50916 .50064 L
.50865 .5022 L
.50787 .50343 L
Mistroke
.50691 .50433 L
.50582 .50491 L
.50467 .50519 L
.50352 .50523 L
.50242 .50505 L
.50139 .5047 L
.50048 .50421 L
.49969 .50364 L
.49904 .50301 L
.49854 .50236 L
.49817 .50172 L
.49793 .50112 L
.49782 .50057 L
.49781 .50008 L
.49789 .49967 L
.49804 .49934 L
.49825 .49908 L
.49849 .49891 L
.49876 .49881 L
.49903 .49877 L
.49929 .49878 L
.49955 .49885 L
.49978 .49894 L
.49998 .49907 L
.50015 .49921 L
.50028 .49936 L
.50039 .49951 L
.50046 .49966 L
.5005 .4998 L
.50052 .49992 L
.50051 .50003 L
.50048 .50012 L
.50044 .50019 L
.50039 .50024 L
.50033 .50027 L
.50026 .50029 L
.5002 .50029 L
.50014 .50028 L
.50008 .50026 L
.50003 .50024 L
.49999 .5002 L
.49995 .50017 L
.49992 .50013 L
.4999 .5001 L
.49989 .50006 L
.49988 .50003 L
.49988 .50001 L
.49988 .49998 L
.49989 .49996 L
.4999 .49995 L
Mistroke
.49992 .49994 L
.49993 .49993 L
.49995 .49993 L
.49996 .49993 L
.49997 .49994 L
.49999 .49994 L
.5 .49995 L
.50001 .49996 L
.50002 .49996 L
.50002 .49997 L
.50003 .49998 L
.50003 .49999 L
.50003 .5 L
.50003 .5 L
.50003 .50001 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 .923 r
.29065 1 m
.20878 .88353 L
.15155 .7702 L
.11744 .66426 L
.1041 .56876 L
.10874 .48584 L
.12828 .4168 L
.15954 .36217 L
.19941 .32182 L
.24489 .29508 L
.29327 .28082 L
.34216 .27762 L
.3895 .28383 L
.43367 .29768 L
.47339 .3174 L
.50781 .34125 L
.53638 .36763 L
.55892 .39506 L
.57548 .42229 L
.58636 .44825 L
.59204 .47212 L
.59313 .49326 L
.59032 .51129 L
.58435 .52596 L
.57597 .53725 L
.56589 .54523 L
.55479 .55012 L
.54329 .55222 L
.5319 .5519 L
.52107 .54955 L
.51113 .5456 L
.50234 .54046 L
.49487 .53453 L
.4888 .52816 L
.48416 .5217 L
.48089 .5154 L
.47892 .5095 L
.4781 .50417 L
.47829 .49952 L
.47932 .49564 L
.48101 .49256 L
.48319 .49027 L
.48569 .48874 L
.48836 .4879 L
.49107 .48768 L
.4937 .48799 L
.49616 .48873 L
.49838 .4898 L
.50031 .49111 L
.50191 .49256 L
Mistroke
.50318 .49408 L
.50412 .49559 L
.50475 .49703 L
.50508 .49837 L
.50516 .49955 L
.50502 .50056 L
.5047 .50138 L
.50424 .50202 L
.50369 .50248 L
.50308 .50276 L
.50244 .50289 L
.50181 .50288 L
.50121 .50276 L
.50065 .50254 L
.50016 .50226 L
.49974 .50194 L
.4994 .50159 L
.49914 .50123 L
.49895 .50088 L
.49884 .50055 L
.49879 .50025 L
.4988 .49999 L
.49885 .49977 L
.49894 .4996 L
.49906 .49947 L
.4992 .49938 L
.49934 .49933 L
.49949 .49932 L
.49964 .49933 L
.49978 .49937 L
.4999 .49943 L
.50001 .4995 L
.5001 .49958 L
.50017 .49967 L
.50023 .49975 L
.50026 .49983 L
.50028 .4999 L
.50029 .49997 L
.50028 .50003 L
.50026 .50007 L
.50024 .50011 L
.50021 .50014 L
.50017 .50015 L
.50014 .50016 L
.5001 .50016 L
.50007 .50015 L
.50004 .50014 L
.50001 .50013 L
.49999 .50011 L
.49997 .50009 L
Mistroke
.49995 .50007 L
.49994 .50005 L
.49994 .50003 L
.49993 .50002 L
.49993 .5 L
.49994 .49999 L
.49994 .49998 L
.49995 .49997 L
.49995 .49997 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49999 .49997 L
.49999 .49997 L
.5 .49997 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 .129 0 r
.67961 1 m
.63146 .98223 L
.53793 .93038 L
.45789 .86964 L
.39239 .80386 L
.34171 .7365 L
.30549 .67049 L
.28287 .60827 L
.27256 .5517 L
.273 .50215 L
.28245 .46046 L
.29908 .42705 L
.32108 .40192 L
.3467 .38475 L
.37434 .37494 L
.40256 .37171 L
.43015 .37413 L
.45611 .38119 L
.47965 .39187 L
.50023 .40516 L
.51749 .42011 L
.53128 .43585 L
.54161 .45163 L
.54862 .46682 L
.55255 .48089 L
.55376 .49346 L
.55262 .50428 L
.54956 .51319 L
.54501 .52015 L
.53939 .52518 L
.53309 .52839 L
.52649 .52996 L
.51988 .53007 L
.51354 .52897 L
.50768 .52688 L
.50245 .52405 L
.49796 .52072 L
.49428 .51709 L
.49141 .51336 L
.48935 .5097 L
.48805 .50623 L
.48743 .50308 L
.48741 .5003 L
.4879 .49796 L
.4888 .49608 L
.49 .49466 L
.49141 .49367 L
.49293 .4931 L
.49449 .4929 L
.49602 .49301 L
Mistroke
.49747 .49339 L
.49878 .49397 L
.49994 .49469 L
.50091 .49552 L
.50168 .49639 L
.50227 .49726 L
.50267 .4981 L
.5029 .49889 L
.50298 .49959 L
.50292 .5002 L
.50276 .5007 L
.50251 .50109 L
.5022 .50138 L
.50186 .50156 L
.50149 .50166 L
.50113 .50167 L
.50077 .50161 L
.50045 .5015 L
.50016 .50134 L
.4999 .50116 L
.4997 .50096 L
.49953 .50075 L
.49942 .50055 L
.49934 .50036 L
.49931 .50018 L
.4993 .50003 L
.49933 .4999 L
.49938 .49979 L
.49944 .49971 L
.49952 .49965 L
.4996 .49962 L
.49969 .49961 L
.49977 .49961 L
.49985 .49963 L
.49993 .49966 L
.49999 .4997 L
.50005 .49975 L
.50009 .4998 L
.50012 .49984 L
.50015 .49989 L
.50016 .49994 L
.50016 .49997 L
.50016 .50001 L
.50015 .50004 L
.50014 .50006 L
.50012 .50008 L
.5001 .50009 L
.50008 .50009 L
.50006 .50009 L
.50004 .50009 L
Mistroke
.50003 .50008 L
.50001 .50008 L
.5 .50007 L
.49998 .50005 L
.49997 .50004 L
.49997 .50003 L
.49996 .50002 L
.49996 .50001 L
.49996 .5 L
.49996 .49999 L
.49997 .49999 L
.49997 .49998 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.424 0 1 r
.99211 0 m
1 .01699 L
s
1 .73565 m
.94652 .78394 L
.87544 .82064 L
.80077 .83863 L
.72605 .84018 L
.65429 .82788 L
.58788 .80445 L
.52862 .7726 L
.47773 .73496 L
.43589 .69397 L
.40334 .65181 L
.37988 .61034 L
.36499 .57112 L
.35789 .53535 L
.35761 .50391 L
.36307 .47736 L
.37313 .45598 L
.38665 .43979 L
.40253 .42861 L
.41976 .42207 L
.43743 .41971 L
.45477 .42093 L
.47113 .42512 L
.48602 .43163 L
.49908 .43983 L
.51008 .44912 L
.51891 .45896 L
.52556 .46885 L
.53013 .4784 L
.53276 .48729 L
.53365 .49525 L
.53306 .50213 L
.53124 .50781 L
.52846 .51228 L
.52499 .51553 L
.52108 .51764 L
.51695 .51871 L
.51281 .51886 L
.50882 .51822 L
.50512 .51697 L
.50181 .51523 L
.49895 .51317 L
.4966 .51091 L
.49476 .50857 L
.49343 .50627 L
.49257 .50409 L
.49215 .50209 L
.49211 .50033 L
.49239 .49884 L
.49293 .49764 L
Mistroke
.49367 .49672 L
.49454 .49608 L
.49549 .4957 L
.49647 .49556 L
.49743 .49561 L
.49834 .49583 L
.49917 .49619 L
.4999 .49663 L
.50052 .49714 L
.50102 .49769 L
.50139 .49824 L
.50165 .49877 L
.50181 .49926 L
.50186 .49971 L
.50184 .50009 L
.50174 .50041 L
.50159 .50066 L
.5014 .50085 L
.50118 .50097 L
.50096 .50103 L
.50073 .50104 L
.5005 .50101 L
.5003 .50095 L
.50011 .50085 L
.49995 .50074 L
.49982 .50061 L
.49972 .50048 L
.49964 .50036 L
.49959 .50023 L
.49957 .50012 L
.49956 .50003 L
.49958 .49994 L
.49961 .49987 L
.49965 .49982 L
.49969 .49979 L
.49975 .49976 L
.4998 .49975 L
.49985 .49976 L
.4999 .49977 L
.49995 .49979 L
.49999 .49981 L
.50003 .49984 L
.50005 .49987 L
.50008 .4999 L
.50009 .49993 L
.5001 .49996 L
.5001 .49998 L
.5001 .5 L
.5001 .50002 L
.50009 .50004 L
Mistroke
.50008 .50005 L
.50007 .50005 L
.50005 .50006 L
.50004 .50006 L
.50003 .50006 L
.50002 .50005 L
.50001 .50005 L
.5 .50004 L
.49999 .50003 L
.49998 .50003 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 .91 0 r
.1835 1 m
.14869 .94967 L
.08201 .815 L
.04275 .68935 L
.02808 .57631 L
.03464 .47835 L
.05876 .397 L
.09664 .33282 L
.14458 .28563 L
.19903 .25459 L
.25678 .23834 L
.31498 .23517 L
.37124 .2431 L
.42361 .26003 L
.47063 .28383 L
.51128 .31246 L
.54495 .344 L
.57142 .3767 L
.59078 .40909 L
.6034 .43992 L
.60986 .46819 L
.61089 .4932 L
.60732 .51447 L
.60004 .53175 L
.58992 .54498 L
.57783 .55428 L
.56457 .55993 L
.55085 .56227 L
.53731 .56174 L
.52444 .55883 L
.51267 .55404 L
.50228 .54785 L
.49346 .54074 L
.48632 .53315 L
.48088 .52545 L
.47707 .51796 L
.47479 .51096 L
.47389 .50465 L
.47417 .49916 L
.47545 .49459 L
.4775 .49097 L
.48012 .48829 L
.48311 .48651 L
.4863 .48555 L
.48953 .48533 L
.49265 .48573 L
.49557 .48663 L
.4982 .48793 L
.50047 .4895 L
.50237 .49123 L
Mistroke
.50386 .49304 L
.50496 .49484 L
.50569 .49655 L
.50607 .49813 L
.50614 .49953 L
.50596 .50072 L
.50557 .5017 L
.50502 .50244 L
.50436 .50298 L
.50363 .5033 L
.50287 .50344 L
.50212 .50343 L
.5014 .50327 L
.50075 .50301 L
.50016 .50268 L
.49967 .50229 L
.49927 .50187 L
.49896 .50144 L
.49874 .50102 L
.49861 .50063 L
.49856 .50028 L
.49857 .49997 L
.49863 .49972 L
.49874 .49951 L
.49889 .49936 L
.49905 .49926 L
.49923 .4992 L
.49941 .49919 L
.49958 .49921 L
.49974 .49926 L
.49989 .49933 L
.50002 .49941 L
.50012 .49951 L
.50021 .49961 L
.50027 .49971 L
.50031 .4998 L
.50033 .49989 L
.50034 .49997 L
.50033 .50004 L
.50031 .50009 L
.50028 .50013 L
.50024 .50016 L
.5002 .50018 L
.50016 .50019 L
.50012 .50019 L
.50008 .50018 L
.50004 .50017 L
.50001 .50015 L
.49998 .50013 L
.49996 .50011 L
Mistroke
.49994 .50008 L
.49993 .50006 L
.49992 .50004 L
.49992 .50002 L
.49992 .5 L
.49992 .49999 L
.49993 .49997 L
.49994 .49997 L
.49995 .49996 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49999 .49996 L
.49999 .49996 L
.5 .49997 L
.50001 .49997 L
.50001 .49998 L
.50001 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.342 0 1 r
.88036 0 m
.9479 .12748 L
.99634 .26762 L
s
.99634 .26762 m
1 .28997 L
s
1 .56095 m
.99069 .59809 L
.95155 .67205 L
.90064 .72725 L
.84188 .76451 L
.77889 .7852 L
.71485 .79117 L
.6525 .78454 L
.59406 .76759 L
.54125 .74266 L
.49526 .71203 L
.45685 .67784 L
.42633 .64203 L
.40365 .60628 L
.38847 .57203 L
.38018 .54039 L
.37802 .51222 L
.38108 .48808 L
.38841 .46829 L
.39902 .45295 L
.41197 .44195 L
.42636 .43504 L
.44138 .43184 L
.45634 .43188 L
.47064 .43463 L
.48382 .43956 L
.49553 .44611 L
.50554 .45377 L
.51372 .46204 L
.52004 .47051 L
.52454 .47879 L
.52734 .4866 L
.5286 .49368 L
.52851 .49988 L
.52729 .50509 L
.52518 .50926 L
.5224 .51239 L
.51917 .51453 L
.5157 .51574 L
.51215 .51612 L
.50869 .5158 L
.50543 .5149 L
.50248 .51355 L
.49991 .51187 L
.49775 .50999 L
.49603 .50801 L
.49474 .50603 L
.49387 .50412 L
.49339 .50236 L
.49325 .50078 L
Mistroke
.4934 .49943 L
.49379 .49832 L
.49436 .49745 L
.49507 .49682 L
.49586 .49642 L
.49669 .49623 L
.49752 .49622 L
.49832 .49637 L
.49905 .49663 L
.49971 .49699 L
.50027 .49741 L
.50073 .49786 L
.50109 .49833 L
.50134 .49879 L
.50151 .49923 L
.50158 .49962 L
.50158 .49997 L
.50152 .50026 L
.5014 .5005 L
.50125 .50068 L
.50108 .5008 L
.50088 .50087 L
.50069 .50089 L
.50049 .50088 L
.50031 .50083 L
.50015 .50076 L
.5 .50066 L
.49988 .50056 L
.49979 .50045 L
.49971 .50034 L
.49966 .50024 L
.49964 .50014 L
.49963 .50005 L
.49963 .49997 L
.49965 .49991 L
.49969 .49986 L
.49972 .49983 L
.49977 .4998 L
.49981 .49979 L
.49986 .49979 L
.4999 .4998 L
.49994 .49981 L
.49998 .49983 L
.50001 .49985 L
.50004 .49988 L
.50006 .49991 L
.50007 .49993 L
.50008 .49996 L
.50009 .49998 L
.50009 .5 L
Mistroke
.50008 .50001 L
.50008 .50003 L
.50007 .50004 L
.50006 .50004 L
.50005 .50005 L
.50004 .50005 L
.50003 .50005 L
.50002 .50005 L
.50001 .50004 L
.5 .50004 L
.49999 .50003 L
.49999 .50003 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.355 1 0 r
0 .15525 m
.07929 .11936 L
.16685 .10256 L
.25368 .10436 L
.33642 .12168 L
.41242 .15135 L
.47972 .1902 L
.53703 .23521 L
.58365 .28357 L
.61945 .33283 L
.64472 .38086 L
.66015 .42595 L
.66669 .46676 L
.66552 .50235 L
.65792 .53213 L
.64522 .55584 L
.62876 .57351 L
.60979 .58541 L
.58947 .59198 L
.56884 .59382 L
.54877 .59161 L
.52996 .58609 L
.51298 .57802 L
.49821 .56812 L
.48588 .55709 L
.47609 .54554 L
.46884 .53403 L
.46399 .523 L
.46136 .51283 L
.4607 .50377 L
.46171 .49602 L
.4641 .48967 L
.46753 .48476 L
.47172 .48124 L
.47636 .47904 L
.4812 .47803 L
.48602 .47806 L
.49062 .47896 L
.49486 .48056 L
.49863 .48268 L
.50184 .48515 L
.50447 .48782 L
.50649 .49055 L
.50793 .49322 L
.50882 .49573 L
.50922 .49801 L
.50918 .5 L
.50878 .50167 L
.5081 .50301 L
.5072 .50401 L
Mistroke
.50616 .50469 L
.50504 .50508 L
.50389 .50519 L
.50278 .50509 L
.50173 .50479 L
.50078 .50436 L
.49996 .50381 L
.49926 .50321 L
.49871 .50257 L
.4983 .50193 L
.49802 .50132 L
.49787 .50075 L
.49782 .50024 L
.49787 .49981 L
.498 .49945 L
.49819 .49917 L
.49842 .49897 L
.49867 .49885 L
.49894 .49879 L
.49921 .49878 L
.49946 .49883 L
.4997 .49892 L
.49991 .49903 L
.50009 .49917 L
.50024 .49931 L
.50035 .49947 L
.50043 .49961 L
.50049 .49975 L
.50051 .49988 L
.50051 .49999 L
.50049 .50009 L
.50045 .50016 L
.5004 .50022 L
.50035 .50026 L
.50028 .50028 L
.50022 .50029 L
.50016 .50028 L
.5001 .50027 L
.50005 .50024 L
.5 .50021 L
.49996 .50018 L
.49993 .50014 L
.49991 .50011 L
.49989 .50008 L
.49988 .50004 L
.49988 .50002 L
.49988 .49999 L
.49989 .49997 L
.4999 .49996 L
.49991 .49994 L
Mistroke
.49993 .49994 L
.49994 .49993 L
.49996 .49993 L
.49997 .49993 L
.49998 .49994 L
.49999 .49995 L
.5 .49995 L
.50001 .49996 L
.50002 .49997 L
.50002 .49998 L
.50003 .49999 L
.50003 .49999 L
.50003 .5 L
.50003 .5 L
.50003 .50001 L
.50002 .50001 L
.50002 .50001 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.114 0 1 r
.39307 1 m
.35369 .96197 L
.27588 .8627 L
.21953 .76487 L
.18345 .67215 L
.16581 .58743 L
.16437 .51282 L
.17659 .44967 L
.19977 .39868 L
.23124 .35992 L
.26841 .33298 L
.30887 .31705 L
.35047 .311 L
.39138 .31347 L
.43006 .32301 L
.46533 .33809 L
.49633 .35722 L
.52249 .379 L
.54356 .40211 L
.5595 .42543 L
.5705 .44799 L
.57692 .46901 L
.57923 .48789 L
.578 .50422 L
.57385 .51777 L
.56741 .52843 L
.55931 .53624 L
.55014 .54134 L
.54044 .54398 L
.53067 .54443 L
.52125 .54303 L
.51249 .54014 L
.50464 .53611 L
.49786 .53128 L
.49226 .52597 L
.48786 .52048 L
.48466 .51505 L
.48258 .50989 L
.48154 .50516 L
.4814 .50099 L
.48202 .49744 L
.48327 .49457 L
.48498 .49238 L
.48702 .49084 L
.48925 .48992 L
.49156 .48954 L
.49383 .48965 L
.49598 .49015 L
.49795 .49097 L
.49968 .49201 L
Mistroke
.50115 .49321 L
.50234 .49449 L
.50324 .49578 L
.50387 .49703 L
.50424 .4982 L
.50438 .49926 L
.50433 .50017 L
.50411 .50093 L
.50376 .50154 L
.50332 .50198 L
.50281 .50227 L
.50228 .50243 L
.50174 .50246 L
.50121 .50239 L
.50073 .50224 L
.50029 .50202 L
.49991 .50175 L
.49959 .50146 L
.49934 .50116 L
.49916 .50085 L
.49904 .50057 L
.49898 .5003 L
.49897 .50007 L
.499 .49987 L
.49907 .49971 L
.49916 .49959 L
.49927 .4995 L
.4994 .49944 L
.49952 .49942 L
.49965 .49943 L
.49977 .49945 L
.49988 .4995 L
.49998 .49955 L
.50006 .49962 L
.50013 .49969 L
.50018 .49976 L
.50021 .49983 L
.50023 .4999 L
.50024 .49995 L
.50024 .50001 L
.50023 .50005 L
.50021 .50008 L
.50019 .50011 L
.50016 .50012 L
.50013 .50013 L
.5001 .50014 L
.50007 .50013 L
.50004 .50012 L
.50002 .50011 L
.5 .5001 L
Mistroke
.49998 .50008 L
.49996 .50007 L
.49995 .50005 L
.49995 .50003 L
.49994 .50002 L
.49994 .5 L
.49994 .49999 L
.49995 .49998 L
.49995 .49998 L
.49996 .49997 L
.49997 .49997 L
.49997 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49998 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 .666 r
.09778 1 m
.04203 .89777 L
s
.04203 .89777 m
0 .78116 L
s
0 .38505 m
.02896 .3275 L
.0808 .26882 L
.14108 .2288 L
.20603 .20606 L
.27231 .19872 L
.33706 .2046 L
.39793 .22136 L
.45311 .24656 L
.5013 .27786 L
.54171 .31301 L
.57396 .35 L
.59807 .38705 L
.61439 .42267 L
.62352 .45566 L
.62624 .48513 L
.62348 .51046 L
.61622 .53131 L
.60548 .54755 L
.59225 .55929 L
.57745 .56678 L
.56193 .57039 L
.54643 .5706 L
.53155 .56796 L
.51781 .56303 L
.50556 .55636 L
.49505 .54851 L
.48643 .53999 L
.47973 .53123 L
.47492 .52263 L
.47189 .5145 L
.47046 .5071 L
.47045 .50061 L
.47162 .49513 L
.47374 .49073 L
.47657 .4874 L
.47988 .48511 L
.48346 .48379 L
.48713 .48332 L
.49073 .4836 L
.49411 .48449 L
.4972 .48586 L
.49989 .48757 L
.50216 .4895 L
.50398 .49155 L
.50535 .4936 L
.50628 .49558 L
.50681 .49742 L
.50699 .49907 L
.50686 .50049 L
Mistroke
.50647 .50166 L
.50589 .50258 L
.50516 .50324 L
.50435 .50367 L
.50349 .50389 L
.50263 .50391 L
.5018 .50378 L
.50104 .50351 L
.50035 .50315 L
.49976 .50272 L
.49928 .50225 L
.4989 .50176 L
.49863 .50129 L
.49845 .50083 L
.49837 .50042 L
.49836 .50006 L
.49842 .49975 L
.49854 .4995 L
.49869 .49931 L
.49887 .49918 L
.49907 .49911 L
.49927 .49908 L
.49947 .49909 L
.49966 .49914 L
.49983 .49921 L
.49998 .4993 L
.50011 .49941 L
.50021 .49952 L
.50029 .49964 L
.50034 .49975 L
.50038 .49985 L
.50039 .49994 L
.50038 .50002 L
.50036 .50009 L
.50033 .50014 L
.50029 .50018 L
.50024 .5002 L
.5002 .50021 L
.50015 .50022 L
.5001 .50021 L
.50006 .5002 L
.50002 .50018 L
.49999 .50015 L
.49996 .50013 L
.49994 .5001 L
.49992 .50007 L
.49991 .50005 L
.49991 .50002 L
.49991 .5 L
.49991 .49999 L
Mistroke
.49992 .49997 L
.49993 .49996 L
.49994 .49996 L
.49995 .49995 L
.49996 .49995 L
.49997 .49995 L
.49998 .49995 L
.49999 .49996 L
.5 .49996 L
.50001 .49997 L
.50001 .49997 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.72 1 0 r
1 .78295 m
.94568 .82215 L
.86769 .85269 L
.78751 .86422 L
.70871 .85934 L
.63421 .84087 L
.5663 .81174 L
.50665 .77481 L
.45631 .73283 L
.41579 .68827 L
.38515 .64334 L
.36402 .59989 L
.35172 .55942 L
.34732 .52307 L
.34974 .49164 L
.35778 .46558 L
.37021 .44509 L
.38584 .43008 L
.40352 .42028 L
.42223 .41523 L
.44104 .41439 L
.45919 .41711 L
.47605 .4227 L
.49117 .43049 L
.50421 .43981 L
.51499 .45004 L
.52344 .46062 L
.5296 .47108 L
.53358 .48102 L
.53559 .49012 L
.53584 .49815 L
.53463 .50497 L
.53222 .5105 L
.52891 .51472 L
.52498 .51767 L
.52068 .51944 L
.51624 .52015 L
.51186 .51994 L
.50772 .51897 L
.50393 .51739 L
.50059 .51537 L
.49776 .51306 L
.49548 .5106 L
.49375 .50811 L
.49254 .5057 L
.49182 .50344 L
.49155 .50141 L
.49166 .49965 L
.49208 .49819 L
.49276 .49703 L
Mistroke
.49361 .49618 L
.49459 .49562 L
.49562 .49532 L
.49666 .49526 L
.49767 .49539 L
.49861 .49569 L
.49945 .49612 L
.50019 .49663 L
.50079 .49719 L
.50127 .49778 L
.50162 .49836 L
.50185 .49891 L
.50197 .49942 L
.50199 .49987 L
.50192 .50025 L
.5018 .50056 L
.50162 .5008 L
.5014 .50097 L
.50116 .50107 L
.50092 .50111 L
.50067 .50111 L
.50044 .50106 L
.50023 .50097 L
.50005 .50086 L
.49989 .50073 L
.49976 .5006 L
.49966 .50046 L
.49959 .50032 L
.49955 .5002 L
.49953 .50009 L
.49954 .49999 L
.49956 .4999 L
.4996 .49984 L
.49964 .49979 L
.4997 .49976 L
.49975 .49974 L
.49981 .49974 L
.49987 .49974 L
.49992 .49976 L
.49997 .49978 L
.50001 .49981 L
.50004 .49984 L
.50007 .49987 L
.50009 .49991 L
.5001 .49994 L
.50011 .49997 L
.50011 .49999 L
.50011 .50001 L
.5001 .50003 L
.50009 .50004 L
Mistroke
.50008 .50005 L
.50007 .50006 L
.50005 .50006 L
.50004 .50006 L
.50003 .50006 L
.50001 .50005 L
.5 .50005 L
.49999 .50004 L
.49999 .50003 L
.49998 .50003 L
.49998 .50002 L
.49998 .50001 L
.49997 .50001 L
.49997 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 1 .303 r
.07864 .9885 m
.00793 .83496 L
s
.00793 .83496 m
0 .80655 L
s
0 .36444 m
.04498 .29591 L
.10188 .24511 L
.16556 .21266 L
.2324 .19691 L
.2992 .19581 L
.36331 .20705 L
.4226 .2282 L
.47546 .25683 L
.52081 .29058 L
.55806 .32729 L
.587 .36501 L
.60781 .40208 L
.62098 .43711 L
.62719 .46903 L
.62732 .49706 L
.62233 .52071 L
.61326 .53974 L
.60111 .55412 L
.58687 .56403 L
.57144 .56979 L
.55563 .57183 L
.54014 .57067 L
.52552 .56688 L
.51224 .56101 L
.50059 .55365 L
.4908 .54533 L
.48294 .53653 L
.47703 .52768 L
.47298 .51914 L
.47066 .51121 L
.46989 .50411 L
.47045 .49798 L
.4721 .49291 L
.4746 .48895 L
.47772 .48606 L
.48122 .48419 L
.48492 .48325 L
.48862 .48314 L
.49218 .48372 L
.49549 .48485 L
.49844 .48641 L
.50099 .48826 L
.50308 .49029 L
.50472 .49238 L
.5059 .49443 L
.50666 .49638 L
.50703 .49816 L
.50706 .49973 L
.5068 .50106 L
Mistroke
.50631 .50213 L
.50565 .50295 L
.50487 .50351 L
.50402 .50385 L
.50314 .50398 L
.50228 .50392 L
.50147 .50372 L
.50073 .5034 L
.50008 .503 L
.49953 .50254 L
.49908 .50206 L
.49875 .50157 L
.49852 .50109 L
.49838 .50065 L
.49833 .50025 L
.49836 .49991 L
.49845 .49963 L
.49858 .4994 L
.49875 .49924 L
.49895 .49913 L
.49915 .49908 L
.49936 .49907 L
.49955 .4991 L
.49974 .49916 L
.4999 .49924 L
.50005 .49934 L
.50016 .49945 L
.50026 .49957 L
.50032 .49968 L
.50037 .49979 L
.50039 .49989 L
.50039 .49998 L
.50038 .50005 L
.50035 .50011 L
.50032 .50016 L
.50027 .50019 L
.50023 .50021 L
.50018 .50022 L
.50013 .50022 L
.50008 .50021 L
.50004 .50019 L
.50001 .50017 L
.49998 .50014 L
.49995 .50012 L
.49993 .50009 L
.49992 .50006 L
.49991 .50004 L
.49991 .50002 L
.49991 .5 L
.49991 .49998 L
Mistroke
.49992 .49997 L
.49993 .49996 L
.49994 .49995 L
.49995 .49995 L
.49996 .49995 L
.49997 .49995 L
.49998 .49995 L
.49999 .49996 L
.5 .49996 L
.50001 .49997 L
.50001 .49998 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 .75 0 r
0 .01986 m
.09502 .00371 L
.20297 .00795 L
.30547 .03119 L
.39929 .06945 L
.48208 .11878 L
.55229 .17544 L
.60914 .23598 L
.6525 .29736 L
.6828 .35699 L
.70092 .41276 L
.7081 .46307 L
.70581 .50678 L
.69565 .5432 L
.6793 .57205 L
.65841 .59338 L
.63453 .60756 L
.60911 .61515 L
.5834 .61693 L
.55849 .61374 L
.53524 .60651 L
.51431 .59619 L
.49617 .58368 L
.4811 .56983 L
.4692 .55541 L
.46044 .54109 L
.45467 .52742 L
.45164 .51486 L
.45103 .50371 L
.45248 .49421 L
.45559 .48646 L
.45998 .4805 L
.46527 .47628 L
.47109 .47368 L
.47714 .47255 L
.48313 .4727 L
.48883 .47392 L
.49407 .47599 L
.4987 .47868 L
.50264 .4818 L
.50584 .48514 L
.50829 .48854 L
.51002 .49185 L
.51107 .49496 L
.51151 .49777 L
.51142 .50021 L
.51089 .50226 L
.51 .50389 L
.50886 .5051 L
.50755 .50591 L
Mistroke
.50614 .50636 L
.50472 .50648 L
.50334 .50632 L
.50204 .50593 L
.50087 .50537 L
.49985 .50469 L
.49901 .50392 L
.49834 .50313 L
.49784 .50233 L
.49751 .50157 L
.49733 .50087 L
.49729 .50025 L
.49736 .49971 L
.49753 .49928 L
.49776 .49894 L
.49805 .4987 L
.49838 .49855 L
.49871 .49848 L
.49904 .49849 L
.49936 .49855 L
.49965 .49866 L
.49991 .49881 L
.50013 .49898 L
.50031 .49916 L
.50045 .49935 L
.50055 .49954 L
.50061 .49971 L
.50064 .49987 L
.50063 .5 L
.50061 .50012 L
.50056 .50021 L
.5005 .50028 L
.50042 .50032 L
.50035 .50035 L
.50027 .50036 L
.50019 .50035 L
.50012 .50033 L
.50005 .5003 L
.5 .50026 L
.49995 .50022 L
.49991 .50018 L
.49988 .50013 L
.49986 .50009 L
.49985 .50005 L
.49985 .50002 L
.49985 .49999 L
.49986 .49996 L
.49988 .49994 L
.49989 .49993 L
.49991 .49992 L
Mistroke
.49993 .49992 L
.49995 .49992 L
.49996 .49992 L
.49998 .49993 L
.49999 .49993 L
.50001 .49994 L
.50002 .49995 L
.50002 .49996 L
.50003 .49997 L
.50003 .49998 L
.50004 .49999 L
.50004 .5 L
.50003 .50001 L
.50003 .50001 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 .178 1 r
.48513 1 m
.48014 .99659 L
.39055 .91492 L
.31972 .82976 L
.26747 .74509 L
.23291 .66421 L
.21458 .58975 L
.2106 .52366 L
.21884 .46723 L
.23699 .42117 L
.26275 .38565 L
.29386 .36041 L
.32822 .34481 L
.36394 .33791 L
.39936 .33861 L
.43312 .34565 L
.46413 .35773 L
.4916 .37356 L
.51499 .3919 L
.53403 .41162 L
.54866 .43171 L
.55898 .45131 L
.5653 .46971 L
.56798 .48636 L
.56752 .50089 L
.56443 .51305 L
.55926 .52273 L
.55255 .52995 L
.54482 .53482 L
.53653 .53751 L
.52812 .53827 L
.51993 .53737 L
.51226 .53513 L
.50533 .53184 L
.4993 .52781 L
.49426 .52331 L
.49027 .5186 L
.4873 .5139 L
.48532 .5094 L
.48424 .50525 L
.48397 .50156 L
.48438 .49839 L
.48535 .4958 L
.48675 .49379 L
.48846 .49235 L
.49035 .49145 L
.49232 .49104 L
.49429 .49105 L
.49617 .49142 L
.4979 .49207 L
Mistroke
.49943 .49293 L
.50074 .49394 L
.50182 .49503 L
.50264 .49614 L
.50323 .49723 L
.5036 .49825 L
.50376 .49918 L
.50375 .5 L
.50358 .50068 L
.5033 .50122 L
.50294 .50163 L
.50251 .50191 L
.50206 .50207 L
.50159 .50212 L
.50114 .50208 L
.50071 .50196 L
.50032 .50178 L
.49998 .50156 L
.4997 .50131 L
.49948 .50105 L
.49931 .50079 L
.49919 .50054 L
.49913 .50031 L
.49911 .5001 L
.49913 .49992 L
.49918 .49978 L
.49926 .49966 L
.49935 .49958 L
.49946 .49953 L
.49957 .4995 L
.49968 .4995 L
.49978 .49952 L
.49988 .49956 L
.49996 .4996 L
.50004 .49966 L
.5001 .49972 L
.50014 .49978 L
.50018 .49984 L
.5002 .4999 L
.50021 .49995 L
.50021 .5 L
.5002 .50004 L
.50018 .50007 L
.50016 .50009 L
.50014 .5001 L
.50012 .50011 L
.50009 .50012 L
.50006 .50012 L
.50004 .50011 L
.50002 .5001 L
Mistroke
.5 .50009 L
.49998 .50007 L
.49997 .50006 L
.49996 .50004 L
.49996 .50003 L
.49995 .50002 L
.49995 .50001 L
.49995 .5 L
.49995 .49999 L
.49996 .49998 L
.49996 .49998 L
.49997 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 .209 0 r
.2052 1 m
.15019 .9172 L
.08936 .7879 L
.05472 .66785 L
.04345 .56036 L
.05224 .46772 L
.07753 .39124 L
.11565 .33138 L
.16303 .28788 L
.21627 .25984 L
.27231 .24591 L
.32846 .24438 L
.38246 .25332 L
.43248 .27068 L
.47718 .29443 L
.51561 .32258 L
.54725 .35332 L
.57192 .38498 L
.58975 .41616 L
.60113 .44568 L
.60664 .47264 L
.607 .49637 L
.60303 .51643 L
.59557 .53261 L
.58549 .54489 L
.5736 .55341 L
.56069 .55842 L
.54741 .56029 L
.53438 .55945 L
.52206 .55637 L
.51084 .55152 L
.50098 .5454 L
.49267 .53844 L
.48599 .53106 L
.48094 .52363 L
.47746 .51644 L
.47544 .50975 L
.47473 .50375 L
.47514 .49855 L
.47648 .49425 L
.47855 .49087 L
.48114 .4884 L
.48407 .48679 L
.48717 .48596 L
.49028 .48583 L
.49328 .48629 L
.49607 .48722 L
.49857 .48851 L
.50072 .49006 L
.5025 .49175 L
Mistroke
.5039 .49351 L
.50491 .49524 L
.50556 .49688 L
.50589 .49838 L
.50593 .49971 L
.50573 .50084 L
.50533 .50175 L
.50478 .50244 L
.50412 .50293 L
.50341 .50322 L
.50268 .50334 L
.50195 .5033 L
.50127 .50314 L
.50064 .50287 L
.50009 .50254 L
.49962 .50216 L
.49925 .50175 L
.49896 .50134 L
.49876 .50094 L
.49865 .50057 L
.4986 .50023 L
.49862 .49994 L
.49869 .4997 L
.4988 .49951 L
.49894 .49937 L
.49911 .49927 L
.49928 .49922 L
.49945 .49922 L
.49962 .49924 L
.49977 .49929 L
.49991 .49936 L
.50003 .49944 L
.50013 .49954 L
.50021 .49963 L
.50027 .49973 L
.50031 .49982 L
.50033 .4999 L
.50033 .49998 L
.50032 .50004 L
.5003 .50009 L
.50027 .50013 L
.50023 .50016 L
.50019 .50018 L
.50015 .50018 L
.50011 .50018 L
.50007 .50017 L
.50004 .50016 L
.50001 .50014 L
.49998 .50012 L
.49996 .5001 L
Mistroke
.49994 .50008 L
.49993 .50005 L
.49993 .50003 L
.49992 .50001 L
.49992 .5 L
.49993 .49998 L
.49993 .49997 L
.49994 .49997 L
.49995 .49996 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49999 .49996 L
.49999 .49996 L
.5 .49997 L
.50001 .49997 L
.50001 .49998 L
.50001 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 .779 0 r
.59466 1 m
.53284 .96464 L
.44679 .89759 L
.37668 .8254 L
.32275 .75179 L
.28457 .67993 L
.26114 .61241 L
.25102 .55123 L
.25248 .49783 L
.26361 .45308 L
.2824 .4174 L
.30687 .39075 L
.33514 .37275 L
.36547 .36272 L
.39631 .3598 L
.42634 .36295 L
.45449 .37107 L
.47995 .38305 L
.50212 .39778 L
.52065 .41423 L
.53537 .43148 L
.54632 .44869 L
.55366 .46519 L
.55767 .48044 L
.55874 .49402 L
.55728 .50566 L
.55377 .5152 L
.54867 .5226 L
.54244 .52792 L
.53552 .53126 L
.52828 .53281 L
.52108 .53281 L
.51419 .53149 L
.50784 .52913 L
.5022 .52598 L
.49737 .52229 L
.49342 .51831 L
.49037 .51423 L
.4882 .51024 L
.48684 .50648 L
.48623 .50307 L
.48627 .50008 L
.48685 .49756 L
.48787 .49555 L
.4892 .49404 L
.49075 .49301 L
.49243 .49243 L
.49414 .49224 L
.4958 .49239 L
.49737 .49282 L
Mistroke
.49879 .49347 L
.50004 .49428 L
.50108 .49518 L
.50191 .49614 L
.50253 .49709 L
.50295 .49801 L
.50318 .49886 L
.50325 .49962 L
.50318 .50027 L
.50299 .50081 L
.50272 .50123 L
.50238 .50153 L
.50199 .50172 L
.50159 .50181 L
.5012 .50182 L
.50081 .50175 L
.50046 .50162 L
.50014 .50145 L
.49987 .50125 L
.49965 .50103 L
.49948 .5008 L
.49935 .50058 L
.49928 .50037 L
.49924 .50018 L
.49924 .50002 L
.49927 .49987 L
.49932 .49976 L
.4994 .49968 L
.49948 .49962 L
.49957 .49958 L
.49967 .49957 L
.49976 .49958 L
.49985 .4996 L
.49993 .49964 L
.5 .49968 L
.50006 .49973 L
.5001 .49978 L
.50014 .49984 L
.50016 .49989 L
.50018 .49993 L
.50018 .49998 L
.50018 .50001 L
.50017 .50004 L
.50015 .50007 L
.50013 .50008 L
.50011 .50009 L
.50009 .5001 L
.50007 .5001 L
.50005 .5001 L
.50003 .50009 L
Mistroke
.50001 .50008 L
.49999 .50007 L
.49998 .50006 L
.49997 .50005 L
.49996 .50003 L
.49996 .50002 L
.49996 .50001 L
.49996 .5 L
.49996 .49999 L
.49996 .49999 L
.49997 .49998 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 1 .545 r
.63417 0 m
.70365 .07903 L
.7715 .18229 L
.8176 .28168 L
.8436 .37385 L
.85168 .45626 L
.84441 .52719 L
.82452 .58565 L
.79486 .6313 L
.75816 .66437 L
.71703 .68555 L
.67383 .69592 L
.63061 .69678 L
.5891 .68964 L
.5507 .67606 L
.51643 .65762 L
.48701 .63584 L
.46283 .61212 L
.44402 .58773 L
.43047 .56374 L
.42187 .54106 L
.41778 .52037 L
.41763 .5022 L
.4208 .48685 L
.42663 .47449 L
.43446 .46514 L
.44365 .45868 L
.45362 .45491 L
.46384 .45355 L
.47387 .45427 L
.48333 .45669 L
.49194 .46047 L
.49949 .46521 L
.50585 .47059 L
.51096 .47628 L
.5148 .482 L
.51744 .48753 L
.51895 .49266 L
.51947 .49727 L
.51912 .50124 L
.51807 .50453 L
.51646 .50711 L
.51445 .50899 L
.51219 .51021 L
.5098 .51082 L
.5074 .51091 L
.50509 .51054 L
.50295 .50981 L
.50104 .50881 L
.49939 .50761 L
Mistroke
.49803 .5063 L
.49697 .50495 L
.4962 .50362 L
.4957 .50236 L
.49546 .50121 L
.49543 .50019 L
.4956 .49933 L
.49591 .49863 L
.49634 .4981 L
.49684 .49773 L
.49739 .49751 L
.49796 .49743 L
.49851 .49746 L
.49904 .49759 L
.49952 .49779 L
.49994 .49805 L
.5003 .49835 L
.50059 .49866 L
.50081 .49898 L
.50096 .49929 L
.50105 .49957 L
.50108 .49983 L
.50106 .50005 L
.50101 .50024 L
.50092 .50038 L
.50081 .50049 L
.50068 .50056 L
.50055 .5006 L
.50042 .5006 L
.50029 .50059 L
.50017 .50055 L
.50006 .50049 L
.49997 .50043 L
.4999 .50035 L
.49984 .50028 L
.49979 .50021 L
.49976 .50014 L
.49975 .50007 L
.49975 .50001 L
.49976 .49997 L
.49977 .49993 L
.4998 .4999 L
.49982 .49988 L
.49985 .49986 L
.49988 .49986 L
.49992 .49986 L
.49994 .49987 L
.49997 .49988 L
.5 .49989 L
.50002 .49991 L
Mistroke
.50003 .49992 L
.50004 .49994 L
.50005 .49996 L
.50006 .49998 L
.50006 .49999 L
.50006 .5 L
.50006 .50001 L
.50005 .50002 L
.50005 .50003 L
.50004 .50003 L
.50003 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.5 .50003 L
.5 .50002 L
.49999 .50002 L
.49999 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.474 0 1 r
1 .80041 m
.96724 .82567 L
.88767 .85958 L
.80537 .87367 L
.72407 .87056 L
.64686 .85312 L
.57618 .82437 L
.51379 .78726 L
.46087 .74462 L
.41801 .69904 L
.38531 .65282 L
.36245 .60791 L
.34876 .56589 L
.34331 .52799 L
.34501 .49505 L
.35263 .4676 L
.36492 .44585 L
.38064 .42975 L
.3986 .41905 L
.41774 .41331 L
.4371 .41195 L
.45586 .41434 L
.47338 .41976 L
.48915 .42753 L
.50282 .43694 L
.51418 .44737 L
.52315 .45822 L
.52976 .46901 L
.53412 .4793 L
.53641 .48877 L
.53688 .49716 L
.53579 .50433 L
.53345 .51017 L
.53015 .51466 L
.52617 .51785 L
.52179 .51981 L
.51724 .52067 L
.51272 .52056 L
.50843 .51964 L
.50449 .51809 L
.501 .51606 L
.49803 .51372 L
.49561 .5112 L
.49376 .50864 L
.49246 .50615 L
.49167 .50381 L
.49133 .50169 L
.4914 .49985 L
.4918 .49831 L
.49246 .49708 L
Mistroke
.49332 .49617 L
.49431 .49555 L
.49537 .49521 L
.49644 .49512 L
.49748 .49524 L
.49846 .49553 L
.49934 .49595 L
.50011 .49647 L
.50074 .49704 L
.50125 .49764 L
.50163 .49824 L
.50188 .49881 L
.50201 .49934 L
.50204 .49981 L
.50199 .50021 L
.50186 .50054 L
.50168 .5008 L
.50147 .50098 L
.50122 .50109 L
.50097 .50114 L
.50072 .50114 L
.50048 .50109 L
.50026 .50101 L
.50007 .5009 L
.4999 .50077 L
.49977 .50063 L
.49966 .50049 L
.49959 .50035 L
.49954 .50022 L
.49952 .5001 L
.49952 .5 L
.49954 .49991 L
.49958 .49984 L
.49963 .49979 L
.49968 .49976 L
.49974 .49974 L
.4998 .49973 L
.49986 .49974 L
.49991 .49975 L
.49996 .49977 L
.5 .4998 L
.50004 .49983 L
.50007 .49987 L
.50009 .4999 L
.5001 .49993 L
.50011 .49996 L
.50011 .49999 L
.50011 .50001 L
.5001 .50003 L
.50009 .50004 L
Mistroke
.50008 .50005 L
.50007 .50006 L
.50005 .50006 L
.50004 .50006 L
.50003 .50006 L
.50002 .50006 L
.5 .50005 L
.5 .50004 L
.49999 .50004 L
.49998 .50003 L
.49998 .50002 L
.49997 .50001 L
.49997 .50001 L
.49997 .5 L
.49997 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.164 0 1 r
.14233 1 m
.1174 .96279 L
.04969 .82036 L
.01086 .68798 L
s
.01086 .68798 m
0 .58915 L
s
0 .54495 m
.00696 .46697 L
.03435 .38236 L
.07596 .31604 L
.12785 .26772 L
.18629 .23644 L
.24789 .22073 L
.30969 .21871 L
.36917 .22826 L
.42434 .24714 L
.47368 .27311 L
.51614 .30398 L
.55115 .33773 L
.57849 .37255 L
.5983 .40688 L
.611 .43942 L
.61722 .46916 L
.61776 .49536 L
.6135 .51754 L
.60538 .53545 L
.59436 .54908 L
.58133 .55855 L
.56714 .56416 L
.55254 .5663 L
.53819 .56545 L
.52461 .56212 L
.51223 .55684 L
.50135 .55013 L
.49216 .5425 L
.48476 .53439 L
.47915 .52621 L
.47528 .51829 L
.47302 .51091 L
.47221 .50428 L
.47263 .49855 L
.47408 .49379 L
.47634 .49005 L
.47917 .4873 L
.48239 .4855 L
.48579 .48457 L
.48922 .48441 L
.49253 .4849 L
.4956 .48591 L
.49836 .48732 L
.50074 .48902 L
.50271 .49088 L
.50425 .4928 L
.50538 .49471 L
.50611 .49652 L
.50648 .49818 L
Mistroke
.50653 .49965 L
.50631 .50089 L
.50587 .5019 L
.50527 .50267 L
.50456 .50321 L
.50378 .50354 L
.50297 .50367 L
.50217 .50363 L
.50141 .50346 L
.50072 .50317 L
.50012 .5028 L
.4996 .50238 L
.49918 .50194 L
.49887 .50148 L
.49864 .50104 L
.49851 .50063 L
.49846 .50026 L
.49848 .49994 L
.49856 .49967 L
.49868 .49946 L
.49883 .49931 L
.49901 .4992 L
.4992 .49915 L
.49939 .49914 L
.49957 .49916 L
.49974 .49922 L
.4999 .49929 L
.50003 .49938 L
.50014 .49949 L
.50023 .49959 L
.50029 .4997 L
.50034 .4998 L
.50036 .49989 L
.50036 .49997 L
.50035 .50004 L
.50033 .5001 L
.50029 .50015 L
.50026 .50018 L
.50021 .50019 L
.50017 .5002 L
.50012 .5002 L
.50008 .50019 L
.50004 .50018 L
.50001 .50016 L
.49998 .50013 L
.49996 .50011 L
.49994 .50008 L
.49993 .50006 L
.49992 .50004 L
.49991 .50002 L
Mistroke
.49992 .5 L
.49992 .49998 L
.49993 .49997 L
.49993 .49996 L
.49994 .49996 L
.49995 .49995 L
.49997 .49995 L
.49998 .49995 L
.49999 .49996 L
.49999 .49996 L
.5 .49997 L
.50001 .49997 L
.50001 .49998 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 .889 0 r
.03187 1 m
0 .92982 L
s
0 .29313 m
.01058 .27733 L
.07235 .22318 L
.14131 .1888 L
.21354 .17238 L
.28563 .1717 L
.35472 .18426 L
.41853 .20743 L
.47535 .23858 L
.52403 .27518 L
.56394 .31489 L
.59488 .35564 L
.61707 .39561 L
.63101 .43334 L
.63747 .46768 L
.6374 .4978 L
.63184 .52317 L
.62191 .54354 L
.60869 .5589 L
.59325 .56944 L
.57656 .57551 L
.55949 .57759 L
.54278 .57623 L
.52704 .57204 L
.51275 .56564 L
.50024 .55764 L
.48973 .54862 L
.48132 .53911 L
.475 .52956 L
.4707 .52036 L
.46826 .51182 L
.46749 .50418 L
.46813 .4976 L
.46995 .49218 L
.47268 .48793 L
.47606 .48485 L
.47986 .48287 L
.48385 .4819 L
.48785 .4818 L
.49169 .48245 L
.49525 .48369 L
.49842 .48539 L
.50115 .4874 L
.5034 .48959 L
.50515 .49184 L
.50641 .49406 L
.50721 .49616 L
.5076 .49808 L
.50762 .49977 L
.50733 .50119 L
Mistroke
.5068 .50234 L
.50608 .50321 L
.50523 .50381 L
.50431 .50416 L
.50336 .50429 L
.50243 .50423 L
.50156 .50401 L
.50076 .50366 L
.50006 .50323 L
.49947 .50273 L
.499 .5022 L
.49864 .50167 L
.49839 .50116 L
.49825 .50069 L
.4982 .50026 L
.49823 .49989 L
.49833 .49959 L
.49848 .49935 L
.49866 .49917 L
.49887 .49906 L
.49909 .499 L
.49931 .49899 L
.49952 .49902 L
.49972 .49909 L
.4999 .49918 L
.50005 .49929 L
.50018 .49941 L
.50028 .49954 L
.50035 .49966 L
.5004 .49978 L
.50042 .49989 L
.50042 .49998 L
.50041 .50006 L
.50038 .50013 L
.50034 .50017 L
.50029 .50021 L
.50024 .50023 L
.50019 .50024 L
.50014 .50023 L
.50009 .50022 L
.50005 .5002 L
.50001 .50018 L
.49997 .50015 L
.49995 .50012 L
.49993 .50009 L
.49991 .50007 L
.4999 .50004 L
.4999 .50002 L
.4999 .5 L
.49991 .49998 L
Mistroke
.49991 .49996 L
.49993 .49995 L
.49994 .49995 L
.49995 .49994 L
.49996 .49994 L
.49997 .49995 L
.49998 .49995 L
.49999 .49995 L
.5 .49996 L
.50001 .49997 L
.50002 .49997 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 1 .465 r
0 .08367 m
.05332 .06376 L
.15214 .05097 L
.24901 .05819 L
.34036 .08192 L
.42343 .11856 L
.49623 .16457 L
.55749 .21661 L
.60661 .27162 L
.64359 .32694 L
.66889 .3803 L
.68337 .42987 L
.68819 .4743 L
.68472 .51261 L
.67441 .54428 L
.65879 .56909 L
.63932 .58715 L
.61741 .59883 L
.59432 .60468 L
.57116 .6054 L
.54888 .6018 L
.52822 .5947 L
.50975 .58495 L
.49385 .57338 L
.48075 .56072 L
.47053 .54767 L
.46312 .53481 L
.45838 .52262 L
.45606 .51149 L
.45588 .50168 L
.45748 .49338 L
.46053 .48667 L
.46467 .48158 L
.46956 .47804 L
.47488 .47595 L
.48035 .47515 L
.48572 .47548 L
.49081 .47673 L
.49545 .47872 L
.49952 .48123 L
.50296 .48409 L
.50573 .48713 L
.50782 .4902 L
.50927 .49317 L
.51011 .49593 L
.51042 .49841 L
.51025 .50056 L
.50971 .50234 L
.50886 .50374 L
.5078 .50476 L
Mistroke
.50659 .50544 L
.50532 .50578 L
.50403 .50584 L
.50279 .50566 L
.50164 .50528 L
.50061 .50475 L
.49972 .50411 L
.49898 .50341 L
.4984 .50269 L
.49798 .50198 L
.49771 .5013 L
.49757 .50068 L
.49755 .50013 L
.49764 .49966 L
.4978 .49929 L
.49803 .499 L
.49829 .4988 L
.49859 .49867 L
.49889 .49863 L
.49919 .49864 L
.49947 .49871 L
.49973 .49881 L
.49996 .49895 L
.50015 .49911 L
.50031 .49928 L
.50043 .49945 L
.50051 .49961 L
.50056 .49976 L
.50058 .4999 L
.50057 .50002 L
.50054 .50012 L
.50049 .5002 L
.50044 .50026 L
.50037 .5003 L
.5003 .50032 L
.50023 .50032 L
.50016 .50031 L
.5001 .50029 L
.50004 .50027 L
.49999 .50023 L
.49995 .50019 L
.49991 .50015 L
.49989 .50011 L
.49987 .50007 L
.49987 .50004 L
.49986 .50001 L
.49987 .49998 L
.49988 .49996 L
.49989 .49995 L
.4999 .49993 L
Mistroke
.49992 .49993 L
.49994 .49992 L
.49995 .49992 L
.49997 .49993 L
.49998 .49993 L
.5 .49994 L
.50001 .49995 L
.50002 .49996 L
.50002 .49997 L
.50003 .49998 L
.50003 .49999 L
.50003 .49999 L
.50003 .5 L
.50003 .50001 L
.50003 .50001 L
.50002 .50001 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.165 0 1 r
.40608 0 m
.49499 .0562 L
.57605 .12504 L
.64105 .19783 L
.68997 .27102 L
.72344 .34161 L
.74261 .40721 L
.74899 .46598 L
.74439 .51668 L
.73076 .55857 L
.71009 .5914 L
.68434 .6153 L
.65534 .63075 L
.6248 .63849 L
.59416 .63946 L
.56468 .63469 L
.53734 .6253 L
.5129 .6124 L
.49187 .59708 L
.47454 .58034 L
.46101 .56308 L
.45121 .54606 L
.44493 .52993 L
.44187 .5152 L
.44162 .50222 L
.44375 .49124 L
.44778 .48237 L
.45326 .47563 L
.45972 .47095 L
.46676 .46818 L
.474 .46712 L
.48111 .46756 L
.48784 .46921 L
.49397 .47184 L
.49936 .47517 L
.50392 .47896 L
.50758 .48298 L
.51035 .48703 L
.51226 .49096 L
.51338 .49461 L
.51378 .4979 L
.51357 .50074 L
.51284 .50309 L
.51172 .50495 L
.51032 .5063 L
.50872 .50719 L
.50703 .50765 L
.50533 .50773 L
.5037 .50749 L
.50217 .50698 L
Mistroke
.50081 .50628 L
.49963 .50544 L
.49865 .50452 L
.49789 .50356 L
.49733 .50262 L
.49697 .50172 L
.49679 .5009 L
.49676 .50017 L
.49687 .49955 L
.49709 .49906 L
.49739 .49867 L
.49774 .49841 L
.49813 .49825 L
.49853 .49818 L
.49893 .4982 L
.4993 .49829 L
.49964 .49843 L
.49994 .49861 L
.5002 .49882 L
.50041 .49904 L
.50056 .49927 L
.50067 .49948 L
.50074 .49969 L
.50076 .49987 L
.50075 .50003 L
.50071 .50016 L
.50065 .50027 L
.50058 .50034 L
.50049 .5004 L
.5004 .50042 L
.5003 .50043 L
.50021 .50042 L
.50013 .50039 L
.50005 .50035 L
.49998 .5003 L
.49993 .50025 L
.49989 .5002 L
.49985 .50015 L
.49983 .5001 L
.49982 .50005 L
.49982 .50001 L
.49983 .49998 L
.49984 .49995 L
.49985 .49993 L
.49987 .49991 L
.49989 .4999 L
.49992 .4999 L
.49994 .4999 L
.49996 .4999 L
.49998 .49991 L
Mistroke
.5 .49992 L
.50001 .49993 L
.50002 .49995 L
.50003 .49996 L
.50004 .49997 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50004 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 .704 r
.41289 1 m
.33319 .91615 L
.26462 .82035 L
.21647 .72712 L
.18739 .63978 L
.17548 .56087 L
.17846 .49219 L
.19382 .43485 L
.21896 .38933 L
.2513 .35553 L
.28839 .33294 L
.32799 .32066 L
.36812 .31752 L
.40707 .32218 L
.44349 .3332 L
.47632 .34913 L
.50482 .36853 L
.52856 .39007 L
.54735 .41256 L
.56122 .43492 L
.57042 .4563 L
.57533 .476 L
.57643 .49349 L
.57431 .50844 L
.56955 .52065 L
.56277 .53007 L
.55458 .53678 L
.54551 .54094 L
.53608 .54279 L
.52672 .54264 L
.5178 .5408 L
.5096 .53763 L
.50233 .53346 L
.49613 .52863 L
.49108 .52342 L
.4872 .51812 L
.48446 .51294 L
.48278 .50807 L
.48205 .50367 L
.48216 .49982 L
.48297 .4966 L
.48432 .49403 L
.48609 .49212 L
.48813 .49082 L
.49032 .4901 L
.49254 .48989 L
.4947 .49012 L
.49673 .49071 L
.49857 .49158 L
.50016 .49264 L
Mistroke
.5015 .49383 L
.50256 .49507 L
.50334 .49631 L
.50387 .4975 L
.50416 .4986 L
.50423 .49957 L
.50413 .50041 L
.50387 .5011 L
.50351 .50163 L
.50306 .50201 L
.50256 .50225 L
.50204 .50237 L
.50152 .50236 L
.50102 .50227 L
.50056 .5021 L
.50016 .50187 L
.49981 .50161 L
.49952 .50132 L
.4993 .50102 L
.49915 .50074 L
.49905 .50047 L
.49901 .50022 L
.49901 .5 L
.49905 .49982 L
.49913 .49968 L
.49922 .49957 L
.49933 .4995 L
.49945 .49945 L
.49958 .49944 L
.4997 .49945 L
.49981 .49948 L
.49991 .49953 L
.5 .49959 L
.50008 .49965 L
.50014 .49972 L
.50018 .49979 L
.50021 .49986 L
.50023 .49992 L
.50023 .49997 L
.50023 .50002 L
.50022 .50006 L
.5002 .50009 L
.50017 .50011 L
.50014 .50012 L
.50011 .50013 L
.50009 .50013 L
.50006 .50013 L
.50003 .50012 L
.50001 .5001 L
.49999 .50009 L
Mistroke
.49997 .50007 L
.49996 .50006 L
.49995 .50004 L
.49995 .50003 L
.49995 .50001 L
.49995 .5 L
.49995 .49999 L
.49995 .49998 L
.49996 .49998 L
.49996 .49997 L
.49997 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49998 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 .981 1 r
.52804 1 m
.45058 .94137 L
.37233 .86299 L
.31175 .78268 L
.26842 .70395 L
.24131 .62971 L
.22889 .56221 L
.22932 .50305 L
.24049 .45327 L
.26025 .41334 L
.28643 .3833 L
.31694 .36274 L
.34988 .35097 L
.38353 .34706 L
.41644 .34988 L
.4474 .35826 L
.4755 .37096 L
.50007 .38678 L
.52069 .40459 L
.53717 .42335 L
.54952 .44217 L
.5579 .46028 L
.56263 .47707 L
.56409 .49208 L
.56275 .505 L
.55912 .51564 L
.55371 .52395 L
.54702 .52997 L
.53952 .53383 L
.53165 .53571 L
.52377 .53586 L
.51621 .53455 L
.50921 .53207 L
.50297 .52871 L
.49761 .52474 L
.49321 .52042 L
.48979 .51597 L
.48732 .5116 L
.48576 .50747 L
.48501 .5037 L
.48499 .50039 L
.48557 .49759 L
.48663 .49534 L
.48806 .49364 L
.48974 .49247 L
.49155 .49178 L
.49342 .49153 L
.49524 .49167 L
.49697 .49211 L
.49854 .4928 L
Mistroke
.49991 .49366 L
.50107 .49464 L
.502 .49568 L
.5027 .49672 L
.50318 .49773 L
.50345 .49867 L
.50355 .49951 L
.50348 .50023 L
.50329 .50083 L
.503 .5013 L
.50263 .50164 L
.50222 .50186 L
.50178 .50197 L
.50135 .50199 L
.50093 .50192 L
.50054 .50179 L
.50019 .5016 L
.49989 .50139 L
.49964 .50115 L
.49945 .5009 L
.49931 .50066 L
.49922 .50043 L
.49917 .50022 L
.49917 .50003 L
.4992 .49988 L
.49926 .49975 L
.49933 .49965 L
.49942 .49959 L
.49953 .49955 L
.49963 .49953 L
.49973 .49954 L
.49983 .49956 L
.49991 .4996 L
.49999 .49965 L
.50006 .4997 L
.50011 .49976 L
.50015 .49981 L
.50017 .49987 L
.50019 .49992 L
.5002 .49997 L
.50019 .50001 L
.50018 .50004 L
.50017 .50007 L
.50015 .50009 L
.50012 .5001 L
.5001 .50011 L
.50008 .50011 L
.50005 .50011 L
.50003 .5001 L
.50001 .50009 L
Mistroke
.49999 .50008 L
.49998 .50006 L
.49997 .50005 L
.49996 .50004 L
.49996 .50002 L
.49995 .50001 L
.49995 .5 L
.49996 .49999 L
.49996 .49999 L
.49996 .49998 L
.49997 .49998 L
.49997 .49998 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 .627 r
.35603 0 m
.43466 .03934 L
.52139 .09984 L
.59335 .16664 L
.65003 .23604 L
.6916 .30486 L
.71884 .37043 L
.73295 .43066 L
.73549 .48399 L
.72819 .5294 L
.71295 .56634 L
.69163 .5947 L
.66608 .61472 L
.63798 .62694 L
.60888 .63212 L
.5801 .63118 L
.55273 .62515 L
.52765 .61508 L
.50549 .60203 L
.48667 .58699 L
.4714 .57089 L
.45973 .55454 L
.45154 .53863 L
.4466 .52373 L
.4446 .51028 L
.44513 .49857 L
.44777 .4888 L
.45207 .48105 L
.4576 .47529 L
.46394 .47145 L
.4707 .46937 L
.47755 .46885 L
.4842 .46966 L
.49041 .47155 L
.49601 .47427 L
.50086 .47759 L
.50491 .48127 L
.50811 .48511 L
.51047 .48893 L
.51203 .49257 L
.51286 .49593 L
.51305 .49891 L
.51268 .50146 L
.51186 .50354 L
.5107 .50515 L
.5093 .50629 L
.50775 .50699 L
.50614 .50731 L
.50455 .50728 L
.50303 .50696 L
Mistroke
.50163 .50642 L
.50039 .50571 L
.49933 .50488 L
.49847 .50399 L
.49781 .50308 L
.49734 .5022 L
.49706 .50137 L
.49694 .50062 L
.49696 .49996 L
.49709 .49942 L
.49733 .49898 L
.49763 .49865 L
.49798 .49843 L
.49835 .49831 L
.49873 .49827 L
.4991 .49831 L
.49945 .49842 L
.49976 .49856 L
.50003 .49875 L
.50026 .49895 L
.50044 .49916 L
.50057 .49937 L
.50066 .49957 L
.50071 .49976 L
.50072 .49993 L
.5007 .50007 L
.50066 .50019 L
.5006 .50028 L
.50052 .50034 L
.50044 .50039 L
.50035 .5004 L
.50026 .5004 L
.50017 .50039 L
.5001 .50036 L
.50003 .50032 L
.49997 .50027 L
.49992 .50022 L
.49988 .50017 L
.49985 .50013 L
.49984 .50008 L
.49983 .50004 L
.49983 .5 L
.49984 .49997 L
.49985 .49994 L
.49987 .49993 L
.49989 .49991 L
.49991 .49991 L
.49993 .4999 L
.49995 .49991 L
.49997 .49991 L
Mistroke
.49999 .49992 L
.5 .49993 L
.50001 .49994 L
.50002 .49995 L
.50003 .49996 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .5 L
.50004 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.168 0 1 r
.80932 0 m
.84307 .04801 L
.91053 .18154 L
.95074 .30637 L
.96647 .41891 L
.96102 .51662 L
.93801 .59798 L
.90118 .66236 L
.85421 .70991 L
.80063 .74143 L
.74362 .75824 L
.68602 .76202 L
.63023 .75472 L
.57819 .7384 L
.53138 .71517 L
.49083 .68706 L
.45715 .65599 L
.4306 .62367 L
.41108 .59159 L
.39825 .561 L
.39155 .53288 L
.39027 .50796 L
.39357 .48672 L
.40061 .46942 L
.41049 .45612 L
.42236 .44672 L
.43543 .44095 L
.44898 .43847 L
.4624 .43885 L
.47517 .44161 L
.48688 .44627 L
.49724 .45232 L
.50604 .45931 L
.51319 .46681 L
.51866 .47443 L
.52251 .48185 L
.52484 .4888 L
.5258 .49509 L
.52558 .50056 L
.52437 .50513 L
.52238 .50876 L
.51981 .51146 L
.51687 .51327 L
.51372 .51426 L
.51053 .51451 L
.50743 .51415 L
.50453 .51328 L
.50191 .51202 L
.49964 .51048 L
.49775 .50876 L
Mistroke
.49625 .50698 L
.49514 .5052 L
.49441 .5035 L
.49401 .50193 L
.49392 .50053 L
.49409 .49934 L
.49446 .49837 L
.495 .49762 L
.49565 .49708 L
.49637 .49675 L
.49712 .4966 L
.49787 .49661 L
.49858 .49675 L
.49923 .497 L
.49981 .49733 L
.5003 .49772 L
.5007 .49813 L
.50101 .49855 L
.50123 .49897 L
.50137 .49935 L
.50143 .4997 L
.50142 .50001 L
.50136 .50027 L
.50125 .50047 L
.50111 .50063 L
.50095 .50073 L
.50077 .50079 L
.5006 .5008 L
.50042 .50079 L
.50026 .50074 L
.50012 .50067 L
.49999 .50059 L
.49988 .50049 L
.4998 .50039 L
.49973 .50029 L
.49969 .5002 L
.49967 .50011 L
.49966 .50003 L
.49967 .49997 L
.49969 .49991 L
.49972 .49987 L
.49976 .49984 L
.4998 .49982 L
.49984 .49981 L
.49988 .49981 L
.49992 .49982 L
.49995 .49983 L
.49999 .49985 L
.50001 .49987 L
.50004 .49989 L
Mistroke
.50006 .49992 L
.50007 .49994 L
.50008 .49996 L
.50008 .49998 L
.50008 .5 L
.50008 .50001 L
.50007 .50003 L
.50006 .50003 L
.50005 .50004 L
.50004 .50004 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50001 .50004 L
.5 .50003 L
.49999 .50003 L
.49999 .50002 L
.49999 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 .735 r
1 .76937 m
.99349 .77656 L
.92172 .82298 L
.84461 .84902 L
.7661 .85693 L
.68956 .84929 L
.61772 .82892 L
.5527 .79866 L
.49602 .76131 L
.4486 .71951 L
.41084 .67565 L
.38271 .6318 L
.36379 .58972 L
.35336 .55081 L
.35046 .51611 L
.35401 .48634 L
.36282 .46189 L
.37571 .4429 L
.3915 .42924 L
.40909 .4206 L
.42749 .41652 L
.44584 .41643 L
.46341 .4197 L
.47962 .42566 L
.49405 .43363 L
.50639 .44298 L
.5165 .45311 L
.52433 .46348 L
.52992 .47366 L
.53342 .48325 L
.53503 .49197 L
.53497 .49961 L
.53353 .50604 L
.53097 .5112 L
.52759 .51508 L
.52365 .51773 L
.51939 .51925 L
.51505 .51976 L
.51079 .51939 L
.50679 .51831 L
.50316 .51667 L
.49999 .51463 L
.49733 .51233 L
.4952 .5099 L
.4936 .50747 L
.49252 .50513 L
.49191 .50296 L
.49172 .50102 L
.49189 .49935 L
.49236 .49798 L
Mistroke
.49306 .4969 L
.49393 .49613 L
.49489 .49563 L
.49591 .49539 L
.49693 .49537 L
.49791 .49554 L
.49881 .49586 L
.49962 .49629 L
.50031 .4968 L
.50088 .49736 L
.50132 .49794 L
.50164 .4985 L
.50184 .49904 L
.50194 .49952 L
.50194 .49995 L
.50186 .50031 L
.50173 .5006 L
.50154 .50082 L
.50133 .50097 L
.50109 .50106 L
.50085 .50109 L
.50061 .50108 L
.50039 .50102 L
.50019 .50093 L
.50001 .50082 L
.49986 .50069 L
.49974 .50056 L
.49965 .50042 L
.49959 .50029 L
.49955 .50017 L
.49954 .50006 L
.49955 .49997 L
.49957 .49989 L
.49961 .49983 L
.49966 .49979 L
.49971 .49976 L
.49977 .49975 L
.49983 .49974 L
.49988 .49975 L
.49993 .49977 L
.49998 .49979 L
.50001 .49982 L
.50005 .49985 L
.50007 .49988 L
.50009 .49991 L
.5001 .49994 L
.50011 .49997 L
.50011 .5 L
.5001 .50002 L
.5001 .50003 L
Mistroke
.50009 .50004 L
.50007 .50005 L
.50006 .50006 L
.50005 .50006 L
.50003 .50006 L
.50002 .50006 L
.50001 .50005 L
.5 .50005 L
.49999 .50004 L
.49999 .50003 L
.49998 .50002 L
.49998 .50002 L
.49998 .50001 L
.49997 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.484 1 0 r
.43801 0 m
.48118 .02604 L
.56832 .09711 L
.63874 .17289 L
.69231 .24957 L
.72959 .32397 L
.7517 .39345 L
.7602 .45605 L
.75692 .51035 L
.7439 .55552 L
.72322 .59122 L
.69693 .61754 L
.66698 .63493 L
.63517 .64414 L
.60305 .6461 L
.57198 .64191 L
.54301 .63271 L
.51697 .61968 L
.49444 .60396 L
.47574 .58661 L
.46102 .56858 L
.45022 .5507 L
.44314 .53366 L
.43948 .51801 L
.43882 .50416 L
.44071 .49236 L
.44467 .48276 L
.45021 .47539 L
.45685 .47019 L
.46415 .46702 L
.47171 .46567 L
.47919 .46592 L
.4863 .46748 L
.49282 .4701 L
.49857 .47349 L
.50346 .4774 L
.50743 .48158 L
.51046 .48583 L
.51259 .48996 L
.51387 .49383 L
.51439 .49733 L
.51426 .50037 L
.51357 .50291 L
.51245 .50492 L
.51102 .50642 L
.50937 .50742 L
.50761 .50796 L
.50583 .50809 L
.50411 .50788 L
.50249 .50739 L
Mistroke
.50104 .50668 L
.49978 .50582 L
.49872 .50487 L
.49789 .50387 L
.49728 .50288 L
.49687 .50193 L
.49666 .50106 L
.49661 .50028 L
.49671 .49962 L
.49692 .49908 L
.49722 .49866 L
.49758 .49837 L
.49799 .49818 L
.4984 .4981 L
.49882 .49811 L
.49921 .49819 L
.49958 .49833 L
.4999 .49852 L
.50017 .49873 L
.5004 .49896 L
.50057 .4992 L
.50069 .49943 L
.50076 .49964 L
.5008 .49984 L
.50079 .50001 L
.50075 .50015 L
.50069 .50027 L
.50062 .50035 L
.50053 .50041 L
.50043 .50044 L
.50033 .50045 L
.50023 .50044 L
.50014 .50041 L
.50006 .50037 L
.49999 .50033 L
.49993 .50027 L
.49989 .50022 L
.49985 .50016 L
.49983 .50011 L
.49982 .50006 L
.49981 .50002 L
.49982 .49998 L
.49983 .49995 L
.49984 .49993 L
.49986 .49991 L
.49989 .4999 L
.49991 .4999 L
.49993 .4999 L
.49995 .4999 L
.49998 .49991 L
Mistroke
.49999 .49992 L
.50001 .49993 L
.50002 .49994 L
.50003 .49995 L
.50004 .49997 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50004 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 .31 r
.49339 1 m
.41108 .92974 L
.33666 .84599 L
.28072 .76186 L
.24253 .68075 L
.22077 .60545 L
.21366 .53801 L
.21915 .47988 L
.23499 .43189 L
.25888 .39433 L
.28858 .36702 L
.32197 .34941 L
.35711 .34066 L
.39233 .33968 L
.4262 .34527 L
.45758 .35615 L
.48562 .37103 L
.50974 .38869 L
.52959 .40796 L
.54507 .42781 L
.55627 .44737 L
.56341 .46589 L
.56688 .4828 L
.56711 .49769 L
.56462 .51028 L
.55995 .52043 L
.55363 .52814 L
.54618 .53348 L
.53808 .53663 L
.52976 .53781 L
.52158 .53729 L
.51385 .53536 L
.50681 .53232 L
.50063 .52848 L
.49541 .52412 L
.49122 .51949 L
.48805 .51483 L
.48587 .51032 L
.4846 .50613 L
.48415 .50236 L
.48441 .4991 L
.48525 .4964 L
.48654 .49428 L
.48817 .49273 L
.49001 .49172 L
.49195 .4912 L
.4939 .49111 L
.49578 .4914 L
.49753 .49198 L
.4991 .49279 L
Mistroke
.50045 .49376 L
.50157 .49483 L
.50244 .49592 L
.50308 .49701 L
.50349 .49804 L
.5037 .49898 L
.50372 .49982 L
.50359 .50052 L
.50334 .5011 L
.503 .50153 L
.50259 .50184 L
.50214 .50202 L
.50168 .50209 L
.50123 .50207 L
.5008 .50197 L
.5004 .5018 L
.50006 .50159 L
.49977 .50135 L
.49953 .5011 L
.49935 .50084 L
.49922 .50059 L
.49915 .50036 L
.49912 .50014 L
.49913 .49996 L
.49918 .49981 L
.49925 .49969 L
.49934 .4996 L
.49944 .49954 L
.49955 .49951 L
.49965 .49951 L
.49976 .49952 L
.49986 .49955 L
.49994 .4996 L
.50002 .49965 L
.50008 .49971 L
.50013 .49977 L
.50017 .49983 L
.50019 .49989 L
.5002 .49994 L
.50021 .49999 L
.5002 .50003 L
.50019 .50006 L
.50017 .50008 L
.50015 .5001 L
.50012 .50011 L
.50009 .50012 L
.50007 .50011 L
.50005 .50011 L
.50002 .5001 L
.5 .50009 L
Mistroke
.49999 .50008 L
.49997 .50006 L
.49996 .50005 L
.49996 .50003 L
.49995 .50002 L
.49995 .50001 L
.49995 .5 L
.49995 .49999 L
.49996 .49998 L
.49996 .49998 L
.49997 .49997 L
.49997 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.424 0 1 r
.02212 1 m
0 .95886 L
s
0 .28082 m
.03627 .24063 L
.10361 .19694 L
.176 .17237 L
.24972 .16486 L
.32161 .17195 L
.38909 .19102 L
.45018 .21939 L
.50345 .25442 L
.54803 .29365 L
.58354 .33484 L
.61 .37601 L
.62781 .41554 L
.63766 .45209 L
.64042 .4847 L
.63712 .51268 L
.62886 .53566 L
.61678 .55353 L
.60197 .56638 L
.58546 .57452 L
.56818 .57837 L
.55095 .57847 L
.53445 .57542 L
.51922 .56984 L
.50566 .56236 L
.49406 .55359 L
.48456 .54409 L
.4772 .53434 L
.47193 .52479 L
.46863 .51578 L
.46712 .50759 L
.46716 .5004 L
.46851 .49436 L
.4709 .48951 L
.47407 .48586 L
.47777 .48336 L
.48177 .48193 L
.48585 .48145 L
.48984 .48179 L
.4936 .4828 L
.49701 .48434 L
.49999 .48625 L
.5025 .48841 L
.5045 .49069 L
.506 .49297 L
.50702 .49517 L
.5076 .49721 L
.50777 .49903 L
.50761 .5006 L
.50718 .50189 L
Mistroke
.50652 .5029 L
.50571 .50363 L
.5048 .5041 L
.50384 .50433 L
.50289 .50435 L
.50197 .50419 L
.50112 .50389 L
.50036 .50349 L
.49971 .503 L
.49918 .50248 L
.49876 .50194 L
.49846 .50141 L
.49827 .50091 L
.49818 .50045 L
.49818 .50005 L
.49825 .49971 L
.49838 .49944 L
.49855 .49923 L
.49875 .49909 L
.49897 .499 L
.4992 .49897 L
.49942 .49899 L
.49963 .49904 L
.49982 .49913 L
.49999 .49923 L
.50013 .49935 L
.50024 .49948 L
.50033 .4996 L
.50039 .49972 L
.50042 .49984 L
.50043 .49994 L
.50042 .50003 L
.5004 .5001 L
.50036 .50016 L
.50032 .5002 L
.50027 .50023 L
.50022 .50024 L
.50016 .50024 L
.50011 .50023 L
.50007 .50022 L
.50002 .50019 L
.49999 .50017 L
.49996 .50014 L
.49993 .50011 L
.49992 .50008 L
.4999 .50005 L
.4999 .50003 L
.4999 .5 L
.4999 .49999 L
.49991 .49997 L
Mistroke
.49992 .49996 L
.49993 .49995 L
.49994 .49995 L
.49995 .49994 L
.49997 .49994 L
.49998 .49995 L
.49999 .49995 L
.5 .49996 L
.50001 .49996 L
.50001 .49997 L
.50002 .49998 L
.50002 .49998 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 1 .938 r
.15544 1 m
.08226 .86677 L
.03356 .73303 L
.01133 .61145 L
.01222 .50492 L
.03247 .4153 L
.06816 .34346 L
.11539 .28941 L
.17042 .25245 L
.2298 .23133 L
.29044 .22435 L
.34974 .22951 L
.40552 .24466 L
.45612 .26758 L
.50036 .29612 L
.53748 .32824 L
.56714 .36206 L
.58935 .39597 L
.60443 .4286 L
.61291 .45884 L
.61551 .48588 L
.61307 .50914 L
.60651 .5283 L
.59674 .54325 L
.58467 .55407 L
.57115 .56099 L
.55696 .56436 L
.54276 .56462 L
.52914 .56225 L
.51654 .55778 L
.5053 .55171 L
.49565 .54454 L
.48772 .53675 L
.48156 .52874 L
.47713 .52086 L
.47432 .51342 L
.47299 .50663 L
.47295 .50067 L
.474 .49564 L
.47592 .49159 L
.4785 .48852 L
.48152 .48641 L
.4848 .48518 L
.48816 .48474 L
.49145 .48498 L
.49455 .48579 L
.49738 .48703 L
.49986 .48859 L
.50194 .49036 L
.50361 .49223 L
Mistroke
.50487 .49411 L
.50573 .49592 L
.50623 .49761 L
.50639 .49912 L
.50628 .50042 L
.50593 .5015 L
.5054 .50234 L
.50474 .50296 L
.50399 .50336 L
.50321 .50356 L
.50242 .50358 L
.50167 .50346 L
.50096 .50322 L
.50034 .50289 L
.49979 .5025 L
.49935 .50207 L
.499 .50162 L
.49875 .50119 L
.49859 .50077 L
.49851 .50039 L
.4985 .50006 L
.49855 .49978 L
.49866 .49955 L
.4988 .49938 L
.49896 .49925 L
.49915 .49918 L
.49933 .49916 L
.49951 .49917 L
.49969 .49921 L
.49984 .49928 L
.49998 .49936 L
.5001 .49946 L
.50019 .49956 L
.50027 .49967 L
.50031 .49977 L
.50034 .49986 L
.50035 .49995 L
.50035 .50002 L
.50033 .50008 L
.5003 .50013 L
.50027 .50016 L
.50022 .50018 L
.50018 .5002 L
.50014 .5002 L
.5001 .50019 L
.50006 .50018 L
.50002 .50016 L
.49999 .50014 L
.49997 .50012 L
.49995 .50009 L
Mistroke
.49993 .50007 L
.49992 .50004 L
.49992 .50002 L
.49992 .5 L
.49992 .49999 L
.49993 .49998 L
.49993 .49997 L
.49994 .49996 L
.49995 .49995 L
.49996 .49995 L
.49997 .49995 L
.49998 .49996 L
.49999 .49996 L
.5 .49996 L
.50001 .49997 L
.50001 .49998 L
.50001 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 .657 0 r
.6327 1 m
.54647 .95344 L
.46186 .89063 L
.39236 .82228 L
.33833 .75202 L
.29943 .68296 L
.2748 .61767 L
.26313 .55815 L
.26281 .50587 L
.27202 .46174 L
.28887 .42623 L
.31146 .39937 L
.33796 .38085 L
.36669 .37006 L
.39613 .3662 L
.42501 .36832 L
.45224 .37536 L
.47702 .38625 L
.49873 .39994 L
.51701 .41544 L
.53168 .43183 L
.54272 .44831 L
.55028 .46422 L
.55462 .479 L
.55608 .49225 L
.55506 .50368 L
.552 .51313 L
.54735 .52054 L
.54156 .52594 L
.53503 .52943 L
.52816 .53118 L
.52125 .53141 L
.51461 .53035 L
.50845 .52824 L
.50294 .52534 L
.4982 .52189 L
.49429 .51812 L
.49124 .51423 L
.48902 .5104 L
.48761 .50677 L
.48691 .50345 L
.48685 .50052 L
.48733 .49804 L
.48823 .49604 L
.48946 .49452 L
.49092 .49346 L
.4925 .49284 L
.49413 .4926 L
.49573 .49269 L
.49725 .49306 L
Mistroke
.49863 .49365 L
.49985 .4944 L
.50088 .49525 L
.5017 .49616 L
.50233 .49707 L
.50276 .49796 L
.50301 .49878 L
.5031 .49952 L
.50306 .50016 L
.50289 .50069 L
.50264 .50111 L
.50233 .50142 L
.50197 .50162 L
.50159 .50172 L
.5012 .50174 L
.50083 .50169 L
.50049 .50157 L
.50018 .50142 L
.49992 .50123 L
.4997 .50102 L
.49953 .5008 L
.4994 .50059 L
.49932 .50039 L
.49928 .5002 L
.49927 .50004 L
.4993 .4999 L
.49934 .49979 L
.49941 .4997 L
.49949 .49964 L
.49958 .49961 L
.49967 .49959 L
.49976 .49959 L
.49984 .49961 L
.49992 .49965 L
.49999 .49969 L
.50004 .49973 L
.50009 .49978 L
.50013 .49983 L
.50015 .49988 L
.50017 .49993 L
.50017 .49997 L
.50017 .50001 L
.50016 .50004 L
.50015 .50006 L
.50013 .50008 L
.50011 .50009 L
.50009 .5001 L
.50007 .5001 L
.50005 .50009 L
.50003 .50009 L
Mistroke
.50001 .50008 L
.5 .50007 L
.49998 .50006 L
.49997 .50005 L
.49997 .50003 L
.49996 .50002 L
.49996 .50001 L
.49996 .5 L
.49996 .5 L
.49996 .49999 L
.49997 .49998 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 1 .636 r
0 .00922 m
.03102 .00023 L
s
.03102 .00023 m
.03473 0 L
s
.19171 0 m
.25016 .00786 L
.35063 .03971 L
.44094 .08486 L
.51912 .13935 L
.58398 .19952 L
.63507 .26205 L
.67255 .32405 L
.69712 .38314 L
.70986 .43741 L
.71217 .48548 L
.70561 .5264 L
.69189 .5597 L
.6727 .58527 L
.64968 .60332 L
.62437 .61435 L
.59815 .61903 L
.57222 .6182 L
.54756 .61277 L
.52496 .60371 L
.50499 .59195 L
.48802 .57841 L
.47426 .5639 L
.46374 .54917 L
.45635 .53483 L
.4519 .52141 L
.45009 .50928 L
.45056 .49873 L
.45293 .48993 L
.45681 .48294 L
.46179 .47775 L
.4675 .47429 L
.47359 .47241 L
.47976 .47194 L
.48575 .47266 L
.49135 .47436 L
.49639 .47682 L
.50077 .4798 L
.50442 .48312 L
.5073 .48658 L
.50943 .49001 L
.51084 .4933 L
.51159 .49633 L
.51175 .49902 L
.51142 .50131 L
.51069 .50319 L
.50965 .50463 L
.50838 .50566 L
.50699 .5063 L
.50554 .50658 L
Mistroke
.5041 .50656 L
.50273 .50627 L
.50147 .50578 L
.50035 .50514 L
.4994 .5044 L
.49862 .5036 L
.49803 .50278 L
.49761 .50198 L
.49735 .50124 L
.49724 .50056 L
.49726 .49997 L
.49738 .49947 L
.49759 .49908 L
.49786 .49879 L
.49818 .49859 L
.49851 .49848 L
.49885 .49845 L
.49919 .49848 L
.4995 .49857 L
.49978 .49871 L
.50003 .49887 L
.50023 .49905 L
.50039 .49924 L
.50051 .49943 L
.5006 .49962 L
.50064 .49979 L
.50065 .49994 L
.50063 .50006 L
.5006 .50017 L
.50054 .50025 L
.50047 .50031 L
.50039 .50035 L
.50031 .50036 L
.50023 .50036 L
.50016 .50035 L
.50009 .50032 L
.50002 .50029 L
.49997 .50025 L
.49993 .5002 L
.49989 .50016 L
.49987 .50011 L
.49985 .50007 L
.49985 .50003 L
.49985 .5 L
.49985 .49997 L
.49987 .49995 L
.49988 .49993 L
.4999 .49992 L
.49992 .49992 L
.49994 .49991 L
Mistroke
.49995 .49992 L
.49997 .49992 L
.49999 .49993 L
.5 .49994 L
.50001 .49995 L
.50002 .49996 L
.50003 .49997 L
.50003 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .5 L
.50003 .50001 L
.50003 .50001 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.488 0 1 r
.48114 1 m
.46407 .98774 L
.37678 .90453 L
.30844 .8185 L
.25873 .73354 L
.22665 .65289 L
.21066 .57907 L
.2088 .51394 L
.21888 .45871 L
.23859 .41399 L
.26558 .3799 L
.29762 .35608 L
.33261 .34184 L
.36867 .33621 L
.4042 .33803 L
.43785 .34604 L
.46859 .35892 L
.49564 .37538 L
.51853 .39417 L
.53701 .41418 L
.55103 .43441 L
.56077 .45402 L
.56651 .47231 L
.56867 .48878 L
.56774 .50305 L
.56424 .51491 L
.55874 .52427 L
.55178 .53115 L
.54386 .53569 L
.53546 .53807 L
.52699 .53854 L
.5188 .5374 L
.51117 .53494 L
.50432 .53149 L
.4984 .52732 L
.49349 .52274 L
.48963 .51798 L
.48681 .51326 L
.48496 .50878 L
.48402 .50466 L
.48386 .50101 L
.48438 .49792 L
.48543 .4954 L
.4869 .49347 L
.48866 .49211 L
.49059 .49128 L
.49258 .49094 L
.49456 .49101 L
.49643 .49143 L
.49814 .49213 L
Mistroke
.49966 .49303 L
.50094 .49406 L
.50198 .49517 L
.50278 .49629 L
.50333 .49738 L
.50367 .4984 L
.5038 .49932 L
.50376 .50012 L
.50357 .50078 L
.50328 .50131 L
.5029 .5017 L
.50246 .50196 L
.502 .5021 L
.50153 .50214 L
.50107 .50208 L
.50065 .50195 L
.50027 .50176 L
.49993 .50153 L
.49966 .50128 L
.49944 .50101 L
.49928 .50075 L
.49917 .5005 L
.49912 .50027 L
.49911 .50007 L
.49913 .4999 L
.49919 .49975 L
.49927 .49964 L
.49936 .49957 L
.49947 .49952 L
.49958 .4995 L
.49969 .4995 L
.4998 .49952 L
.49989 .49956 L
.49998 .49961 L
.50005 .49967 L
.50011 .49973 L
.50015 .49979 L
.50018 .49985 L
.5002 .49991 L
.50021 .49996 L
.50021 .5 L
.5002 .50004 L
.50018 .50007 L
.50016 .50009 L
.50014 .50011 L
.50011 .50012 L
.50009 .50012 L
.50006 .50012 L
.50004 .50011 L
.50002 .5001 L
Mistroke
.5 .50009 L
.49998 .50007 L
.49997 .50006 L
.49996 .50004 L
.49995 .50003 L
.49995 .50002 L
.49995 .5 L
.49995 .49999 L
.49995 .49999 L
.49996 .49998 L
.49996 .49998 L
.49997 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.929 0 1 r
.92416 0 m
.96859 .07976 L
s
.96859 .07976 m
1 .16434 L
s
1 .65168 m
.98928 .67381 L
.93641 .73561 L
.87458 .77806 L
.8077 .80258 L
.73925 .81107 L
.67222 .80575 L
.60906 .78906 L
.55169 .76349 L
.50145 .73148 L
.45923 .69536 L
.42541 .65723 L
.40001 .61893 L
.38268 .58202 L
.37282 .54776 L
.36964 .51709 L
.37218 .49066 L
.37942 .46884 L
.39032 .45178 L
.40386 .43938 L
.41907 .4314 L
.43507 .42744 L
.4511 .42702 L
.46651 .42958 L
.48079 .43455 L
.49355 .44134 L
.50451 .44939 L
.51353 .45816 L
.52057 .4672 L
.52565 .47611 L
.52889 .48453 L
.53045 .49223 L
.53055 .499 L
.52941 .50472 L
.52727 .50933 L
.52439 .51283 L
.521 .51526 L
.51731 .51669 L
.51352 .51722 L
.5098 .51697 L
.50628 .51609 L
.50308 .5147 L
.50027 .51295 L
.4979 .51097 L
.49599 .50886 L
.49455 .50674 L
.49356 .50468 L
.49299 .50278 L
.49278 .50106 L
.4929 .49958 L
Mistroke
.49329 .49835 L
.49388 .49739 L
.49462 .49668 L
.49546 .49623 L
.49634 .49599 L
.49723 .49596 L
.49809 .49609 L
.49888 .49635 L
.49959 .49672 L
.50021 .49716 L
.50072 .49765 L
.50111 .49815 L
.5014 .49864 L
.50159 .49911 L
.50168 .49954 L
.50169 .49992 L
.50163 .50024 L
.50152 .5005 L
.50136 .5007 L
.50118 .50084 L
.50097 .50092 L
.50076 .50095 L
.50056 .50094 L
.50036 .5009 L
.50018 .50082 L
.50003 .50072 L
.49989 .50062 L
.49978 .5005 L
.4997 .50038 L
.49965 .50027 L
.49961 .50016 L
.4996 .50007 L
.49961 .49998 L
.49963 .49991 L
.49966 .49986 L
.4997 .49982 L
.49974 .49979 L
.49979 .49978 L
.49984 .49978 L
.49989 .49978 L
.49994 .4998 L
.49997 .49982 L
.50001 .49984 L
.50004 .49987 L
.50006 .4999 L
.50008 .49992 L
.50009 .49995 L
.50009 .49997 L
.50009 .49999 L
.50009 .50001 L
Mistroke
.50008 .50003 L
.50008 .50004 L
.50007 .50005 L
.50005 .50005 L
.50004 .50005 L
.50003 .50005 L
.50002 .50005 L
.50001 .50005 L
.5 .50004 L
.49999 .50003 L
.49999 .50003 L
.49998 .50002 L
.49998 .50002 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.476 0 1 r
0 .06873 m
.00445 .06655 L
.10488 .04442 L
.20499 .04407 L
.30082 .062 L
.38923 .09457 L
.46788 .13812 L
.53519 .18915 L
.59028 .24442 L
.63292 .30104 L
.6634 .35652 L
.68245 .40884 L
.69114 .4564 L
.6908 .49807 L
.68288 .53313 L
.66892 .56123 L
.65045 .58237 L
.62892 .59683 L
.6057 .60509 L
.58197 .60782 L
.55878 .60581 L
.53696 .59988 L
.51717 .59091 L
.49986 .57975 L
.48534 .56719 L
.47374 .55396 L
.46505 .54069 L
.45915 .52793 L
.45584 .5161 L
.45482 .50553 L
.45577 .49643 L
.45834 .48893 L
.46216 .48308 L
.46688 .47885 L
.47217 .47614 L
.47772 .47482 L
.48327 .47472 L
.4886 .47565 L
.49353 .4774 L
.49793 .47977 L
.5017 .48258 L
.5048 .48562 L
.50721 .48876 L
.50895 .49184 L
.51004 .49475 L
.51057 .49741 L
.51058 .49974 L
.51017 .50171 L
.50942 .50329 L
.50841 .50449 L
Mistroke
.50723 .50531 L
.50595 .5058 L
.50463 .50597 L
.50335 .50587 L
.50213 .50556 L
.50103 .50507 L
.50006 .50446 L
.49924 .50377 L
.49859 .50304 L
.49809 .50231 L
.49776 .5016 L
.49756 .50094 L
.4975 .50035 L
.49754 .49984 L
.49768 .49941 L
.49789 .49908 L
.49815 .49884 L
.49844 .49869 L
.49874 .49861 L
.49905 .4986 L
.49935 .49865 L
.49962 .49874 L
.49987 .49887 L
.50008 .49902 L
.50025 .49919 L
.50039 .49937 L
.50049 .49954 L
.50055 .4997 L
.50058 .49985 L
.50059 .49998 L
.50057 .50009 L
.50052 .50018 L
.50047 .50024 L
.50041 .50029 L
.50033 .50032 L
.50026 .50033 L
.50019 .50033 L
.50012 .50031 L
.50006 .50028 L
.50001 .50025 L
.49996 .50021 L
.49992 .50017 L
.4999 .50013 L
.49988 .50009 L
.49987 .50005 L
.49986 .50002 L
.49986 .49999 L
.49987 .49997 L
.49988 .49995 L
.4999 .49994 L
Mistroke
.49991 .49993 L
.49993 .49992 L
.49995 .49992 L
.49996 .49992 L
.49998 .49993 L
.49999 .49994 L
.5 .49995 L
.50001 .49995 L
.50002 .49996 L
.50003 .49997 L
.50003 .49998 L
.50003 .49999 L
.50003 .5 L
.50003 .5 L
.50003 .50001 L
.50003 .50001 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.205 1 0 r
.48452 1 m
.40859 .93493 L
.33333 .84992 L
.27682 .76456 L
.23831 .68232 L
.21644 .606 L
.20943 .53769 L
.21516 .47884 L
.23136 .43028 L
.2557 .39231 L
.28591 .36474 L
.31982 .34701 L
.3555 .33824 L
.39123 .33734 L
.42557 .3431 L
.45737 .3542 L
.48578 .36936 L
.51019 .3873 L
.53028 .40687 L
.54593 .42703 L
.55723 .44686 L
.56442 .46564 L
.56789 .48277 L
.56809 .49785 L
.56553 .51059 L
.56076 .52086 L
.55433 .52865 L
.54675 .53404 L
.53853 .5372 L
.53008 .53837 L
.52179 .53782 L
.51395 .53584 L
.50682 .53275 L
.50056 .52885 L
.49528 .52441 L
.49104 .51972 L
.48784 .51498 L
.48563 .51041 L
.48436 .50616 L
.48392 .50234 L
.48419 .49905 L
.48505 .49631 L
.48636 .49417 L
.48802 .4926 L
.48988 .49158 L
.49186 .49106 L
.49384 .49099 L
.49575 .49128 L
.49752 .49188 L
.49911 .4927 L
Mistroke
.50047 .49369 L
.5016 .49476 L
.50249 .49588 L
.50313 .49698 L
.50355 .49803 L
.50375 .49898 L
.50377 .49982 L
.50364 .50054 L
.50339 .50112 L
.50304 .50156 L
.50262 .50187 L
.50217 .50205 L
.5017 .50212 L
.50124 .5021 L
.5008 .50199 L
.5004 .50183 L
.50005 .50161 L
.49976 .50137 L
.49952 .50111 L
.49934 .50085 L
.49921 .50059 L
.49914 .50036 L
.49911 .50014 L
.49912 .49996 L
.49917 .49981 L
.49924 .49968 L
.49933 .4996 L
.49943 .49954 L
.49954 .49951 L
.49965 .4995 L
.49976 .49952 L
.49986 .49955 L
.49994 .49959 L
.50002 .49965 L
.50008 .49971 L
.50013 .49977 L
.50017 .49983 L
.5002 .49989 L
.50021 .49994 L
.50021 .49999 L
.5002 .50003 L
.50019 .50006 L
.50017 .50008 L
.50015 .5001 L
.50012 .50011 L
.5001 .50012 L
.50007 .50012 L
.50005 .50011 L
.50002 .5001 L
.5 .50009 L
Mistroke
.49999 .50008 L
.49997 .50006 L
.49996 .50005 L
.49996 .50003 L
.49995 .50002 L
.49995 .50001 L
.49995 .5 L
.49995 .49999 L
.49996 .49998 L
.49996 .49998 L
.49997 .49997 L
.49997 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 .653 0 r
.42209 1 m
.38107 .9629 L
.30191 .86848 L
.24339 .77448 L
.20451 .68459 L
.1837 .60176 L
.17888 .52815 L
.18767 .46523 L
.20754 .41381 L
.23592 .37409 L
.2703 .34578 L
.30834 .32818 L
.34795 .32028 L
.38727 .32083 L
.42479 .32846 L
.4593 .34173 L
.48989 .35919 L
.51598 .37948 L
.53723 .40134 L
.55359 .42363 L
.56518 .44539 L
.5723 .46585 L
.57539 .48439 L
.57496 .50057 L
.57161 .51414 L
.56593 .52496 L
.55853 .53304 L
.54997 .53851 L
.54079 .54156 L
.53145 .54246 L
.52236 .54151 L
.51383 .53906 L
.50611 .53544 L
.49939 .53098 L
.49378 .526 L
.48931 .52078 L
.48599 .51557 L
.48376 .51057 L
.48254 .50595 L
.48221 .50183 L
.48265 .49831 L
.48371 .49541 L
.48525 .49317 L
.48714 .49155 L
.48923 .49054 L
.49142 .49006 L
.4936 .49006 L
.49569 .49046 L
.49762 .49118 L
.49933 .49213 L
Mistroke
.50079 .49324 L
.50199 .49445 L
.50291 .49568 L
.50357 .49689 L
.50398 .49803 L
.50417 .49907 L
.50416 .49997 L
.50398 .50073 L
.50368 .50134 L
.50327 .5018 L
.5028 .50211 L
.5023 .50229 L
.50178 .50235 L
.50127 .50231 L
.5008 .50217 L
.50037 .50198 L
.49999 .50173 L
.49968 .50146 L
.49942 .50117 L
.49924 .50088 L
.49911 .5006 L
.49904 .50035 L
.49902 .50012 L
.49904 .49992 L
.49909 .49976 L
.49918 .49963 L
.49928 .49954 L
.4994 .49948 L
.49952 .49945 L
.49964 .49945 L
.49975 .49947 L
.49986 .49951 L
.49996 .49956 L
.50004 .49962 L
.50011 .49969 L
.50016 .49976 L
.5002 .49982 L
.50022 .49989 L
.50023 .49994 L
.50023 .5 L
.50022 .50004 L
.5002 .50007 L
.50018 .5001 L
.50016 .50012 L
.50013 .50013 L
.5001 .50013 L
.50007 .50013 L
.50005 .50012 L
.50002 .50011 L
.5 .5001 L
Mistroke
.49998 .50008 L
.49997 .50007 L
.49996 .50005 L
.49995 .50003 L
.49995 .50002 L
.49995 .50001 L
.49995 .5 L
.49995 .49999 L
.49995 .49998 L
.49996 .49997 L
.49997 .49997 L
.49997 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49998 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 .045 1 r
.49504 1 m
.41169 .92894 L
.33739 .84543 L
.28152 .76151 L
.24336 .68061 L
.22158 .60548 L
.21444 .53819 L
.21986 .48017 L
.23562 .43226 L
.25942 .39475 L
.28901 .36748 L
.3223 .34988 L
.35734 .34111 L
.39247 .3401 L
.42626 .34565 L
.45757 .35648 L
.48555 .37131 L
.50961 .3889 L
.52943 .40812 L
.54489 .42792 L
.55608 .44743 L
.56322 .46591 L
.56669 .48278 L
.56694 .49763 L
.56447 .5102 L
.55981 .52034 L
.55352 .52803 L
.54609 .53338 L
.53801 .53652 L
.52971 .53771 L
.52156 .53719 L
.51385 .53527 L
.50682 .53225 L
.50065 .52842 L
.49545 .52408 L
.49126 .51946 L
.48809 .51481 L
.48591 .51031 L
.48464 .50613 L
.48419 .50237 L
.48445 .49912 L
.48528 .49642 L
.48657 .4943 L
.48819 .49275 L
.49002 .49174 L
.49196 .49122 L
.49391 .49114 L
.49579 .49142 L
.49753 .492 L
.49909 .49281 L
Mistroke
.50044 .49378 L
.50156 .49483 L
.50243 .49593 L
.50307 .49701 L
.50348 .49804 L
.50368 .49898 L
.50371 .49981 L
.50358 .50052 L
.50333 .50109 L
.50299 .50153 L
.50258 .50183 L
.50214 .50201 L
.50168 .50209 L
.50123 .50206 L
.5008 .50196 L
.5004 .5018 L
.50006 .50159 L
.49977 .50135 L
.49953 .5011 L
.49935 .50084 L
.49923 .50059 L
.49915 .50036 L
.49913 .50015 L
.49914 .49996 L
.49918 .49981 L
.49925 .49969 L
.49934 .4996 L
.49944 .49955 L
.49955 .49952 L
.49965 .49951 L
.49976 .49952 L
.49986 .49955 L
.49994 .4996 L
.50002 .49965 L
.50008 .49971 L
.50013 .49977 L
.50017 .49983 L
.50019 .49989 L
.5002 .49994 L
.50021 .49999 L
.5002 .50003 L
.50019 .50006 L
.50017 .50008 L
.50014 .5001 L
.50012 .50011 L
.50009 .50012 L
.50007 .50011 L
.50005 .50011 L
.50002 .5001 L
.5 .50009 L
Mistroke
.49999 .50008 L
.49997 .50006 L
.49996 .50005 L
.49996 .50003 L
.49995 .50002 L
.49995 .50001 L
.49995 .5 L
.49995 .49999 L
.49996 .49998 L
.49996 .49998 L
.49997 .49998 L
.49997 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 .11 0 r
.73834 0 m
.75152 .01547 L
.82887 .13744 L
.88065 .25433 L
.9089 .36228 L
.91626 .45841 L
.90579 .54076 L
.88078 .60827 L
.84455 .66061 L
.80036 .69812 L
.75126 .72169 L
.69999 .7326 L
.64895 .73247 L
.60015 .72306 L
.55518 .70624 L
.51523 .68387 L
.48107 .65774 L
.45316 .6295 L
.43161 .60061 L
.41624 .57234 L
.4067 .54571 L
.40242 .52153 L
.40272 .50038 L
.40687 .4826 L
.41408 .46837 L
.42356 .45769 L
.43458 .45042 L
.44645 .4463 L
.45855 .44499 L
.47037 .44608 L
.48147 .44916 L
.49154 .45378 L
.50032 .4595 L
.50769 .46593 L
.51356 .47268 L
.51795 .47945 L
.52091 .48595 L
.52257 .49196 L
.52305 .49734 L
.52254 .50195 L
.5212 .50575 L
.51924 .50871 L
.51682 .51085 L
.51411 .5122 L
.51128 .51286 L
.50845 .51289 L
.50573 .5124 L
.50323 .5115 L
.50099 .51028 L
.49908 .50884 L
Mistroke
.49751 .50728 L
.49629 .50569 L
.49541 .50412 L
.49486 .50263 L
.49461 .50128 L
.49461 .5001 L
.49482 .4991 L
.49521 .4983 L
.49573 .49769 L
.49633 .49728 L
.49699 .49704 L
.49766 .49695 L
.49831 .49701 L
.49893 .49717 L
.49949 .49742 L
.49999 .49773 L
.5004 .49809 L
.50073 .49846 L
.50098 .49884 L
.50115 .4992 L
.50125 .49953 L
.50128 .49983 L
.50125 .50009 L
.50118 .5003 L
.50107 .50047 L
.50094 .50059 L
.50079 .50067 L
.50064 .50071 L
.50048 .50071 L
.50033 .50069 L
.50019 .50064 L
.50006 .50057 L
.49996 .5005 L
.49987 .50041 L
.4998 .50032 L
.49975 .50023 L
.49972 .50015 L
.4997 .50008 L
.4997 .50001 L
.49971 .49995 L
.49973 .49991 L
.49976 .49987 L
.49979 .49985 L
.49983 .49984 L
.49987 .49983 L
.4999 .49983 L
.49994 .49984 L
.49997 .49986 L
.5 .49987 L
.50002 .49989 L
Mistroke
.50004 .49991 L
.50005 .49993 L
.50006 .49995 L
.50007 .49997 L
.50007 .49999 L
.50007 .5 L
.50007 .50002 L
.50006 .50003 L
.50005 .50003 L
.50004 .50004 L
.50004 .50004 L
.50003 .50004 L
.50002 .50004 L
.50001 .50004 L
.5 .50003 L
.5 .50003 L
.49999 .50002 L
.49999 .50002 L
.49999 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 .08 r
.56769 1 m
.47542 .93536 L
.39719 .86245 L
.33563 .78675 L
.29052 .71174 L
.26104 .6403 L
.24584 .57472 L
.24325 .51669 L
.25134 .4673 L
.26807 .42714 L
.2914 .39635 L
.31932 .37465 L
.34998 .36144 L
.38172 .3559 L
.4131 .357 L
.44291 .36365 L
.47022 .37468 L
.49433 .38896 L
.51481 .40538 L
.5314 .42295 L
.54407 .44078 L
.55295 .45812 L
.55828 .47434 L
.56043 .48899 L
.55981 .50173 L
.55691 .51235 L
.55219 .52078 L
.54614 .52702 L
.53922 .53117 L
.53184 .53342 L
.52438 .53397 L
.51713 .53307 L
.51037 .53099 L
.50427 .52801 L
.49899 .52438 L
.49459 .52037 L
.49112 .51618 L
.48855 .51202 L
.48686 .50804 L
.48596 .50439 L
.48577 .50114 L
.48618 .49837 L
.48708 .49611 L
.48835 .49437 L
.48988 .49313 L
.49157 .49237 L
.49332 .49203 L
.49507 .49207 L
.49672 .49242 L
.49825 .49301 L
Mistroke
.4996 .49379 L
.50074 .49469 L
.50168 .49566 L
.5024 .49665 L
.5029 .49761 L
.50321 .49852 L
.50334 .49934 L
.50332 .50005 L
.50317 .50065 L
.50291 .50112 L
.50258 .50147 L
.5022 .50171 L
.50179 .50184 L
.50138 .50188 L
.50098 .50184 L
.5006 .50173 L
.50026 .50156 L
.49996 .50137 L
.49972 .50114 L
.49952 .50091 L
.49937 .50068 L
.49928 .50046 L
.49923 .50026 L
.49921 .50008 L
.49923 .49992 L
.49928 .49979 L
.49935 .49969 L
.49943 .49962 L
.49953 .49958 L
.49962 .49956 L
.49972 .49956 L
.49981 .49958 L
.4999 .49961 L
.49997 .49965 L
.50004 .4997 L
.50009 .49976 L
.50013 .49981 L
.50016 .49986 L
.50018 .49991 L
.50018 .49996 L
.50018 .5 L
.50018 .50003 L
.50016 .50006 L
.50014 .50008 L
.50012 .50009 L
.5001 .5001 L
.50008 .5001 L
.50006 .5001 L
.50003 .5001 L
.50002 .50009 L
Mistroke
.5 .50008 L
.49999 .50006 L
.49997 .50005 L
.49997 .50004 L
.49996 .50003 L
.49996 .50001 L
.49996 .5 L
.49996 .5 L
.49996 .49999 L
.49996 .49998 L
.49997 .49998 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 .31 r
.7024 0 m
.70971 .00789 L
.79026 .12344 L
.84627 .2355 L
.87943 .34014 L
.8921 .43438 L
.88706 .51611 L
.86735 .58408 L
.83611 .63778 L
.79644 .67734 L
.75129 .70346 L
.70334 .71725 L
.65496 .72014 L
.60814 .71376 L
.56452 .69986 L
.52532 .68019 L
.4914 .65648 L
.46327 .63032 L
.44113 .60315 L
.42489 .57621 L
.41427 .55055 L
.40878 .52699 L
.40781 .50613 L
.41069 .48838 L
.41668 .47394 L
.42504 .46286 L
.43506 .45504 L
.44606 .45028 L
.45745 .44827 L
.46872 .44865 L
.47943 .45103 L
.48924 .45498 L
.49791 .46009 L
.50527 .46599 L
.51123 .47229 L
.51579 .47869 L
.51899 .48492 L
.52091 .49075 L
.52169 .49601 L
.52148 .50059 L
.52044 .50441 L
.51875 .50744 L
.51658 .50969 L
.5141 .51118 L
.51145 .51199 L
.50877 .51219 L
.50617 .51188 L
.50374 .51113 L
.50155 .51006 L
.49965 .50876 L
Mistroke
.49807 .50732 L
.49682 .50582 L
.4959 .50433 L
.49529 .5029 L
.49496 .50158 L
.49489 .50042 L
.49504 .49942 L
.49536 .49861 L
.49581 .49798 L
.49636 .49754 L
.49697 .49726 L
.4976 .49714 L
.49822 .49715 L
.49882 .49728 L
.49937 .49749 L
.49985 .49777 L
.50026 .49809 L
.5006 .49844 L
.50086 .49879 L
.50104 .49914 L
.50115 .49947 L
.5012 .49976 L
.50119 .50002 L
.50114 .50023 L
.50105 .5004 L
.50093 .50053 L
.50079 .50061 L
.50064 .50066 L
.5005 .50068 L
.50035 .50066 L
.50022 .50062 L
.50009 .50056 L
.49999 .50049 L
.4999 .50041 L
.49983 .50033 L
.49978 .50025 L
.49974 .50017 L
.49972 .50009 L
.49972 .50003 L
.49972 .49997 L
.49974 .49993 L
.49977 .49989 L
.4998 .49987 L
.49983 .49985 L
.49986 .49984 L
.4999 .49984 L
.49993 .49985 L
.49996 .49986 L
.49999 .49988 L
.50001 .49989 L
Mistroke
.50003 .49991 L
.50005 .49993 L
.50006 .49995 L
.50006 .49997 L
.50007 .49999 L
.50007 .5 L
.50006 .50001 L
.50006 .50002 L
.50005 .50003 L
.50004 .50003 L
.50004 .50004 L
.50003 .50004 L
.50002 .50004 L
.50001 .50003 L
.50001 .50003 L
.5 .50003 L
.49999 .50002 L
.49999 .50002 L
.49999 .50001 L
.49999 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.867 1 0 r
.80132 0 m
.83375 .04528 L
.90211 .17755 L
.94341 .30148 L
.96035 .41345 L
.95616 .5109 L
.9344 .59227 L
.89877 .65689 L
.8529 .70486 L
.80029 .73694 L
.74412 .75439 L
.6872 .75887 L
.63193 .75228 L
.58026 .73665 L
.53368 .71407 L
.49323 .68656 L
.45954 .656 L
.43288 .62411 L
.41318 .59238 L
.40012 .56204 L
.39315 .5341 L
.39157 .50928 L
.39458 .48807 L
.40132 .47074 L
.41093 .45737 L
.42256 .44785 L
.43541 .44194 L
.44879 .4393 L
.46206 .43951 L
.47473 .44211 L
.48636 .44661 L
.49668 .45252 L
.50547 .45938 L
.51264 .46676 L
.51814 .47428 L
.52204 .48163 L
.52443 .48853 L
.52546 .49479 L
.52531 .50024 L
.52417 .50481 L
.52224 .50846 L
.51974 .51118 L
.51684 .51302 L
.51374 .51404 L
.51059 .51434 L
.50752 .51401 L
.50464 .51318 L
.50204 .51195 L
.49977 .51045 L
.49788 .50876 L
Mistroke
.49638 .507 L
.49526 .50524 L
.49451 .50355 L
.4941 .50199 L
.49399 .50061 L
.49414 .49942 L
.4945 .49844 L
.49503 .49769 L
.49566 .49714 L
.49637 .4968 L
.49711 .49664 L
.49785 .49665 L
.49855 .49678 L
.4992 .49702 L
.49978 .49735 L
.50027 .49772 L
.50067 .49813 L
.50099 .49855 L
.50121 .49895 L
.50135 .49934 L
.50141 .49969 L
.5014 .49999 L
.50134 .50025 L
.50124 .50046 L
.5011 .50061 L
.50094 .50071 L
.50077 .50077 L
.5006 .50079 L
.50043 .50078 L
.50027 .50073 L
.50012 .50067 L
.5 .50058 L
.49989 .50049 L
.4998 .50039 L
.49974 .5003 L
.4997 .5002 L
.49967 .50012 L
.49967 .50004 L
.49967 .49997 L
.49969 .49992 L
.49972 .49987 L
.49976 .49984 L
.4998 .49982 L
.49984 .49981 L
.49988 .49981 L
.49992 .49982 L
.49995 .49983 L
.49999 .49985 L
.50001 .49987 L
.50004 .49989 L
Mistroke
.50005 .49992 L
.50007 .49994 L
.50007 .49996 L
.50008 .49998 L
.50008 .5 L
.50007 .50001 L
.50007 .50002 L
.50006 .50003 L
.50005 .50004 L
.50004 .50004 L
.50003 .50004 L
.50002 .50004 L
.50002 .50004 L
.50001 .50004 L
.5 .50003 L
.49999 .50003 L
.49999 .50002 L
.49999 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 1 .13 r
.25191 0 m
.28716 .00739 L
.38611 .04606 L
.47373 .09667 L
.54833 .15528 L
.60903 .21827 L
.65562 .28241 L
.6885 .34496 L
.70857 .40366 L
.71708 .4568 L
.71554 .50313 L
.70563 .54189 L
.68908 .57276 L
.66763 .59577 L
.64292 .61125 L
.61647 .61979 L
.5896 .62218 L
.56346 .61929 L
.53898 .6121 L
.51687 .60158 L
.49764 .58869 L
.48159 .57432 L
.46885 .55928 L
.4594 .54429 L
.4531 .52993 L
.44968 .51669 L
.44882 .5049 L
.45015 .4948 L
.45325 .48654 L
.45773 .48014 L
.46318 .47556 L
.46923 .4727 L
.47553 .47139 L
.48181 .47143 L
.4878 .4726 L
.49332 .47469 L
.49822 .47745 L
.5024 .48067 L
.50582 .48415 L
.50846 .4877 L
.51033 .49117 L
.51149 .49444 L
.512 .49741 L
.51196 .5 L
.51144 .50218 L
.51054 .50392 L
.50937 .50522 L
.50802 .50611 L
.50656 .50661 L
.50507 .50677 L
Mistroke
.50362 .50662 L
.50225 .50624 L
.50102 .50567 L
.49994 .50496 L
.49904 .50417 L
.49832 .50334 L
.49778 .50251 L
.49742 .50171 L
.49722 .50097 L
.49717 .50032 L
.49723 .49975 L
.4974 .49928 L
.49764 .49892 L
.49794 .49866 L
.49827 .4985 L
.49862 .49842 L
.49897 .49842 L
.4993 .49848 L
.49961 .49859 L
.49988 .49874 L
.50012 .49892 L
.50031 .49911 L
.50046 .4993 L
.50057 .4995 L
.50063 .49968 L
.50066 .49985 L
.50066 .49999 L
.50064 .50011 L
.50059 .50021 L
.50052 .50028 L
.50045 .50034 L
.50037 .50036 L
.50029 .50037 L
.50021 .50037 L
.50013 .50035 L
.50006 .50032 L
.5 .50028 L
.49995 .50023 L
.49991 .50019 L
.49988 .50014 L
.49986 .5001 L
.49985 .50006 L
.49984 .50002 L
.49985 .49999 L
.49986 .49996 L
.49987 .49994 L
.49988 .49993 L
.4999 .49992 L
.49992 .49991 L
.49994 .49991 L
Mistroke
.49996 .49992 L
.49998 .49992 L
.49999 .49993 L
.50001 .49994 L
.50002 .49995 L
.50002 .49996 L
.50003 .49997 L
.50003 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50003 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
0 1 .908 r
.22774 1 m
.16421 .905 L
.10499 .78017 L
.07108 .66419 L
.05977 .56025 L
.06788 .4706 L
.09196 .39651 L
.1285 .33846 L
.17403 .29618 L
.22528 .26885 L
.27929 .25514 L
.33346 .25343 L
.38559 .26185 L
.43392 .27845 L
.47714 .30124 L
.51434 .32832 L
.54499 .35791 L
.56892 .38844 L
.58625 .41853 L
.59735 .44705 L
.60277 .4731 L
.60322 .49605 L
.59946 .51547 L
.59234 .53116 L
.58266 .54308 L
.57123 .55136 L
.55879 .55626 L
.54599 .55813 L
.53341 .55737 L
.52151 .55443 L
.51067 .5498 L
.50113 .54391 L
.49309 .53722 L
.48661 .53011 L
.4817 .52293 L
.47832 .516 L
.47635 .50953 L
.47563 .50373 L
.47601 .4987 L
.47729 .49454 L
.47927 .49126 L
.48176 .48886 L
.48458 .48729 L
.48756 .48648 L
.49057 .48634 L
.49346 .48677 L
.49616 .48765 L
.49857 .4889 L
.50066 .49038 L
.50238 .49201 L
Mistroke
.50373 .4937 L
.50472 .49537 L
.50536 .49696 L
.50568 .49841 L
.50572 .4997 L
.50553 .50079 L
.50515 .50167 L
.50462 .50234 L
.50399 .50282 L
.50331 .5031 L
.5026 .50322 L
.5019 .50318 L
.50124 .50303 L
.50063 .50278 L
.5001 .50246 L
.49965 .50209 L
.49928 .5017 L
.499 .5013 L
.49881 .50091 L
.4987 .50055 L
.49865 .50023 L
.49867 .49995 L
.49874 .49971 L
.49884 .49953 L
.49898 .49939 L
.49913 .4993 L
.4993 .49925 L
.49947 .49924 L
.49963 .49926 L
.49978 .49931 L
.49991 .49938 L
.50003 .49946 L
.50013 .49955 L
.5002 .49964 L
.50026 .49974 L
.50029 .49983 L
.50031 .49991 L
.50032 .49998 L
.50031 .50004 L
.50029 .50009 L
.50026 .50013 L
.50022 .50015 L
.50019 .50017 L
.50015 .50018 L
.50011 .50018 L
.50007 .50017 L
.50004 .50015 L
.50001 .50014 L
.49998 .50012 L
.49996 .5001 L
Mistroke
.49995 .50007 L
.49993 .50005 L
.49993 .50003 L
.49993 .50001 L
.49993 .5 L
.49993 .49998 L
.49994 .49997 L
.49994 .49997 L
.49995 .49996 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49999 .49996 L
.49999 .49997 L
.5 .49997 L
.50001 .49997 L
.50001 .49998 L
.50001 .49999 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 .003 0 r
.82951 0 m
.86846 .05845 L
.93291 .19497 L
.9697 .32177 L
.98181 .43534 L
.9727 .53326 L
.94615 .61413 L
.90603 .67745 L
.8561 .72352 L
.79996 .75324 L
.74083 .76807 L
.68156 .7698 L
.62455 .76046 L
.57171 .74221 L
.52448 .7172 L
.48386 .68752 L
.45041 .6551 L
.42431 .62169 L
.40542 .58877 L
.39335 .55759 L
.38748 .52911 L
.38706 .50404 L
.39122 .48284 L
.39906 .46572 L
.40968 .45272 L
.4222 .4437 L
.43583 .43838 L
.44984 .43638 L
.4636 .43724 L
.47661 .44048 L
.48846 .44557 L
.49888 .45203 L
.50766 .45936 L
.51473 .46715 L
.52008 .47499 L
.52376 .48258 L
.52591 .48965 L
.52667 .49599 L
.52624 .50148 L
.52483 .50603 L
.52266 .5096 L
.51993 .51222 L
.51684 .51393 L
.51357 .51481 L
.51029 .51495 L
.50712 .51448 L
.50417 .5135 L
.50153 .51213 L
.49926 .51051 L
.49737 .50872 L
Mistroke
.4959 .50687 L
.49483 .50504 L
.49413 .50331 L
.49378 .50172 L
.49374 .50032 L
.49395 .49913 L
.49437 .49816 L
.49495 .49743 L
.49564 .49691 L
.49639 .4966 L
.49717 .49648 L
.49793 .49652 L
.49865 .49669 L
.49932 .49696 L
.4999 .49732 L
.50039 .49772 L
.50079 .49815 L
.50109 .49858 L
.5013 .49901 L
.50143 .4994 L
.50148 .49975 L
.50146 .50006 L
.50138 .50032 L
.50126 .50052 L
.50112 .50067 L
.50095 .50077 L
.50076 .50082 L
.50058 .50083 L
.50041 .5008 L
.50024 .50075 L
.50009 .50068 L
.49997 .50059 L
.49986 .50049 L
.49978 .50039 L
.49972 .50029 L
.49968 .50019 L
.49966 .5001 L
.49965 .50002 L
.49966 .49996 L
.49969 .4999 L
.49972 .49986 L
.49976 .49983 L
.4998 .49981 L
.49984 .49981 L
.49988 .49981 L
.49992 .49982 L
.49996 .49983 L
.49999 .49985 L
.50002 .49987 L
.50004 .4999 L
Mistroke
.50006 .49992 L
.50007 .49994 L
.50008 .49997 L
.50008 .49999 L
.50008 .5 L
.50008 .50002 L
.50007 .50003 L
.50006 .50004 L
.50005 .50004 L
.50004 .50005 L
.50003 .50005 L
.50002 .50004 L
.50001 .50004 L
.50001 .50004 L
.5 .50003 L
.49999 .50003 L
.49999 .50002 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 0 .031 r
1 .94906 m
.8995 .96957 L
.79665 .96853 L
.69845 .94892 L
.60808 .9145 L
.5279 .86903 L
.45947 .81611 L
.40365 .75904 L
.36065 .70077 L
.33012 .64383 L
.31128 .59028 L
.30302 .54172 L
.30396 .49928 L
.31259 .46369 L
.32733 .43526 L
.3466 .41398 L
.36892 .39956 L
.3929 .39148 L
.41731 .38903 L
.4411 .39141 L
.46344 .39775 L
.48364 .40716 L
.50126 .41878 L
.516 .43177 L
.52774 .44541 L
.53648 .45904 L
.54236 .47213 L
.5456 .48422 L
.54649 .49501 L
.54539 .50426 L
.54264 .51186 L
.53864 .51776 L
.53373 .52201 L
.52826 .52469 L
.52253 .52596 L
.51683 .52598 L
.51137 .52496 L
.50633 .52311 L
.50184 .52063 L
.49801 .51772 L
.49487 .51457 L
.49243 .51135 L
.49069 .50819 L
.48961 .5052 L
.48911 .50249 L
.48913 .50012 L
.48958 .49812 L
.49037 .49652 L
.49142 .49531 L
.49265 .49448 L
Mistroke
.49397 .49401 L
.49532 .49386 L
.49665 .49397 L
.49789 .49431 L
.49902 .49482 L
.5 .49545 L
.50083 .49617 L
.50149 .49692 L
.50199 .49768 L
.50233 .49841 L
.50252 .49908 L
.50257 .49968 L
.50252 .5002 L
.50237 .50063 L
.50216 .50096 L
.50189 .5012 L
.50159 .50136 L
.50127 .50143 L
.50095 .50144 L
.50065 .50139 L
.50037 .50129 L
.50012 .50115 L
.4999 .50099 L
.49973 .50082 L
.49959 .50064 L
.49949 .50047 L
.49943 .5003 L
.4994 .50015 L
.4994 .50002 L
.49942 .4999 L
.49946 .49981 L
.49952 .49974 L
.49959 .4997 L
.49966 .49967 L
.49974 .49966 L
.49981 .49967 L
.49988 .49968 L
.49994 .49971 L
.5 .49975 L
.50004 .49978 L
.50008 .49983 L
.50011 .49987 L
.50013 .49991 L
.50014 .49995 L
.50014 .49998 L
.50014 .50001 L
.50013 .50003 L
.50012 .50005 L
.50011 .50007 L
.50009 .50007 L
Mistroke
.50007 .50008 L
.50005 .50008 L
.50004 .50008 L
.50002 .50007 L
.50001 .50006 L
.5 .50006 L
.49999 .50005 L
.49998 .50004 L
.49997 .50003 L
.49997 .50002 L
.49997 .50001 L
.49997 .5 L
.49997 .5 L
.49997 .49999 L
.49997 .49999 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0333333 0.5 0.0333333 [
[0 .4875 -18.4688 -20 ]
[0 .4875 18.4688 0 ]
[.16667 .4875 -18.4688 -20 ]
[.16667 .4875 18.4688 0 ]
[.33333 .4875 -13.4688 -20 ]
[.33333 .4875 13.4688 0 ]
[.66667 .4875 -7 -20 ]
[.66667 .4875 7 0 ]
[.83333 .4875 -12 -20 ]
[.83333 .4875 12 0 ]
[1 .4875 -12 -20 ]
[1 .4875 12 0 ]
[.4875 0 -36.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .16667 -36.9375 -10 ]
[.4875 .16667 0 10 ]
[.4875 .33333 -26.9375 -10 ]
[.4875 .33333 0 10 ]
[.4875 .66667 -14 -10 ]
[.4875 .66667 0 10 ]
[.4875 .83333 -24 -10 ]
[.4875 .83333 0 10 ]
[.4875 1 -24 -10 ]
[.4875 1 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.16667 .5 m
.16667 .50625 L
s
gsave
.16667 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.33333 .5 m
.33333 .50625 L
s
gsave
.33333 .4875 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.66667 .5 m
.66667 .50625 L
s
gsave
.66667 .4875 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.83333 .5 m
.83333 .50625 L
s
gsave
.83333 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.5 .16667 m
.50625 .16667 L
s
gsave
.4875 .16667 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 .33333 m
.50625 .33333 L
s
gsave
.4875 .33333 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .66667 m
.50625 .66667 L
s
gsave
.4875 .66667 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .83333 m
.50625 .83333 L
s
gsave
.4875 .83333 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.01 w
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.305 0 1 r
.5 Mabswid
.20188 .66639 m
.18449 .58594 L
.18252 .51496 L
.19355 .45478 L
.21507 .40607 L
.24453 .36894 L
.27948 .34301 L
.31763 .32752 L
.35695 .32141 L
.39568 .32343 L
.43236 .33218 L
.46586 .34624 L
.49535 .36419 L
.52029 .38469 L
.54041 .40651 L
.55569 .42857 L
.56628 .44994 L
.57253 .46988 L
.57487 .48783 L
.57384 .50338 L
.57003 .5163 L
.56402 .52649 L
.55642 .53399 L
.54779 .53892 L
.53863 .54151 L
.52939 .54202 L
.52046 .54077 L
.51215 .53809 L
.50469 .53431 L
.49823 .52977 L
.49289 .52477 L
.48868 .51958 L
.48561 .51444 L
.4836 .50955 L
.48257 .50506 L
.4824 .50109 L
.48297 .49772 L
.48412 .49497 L
.48573 .49287 L
.48764 .49139 L
.48975 .49049 L
.49192 .49012 L
.49407 .4902 L
.49611 .49066 L
.49798 .49142 L
.49963 .4924 L
.50103 .49353 L
.50217 .49474 L
.50303 .49596 L
.50364 .49715 L
Mistroke
.504 .49826 L
.50414 .49926 L
.5041 .50013 L
.5039 .50086 L
.50357 .50143 L
.50316 .50186 L
.50268 .50214 L
.50218 .50229 L
.50166 .50233 L
.50117 .50226 L
.5007 .50212 L
.50029 .50192 L
.49993 .50167 L
.49963 .50139 L
.49939 .5011 L
.49921 .50082 L
.4991 .50055 L
.49904 .5003 L
.49903 .50008 L
.49905 .49989 L
.49912 .49973 L
.4992 .49961 L
.49931 .49953 L
.49942 .49948 L
.49954 .49945 L
.49966 .49946 L
.49978 .49948 L
.49988 .49952 L
.49997 .49958 L
.50005 .49964 L
.50012 .4997 L
.50016 .49977 L
.5002 .49984 L
.50022 .4999 L
.50023 .49996 L
.50023 .5 L
.50022 .50004 L
.5002 .50008 L
.50018 .5001 L
.50015 .50012 L
.50012 .50013 L
.50009 .50013 L
.50007 .50013 L
.50004 .50012 L
.50002 .50011 L
.5 .50009 L
.49998 .50008 L
.49997 .50006 L
.49996 .50005 L
.49995 .50003 L
Mistroke
.49995 .50002 L
.49995 .50001 L
.49995 .49999 L
.49995 .49999 L
.49996 .49998 L
.49996 .49997 L
.49997 .49997 L
.49997 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49998 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.20188 .66639 m
.18449 .58594 L
s
% Start of user PostScript
-8.9436086 4.9917992 -9.4651578 2.5781378 MAarrowhead1
% End of user PostScript
1 .158 0 r
.18252 .51496 m
.19355 .45478 L
s
% Start of user PostScript
-9.524467 0.44887386 -9.193374 -1.356502 MAarrowhead1
% End of user PostScript
1 .473 0 r
.43236 .33218 m
.46586 .34624 L
s
% Start of user PostScript
-2.0290653 -5.0345058 -1.0241102 -4.612732 MAarrowhead1
% End of user PostScript
1 .788 0 r
.57487 .48783 m
.57384 .50338 L
s
% Start of user PostScript
2.2461187 -0.3652267 2.2152809 0.10129766 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52046 .54077 m
.51215 .53809 L
s
% Start of user PostScript
0.61392115 1.2230286 0.36454317 1.1426071 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48257 .50506 m
.4824 .50109 L
s
% Start of user PostScript
-0.52284727 0.15189797 -0.52785088 0.032788515 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49407 .4902 m
.49611 .49066 L
s
% Start of user PostScript
-0.17782533 -0.29391545 -0.11658245 -0.28010572 MAarrowhead1
% End of user PostScript
0 1 .049 r
.504 .49826 m
.50414 .49926 L
s
% Start of user PostScript
0.11994201 -0.052317428 0.12427222 -0.022247202 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50166 .50233 m
.50117 .50226 L
s
% Start of user PostScript
0.049915244 0.06983358 0.035031864 0.067948442 MAarrowhead1
% End of user PostScript
0 1 .679 r
.4991 .50055 m
.49904 .5003 L
s
% Start of user PostScript
-0.027053709 0.016431982 -0.028874003 0.0089214462 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49954 .49945 m
.49966 .49946 L
s
% Start of user PostScript
-0.013676736 -0.016389977 -0.01009857 -0.016304827 MAarrowhead1
% End of user PostScript
0 .69 1 r
.5002 .49984 m
.50022 .4999 L
s
% Start of user PostScript
0.0059798908 -0.0048807253 0.0066096755 -0.0030243449 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50012 .50013 m
.50009 .50013 L
s
% Start of user PostScript
0.0036749743 0.0037949576 0.0028244503 0.0038678152 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49996 .50005 m
.49995 .50003 L
s
% Start of user PostScript
-0.0012888227 0.0013954384 -0.0014871267 0.00094134422 MAarrowhead1
% End of user PostScript
1 0 .962 r
.57482 .19513 m
.62711 .25668 L
.66592 .31808 L
.69186 .3769 L
.70597 .43119 L
.70957 .47952 L
.70422 .52091 L
.69156 .55482 L
.67327 .5811 L
.65099 .59991 L
.62624 .61171 L
.60042 .61714 L
.57473 .61702 L
.55018 .61224 L
.52756 .60374 L
.50747 .59245 L
.49031 .57928 L
.47629 .56505 L
.46547 .55051 L
.45776 .53628 L
.45299 .52288 L
.45086 .51072 L
.45103 .50009 L
.45314 .49115 L
.45678 .48401 L
.46157 .47865 L
.46712 .47501 L
.4731 .47295 L
.47919 .4723 L
.48514 .47286 L
.49073 .47442 L
.49579 .47675 L
.5002 .47964 L
.5039 .48288 L
.50685 .48628 L
.50906 .48969 L
.51054 .49296 L
.51137 .49598 L
.51161 .49869 L
.51134 .50101 L
.51067 .50291 L
.50967 .5044 L
.50845 .50547 L
.50709 .50615 L
.50566 .50647 L
.50424 .50649 L
.50287 .50624 L
.50161 .50578 L
.50049 .50517 L
.49953 .50444 L
Mistroke
.49874 .50366 L
.49813 .50285 L
.49769 .50206 L
.49741 .50132 L
.49728 .50064 L
.49728 .50004 L
.49739 .49954 L
.49759 .49914 L
.49785 .49884 L
.49816 .49863 L
.49849 .49851 L
.49882 .49847 L
.49915 .49849 L
.49947 .49858 L
.49975 .4987 L
.49999 .49886 L
.5002 .49904 L
.50037 .49923 L
.50049 .49942 L
.50058 .4996 L
.50063 .49977 L
.50064 .49992 L
.50063 .50005 L
.50059 .50015 L
.50054 .50024 L
.50047 .5003 L
.5004 .50034 L
.50032 .50036 L
.50024 .50036 L
.50016 .50035 L
.50009 .50032 L
.50003 .50029 L
.49998 .50025 L
.49993 .50021 L
.4999 .50016 L
.49987 .50012 L
.49986 .50008 L
.49985 .50004 L
.49985 .5 L
.49986 .49998 L
.49987 .49995 L
.49988 .49994 L
.4999 .49992 L
.49991 .49992 L
.49993 .49992 L
.49995 .49992 L
.49997 .49992 L
.49998 .49993 L
.5 .49994 L
.50001 .49995 L
Mistroke
.50002 .49996 L
.50003 .49997 L
.50003 .49998 L
.50003 .49999 L
.50004 .49999 L
.50003 .5 L
.50003 .50001 L
.50003 .50001 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.57482 .19513 m
.62711 .25668 L
s
% Start of user PostScript
2.2446763 -9.1460436 3.8132692 -7.299559 MAarrowhead1
% End of user PostScript
1 .158 0 r
.66592 .31808 m
.69186 .3769 L
s
% Start of user PostScript
4.977544 -5.4576074 5.7558522 -3.69312 MAarrowhead1
% End of user PostScript
1 .473 0 r
.62624 .61171 m
.60042 .61714 L
s
% Start of user PostScript
3.7872839 3.3511804 3.0127228 3.5142501 MAarrowhead1
% End of user PostScript
1 .788 0 r
.46547 .55051 m
.45776 .53628 L
s
% Start of user PostScript
-1.0359688 1.5152592 -1.2670577 1.0883865 MAarrowhead1
% End of user PostScript
.897 1 0 r
.46712 .47501 m
.4731 .47295 L
s
% Start of user PostScript
-0.98630947 -0.74978206 -0.80698851 -0.81157649 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50685 .48628 m
.50906 .48969 L
s
% Start of user PostScript
0.20560069 -0.41156598 0.27165266 -0.30942469 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50845 .50547 m
.50709 .50615 L
s
% Start of user PostScript
0.25361573 0.16408593 0.2127352 0.18448833 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49874 .50366 m
.49813 .50285 L
s
% Start of user PostScript
-0.037878141 0.10978682 -0.056233204 0.085630594 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49785 .49884 m
.49816 .49863 L
s
% Start of user PostScript
-0.064455921 -0.034912463 -0.055302906 -0.04116493 MAarrowhead1
% End of user PostScript
0 1 .679 r
.5002 .49904 m
.50037 .49923 L
s
% Start of user PostScript
0.0060818564 -0.028838209 0.01107092 -0.023197471 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50054 .50024 m
.50047 .5003 L
s
% Start of user PostScript
0.016202123 0.0071512982 0.014197255 0.0089783233 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49998 .50025 m
.49993 .50021 L
s
% Start of user PostScript
-0.00068061648 0.0074729718 -0.0020122669 0.0061743542 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49987 .49995 m
.49988 .49994 L
s
% Start of user PostScript
-0.004029805 -0.0013856681 -0.0036027366 -0.0019018628 MAarrowhead1
% End of user PostScript
0 .06 1 r
.5 .49994 m
.50001 .49995 L
s
% Start of user PostScript
-0.000035901902 -0.0019128691 0.00031407087 -0.0016187318 MAarrowhead1
% End of user PostScript
1 0 .664 r
.49407 .73789 m
.45099 .69942 L
.41679 .65915 L
.39141 .61898 L
.37445 .5805 L
.36523 .54497 L
.36288 .51336 L
.36639 .48628 L
.37468 .4641 L
.38665 .44692 L
.40123 .43462 L
.41742 .4269 L
.43432 .42335 L
.45112 .42344 L
.46719 .42657 L
.48199 .43213 L
.49513 .43952 L
.50635 .44814 L
.51552 .45745 L
.5226 .46697 L
.52764 .47627 L
.53076 .48504 L
.53215 .49299 L
.53204 .49995 L
.53066 .50579 L
.52827 .51047 L
.52514 .51397 L
.52151 .51636 L
.51759 .5177 L
.51361 .51812 L
.50972 .51775 L
.50606 .51673 L
.50275 .51521 L
.49986 .51332 L
.49744 .5112 L
.49551 .50897 L
.49407 .50675 L
.4931 .50461 L
.49256 .50263 L
.49241 .50086 L
.49258 .49934 L
.49302 .49809 L
.49367 .49712 L
.49447 .49642 L
.49536 .49598 L
.4963 .49576 L
.49723 .49575 L
.49812 .49592 L
.49895 .49622 L
.49968 .49662 L
Mistroke
.50031 .49709 L
.50083 .49761 L
.50123 .49813 L
.50151 .49865 L
.50169 .49914 L
.50178 .49958 L
.50178 .49997 L
.5017 .5003 L
.50158 .50056 L
.50141 .50076 L
.50121 .5009 L
.50099 .50098 L
.50077 .501 L
.50055 .50099 L
.50035 .50093 L
.50016 .50085 L
.5 .50075 L
.49987 .50063 L
.49976 .50051 L
.49968 .50038 L
.49962 .50026 L
.49959 .50015 L
.49958 .50005 L
.49959 .49997 L
.49961 .4999 L
.49965 .49984 L
.49969 .4998 L
.49974 .49978 L
.49979 .49977 L
.49984 .49976 L
.49989 .49977 L
.49994 .49979 L
.49998 .49981 L
.50001 .49984 L
.50004 .49987 L
.50007 .49989 L
.50008 .49992 L
.50009 .49995 L
.5001 .49998 L
.5001 .5 L
.50009 .50002 L
.50009 .50003 L
.50008 .50004 L
.50007 .50005 L
.50006 .50005 L
.50004 .50006 L
.50003 .50005 L
.50002 .50005 L
.50001 .50005 L
.5 .50004 L
Mistroke
.49999 .50004 L
.49999 .50003 L
.49998 .50002 L
.49998 .50002 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.49407 .73789 m
.45099 .69942 L
s
% Start of user PostScript
-0.17802447 7.1368351 -1.4702354 5.9825973 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41679 .65915 m
.39141 .61898 L
s
% Start of user PostScript
-2.4961966 4.7744221 -3.2576249 3.5692832 MAarrowhead1
% End of user PostScript
1 .473 0 r
.40123 .43462 m
.41742 .4269 L
s
% Start of user PostScript
-2.9630355 -1.9615034 -2.4773233 -2.1928796 MAarrowhead1
% End of user PostScript
1 .788 0 r
.51552 .45745 m
.5226 .46697 L
s
% Start of user PostScript
0.46574865 -1.2765282 0.67807129 -0.99104253 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52514 .51397 m
.52151 .51636 L
s
% Start of user PostScript
0.75422299 0.41916175 0.64518249 0.49065209 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49744 .5112 m
.49551 .50897 L
s
% Start of user PostScript
-0.076720012 0.33598005 -0.13459103 0.26919459 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49367 .49712 m
.49447 .49642 L
s
% Start of user PostScript
-0.18986793 -0.086377454 -0.16590473 -0.10738331 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50031 .49709 m
.50083 .49761 L
s
% Start of user PostScript
0.0093195332 -0.087218752 0.024801887 -0.071811679 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50158 .50056 m
.50141 .50076 L
s
% Start of user PostScript
0.047292034 0.016890791 0.042165542 0.022849726 MAarrowhead1
% End of user PostScript
0 1 .679 r
.5 .50075 m
.49987 .50063 L
s
% Start of user PostScript
0.000092833557 0.022361848 -0.0039842543 0.018863784 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49961 .4999 m
.49965 .49984 L
s
% Start of user PostScript
-0.011657379 -0.0030346421 -0.010599332 -0.0046809533 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49998 .49981 m
.50001 .49984 L
s
% Start of user PostScript
-0.00061226905 -0.0056677901 0.00044662144 -0.0048884127 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50009 .50002 m
.50009 .50003 L
s
% Start of user PostScript
0.0028437189 0.00046178001 0.0026363434 0.00090715931 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50001 .50005 m
.5 .50004 L
s
% Start of user PostScript
0.00029475712 0.0014210066 0.0000231534 0.0012513321 MAarrowhead1
% End of user PostScript
.35 0 1 r
.38783 .17375 m
.45212 .2046 L
.508 .24231 L
.55459 .28427 L
.59152 .32813 L
.61886 .37181 L
.63705 .41361 L
.64685 .45215 L
.6492 .48642 L
.6452 .51573 L
.63604 .53971 L
.62291 .55824 L
.60698 .57148 L
.58932 .57973 L
.57093 .58346 L
.55265 .58326 L
.5352 .57977 L
.51915 .57364 L
.50491 .56555 L
.49275 .55614 L
.48284 .546 L
.47521 .53564 L
.46979 .52552 L
.46645 .51601 L
.46499 .50738 L
.46516 .49984 L
.4667 .49352 L
.46932 .48848 L
.47275 .4847 L
.47672 .48214 L
.48098 .48071 L
.48532 .48028 L
.48955 .4807 L
.49352 .48183 L
.49711 .48351 L
.50024 .48557 L
.50285 .48788 L
.50494 .49031 L
.50649 .49273 L
.50753 .49506 L
.50811 .4972 L
.50826 .49912 L
.50807 .50076 L
.50758 .50211 L
.50686 .50316 L
.50599 .50391 L
.50502 .50439 L
.504 .50461 L
.50299 .50462 L
.50202 .50444 L
Mistroke
.50112 .50411 L
.50032 .50366 L
.49964 .50315 L
.49909 .50259 L
.49865 .50201 L
.49835 .50145 L
.49815 .50092 L
.49806 .50044 L
.49807 .50002 L
.49815 .49966 L
.49829 .49938 L
.49848 .49917 L
.49869 .49902 L
.49893 .49894 L
.49917 .49891 L
.4994 .49893 L
.49963 .49899 L
.49983 .49908 L
.5 .49919 L
.50015 .49932 L
.50027 .49945 L
.50035 .49959 L
.50041 .49972 L
.50045 .49984 L
.50046 .49994 L
.50045 .50004 L
.50042 .50011 L
.50038 .50017 L
.50034 .50021 L
.50028 .50024 L
.50023 .50025 L
.50017 .50026 L
.50012 .50025 L
.50007 .50023 L
.50002 .5002 L
.49998 .50018 L
.49995 .50015 L
.49993 .50011 L
.49991 .50008 L
.4999 .50005 L
.49989 .50003 L
.49989 .5 L
.4999 .49998 L
.4999 .49997 L
.49991 .49995 L
.49993 .49995 L
.49994 .49994 L
.49995 .49994 L
.49997 .49994 L
.49998 .49994 L
Mistroke
.49999 .49995 L
.5 .49995 L
.50001 .49996 L
.50001 .49997 L
.50002 .49998 L
.50002 .49998 L
.50002 .49999 L
.50003 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.38783 .17375 m
.45212 .2046 L
s
% Start of user PostScript
-3.3650095 -9.7875576 -1.4364087 -8.8620034 MAarrowhead1
% End of user PostScript
1 .158 0 r
.508 .24231 m
.55459 .28427 L
s
% Start of user PostScript
0.24001039 -7.7306514 1.6376942 -6.4717837 MAarrowhead1
% End of user PostScript
1 .473 0 r
.63604 .53971 m
.62291 .55824 L
s
% Start of user PostScript
4.0813124 1.1911598 3.6874398 1.7473102 MAarrowhead1
% End of user PostScript
1 .788 0 r
.50491 .56555 m
.49275 .55614 L
s
% Start of user PostScript
0.14715815 1.9665781 -0.21741994 1.6842631 MAarrowhead1
% End of user PostScript
.897 1 0 r
.4667 .49352 m
.46932 .48848 L
s
% Start of user PostScript
-0.9989992 -0.19430966 -0.92030383 -0.34572801 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49711 .48351 m
.50024 .48557 L
s
% Start of user PostScript
-0.086796398 -0.49477615 0.0070861517 -0.43281358 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50807 .50076 m
.50758 .50211 L
s
% Start of user PostScript
0.2419619 0.022901158 0.22730239 0.063373184 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50112 .50411 m
.50032 .50366 L
s
% Start of user PostScript
0.033636896 0.12316814 0.0097445862 0.10993455 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49807 .50002 m
.49815 .49966 L
s
% Start of user PostScript
-0.057966446 0.00057980858 -0.055559411 -0.010069537 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49963 .49899 m
.49983 .49908 L
s
% Start of user PostScript
-0.011225438 -0.030343575 -0.0052119716 -0.027618625 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50046 .49994 m
.50045 .50004 L
s
% Start of user PostScript
0.013726811 -0.0016770969 0.013437274 0.0010867681 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50012 .50025 m
.50007 .50023 L
s
% Start of user PostScript
0.0034621624 0.0073978424 0.0019646213 0.0068656141 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49989 .50003 m
.49989 .5 L
s
% Start of user PostScript
-0.0032099491 0.00078758891 -0.0032142632 0.000079119664 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49997 .49994 m
.49998 .49994 L
s
% Start of user PostScript
-0.0010160481 -0.0017844664 -0.00064697715 -0.0016890394 MAarrowhead1
% End of user PostScript
0 1 .338 r
.73979 .59102 m
.71281 .62039 L
.68166 .64023 L
.64824 .65127 L
.61427 .6545 L
.58117 .65103 L
.55014 .64207 L
.52209 .62887 L
.49766 .61264 L
.47725 .59451 L
.46102 .57551 L
.44896 .55654 L
.44087 .53836 L
.43645 .52156 L
.43527 .50659 L
.43688 .49377 L
.44075 .48325 L
.44637 .47509 L
.45323 .46924 L
.46086 .46555 L
.46883 .46384 L
.47677 .46385 L
.48436 .4653 L
.49136 .46791 L
.49758 .47138 L
.5029 .47543 L
.50725 .47982 L
.51061 .48432 L
.51301 .48871 L
.5145 .49286 L
.51517 .49662 L
.51513 .49991 L
.51449 .50268 L
.51337 .5049 L
.5119 .50657 L
.51019 .5077 L
.50834 .50835 L
.50646 .50855 L
.50462 .50839 L
.5029 .50791 L
.50133 .50719 L
.49996 .50631 L
.49881 .50531 L
.4979 .50426 L
.49721 .50321 L
.49675 .50219 L
.49649 .50126 L
.49642 .50042 L
.49649 .4997 L
.4967 .49911 L
Mistroke
.49701 .49865 L
.49738 .49832 L
.4978 .4981 L
.49824 .498 L
.49868 .498 L
.4991 .49807 L
.4995 .49821 L
.49984 .4984 L
.50014 .49862 L
.50039 .49887 L
.50058 .49911 L
.50071 .49936 L
.5008 .49959 L
.50084 .4998 L
.50084 .49998 L
.50081 .50014 L
.50075 .50026 L
.50067 .50036 L
.50057 .50042 L
.50047 .50046 L
.50037 .50047 L
.50026 .50047 L
.50017 .50044 L
.50008 .5004 L
.5 .50035 L
.49994 .5003 L
.49989 .50024 L
.49985 .50018 L
.49982 .50013 L
.49981 .50007 L
.4998 .50003 L
.49981 .49999 L
.49982 .49995 L
.49983 .49993 L
.49985 .49991 L
.49988 .4999 L
.4999 .49989 L
.49993 .49989 L
.49995 .49989 L
.49997 .4999 L
.49999 .49991 L
.50001 .49992 L
.50002 .49994 L
.50003 .49995 L
.50004 .49996 L
.50004 .49998 L
.50005 .49999 L
.50005 .5 L
.50004 .50001 L
.50004 .50001 L
Mistroke
.50004 .50002 L
.50003 .50002 L
.50003 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.73979 .59102 m
.71281 .62039 L
s
% Start of user PostScript
7.1935904 2.7306203 6.3844088 3.6116698 MAarrowhead1
% End of user PostScript
1 .158 0 r
.68166 .64023 m
.64824 .65127 L
s
% Start of user PostScript
5.4498249 4.2068434 4.4473451 4.5382357 MAarrowhead1
% End of user PostScript
1 .473 0 r
.46102 .57551 m
.44896 .55654 L
s
% Start of user PostScript
-1.1694252 2.2652799 -1.5313406 1.6962061 MAarrowhead1
% End of user PostScript
1 .788 0 r
.45323 .46924 m
.46086 .46555 L
s
% Start of user PostScript
-1.4030344 -0.92286625 -1.1741237 -1.0333579 MAarrowhead1
% End of user PostScript
.897 1 0 r
.50725 .47982 m
.51061 .48432 L
s
% Start of user PostScript
0.21744176 -0.60526965 0.31826231 -0.47052405 MAarrowhead1
% End of user PostScript
.581 1 0 r
.5119 .50657 m
.51019 .5077 L
s
% Start of user PostScript
0.35697749 0.19697464 0.30562612 0.23103406 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49881 .50531 m
.4979 .50426 L
s
% Start of user PostScript
-0.035572323 0.15921635 -0.0630306 0.12771048 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49701 .49865 m
.49738 .49832 L
s
% Start of user PostScript
-0.089828039 -0.04052365 -0.078553189 -0.050515481 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50014 .49862 m
.50039 .49887 L
s
% Start of user PostScript
0.004230479 -0.041311073 0.011571643 -0.03404699 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50075 .50026 m
.50067 .50036 L
s
% Start of user PostScript
0.022365207 0.0079043939 0.01995602 0.010735608 MAarrowhead1
% End of user PostScript
0 1 .995 r
.5 .50035 m
.49994 .5003 L
s
% Start of user PostScript
0.000087522302 0.010586817 -0.0018445908 0.0089386578 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49982 .49995 m
.49983 .49993 L
s
% Start of user PostScript
-0.0055107672 -0.0014139486 -0.0050143532 -0.0021954456 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49999 .49991 m
.50001 .49992 L
s
% Start of user PostScript
-0.00030019744 -0.0026821638 0.0002013536 -0.0023152438 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50004 .50001 m
.50004 .50001 L
s
% Start of user PostScript
0.001343761 0.00021306995 0.0012467044 0.00042433555 MAarrowhead1
% End of user PostScript
1 .153 0 r
.72509 .40722 m
.73223 .4628 L
.72894 .51095 L
.71702 .55093 L
.69834 .58245 L
.67472 .60562 L
.64791 .62084 L
.61949 .62879 L
.59085 .63031 L
.56318 .62638 L
.53742 .61802 L
.5143 .60628 L
.49433 .59218 L
.47778 .57666 L
.46478 .56056 L
.45528 .54463 L
.44909 .52947 L
.44593 .51556 L
.44544 .50327 L
.44721 .49281 L
.4508 .48433 L
.45579 .47783 L
.46174 .47326 L
.46827 .4705 L
.47502 .46936 L
.48169 .46962 L
.48801 .47106 L
.4938 .47343 L
.49891 .47648 L
.50324 .47998 L
.50675 .48371 L
.50942 .4875 L
.51129 .49118 L
.51241 .49463 L
.51285 .49773 L
.51271 .50043 L
.51208 .50268 L
.51107 .50445 L
.50977 .50577 L
.5083 .50664 L
.50673 .50711 L
.50514 .50722 L
.50361 .50702 L
.50217 .50657 L
.50088 .50594 L
.49976 .50516 L
.49883 .50431 L
.4981 .50342 L
.49756 .50253 L
.4972 .50169 L
Mistroke
.49701 .50091 L
.49698 .50023 L
.49707 .49964 L
.49726 .49916 L
.49753 .49879 L
.49786 .49853 L
.49822 .49837 L
.49859 .49831 L
.49896 .49831 L
.49931 .49839 L
.49963 .49852 L
.49992 .49868 L
.50016 .49888 L
.50036 .49908 L
.50051 .49929 L
.50062 .4995 L
.50068 .49969 L
.50071 .49986 L
.5007 .50001 L
.50067 .50014 L
.50062 .50024 L
.50055 .50032 L
.50047 .50037 L
.50038 .50039 L
.50029 .5004 L
.50021 .50039 L
.50013 .50037 L
.50005 .50033 L
.49999 .50029 L
.49994 .50024 L
.4999 .50019 L
.49987 .50014 L
.49985 .5001 L
.49984 .50005 L
.49983 .50002 L
.49984 .49998 L
.49985 .49996 L
.49986 .49993 L
.49988 .49992 L
.4999 .49991 L
.49992 .49991 L
.49994 .49991 L
.49996 .49991 L
.49998 .49992 L
.49999 .49993 L
.50001 .49994 L
.50002 .49995 L
.50003 .49996 L
.50003 .49997 L
.50004 .49998 L
Mistroke
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50003 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.72509 .40722 m
.73223 .4628 L
s
% Start of user PostScript
6.7527548 -2.7833605 6.9670172 -1.1158848 MAarrowhead1
% End of user PostScript
1 .158 0 r
.72894 .51095 m
.71702 .55093 L
s
% Start of user PostScript
6.8682724 0.32851334 6.5107201 1.5278863 MAarrowhead1
% End of user PostScript
1 .473 0 r
.53742 .61802 m
.5143 .60628 L
s
% Start of user PostScript
1.1226883 3.540555 0.42913486 3.188519 MAarrowhead1
% End of user PostScript
1 .788 0 r
.44544 .50327 m
.44721 .49281 L
s
% Start of user PostScript
-1.636934 0.097993849 -1.5838275 -0.21556621 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48801 .47106 m
.4938 .47343 L
s
% Start of user PostScript
-0.35961204 -0.86813572 -0.18589889 -0.79717777 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51285 .49773 m
.51271 .50043 L
s
% Start of user PostScript
0.38548159 -0.068056402 0.38116833 0.012854065 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50361 .50702 m
.50217 .50657 L
s
% Start of user PostScript
0.10816851 0.21063882 0.065113303 0.1972315 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49701 .50091 m
.49698 .50023 L
s
% Start of user PostScript
-0.08958978 0.027432031 -0.09070294 0.0068019046 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49896 .49831 m
.49931 .49839 L
s
% Start of user PostScript
-0.031203528 -0.050555978 -0.020642524 -0.048292796 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50068 .49969 m
.50071 .49986 L
s
% Start of user PostScript
0.020514972 -0.0093206769 0.02132342 -0.0041189279 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50029 .5004 m
.50021 .50039 L
s
% Start of user PostScript
0.0087318962 0.011995714 0.0061684584 0.011700611 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49985 .5001 m
.49984 .50005 L
s
% Start of user PostScript
-0.0046174606 0.0029049328 -0.0049464242 0.0016072775 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49992 .49991 m
.49994 .49991 L
s
% Start of user PostScript
-0.0023867098 -0.0028112383 -0.0017712056 -0.002804074 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50003 .49997 m
.50004 .49998 L
s
% Start of user PostScript
0.0010179839 -0.00085847889 0.0011302241 -0.0005381188 MAarrowhead1
% End of user PostScript
1 .052 0 r
.62507 .34817 m
.6473 .39481 L
.66008 .43818 L
.6644 .47705 L
.66145 .5106 L
.65252 .53834 L
.63893 .5601 L
.62196 .57596 L
.60284 .58623 L
.58267 .59141 L
.56244 .5921 L
.54296 .58899 L
.52489 .58283 L
.50872 .57434 L
.4948 .56425 L
.48333 .5532 L
.47436 .5418 L
.46786 .53056 L
.46368 .5199 L
.46163 .51016 L
.46144 .50157 L
.46283 .4943 L
.46548 .48843 L
.46908 .48396 L
.47334 .48085 L
.47799 .479 L
.48277 .4783 L
.48747 .47857 L
.49191 .47965 L
.49597 .48138 L
.49954 .48357 L
.50255 .48607 L
.50498 .48872 L
.50681 .4914 L
.50808 .494 L
.50883 .49641 L
.5091 .49858 L
.50896 .50046 L
.50849 .50202 L
.50775 .50325 L
.50682 .50415 L
.50577 .50474 L
.50466 .50505 L
.50354 .5051 L
.50245 .50495 L
.50145 .50462 L
.50054 .50415 L
.49976 .5036 L
.49912 .50299 L
.49861 .50236 L
Mistroke
.49824 .50174 L
.498 .50114 L
.49788 .5006 L
.49786 .50012 L
.49793 .49971 L
.49808 .49938 L
.49827 .49913 L
.49851 .49895 L
.49876 .49884 L
.49903 .4988 L
.49929 .49881 L
.49954 .49887 L
.49976 .49896 L
.49996 .49908 L
.50013 .49922 L
.50027 .49936 L
.50037 .49951 L
.50044 .49966 L
.50049 .49979 L
.5005 .49991 L
.5005 .50002 L
.50047 .50011 L
.50043 .50018 L
.50038 .50023 L
.50032 .50026 L
.50026 .50028 L
.5002 .50028 L
.50014 .50027 L
.50008 .50026 L
.50003 .50023 L
.49999 .5002 L
.49995 .50017 L
.49992 .50013 L
.4999 .5001 L
.49989 .50007 L
.49988 .50004 L
.49988 .50001 L
.49989 .49999 L
.49989 .49997 L
.4999 .49995 L
.49992 .49994 L
.49993 .49994 L
.49995 .49993 L
.49996 .49993 L
.49997 .49994 L
.49999 .49994 L
.5 .49995 L
.50001 .49996 L
.50001 .49996 L
.50002 .49997 L
Mistroke
.50002 .49998 L
.50003 .49999 L
.50003 .49999 L
.50003 .5 L
.50003 .50001 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.62507 .34817 m
.6473 .39481 L
s
% Start of user PostScript
3.75205 -4.5549378 4.4190637 -3.1555533 MAarrowhead1
% End of user PostScript
1 .158 0 r
.66008 .43818 m
.6644 .47705 L
s
% Start of user PostScript
4.802276 -1.8546405 4.9319247 -0.68841361 MAarrowhead1
% End of user PostScript
1 .473 0 r
.56244 .5921 m
.54296 .58899 L
s
% Start of user PostScript
1.873189 2.7629207 1.2887449 2.6698169 MAarrowhead1
% End of user PostScript
1 .788 0 r
.46368 .5199 m
.46163 .51016 L
s
% Start of user PostScript
-1.0895215 0.59703713 -1.151041 0.30474196 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48277 .4783 m
.48747 .47857 L
s
% Start of user PostScript
-0.51700702 -0.65114272 -0.37599519 -0.64296153 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50808 .494 m
.50883 .49641 L
s
% Start of user PostScript
0.24253374 -0.18014818 0.26483355 -0.10765545 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50466 .50505 m
.50354 .5051 L
s
% Start of user PostScript
0.13975444 0.15146184 0.10610879 0.15310949 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49824 .50174 m
.498 .50114 L
s
% Start of user PostScript
-0.052742345 0.052081638 -0.059942476 0.034288453 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49876 .49884 m
.49903 .4988 L
s
% Start of user PostScript
-0.037129581 -0.034716874 -0.029196692 -0.036022771 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50037 .49951 m
.50044 .49966 L
s
% Start of user PostScript
0.011128896 -0.014598398 0.013305499 -0.010276676 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50032 .50026 m
.50026 .50028 L
s
% Start of user PostScript
0.0097186994 0.0078230064 0.0078725183 0.0083635354 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49992 .50013 m
.4999 .5001 L
s
% Start of user PostScript
-0.0022529915 0.0039954381 -0.002883075 0.0029570429 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49992 .49994 m
.49993 .49994 L
s
% Start of user PostScript
-0.0025105091 -0.0017271273 -0.0020871023 -0.0019129195 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50001 .49996 m
.50002 .49997 L
s
% Start of user PostScript
0.00042865394 -0.0010725834 0.00060543731 -0.00082591165 MAarrowhead1
% End of user PostScript
.721 1 0 r
.51978 .72642 m
.47768 .69443 L
.44323 .6598 L
.41659 .62435 L
.39755 .58961 L
.38567 .55686 L
.38027 .5271 L
.38052 .50103 L
.38552 .47911 L
.39428 .46154 L
.40587 .44833 L
.41936 .43931 L
.43391 .43416 L
.44877 .43247 L
.46329 .43375 L
.47695 .43748 L
.48933 .44311 L
.50016 .45011 L
.50924 .45798 L
.51649 .46627 L
.52192 .47457 L
.5256 .48256 L
.52767 .48997 L
.5283 .49658 L
.52769 .50228 L
.52608 .50696 L
.52368 .51062 L
.52072 .51326 L
.51741 .51495 L
.51393 .51577 L
.51045 .51583 L
.50712 .51524 L
.50403 .51414 L
.50128 .51265 L
.49892 .5109 L
.49698 .50899 L
.49547 .50703 L
.49439 .5051 L
.49371 .50327 L
.49338 .50161 L
.49337 .50015 L
.49363 .49892 L
.49411 .49793 L
.49474 .49718 L
.49548 .49667 L
.49628 .49637 L
.4971 .49626 L
.49791 .49632 L
.49867 .49652 L
.49936 .49682 L
Mistroke
.49997 .49721 L
.50048 .49764 L
.50089 .4981 L
.5012 .49856 L
.50141 .499 L
.50153 .49942 L
.50157 .49979 L
.50154 .50011 L
.50145 .50037 L
.50132 .50058 L
.50116 .50073 L
.50098 .50082 L
.50079 .50087 L
.50059 .50088 L
.50041 .50085 L
.50023 .50079 L
.50008 .50071 L
.49995 .50061 L
.49984 .50051 L
.49975 .5004 L
.49969 .50029 L
.49965 .50019 L
.49963 .5001 L
.49963 .50001 L
.49965 .49994 L
.49967 .49989 L
.49971 .49985 L
.49975 .49982 L
.49979 .4998 L
.49984 .49979 L
.49988 .4998 L
.49992 .49981 L
.49996 .49982 L
.5 .49984 L
.50002 .49987 L
.50005 .49989 L
.50007 .49992 L
.50008 .49994 L
.50008 .49997 L
.50009 .49999 L
.50009 .5 L
.50008 .50002 L
.50007 .50003 L
.50006 .50004 L
.50005 .50005 L
.50004 .50005 L
.50003 .50005 L
.50002 .50005 L
.50001 .50004 L
.50001 .50004 L
Mistroke
.5 .50003 L
.49999 .50003 L
.49999 .50002 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.51978 .72642 m
.47768 .69443 L
s
% Start of user PostScript
0.59333598 6.7925924 -0.66960918 5.8329631 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44323 .6598 m
.41659 .62435 L
s
% Start of user PostScript
-1.7030199 4.7941371 -2.5024205 3.7303711 MAarrowhead1
% End of user PostScript
1 .473 0 r
.40587 .44833 m
.41936 .43931 L
s
% Start of user PostScript
-2.8238687 -1.5501128 -2.4191209 -1.8208057 MAarrowhead1
% End of user PostScript
1 .788 0 r
.50924 .45798 m
.51649 .46627 L
s
% Start of user PostScript
0.2771897 -1.2605906 0.4947828 -1.0119549 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52368 .51062 m
.52072 .51326 L
s
% Start of user PostScript
0.71037167 0.31851986 0.62156323 0.39784248 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49892 .5109 m
.49698 .50899 L
s
% Start of user PostScript
-0.032438994 0.32696163 -0.09058679 0.26965923 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49411 .49793 m
.49474 .49718 L
s
% Start of user PostScript
-0.17681556 -0.062015426 -0.15785551 -0.084473252 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49997 .49721 m
.50048 .49764 L
s
% Start of user PostScript
-0.00094012643 -0.083763135 0.01435753 -0.070767967 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50145 .50037 m
.50132 .50058 L
s
% Start of user PostScript
0.043554648 0.011057899 0.039652582 0.017252943 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50008 .50071 m
.49995 .50061 L
s
% Start of user PostScript
0.0024338788 0.021214803 -0.0015357584 0.018323444 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49965 .49994 m
.49967 .49989 L
s
% Start of user PostScript
-0.010617391 -0.0016542611 -0.0098558516 -0.0033281223 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49996 .49982 m
.5 .49984 L
s
% Start of user PostScript
-0.0011369838 -0.0053151425 -0.00011958117 -0.0046867697 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50009 .5 m
.50008 .50002 L
s
% Start of user PostScript
0.0025607326 0.0001392115 0.0024243773 0.00058375001 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50001 .50004 m
.50001 .50004 L
s
% Start of user PostScript
0.00040984289 0.0013177363 0.00015206061 0.0011852566 MAarrowhead1
% End of user PostScript
0 1 .592 r
.49863 .39106 m
.51853 .40794 L
.5345 .42578 L
.54652 .44373 L
.55475 .46105 L
.55947 .47715 L
.56106 .49157 L
.55995 .50402 L
.55662 .5143 L
.55156 .52237 L
.54525 .52824 L
.53814 .53205 L
.53065 .53396 L
.52314 .5342 L
.51591 .53304 L
.5092 .53074 L
.5032 .52759 L
.49804 .52383 L
.49378 .51973 L
.49046 .5155 L
.48805 .51132 L
.4865 .50737 L
.48575 .50375 L
.48568 .50056 L
.4862 .49787 L
.48719 .49569 L
.48853 .49403 L
.49011 .49288 L
.49184 .4922 L
.49361 .49194 L
.49536 .49204 L
.49701 .49245 L
.49851 .49309 L
.49984 .4939 L
.50095 .49483 L
.50185 .49582 L
.50253 .49681 L
.50301 .49778 L
.50328 .49867 L
.50338 .49948 L
.50333 .50018 L
.50315 .50075 L
.50288 .50121 L
.50253 .50154 L
.50214 .50176 L
.50173 .50188 L
.50131 .5019 L
.50091 .50184 L
.50053 .50171 L
.5002 .50154 L
Mistroke
.49991 .50134 L
.49967 .50111 L
.49948 .50087 L
.49935 .50064 L
.49926 .50042 L
.49921 .50022 L
.49921 .50004 L
.49923 .49989 L
.49929 .49977 L
.49936 .49968 L
.49945 .49961 L
.49954 .49957 L
.49964 .49955 L
.49974 .49956 L
.49983 .49958 L
.49991 .49961 L
.49999 .49966 L
.50005 .49971 L
.5001 .49976 L
.50014 .49982 L
.50016 .49987 L
.50018 .49992 L
.50019 .49997 L
.50018 .50001 L
.50018 .50004 L
.50016 .50007 L
.50014 .50008 L
.50012 .5001 L
.5001 .5001 L
.50007 .50011 L
.50005 .5001 L
.50003 .5001 L
.50001 .50009 L
.5 .50007 L
.49998 .50006 L
.49997 .50005 L
.49996 .50004 L
.49996 .50002 L
.49996 .50001 L
.49996 .5 L
.49996 .49999 L
.49996 .49999 L
.49996 .49998 L
.49997 .49998 L
.49997 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
Mistroke
.5 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.49863 .39106 m
.51853 .40794 L
s
% Start of user PostScript
-0.041090977 -3.2681082 0.55595464 -2.7618913 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5345 .42578 m
.54652 .44373 L
s
% Start of user PostScript
1.0349163 -2.2264967 1.395598 -1.688019 MAarrowhead1
% End of user PostScript
1 .473 0 r
.54525 .52824 m
.53814 .53205 L
s
% Start of user PostScript
1.3574403 0.84729345 1.144271 0.96135948 MAarrowhead1
% End of user PostScript
1 .788 0 r
.49378 .51973 m
.49046 .5155 L
s
% Start of user PostScript
-0.18657742 0.59188499 -0.28629791 0.46486501 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48853 .49403 m
.49011 .49288 L
s
% Start of user PostScript
-0.34417368 -0.17901533 -0.29664848 -0.21356557 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50095 .49483 m
.50185 .49582 L
s
% Start of user PostScript
0.028608609 -0.15500774 0.055602168 -0.1254318 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50288 .50121 m
.50253 .50154 L
s
% Start of user PostScript
0.086318586 0.036307717 0.075963764 0.04632301 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49991 .50134 m
.49967 .50111 L
s
% Start of user PostScript
-0.0026906801 0.040060093 -0.0098707315 0.033273111 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49929 .49977 m
.49936 .49968 L
s
% Start of user PostScript
-0.021421937 -0.0069280049 -0.01923148 -0.0097408836 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49999 .49966 m
.50005 .49971 L
s
% Start of user PostScript
-0.00041954196 -0.010228965 0.0014617826 -0.0086975301 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50018 .50004 m
.50016 .50007 L
s
% Start of user PostScript
0.0052613734 0.0011912665 0.0048163298 0.0019623405 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50001 .50009 m
.5 .50007 L
s
% Start of user PostScript
0.00036946357 0.0025826601 -0.00011696597 0.002243997 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49996 .49999 m
.49996 .49999 L
s
% Start of user PostScript
-0.0012787593 -0.00016318794 -0.0011936059 -0.00037045466 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49999 .49998 m
.5 .49998 L
s
% Start of user PostScript
-0.00015576042 -0.00064512663 -0.000031503164 -0.00057209238 MAarrowhead1
% End of user PostScript
0 .145 1 r
.70401 .20139 m
.74956 .28549 L
.77781 .36466 L
.79042 .43654 L
.78939 .49941 L
.77696 .55222 L
.75544 .59445 L
.72716 .62613 L
.69434 .64768 L
.65902 .65987 L
.62301 .6637 L
.58786 .66038 L
.55484 .65117 L
.52493 .6374 L
.49882 .62034 L
.47695 .60121 L
.45952 .5811 L
.4465 .56098 L
.43771 .54165 L
.43282 .52376 L
.43141 .50779 L
.43296 .49407 L
.43695 .48279 L
.44282 .47401 L
.45003 .46768 L
.45808 .46366 L
.46652 .46174 L
.47494 .46165 L
.48301 .46312 L
.49046 .46582 L
.4971 .46945 L
.50279 .47373 L
.50746 .47837 L
.51107 .48313 L
.51367 .48779 L
.5153 .4922 L
.51606 .49621 L
.51605 .49973 L
.5154 .5027 L
.51424 .50508 L
.5127 .50688 L
.5109 .50811 L
.50895 .50882 L
.50695 .50906 L
.505 .5089 L
.50316 .50842 L
.50149 .50767 L
.50003 .50674 L
.4988 .50568 L
.49782 .50457 L
Mistroke
.49708 .50346 L
.49658 .50238 L
.49629 .50138 L
.4962 .50049 L
.49628 .49972 L
.49649 .49909 L
.49681 .49859 L
.4972 .49823 L
.49765 .498 L
.49811 .49789 L
.49858 .49787 L
.49903 .49795 L
.49944 .49809 L
.49981 .49829 L
.50013 .49853 L
.5004 .49878 L
.5006 .49905 L
.50075 .49931 L
.50084 .49955 L
.50089 .49978 L
.50089 .49997 L
.50086 .50014 L
.50079 .50027 L
.50071 .50037 L
.50061 .50044 L
.5005 .50049 L
.50039 .5005 L
.50028 .50049 L
.50018 .50047 L
.50009 .50043 L
.50001 .50038 L
.49994 .50032 L
.49988 .50026 L
.49984 .5002 L
.49981 .50014 L
.4998 .50008 L
.49979 .50003 L
.49979 .49999 L
.4998 .49995 L
.49982 .49992 L
.49984 .4999 L
.49987 .49989 L
.49989 .49988 L
.49992 .49988 L
.49994 .49989 L
.49997 .49989 L
.49999 .4999 L
.50001 .49992 L
.50002 .49993 L
.50003 .49995 L
Mistroke
.50004 .49996 L
.50005 .49997 L
.50005 .49999 L
.50005 .5 L
.50005 .50001 L
.50004 .50001 L
.50004 .50002 L
.50003 .50002 L
.50003 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.70401 .20139 m
.74956 .28549 L
s
% Start of user PostScript
6.1204167 -8.958254 7.4868051 -6.4353467 MAarrowhead1
% End of user PostScript
1 .158 0 r
.77781 .36466 m
.79042 .43654 L
s
% Start of user PostScript
8.3344343 -4.0601268 8.7126911 -1.9038686 MAarrowhead1
% End of user PostScript
1 .473 0 r
.62301 .6637 m
.58786 .66038 L
s
% Start of user PostScript
3.69022 4.9110996 2.6357373 4.811292 MAarrowhead1
% End of user PostScript
1 .788 0 r
.43771 .54165 m
.43282 .52376 L
s
% Start of user PostScript
-1.8686752 1.2495115 -2.0152649 0.71273868 MAarrowhead1
% End of user PostScript
.897 1 0 r
.46652 .46174 m
.47494 .46165 L
s
% Start of user PostScript
-1.004474 -1.1478891 -0.75185307 -1.1504152 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51367 .48779 m
.5153 .4922 L
s
% Start of user PostScript
0.41002518 -0.366161 0.45894584 -0.23392216 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50895 .50882 m
.50695 .50906 L
s
% Start of user PostScript
0.26843039 0.26455352 0.20860818 0.2718622 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49708 .50346 m
.49658 .50238 L
s
% Start of user PostScript
-0.087539596 0.10366955 -0.10262779 0.071429371 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49765 .498 m
.49811 .49789 L
s
% Start of user PostScript
-0.070619967 -0.059996744 -0.056630824 -0.06342905 MAarrowhead1
% End of user PostScript
0 1 .679 r
.5006 .49905 m
.50075 .49931 L
s
% Start of user PostScript
0.018016577 -0.028597927 0.022444546 -0.020821127 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50061 .50044 m
.5005 .50049 L
s
% Start of user PostScript
0.018325556 0.013349154 0.015099746 0.014588731 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49988 .50026 m
.49984 .5002 L
s
% Start of user PostScript
-0.0035163253 0.0077270717 -0.0047713402 0.0058720074 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49984 .4999 m
.49987 .49989 L
s
% Start of user PostScript
-0.0046968057 -0.0029011937 -0.0039647821 -0.0033006585 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50002 .49993 m
.50003 .49995 L
s
% Start of user PostScript
0.00062965289 -0.0020521517 0.00097614559 -0.0016148947 MAarrowhead1
% End of user PostScript
1 0 .654 r
.54545 .42978 m
.55627 .44909 L
.56311 .46734 L
.56632 .48397 L
.56636 .49857 L
.56375 .51088 L
.559 .52078 L
.55266 .52826 L
.54523 .53341 L
.53718 .5364 L
.52894 .53745 L
.52086 .53683 L
.51325 .53485 L
.50633 .53178 L
.50027 .52794 L
.49517 .5236 L
.49108 .51901 L
.488 .51439 L
.4859 .50995 L
.4847 .50581 L
.4843 .50211 L
.4846 .49892 L
.48546 .49629 L
.48677 .49422 L
.4884 .49272 L
.49022 .49175 L
.49215 .49127 L
.49408 .49121 L
.49594 .49151 L
.49766 .49211 L
.4992 .49292 L
.50052 .49389 L
.50161 .49495 L
.50246 .49603 L
.50308 .49711 L
.50347 .49812 L
.50367 .49905 L
.50368 .49987 L
.50354 .50056 L
.50329 .50112 L
.50294 .50154 L
.50254 .50183 L
.50209 .50201 L
.50164 .50207 L
.50119 .50204 L
.50076 .50194 L
.50038 .50177 L
.50004 .50156 L
.49975 .50132 L
.49952 .50107 L
Mistroke
.49935 .50082 L
.49923 .50057 L
.49916 .50034 L
.49913 .50013 L
.49915 .49995 L
.49919 .4998 L
.49926 .49969 L
.49935 .4996 L
.49945 .49955 L
.49956 .49952 L
.49966 .49951 L
.49977 .49953 L
.49986 .49956 L
.49995 .4996 L
.50002 .49966 L
.50009 .49972 L
.50013 .49978 L
.50017 .49984 L
.50019 .49989 L
.5002 .49994 L
.5002 .49999 L
.5002 .50003 L
.50018 .50006 L
.50016 .50008 L
.50014 .5001 L
.50012 .50011 L
.50009 .50011 L
.50007 .50011 L
.50004 .50011 L
.50002 .5001 L
.5 .50009 L
.49999 .50007 L
.49997 .50006 L
.49996 .50005 L
.49996 .50003 L
.49995 .50002 L
.49995 .50001 L
.49995 .5 L
.49995 .49999 L
.49996 .49998 L
.49996 .49998 L
.49997 .49998 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49999 L
Mistroke
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.54545 .42978 m
.55627 .44909 L
s
% Start of user PostScript
1.3636011 -2.1067387 1.6882224 -1.5272175 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56311 .46734 m
.56632 .48397 L
s
% Start of user PostScript
1.8932165 -0.97966142 1.989591 -0.48083524 MAarrowhead1
% End of user PostScript
1 .473 0 r
.52894 .53745 m
.52086 .53683 L
s
% Start of user PostScript
0.86821263 1.1234967 0.62594109 1.1050378 MAarrowhead1
% End of user PostScript
1 .788 0 r
.4859 .50995 m
.4847 .50581 L
s
% Start of user PostScript
-0.42296613 0.29838355 -0.45898062 0.17444128 MAarrowhead1
% End of user PostScript
.897 1 0 r
.49215 .49127 m
.49408 .49121 L
s
% Start of user PostScript
-0.23548302 -0.26196512 -0.17756043 -0.26367951 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50308 .49711 m
.50347 .49812 L
s
% Start of user PostScript
0.092396555 -0.086824973 0.10420608 -0.056347863 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50209 .50201 m
.50164 .50207 L
s
% Start of user PostScript
0.062740806 0.060210085 0.049054339 0.062173719 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49935 .50082 m
.49923 .50057 L
s
% Start of user PostScript
-0.019612645 0.024454891 -0.023216803 0.017038606 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49945 .49955 m
.49956 .49952 L
s
% Start of user PostScript
-0.016463273 -0.013611228 -0.013270452 -0.014470408 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50013 .49978 m
.50017 .49984 L
s
% Start of user PostScript
0.0040040645 -0.0067186616 0.0050542624 -0.0049332669 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50014 .5001 m
.50012 .50011 L
s
% Start of user PostScript
0.0042622316 0.0030168037 0.0035279877 0.0033189414 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49997 .50006 m
.49996 .50005 L
s
% Start of user PostScript
-0.00077189921 0.0018093259 -0.0010679969 0.0013843285 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49996 .49998 m
.49997 .49998 L
s
% Start of user PostScript
-0.0010900793 -0.0006524583 -0.00092398711 -0.00074845167 MAarrowhead1
% End of user PostScript
0 .06 1 r
.5 .49998 m
.50001 .49999 L
s
% Start of user PostScript
0.00013523551 -0.00047916141 0.00021664963 -0.0003792116 MAarrowhead1
% End of user PostScript
0 .012 1 r
.5783 .19481 m
.63049 .25705 L
.66909 .319 L
.69472 .37825 L
.70846 .43286 L
.71165 .48138 L
.70587 .52286 L
.69278 .55676 L
.67409 .58296 L
.65143 .60162 L
.62636 .61323 L
.60026 .61845 L
.57434 .61809 L
.5496 .61307 L
.52686 .60433 L
.50669 .59282 L
.48949 .57945 L
.47548 .56505 L
.46469 .55036 L
.45705 .53601 L
.45235 .52253 L
.45031 .51031 L
.45059 .49964 L
.4528 .4907 L
.45654 .48356 L
.46142 .47823 L
.46706 .47462 L
.47311 .47261 L
.47926 .47202 L
.48526 .47264 L
.49088 .47425 L
.49596 .47664 L
.50039 .47958 L
.5041 .48286 L
.50704 .4863 L
.50923 .48973 L
.5107 .49303 L
.51151 .49607 L
.51172 .49879 L
.51144 .50111 L
.51074 .50302 L
.50972 .5045 L
.50848 .50557 L
.5071 .50623 L
.50566 .50655 L
.50422 .50655 L
.50284 .50629 L
.50157 .50582 L
.50045 .50519 L
.49948 .50445 L
Mistroke
.49869 .50366 L
.49808 .50285 L
.49765 .50205 L
.49738 .5013 L
.49725 .50062 L
.49726 .50002 L
.49737 .49952 L
.49758 .49912 L
.49784 .49881 L
.49815 .49861 L
.49849 .49849 L
.49883 .49845 L
.49916 .49848 L
.49947 .49857 L
.49976 .4987 L
.50001 .49886 L
.50021 .49904 L
.50038 .49923 L
.5005 .49942 L
.50059 .4996 L
.50063 .49977 L
.50065 .49992 L
.50064 .50005 L
.5006 .50016 L
.50054 .50024 L
.50047 .5003 L
.5004 .50034 L
.50032 .50036 L
.50024 .50036 L
.50016 .50035 L
.50009 .50032 L
.50003 .50029 L
.49997 .50025 L
.49993 .50021 L
.4999 .50016 L
.49987 .50012 L
.49986 .50007 L
.49985 .50004 L
.49985 .5 L
.49985 .49998 L
.49986 .49995 L
.49988 .49994 L
.4999 .49992 L
.49991 .49992 L
.49993 .49991 L
.49995 .49992 L
.49997 .49992 L
.49999 .49993 L
.5 .49994 L
.50001 .49995 L
Mistroke
.50002 .49996 L
.50003 .49997 L
.50003 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .5 L
.50003 .50001 L
.50003 .50001 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.5783 .19481 m
.63049 .25705 L
s
% Start of user PostScript
2.3489096 -9.155572 3.9147199 -7.2886043 MAarrowhead1
% End of user PostScript
1 .158 0 r
.66909 .319 m
.69472 .37825 L
s
% Start of user PostScript
5.0726019 -5.429896 5.8417421 -3.6524503 MAarrowhead1
% End of user PostScript
1 .473 0 r
.62636 .61323 m
.60026 .61845 L
s
% Start of user PostScript
3.790728 3.3969883 3.007674 3.553485 MAarrowhead1
% End of user PostScript
1 .788 0 r
.46469 .55036 m
.45705 .53601 L
s
% Start of user PostScript
-1.0592357 1.5107416 -1.2884932 1.0803411 MAarrowhead1
% End of user PostScript
.897 1 0 r
.46706 .47462 m
.47311 .47261 L
s
% Start of user PostScript
-0.98833511 -0.76130657 -0.80682723 -0.82165846 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50704 .4863 m
.50923 .48973 L
s
% Start of user PostScript
0.21123581 -0.41103462 0.27694673 -0.30795045 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50848 .50557 m
.5071 .50623 L
s
% Start of user PostScript
0.25440015 0.1669547 0.21296309 0.18704905 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49869 .50366 m
.49808 .50285 L
s
% Start of user PostScript
-0.039228086 0.10980083 -0.057527184 0.085396517 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49784 .49881 m
.49815 .49861 L
s
% Start of user PostScript
-0.064717607 -0.035619185 -0.055424524 -0.041808229 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50021 .49904 m
.50038 .49923 L
s
% Start of user PostScript
0.0064015183 -0.028877394 0.011383862 -0.023172272 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50054 .50024 m
.50047 .5003 L
s
% Start of user PostScript
0.016282815 0.0073235926 0.014243067 0.0091382331 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49997 .50025 m
.49993 .50021 L
s
% Start of user PostScript
-0.00075536446 0.0074913456 -0.0020871215 0.006176225 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49986 .49995 m
.49988 .49994 L
s
% Start of user PostScript
-0.0040534827 -0.0014272264 -0.0036178184 -0.0019412014 MAarrowhead1
% End of user PostScript
0 .06 1 r
.5 .49994 m
.50001 .49995 L
s
% Start of user PostScript
-0.000018666379 -0.0019195011 0.00033176728 -0.0016211821 MAarrowhead1
% End of user PostScript
1 0 .043 r
.45885 .23817 m
.50833 .27183 L
.54953 .30921 L
.58213 .34822 L
.60622 .38704 L
.62219 .42414 L
.63071 .45832 L
.63263 .48868 L
.62895 .51462 L
.62069 .53581 L
.60894 .55216 L
.59472 .56381 L
.57899 .57103 L
.56263 .57425 L
.54639 .57399 L
.5309 .57081 L
.51667 .56531 L
.50405 .55808 L
.49329 .54969 L
.48454 .54065 L
.4778 .53145 L
.47304 .52246 L
.47011 .51402 L
.46886 .50637 L
.46904 .4997 L
.47044 .49411 L
.4728 .48965 L
.47586 .48632 L
.4794 .48407 L
.48319 .48283 L
.48705 .48246 L
.4908 .48286 L
.49433 .48388 L
.49751 .48538 L
.50028 .48722 L
.50259 .48928 L
.50443 .49144 L
.5058 .49359 L
.50672 .49566 L
.50722 .49756 L
.50735 .49926 L
.50716 .50071 L
.50672 .50191 L
.50608 .50283 L
.5053 .50349 L
.50444 .50391 L
.50353 .5041 L
.50263 .5041 L
.50177 .50394 L
.50098 .50364 L
Mistroke
.50027 .50325 L
.49967 .50279 L
.49918 .50229 L
.49879 .50178 L
.49852 .50128 L
.49835 .50081 L
.49828 .50038 L
.49828 .50001 L
.49836 .49969 L
.49848 .49944 L
.49865 .49925 L
.49884 .49913 L
.49905 .49905 L
.49927 .49903 L
.49948 .49905 L
.49967 .4991 L
.49985 .49918 L
.50001 .49928 L
.50014 .4994 L
.50024 .49952 L
.50032 .49964 L
.50037 .49975 L
.5004 .49986 L
.50041 .49995 L
.5004 .50003 L
.50037 .5001 L
.50034 .50015 L
.5003 .50019 L
.50025 .50022 L
.5002 .50023 L
.50015 .50023 L
.5001 .50022 L
.50006 .5002 L
.50002 .50018 L
.49998 .50016 L
.49996 .50013 L
.49993 .5001 L
.49992 .50007 L
.49991 .50005 L
.4999 .50002 L
.4999 .5 L
.49991 .49998 L
.49992 .49997 L
.49992 .49996 L
.49994 .49995 L
.49995 .49995 L
.49996 .49995 L
.49997 .49995 L
.49998 .49995 L
.49999 .49995 L
Mistroke
.5 .49996 L
.50001 .49997 L
.50001 .49997 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.45885 .23817 m
.50833 .27183 L
s
% Start of user PostScript
-1.2344159 -7.8549641 0.24982191 -6.8451132 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54953 .30921 m
.58213 .34822 L
s
% Start of user PostScript
1.4857854 -5.7236527 2.4639076 -4.5533476 MAarrowhead1
% End of user PostScript
1 .473 0 r
.60894 .55216 m
.59472 .56381 L
s
% Start of user PostScript
3.2682245 1.5648528 2.8415307 1.9141652 MAarrowhead1
% End of user PostScript
1 .788 0 r
.49329 .54969 m
.48454 .54065 L
s
% Start of user PostScript
-0.20115449 1.4905516 -0.46392933 1.2196185 MAarrowhead1
% End of user PostScript
.897 1 0 r
.4728 .48965 m
.47586 .48632 L
s
% Start of user PostScript
-0.81610426 -0.31052829 -0.72416829 -0.41036557 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50028 .48722 m
.50259 .48928 L
s
% Start of user PostScript
0.0083432889 -0.38326526 0.077790887 -0.32150159 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50672 .50191 m
.50608 .50283 L
s
% Start of user PostScript
0.20167065 0.057198114 0.18251067 0.084940348 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50027 .50325 m
.49967 .50279 L
s
% Start of user PostScript
0.0081386843 0.097403885 -0.0099555777 0.08357575 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49836 .49969 m
.49848 .49944 L
s
% Start of user PostScript
-0.049319894 -0.009180312 -0.045509914 -0.016720589 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49985 .49918 m
.50001 .49928 L
s
% Start of user PostScript
-0.004500502 -0.024483643 0.00015411393 -0.02145489 MAarrowhead1
% End of user PostScript
0 1 .995 r
.5004 .50003 m
.50037 .5001 L
s
% Start of user PostScript
0.011934599 0.0010259871 0.011230398 0.0030385249 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50006 .5002 m
.50002 .50018 L
s
% Start of user PostScript
0.0017132025 0.0060894641 0.00052978519 0.0054443332 MAarrowhead1
% End of user PostScript
0 .375 1 r
.4999 .5 m
.49991 .49998 L
s
% Start of user PostScript
-0.0028564193 0.000054867301 -0.0027425971 -0.0004740351 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49998 .49995 m
.49999 .49995 L
s
% Start of user PostScript
-0.00056688606 -0.0014988694 -0.00026930431 -0.0013665224 MAarrowhead1
% End of user PostScript
1 .607 0 r
.64634 .81195 m
.58318 .78957 L
.52683 .75921 L
.47846 .72335 L
.43871 .68432 L
.40779 .64418 L
.38553 .60472 L
.37142 .56741 L
.36471 .53339 L
.36449 .5035 L
.36973 .47827 L
.37933 .45796 L
.39222 .44259 L
.40735 .43198 L
.42376 .4258 L
.44058 .42357 L
.45707 .42476 L
.47264 .42877 L
.4868 .43498 L
.49921 .4428 L
.50967 .45165 L
.51805 .46101 L
.52437 .47042 L
.5287 .47951 L
.53119 .48796 L
.53203 .49553 L
.53146 .50207 L
.52972 .50748 L
.52707 .51171 L
.52376 .5148 L
.52003 .5168 L
.51611 .51781 L
.51216 .51794 L
.50837 .51734 L
.50485 .51614 L
.5017 .51448 L
.49899 .51252 L
.49675 .51036 L
.495 .50814 L
.49374 .50595 L
.49292 .50388 L
.49252 .50198 L
.49249 .50031 L
.49276 .49889 L
.49327 .49774 L
.49398 .49687 L
.49481 .49627 L
.49571 .49591 L
.49664 .49577 L
.49756 .49582 L
Mistroke
.49843 .49604 L
.49922 .49637 L
.49991 .4968 L
.5005 .49729 L
.50097 .4978 L
.50133 .49833 L
.50158 .49883 L
.50172 .4993 L
.50177 .49972 L
.50175 .50009 L
.50165 .50039 L
.50151 .50063 L
.50133 .50081 L
.50112 .50092 L
.50091 .50098 L
.50069 .50099 L
.50048 .50096 L
.50028 .5009 L
.50011 .50081 L
.49995 .5007 L
.49983 .50058 L
.49973 .50046 L
.49966 .50034 L
.49961 .50022 L
.49959 .50012 L
.49958 .50002 L
.4996 .49994 L
.49963 .49988 L
.49966 .49983 L
.49971 .4998 L
.49976 .49977 L
.49981 .49977 L
.49986 .49977 L
.49991 .49978 L
.49995 .4998 L
.49999 .49982 L
.50003 .49985 L
.50005 .49988 L
.50007 .49991 L
.50009 .49993 L
.50009 .49996 L
.5001 .49998 L
.5001 .5 L
.50009 .50002 L
.50008 .50003 L
.50007 .50004 L
.50006 .50005 L
.50005 .50005 L
.50004 .50006 L
.50003 .50005 L
Mistroke
.50002 .50005 L
.50001 .50005 L
.5 .50004 L
.49999 .50003 L
.49999 .50003 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.64634 .81195 m
.58318 .78957 L
s
% Start of user PostScript
4.3903142 9.358486 2.4954226 8.6871284 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52683 .75921 m
.47846 .72335 L
s
% Start of user PostScript
0.80495129 7.7761568 -0.64631647 6.7004691 MAarrowhead1
% End of user PostScript
1 .473 0 r
.36973 .47827 m
.37933 .45796 L
s
% Start of user PostScript
-3.9081662 -0.65187096 -3.6200268 -1.2612527 MAarrowhead1
% End of user PostScript
1 .788 0 r
.4868 .43498 m
.49921 .4428 L
s
% Start of user PostScript
-0.39608856 -1.9505341 -0.023642514 -1.7160821 MAarrowhead1
% End of user PostScript
.897 1 0 r
.53146 .50207 m
.52972 .50748 L
s
% Start of user PostScript
0.94371637 0.062133823 0.89149229 0.22425899 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50485 .51614 m
.5017 .51448 L
s
% Start of user PostScript
0.14538688 0.48413717 0.050902456 0.43451877 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49249 .50031 m
.49276 .49889 L
s
% Start of user PostScript
-0.22536709 0.0091551126 -0.21726575 -0.03333308 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49843 .49604 m
.49922 .49637 L
s
% Start of user PostScript
-0.047246127 -0.11892389 -0.023536966 -0.10883627 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50177 .49972 m
.50175 .50009 L
s
% Start of user PostScript
0.053186158 -0.0082702059 0.052387087 0.0027172657 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50048 .50096 m
.50028 .5009 L
s
% Start of user PostScript
0.01433975 0.028908143 0.0084527434 0.026976074 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49959 .50012 m
.49958 .50002 L
s
% Start of user PostScript
-0.012390553 0.0035009526 -0.012491141 0.00069379343 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49986 .49977 m
.49991 .49978 L
s
% Start of user PostScript
-0.0041625834 -0.0069516583 -0.002715951 -0.006617141 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50009 .49996 m
.5001 .49998 L
s
% Start of user PostScript
0.0028450198 -0.0012147879 0.0029429637 -0.00050563838 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50004 .50006 m
.50003 .50005 L
s
% Start of user PostScript
0.0011703196 0.0016528403 0.00081853634 0.0016062027 MAarrowhead1
% End of user PostScript
.617 1 0 r
.41239 .68646 m
.38222 .64119 L
.36161 .59755 L
.34984 .55701 L
.34597 .5207 L
.34887 .48939 L
.35736 .46353 L
.37018 .44328 L
.38614 .42855 L
.40409 .41904 L
.42299 .4143 L
.44194 .41374 L
.46017 .41673 L
.47706 .42256 L
.49216 .43056 L
.50515 .44004 L
.51585 .45041 L
.52419 .46109 L
.53023 .47161 L
.53409 .48158 L
.53597 .49069 L
.53611 .4987 L
.53478 .50548 L
.53227 .51096 L
.52888 .51511 L
.52487 .518 L
.52052 .5197 L
.51604 .52034 L
.51164 .52006 L
.50748 .51903 L
.50369 .5174 L
.50036 .51534 L
.49755 .51299 L
.49529 .51051 L
.49358 .508 L
.4924 .50557 L
.49172 .50331 L
.49147 .50128 L
.49161 .49953 L
.49206 .49807 L
.49275 .49693 L
.49363 .49609 L
.49462 .49555 L
.49566 .49527 L
.49671 .49522 L
.49772 .49537 L
.49867 .49568 L
.49951 .49612 L
.50024 .49664 L
.50084 .49721 L
Mistroke
.50131 .4978 L
.50165 .49839 L
.50188 .49894 L
.50199 .49945 L
.502 .4999 L
.50193 .50028 L
.5018 .50059 L
.50161 .50082 L
.50139 .50099 L
.50115 .50109 L
.50091 .50113 L
.50066 .50111 L
.50043 .50106 L
.50022 .50097 L
.50003 .50086 L
.49987 .50073 L
.49975 .50059 L
.49965 .50045 L
.49958 .50032 L
.49954 .50019 L
.49953 .50008 L
.49953 .49998 L
.49956 .4999 L
.4996 .49983 L
.49964 .49979 L
.4997 .49976 L
.49976 .49974 L
.49981 .49974 L
.49987 .49974 L
.49992 .49976 L
.49997 .49978 L
.50001 .49981 L
.50004 .49984 L
.50007 .49988 L
.50009 .49991 L
.5001 .49994 L
.50011 .49997 L
.50011 .49999 L
.50011 .50001 L
.5001 .50003 L
.50009 .50004 L
.50008 .50005 L
.50006 .50006 L
.50005 .50006 L
.50004 .50006 L
.50002 .50006 L
.50001 .50005 L
.5 .50005 L
.49999 .50004 L
.49999 .50003 L
Mistroke
.49998 .50003 L
.49998 .50002 L
.49997 .50001 L
.49997 .5 L
.49997 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.41239 .68646 m
.38222 .64119 L
s
% Start of user PostScript
-2.6283851 5.5937852 -3.533325 4.2357765 MAarrowhead1
% End of user PostScript
1 .158 0 r
.36161 .59755 m
.34984 .55701 L
s
% Start of user PostScript
-4.1516866 2.926399 -4.5047498 1.7102071 MAarrowhead1
% End of user PostScript
1 .473 0 r
.42299 .4143 m
.44194 .41374 L
s
% Start of user PostScript
-2.3101504 -2.5710225 -1.7417185 -2.5876721 MAarrowhead1
% End of user PostScript
1 .788 0 r
.53023 .47161 m
.53409 .48158 L
s
% Start of user PostScript
0.90699616 -0.8516275 1.0227994 -0.55256004 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52052 .5197 m
.51604 .52034 L
s
% Start of user PostScript
0.6155322 0.59094955 0.48121344 0.61017561 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49358 .508 m
.4924 .50557 L
s
% Start of user PostScript
-0.19254227 0.23988613 -0.22788992 0.16710903 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49462 .49555 m
.49566 .49527 L
s
% Start of user PostScript
-0.16152297 -0.13359814 -0.13018749 -0.14201871 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50131 .4978 m
.50165 .49839 L
s
% Start of user PostScript
0.039314022 -0.065909678 0.049614911 -0.048388797 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50139 .50099 m
.50115 .50109 L
s
% Start of user PostScript
0.041818722 0.029612619 0.034612282 0.032574931 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49975 .50059 m
.49965 .50045 L
s
% Start of user PostScript
-0.0075804374 0.017750288 -0.01048495 0.013579462 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49964 .49979 m
.4997 .49976 L
s
% Start of user PostScript
-0.010695624 -0.0064049586 -0.0090653843 -0.0073463254 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50004 .49984 m
.50007 .49988 L
s
% Start of user PostScript
0.0013285609 -0.0047009907 0.002127227 -0.0037200714 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50009 .50004 m
.50008 .50005 L
s
% Start of user PostScript
0.002704678 0.0013417695 0.0023430451 0.0016235013 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49999 .50004 m
.49999 .50003 L
s
% Start of user PostScript
-0.00019087532 0.0012270875 -0.00040610748 0.00099943967 MAarrowhead1
% End of user PostScript
1 0 .225 r
.50393 .40014 m
.52194 .41655 L
.53619 .43367 L
.54671 .45068 L
.55366 .46694 L
.55736 .48191 L
.55817 .4952 L
.55652 .50655 L
.55288 .51582 L
.5477 .52296 L
.54145 .52804 L
.53455 .53118 L
.52737 .53258 L
.52025 .53244 L
.51346 .53103 L
.50723 .5286 L
.50171 .52542 L
.497 .52174 L
.49317 .51778 L
.49023 .51374 L
.48815 .5098 L
.48688 .5061 L
.48634 .50275 L
.48643 .49983 L
.48705 .49738 L
.48809 .49544 L
.48943 .49398 L
.49099 .493 L
.49265 .49246 L
.49434 .49231 L
.49599 .49249 L
.49753 .49294 L
.49892 .4936 L
.50014 .49441 L
.50115 .49531 L
.50195 .49626 L
.50255 .4972 L
.50295 .49811 L
.50317 .49894 L
.50322 .49968 L
.50314 .50032 L
.50295 .50084 L
.50266 .50125 L
.50232 .50154 L
.50194 .50172 L
.50154 .5018 L
.50115 .5018 L
.50077 .50173 L
.50042 .50159 L
.50012 .50142 L
Mistroke
.49985 .50122 L
.49964 .501 L
.49947 .50078 L
.49935 .50056 L
.49928 .50035 L
.49924 .50016 L
.49925 .5 L
.49928 .49986 L
.49934 .49975 L
.49941 .49967 L
.49949 .49962 L
.49959 .49958 L
.49968 .49957 L
.49977 .49958 L
.49986 .49961 L
.49994 .49964 L
.5 .49969 L
.50006 .49974 L
.50011 .49979 L
.50014 .49984 L
.50016 .49989 L
.50017 .49994 L
.50018 .49998 L
.50017 .50002 L
.50016 .50004 L
.50015 .50007 L
.50013 .50008 L
.50011 .50009 L
.50009 .5001 L
.50007 .5001 L
.50004 .5001 L
.50002 .50009 L
.50001 .50008 L
.49999 .50007 L
.49998 .50006 L
.49997 .50004 L
.49996 .50003 L
.49996 .50002 L
.49996 .50001 L
.49996 .5 L
.49996 .49999 L
.49996 .49999 L
.49997 .49998 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
Mistroke
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.50393 .40014 m
.52194 .41655 L
s
% Start of user PostScript
0.11776426 -2.9958029 0.65832542 -2.5034541 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53619 .43367 m
.54671 .45068 L
s
% Start of user PostScript
1.085777 -1.9900361 1.4011844 -1.4794628 MAarrowhead1
% End of user PostScript
1 .473 0 r
.54145 .52804 m
.53455 .53118 L
s
% Start of user PostScript
1.2435707 0.8412456 1.0364388 0.93552166 MAarrowhead1
% End of user PostScript
1 .788 0 r
.49317 .51778 m
.49023 .51374 L
s
% Start of user PostScript
-0.20487658 0.53326876 -0.29312729 0.41212937 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48943 .49398 m
.49099 .493 L
s
% Start of user PostScript
-0.31701895 -0.18048748 -0.27040267 -0.20986026 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50115 .49531 m
.50195 .49626 L
s
% Start of user PostScript
0.03449402 -0.14062759 0.058613217 -0.11224002 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50266 .50125 m
.50232 .50154 L
s
% Start of user PostScript
0.079919867 0.03739778 0.069643859 0.046076246 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49985 .50122 m
.49964 .501 L
s
% Start of user PostScript
-0.0044655127 0.036569102 -0.01093277 0.030007581 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49934 .49975 m
.49941 .49967 L
s
% Start of user PostScript
-0.019933765 -0.0073733096 -0.017726706 -0.0098451317 MAarrowhead1
% End of user PostScript
0 1 .679 r
.5 .49969 m
.50006 .49974 L
s
% Start of user PostScript
0.00009336573 -0.0093906112 0.0017997568 -0.007897531 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50016 .50004 m
.50015 .50007 L
s
% Start of user PostScript
0.0049203263 0.0013434629 0.0044623444 0.0020284943 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50001 .50008 m
.49999 .50007 L
s
% Start of user PostScript
0.00022573935 0.0023836193 -0.00021820628 0.0020500643 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49996 .49999 m
.49996 .49999 L
s
% Start of user PostScript
-0.0012019246 -0.00021078228 -0.0011114327 -0.00039657289 MAarrowhead1
% End of user PostScript
0 .06 1 r
.5 .49998 m
.5 .49998 L
s
% Start of user PostScript
-0.00011643383 -0.00059845007 -0.0000023830783 -0.00052558966 MAarrowhead1
% End of user PostScript
0 .548 1 r
.71862 .59048 m
.69266 .61608 L
.66316 .63292 L
.63188 .64175 L
.60035 .64349 L
.56986 .63921 L
.54148 .63005 L
.51599 .61717 L
.49395 .60166 L
.4757 .58458 L
.46135 .56686 L
.45084 .54931 L
.44399 .53261 L
.44048 .51728 L
.43992 .50372 L
.44184 .49219 L
.44578 .48283 L
.45126 .47565 L
.45781 .4706 L
.46499 .46754 L
.47242 .46626 L
.47976 .46654 L
.48673 .46812 L
.49312 .47071 L
.49875 .47406 L
.50353 .47791 L
.5074 .48203 L
.51035 .4862 L
.51242 .49025 L
.51365 .49405 L
.51415 .49747 L
.51399 .50044 L
.51331 .50292 L
.5122 .50489 L
.51078 .50634 L
.50916 .50731 L
.50743 .50783 L
.50568 .50795 L
.50399 .50773 L
.5024 .50724 L
.50098 .50654 L
.49975 .50569 L
.49872 .50475 L
.49791 .50377 L
.49731 .5028 L
.49692 .50187 L
.49671 .50101 L
.49667 .50026 L
.49677 .49961 L
.49698 .49908 L
Mistroke
.49728 .49868 L
.49764 .49839 L
.49803 .49821 L
.49844 .49813 L
.49885 .49814 L
.49924 .49823 L
.49959 .49837 L
.49991 .49855 L
.50018 .49876 L
.5004 .49899 L
.50056 .49922 L
.50068 .49944 L
.50075 .49966 L
.50078 .49985 L
.50078 .50001 L
.50074 .50015 L
.50068 .50026 L
.5006 .50035 L
.50051 .5004 L
.50042 .50043 L
.50032 .50044 L
.50023 .50043 L
.50014 .5004 L
.50006 .50037 L
.49999 .50032 L
.49993 .50027 L
.49989 .50021 L
.49985 .50016 L
.49983 .50011 L
.49982 .50006 L
.49982 .50002 L
.49982 .49998 L
.49983 .49995 L
.49985 .49993 L
.49987 .49991 L
.49989 .4999 L
.49991 .4999 L
.49993 .4999 L
.49996 .4999 L
.49998 .49991 L
.49999 .49992 L
.50001 .49993 L
.50002 .49994 L
.50003 .49996 L
.50004 .49997 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50004 .50001 L
Mistroke
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.71862 .59048 m
.69266 .61608 L
s
% Start of user PostScript
6.5584596 2.714442 5.7797554 3.4823496 MAarrowhead1
% End of user PostScript
1 .158 0 r
.66316 .63292 m
.63188 .64175 L
s
% Start of user PostScript
4.894936 3.9877169 3.9564211 4.2524835 MAarrowhead1
% End of user PostScript
1 .473 0 r
.46135 .56686 m
.45084 .54931 L
s
% Start of user PostScript
-1.1595805 2.0057904 -1.4746583 1.4792979 MAarrowhead1
% End of user PostScript
1 .788 0 r
.45781 .4706 m
.46499 .46754 L
s
% Start of user PostScript
-1.2657027 -0.88194965 -1.0501976 -0.97385881 MAarrowhead1
% End of user PostScript
.897 1 0 r
.5074 .48203 m
.51035 .4862 L
s
% Start of user PostScript
0.22195732 -0.53921165 0.31055011 -0.41402697 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51078 .50634 m
.50916 .50731 L
s
% Start of user PostScript
0.32334022 0.19022451 0.2746764 0.21921815 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49872 .50475 m
.49791 .50377 L
s
% Start of user PostScript
-0.038386488 0.14258537 -0.062693557 0.11318108 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49728 .49868 m
.49764 .49839 L
s
% Start of user PostScript
-0.08167547 -0.039699921 -0.070904043 -0.048336294 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50018 .49876 m
.5004 .49899 L
s
% Start of user PostScript
0.0053366232 -0.037168278 0.011875257 -0.030353908 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50068 .50026 m
.5006 .50035 L
s
% Start of user PostScript
0.020410733 0.0079107172 0.018085114 0.010384943 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49999 .50032 m
.49993 .50027 L
s
% Start of user PostScript
-0.00028406426 0.0095655366 -0.0020140508 0.0080102261 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49983 .49995 m
.49985 .49993 L
s
% Start of user PostScript
-0.0050475866 -0.0014671421 -0.004561561 -0.0021559125 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49999 .49992 m
.50001 .49993 L
s
% Start of user PostScript
-0.00018514773 -0.0024330084 0.00026603429 -0.0020842966 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50004 .50001 m
.50004 .50001 L
s
% Start of user PostScript
0.0012353588 0.00023878416 0.0011383173 0.00042626309 MAarrowhead1
% End of user PostScript
.216 1 0 r
.62802 .48587 m
.62504 .5114 L
.61755 .53239 L
.60655 .54871 L
.59306 .56046 L
.57802 .56791 L
.56227 .57144 L
.54655 .57155 L
.5315 .56879 L
.51761 .56371 L
.50524 .5569 L
.49465 .54891 L
.48597 .54025 L
.47925 .53137 L
.47443 .52266 L
.47141 .51444 L
.47002 .50696 L
.47005 .50041 L
.47128 .49489 L
.47345 .49046 L
.47634 .48713 L
.47971 .48484 L
.48335 .48353 L
.48707 .48308 L
.49072 .48339 L
.49414 .48431 L
.49726 .48571 L
.49998 .48746 L
.50226 .48942 L
.50409 .4915 L
.50546 .49358 L
.5064 .49558 L
.50692 .49744 L
.50709 .49911 L
.50694 .50054 L
.50655 .50172 L
.50595 .50264 L
.50521 .50331 L
.50438 .50374 L
.50351 .50395 L
.50264 .50397 L
.5018 .50382 L
.50103 .50355 L
.50034 .50318 L
.49974 .50274 L
.49925 .50226 L
.49887 .50177 L
.4986 .50129 L
.49843 .50083 L
.49834 .50041 L
Mistroke
.49834 .50005 L
.4984 .49974 L
.49852 .49949 L
.49868 .4993 L
.49886 .49917 L
.49906 .49909 L
.49927 .49906 L
.49947 .49908 L
.49966 .49913 L
.49984 .4992 L
.49999 .4993 L
.50012 .49941 L
.50022 .49952 L
.5003 .49964 L
.50035 .49975 L
.50038 .49985 L
.50039 .49994 L
.50039 .50002 L
.50036 .50009 L
.50033 .50014 L
.50029 .50018 L
.50025 .50021 L
.5002 .50022 L
.50015 .50022 L
.5001 .50021 L
.50006 .5002 L
.50002 .50018 L
.49999 .50015 L
.49996 .50013 L
.49994 .5001 L
.49992 .50007 L
.49991 .50005 L
.49991 .50002 L
.49991 .5 L
.49991 .49999 L
.49992 .49997 L
.49993 .49996 L
.49994 .49995 L
.49995 .49995 L
.49996 .49995 L
.49997 .49995 L
.49998 .49995 L
.49999 .49996 L
.5 .49996 L
.50001 .49997 L
.50001 .49997 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
Mistroke
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.62802 .48587 m
.62504 .5114 L
s
% Start of user PostScript
3.8405812 -0.42404714 3.7513428 0.34214386 MAarrowhead1
% End of user PostScript
1 .158 0 r
.61755 .53239 m
.60655 .54871 L
s
% Start of user PostScript
3.5264159 0.97164605 3.1965791 1.4612302 MAarrowhead1
% End of user PostScript
1 .473 0 r
.50524 .5569 m
.49465 .54891 L
s
% Start of user PostScript
0.15720363 1.707138 -0.16055458 1.4674331 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47128 .49489 m
.47345 .49046 L
s
% Start of user PostScript
-0.86165551 -0.15329507 -0.79638405 -0.2861441 MAarrowhead1
% End of user PostScript
.897 1 0 r
.49726 .48571 m
.49998 .48746 L
s
% Start of user PostScript
-0.082329727 -0.42872537 -0.00067150698 -0.3763315 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50694 .50054 m
.50655 .50172 L
s
% Start of user PostScript
0.20831919 0.016126497 0.19635194 0.051535607 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50103 .50355 m
.50034 .50318 L
s
% Start of user PostScript
0.030834513 0.1065377 0.010092801 0.095407754 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49834 .50005 m
.4984 .49974 L
s
% Start of user PostScript
-0.04981194 0.001409614 -0.047909518 -0.0078848758 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49966 .49913 m
.49984 .4992 L
s
% Start of user PostScript
-0.010122101 -0.026200606 -0.0049110751 -0.023925908 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50039 .49994 m
.50039 .50002 L
s
% Start of user PostScript
0.011771718 -0.0016722632 0.011566046 0.00073473456 MAarrowhead1
% End of user PostScript
0 1 .995 r
.5001 .50021 m
.50006 .5002 L
s
% Start of user PostScript
0.0030912368 0.0063764433 0.0017958152 0.0059372031 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49991 .50002 m
.49991 .5 L
s
% Start of user PostScript
-0.0027465823 0.00073475679 -0.0027613587 0.00011899125 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49997 .49995 m
.49998 .49995 L
s
% Start of user PostScript
-0.00090115199 -0.0015352636 -0.00058245201 -0.0014580803 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50002 .49999 m
.50002 .5 L
s
% Start of user PostScript
0.0006317382 -0.00025880902 0.00065149491 -0.00010306086 MAarrowhead1
% End of user PostScript
.331 0 1 r
.7069 .20956 m
.75083 .2929 L
.77768 .37114 L
.78911 .44197 L
.78715 .50375 L
.77402 .55547 L
.75204 .59666 L
.72351 .62737 L
.69062 .64806 L
.65539 .65951 L
.6196 .66274 L
.58477 .65894 L
.55215 .6494 L
.52268 .63542 L
.49703 .61826 L
.47562 .59913 L
.45862 .57911 L
.446 .55914 L
.43757 .54 L
.43299 .52235 L
.43183 .50663 L
.43357 .49317 L
.4377 .48214 L
.44365 .4736 L
.4509 .46749 L
.45895 .46366 L
.46735 .46189 L
.47571 .46193 L
.48369 .46349 L
.49105 .46626 L
.49758 .46993 L
.50316 .47422 L
.50772 .47885 L
.51124 .48358 L
.51374 .48821 L
.5153 .49257 L
.51599 .49652 L
.51593 .49998 L
.51524 .50288 L
.51406 .50521 L
.5125 .50695 L
.51069 .50813 L
.50875 .5088 L
.50676 .50901 L
.50483 .50883 L
.50301 .50832 L
.50137 .50756 L
.49993 .50662 L
.49873 .50557 L
.49777 .50446 L
Mistroke
.49705 .50335 L
.49657 .50229 L
.4963 .5013 L
.49622 .50043 L
.49631 .49967 L
.49653 .49905 L
.49685 .49857 L
.49725 .49822 L
.49769 .498 L
.49816 .49789 L
.49862 .49789 L
.49907 .49797 L
.49948 .49812 L
.49984 .49832 L
.50015 .49855 L
.50041 .49881 L
.50061 .49907 L
.50075 .49933 L
.50084 .49957 L
.50088 .49979 L
.50088 .49999 L
.50085 .50015 L
.50078 .50028 L
.5007 .50038 L
.5006 .50045 L
.50049 .50049 L
.50038 .5005 L
.50027 .50049 L
.50017 .50046 L
.50008 .50042 L
.5 .50037 L
.49993 .50031 L
.49988 .50025 L
.49984 .50019 L
.49981 .50013 L
.4998 .50008 L
.49979 .50003 L
.4998 .49998 L
.49981 .49995 L
.49982 .49992 L
.49985 .4999 L
.49987 .49989 L
.4999 .49988 L
.49992 .49988 L
.49995 .49989 L
.49997 .4999 L
.49999 .49991 L
.50001 .49992 L
.50002 .49993 L
.50003 .49995 L
Mistroke
.50004 .49996 L
.50005 .49998 L
.50005 .49999 L
.50005 .5 L
.50005 .50001 L
.50004 .50002 L
.50004 .50002 L
.50003 .50002 L
.50003 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.7069 .20956 m
.75083 .2929 L
s
% Start of user PostScript
6.206859 -8.7131705 7.5248601 -6.213042 MAarrowhead1
% End of user PostScript
1 .158 0 r
.77768 .37114 m
.78911 .44197 L
s
% Start of user PostScript
8.3303484 -3.8658339 8.6733931 -1.74086 MAarrowhead1
% End of user PostScript
1 .473 0 r
.6196 .66274 m
.58477 .65894 L
s
% Start of user PostScript
3.5880119 4.8821785 2.5432274 4.7683004 MAarrowhead1
% End of user PostScript
1 .788 0 r
.43757 .54 m
.43299 .52235 L
s
% Start of user PostScript
-1.872835 1.2001373 -2.0102513 0.67036768 MAarrowhead1
% End of user PostScript
.897 1 0 r
.46735 .46189 m
.47571 .46193 L
s
% Start of user PostScript
-0.9794801 -1.1432536 -0.72878692 -1.1419558 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51374 .48821 m
.5153 .49257 L
s
% Start of user PostScript
0.41231464 -0.3537511 0.45887568 -0.22304591 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50875 .5088 m
.50676 .50901 L
s
% Start of user PostScript
0.26238272 0.26403782 0.20291659 0.27032602 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49705 .50335 m
.49657 .50229 L
s
% Start of user PostScript
-0.08840993 0.10058323 -0.10289824 0.068669654 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49769 .498 m
.49816 .49789 L
s
% Start of user PostScript
-0.069172634 -0.060025614 -0.055240969 -0.063189759 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50061 .49907 m
.50075 .49933 L
s
% Start of user PostScript
0.018304373 -0.02783831 0.022581508 -0.020128491 MAarrowhead1
% End of user PostScript
0 1 .995 r
.5006 .50045 m
.50049 .50049 L
s
% Start of user PostScript
0.017983198 0.013394678 0.014763937 0.014564742 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49988 .50025 m
.49984 .50019 L
s
% Start of user PostScript
-0.003604604 0.0075420541 -0.0048220926 0.0056999926 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49985 .4999 m
.49987 .49989 L
s
% Start of user PostScript
-0.0046168446 -0.002921774 -0.0038845385 -0.0033034395 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50002 .49993 m
.50003 .49995 L
s
% Start of user PostScript
0.00065546485 -0.0020075674 0.00099271796 -0.001572617 MAarrowhead1
% End of user PostScript
1 0 .097 r
.3509 .30831 m
.39228 .31128 L
.43132 .32132 L
.46685 .3369 L
.49799 .3565 L
.52422 .37869 L
.54526 .40217 L
.56112 .42579 L
.57199 .44859 L
.57823 .46978 L
.58034 .48878 L
.57891 .50518 L
.57454 .51874 L
.5679 .52937 L
.55961 .53712 L
.55026 .54214 L
.54041 .54467 L
.53052 .54501 L
.521 .54349 L
.51216 .54048 L
.50426 .53633 L
.49746 .5314 L
.49185 .526 L
.48747 .52043 L
.48429 .51494 L
.48225 .50973 L
.48125 .50497 L
.48116 .50077 L
.48183 .49722 L
.48313 .49435 L
.48489 .49216 L
.48697 .49064 L
.48924 .48974 L
.49158 .48939 L
.49387 .48953 L
.49605 .49006 L
.49803 .4909 L
.49977 .49197 L
.50125 .49319 L
.50243 .49449 L
.50333 .4958 L
.50395 .49706 L
.50431 .49825 L
.50445 .49931 L
.50438 .50023 L
.50415 .50099 L
.50379 .50159 L
.50334 .50203 L
.50282 .50232 L
.50228 .50247 L
Mistroke
.50173 .50249 L
.5012 .50242 L
.50071 .50226 L
.50027 .50203 L
.49988 .50176 L
.49957 .50146 L
.49932 .50115 L
.49914 .50085 L
.49902 .50056 L
.49896 .50029 L
.49896 .50006 L
.49899 .49986 L
.49906 .4997 L
.49916 .49957 L
.49927 .49949 L
.4994 .49943 L
.49952 .49941 L
.49965 .49942 L
.49977 .49945 L
.49988 .49949 L
.49998 .49955 L
.50006 .49962 L
.50013 .49969 L
.50018 .49976 L
.50022 .49983 L
.50024 .4999 L
.50025 .49996 L
.50024 .50001 L
.50023 .50005 L
.50021 .50009 L
.50019 .50011 L
.50016 .50013 L
.50013 .50014 L
.5001 .50014 L
.50007 .50013 L
.50004 .50013 L
.50002 .50011 L
.5 .5001 L
.49998 .50008 L
.49996 .50007 L
.49995 .50005 L
.49995 .50003 L
.49994 .50002 L
.49994 .5 L
.49994 .49999 L
.49995 .49998 L
.49995 .49998 L
.49996 .49997 L
.49997 .49997 L
.49997 .49997 L
Mistroke
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49997 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.3509 .30831 m
.39228 .31128 L
s
% Start of user PostScript
-4.4729193 -5.7508464 -3.2315549 -5.6616058 MAarrowhead1
% End of user PostScript
1 .158 0 r
.43132 .32132 m
.46685 .3369 L
s
% Start of user PostScript
-2.0602539 -5.3602862 -0.99460815 -4.8929851 MAarrowhead1
% End of user PostScript
1 .473 0 r
.58034 .48878 m
.57891 .50518 L
s
% Start of user PostScript
2.4103281 -0.33659341 2.367157 0.15533985 MAarrowhead1
% End of user PostScript
1 .788 0 r
.521 .54349 m
.51216 .54048 L
s
% Start of user PostScript
0.62991432 1.3048127 0.36494665 1.214449 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48125 .50497 m
.48116 .50077 L
s
% Start of user PostScript
-0.56253222 0.14897195 -0.56528267 0.023094071 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49387 .48953 m
.49605 .49006 L
s
% Start of user PostScript
-0.1837756 -0.3142311 -0.11857443 -0.29831184 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50431 .49825 m
.50445 .49931 L
s
% Start of user PostScript
0.12942737 -0.052623003 0.13340208 -0.02077705 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50173 .50249 m
.5012 .50242 L
s
% Start of user PostScript
0.051862125 0.074827908 0.03598467 0.072512342 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49902 .50056 m
.49896 .50029 L
s
% Start of user PostScript
-0.029294338 0.01675984 -0.031077225 0.0087896541 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49952 .49941 m
.49965 .49942 L
s
% Start of user PostScript
-0.014270113 -0.017604987 -0.01044492 -0.017436934 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50022 .49983 m
.50024 .4999 L
s
% Start of user PostScript
0.0065024229 -0.005023003 0.0071354725 -0.0030490827 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50013 .50014 m
.5001 .50014 L
s
% Start of user PostScript
0.0038477176 0.0040873821 0.0029364426 0.0041457387 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49995 .50005 m
.49995 .50003 L
s
% Start of user PostScript
-0.0014089439 0.0014453081 -0.0016111245 0.00096149581 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49997 .49997 m
.49997 .49997 L
s
% Start of user PostScript
-0.0010200692 -0.00093486378 -0.00080557345 -0.00097371504 MAarrowhead1
% End of user PostScript
0 1 .591 r
.21349 .20538 m
.27957 .1995 L
.34386 .20659 L
.40407 .22427 L
.45845 .25014 L
.50576 .28184 L
.54525 .31719 L
.57659 .35416 L
.59983 .39104 L
.61535 .42635 L
.62377 .45894 L
.62588 .48793 L
.62262 .51276 L
.61498 .53309 L
.60397 .54883 L
.59057 .56009 L
.5757 .56714 L
.56019 .57038 L
.54476 .57028 L
.53002 .56738 L
.51645 .56226 L
.50439 .55547 L
.4941 .54755 L
.48569 .539 L
.47921 .53026 L
.4746 .52172 L
.47174 .51368 L
.47048 .50638 L
.47059 .5 L
.47187 .49465 L
.47406 .49036 L
.47694 .48715 L
.48028 .48497 L
.48387 .48374 L
.48753 .48336 L
.4911 .48371 L
.49446 .48465 L
.49749 .48605 L
.50014 .48779 L
.50236 .48973 L
.50413 .49178 L
.50545 .49382 L
.50634 .49579 L
.50683 .4976 L
.50697 .49922 L
.50681 .50062 L
.5064 .50176 L
.50581 .50265 L
.50507 .50329 L
.50425 .5037 L
Mistroke
.50339 .50389 L
.50254 .5039 L
.50172 .50375 L
.50096 .50347 L
.50029 .5031 L
.49971 .50267 L
.49924 .50219 L
.49887 .50171 L
.49861 .50124 L
.49844 .50079 L
.49837 .50038 L
.49837 .50002 L
.49844 .49972 L
.49855 .49948 L
.49871 .4993 L
.49889 .49917 L
.49909 .4991 L
.4993 .49908 L
.49949 .4991 L
.49968 .49915 L
.49985 .49922 L
.5 .49932 L
.50012 .49942 L
.50022 .49954 L
.5003 .49965 L
.50035 .49976 L
.50038 .49986 L
.50039 .49995 L
.50038 .50003 L
.50036 .50009 L
.50032 .50014 L
.50028 .50018 L
.50024 .5002 L
.50019 .50021 L
.50014 .50022 L
.5001 .50021 L
.50006 .50019 L
.50002 .50017 L
.49999 .50015 L
.49996 .50012 L
.49994 .5001 L
.49992 .50007 L
.49991 .50005 L
.49991 .50002 L
.49991 .5 L
.49991 .49999 L
.49992 .49997 L
.49993 .49996 L
.49994 .49995 L
.49995 .49995 L
Mistroke
.49996 .49995 L
.49997 .49995 L
.49998 .49995 L
.49999 .49996 L
.5 .49996 L
.50001 .49997 L
.50001 .49997 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.21349 .20538 m
.27957 .1995 L
s
% Start of user PostScript
-8.5953079 -8.8386304 -6.6128327 -9.0148989 MAarrowhead1
% End of user PostScript
1 .158 0 r
.34386 .20659 m
.40407 .22427 L
s
% Start of user PostScript
-4.6841848 -8.8023656 -2.8778486 -8.271949 MAarrowhead1
% End of user PostScript
1 .473 0 r
.62377 .45894 m
.62588 .48793 L
s
% Start of user PostScript
3.7129671 -1.2319464 3.7764138 -0.36200888 MAarrowhead1
% End of user PostScript
1 .788 0 r
.54476 .57028 m
.53002 .56738 L
s
% Start of user PostScript
1.3428268 2.1083516 0.90059756 2.021535 MAarrowhead1
% End of user PostScript
.897 1 0 r
.47174 .51368 m
.47048 .50638 L
s
% Start of user PostScript
-0.84771544 0.41038879 -0.88571955 0.19147555 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48753 .48336 m
.4911 .48371 L
s
% Start of user PostScript
-0.37399602 -0.49916456 -0.26686505 -0.48882372 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50634 .49579 m
.50683 .4976 L
s
% Start of user PostScript
0.19013547 -0.12643751 0.20492352 -0.071931357 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50339 .50389 m
.50254 .5039 L
s
% Start of user PostScript
0.1018392 0.11670001 0.076168684 0.11690572 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49861 .50124 m
.49844 .50079 L
s
% Start of user PostScript
-0.041738019 0.037079254 -0.046682564 0.023648602 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49909 .4991 m
.4993 .49908 L
s
% Start of user PostScript
-0.027223438 -0.026903206 -0.021143155 -0.027632964 MAarrowhead1
% End of user PostScript
0 1 .995 r
.5003 .49965 m
.50035 .49976 L
s
% Start of user PostScript
0.0089160996 -0.01050381 0.010442818 -0.0072287477 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50024 .5002 m
.50019 .50021 L
s
% Start of user PostScript
0.0071639996 0.0061031946 0.0057418083 0.0064487324 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49994 .5001 m
.49992 .50007 L
s
% Start of user PostScript
-0.0018364839 0.0028987745 -0.0022848714 0.0021086238 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49994 .49995 m
.49995 .49995 L
s
% Start of user PostScript
-0.0018594699 -0.0013584723 -0.0015314316 -0.0014836295 MAarrowhead1
% End of user PostScript
.925 1 0 r
.70762 .82676 m
.6391 .81321 L
.57602 .78931 L
.52003 .75769 L
.47223 .72083 L
.43321 .68106 L
.40312 .64043 L
.38174 .60071 L
.36853 .56334 L
.36269 .52944 L
.36328 .4998 L
.36924 .47493 L
.37947 .45505 L
.39289 .44017 L
.40843 .43006 L
.42514 .42437 L
.44216 .42263 L
.45876 .42425 L
.47434 .42865 L
.48845 .43519 L
.50076 .44327 L
.51106 .45233 L
.51926 .46183 L
.52538 .47134 L
.5295 .48047 L
.53178 .48891 L
.53242 .49644 L
.53166 .50291 L
.52976 .50822 L
.52697 .51234 L
.52356 .51532 L
.51974 .5172 L
.51576 .51809 L
.51178 .51812 L
.50797 .51742 L
.50445 .51613 L
.50132 .5144 L
.49864 .51238 L
.49644 .51019 L
.49474 .50794 L
.49352 .50573 L
.49276 .50365 L
.49241 .50176 L
.49242 .5001 L
.49273 .4987 L
.49328 .49758 L
.49401 .49674 L
.49487 .49616 L
.49579 .49583 L
.49673 .49572 L
Mistroke
.49765 .49579 L
.49852 .49603 L
.49931 .49638 L
.5 .49682 L
.50057 .49732 L
.50104 .49785 L
.50138 .49838 L
.50162 .49888 L
.50175 .49935 L
.50179 .49977 L
.50176 .50014 L
.50166 .50044 L
.50151 .50067 L
.50132 .50084 L
.50111 .50095 L
.50089 .501 L
.50067 .501 L
.50046 .50097 L
.50026 .5009 L
.50008 .50081 L
.49993 .50069 L
.49981 .50057 L
.49971 .50045 L
.49965 .50033 L
.4996 .50021 L
.49958 .5001 L
.49958 .50001 L
.4996 .49993 L
.49963 .49987 L
.49967 .49982 L
.49971 .49979 L
.49976 .49977 L
.49982 .49976 L
.49987 .49977 L
.49991 .49978 L
.49996 .4998 L
.5 .49982 L
.50003 .49985 L
.50006 .49988 L
.50008 .49991 L
.50009 .49994 L
.5001 .49996 L
.5001 .49999 L
.5001 .50001 L
.50009 .50002 L
.50008 .50004 L
.50007 .50005 L
.50006 .50005 L
.50005 .50006 L
.50004 .50006 L
Mistroke
.50003 .50005 L
.50002 .50005 L
.50001 .50004 L
.5 .50004 L
.49999 .50003 L
.49998 .50003 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.70762 .82676 m
.6391 .81321 L
s
% Start of user PostScript
6.228493 9.802682 4.1730153 9.3963151 MAarrowhead1
% End of user PostScript
1 .158 0 r
.57602 .78931 m
.52003 .75769 L
s
% Start of user PostScript
2.2806525 8.6794317 0.60089261 7.730551 MAarrowhead1
% End of user PostScript
1 .473 0 r
.36328 .4998 m
.36924 .47493 L
s
% Start of user PostScript
-4.1016868 -0.0059616467 -3.9228071 -0.75211988 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47434 .42865 m
.48845 .43519 L
s
% Start of user PostScript
-0.76977605 -2.1406229 -0.34650853 -1.9443563 MAarrowhead1
% End of user PostScript
.897 1 0 r
.53242 .49644 m
.53166 .50291 L
s
% Start of user PostScript
0.97254498 -0.10675601 0.94983345 0.087167242 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50797 .51742 m
.50445 .51613 L
s
% Start of user PostScript
0.2389946 0.52247372 0.13346986 0.48387938 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49241 .50176 m
.49242 .5001 L
s
% Start of user PostScript
-0.22774349 0.052741061 -0.22747804 0.0029689137 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49765 .49579 m
.49852 .49603 L
s
% Start of user PostScript
-0.070449654 -0.12617394 -0.044414153 -0.11917308 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50175 .49935 m
.50179 .49977 L
s
% Start of user PostScript
0.052599043 -0.019384918 0.053849893 -0.0067573067 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50067 .501 m
.50046 .50097 L
s
% Start of user PostScript
0.020031986 0.030134042 0.013674951 0.029046083 MAarrowhead1
% End of user PostScript
0 1 .995 r
.4996 .50021 m
.49958 .5001 L
s
% Start of user PostScript
-0.011957982 0.0063037862 -0.012587839 0.0031348502 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49982 .49976 m
.49987 .49977 L
s
% Start of user PostScript
-0.0055444015 -0.007112255 -0.0040086205 -0.0070041833 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50009 .49994 m
.5001 .49996 L
s
% Start of user PostScript
0.0026684869 -0.0019140777 0.002901454 -0.0011271637 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50005 .50006 m
.50004 .50006 L
s
% Start of user PostScript
0.0015021466 0.0016570881 0.0011352061 0.0016702229 MAarrowhead1
% End of user PostScript
1 .612 0 r
.74673 .64173 m
.71022 .66439 L
.67117 .67684 L
.63154 .68022 L
.59301 .67585 L
.55695 .66515 L
.5244 .64956 L
.4961 .6305 L
.4725 .60928 L
.45379 .58709 L
.43993 .56498 L
.43069 .54383 L
.42572 .52431 L
.42451 .50696 L
.42651 .49212 L
.43113 .47997 L
.43777 .47058 L
.44582 .46387 L
.45475 .45968 L
.46406 .45777 L
.47331 .45786 L
.48214 .45963 L
.49027 .46272 L
.49748 .46681 L
.50364 .47157 L
.50866 .4767 L
.51253 .48194 L
.51527 .48706 L
.51697 .49187 L
.51771 .49624 L
.51763 .50006 L
.51686 .50326 L
.51553 .50582 L
.5138 .50773 L
.51179 .50903 L
.50964 .50976 L
.50744 .50998 L
.5053 .50977 L
.50329 .5092 L
.50147 .50835 L
.49989 .50731 L
.49856 .50614 L
.49751 .50491 L
.49672 .50368 L
.49619 .50251 L
.4959 .50142 L
.49582 .50045 L
.49592 .49962 L
.49616 .49893 L
.49652 .4984 L
Mistroke
.49697 .49802 L
.49746 .49778 L
.49797 .49767 L
.49849 .49766 L
.49898 .49775 L
.49943 .49792 L
.49983 .49814 L
.50018 .49841 L
.50046 .49869 L
.50068 .49898 L
.50084 .49926 L
.50093 .49953 L
.50098 .49978 L
.50098 .49999 L
.50094 .50017 L
.50087 .50031 L
.50077 .50042 L
.50066 .5005 L
.50054 .50054 L
.50042 .50055 L
.5003 .50054 L
.50019 .50051 L
.50009 .50047 L
.5 .50041 L
.49993 .50034 L
.49987 .50028 L
.49982 .50021 L
.49979 .50014 L
.49977 .50008 L
.49977 .50003 L
.49977 .49998 L
.49979 .49994 L
.49981 .49991 L
.49983 .49989 L
.49986 .49988 L
.49989 .49987 L
.49991 .49987 L
.49994 .49988 L
.49997 .49988 L
.49999 .4999 L
.50001 .49991 L
.50002 .49993 L
.50004 .49994 L
.50005 .49996 L
.50005 .49997 L
.50005 .49999 L
.50005 .5 L
.50005 .50001 L
.50005 .50002 L
.50004 .50002 L
Mistroke
.50004 .50003 L
.50003 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50003 L
.5 .50002 L
.5 .50002 L
.49999 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.74673 .64173 m
.71022 .66439 L
s
% Start of user PostScript
7.401983 4.2517745 6.3067 4.931677 MAarrowhead1
% End of user PostScript
1 .158 0 r
.67117 .67684 m
.63154 .68022 L
s
% Start of user PostScript
5.1350539 5.3052096 3.9461581 5.4066204 MAarrowhead1
% End of user PostScript
1 .473 0 r
.43993 .56498 m
.43069 .54383 L
s
% Start of user PostScript
-1.8021829 1.9495058 -2.0791542 1.3148146 MAarrowhead1
% End of user PostScript
1 .788 0 r
.45475 .45968 m
.46406 .45777 L
s
% Start of user PostScript
-1.3574039 -1.209685 -1.078229 -1.2667815 MAarrowhead1
% End of user PostScript
.897 1 0 r
.51253 .48194 m
.51527 .48706 L
s
% Start of user PostScript
0.37578486 -0.54190175 0.45819974 -0.38827555 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51179 .50903 m
.50964 .50976 L
s
% Start of user PostScript
0.3537307 0.27090705 0.28905377 0.29275393 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49751 .50491 m
.49672 .50368 L
s
% Start of user PostScript
-0.074783403 0.14732791 -0.098376615 0.1105487 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49697 .49802 m
.49746 .49778 L
s
% Start of user PostScript
-0.091009835 -0.059356215 -0.076253531 -0.066603084 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50046 .49869 m
.50068 .49898 L
s
% Start of user PostScript
0.013840063 -0.039331561 0.02040413 -0.030628307 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50077 .50042 m
.50066 .5005 L
s
% Start of user PostScript
0.023142478 0.012648528 0.019835486 0.014875605 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49993 .50034 m
.49987 .50028 L
s
% Start of user PostScript
-0.0022428744 0.010338531 -0.0040287492 0.0083049321 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49981 .49991 m
.49983 .49989 L
s
% Start of user PostScript
-0.0058202607 -0.0025963906 -0.0050950571 -0.0032483962 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50001 .49991 m
.50002 .49993 L
s
% Start of user PostScript
0.00025882388 -0.0026807193 0.00073588019 -0.0022122042 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50005 .50002 m
.50004 .50002 L
s
% Start of user PostScript
0.0014483443 0.00050472958 0.0012936304 0.00068919948 MAarrowhead1
% End of user PostScript
.689 1 0 r
.23471 .7838 m
.19452 .69087 L
.173 .60523 L
.168 .52913 L
.17709 .46408 L
.19763 .41091 L
.22696 .36984 L
.26251 .34056 L
.30184 .32237 L
.34279 .3142 L
.38344 .31477 L
.42223 .32265 L
.45791 .33636 L
.48954 .35442 L
.51651 .3754 L
.53849 .39799 L
.5554 .42103 L
.56738 .44354 L
.57475 .46469 L
.57794 .48385 L
.5775 .50059 L
.57403 .51461 L
.56816 .5258 L
.56051 .53416 L
.55167 .53981 L
.54218 .54296 L
.53252 .54389 L
.52312 .54292 L
.5143 .54038 L
.50632 .53664 L
.49938 .53203 L
.49357 .52688 L
.48895 .52149 L
.48552 .5161 L
.48321 .51093 L
.48195 .50615 L
.48161 .5019 L
.48206 .49825 L
.48316 .49526 L
.48475 .49294 L
.4867 .49127 L
.48887 .49022 L
.49113 .48973 L
.49339 .48973 L
.49554 .49014 L
.49753 .49088 L
.4993 .49186 L
.50082 .49301 L
.50205 .49426 L
.50301 .49554 L
Mistroke
.50369 .49679 L
.50412 .49796 L
.50431 .49903 L
.5043 .49997 L
.50412 .50076 L
.5038 .50139 L
.50338 .50186 L
.5029 .50219 L
.50237 .50237 L
.50184 .50243 L
.50132 .50238 L
.50083 .50225 L
.50038 .50205 L
.49999 .50179 L
.49966 .50151 L
.4994 .50121 L
.49921 .50091 L
.49908 .50063 L
.499 .50036 L
.49898 .50012 L
.499 .49992 L
.49906 .49975 L
.49915 .49962 L
.49926 .49952 L
.49937 .49946 L
.4995 .49943 L
.49962 .49943 L
.49974 .49945 L
.49986 .49949 L
.49995 .49955 L
.50004 .49961 L
.50011 .49968 L
.50016 .49975 L
.5002 .49982 L
.50023 .49988 L
.50024 .49994 L
.50024 .49999 L
.50023 .50004 L
.50021 .50007 L
.50019 .5001 L
.50016 .50012 L
.50013 .50013 L
.5001 .50013 L
.50007 .50013 L
.50005 .50013 L
.50002 .50011 L
.5 .5001 L
.49998 .50008 L
.49997 .50007 L
.49996 .50005 L
Mistroke
.49995 .50004 L
.49995 .50002 L
.49994 .50001 L
.49994 .5 L
.49995 .49999 L
.49995 .49998 L
.49996 .49997 L
.49996 .49997 L
.49997 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49997 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.23471 .7838 m
.19452 .69087 L
s
% Start of user PostScript
-7.9585954 8.514058 -9.1643978 5.72616 MAarrowhead1
% End of user PostScript
1 .158 0 r
.173 .60523 m
.168 .52913 L
s
% Start of user PostScript
-9.8101355 3.1568519 -9.9599001 0.87378669 MAarrowhead1
% End of user PostScript
1 .473 0 r
.38344 .31477 m
.42223 .32265 L
s
% Start of user PostScript
-3.4966995 -5.5570089 -2.332957 -5.3204248 MAarrowhead1
% End of user PostScript
1 .788 0 r
.57475 .46469 m
.57794 .48385 L
s
% Start of user PostScript
2.2423626 -1.0594227 2.3381309 -0.48446448 MAarrowhead1
% End of user PostScript
.897 1 0 r
.53252 .54389 m
.52312 .54292 L
s
% Start of user PostScript
0.97564538 1.316779 0.69351191 1.2875069 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48321 .51093 m
.48195 .50615 L
s
% Start of user PostScript
-0.5036329 0.32782445 -0.54151324 0.18456156 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49113 .48973 m
.49339 .48973 L
s
% Start of user PostScript
-0.26605398 -0.30813947 -0.19839589 -0.30816419 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50369 .49679 m
.50412 .49796 L
s
% Start of user PostScript
0.11074312 -0.096419505 0.12350497 -0.06109256 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50237 .50237 m
.50184 .50243 L
s
% Start of user PostScript
0.071207083 0.071111457 0.055168018 0.072903622 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49921 .50091 m
.49908 .50063 L
s
% Start of user PostScript
-0.023708813 0.027372028 -0.027666754 0.018751119 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49937 .49946 m
.4995 .49943 L
s
% Start of user PostScript
-0.018758126 -0.016151988 -0.015003048 -0.017029788 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50016 .49975 m
.5002 .49982 L
s
% Start of user PostScript
0.0048981434 -0.007566475 0.0060640097 -0.0054849652 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50016 .50012 m
.50013 .50013 L
s
% Start of user PostScript
0.0048733385 0.0036004834 0.0040062918 0.0039221839 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49997 .50007 m
.49996 .50005 L
s
% Start of user PostScript
-0.00096147985 0.0020479039 -0.0012928153 0.0015508745 MAarrowhead1
% End of user PostScript
.033 0 1 r
.78687 .61496 m
.75349 .64914 L
.71534 .67187 L
.6747 .68408 L
.6336 .68696 L
.59376 .68191 L
.55656 .67039 L
.52307 .65391 L
.49404 .63392 L
.4699 .61178 L
.45085 .58873 L
.43682 .56583 L
.42756 .54397 L
.42269 .52387 L
.4217 .50604 L
.42399 .49082 L
.42896 .47842 L
.43597 .46887 L
.44441 .4621 L
.45372 .45794 L
.46339 .45612 L
.47297 .45635 L
.48209 .45829 L
.49047 .46158 L
.49788 .46588 L
.50418 .47086 L
.50931 .4762 L
.51324 .48164 L
.51601 .48694 L
.5177 .49191 L
.5184 .4964 L
.51826 .50032 L
.51741 .5036 L
.516 .5062 L
.51418 .50814 L
.51208 .50944 L
.50984 .51016 L
.50756 .51036 L
.50535 .5101 L
.50327 .50949 L
.5014 .50859 L
.49978 .5075 L
.49842 .50628 L
.49735 .50501 L
.49655 .50373 L
.49602 .50252 L
.49573 .5014 L
.49566 .5004 L
.49578 .49955 L
.49604 .49885 L
Mistroke
.49642 .49831 L
.49689 .49792 L
.4974 .49768 L
.49793 .49757 L
.49847 .49758 L
.49897 .49768 L
.49944 .49786 L
.49985 .49809 L
.50021 .49837 L
.5005 .49866 L
.50072 .49896 L
.50088 .49926 L
.50097 .49953 L
.50102 .49978 L
.50101 .5 L
.50097 .50019 L
.50089 .50033 L
.50079 .50044 L
.50068 .50052 L
.50055 .50056 L
.50043 .50057 L
.5003 .50056 L
.50019 .50053 L
.50008 .50048 L
.49999 .50042 L
.49992 .50035 L
.49986 .50028 L
.49981 .50021 L
.49978 .50014 L
.49976 .50008 L
.49976 .50003 L
.49977 .49998 L
.49978 .49994 L
.4998 .49991 L
.49983 .49989 L
.49985 .49987 L
.49988 .49987 L
.49991 .49987 L
.49994 .49987 L
.49997 .49988 L
.49999 .49989 L
.50001 .49991 L
.50003 .49992 L
.50004 .49994 L
.50005 .49996 L
.50005 .49997 L
.50006 .49999 L
.50006 .5 L
.50005 .50001 L
.50005 .50002 L
Mistroke
.50004 .50002 L
.50004 .50003 L
.50003 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50003 L
.5 .50002 L
.5 .50002 L
.49999 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.78687 .61496 m
.75349 .64914 L
s
% Start of user PostScript
8.6060308 3.4487493 7.6048222 4.4741857 MAarrowhead1
% End of user PostScript
1 .158 0 r
.71534 .67187 m
.6747 .68408 L
s
% Start of user PostScript
6.4602361 5.156074 5.2410623 5.5223001 MAarrowhead1
% End of user PostScript
1 .473 0 r
.45085 .58873 m
.43682 .56583 L
s
% Start of user PostScript
-1.4746142 2.6619305 -1.895548 1.9749205 MAarrowhead1
% End of user PostScript
1 .788 0 r
.44441 .4621 m
.45372 .45794 L
s
% Start of user PostScript
-1.6676285 -1.1368897 -1.3882656 -1.2619339 MAarrowhead1
% End of user PostScript
.897 1 0 r
.50931 .4762 m
.51324 .48164 L
s
% Start of user PostScript
0.27932302 -0.71390312 0.39724811 -0.55081057 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51418 .50814 m
.51208 .50944 L
s
% Start of user PostScript
0.42535421 0.24425985 0.36242626 0.28334106 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49842 .50628 m
.49735 .50501 L
s
% Start of user PostScript
-0.047375048 0.18839569 -0.079636543 0.15015344 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49642 .49831 m
.49689 .49792 L
s
% Start of user PostScript
-0.10728626 -0.050708783 -0.093399499 -0.062279551 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50021 .49837 m
.5005 .49866 L
s
% Start of user PostScript
0.0062583384 -0.049021552 0.014916015 -0.040176127 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50089 .50033 m
.50079 .50044 L
s
% Start of user PostScript
0.026772876 0.010026188 0.02378616 0.013326714 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49999 .50042 m
.49992 .50035 L
s
% Start of user PostScript
-0.0001896977 0.012595472 -0.0024756576 0.010581086 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49978 .49994 m
.4998 .49991 L
s
% Start of user PostScript
-0.0066117006 -0.0018356227 -0.0059907598 -0.0027513661 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49999 .49989 m
.50001 .49991 L
s
% Start of user PostScript
-0.00028749709 -0.0031988111 0.00030760735 -0.002748368 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50005 .50001 m
.50005 .50002 L
s
% Start of user PostScript
0.00161589 0.00029093271 0.0014928553 0.00053952586 MAarrowhead1
% End of user PostScript
.884 1 0 r
.69092 .42152 m
.69693 .46863 L
.69411 .50943 L
.68398 .54331 L
.66812 .57001 L
.64808 .58963 L
.62533 .60251 L
.60123 .60922 L
.57695 .61049 L
.55348 .60714 L
.53165 .60004 L
.51206 .59008 L
.49513 .57812 L
.48111 .56495 L
.4701 .5513 L
.46205 .53779 L
.45681 .52494 L
.45414 .51315 L
.45373 .50273 L
.45524 .49388 L
.4583 .48669 L
.46253 .48118 L
.46758 .47732 L
.47312 .47498 L
.47884 .47401 L
.48449 .47424 L
.48986 .47547 L
.49476 .47748 L
.49909 .48006 L
.50276 .48303 L
.50573 .4862 L
.508 .48942 L
.50958 .49254 L
.51052 .49545 L
.5109 .49809 L
.51077 .50037 L
.51024 .50228 L
.50938 .50378 L
.50828 .5049 L
.50703 .50564 L
.5057 .50603 L
.50436 .50612 L
.50305 .50595 L
.50184 .50557 L
.50074 .50503 L
.49979 .50438 L
.499 .50365 L
.49838 .50289 L
.49793 .50215 L
.49762 .50143 L
Mistroke
.49747 .50077 L
.49744 .50019 L
.49751 .49969 L
.49768 .49929 L
.49791 .49898 L
.49818 .49876 L
.49849 .49862 L
.49881 .49856 L
.49912 .49857 L
.49942 .49864 L
.49969 .49874 L
.49993 .49889 L
.50014 .49905 L
.50031 .49922 L
.50044 .4994 L
.50053 .49957 L
.50058 .49974 L
.5006 .49988 L
.5006 .50001 L
.50057 .50012 L
.50052 .5002 L
.50046 .50027 L
.50039 .50031 L
.50032 .50033 L
.50025 .50034 L
.50017 .50033 L
.50011 .50031 L
.50005 .50028 L
.49999 .50025 L
.49995 .50021 L
.49991 .50016 L
.49989 .50012 L
.49987 .50008 L
.49986 .50005 L
.49986 .50001 L
.49986 .49998 L
.49987 .49996 L
.49988 .49994 L
.4999 .49993 L
.49992 .49992 L
.49993 .49992 L
.49995 .49992 L
.49997 .49992 L
.49998 .49993 L
.5 .49994 L
.50001 .49995 L
.50002 .49996 L
.50002 .49997 L
.50003 .49998 L
.50003 .49998 L
Mistroke
.50003 .49999 L
.50003 .5 L
.50003 .50001 L
.50003 .50001 L
.50003 .50001 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.69092 .42152 m
.69693 .46863 L
s
% Start of user PostScript
5.72745 -2.3542889 5.9080033 -0.9410098 MAarrowhead1
% End of user PostScript
1 .158 0 r
.69411 .50943 m
.68398 .54331 L
s
% Start of user PostScript
5.8233107 0.28300794 5.5193424 1.2992008 MAarrowhead1
% End of user PostScript
1 .473 0 r
.53165 .60004 m
.51206 .59008 L
s
% Start of user PostScript
0.94954211 3.0012662 0.36172183 2.7024615 MAarrowhead1
% End of user PostScript
1 .788 0 r
.45373 .50273 m
.45524 .49388 L
s
% Start of user PostScript
-1.3880036 0.081949844 -1.3427651 -0.18374727 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48986 .47547 m
.49476 .47748 L
s
% Start of user PostScript
-0.30432922 -0.73595988 -0.15708735 -0.67570874 MAarrowhead1
% End of user PostScript
.581 1 0 r
.5109 .49809 m
.51077 .50037 L
s
% Start of user PostScript
0.32689111 -0.057417422 0.32317973 0.011148873 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50305 .50595 m
.50184 .50557 L
s
% Start of user PostScript
0.091573703 0.17858255 0.055076662 0.16719139 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49747 .50077 m
.49744 .50019 L
s
% Start of user PostScript
-0.07598055 0.023187782 -0.07691056 0.0057036248 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49912 .49857 m
.49942 .49864 L
s
% Start of user PostScript
-0.02642324 -0.042865581 -0.0174702 -0.040940524 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50058 .49974 m
.5006 .49988 L
s
% Start of user PostScript
0.01740066 -0.007885245 0.018082648 -0.0034763775 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50025 .50034 m
.50017 .50033 L
s
% Start of user PostScript
0.0073956376 0.010171858 0.0052223253 0.0099200495 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49987 .50008 m
.49986 .50005 L
s
% Start of user PostScript
-0.0039170396 0.0024587488 -0.0041950945 0.0013588044 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49993 .49992 m
.49995 .49992 L
s
% Start of user PostScript
-0.0020217804 -0.0023840393 -0.0014999062 -0.0023775553 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50003 .49998 m
.50003 .49998 L
s
% Start of user PostScript
0.0008637124 -0.00072685282 0.00095866495 -0.00045528206 MAarrowhead1
% End of user PostScript
1 .716 0 r
.47289 .73736 m
.43084 .69511 L
.3983 .65184 L
.37505 .60945 L
.36053 .56949 L
.35392 .53316 L
.35421 .50134 L
.36028 .47458 L
.37097 .45312 L
.3851 .43699 L
.40156 .42597 L
.41931 .41967 L
.43744 .4176 L
.45516 .41916 L
.47183 .4237 L
.48695 .43056 L
.50016 .4391 L
.51125 .4487 L
.5201 .45881 L
.52673 .46895 L
.53123 .4787 L
.53376 .48774 L
.53453 .49581 L
.53379 .50276 L
.53183 .50848 L
.5289 .51294 L
.52529 .51617 L
.52125 .51824 L
.51701 .51924 L
.51276 .51931 L
.50869 .5186 L
.50493 .51726 L
.50157 .51545 L
.49869 .5133 L
.49632 .51097 L
.49448 .50858 L
.49316 .50623 L
.49232 .504 L
.49193 .50197 L
.49192 .50019 L
.49223 .49869 L
.49281 .49748 L
.49358 .49657 L
.49448 .49594 L
.49546 .49557 L
.49646 .49544 L
.49745 .49551 L
.49838 .49575 L
.49922 .49612 L
.49996 .49659 L
Mistroke
.50058 .49712 L
.50108 .49768 L
.50146 .49824 L
.50171 .49878 L
.50186 .49929 L
.50191 .49974 L
.50188 .50013 L
.50177 .50045 L
.50161 .5007 L
.50142 .50088 L
.50119 .501 L
.50096 .50106 L
.50072 .50107 L
.5005 .50103 L
.50029 .50096 L
.5001 .50086 L
.49994 .50075 L
.4998 .50062 L
.4997 .50048 L
.49963 .50035 L
.49958 .50023 L
.49955 .50012 L
.49955 .50002 L
.49957 .49993 L
.4996 .49986 L
.49964 .49981 L
.49969 .49978 L
.49974 .49976 L
.4998 .49975 L
.49985 .49975 L
.49991 .49976 L
.49995 .49978 L
.5 .49981 L
.50003 .49984 L
.50006 .49987 L
.50008 .4999 L
.50009 .49993 L
.5001 .49996 L
.50011 .49998 L
.5001 .50001 L
.5001 .50002 L
.50009 .50004 L
.50008 .50005 L
.50007 .50006 L
.50005 .50006 L
.50004 .50006 L
.50003 .50006 L
.50002 .50005 L
.50001 .50005 L
.5 .50004 L
Mistroke
.49999 .50003 L
.49998 .50003 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.47289 .73736 m
.43084 .69511 L
s
% Start of user PostScript
-0.81315526 7.1206568 -2.0748887 5.8532771 MAarrowhead1
% End of user PostScript
1 .158 0 r
.3983 .65184 m
.37505 .60945 L
s
% Start of user PostScript
-3.0510855 4.5552956 -3.7485488 3.2835309 MAarrowhead1
% End of user PostScript
1 .473 0 r
.40156 .42597 m
.41931 .41967 L
s
% Start of user PostScript
-2.9531908 -2.2209929 -2.420641 -2.4097878 MAarrowhead1
% End of user PostScript
1 .788 0 r
.5201 .45881 m
.52673 .46895 L
s
% Start of user PostScript
0.60308029 -1.2356116 0.80199739 -0.9315434 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52529 .51617 m
.52125 .51824 L
s
% Start of user PostScript
0.75873856 0.48521975 0.63747029 0.54714917 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49632 .51097 m
.49448 .50858 L
s
% Start of user PostScript
-0.11035728 0.32922992 -0.16554074 0.25737867 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49358 .49657 m
.49448 .49594 L
s
% Start of user PostScript
-0.19268209 -0.10300843 -0.16556769 -0.12191271 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50058 .49712 m
.50108 .49768 L
s
% Start of user PostScript
0.017472102 -0.086395023 0.032451034 -0.069632492 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50161 .5007 m
.50142 .50088 L
s
% Start of user PostScript
0.048398178 0.021033586 0.042469156 0.026542808 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49994 .50075 m
.4998 .50062 L
s
% Start of user PostScript
-0.0018616404 0.022368172 -0.0058551604 0.018513119 MAarrowhead1
% End of user PostScript
0 1 .995 r
.4996 .49986 m
.49964 .49981 L
s
% Start of user PostScript
-0.012028965 -0.0040559229 -0.010768792 -0.005609385 MAarrowhead1
% End of user PostScript
0 .69 1 r
.5 .49981 m
.50003 .49984 L
s
% Start of user PostScript
-0.00014908846 -0.0057209835 0.0008994136 -0.0048488796 MAarrowhead1
% End of user PostScript
0 .375 1 r
.5001 .50002 m
.50009 .50004 L
s
% Start of user PostScript
0.0029587686 0.0007109354 0.0027010241 0.0011381065 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50001 .50005 m
.5 .50004 L
s
% Start of user PostScript
0.00018635491 0.0014467208 -0.000085233632 0.0012532596 MAarrowhead1
% End of user PostScript
0 1 .928 r
.29076 .25239 m
.34493 .2532 L
.39661 .26375 L
.44412 .28205 L
.48624 .30613 L
.52215 .3341 L
.5514 .36421 L
.57391 .39492 L
.58985 .4249 L
.59963 .45307 L
.60386 .47859 L
.60326 .50087 L
.59862 .51954 L
.59079 .53444 L
.58058 .54556 L
.56879 .55308 L
.55614 .55726 L
.54328 .55849 L
.53075 .55718 L
.519 .55379 L
.50838 .5488 L
.49913 .54265 L
.4914 .53579 L
.48525 .5286 L
.48068 .52142 L
.47762 .51453 L
.47594 .50817 L
.4755 .5025 L
.4761 .49765 L
.47757 .49366 L
.47969 .49057 L
.48229 .48836 L
.48518 .48696 L
.4882 .48631 L
.4912 .48631 L
.49408 .48686 L
.49673 .48785 L
.49908 .48916 L
.50109 .4907 L
.50274 .49236 L
.50401 .49406 L
.50492 .49572 L
.50549 .49729 L
.50574 .49872 L
.50573 .49997 L
.50549 .50101 L
.50506 .50185 L
.50451 .50248 L
.50386 .50291 L
.50316 .50316 L
Mistroke
.50245 .50324 L
.50175 .50317 L
.5011 .50299 L
.5005 .50272 L
.49999 .50239 L
.49955 .50201 L
.49921 .50161 L
.49895 .50121 L
.49877 .50083 L
.49867 .50048 L
.49864 .50016 L
.49867 .49989 L
.49875 .49966 L
.49887 .49949 L
.49901 .49936 L
.49917 .49928 L
.49933 .49924 L
.4995 .49924 L
.49966 .49927 L
.49981 .49932 L
.49994 .49939 L
.50005 .49948 L
.50015 .49957 L
.50022 .49966 L
.50027 .49976 L
.5003 .49984 L
.50032 .49992 L
.50032 .49999 L
.50031 .50005 L
.50028 .5001 L
.50025 .50014 L
.50022 .50016 L
.50018 .50017 L
.50014 .50018 L
.5001 .50018 L
.50006 .50017 L
.50003 .50015 L
.5 .50013 L
.49998 .50011 L
.49996 .50009 L
.49994 .50007 L
.49993 .50005 L
.49993 .50003 L
.49992 .50001 L
.49993 .49999 L
.49993 .49998 L
.49994 .49997 L
.49994 .49997 L
.49995 .49996 L
.49996 .49996 L
Mistroke
.49997 .49996 L
.49998 .49996 L
.49999 .49996 L
.5 .49997 L
.5 .49997 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.29076 .25239 m
.34493 .2532 L
s
% Start of user PostScript
-6.2771831 -7.4282443 -4.6520831 -7.4039747 MAarrowhead1
% End of user PostScript
1 .158 0 r
.39661 .26375 m
.44412 .28205 L
s
% Start of user PostScript
-3.1018461 -7.0875187 -1.6764469 -6.5384397 MAarrowhead1
% End of user PostScript
1 .473 0 r
.60386 .47859 m
.60326 .50087 L
s
% Start of user PostScript
3.1158277 -0.64225721 3.0977504 0.0262243 MAarrowhead1
% End of user PostScript
1 .788 0 r
.53075 .55718 m
.519 .55379 L
s
% Start of user PostScript
0.9224366 1.7152892 0.57002352 1.6136852 MAarrowhead1
% End of user PostScript
.897 1 0 r
.47594 .50817 m
.4755 .5025 L
s
% Start of user PostScript
-0.72171688 0.24510069 -0.73507645 0.075118258 MAarrowhead1
% End of user PostScript
.581 1 0 r
.4912 .48631 m
.49408 .48686 L
s
% Start of user PostScript
-0.2639588 -0.41059325 -0.17773024 -0.39413203 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50549 .49729 m
.50574 .49872 L
s
% Start of user PostScript
0.1646279 -0.081199959 0.17228189 -0.038450558 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50245 .50324 m
.50175 .50317 L
s
% Start of user PostScript
0.073414737 0.097145722 0.052538008 0.09524777 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49877 .50083 m
.49867 .50048 L
s
% Start of user PostScript
-0.03688502 0.02493518 -0.039827962 0.014297351 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49933 .49924 m
.4995 .49924 L
s
% Start of user PostScript
-0.019968693 -0.022695161 -0.014969345 -0.022764962 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50027 .49976 m
.5003 .49984 L
s
% Start of user PostScript
0.0080861518 -0.0072963672 0.0090646307 -0.0046766398 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50018 .50017 m
.50014 .50018 L
s
% Start of user PostScript
0.0053330407 0.0052276663 0.0041496868 0.0053773278 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49994 .50007 m
.49993 .50005 L
s
% Start of user PostScript
-0.0017243913 0.0020635636 -0.0020255095 0.0014251134 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49995 .49996 m
.49996 .49996 L
s
% Start of user PostScript
-0.0014022938 -0.0011847965 -0.0011257064 -0.0012539815 MAarrowhead1
% End of user PostScript
1 .255 0 r
.82161 .45241 m
.81634 .51847 L
.79926 .57319 L
.77296 .61619 L
.73996 .64765 L
.70267 .66815 L
.66326 .67863 L
.62365 .68029 L
.58545 .67447 L
.54996 .66261 L
.51818 .64615 L
.49077 .62649 L
.46813 .60493 L
.4504 .58263 L
.4375 .56061 L
.42917 .5397 L
.42501 .52056 L
.42452 .50367 L
.42712 .48934 L
.43222 .47774 L
.43921 .4689 L
.44751 .46271 L
.45658 .45901 L
.46593 .45755 L
.47514 .45802 L
.48386 .46009 L
.49183 .46342 L
.49885 .46768 L
.50479 .47255 L
.50958 .47774 L
.51322 .48298 L
.51574 .48806 L
.51724 .49281 L
.5178 .49708 L
.51756 .50078 L
.51666 .50385 L
.51523 .50628 L
.51343 .50807 L
.51138 .50925 L
.5092 .50987 L
.507 .50999 L
.50488 .50969 L
.5029 .50906 L
.50113 .50816 L
.49959 .50709 L
.49832 .5059 L
.49732 .50466 L
.49658 .50344 L
.4961 .50228 L
.49586 .50121 L
Mistroke
.49582 .50027 L
.49595 .49946 L
.49622 .49881 L
.4966 .49831 L
.49706 .49796 L
.49756 .49774 L
.49808 .49765 L
.49859 .49767 L
.49907 .49778 L
.49952 .49796 L
.49991 .49819 L
.50024 .49846 L
.50051 .49875 L
.50072 .49904 L
.50086 .49932 L
.50095 .49958 L
.50098 .49982 L
.50097 .50003 L
.50093 .5002 L
.50085 .50034 L
.50075 .50044 L
.50064 .50051 L
.50052 .50054 L
.5004 .50055 L
.50028 .50054 L
.50017 .5005 L
.50007 .50046 L
.49998 .5004 L
.49991 .50033 L
.49985 .50026 L
.49981 .5002 L
.49979 .50013 L
.49977 .50007 L
.49977 .50002 L
.49977 .49997 L
.49979 .49994 L
.49981 .49991 L
.49984 .49989 L
.49986 .49988 L
.49989 .49987 L
.49992 .49987 L
.49995 .49988 L
.49997 .49989 L
.49999 .4999 L
.50001 .49991 L
.50003 .49993 L
.50004 .49995 L
.50005 .49996 L
.50005 .49998 L
.50005 .49999 L
Mistroke
.50005 .5 L
.50005 .50001 L
.50005 .50002 L
.50004 .50002 L
.50004 .50003 L
.50003 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.5 .50003 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.82161 .45241 m
.81634 .51847 L
s
% Start of user PostScript
9.6483994 -1.4276124 9.4902051 0.55418111 MAarrowhead1
% End of user PostScript
1 .158 0 r
.79926 .57319 m
.77296 .61619 L
s
% Start of user PostScript
8.9778973 2.1956501 8.1888135 3.4857893 MAarrowhead1
% End of user PostScript
1 .473 0 r
.51818 .64615 m
.49077 .62649 L
s
% Start of user PostScript
0.5453977 4.3845377 -0.27685815 3.7946896 MAarrowhead1
% End of user PostScript
1 .788 0 r
.42712 .48934 m
.43222 .47774 L
s
% Start of user PostScript
-2.1863479 -0.31976612 -2.033334 -0.66773222 MAarrowhead1
% End of user PostScript
.897 1 0 r
.49183 .46342 m
.49885 .46768 L
s
% Start of user PostScript
-0.24503132 -1.0973805 -0.034529415 -0.96951831 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51756 .50078 m
.51666 .50385 L
s
% Start of user PostScript
0.52675839 0.023371724 0.49966824 0.1156436 MAarrowhead1
% End of user PostScript
.266 1 0 r
.5029 .50906 m
.50113 .50816 L
s
% Start of user PostScript
0.087055959 0.27179233 0.033777198 0.24492701 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49582 .50027 m
.49595 .49946 L
s
% Start of user PostScript
-0.12549562 0.0079779465 -0.12150896 -0.01613428 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49907 .49778 m
.49952 .49796 L
s
% Start of user PostScript
-0.027812574 -0.066619813 -0.014472634 -0.061213978 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50098 .49982 m
.50097 .50003 L
s
% Start of user PostScript
0.029540685 -0.0053355181 0.029232029 0.00088379342 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50028 .50054 m
.50017 .5005 L
s
% Start of user PostScript
0.0083520213 0.016158489 0.0050468275 0.015139864 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49977 .50007 m
.49977 .50002 L
s
% Start of user PostScript
-0.0068623797 0.0021326674 -0.0069533708 0.00054750415 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49992 .49987 m
.49995 .49988 L
s
% Start of user PostScript
-0.002406533 -0.0038768105 -0.0015960826 -0.0037057637 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50005 .49998 m
.50005 .49999 L
s
% Start of user PostScript
0.0015705719 -0.00072191403 0.001633985 -0.00032236976 MAarrowhead1
% End of user PostScript
0 .298 1 r
.55622 .65577 m
.52541 .64153 L
.49853 .62391 L
.47602 .60416 L
.45809 .58342 L
.44471 .56268 L
.43569 .54275 L
.43069 .52432 L
.42927 .50787 L
.4309 .49375 L
.43503 .48215 L
.4411 .47312 L
.44855 .46662 L
.45686 .46249 L
.46556 .46053 L
.47424 .46046 L
.48256 .46198 L
.49024 .46478 L
.49708 .46854 L
.50294 .47295 L
.50773 .47774 L
.51145 .48265 L
.51412 .48746 L
.51579 .492 L
.51656 .49614 L
.51655 .49976 L
.51587 .50281 L
.51467 .50526 L
.51308 .50711 L
.51122 .50837 L
.50921 .5091 L
.50715 .50935 L
.50514 .50918 L
.50324 .50867 L
.50152 .5079 L
.50002 .50694 L
.49875 .50585 L
.49774 .5047 L
.49698 .50355 L
.49647 .50244 L
.49618 .50142 L
.49608 .5005 L
.49616 .49971 L
.49638 .49905 L
.49671 .49854 L
.49712 .49817 L
.49758 .49794 L
.49806 .49782 L
.49854 .49781 L
.499 .49789 L
Mistroke
.49943 .49804 L
.49981 .49824 L
.50014 .49848 L
.50041 .49875 L
.50062 .49902 L
.50077 .49929 L
.50087 .49954 L
.50092 .49977 L
.50092 .49997 L
.50088 .50014 L
.50082 .50028 L
.50073 .50039 L
.50063 .50046 L
.50052 .5005 L
.5004 .50052 L
.50029 .50051 L
.50019 .50048 L
.50009 .50044 L
.50001 .50039 L
.49994 .50033 L
.49988 .50026 L
.49984 .5002 L
.49981 .50014 L
.49979 .50008 L
.49978 .50003 L
.49979 .49999 L
.4998 .49995 L
.49982 .49992 L
.49984 .4999 L
.49986 .49989 L
.49989 .49988 L
.49992 .49988 L
.49994 .49988 L
.49997 .49989 L
.49999 .4999 L
.50001 .49992 L
.50002 .49993 L
.50003 .49994 L
.50004 .49996 L
.50005 .49997 L
.50005 .49999 L
.50005 .5 L
.50005 .50001 L
.50005 .50002 L
.50004 .50002 L
.50004 .50003 L
.50003 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
Mistroke
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.55622 .65577 m
.52541 .64153 L
s
% Start of user PostScript
1.6864995 4.6732007 0.76220275 4.245823 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49853 .62391 m
.47602 .60416 L
s
% Start of user PostScript
-0.044184886 3.7172686 -0.71934571 3.1249174 MAarrowhead1
% End of user PostScript
1 .473 0 r
.43503 .48215 m
.4411 .47312 L
s
% Start of user PostScript
-1.9490703 -0.53558179 -1.7670322 -0.80640611 MAarrowhead1
% End of user PostScript
1 .788 0 r
.49708 .46854 m
.50294 .47295 L
s
% Start of user PostScript
-0.087645711 -0.94374523 0.088050425 -0.81136563 MAarrowhead1
% End of user PostScript
.897 1 0 r
.51587 .50281 m
.51467 .50526 L
s
% Start of user PostScript
0.4762036 0.084358743 0.44019645 0.15783608 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50152 .5079 m
.50002 .50694 L
s
% Start of user PostScript
0.045689184 0.23698974 0.00054259143 0.20806022 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49616 .49971 m
.49638 .49905 L
s
% Start of user PostScript
-0.1151204 -0.0088208251 -0.10852367 -0.028402738 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49943 .49804 m
.49981 .49824 L
s
% Start of user PostScript
-0.017087099 -0.058886916 -0.0056205677 -0.05274301 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50092 .49997 m
.50088 .50014 L
s
% Start of user PostScript
0.027524447 -0.0008020303 0.026477443 0.0043374351 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50019 .50048 m
.50009 .50044 L
s
% Start of user PostScript
0.0056052144 0.014480785 0.0027246679 0.013225559 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49978 .50003 m
.49979 .49999 L
s
% Start of user PostScript
-0.0065040553 0.0009299013 -0.0063915025 -0.00040093729 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49994 .49988 m
.49997 .49989 L
s
% Start of user PostScript
-0.0017110625 -0.0035239035 -0.00099503797 -0.0032816534 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50005 .49999 m
.50005 .5 L
s
% Start of user PostScript
0.001517372 -0.00040747321 0.0015258177 -0.000067044713 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50002 .50003 m
.50001 .50003 L
s
% Start of user PostScript
0.00049865847 0.00084838278 0.00032251601 0.00080585611 MAarrowhead1
% End of user PostScript
1 0 .706 r
.33993 .82915 m
.28691 .74826 L
.25093 .67042 L
.23069 .59827 L
.22446 .53377 L
.23025 .47827 L
.2459 .43256 L
.2692 .39688 L
.29799 .37105 L
.33024 .35452 L
.36409 .34647 L
.39795 .34585 L
.43045 .35149 L
.46051 .36216 L
.48733 .37664 L
.51035 .39372 L
.52926 .41231 L
.54396 .43143 L
.55455 .45021 L
.56125 .46797 L
.56443 .48416 L
.56452 .49839 L
.56202 .51039 L
.55744 .52006 L
.55129 .52737 L
.54409 .53241 L
.53627 .53534 L
.52826 .53639 L
.52041 .53582 L
.513 .53391 L
.50626 .53095 L
.50035 .52722 L
.49538 .52301 L
.49139 .51855 L
.48838 .51406 L
.48632 .50974 L
.48514 .50572 L
.48475 .50211 L
.48502 .499 L
.48585 .49643 L
.48712 .49441 L
.48869 .49295 L
.49047 .492 L
.49234 .49152 L
.49422 .49146 L
.49602 .49175 L
.4977 .49232 L
.4992 .49311 L
.50049 .49404 L
.50155 .49507 L
Mistroke
.50238 .49613 L
.50299 .49717 L
.50337 .49816 L
.50356 .49906 L
.50358 .49986 L
.50345 .50053 L
.5032 .50108 L
.50287 .50149 L
.50247 .50178 L
.50204 .50195 L
.5016 .50201 L
.50116 .50199 L
.50075 .50189 L
.50037 .50173 L
.50004 .50152 L
.49976 .50129 L
.49954 .50104 L
.49937 .5008 L
.49925 .50056 L
.49918 .50033 L
.49916 .50013 L
.49917 .49996 L
.49921 .49981 L
.49928 .4997 L
.49937 .49961 L
.49946 .49956 L
.49957 .49953 L
.49967 .49953 L
.49977 .49954 L
.49987 .49957 L
.49995 .49961 L
.50002 .49967 L
.50008 .49972 L
.50013 .49978 L
.50016 .49984 L
.50019 .49989 L
.5002 .49994 L
.5002 .49999 L
.50019 .50003 L
.50018 .50006 L
.50016 .50008 L
.50014 .5001 L
.50011 .50011 L
.50009 .50011 L
.50007 .50011 L
.50004 .50011 L
.50002 .5001 L
.5 .50009 L
.49999 .50007 L
.49998 .50006 L
Mistroke
.49997 .50005 L
.49996 .50003 L
.49995 .50002 L
.49995 .50001 L
.49995 .5 L
.49996 .49999 L
.49996 .49998 L
.49996 .49998 L
.49997 .49998 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.33993 .82915 m
.28691 .74826 L
s
% Start of user PostScript
-4.8021669 9.87454 -6.3925923 7.4477158 MAarrowhead1
% End of user PostScript
1 .158 0 r
.25093 .67042 m
.23069 .59827 L
s
% Start of user PostScript
-7.4720483 5.1126691 -8.0794001 2.9480437 MAarrowhead1
% End of user PostScript
1 .473 0 r
.36409 .34647 m
.39795 .34585 L
s
% Start of user PostScript
-4.0772396 -4.6059753 -3.0615573 -4.6246221 MAarrowhead1
% End of user PostScript
1 .788 0 r
.55455 .45021 m
.56125 .46797 L
s
% Start of user PostScript
1.6364463 -1.4936387 1.8375686 -0.96079141 MAarrowhead1
% End of user PostScript
.897 1 0 r
.53627 .53534 m
.52826 .53639 L
s
% Start of user PostScript
1.0881708 1.0603038 0.84787497 1.0918418 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48838 .51406 m
.48632 .50974 L
s
% Start of user PostScript
-0.3485267 0.42193387 -0.41027176 0.29212985 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49047 .492 m
.49234 .49152 L
s
% Start of user PostScript
-0.2859605 -0.24013546 -0.22982601 -0.25447531 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50238 .49613 m
.50299 .49717 L
s
% Start of user PostScript
0.071487965 -0.11618844 0.089552172 -0.084904159 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50247 .50178 m
.50204 .50195 L
s
% Start of user PostScript
0.074131298 0.053342391 0.061201998 0.058460235 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49954 .50104 m
.49937 .5008 L
s
% Start of user PostScript
-0.013880767 0.031348613 -0.018989028 0.023892754 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49937 .49961 m
.49946 .49956 L
s
% Start of user PostScript
-0.01898234 -0.011569141 -0.016052279 -0.013208141 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50008 .49972 m
.50013 .49978 L
s
% Start of user PostScript
0.0024632412 -0.0083153883 0.0038710617 -0.0065596611 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50016 .50008 m
.50014 .5001 L
s
% Start of user PostScript
0.0048055246 0.0024325036 0.0041541573 0.0029254424 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49999 .50007 m
.49998 .50006 L
s
% Start of user PostScript
-0.00036446892 0.0021735326 -0.00074456517 0.0017654977 MAarrowhead1
% End of user PostScript
0 1 .709 r
.52338 .68512 m
.48865 .66028 L
.45995 .63302 L
.43746 .60481 L
.42108 .57695 L
.41048 .55048 L
.40517 .52624 L
.4045 .50484 L
.40776 .48668 L
.41418 .47198 L
.42301 .46075 L
.43349 .4529 L
.44496 .44819 L
.45678 .4463 L
.46843 .44687 L
.47948 .44947 L
.48957 .45368 L
.49846 .45906 L
.50598 .46521 L
.51206 .47177 L
.51668 .47841 L
.51989 .48484 L
.52179 .49084 L
.52251 .49625 L
.52222 .50094 L
.52108 .50484 L
.51929 .50792 L
.51701 .51019 L
.51442 .51169 L
.51166 .51247 L
.50889 .51264 L
.5062 .51227 L
.5037 .51147 L
.50145 .51034 L
.4995 .50898 L
.49789 .50748 L
.49662 .50592 L
.49568 .50437 L
.49508 .5029 L
.49476 .50154 L
.49471 .50035 L
.49487 .49933 L
.49522 .4985 L
.4957 .49787 L
.49627 .49742 L
.49691 .49714 L
.49756 .49703 L
.49821 .49705 L
.49882 .49719 L
.49938 .49742 L
Mistroke
.49988 .49771 L
.5003 .49805 L
.50065 .49841 L
.50091 .49878 L
.50109 .49914 L
.5012 .49947 L
.50125 .49977 L
.50123 .50003 L
.50117 .50025 L
.50108 .50043 L
.50095 .50056 L
.50081 .50064 L
.50066 .50069 L
.5005 .5007 L
.50035 .50068 L
.50021 .50064 L
.50009 .50058 L
.49998 .5005 L
.49989 .50042 L
.49982 .50033 L
.49976 .50025 L
.49973 .50017 L
.49971 .50009 L
.49971 .50002 L
.49972 .49997 L
.49973 .49992 L
.49976 .49988 L
.49979 .49986 L
.49983 .49984 L
.49986 .49984 L
.4999 .49984 L
.49993 .49984 L
.49996 .49986 L
.49999 .49987 L
.50002 .49989 L
.50003 .49991 L
.50005 .49993 L
.50006 .49995 L
.50007 .49997 L
.50007 .49999 L
.50007 .5 L
.50007 .50001 L
.50006 .50002 L
.50005 .50003 L
.50005 .50004 L
.50004 .50004 L
.50003 .50004 L
.50002 .50004 L
.50001 .50004 L
.50001 .50003 L
Mistroke
.5 .50003 L
.49999 .50002 L
.49999 .50002 L
.49999 .50001 L
.49999 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.52338 .68512 m
.48865 .66028 L
s
% Start of user PostScript
0.70141228 5.5535284 -0.34053025 4.8083482 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45995 .63302 m
.43746 .60481 L
s
% Start of user PostScript
-1.2015785 3.990517 -1.8763408 3.1444033 MAarrowhead1
% End of user PostScript
1 .473 0 r
.42301 .46075 m
.43349 .4529 L
s
% Start of user PostScript
-2.3098201 -1.1775178 -1.9952203 -1.4131469 MAarrowhead1
% End of user PostScript
1 .788 0 r
.50598 .46521 m
.51206 .47177 L
s
% Start of user PostScript
0.17952517 -1.0435826 0.3618251 -0.84684654 MAarrowhead1
% End of user PostScript
.897 1 0 r
.51929 .50792 m
.51701 .51019 L
s
% Start of user PostScript
0.5786711 0.23761062 0.51030851 0.30566266 MAarrowhead1
% End of user PostScript
.581 1 0 r
.4995 .50898 m
.49789 .50748 L
s
% Start of user PostScript
-0.015013767 0.26935748 -0.06342467 0.22428355 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49522 .4985 m
.4957 .49787 L
s
% Start of user PostScript
-0.14345761 -0.044975817 -0.12904717 -0.064036102 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49988 .49771 m
.5003 .49805 L
s
% Start of user PostScript
-0.0035506151 -0.068696635 0.0091159329 -0.058545196 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50117 .50025 m
.50108 .50043 L
s
% Start of user PostScript
0.035196697 0.0076177187 0.032283526 0.012831166 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50009 .50058 m
.49998 .5005 L
s
% Start of user PostScript
0.0026550541 0.01732552 -0.00061576304 0.015085789 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49972 .49997 m
.49973 .49992 L
s
% Start of user PostScript
-0.0085451639 -0.0010025584 -0.0079921513 -0.0024014156 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49996 .49986 m
.49999 .49987 L
s
% Start of user PostScript
-0.0010867568 -0.0043231083 -0.00025222383 -0.0038415211 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50007 .5 m
.50007 .50001 L
s
% Start of user PostScript
0.002052267 0.000028659106 0.0019580883 0.00039796125 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50001 .50004 m
.50001 .50003 L
s
% Start of user PostScript
0.00037174993 0.0010675143 0.00016119513 0.00096742765 MAarrowhead1
% End of user PostScript
0 .635 1 r
.69991 .60301 m
.67248 .62323 L
.64256 .63528 L
.61174 .63998 L
.5814 .63833 L
.55267 .63141 L
.52646 .62035 L
.50339 .60625 L
.48389 .59017 L
.46816 .57306 L
.45623 .55578 L
.44797 .53904 L
.44312 .52343 L
.44132 .50938 L
.44215 .49722 L
.44517 .48712 L
.44989 .47916 L
.45586 .4733 L
.46263 .46946 L
.46982 .46745 L
.47705 .46707 L
.48404 .46807 L
.49055 .47018 L
.49639 .47315 L
.50144 .47671 L
.50562 .48063 L
.5089 .4847 L
.5113 .48873 L
.51287 .49256 L
.51366 .49607 L
.51379 .49918 L
.51334 .50182 L
.51243 .50396 L
.51117 .5056 L
.50966 .50676 L
.50801 .50746 L
.50631 .50774 L
.50463 .50768 L
.50303 .50731 L
.50156 .50671 L
.50027 .50594 L
.49918 .50506 L
.49829 .50411 L
.49762 .50316 L
.49715 .50223 L
.49686 .50136 L
.49675 .50057 L
.49679 .49989 L
.49695 .49932 L
.4972 .49887 L
Mistroke
.49753 .49854 L
.4979 .49832 L
.4983 .4982 L
.4987 .49818 L
.49909 .49823 L
.49945 .49834 L
.49978 .4985 L
.50006 .4987 L
.5003 .49891 L
.50048 .49914 L
.50062 .49936 L
.50071 .49957 L
.50075 .49977 L
.50076 .49994 L
.50074 .50009 L
.50069 .50021 L
.50062 .5003 L
.50054 .50037 L
.50045 .50041 L
.50036 .50043 L
.50026 .50043 L
.50017 .50041 L
.50009 .50037 L
.50002 .50033 L
.49996 .50028 L
.49991 .50023 L
.49987 .50018 L
.49984 .50013 L
.49983 .50008 L
.49982 .50003 L
.49982 .5 L
.49983 .49996 L
.49984 .49994 L
.49986 .49992 L
.49988 .49991 L
.4999 .4999 L
.49993 .4999 L
.49995 .4999 L
.49997 .49991 L
.49999 .49992 L
.5 .49993 L
.50002 .49994 L
.50003 .49995 L
.50003 .49996 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .5 L
.50004 .50001 L
.50003 .50002 L
Mistroke
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.69991 .60301 m
.67248 .62323 L
s
% Start of user PostScript
5.9972909 3.090405 5.1744322 3.6970033 MAarrowhead1
% End of user PostScript
1 .158 0 r
.64256 .63528 m
.61174 .63998 L
s
% Start of user PostScript
4.2767538 4.0583744 3.3521651 4.1994367 MAarrowhead1
% End of user PostScript
1 .473 0 r
.45623 .55578 m
.44797 .53904 L
s
% Start of user PostScript
-1.3129552 1.6733025 -1.5608242 1.1711364 MAarrowhead1
% End of user PostScript
1 .788 0 r
.46263 .46946 m
.46982 .46745 L
s
% Start of user PostScript
-1.1210152 -0.91618356 -0.90554627 -0.97635774 MAarrowhead1
% End of user PostScript
.897 1 0 r
.5089 .4847 m
.5113 .48873 L
s
% Start of user PostScript
0.2670942 -0.45895196 0.33911169 -0.3381616 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50966 .50676 m
.50801 .50746 L
s
% Start of user PostScript
0.28994276 0.20272428 0.24044985 0.22367 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49829 .50411 m
.49762 .50316 L
s
% Start of user PostScript
-0.051205623 0.12342554 -0.07146719 0.094697987 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49753 .49854 m
.4979 .49832 L
s
% Start of user PostScript
-0.07408787 -0.043751013 -0.062907459 -0.050368579 MAarrowhead1
% End of user PostScript
0 1 .364 r
.5003 .49891 m
.50048 .49914 L
s
% Start of user PostScript
0.0088813987 -0.032648339 0.014443102 -0.025898783 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50062 .5003 m
.50054 .50037 L
s
% Start of user PostScript
0.018718872 0.0091382244 0.016243006 0.011111342 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49996 .50028 m
.49991 .50023 L
s
% Start of user PostScript
-0.0012437327 0.0085129937 -0.0027404071 0.0069483311 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49984 .49994 m
.49986 .49992 L
s
% Start of user PostScript
-0.0046788979 -0.0018230564 -0.0041440262 -0.0023887277 MAarrowhead1
% End of user PostScript
0 .375 1 r
.5 .49993 m
.50002 .49994 L
s
% Start of user PostScript
0.00007014385 -0.0021914489 0.0004662614 -0.0018342072 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50004 .50001 m
.50003 .50002 L
s
% Start of user PostScript
0.0011573484 0.00033876436 0.0010454776 0.0004963187 MAarrowhead1
% End of user PostScript
0 1 .753 r
.36043 .79038 m
.31359 .71931 L
.28172 .65089 L
.2637 .58741 L
.25802 .53063 L
.26293 .48174 L
.27653 .44143 L
.29689 .40994 L
.3221 .3871 L
.35037 .37244 L
.38009 .36524 L
.40984 .36458 L
.43841 .36944 L
.46486 .37875 L
.48847 .39141 L
.50875 .40638 L
.52542 .42269 L
.5384 .43947 L
.54776 .45598 L
.55371 .4716 L
.55656 .48585 L
.55668 .49837 L
.55452 .50895 L
.55053 .51748 L
.54516 .52393 L
.53884 .5284 L
.53198 .53101 L
.52495 .53196 L
.51805 .53148 L
.51153 .52982 L
.5056 .52723 L
.5004 .52397 L
.49601 .52028 L
.49249 .51636 L
.48984 .51242 L
.48802 .50862 L
.48697 .50508 L
.4866 .50191 L
.48684 .49917 L
.48756 .4969 L
.48866 .49512 L
.49004 .49382 L
.4916 .49298 L
.49324 .49255 L
.49489 .49249 L
.49648 .49274 L
.49795 .49324 L
.49927 .49393 L
.50041 .49475 L
.50135 .49565 L
Mistroke
.50208 .49658 L
.50261 .4975 L
.50296 .49837 L
.50313 .49916 L
.50314 .49986 L
.50303 .50046 L
.50282 .50094 L
.50252 .5013 L
.50218 .50156 L
.5018 .50171 L
.50141 .50177 L
.50103 .50175 L
.50066 .50166 L
.50033 .50152 L
.50004 .50134 L
.4998 .50114 L
.4996 .50092 L
.49945 .5007 L
.49934 .50049 L
.49928 .50029 L
.49926 .50012 L
.49927 .49996 L
.49931 .49984 L
.49937 .49974 L
.49944 .49966 L
.49953 .49961 L
.49962 .49959 L
.49971 .49958 L
.4998 .4996 L
.49988 .49962 L
.49995 .49966 L
.50002 .49971 L
.50007 .49976 L
.50011 .49981 L
.50014 .49986 L
.50016 .49991 L
.50017 .49995 L
.50017 .49999 L
.50017 .50002 L
.50016 .50005 L
.50014 .50007 L
.50012 .50009 L
.5001 .50009 L
.50008 .5001 L
.50006 .5001 L
.50004 .50009 L
.50002 .50008 L
.5 .50008 L
.49999 .50006 L
.49998 .50005 L
Mistroke
.49997 .50004 L
.49996 .50003 L
.49996 .50002 L
.49996 .50001 L
.49996 .5 L
.49996 .49999 L
.49996 .49999 L
.49997 .49998 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.36043 .79038 m
.31359 .71931 L
s
% Start of user PostScript
-4.1870883 8.711376 -5.5923126 6.5794175 MAarrowhead1
% End of user PostScript
1 .158 0 r
.28172 .65089 m
.2637 .58741 L
s
% Start of user PostScript
-6.548303 4.5266211 -7.0889512 2.6223685 MAarrowhead1
% End of user PostScript
1 .473 0 r
.38009 .36524 m
.40984 .36458 L
s
% Start of user PostScript
-3.5972074 -4.0428976 -2.7048937 -4.0626178 MAarrowhead1
% End of user PostScript
1 .788 0 r
.54776 .45598 m
.55371 .4716 L
s
% Start of user PostScript
1.4329232 -1.3206528 1.6113592 -0.85206692 MAarrowhead1
% End of user PostScript
.897 1 0 r
.53198 .53101 m
.52495 .53196 L
s
% Start of user PostScript
0.9595065 0.9301964 0.74848607 0.9587502 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48984 .51242 m
.48802 .50862 L
s
% Start of user PostScript
-0.30484354 0.37269807 -0.35951414 0.25858984 MAarrowhead1
% End of user PostScript
.266 1 0 r
.4916 .49298 m
.49324 .49255 L
s
% Start of user PostScript
-0.25202374 -0.21054065 -0.2027508 -0.22335104 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50208 .49658 m
.50261 .4975 L
s
% Start of user PostScript
0.062431613 -0.10255078 0.078404371 -0.075059706 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50218 .50156 m
.5018 .50171 L
s
% Start of user PostScript
0.065304723 0.046733897 0.053961718 0.051282802 MAarrowhead1
% End of user PostScript
0 1 .679 r
.4996 .50092 m
.49945 .5007 L
s
% Start of user PostScript
-0.012093754 0.027651494 -0.01660607 0.021102264 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49944 .49966 m
.49953 .49961 L
s
% Start of user PostScript
-0.016715385 -0.010126426 -0.01414637 -0.01157929 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50007 .49976 m
.50011 .49981 L
s
% Start of user PostScript
0.0021371826 -0.0073307488 0.0033797909 -0.0057891828 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50014 .50007 m
.50012 .50009 L
s
% Start of user PostScript
0.0042300155 0.0021265162 0.0036593281 0.0025627268 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49999 .50006 m
.49998 .50005 L
s
% Start of user PostScript
-0.00031316058 0.0019152533 -0.00064843698 0.0015571619 MAarrowhead1
% End of user PostScript
0 1 .037 r
.2068 .80657 m
.16367 .70497 L
.14092 .61149 L
.13617 .52856 L
.14674 .45781 L
.16974 .40009 L
.20225 .35564 L
.24145 .3241 L
.2847 .30466 L
.32961 .29615 L
.37413 .29715 L
.41653 .30611 L
.45546 .32138 L
.48993 .34135 L
.51926 .36445 L
.54312 .38927 L
.56142 .41453 L
.57432 .43915 L
.58219 .46225 L
.5855 .48315 L
.58486 .50137 L
.58093 .51662 L
.5744 .52874 L
.56594 .53778 L
.5562 .54385 L
.54578 .54719 L
.5352 .54811 L
.52491 .54696 L
.51527 .54412 L
.50658 .53996 L
.49901 .53488 L
.4927 .52922 L
.4877 .52329 L
.48399 .51739 L
.48151 .51174 L
.48018 .50653 L
.47985 .50189 L
.48037 .49792 L
.4816 .49468 L
.48337 .49216 L
.48552 .49036 L
.4879 .48924 L
.49039 .48873 L
.49286 .48875 L
.49521 .48922 L
.49739 .49004 L
.49931 .49113 L
.50096 .4924 L
.5023 .49377 L
.50334 .49517 L
Mistroke
.50407 .49653 L
.50453 .49782 L
.50473 .49899 L
.50471 .50001 L
.5045 .50086 L
.50415 .50155 L
.50369 .50206 L
.50315 .50241 L
.50258 .5026 L
.50199 .50266 L
.50142 .50261 L
.50088 .50246 L
.5004 .50223 L
.49997 .50195 L
.49962 .50164 L
.49934 .50131 L
.49913 .50099 L
.49898 .50067 L
.49891 .50038 L
.49888 .50012 L
.49891 .4999 L
.49898 .49972 L
.49907 .49957 L
.49919 .49947 L
.49932 .49941 L
.49946 .49938 L
.49959 .49938 L
.49973 .4994 L
.49985 .49944 L
.49995 .4995 L
.50005 .49957 L
.50012 .49965 L
.50018 .49973 L
.50022 .4998 L
.50025 .49987 L
.50026 .49994 L
.50026 .5 L
.50025 .50004 L
.50023 .50008 L
.50021 .50011 L
.50018 .50013 L
.50014 .50014 L
.50011 .50015 L
.50008 .50014 L
.50005 .50014 L
.50002 .50012 L
.5 .50011 L
.49998 .50009 L
.49996 .50007 L
.49995 .50006 L
Mistroke
.49994 .50004 L
.49994 .50002 L
.49994 .50001 L
.49994 .5 L
.49994 .49998 L
.49995 .49998 L
.49995 .49997 L
.49996 .49997 L
.49997 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.5 .49997 L
.5 .49998 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.2068 .80657 m
.16367 .70497 L
s
% Start of user PostScript
-8.7959523 9.1969748 -10.089847 6.1492126 MAarrowhead1
% End of user PostScript
1 .158 0 r
.14092 .61149 m
.13617 .52856 L
s
% Start of user PostScript
-10.772526 3.3448421 -10.914815 0.85693428 MAarrowhead1
% End of user PostScript
1 .473 0 r
.37413 .29715 m
.41653 .30611 L
s
% Start of user PostScript
-3.776192 -6.0853811 -2.5040951 -5.816652 MAarrowhead1
% End of user PostScript
1 .788 0 r
.58219 .46225 m
.5855 .48315 L
s
% Start of user PostScript
2.4655546 -1.1324941 2.5649577 -0.50539709 MAarrowhead1
% End of user PostScript
.897 1 0 r
.5352 .54811 m
.52491 .54696 L
s
% Start of user PostScript
1.0558516 1.4433796 0.74718199 1.4088167 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48151 .51174 m
.48018 .50653 L
s
% Start of user PostScript
-0.55461626 0.35224434 -0.59473457 0.19585669 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49039 .48873 m
.49286 .48875 L
s
% Start of user PostScript
-0.28841022 -0.33812417 -0.21432155 -0.33750776 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50407 .49653 m
.50453 .49782 L
s
% Start of user PostScript
0.12218517 -0.10395735 0.13582402 -0.065361464 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50258 .5026 m
.50199 .50266 L
s
% Start of user PostScript
0.077298553 0.078124493 0.059718066 0.079923827 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49913 .50099 m
.49898 .50067 L
s
% Start of user PostScript
-0.026222414 0.029585403 -0.03047455 0.020158747 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49932 .49941 m
.49946 .49938 L
s
% Start of user PostScript
-0.020387348 -0.017769477 -0.016267034 -0.018689782 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50018 .49973 m
.50022 .4998 L
s
% Start of user PostScript
0.0054356191 -0.0081940642 0.006692499 -0.0059160083 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50018 .50013 m
.50014 .50014 L
s
% Start of user PostScript
0.0053022734 0.0039676215 0.0043497621 0.0043097406 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49996 .50007 m
.49995 .50006 L
s
% Start of user PostScript
-0.0010723335 0.0022212273 -0.0014304336 0.0016767626 MAarrowhead1
% End of user PostScript
.214 1 0 r
.62287 .47106 m
.62281 .49798 L
.61786 .52067 L
.60898 .53889 L
.59718 .55263 L
.58338 .56205 L
.56846 .56749 L
.5532 .56935 L
.53826 .56814 L
.52419 .5644 L
.51142 .55868 L
.50023 .55154 L
.49084 .54348 L
.48331 .53498 L
.47767 .52644 L
.47382 .51821 L
.47164 .51058 L
.47094 .50375 L
.47151 .49787 L
.47314 .49302 L
.47557 .48922 L
.4786 .48647 L
.48199 .48469 L
.48556 .48382 L
.48913 .48373 L
.49256 .48431 L
.49574 .48542 L
.49858 .48694 L
.50103 .48873 L
.50303 .49069 L
.5046 .49271 L
.50573 .49469 L
.50645 .49657 L
.50679 .49828 L
.50681 .49979 L
.50655 .50106 L
.50608 .50209 L
.50543 .50287 L
.50467 .50341 L
.50385 .50372 L
.50301 .50384 L
.50218 .50378 L
.50139 .50358 L
.50068 .50327 L
.50005 .50288 L
.49953 .50244 L
.4991 .50197 L
.49878 .5015 L
.49856 .50104 L
.49844 .50062 L
Mistroke
.49839 .50023 L
.49842 .4999 L
.4985 .49963 L
.49864 .49942 L
.4988 .49926 L
.49899 .49916 L
.49919 .49911 L
.49938 .4991 L
.49957 .49913 L
.49975 .49919 L
.49991 .49927 L
.50005 .49937 L
.50016 .49948 L
.50025 .49959 L
.50031 .4997 L
.50035 .4998 L
.50038 .4999 L
.50038 .49998 L
.50036 .50005 L
.50034 .50011 L
.5003 .50016 L
.50026 .50019 L
.50022 .50021 L
.50017 .50021 L
.50012 .50021 L
.50008 .5002 L
.50004 .50018 L
.50001 .50016 L
.49998 .50014 L
.49995 .50011 L
.49993 .50008 L
.49992 .50006 L
.49991 .50004 L
.49991 .50001 L
.49991 .5 L
.49992 .49998 L
.49992 .49997 L
.49993 .49996 L
.49994 .49995 L
.49995 .49995 L
.49997 .49995 L
.49998 .49995 L
.49999 .49995 L
.49999 .49996 L
.5 .49996 L
.50001 .49997 L
.50001 .49998 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
Mistroke
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.62287 .47106 m
.62281 .49798 L
s
% Start of user PostScript
3.6860454 -0.86834687 3.6844319 -0.060465768 MAarrowhead1
% End of user PostScript
1 .158 0 r
.61786 .52067 m
.60898 .53889 L
s
% Start of user PostScript
3.535738 0.6201337 3.2695228 1.1666687 MAarrowhead1
% End of user PostScript
1 .473 0 r
.51142 .55868 m
.50023 .55154 L
s
% Start of user PostScript
0.3424809 1.7604693 0.0069776189 1.5461285 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47151 .49787 m
.47314 .49302 L
s
% Start of user PostScript
-0.85458703 -0.063916854 -0.80590163 -0.20952743 MAarrowhead1
% End of user PostScript
.897 1 0 r
.49574 .48542 m
.49858 .48694 L
s
% Start of user PostScript
-0.12766117 -0.4373579 -0.04246563 -0.39186393 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50681 .49979 m
.50655 .50106 L
s
% Start of user PostScript
0.20428424 -0.0063503449 0.19658591 0.031856876 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50139 .50358 m
.50068 .50327 L
s
% Start of user PostScript
0.041809109 0.10753007 0.020410933 0.098243084 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49839 .50023 m
.49842 .4999 L
s
% Start of user PostScript
-0.048262079 0.0070025071 -0.047445547 -0.0028888111 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49957 .49913 m
.49975 .49919 L
s
% Start of user PostScript
-0.012750045 -0.026162554 -0.0074320377 -0.024372499 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50038 .4999 m
.50038 .49998 L
s
% Start of user PostScript
0.011256662 -0.0030495298 0.011324177 -0.00051985871 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50012 .50021 m
.50008 .5002 L
s
% Start of user PostScript
0.0037132395 0.0062974275 0.0024052484 0.0059839012 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49991 .50004 m
.49991 .50001 L
s
% Start of user PostScript
-0.0025881239 0.0010703916 -0.0026709025 0.00043073111 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49997 .49995 m
.49998 .49995 L
s
% Start of user PostScript
-0.0010465246 -0.0014988094 -0.0007281631 -0.0014538349 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50002 .49999 m
.50002 .49999 L
s
% Start of user PostScript
0.00058531305 -0.0003397325 0.00062182181 -0.00017972032 MAarrowhead1
% End of user PostScript
0 .506 1 r
.51936 .28906 m
.55694 .32575 L
.58621 .36351 L
.60734 .40067 L
.62078 .43583 L
.62723 .46792 L
.62756 .49613 L
.62273 .51998 L
.61378 .53919 L
.60171 .55375 L
.58751 .56383 L
.57209 .56973 L
.55626 .5719 L
.54072 .57085 L
.52606 .56713 L
.5127 .56132 L
.50098 .554 L
.4911 .54569 L
.48316 .53689 L
.47718 .52802 L
.47306 .51946 L
.47068 .51149 L
.46986 .50435 L
.47038 .49817 L
.47199 .49307 L
.47447 .48905 L
.47757 .48612 L
.48107 .48422 L
.48476 .48325 L
.48848 .48311 L
.49205 .48367 L
.49537 .48479 L
.49834 .48633 L
.5009 .48818 L
.50302 .4902 L
.50467 .49229 L
.50587 .49435 L
.50665 .49631 L
.50703 .4981 L
.50707 .49968 L
.50682 .50102 L
.50634 .5021 L
.50568 .50293 L
.5049 .5035 L
.50405 .50384 L
.50318 .50398 L
.50232 .50393 L
.5015 .50374 L
.50075 .50342 L
.5001 .50302 L
Mistroke
.49954 .50256 L
.4991 .50208 L
.49876 .50159 L
.49852 .50111 L
.49838 .50067 L
.49833 .50027 L
.49836 .49992 L
.49844 .49963 L
.49858 .49941 L
.49874 .49924 L
.49894 .49913 L
.49914 .49908 L
.49935 .49906 L
.49955 .49909 L
.49973 .49915 L
.4999 .49924 L
.50004 .49934 L
.50016 .49945 L
.50025 .49956 L
.50032 .49968 L
.50037 .49979 L
.50039 .49989 L
.50039 .49998 L
.50038 .50005 L
.50035 .50011 L
.50032 .50016 L
.50027 .50019 L
.50023 .50021 L
.50018 .50022 L
.50013 .50022 L
.50009 .50021 L
.50004 .50019 L
.50001 .50017 L
.49998 .50014 L
.49995 .50012 L
.49993 .50009 L
.49992 .50006 L
.49991 .50004 L
.49991 .50002 L
.49991 .5 L
.49991 .49998 L
.49992 .49997 L
.49993 .49996 L
.49994 .49995 L
.49995 .49995 L
.49996 .49995 L
.49997 .49995 L
.49998 .49995 L
.49999 .49996 L
.5 .49996 L
Mistroke
.50001 .49997 L
.50001 .49998 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.51936 .28906 m
.55694 .32575 L
s
% Start of user PostScript
0.58081398 -6.3280926 1.7082582 -5.2276125 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58621 .36351 m
.60734 .40067 L
s
% Start of user PostScript
2.5863865 -4.0947561 3.2201086 -2.9800238 MAarrowhead1
% End of user PostScript
1 .473 0 r
.58751 .56383 m
.57209 .56973 L
s
% Start of user PostScript
2.6251841 1.9148824 2.1626083 2.0920495 MAarrowhead1
% End of user PostScript
1 .788 0 r
.48316 .53689 m
.47718 .52802 L
s
% Start of user PostScript
-0.50507036 1.1065675 -0.68473133 0.84063516 MAarrowhead1
% End of user PostScript
.897 1 0 r
.47757 .48612 m
.48107 .48422 L
s
% Start of user PostScript
-0.67289791 -0.41625809 -0.56791145 -0.47339201 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50302 .4902 m
.50467 .49229 L
s
% Start of user PostScript
0.090528282 -0.29392147 0.14014006 -0.23123195 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50568 .50293 m
.5049 .5035 L
s
% Start of user PostScript
0.17051153 0.087787828 0.14713047 0.10504635 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49954 .50256 m
.4991 .50208 L
s
% Start of user PostScript
-0.013703236 0.07691854 -0.027119456 0.062332055 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49858 .49941 m
.49874 .49924 L
s
% Start of user PostScript
-0.042740438 -0.017759346 -0.03765304 -0.022752712 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50004 .49934 m
.50016 .49945 L
s
% Start of user PostScript
0.0012182949 -0.01986576 0.0047839038 -0.016521233 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50035 .50011 m
.50032 .50016 L
s
% Start of user PostScript
0.010601257 0.0033750228 0.0095269912 0.0047754653 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50001 .50017 m
.49998 .50014 L
s
% Start of user PostScript
0.00023555309 0.0050694713 -0.00069802823 0.004315525 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49991 .49998 m
.49992 .49997 L
s
% Start of user PostScript
-0.0026023286 -0.00057596682 -0.0023846182 -0.00095942988 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49999 .49996 m
.5 .49996 L
s
% Start of user PostScript
-0.00018965584 -0.0012792361 0.000051569536 -0.0011127024 MAarrowhead1
% End of user PostScript
.823 1 0 r
.43318 .6642 m
.40617 .62622 L
.38724 .58929 L
.37587 .55472 L
.37128 .52351 L
.37258 .49637 L
.37877 .47373 L
.38881 .45578 L
.40168 .44247 L
.41642 .43361 L
.43214 .42882 L
.44804 .42765 L
.46347 .42956 L
.47789 .43398 L
.49087 .44033 L
.50214 .44804 L
.51151 .4566 L
.51891 .46552 L
.52437 .47438 L
.52798 .48285 L
.52989 .49064 L
.5303 .49756 L
.52943 .50346 L
.52753 .50828 L
.52483 .51199 L
.52157 .51463 L
.51797 .51626 L
.51423 .51697 L
.51052 .5169 L
.50698 .51616 L
.50374 .51489 L
.50086 .51323 L
.49842 .51131 L
.49643 .50924 L
.4949 .50714 L
.49382 .50509 L
.49316 .50316 L
.49288 .50142 L
.49293 .4999 L
.49326 .49863 L
.4938 .49761 L
.4945 .49686 L
.49531 .49635 L
.49618 .49607 L
.49706 .49599 L
.49792 .49609 L
.49872 .49632 L
.49945 .49667 L
.50008 .49709 L
.5006 .49756 L
Mistroke
.50102 .49806 L
.50133 .49855 L
.50154 .49902 L
.50165 .49945 L
.50168 .49984 L
.50164 .50017 L
.50153 .50044 L
.50139 .50065 L
.50121 .5008 L
.50101 .5009 L
.5008 .50094 L
.5006 .50094 L
.5004 .5009 L
.50022 .50083 L
.50006 .50074 L
.49992 .50063 L
.49981 .50052 L
.49972 .5004 L
.49966 .50029 L
.49962 .50018 L
.49961 .50009 L
.49961 .5 L
.49962 .49993 L
.49965 .49987 L
.49969 .49983 L
.49974 .4998 L
.49978 .49978 L
.49983 .49978 L
.49988 .49978 L
.49993 .4998 L
.49997 .49981 L
.5 .49984 L
.50003 .49986 L
.50006 .49989 L
.50007 .49992 L
.50008 .49994 L
.50009 .49997 L
.50009 .49999 L
.50009 .50001 L
.50009 .50002 L
.50008 .50004 L
.50007 .50004 L
.50006 .50005 L
.50005 .50005 L
.50003 .50005 L
.50002 .50005 L
.50001 .50005 L
.5 .50004 L
.5 .50004 L
.49999 .50003 L
Mistroke
.49998 .50002 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.43318 .6642 m
.40617 .62622 L
s
% Start of user PostScript
-2.0046331 4.9260446 -2.8149859 3.7866078 MAarrowhead1
% End of user PostScript
1 .158 0 r
.38724 .58929 m
.37587 .55472 L
s
% Start of user PostScript
-3.3826718 2.6786742 -3.7239477 1.6414922 MAarrowhead1
% End of user PostScript
1 .473 0 r
.43214 .42882 m
.44804 .42765 L
s
% Start of user PostScript
-2.0359091 -2.1353738 -1.5587152 -2.17055 MAarrowhead1
% End of user PostScript
1 .788 0 r
.52437 .47438 m
.52798 .48285 L
s
% Start of user PostScript
0.73122462 -0.76851367 0.8395083 -0.51452619 MAarrowhead1
% End of user PostScript
.897 1 0 r
.51797 .51626 m
.51423 .51697 L
s
% Start of user PostScript
0.53901844 0.48772199 0.42681851 0.50923751 MAarrowhead1
% End of user PostScript
.581 1 0 r
.4949 .50714 m
.49382 .50509 L
s
% Start of user PostScript
-0.15306595 0.21417151 -0.185441 0.15262675 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49531 .49635 m
.49618 .49607 L
s
% Start of user PostScript
-0.14065906 -0.10944263 -0.11462772 -0.11785988 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50102 .49806 m
.50133 .49855 L
s
% Start of user PostScript
0.030634123 -0.05834727 0.039933812 -0.043596082 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50121 .5008 m
.50101 .5009 L
s
% Start of user PostScript
0.036234904 0.024038284 0.030285831 0.026859748 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49981 .50052 m
.49972 .5004 L
s
% Start of user PostScript
-0.0057223086 0.015603593 -0.0083163585 0.012108643 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49969 .49983 m
.49974 .4998 L
s
% Start of user PostScript
-0.0092247271 -0.0051388776 -0.0078888545 -0.0060113406 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50003 .49986 m
.50006 .49989 L
s
% Start of user PostScript
0.00094471793 -0.0041076113 0.0016519421 -0.0032898775 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50008 .50004 m
.50007 .50004 L
s
% Start of user PostScript
0.002322553 0.001059558 0.0020288869 0.0013160479 MAarrowhead1
% End of user PostScript
0 .06 1 r
.5 .50004 m
.49999 .50003 L
s
% Start of user PostScript
-0.00011554037 0.0010664939 -0.00030478696 0.00087781086 MAarrowhead1
% End of user PostScript
0 1 .947 r
.51539 .54839 m
.5059 .54359 L
.49771 .53781 L
.49092 .53145 L
.48559 .52485 L
.48168 .51832 L
.47914 .51211 L
.47784 .5064 L
.47763 .50136 L
.47836 .49707 L
.47983 .49359 L
.48187 .49092 L
.48431 .48905 L
.48698 .48791 L
.48975 .48744 L
.49248 .48755 L
.49508 .48814 L
.49745 .4891 L
.49955 .49035 L
.50132 .49179 L
.50276 .49332 L
.50386 .49487 L
.50463 .49638 L
.50508 .49779 L
.50527 .49906 L
.50521 .50017 L
.50495 .50109 L
.50454 .50182 L
.50401 .50236 L
.5034 .50272 L
.50276 .50291 L
.50211 .50296 L
.50148 .50288 L
.50089 .5027 L
.50036 .50243 L
.4999 .50212 L
.49952 .50177 L
.49922 .5014 L
.499 .50104 L
.49885 .50069 L
.49878 .50038 L
.49876 .50009 L
.4988 .49985 L
.49888 .49966 L
.49899 .49951 L
.49912 .4994 L
.49927 .49933 L
.49942 .49931 L
.49957 .49931 L
.49972 .49934 L
Mistroke
.49985 .49939 L
.49997 .49946 L
.50007 .49954 L
.50015 .49962 L
.50021 .49971 L
.50025 .49979 L
.50028 .49987 L
.50029 .49994 L
.50029 .50001 L
.50028 .50006 L
.50025 .5001 L
.50022 .50013 L
.50019 .50015 L
.50016 .50016 L
.50012 .50016 L
.50008 .50016 L
.50005 .50015 L
.50002 .50014 L
.5 .50012 L
.49997 .5001 L
.49996 .50008 L
.49995 .50006 L
.49994 .50004 L
.49993 .50002 L
.49993 .50001 L
.49993 .49999 L
.49994 .49998 L
.49994 .49997 L
.49995 .49997 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49999 .49997 L
.5 .49997 L
.5 .49997 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
Mistroke
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.51539 .54839 m
.5059 .54359 L
s
% Start of user PostScript
0.46155464 1.4517308 0.17712462 1.307608 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49771 .53781 m
.49092 .53145 L
s
% Start of user PostScript
-0.068725326 1.1343322 -0.27235748 0.94351297 MAarrowhead1
% End of user PostScript
1 .473 0 r
.47983 .49359 m
.48187 .49092 L
s
% Start of user PostScript
-0.6051722 -0.19227523 -0.54391842 -0.27228037 MAarrowhead1
% End of user PostScript
1 .788 0 r
.49955 .49035 m
.50132 .49179 L
s
% Start of user PostScript
-0.013648986 -0.28944396 0.039662968 -0.24643345 MAarrowhead1
% End of user PostScript
.897 1 0 r
.50495 .50109 m
.50454 .50182 L
s
% Start of user PostScript
0.14854356 0.032780709 0.13613392 0.05468427 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50036 .50243 m
.4999 .50212 L
s
% Start of user PostScript
0.0108759 0.073033338 -0.0028980756 0.063534481 MAarrowhead1
% End of user PostScript
.266 1 0 r
.4988 .49985 m
.49888 .49966 L
s
% Start of user PostScript
-0.036080524 -0.0043911862 -0.033716733 -0.010272783 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49985 .49939 m
.49997 .49946 L
s
% Start of user PostScript
-0.0045061318 -0.01823181 -0.00099000217 -0.016186784 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50029 .50001 m
.50028 .50006 L
s
% Start of user PostScript
0.0086695256 0.0001610849 0.0082643913 0.0017148618 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50005 .50015 m
.50002 .50014 L
s
% Start of user PostScript
0.0015495144 0.0045040532 0.00066196463 0.0040783122 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49993 .50001 m
.49993 .49999 L
s
% Start of user PostScript
-0.002059538 0.00018799397 -0.002004506 -0.0002166874 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49998 .49996 m
.49999 .49997 L
s
% Start of user PostScript
-0.00048623217 -0.0011011812 -0.00026458277 -0.0010166547 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50002 .5 m
.50002 .5 L
s
% Start of user PostScript
0.00048329277 -0.00010203253 0.00048092826 0.0000020341784 MAarrowhead1
% End of user PostScript
0 .06 1 r
.5 .50001 m
.5 .50001 L
s
% Start of user PostScript
0.00014433781 0.00026638935 0.000089560196 0.00025080682 MAarrowhead1
% End of user PostScript
1 .128 0 r
.43212 .57005 m
.42231 .54667 L
.41717 .52519 L
.41618 .50614 L
.41869 .48991 L
.42405 .47668 L
.43159 .46652 L
.44066 .45932 L
.45064 .4549 L
.46099 .453 L
.47124 .45328 L
.481 .45539 L
.48995 .45894 L
.49786 .46356 L
.50459 .4689 L
.51006 .47463 L
.51424 .48045 L
.51719 .48611 L
.51897 .49143 L
.51971 .49623 L
.51954 .50041 L
.51862 .50391 L
.5171 .50668 L
.51514 .50875 L
.51289 .51013 L
.51049 .51089 L
.50805 .51109 L
.50568 .51081 L
.50347 .51015 L
.50147 .50918 L
.49973 .50801 L
.49829 .5067 L
.49714 .50533 L
.49629 .50397 L
.49573 .50267 L
.49543 .50148 L
.49536 .50041 L
.49548 .4995 L
.49577 .49876 L
.49618 .49818 L
.49668 .49777 L
.49723 .49752 L
.4978 .4974 L
.49837 .49741 L
.49891 .49752 L
.49941 .49771 L
.49985 .49796 L
.50023 .49826 L
.50054 .49857 L
.50077 .49889 L
Mistroke
.50094 .49921 L
.50105 .4995 L
.50109 .49977 L
.50108 .50001 L
.50104 .5002 L
.50095 .50036 L
.50085 .50048 L
.50072 .50056 L
.50059 .5006 L
.50046 .50061 L
.50032 .5006 L
.5002 .50056 L
.50009 .50051 L
.49999 .50045 L
.49991 .50038 L
.49985 .5003 L
.4998 .50023 L
.49977 .50015 L
.49975 .50009 L
.49974 .50003 L
.49975 .49998 L
.49976 .49993 L
.49979 .4999 L
.49981 .49988 L
.49984 .49986 L
.49988 .49986 L
.49991 .49986 L
.49994 .49986 L
.49997 .49987 L
.49999 .49989 L
.50001 .4999 L
.50003 .49992 L
.50004 .49994 L
.50005 .49995 L
.50006 .49997 L
.50006 .49999 L
.50006 .5 L
.50006 .50001 L
.50005 .50002 L
.50005 .50003 L
.50004 .50003 L
.50003 .50003 L
.50003 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50003 L
.5 .50003 L
.5 .50002 L
.49999 .50002 L
.49999 .50001 L
Mistroke
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.43212 .57005 m
.42231 .54667 L
s
% Start of user PostScript
-2.0363175 2.101445 -2.3308146 1.4002251 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41717 .52519 m
.41618 .50614 L
s
% Start of user PostScript
-2.4848237 0.75558647 -2.5147404 0.1842244 MAarrowhead1
% End of user PostScript
1 .473 0 r
.47124 .45328 m
.481 .45539 L
s
% Start of user PostScript
-0.86270328 -1.4014742 -0.57003877 -1.3383176 MAarrowhead1
% End of user PostScript
1 .788 0 r
.51897 .49143 m
.51971 .49623 L
s
% Start of user PostScript
0.56913322 -0.2571814 0.59130718 -0.11309216 MAarrowhead1
% End of user PostScript
.897 1 0 r
.50805 .51109 m
.50568 .51081 L
s
% Start of user PostScript
0.24151438 0.33259664 0.17046528 0.32430731 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49573 .50267 m
.49543 .50148 L
s
% Start of user PostScript
-0.12813598 0.080235655 -0.13719613 0.044284592 MAarrowhead1
% End of user PostScript
.266 1 0 r
.4978 .4974 m
.49837 .49741 L
s
% Start of user PostScript
-0.066035044 -0.077960748 -0.048972616 -0.077734247 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50094 .49921 m
.50105 .4995 L
s
% Start of user PostScript
0.028259328 -0.023727427 0.03135618 -0.014850553 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50059 .5006 m
.50046 .50061 L
s
% Start of user PostScript
0.017712783 0.018025267 0.013661812 0.018418211 MAarrowhead1
% End of user PostScript
0 1 .679 r
.4998 .50023 m
.49977 .50015 L
s
% Start of user PostScript
-0.0060731374 0.0067624373 -0.0070416216 0.0045932936 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49984 .49986 m
.49988 .49986 L
s
% Start of user PostScript
-0.0046749658 -0.0041030791 -0.0037249733 -0.0043096461 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50004 .49994 m
.50005 .49995 L
s
% Start of user PostScript
0.0012612592 -0.001875041 0.0015481144 -0.0013505804 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50004 .50003 m
.50003 .50003 L
s
% Start of user PostScript
0.0012165994 0.00091700807 0.00099683706 0.00099446268 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49999 .50002 m
.49999 .50001 L
s
% Start of user PostScript
-0.00024951356 0.00050874173 -0.00033136198 0.00038332731 MAarrowhead1
% End of user PostScript
1 0 .861 r
.35165 .54341 m
.35017 .50956 L
.35493 .48077 L
.36472 .45737 L
.37835 .43943 L
.39465 .42679 L
.41255 .41911 L
.43108 .4159 L
.44938 .41656 L
.46678 .42046 L
.4827 .42691 L
.49677 .43525 L
.5087 .44484 L
.51837 .45509 L
.52575 .4655 L
.53092 .47561 L
.53402 .48508 L
.53527 .49362 L
.5349 .50105 L
.5332 .50724 L
.53044 .51215 L
.52691 .51578 L
.52287 .5182 L
.51856 .51951 L
.5142 .51982 L
.50998 .51929 L
.50603 .51808 L
.50248 .51633 L
.49939 .51422 L
.49683 .51187 L
.49481 .50943 L
.49331 .507 L
.49233 .50468 L
.49181 .50255 L
.4917 .50066 L
.49194 .49904 L
.49246 .49772 L
.4932 .49671 L
.4941 .49599 L
.49509 .49554 L
.49611 .49535 L
.49713 .49537 L
.49809 .49558 L
.49898 .49592 L
.49977 .49638 L
.50044 .49691 L
.50098 .49747 L
.5014 .49805 L
.5017 .49861 L
.50187 .49914 L
Mistroke
.50195 .49961 L
.50194 .50003 L
.50185 .50038 L
.5017 .50066 L
.5015 .50086 L
.50128 .501 L
.50104 .50108 L
.5008 .5011 L
.50057 .50107 L
.50035 .50101 L
.50015 .50091 L
.49998 .5008 L
.49983 .50067 L
.49972 .50053 L
.49963 .5004 L
.49958 .50027 L
.49955 .50015 L
.49954 .50004 L
.49955 .49995 L
.49958 .49988 L
.49962 .49982 L
.49967 .49978 L
.49972 .49975 L
.49978 .49974 L
.49984 .49974 L
.49989 .49975 L
.49994 .49977 L
.49998 .4998 L
.50002 .49983 L
.50005 .49986 L
.50008 .49989 L
.50009 .49992 L
.5001 .49995 L
.50011 .49998 L
.50011 .5 L
.5001 .50002 L
.50009 .50004 L
.50008 .50005 L
.50007 .50005 L
.50006 .50006 L
.50005 .50006 L
.50003 .50006 L
.50002 .50006 L
.50001 .50005 L
.5 .50004 L
.49999 .50004 L
.49998 .50003 L
.49998 .50002 L
.49998 .50002 L
.49998 .50001 L
Mistroke
.49997 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.35165 .54341 m
.35017 .50956 L
s
% Start of user PostScript
-4.4505663 1.3021525 -4.4948282 0.28683067 MAarrowhead1
% End of user PostScript
1 .158 0 r
.35493 .48077 m
.36472 .45737 L
s
% Start of user PostScript
-4.3522374 -0.57695861 -4.0584939 -1.2790002 MAarrowhead1
% End of user PostScript
1 .473 0 r
.4827 .42691 m
.49677 .43525 L
s
% Start of user PostScript
-0.51887664 -2.1927072 -0.096997926 -1.9425539 MAarrowhead1
% End of user PostScript
1 .788 0 r
.5349 .50105 m
.5332 .50724 L
s
% Start of user PostScript
1.047015 0.031416818 0.99590822 0.21718545 MAarrowhead1
% End of user PostScript
.897 1 0 r
.50603 .51808 m
.50248 .51633 L
s
% Start of user PostScript
0.18088865 0.54230331 0.074270764 0.49000841 MAarrowhead1
% End of user PostScript
.581 1 0 r
.4917 .50066 m
.49194 .49904 L
s
% Start of user PostScript
-0.24904532 0.019670611 -0.24183294 -0.028783307 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49809 .49558 m
.49898 .49592 L
s
% Start of user PostScript
-0.057197885 -0.13273584 -0.030541594 -0.12228982 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50195 .49961 m
.50194 .50003 L
s
% Start of user PostScript
0.058521995 -0.011561604 0.05809114 0.00091511766 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50057 .50107 m
.50035 .50101 L
s
% Start of user PostScript
0.017063594 0.032147721 0.01046845 0.030202565 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49955 .50015 m
.49954 .50004 L
s
% Start of user PostScript
-0.013568641 0.0044763886 -0.013795832 0.0013013234 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49984 .49974 m
.49989 .49975 L
s
% Start of user PostScript
-0.0048938371 -0.0077012119 -0.0032789811 -0.0073820683 MAarrowhead1
% End of user PostScript
0 .69 1 r
.5001 .49995 m
.50011 .49998 L
s
% Start of user PostScript
0.0030985618 -0.0014932236 0.0032362309 -0.0006941268 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50005 .50006 m
.50003 .50006 L
s
% Start of user PostScript
0.0013634632 0.0018236007 0.00097220493 0.0017853018 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49998 .50002 m
.49998 .50001 L
s
% Start of user PostScript
-0.00069516164 0.00046042245 -0.00074889173 0.00026143128 MAarrowhead1
% End of user PostScript
1 0 .709 r
.8005 .19601 m
.84284 .29853 L
.86468 .39264 L
.86842 .47594 L
.85684 .54683 L
.83284 .60446 L
.79938 .64867 L
.75933 .67983 L
.71533 .6988 L
.66979 .70677 L
.62477 .7052 L
.58198 .69567 L
.54279 .67984 L
.50818 .65937 L
.4788 .63581 L
.45498 .6106 L
.43679 .58501 L
.42404 .56014 L
.41638 .53685 L
.41329 .51583 L
.41417 .49754 L
.41834 .4823 L
.4251 .47021 L
.43377 .46125 L
.4437 .45528 L
.45429 .45205 L
.46501 .45126 L
.4754 .45255 L
.48511 .45553 L
.49385 .45981 L
.50144 .465 L
.50775 .47077 L
.51274 .47677 L
.51642 .48275 L
.51885 .48845 L
.52014 .4937 L
.52041 .49836 L
.51983 .50233 L
.51854 .50558 L
.51672 .50808 L
.51453 .50985 L
.5121 .51095 L
.50958 .51143 L
.50708 .51138 L
.5047 .51088 L
.50252 .51003 L
.50058 .50891 L
.49893 .50762 L
.49759 .50623 L
.49656 .50481 L
Mistroke
.49584 .50343 L
.49539 .50213 L
.4952 .50096 L
.49524 .49993 L
.49546 .49908 L
.49582 .49839 L
.4963 .49788 L
.49684 .49754 L
.49743 .49735 L
.49802 .4973 L
.4986 .49736 L
.49914 .49752 L
.49963 .49776 L
.50005 .49804 L
.50041 .49836 L
.50069 .49869 L
.5009 .49902 L
.50104 .49934 L
.50111 .49963 L
.50113 .49989 L
.5011 .50011 L
.50103 .5003 L
.50093 .50044 L
.50081 .50054 L
.50068 .5006 L
.50054 .50063 L
.5004 .50063 L
.50027 .50061 L
.50015 .50056 L
.50004 .5005 L
.49995 .50043 L
.49987 .50035 L
.49981 .50027 L
.49977 .5002 L
.49975 .50012 L
.49973 .50006 L
.49974 .5 L
.49975 .49995 L
.49977 .49991 L
.49979 .49988 L
.49982 .49987 L
.49986 .49985 L
.49989 .49985 L
.49992 .49985 L
.49995 .49986 L
.49998 .49987 L
.5 .49989 L
.50002 .49991 L
.50004 .49993 L
.50005 .49994 L
Mistroke
.50006 .49996 L
.50006 .49998 L
.50006 .49999 L
.50006 .50001 L
.50006 .50002 L
.50005 .50002 L
.50005 .50003 L
.50004 .50003 L
.50003 .50003 L
.50002 .50004 L
.50002 .50003 L
.50001 .50003 L
.5 .50003 L
.5 .50002 L
.49999 .50002 L
.49999 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.8005 .19601 m
.84284 .29853 L
s
% Start of user PostScript
9.0149128 -9.1196723 10.285236 -6.0441788 MAarrowhead1
% End of user PostScript
1 .158 0 r
.86468 .39264 m
.86842 .47594 L
s
% Start of user PostScript
10.940315 -3.2207293 11.052725 -0.7217687 MAarrowhead1
% End of user PostScript
1 .473 0 r
.62477 .7052 m
.58198 .69567 L
s
% Start of user PostScript
3.7430109 6.1558697 2.4595131 5.870017 MAarrowhead1
% End of user PostScript
1 .788 0 r
.41638 .53685 m
.41329 .51583 L
s
% Start of user PostScript
-2.5086083 1.105452 -2.6012197 0.47476372 MAarrowhead1
% End of user PostScript
.897 1 0 r
.46501 .45126 m
.4754 .45255 L
s
% Start of user PostScript
-1.0498459 -1.4621291 -0.73802156 -1.4235252 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51885 .48845 m
.52014 .4937 L
s
% Start of user PostScript
0.56553682 -0.34652379 0.6041398 -0.18904622 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50958 .51143 m
.50708 .51138 L
s
% Start of user PostScript
0.28748137 0.34303696 0.21253812 0.34147914 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49584 .50343 m
.49539 .50213 L
s
% Start of user PostScript
-0.12492511 0.10279506 -0.13823349 0.06388281 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49743 .49735 m
.49802 .4973 L
s
% Start of user PostScript
-0.077208027 -0.079394735 -0.059400098 -0.080977916 MAarrowhead1
% End of user PostScript
0 1 .679 r
.5009 .49902 m
.50104 .49934 L
s
% Start of user PostScript
0.026902651 -0.029363008 0.031084794 -0.019847408 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50068 .5006 m
.50054 .50063 L
s
% Start of user PostScript
0.020399416 0.018093958 0.016219476 0.018965458 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49981 .50027 m
.49977 .5002 L
s
% Start of user PostScript
-0.0056027534 0.0081556274 -0.0068453875 0.0058531708 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49982 .49987 m
.49986 .49985 L
s
% Start of user PostScript
-0.0053136994 -0.004049581 -0.0043457644 -0.0043808984 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50004 .49993 m
.50005 .49994 L
s
% Start of user PostScript
0.0011129707 -0.0022158926 0.0014683376 -0.0016648647 MAarrowhead1
% End of user PostScript
0 1 .282 r
.52665 .6072 m
.50597 .5952 L
.48837 .58132 L
.47406 .56642 L
.46309 .55126 L
.45535 .53648 L
.45064 .52261 L
.44866 .51007 L
.44906 .49913 L
.45142 .48999 L
.45535 .48272 L
.46043 .4773 L
.46628 .47366 L
.47254 .47166 L
.47889 .47111 L
.48507 .47181 L
.49085 .47352 L
.49607 .47602 L
.50061 .47907 L
.5044 .48247 L
.5074 .48603 L
.50962 .48957 L
.5111 .49296 L
.5119 .49609 L
.5121 .49888 L
.51178 .50126 L
.51104 .5032 L
.50998 .50471 L
.50869 .50579 L
.50726 .50646 L
.50577 .50677 L
.50428 .50675 L
.50287 .50647 L
.50156 .50598 L
.50041 .50532 L
.49942 .50456 L
.49861 .50374 L
.49799 .5029 L
.49755 .50208 L
.49728 .50131 L
.49716 .5006 L
.49717 .49999 L
.4973 .49948 L
.49751 .49907 L
.49779 .49876 L
.49811 .49855 L
.49845 .49844 L
.49881 .4984 L
.49915 .49843 L
.49947 .49853 L
Mistroke
.49976 .49866 L
.50002 .49883 L
.50023 .49902 L
.5004 .49921 L
.50053 .49941 L
.50061 .4996 L
.50066 .49977 L
.50067 .49993 L
.50065 .50006 L
.50061 .50017 L
.50056 .50026 L
.50049 .50032 L
.50041 .50036 L
.50033 .50037 L
.50024 .50037 L
.50016 .50036 L
.50009 .50033 L
.50003 .5003 L
.49997 .50026 L
.49993 .50021 L
.49989 .50016 L
.49987 .50012 L
.49985 .50008 L
.49984 .50004 L
.49984 .5 L
.49985 .49997 L
.49986 .49995 L
.49988 .49993 L
.49989 .49992 L
.49991 .49991 L
.49993 .49991 L
.49995 .49991 L
.49997 .49992 L
.49999 .49993 L
.5 .49993 L
.50001 .49994 L
.50002 .49996 L
.50003 .49997 L
.50003 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .5 L
.50003 .50001 L
.50003 .50001 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
Mistroke
.5 .50002 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.52665 .6072 m
.50597 .5952 L
s
% Start of user PostScript
0.79945781 3.215865 0.1790554 2.8559915 MAarrowhead1
% End of user PostScript
1 .158 0 r
.48837 .58132 m
.47406 .56642 L
s
% Start of user PostScript
-0.34890613 2.4396829 -0.77815449 1.9926475 MAarrowhead1
% End of user PostScript
1 .473 0 r
.45535 .48272 m
.46043 .4773 L
s
% Start of user PostScript
-1.3394762 -0.51852796 -1.1869682 -0.68099934 MAarrowhead1
% End of user PostScript
1 .788 0 r
.50061 .47907 m
.5044 .48247 L
s
% Start of user PostScript
0.018317627 -0.62783426 0.13187951 -0.52581096 MAarrowhead1
% End of user PostScript
.897 1 0 r
.51104 .5032 m
.50998 .50471 L
s
% Start of user PostScript
0.33123688 0.096125223 0.29937034 0.14134829 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50041 .50532 m
.49942 .50456 L
s
% Start of user PostScript
0.012229684 0.15968194 -0.017385449 0.13680971 MAarrowhead1
% End of user PostScript
.266 1 0 r
.4973 .49948 m
.49751 .49907 L
s
% Start of user PostScript
-0.081063698 -0.01563095 -0.074702794 -0.027939201 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49976 .49866 m
.50002 .49883 L
s
% Start of user PostScript
-0.007114241 -0.040167356 0.00051035682 -0.035149416 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50065 .50006 m
.50061 .50017 L
s
% Start of user PostScript
0.019630378 0.0018237538 0.018447285 0.0051126295 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50009 .50033 m
.50003 .5003 L
s
% Start of user PostScript
0.0027468277 0.0099973538 0.00080680988 0.0089262248 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49984 .5 m
.49985 .49997 L
s
% Start of user PostScript
-0.0047019169 0.000055716501 -0.0045082536 -0.00080946467 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49997 .49992 m
.49999 .49993 L
s
% Start of user PostScript
-0.00091508002 -0.0024625002 -0.00042688625 -0.002242105 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50004 .5 m
.50004 .5 L
s
% Start of user PostScript
0.0011132136 -0.0001382392 0.001090139 0.000086254638 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50001 .50002 m
.50001 .50002 L
s
% Start of user PostScript
0.00028193808 0.00060025594 0.00016038437 0.00055725718 MAarrowhead1
% End of user PostScript
.592 1 0 r
.67038 .27193 m
.70454 .33881 L
.72503 .4014 L
.73324 .45789 L
.7308 .50699 L
.71952 .54793 L
.70127 .58038 L
.67791 .60441 L
.65118 .6204 L
.6227 .62901 L
.59388 .63108 L
.56593 .62758 L
.53984 .61953 L
.51634 .608 L
.49596 .594 L
.47901 .57849 L
.46563 .56233 L
.45576 .54627 L
.44925 .53094 L
.44582 .51683 L
.4451 .50432 L
.44669 .49364 L
.45016 .48493 L
.45507 .47822 L
.46098 .47346 L
.46751 .47053 L
.47428 .46924 L
.481 .46939 L
.4874 .47074 L
.49328 .47305 L
.49848 .47606 L
.5029 .47954 L
.5065 .48329 L
.50927 .4871 L
.51121 .49081 L
.5124 .4943 L
.5129 .49746 L
.51281 .50021 L
.51221 .50251 L
.51123 .50434 L
.50995 .5057 L
.50848 .50662 L
.50691 .50712 L
.50531 .50726 L
.50376 .50709 L
.50231 .50666 L
.50099 .50603 L
.49985 .50526 L
.4989 .50441 L
.49814 .50352 L
Mistroke
.49758 .50263 L
.49721 .50177 L
.49701 .50099 L
.49696 .50029 L
.49704 .49969 L
.49722 .4992 L
.49749 .49882 L
.49781 .49855 L
.49817 .49838 L
.49855 .4983 L
.49892 .4983 L
.49928 .49837 L
.49961 .4985 L
.4999 .49866 L
.50014 .49885 L
.50035 .49906 L
.5005 .49927 L
.50061 .49948 L
.50068 .49967 L
.50071 .49985 L
.50071 .5 L
.50068 .50013 L
.50063 .50023 L
.50056 .50031 L
.50048 .50036 L
.50039 .50039 L
.5003 .5004 L
.50021 .50039 L
.50013 .50037 L
.50006 .50034 L
.5 .50029 L
.49994 .50025 L
.4999 .5002 L
.49987 .50015 L
.49985 .5001 L
.49983 .50006 L
.49983 .50002 L
.49984 .49998 L
.49985 .49996 L
.49986 .49994 L
.49988 .49992 L
.4999 .49991 L
.49992 .49991 L
.49994 .49991 L
.49996 .49991 L
.49998 .49992 L
.49999 .49993 L
.50001 .49994 L
.50002 .49995 L
.50003 .49996 L
Mistroke
.50003 .49997 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50003 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.67038 .27193 m
.70454 .33881 L
s
% Start of user PostScript
5.1114994 -6.8421524 6.1361868 -4.8356347 MAarrowhead1
% End of user PostScript
1 .158 0 r
.72503 .4014 m
.73324 .45789 L
s
% Start of user PostScript
6.7509836 -2.9578736 6.9971093 -1.2632895 MAarrowhead1
% End of user PostScript
1 .473 0 r
.59388 .63108 m
.56593 .62758 L
s
% Start of user PostScript
2.8163734 3.932426 1.9780278 3.8272869 MAarrowhead1
% End of user PostScript
1 .788 0 r
.44925 .53094 m
.44582 .51683 L
s
% Start of user PostScript
-1.5223812 0.92821921 -1.6254603 0.50502425 MAarrowhead1
% End of user PostScript
.897 1 0 r
.47428 .46924 m
.481 .46939 L
s
% Start of user PostScript
-0.77147804 -0.92279518 -0.56995607 -0.9182642 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51121 .49081 m
.5124 .4943 L
s
% Start of user PostScript
0.33641 -0.27555094 0.37201759 -0.17096327 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50691 .50712 m
.50531 .50726 L
s
% Start of user PostScript
0.20725244 0.21362712 0.15935799 0.21779756 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49758 .50263 m
.49721 .50177 L
s
% Start of user PostScript
-0.072479366 0.078750637 -0.083681549 0.053170486 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49817 .49838 m
.49855 .4983 L
s
% Start of user PostScript
-0.054772252 -0.048698305 -0.043527989 -0.051020011 MAarrowhead1
% End of user PostScript
0 1 .679 r
.5005 .49927 m
.50061 .49948 L
s
% Start of user PostScript
0.015104003 -0.021881769 0.018434917 -0.015691163 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50048 .50036 m
.50039 .50039 L
s
% Start of user PostScript
0.014270303 0.01090255 0.011665907 0.011788062 MAarrowhead1
% End of user PostScript
0 .69 1 r
.4999 .5002 m
.49987 .50015 L
s
% Start of user PostScript
-0.0030031198 0.0059471915 -0.0039561869 0.0044653768 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49988 .49992 m
.4999 .49991 L
s
% Start of user PostScript
-0.0036708458 -0.0023878563 -0.0030767951 -0.0026811388 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50002 .49995 m
.50003 .49996 L
s
% Start of user PostScript
0.0005549687 -0.0015872852 0.00082002632 -0.001236702 MAarrowhead1
% End of user PostScript
.558 1 0 r
.34023 .37022 m
.37079 .36152 L
.40161 .35975 L
.43142 .36387 L
.45919 .37278 L
.48413 .38535 L
.5057 .40048 L
.52358 .41716 L
.53765 .43448 L
.54795 .45163 L
.55468 .46797 L
.55815 .48297 L
.55873 .49623 L
.55687 .50752 L
.55303 .5167 L
.54769 .52373 L
.5413 .52869 L
.53429 .5317 L
.52703 .53297 L
.51985 .53271 L
.51303 .53118 L
.50679 .52865 L
.50127 .52539 L
.4966 .52163 L
.4928 .51761 L
.48991 .51353 L
.48788 .50957 L
.48666 .50585 L
.48618 .50251 L
.48632 .49959 L
.48699 .49717 L
.48807 .49524 L
.48945 .49382 L
.49103 .49287 L
.49272 .49235 L
.49443 .49223 L
.49609 .49244 L
.49763 .49291 L
.49903 .4936 L
.50024 .49443 L
.50124 .49535 L
.50204 .4963 L
.50262 .49725 L
.50301 .49816 L
.50321 .499 L
.50325 .49974 L
.50316 .50038 L
.50295 .50089 L
.50266 .50129 L
.50231 .50157 L
Mistroke
.50193 .50175 L
.50153 .50182 L
.50113 .50181 L
.50075 .50173 L
.5004 .5016 L
.50009 .50142 L
.49983 .50121 L
.49962 .50099 L
.49945 .50077 L
.49934 .50055 L
.49927 .50034 L
.49924 .50015 L
.49924 .49999 L
.49928 .49985 L
.49933 .49974 L
.49941 .49966 L
.4995 .49961 L
.49959 .49958 L
.49968 .49957 L
.49978 .49958 L
.49986 .49961 L
.49994 .49964 L
.50001 .49969 L
.50007 .49974 L
.50011 .49979 L
.50014 .49984 L
.50017 .49989 L
.50018 .49994 L
.50018 .49998 L
.50018 .50002 L
.50016 .50005 L
.50015 .50007 L
.50013 .50009 L
.50011 .5001 L
.50009 .5001 L
.50006 .5001 L
.50004 .5001 L
.50002 .50009 L
.50001 .50008 L
.49999 .50007 L
.49998 .50006 L
.49997 .50004 L
.49996 .50003 L
.49996 .50002 L
.49996 .50001 L
.49996 .5 L
.49996 .49999 L
.49996 .49999 L
.49997 .49998 L
.49997 .49998 L
Mistroke
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.34023 .37022 m
.37079 .36152 L
s
% Start of user PostScript
-4.7932432 -3.8934302 -3.87631 -4.1544946 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40161 .35975 m
.43142 .36387 L
s
% Start of user PostScript
-2.9515715 -4.20751 -2.0572609 -4.083757 MAarrowhead1
% End of user PostScript
1 .473 0 r
.55468 .46797 m
.55815 .48297 L
s
% Start of user PostScript
1.6405238 -0.96087783 1.7444304 -0.51103049 MAarrowhead1
% End of user PostScript
1 .788 0 r
.52703 .53297 m
.51985 .53271 L
s
% Start of user PostScript
0.81079058 0.98897889 0.59550962 0.98120527 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48788 .50957 m
.48666 .50585 L
s
% Start of user PostScript
-0.36355604 0.28695059 -0.40006332 0.17562658 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49272 .49235 m
.49443 .49223 L
s
% Start of user PostScript
-0.21831925 -0.22937147 -0.16707736 -0.23308287 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50262 .49725 m
.50301 .49816 L
s
% Start of user PostScript
0.078613979 -0.082357764 0.090207263 -0.055093242 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50193 .50175 m
.50153 .50182 L
s
% Start of user PostScript
0.057811449 0.052398445 0.045761491 0.054692111 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49945 .50077 m
.49934 .50055 L
s
% Start of user PostScript
-0.016463123 0.022958348 -0.019931216 0.016350963 MAarrowhead1
% End of user PostScript
0 1 .679 r
.4995 .49961 m
.49959 .49958 L
s
% Start of user PostScript
-0.015088474 -0.011760564 -0.012292332 -0.012660232 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50011 .49979 m
.50014 .49984 L
s
% Start of user PostScript
0.0032969094 -0.0062560523 0.0042934988 -0.004672177 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50013 .50009 m
.50011 .5001 L
s
% Start of user PostScript
0.0038874579 0.0025838243 0.0032483235 0.0028857578 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49998 .50006 m
.49997 .50004 L
s
% Start of user PostScript
-0.00061646482 0.0016733571 -0.00089453423 0.0012980435 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49997 .49998 m
.49997 .49998 L
s
% Start of user PostScript
-0.0009898027 -0.00055256124 -0.0008462528 -0.00064599232 MAarrowhead1
% End of user PostScript
1 .041 0 r
.4291 .51401 m
.42963 .49889 L
.43288 .48625 L
.43829 .47619 L
.4453 .46869 L
.45338 .46365 L
.46202 .46087 L
.47079 .4601 L
.47933 .46105 L
.48732 .46341 L
.49453 .46685 L
.50081 .47107 L
.50604 .47576 L
.51019 .48067 L
.51327 .48557 L
.51533 .49025 L
.51644 .49458 L
.51671 .49842 L
.51628 .50171 L
.51526 .50441 L
.51379 .5065 L
.51201 .50799 L
.51004 .50892 L
.50798 .50935 L
.50593 .50933 L
.50397 .50894 L
.50217 .50826 L
.50057 .50736 L
.49921 .50631 L
.49809 .50517 L
.49723 .50401 L
.49662 .50288 L
.49625 .50181 L
.49608 .50084 L
.4961 .49999 L
.49627 .49928 L
.49656 .49872 L
.49694 .49829 L
.49739 .498 L
.49786 .49784 L
.49835 .49779 L
.49882 .49784 L
.49927 .49796 L
.49967 .49815 L
.50002 .49838 L
.50032 .49864 L
.50055 .49891 L
.50072 .49918 L
.50084 .49944 L
.50091 .49968 L
Mistroke
.50093 .4999 L
.5009 .50008 L
.50085 .50023 L
.50077 .50035 L
.50067 .50044 L
.50056 .50049 L
.50045 .50052 L
.50034 .50052 L
.50023 .5005 L
.50013 .50046 L
.50004 .50041 L
.49996 .50035 L
.4999 .50029 L
.49985 .50023 L
.49982 .50016 L
.49979 .5001 L
.49978 .50005 L
.49978 .5 L
.49979 .49996 L
.49981 .49993 L
.49983 .49991 L
.49985 .49989 L
.49988 .49988 L
.49991 .49988 L
.49993 .49988 L
.49996 .49989 L
.49998 .4999 L
.5 .49991 L
.50002 .49992 L
.50003 .49994 L
.50004 .49995 L
.50005 .49997 L
.50005 .49998 L
.50005 .49999 L
.50005 .5 L
.50005 .50001 L
.50004 .50002 L
.50004 .50002 L
.50003 .50003 L
.50003 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50003 L
.5 .50002 L
.5 .50002 L
.49999 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
Mistroke
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.4291 .51401 m
.42963 .49889 L
s
% Start of user PostScript
-2.1268662 0.42027716 -2.1112247 -0.033179314 MAarrowhead1
% End of user PostScript
1 .158 0 r
.43288 .48625 m
.43829 .47619 L
s
% Start of user PostScript
-2.0136671 -0.4125097 -1.8512457 -0.71444512 MAarrowhead1
% End of user PostScript
1 .473 0 r
.49453 .46685 m
.50081 .47107 L
s
% Start of user PostScript
-0.16407236 -0.99443888 0.024170116 -0.86801155 MAarrowhead1
% End of user PostScript
1 .788 0 r
.51628 .50171 m
.51526 .50441 L
s
% Start of user PostScript
0.48826897 0.051446558 0.45773356 0.13229486 MAarrowhead1
% End of user PostScript
.897 1 0 r
.50217 .50826 m
.50057 .50736 L
s
% Start of user PostScript
0.065145768 0.24782666 0.017181927 0.22073761 MAarrowhead1
% End of user PostScript
.581 1 0 r
.4961 .49999 m
.49627 .49928 L
s
% Start of user PostScript
-0.11711199 -0.00015688481 -0.11200702 -0.021463405 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49927 .49796 m
.49967 .49815 L
s
% Start of user PostScript
-0.021985725 -0.061121233 -0.0098998891 -0.055518376 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50093 .4999 m
.5009 .50008 L
s
% Start of user PostScript
0.027767902 -0.0030514948 0.02712007 0.002485899 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50023 .5005 m
.50013 .50046 L
s
% Start of user PostScript
0.0068255094 0.014918032 0.0038124257 0.013816346 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49978 .50005 m
.49978 .5 L
s
% Start of user PostScript
-0.0065023945 0.0015067189 -0.0064949773 0.00008551502 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49993 .49988 m
.49996 .49989 L
s
% Start of user PostScript
-0.0020118995 -0.0036025644 -0.0012685072 -0.0034027454 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50005 .49998 m
.50005 .49999 L
s
% Start of user PostScript
0.0015017526 -0.00055369162 0.0015375082 -0.00019312457 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50002 .50003 m
.50001 .50003 L
s
% Start of user PostScript
0.00057205429 0.00086038776 0.00039054375 0.00082934264 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49999 .50001 m
.49999 .5 L
s
% Start of user PostScript
-0.00034140558 0.00018003837 -0.00035939964 0.00008955404 MAarrowhead1
% End of user PostScript
1 .104 0 r
.47923 .31583 m
.51367 .341 L
.54204 .36848 L
.56417 .39681 L
.58019 .42472 L
.59042 .45116 L
.5954 .4753 L
.59576 .49656 L
.59224 .51455 L
.58559 .52906 L
.57659 .54008 L
.56597 .54773 L
.55441 .55224 L
.54254 .55394 L
.53087 .55321 L
.51984 .55047 L
.50979 .54615 L
.50096 .54068 L
.49351 .53446 L
.48751 .52786 L
.48298 .52121 L
.47985 .51477 L
.47804 .50878 L
.47739 .5034 L
.47775 .49875 L
.47894 .49489 L
.48079 .49186 L
.4831 .48964 L
.48572 .48819 L
.48849 .48744 L
.49128 .48732 L
.49396 .48773 L
.49646 .48856 L
.4987 .48971 L
.50063 .49109 L
.50223 .49261 L
.50348 .49417 L
.50439 .49572 L
.50498 .49719 L
.50527 .49854 L
.50531 .49973 L
.50513 .50074 L
.50477 .50156 L
.50428 .50218 L
.5037 .50262 L
.50306 .50288 L
.5024 .50298 L
.50175 .50295 L
.50114 .50281 L
.50058 .50257 L
Mistroke
.50009 .50228 L
.49967 .50193 L
.49933 .50157 L
.49907 .5012 L
.49889 .50084 L
.49879 .50051 L
.49875 .50021 L
.49876 .49995 L
.49883 .49973 L
.49893 .49956 L
.49905 .49943 L
.4992 .49935 L
.49935 .49931 L
.49951 .4993 L
.49966 .49932 L
.49979 .49936 L
.49992 .49943 L
.50003 .4995 L
.50012 .49958 L
.50019 .49967 L
.50024 .49976 L
.50027 .49984 L
.50029 .49991 L
.50029 .49998 L
.50028 .50004 L
.50027 .50008 L
.50024 .50012 L
.50021 .50014 L
.50017 .50016 L
.50014 .50017 L
.5001 .50016 L
.50007 .50016 L
.50003 .50014 L
.50001 .50013 L
.49998 .50011 L
.49996 .50009 L
.49995 .50007 L
.49994 .50005 L
.49993 .50003 L
.49993 .50001 L
.49993 .5 L
.49993 .49999 L
.49994 .49998 L
.49995 .49997 L
.49996 .49996 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49999 .49996 L
.5 .49997 L
Mistroke
.5 .49997 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.47923 .31583 m
.51367 .341 L
s
% Start of user PostScript
-0.62323376 -5.5250673 0.410136 -4.7701211 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54204 .36848 m
.56417 .39681 L
s
% Start of user PostScript
1.2612043 -3.9456205 1.9252043 -3.0957035 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57659 .54008 m
.56597 .54773 L
s
% Start of user PostScript
2.2976155 1.2024577 1.9790021 1.4319436 MAarrowhead1
% End of user PostScript
1 .788 0 r
.49351 .53446 m
.48751 .52786 L
s
% Start of user PostScript
-0.19484574 1.0337722 -0.37469468 0.83578763 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48079 .49186 m
.4831 .48964 L
s
% Start of user PostScript
-0.57643607 -0.24425672 -0.50695981 -0.31085699 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50063 .49109 m
.50223 .49261 L
s
% Start of user PostScript
0.018904774 -0.26727427 0.066767572 -0.22181907 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50477 .50156 m
.50428 .50218 L
s
% Start of user PostScript
0.14310318 0.046720048 0.1283904 0.065441607 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50009 .50228 m
.49967 .50193 L
s
% Start of user PostScript
0.0025731853 0.068271108 -0.0099734875 0.058008523 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49883 .49973 m
.49893 .49956 L
s
% Start of user PostScript
-0.035158713 -0.0080693548 -0.032164925 -0.013204893 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49992 .49943 m
.50003 .4995 L
s
% Start of user PostScript
-0.0024121024 -0.01724342 0.00083322963 -0.014972342 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50028 .50004 m
.50027 .50008 L
s
% Start of user PostScript
0.0085480802 0.0011180814 0.0079738996 0.0024993112 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50003 .50014 m
.50001 .50013 L
s
% Start of user PostScript
0.0010269931 0.0043087033 0.00019767445 0.0038184948 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49993 .5 m
.49993 .49999 L
s
% Start of user PostScript
-0.0020560077 -0.000057875001 -0.0019563453 -0.00042326615 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49999 .49996 m
.5 .49997 L
s
% Start of user PostScript
-0.00035720151 -0.0010654392 -0.0001476553 -0.00096302882 MAarrowhead1
% End of user PostScript
.383 1 0 r
.64364 .35981 m
.66295 .40801 L
.67264 .45215 L
.67387 .49112 L
.66796 .52419 L
.65627 .55098 L
.64021 .57143 L
.62112 .58574 L
.60026 .59432 L
.57873 .59776 L
.55751 .59673 L
.5374 .592 L
.51902 .58435 L
.50283 .57456 L
.48913 .56336 L
.47806 .55142 L
.46965 .53934 L
.4638 .52763 L
.46033 .51669 L
.45901 .50684 L
.45954 .4983 L
.46161 .4912 L
.46487 .48559 L
.46902 .48146 L
.47374 .47873 L
.47875 .47729 L
.48381 .47699 L
.48871 .47766 L
.49326 .47911 L
.49736 .48117 L
.5009 .48365 L
.50384 .48638 L
.50616 .48922 L
.50785 .49204 L
.50896 .49472 L
.50954 .49718 L
.50964 .49936 L
.50933 .50122 L
.50871 .50273 L
.50783 .50388 L
.50679 .5047 L
.50564 .5052 L
.50445 .50541 L
.50327 .50537 L
.50215 .50512 L
.50112 .50471 L
.50022 .50417 L
.49945 .50355 L
.49882 .5029 L
.49835 .50223 L
Mistroke
.49801 .50158 L
.49781 .50097 L
.49773 .50042 L
.49776 .49994 L
.49786 .49954 L
.49804 .49922 L
.49827 .49899 L
.49853 .49883 L
.4988 .49875 L
.49908 .49873 L
.49936 .49876 L
.49961 .49884 L
.49984 .49895 L
.50004 .49908 L
.5002 .49923 L
.50033 .49939 L
.50043 .49955 L
.50049 .4997 L
.50053 .49983 L
.50053 .49996 L
.50052 .50006 L
.50049 .50015 L
.50044 .50021 L
.50038 .50026 L
.50032 .50029 L
.50025 .5003 L
.50019 .5003 L
.50012 .50028 L
.50007 .50026 L
.50002 .50023 L
.49997 .5002 L
.49994 .50016 L
.49991 .50013 L
.49989 .50009 L
.49988 .50006 L
.49987 .50003 L
.49988 .5 L
.49988 .49998 L
.49989 .49996 L
.4999 .49994 L
.49992 .49994 L
.49993 .49993 L
.49995 .49993 L
.49996 .49993 L
.49998 .49994 L
.49999 .49994 L
.5 .49995 L
.50001 .49996 L
.50002 .49997 L
.50002 .49997 L
Mistroke
.50003 .49998 L
.50003 .49999 L
.50003 .5 L
.50003 .5 L
.50003 .50001 L
.50002 .50001 L
.50002 .50001 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.64364 .35981 m
.66295 .40801 L
s
% Start of user PostScript
4.3093214 -4.2056085 4.8885514 -2.7596304 MAarrowhead1
% End of user PostScript
1 .158 0 r
.67264 .45215 m
.67387 .49112 L
s
% Start of user PostScript
5.1792982 -1.4354372 5.2162492 -0.26643112 MAarrowhead1
% End of user PostScript
1 .473 0 r
.55751 .59673 m
.5374 .592 L
s
% Start of user PostScript
1.7253706 2.9019627 1.1220084 2.7600793 MAarrowhead1
% End of user PostScript
1 .788 0 r
.46033 .51669 m
.45901 .50684 L
s
% Start of user PostScript
-1.1899675 0.50069258 -1.2295844 0.20524587 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48381 .47699 m
.48871 .47766 L
s
% Start of user PostScript
-0.48563383 -0.69030106 -0.33884949 -0.6702503 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50896 .49472 m
.50954 .49718 L
s
% Start of user PostScript
0.26888958 -0.15836968 0.28608015 -0.084499685 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50445 .50541 m
.50327 .50537 L
s
% Start of user PostScript
0.13335041 0.16221925 0.098022964 0.16100953 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49801 .50158 m
.49781 .50097 L
s
% Start of user PostScript
-0.059565392 0.047255003 -0.065590629 0.028977725 MAarrowhead1
% End of user PostScript
0 1 .364 r
.4988 .49875 m
.49908 .49873 L
s
% Start of user PostScript
-0.035895328 -0.037613646 -0.027488312 -0.038239399 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50043 .49955 m
.50049 .4997 L
s
% Start of user PostScript
0.01287384 -0.01355462 0.014784689 -0.0090791358 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50032 .50029 m
.50025 .5003 L
s
% Start of user PostScript
0.0095025578 0.008590113 0.0075260223 0.0089706946 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49991 .50013 m
.49989 .50009 L
s
% Start of user PostScript
-0.0026942173 0.0037768292 -0.003265357 0.0026924299 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49992 .49994 m
.49993 .49993 L
s
% Start of user PostScript
-0.0024795168 -0.0019273459 -0.002020985 -0.0020760215 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50002 .49997 m
.50002 .49997 L
s
% Start of user PostScript
0.00053902579 -0.0010287978 0.00070304967 -0.00076890504 MAarrowhead1
% End of user PostScript
0 1 .221 r
.82936 .42599 m
.82856 .49762 L
.81475 .55784 L
.79058 .60608 L
.75866 .64233 L
.72152 .66707 L
.68149 .68116 L
.64063 .68574 L
.6007 .68216 L
.56316 .67187 L
.52911 .65635 L
.49937 .63708 L
.47443 .61542 L
.45452 .59262 L
.43962 .56978 L
.42953 .54781 L
.42387 .52746 L
.42217 .50928 L
.42385 .49364 L
.42831 .48077 L
.43492 .47074 L
.44307 .46348 L
.45219 .45885 L
.46176 .45661 L
.47132 .45647 L
.48049 .45809 L
.48897 .46112 L
.49653 .46522 L
.50301 .47006 L
.50834 .47531 L
.51247 .48071 L
.51545 .48602 L
.51732 .49103 L
.51821 .49559 L
.51822 .4996 L
.5175 .50298 L
.5162 .5057 L
.51446 .50776 L
.51242 .50917 L
.51021 .50999 L
.50795 .51028 L
.50573 .51011 L
.50364 .50957 L
.50174 .50873 L
.50008 .50767 L
.49867 .50648 L
.49755 .50522 L
.49671 .50395 L
.49613 .50273 L
.4958 .5016 L
Mistroke
.49569 .50058 L
.49577 .49971 L
.49601 .49898 L
.49637 .49841 L
.49681 .498 L
.49732 .49774 L
.49784 .4976 L
.49837 .49759 L
.49888 .49767 L
.49936 .49783 L
.49978 .49806 L
.50014 .49832 L
.50044 .49861 L
.50068 .49891 L
.50085 .49921 L
.50095 .49948 L
.50101 .49974 L
.50101 .49996 L
.50097 .50015 L
.5009 .50031 L
.50081 .50042 L
.5007 .5005 L
.50057 .50055 L
.50045 .50057 L
.50033 .50056 L
.50021 .50053 L
.5001 .50049 L
.50001 .50043 L
.49993 .50036 L
.49987 .50029 L
.49982 .50022 L
.49979 .50016 L
.49977 .50009 L
.49976 .50004 L
.49977 .49999 L
.49978 .49995 L
.4998 .49991 L
.49982 .49989 L
.49985 .49988 L
.49988 .49987 L
.49991 .49987 L
.49994 .49987 L
.49996 .49988 L
.49999 .49989 L
.50001 .49991 L
.50002 .49992 L
.50004 .49994 L
.50005 .49995 L
.50005 .49997 L
.50006 .49998 L
Mistroke
.50006 .5 L
.50005 .50001 L
.50005 .50002 L
.50005 .50002 L
.50004 .50003 L
.50003 .50003 L
.50003 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50003 L
.5 .50002 L
.5 .50002 L
.49999 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.82936 .42599 m
.82856 .49762 L
s
% Start of user PostScript
9.8807407 -2.2201766 9.8568356 -0.071483531 MAarrowhead1
% End of user PostScript
1 .158 0 r
.81475 .55784 m
.79058 .60608 L
s
% Start of user PostScript
9.4425963 1.7351106 8.7172536 3.1822821 MAarrowhead1
% End of user PostScript
1 .473 0 r
.52911 .65635 m
.49937 .63708 L
s
% Start of user PostScript
0.87340433 4.6906481 -0.018825467 4.112428 MAarrowhead1
% End of user PostScript
1 .788 0 r
.42385 .49364 m
.42831 .48077 L
s
% Start of user PostScript
-2.2843578 -0.19072208 -2.1506001 -0.57682398 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48897 .46112 m
.49653 .46522 L
s
% Start of user PostScript
-0.33087197 -1.1663422 -0.10408826 -1.0432755 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51822 .4996 m
.5175 .50298 L
s
% Start of user PostScript
0.54658739 -0.011936725 0.52506893 0.089496868 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50364 .50957 m
.50174 .50873 L
s
% Start of user PostScript
0.10922652 0.28701293 0.052214411 0.26179337 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49569 .50058 m
.49577 .49971 L
s
% Start of user PostScript
-0.12926449 0.01745443 -0.12684053 -0.0088338434 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49888 .49767 m
.49936 .49783 L
s
% Start of user PostScript
-0.033470314 -0.069894053 -0.01928875 -0.065004073 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50101 .49974 m
.50101 .49996 L
s
% Start of user PostScript
0.03018403 -0.00783793 0.030303285 -0.0011080928 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50033 .50056 m
.50021 .50053 L
s
% Start of user PostScript
0.0097797294 0.016839389 0.006288628 0.015973784 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49977 .50009 m
.49976 .50004 L
s
% Start of user PostScript
-0.0069488443 0.0027841797 -0.0071547562 0.0010808588 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49991 .49987 m
.49994 .49987 L
s
% Start of user PostScript
-0.0027629729 -0.004011779 -0.0019124885 -0.0038844403 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50005 .49997 m
.50006 .49998 L
s
% Start of user PostScript
0.0015738729 -0.00088939875 0.0016676491 -0.00046292696 MAarrowhead1
% End of user PostScript
0 1 .586 r
.83228 .73918 m
.77431 .76211 L
.71468 .77087 L
.65603 .7674 L
.60057 .75379 L
.54998 .73221 L
.50552 .70482 L
.46798 .67363 L
.43774 .6405 L
.41485 .60708 L
.39903 .57473 L
.3898 .5446 L
.38645 .51751 L
.38818 .49408 L
.39411 .47464 L
.40332 .45934 L
.41491 .44812 L
.42805 .44078 L
.44196 .43698 L
.45595 .43632 L
.46946 .4383 L
.48202 .44244 L
.49329 .44821 L
.50301 .45513 L
.51105 .46273 L
.51736 .4706 L
.52196 .47838 L
.52495 .48578 L
.52646 .49256 L
.52666 .49855 L
.52577 .50363 L
.52399 .50776 L
.52154 .51091 L
.51862 .51312 L
.51542 .51445 L
.51212 .51499 L
.50887 .51484 L
.50578 .51412 L
.50296 .51295 L
.50047 .51146 L
.49836 .50974 L
.49666 .50791 L
.49536 .50606 L
.49446 .50426 L
.49392 .50258 L
.49372 .50107 L
.49379 .49976 L
.49411 .49867 L
.49461 .4978 L
.49524 .49717 L
Mistroke
.49596 .49674 L
.49673 .49652 L
.49751 .49647 L
.49826 .49657 L
.49896 .49679 L
.49959 .49711 L
.50013 .49749 L
.50058 .49791 L
.50094 .49834 L
.5012 .49877 L
.50137 .49918 L
.50146 .49956 L
.50148 .4999 L
.50143 .50018 L
.50134 .50041 L
.5012 .50059 L
.50104 .50072 L
.50087 .5008 L
.50068 .50083 L
.5005 .50082 L
.50033 .50079 L
.50017 .50072 L
.50004 .50064 L
.49992 .50055 L
.49982 .50045 L
.49975 .50034 L
.4997 .50024 L
.49967 .50015 L
.49965 .50007 L
.49966 .49999 L
.49967 .49993 L
.4997 .49988 L
.49973 .49985 L
.49977 .49982 L
.49982 .49981 L
.49986 .4998 L
.4999 .49981 L
.49994 .49982 L
.49997 .49984 L
.50001 .49986 L
.50003 .49988 L
.50005 .49991 L
.50007 .49993 L
.50008 .49995 L
.50008 .49997 L
.50008 .49999 L
.50008 .50001 L
.50007 .50002 L
.50007 .50003 L
.50006 .50004 L
Mistroke
.50005 .50004 L
.50004 .50005 L
.50003 .50005 L
.50002 .50004 L
.50001 .50004 L
.5 .50004 L
.5 .50003 L
.49999 .50003 L
.49999 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.83228 .73918 m
.77431 .76211 L
s
% Start of user PostScript
9.9683156 7.1754004 8.2292718 7.86319 MAarrowhead1
% End of user PostScript
1 .158 0 r
.71468 .77087 m
.65603 .7674 L
s
% Start of user PostScript
6.4403331 8.1261131 4.6810489 8.021865 MAarrowhead1
% End of user PostScript
1 .473 0 r
.39903 .57473 m
.3898 .5446 L
s
% Start of user PostScript
-3.0289889 2.2420492 -3.3060673 1.3379196 MAarrowhead1
% End of user PostScript
1 .788 0 r
.44196 .43698 m
.45595 .43632 L
s
% Start of user PostScript
-1.7413069 -1.8905208 -1.3214814 -1.9105247 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52196 .47838 m
.52495 .48578 L
s
% Start of user PostScript
0.65890204 -0.64846393 0.74845438 -0.42651969 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51542 .51445 m
.51212 .51499 L
s
% Start of user PostScript
0.46271393 0.43341148 0.36371384 0.4495655 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49536 .50606 m
.49446 .50426 L
s
% Start of user PostScript
-0.13908924 0.18182176 -0.16617785 0.1279077 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49596 .49674 m
.49673 .49652 L
s
% Start of user PostScript
-0.12113596 -0.097685367 -0.098092388 -0.1043947 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50094 .49834 m
.5012 .49877 L
s
% Start of user PostScript
0.028174563 -0.049775495 0.036019573 -0.036819664 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50104 .50072 m
.50087 .5008 L
s
% Start of user PostScript
0.031296216 0.021572353 0.026010371 0.023881878 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49982 .50045 m
.49975 .50034 L
s
% Start of user PostScript
-0.00536548 0.013365146 -0.0075672787 0.010287043 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49973 .49985 m
.49977 .49982 L
s
% Start of user PostScript
-0.0079888211 -0.0046439585 -0.0067966669 -0.0053691038 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50003 .49988 m
.50005 .49991 L
s
% Start of user PostScript
0.00091921031 -0.0035305948 0.0015224404 -0.0028082061 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50007 .50003 m
.50006 .50004 L
s
% Start of user PostScript
0.0020164927 0.00096668541 0.0017530093 0.0011820267 MAarrowhead1
% End of user PostScript
.578 0 1 r
.6696 .82835 m
.60244 .80763 L
.54197 .77793 L
.48952 .74189 L
.44592 .70196 L
.41148 .66036 L
.38611 .61903 L
.36936 .57958 L
.36053 .54327 L
.35869 .51107 L
.3628 .48359 L
.37174 .46118 L
.38437 .44392 L
.3996 .43167 L
.41639 .42413 L
.43384 .42082 L
.45113 .42122 L
.46759 .4247 L
.48271 .43063 L
.4961 .43839 L
.50749 .44736 L
.51675 .457 L
.52386 .46681 L
.52887 .47637 L
.53192 .48535 L
.53321 .49346 L
.53296 .50054 L
.53143 .50646 L
.52889 .51117 L
.52561 .51467 L
.52182 .51703 L
.51778 .51833 L
.51367 .51869 L
.50967 .51824 L
.50593 .51713 L
.50255 .51552 L
.49961 .51354 L
.49716 .51135 L
.49522 .50905 L
.49378 .50675 L
.49282 .50456 L
.4923 .50253 L
.49217 .50073 L
.49238 .49919 L
.49286 .49793 L
.49354 .49695 L
.49438 .49626 L
.4953 .49582 L
.49627 .49562 L
.49723 .49563 L
Mistroke
.49814 .49581 L
.49899 .49613 L
.49973 .49656 L
.50037 .49705 L
.50089 .49758 L
.5013 .49812 L
.50158 .49865 L
.50176 .49915 L
.50184 .49961 L
.50183 .5 L
.50175 .50034 L
.50161 .5006 L
.50143 .5008 L
.50122 .50094 L
.501 .50101 L
.50077 .50103 L
.50055 .50101 L
.50034 .50095 L
.50015 .50087 L
.49999 .50076 L
.49985 .50064 L
.49974 .50051 L
.49966 .50038 L
.49961 .50026 L
.49958 .50015 L
.49957 .50005 L
.49958 .49996 L
.4996 .49989 L
.49964 .49983 L
.49969 .4998 L
.49974 .49977 L
.49979 .49976 L
.49984 .49976 L
.49989 .49977 L
.49994 .49978 L
.49998 .49981 L
.50002 .49983 L
.50005 .49986 L
.50007 .49989 L
.50009 .49992 L
.5001 .49995 L
.5001 .49998 L
.5001 .5 L
.5001 .50002 L
.50009 .50003 L
.50008 .50004 L
.50007 .50005 L
.50006 .50006 L
.50004 .50006 L
.50003 .50006 L
Mistroke
.50002 .50005 L
.50001 .50005 L
.5 .50004 L
.49999 .50004 L
.49999 .50003 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.6696 .82835 m
.60244 .80763 L
s
% Start of user PostScript
5.0878791 9.8504216 3.0731476 9.2287954 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54197 .77793 m
.48952 .74189 L
s
% Start of user PostScript
1.2589728 8.3379101 -0.31429484 7.2566196 MAarrowhead1
% End of user PostScript
1 .473 0 r
.3628 .48359 m
.37174 .46118 L
s
% Start of user PostScript
-4.1158992 -0.49228235 -3.8478233 -1.1645864 MAarrowhead1
% End of user PostScript
1 .788 0 r
.48271 .43063 m
.4961 .43839 L
s
% Start of user PostScript
-0.51855151 -2.0809923 -0.11703503 -1.8483398 MAarrowhead1
% End of user PostScript
.897 1 0 r
.53296 .50054 m
.53143 .50646 L
s
% Start of user PostScript
0.98875119 0.016184021 0.94294445 0.19373466 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50593 .51713 m
.50255 .51552 L
s
% Start of user PostScript
0.17786275 0.51398461 0.076534098 0.46558987 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49217 .50073 m
.49238 .49919 L
s
% Start of user PostScript
-0.23483061 0.021995228 -0.22865781 -0.024234972 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49814 .49581 m
.49899 .49613 L
s
% Start of user PostScript
-0.055733038 -0.125635 -0.030433613 -0.11603833 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50184 .49961 m
.50183 .5 L
s
% Start of user PostScript
0.055090752 -0.011775842 0.054847652 0.00010957663 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50055 .50101 m
.50034 .50095 L
s
% Start of user PostScript
0.016528889 0.030385845 0.010277838 0.028620239 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49958 .50015 m
.49957 .50005 L
s
% Start of user PostScript
-0.01274954 0.0044401417 -0.013005635 0.0014199677 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49984 .49976 m
.49989 .49977 L
s
% Start of user PostScript
-0.0047205683 -0.0072685713 -0.0031920256 -0.0069858729 MAarrowhead1
% End of user PostScript
0 .375 1 r
.5001 .49995 m
.5001 .49998 L
s
% Start of user PostScript
0.0029053343 -0.0014624117 0.0030457669 -0.00070335319 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50004 .50006 m
.50003 .50006 L
s
% Start of user PostScript
0.0013109664 0.0017184706 0.00094113244 0.0016871348 MAarrowhead1
% End of user PostScript
1 0 .219 r
.53504 .4593 m
.54094 .47208 L
.54425 .48392 L
.54526 .49451 L
.5443 .50362 L
.54172 .51112 L
.53789 .51697 L
.53315 .5212 L
.52785 .52391 L
.52229 .52522 L
.51673 .52532 L
.5114 .52439 L
.50646 .52263 L
.50206 .52025 L
.49828 .51744 L
.49518 .51439 L
.49277 .51125 L
.49103 .50816 L
.48993 .50524 L
.48942 .50259 L
.4894 .50025 L
.48982 .49828 L
.49057 .4967 L
.49158 .4955 L
.49277 .49467 L
.49405 .49419 L
.49537 .49402 L
.49665 .49412 L
.49787 .49443 L
.49898 .49492 L
.49995 .49553 L
.50076 .49623 L
.50142 .49696 L
.50191 .49769 L
.50225 .4984 L
.50244 .49906 L
.50251 .49966 L
.50246 .50017 L
.50232 .50059 L
.50211 .50092 L
.50186 .50116 L
.50156 .50132 L
.50126 .50139 L
.50095 .5014 L
.50065 .50136 L
.50038 .50126 L
.50013 .50113 L
.49992 .50098 L
.49974 .50081 L
.49961 .50064 L
Mistroke
.49951 .50046 L
.49945 .5003 L
.49942 .50015 L
.49941 .50002 L
.49943 .49991 L
.49947 .49982 L
.49953 .49975 L
.49959 .49971 L
.49967 .49968 L
.49974 .49967 L
.49981 .49967 L
.49988 .49969 L
.49994 .49972 L
.49999 .49975 L
.50004 .49979 L
.50008 .49983 L
.5001 .49987 L
.50012 .49991 L
.50013 .49995 L
.50014 .49998 L
.50014 .50001 L
.50013 .50003 L
.50012 .50005 L
.5001 .50006 L
.50009 .50007 L
.50007 .50008 L
.50005 .50008 L
.50004 .50008 L
.50002 .50007 L
.50001 .50006 L
.5 .50005 L
.49999 .50005 L
.49998 .50004 L
.49997 .50003 L
.49997 .50002 L
.49997 .50001 L
.49997 .5 L
.49997 .5 L
.49997 .49999 L
.49997 .49999 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
Mistroke
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.53504 .4593 m
.54094 .47208 L
s
% Start of user PostScript
1.0512303 -1.2211173 1.2280816 -0.83769989 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54425 .48392 m
.54526 .49451 L
s
% Start of user PostScript
1.3274301 -0.48233805 1.3577453 -0.16473851 MAarrowhead1
% End of user PostScript
1 .473 0 r
.51673 .52532 m
.5114 .52439 L
s
% Start of user PostScript
0.50195347 0.75953813 0.34185064 0.73157678 MAarrowhead1
% End of user PostScript
1 .788 0 r
.48993 .50524 m
.48942 .50259 L
s
% Start of user PostScript
-0.30196234 0.15734401 -0.31753251 0.077611252 MAarrowhead1
% End of user PostScript
.897 1 0 r
.49537 .49402 m
.49665 .49412 L
s
% Start of user PostScript
-0.13904689 -0.17934476 -0.10035322 -0.17648072 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50225 .4984 m
.50244 .49906 L
s
% Start of user PostScript
0.067433031 -0.047867912 0.07322887 -0.028061254 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50126 .50139 m
.50095 .5014 L
s
% Start of user PostScript
0.037697836 0.041805756 0.028449122 0.042100883 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49951 .50046 m
.49945 .5003 L
s
% Start of user PostScript
-0.014722844 0.013917707 -0.016619679 0.0090483668 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49967 .49968 m
.49974 .49967 L
s
% Start of user PostScript
-0.010040533 -0.0096055177 -0.0078557288 -0.0099244804 MAarrowhead1
% End of user PostScript
0 1 .679 r
.5001 .49987 m
.50012 .49991 L
s
% Start of user PostScript
0.003122977 -0.0039177025 0.0037011906 -0.0027330641 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50009 .50007 m
.50007 .50008 L
s
% Start of user PostScript
0.0026338572 0.0021706193 0.0021243246 0.0023091678 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49998 .50004 m
.49997 .50003 L
s
% Start of user PostScript
-0.00063695346 0.0010758362 -0.00080530026 0.00079071277 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49998 .49998 m
.49998 .49998 L
s
% Start of user PostScript
-0.00068170443 -0.00048087575 -0.00056456655 -0.00052945672 MAarrowhead1
% End of user PostScript
0 .06 1 r
.5 .49999 m
.50001 .49999 L
s
% Start of user PostScript
0.00012260501 -0.00028961018 0.00017004111 -0.00022175577 MAarrowhead1
% End of user PostScript
0 .89 1 r
.34167 .23046 m
.39763 .24399 L
.44869 .26558 L
.49362 .29308 L
.53158 .32445 L
.56219 .35779 L
.5854 .39147 L
.60146 .42409 L
.61089 .4545 L
.61437 .48185 L
.61272 .50553 L
.60683 .5252 L
.59761 .54069 L
.58596 .55207 L
.57275 .55955 L
.55875 .56344 L
.54465 .56417 L
.53103 .56221 L
.51835 .55809 L
.50698 .5523 L
.49715 .54535 L
.48901 .5377 L
.48262 .52977 L
.47795 .52193 L
.47491 .51446 L
.47337 .50762 L
.47313 .50157 L
.47401 .49643 L
.47579 .49226 L
.47825 .48906 L
.48118 .48682 L
.4844 .48546 L
.48772 .48491 L
.491 .48504 L
.49412 .48576 L
.49697 .48692 L
.49948 .48843 L
.50161 .49015 L
.50333 .49199 L
.50465 .49386 L
.50557 .49567 L
.50611 .49736 L
.50633 .49889 L
.50626 .50022 L
.50594 .50132 L
.50545 .5022 L
.50481 .50284 L
.50408 .50327 L
.50331 .5035 L
.50253 .50355 L
Mistroke
.50177 .50346 L
.50106 .50324 L
.50043 .50292 L
.49988 .50254 L
.49942 .50212 L
.49906 .50168 L
.49879 .50124 L
.49862 .50083 L
.49853 .50045 L
.49851 .50011 L
.49856 .49982 L
.49865 .49959 L
.49878 .49941 L
.49895 .49928 L
.49912 .4992 L
.49931 .49917 L
.49949 .49917 L
.49966 .49921 L
.49982 .49927 L
.49996 .49935 L
.50008 .49945 L
.50018 .49955 L
.50025 .49965 L
.50031 .49975 L
.50034 .49985 L
.50035 .49993 L
.50035 .50001 L
.50033 .50007 L
.5003 .50012 L
.50027 .50016 L
.50023 .50018 L
.50019 .50019 L
.50014 .5002 L
.5001 .50019 L
.50006 .50018 L
.50003 .50016 L
.5 .50014 L
.49997 .50012 L
.49995 .50009 L
.49993 .50007 L
.49992 .50005 L
.49992 .50003 L
.49992 .50001 L
.49992 .49999 L
.49992 .49998 L
.49993 .49997 L
.49994 .49996 L
.49995 .49996 L
.49996 .49995 L
.49997 .49995 L
Mistroke
.49998 .49996 L
.49999 .49996 L
.5 .49996 L
.5 .49997 L
.50001 .49997 L
.50001 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.34167 .23046 m
.39763 .24399 L
s
% Start of user PostScript
-4.7499759 -8.0862875 -3.0712168 -7.6804119 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44869 .26558 m
.49362 .29308 L
s
% Start of user PostScript
-1.5391536 -7.0325594 -0.19150217 -6.2074851 MAarrowhead1
% End of user PostScript
1 .473 0 r
.61272 .50553 m
.60683 .5252 L
s
% Start of user PostScript
3.3815951 0.16602962 3.2047735 0.75586742 MAarrowhead1
% End of user PostScript
1 .788 0 r
.51835 .55809 m
.50698 .5523 L
s
% Start of user PostScript
0.55051813 1.742602 0.20925157 1.5689623 MAarrowhead1
% End of user PostScript
.897 1 0 r
.47313 .50157 m
.47401 .49643 L
s
% Start of user PostScript
-0.80605786 0.047160493 -0.77970803 -0.10707063 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49412 .48576 m
.49697 .48692 L
s
% Start of user PostScript
-0.17650897 -0.427336 -0.091021471 -0.39231464 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50633 .49889 m
.50626 .50022 L
s
% Start of user PostScript
0.18984744 -0.033234992 0.18767175 0.0065685539 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50177 .50346 m
.50106 .50324 L
s
% Start of user PostScript
0.053124928 0.10369946 0.031933972 0.097075694 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49853 .50045 m
.49851 .50011 L
s
% Start of user PostScript
-0.044129899 0.01343851 -0.044664758 0.0032881911 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49949 .49917 m
.49966 .49921 L
s
% Start of user PostScript
-0.015331576 -0.024892544 -0.010132992 -0.023772326 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50034 .49985 m
.50035 .49993 L
s
% Start of user PostScript
0.010107162 -0.0045724192 0.010501887 -0.002012745 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50014 .5002 m
.5001 .50019 L
s
% Start of user PostScript
0.0042917205 0.0059072523 0.0030297221 0.0057604227 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49992 .50005 m
.49992 .50003 L
s
% Start of user PostScript
-0.0022754135 0.001426205 -0.0024365561 0.00078757365 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49996 .49995 m
.49997 .49995 L
s
% Start of user PostScript
-0.0011733661 -0.0013846041 -0.00087030827 -0.0013806844 MAarrowhead1
% End of user PostScript
1 0 .949 r
.70322 .24258 m
.7413 .32006 L
.76361 .3923 L
.7718 .45724 L
.76781 .51347 L
.75375 .56013 L
.7318 .5969 L
.7041 .62389 L
.67269 .64159 L
.63941 .65079 L
.6059 .65248 L
.57354 .6478 L
.54343 .63796 L
.51642 .62419 L
.49309 .60766 L
.47378 .58948 L
.45862 .57064 L
.44755 .552 L
.44035 .53427 L
.43669 .51802 L
.43615 .50365 L
.43826 .49145 L
.44249 .48155 L
.44834 .47397 L
.45532 .46866 L
.46297 .46545 L
.47087 .46413 L
.47866 .46446 L
.48606 .46616 L
.49283 .46894 L
.4988 .47252 L
.50385 .47662 L
.50795 .481 L
.51106 .48543 L
.51324 .48974 L
.51453 .49376 L
.51504 .49739 L
.51486 .50054 L
.51412 .50316 L
.51293 .50524 L
.51142 .50677 L
.50969 .50778 L
.50785 .50833 L
.506 .50845 L
.5042 .50821 L
.50252 .50769 L
.50101 .50694 L
.4997 .50603 L
.49862 .50503 L
.49776 .50399 L
Mistroke
.49713 .50295 L
.49672 .50197 L
.4965 .50106 L
.49646 .50026 L
.49657 .49957 L
.4968 .49901 L
.49711 .49859 L
.4975 .49828 L
.49792 .4981 L
.49836 .49802 L
.49879 .49803 L
.4992 .49812 L
.49958 .49827 L
.49991 .49846 L
.50019 .49869 L
.50043 .49893 L
.5006 .49918 L
.50073 .49941 L
.5008 .49964 L
.50083 .49984 L
.50082 .50002 L
.50079 .50017 L
.50072 .50028 L
.50064 .50037 L
.50054 .50043 L
.50044 .50046 L
.50034 .50047 L
.50024 .50046 L
.50015 .50043 L
.50006 .50039 L
.49999 .50034 L
.49993 .50028 L
.49988 .50022 L
.49984 .50017 L
.49982 .50011 L
.49981 .50006 L
.4998 .50002 L
.49981 .49998 L
.49982 .49995 L
.49984 .49992 L
.49986 .49991 L
.49988 .4999 L
.49991 .49989 L
.49993 .49989 L
.49995 .4999 L
.49998 .4999 L
.49999 .49991 L
.50001 .49993 L
.50002 .49994 L
.50003 .49995 L
Mistroke
.50004 .49997 L
.50004 .49998 L
.50005 .49999 L
.50005 .5 L
.50004 .50001 L
.50004 .50002 L
.50004 .50002 L
.50003 .50002 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.70322 .24258 m
.7413 .32006 L
s
% Start of user PostScript
6.0965866 -7.7224801 7.2389198 -5.3981598 MAarrowhead1
% End of user PostScript
1 .158 0 r
.76361 .3923 m
.7718 .45724 L
s
% Start of user PostScript
7.9083772 -3.2311221 8.1541043 -1.2827754 MAarrowhead1
% End of user PostScript
1 .473 0 r
.6059 .65248 m
.57354 .6478 L
s
% Start of user PostScript
3.1771232 4.574362 2.2062159 4.4340277 MAarrowhead1
% End of user PostScript
1 .788 0 r
.44035 .53427 m
.43669 .51802 L
s
% Start of user PostScript
-1.7895521 1.0280566 -1.899235 0.54050516 MAarrowhead1
% End of user PostScript
.897 1 0 r
.47087 .46413 m
.47866 .46446 L
s
% Start of user PostScript
-0.87394554 -1.0760471 -0.64006813 -1.0660908 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51324 .48974 m
.51453 .49376 L
s
% Start of user PostScript
0.39711295 -0.30791868 0.43598486 -0.18718661 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50785 .50833 m
.506 .50845 L
s
% Start of user PostScript
0.23558965 0.24978211 0.17988149 0.25343093 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49713 .50295 m
.49672 .50197 L
s
% Start of user PostScript
-0.08601585 0.088560357 -0.09841805 0.058972672 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49792 .4981 m
.49836 .49802 L
s
% Start of user PostScript
-0.062444502 -0.057118054 -0.049334072 -0.059513742 MAarrowhead1
% End of user PostScript
0 1 .679 r
.5006 .49918 m
.50073 .49941 L
s
% Start of user PostScript
0.018054163 -0.024726504 0.021775348 -0.017551392 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50054 .50043 m
.50044 .50046 L
s
% Start of user PostScript
0.016311411 0.01283501 0.013266556 0.013788541 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49988 .50022 m
.49984 .50017 L
s
% Start of user PostScript
-0.0036274255 0.0067463963 -0.004699001 0.0050252444 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49986 .49991 m
.49988 .4999 L
s
% Start of user PostScript
-0.0042057408 -0.0028239886 -0.0035090656 -0.0031461447 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50002 .49994 m
.50003 .49995 L
s
% Start of user PostScript
0.00068187725 -0.0018064167 0.00098134719 -0.0013982736 MAarrowhead1
% End of user PostScript
0 1 .743 r
.64691 .59636 m
.62299 .60797 L
.59799 .6134 L
.57309 .61342 L
.54926 .60891 L
.52729 .60076 L
.50775 .5899 L
.49104 .57718 L
.47738 .56341 L
.46681 .54933 L
.45926 .53553 L
.45456 .52252 L
.45242 .5107 L
.45254 .50036 L
.45453 .49165 L
.45802 .48468 L
.46263 .47944 L
.46799 .47587 L
.47378 .47383 L
.47968 .47317 L
.48545 .47368 L
.49087 .47517 L
.49579 .47741 L
.50009 .48019 L
.50369 .48332 L
.50657 .48662 L
.50872 .48992 L
.51018 .49309 L
.511 .49603 L
.51124 .49866 L
.511 .50092 L
.51036 .50278 L
.5094 .50423 L
.50822 .50527 L
.50691 .50594 L
.50553 .50627 L
.50414 .50629 L
.50282 .50606 L
.50159 .50562 L
.5005 .50502 L
.49957 .50433 L
.4988 .50357 L
.4982 .50279 L
.49777 .50202 L
.4975 .5013 L
.49737 .50064 L
.49737 .50006 L
.49747 .49957 L
.49766 .49918 L
.49791 .49888 L
Mistroke
.49821 .49868 L
.49852 .49856 L
.49885 .49851 L
.49917 .49854 L
.49947 .49862 L
.49975 .49874 L
.49999 .49889 L
.50019 .49906 L
.50035 .49925 L
.50048 .49943 L
.50056 .49961 L
.50061 .49977 L
.50062 .49992 L
.50061 .50004 L
.50058 .50015 L
.50052 .50023 L
.50046 .50029 L
.50039 .50033 L
.50031 .50035 L
.50023 .50035 L
.50016 .50034 L
.50009 .50031 L
.50003 .50028 L
.49998 .50024 L
.49994 .5002 L
.4999 .50016 L
.49988 .50011 L
.49986 .50007 L
.49985 .50004 L
.49985 .50001 L
.49986 .49998 L
.49987 .49996 L
.49988 .49994 L
.4999 .49993 L
.49992 .49992 L
.49994 .49992 L
.49995 .49992 L
.49997 .49992 L
.49999 .49993 L
.5 .49994 L
.50001 .49995 L
.50002 .49996 L
.50003 .49997 L
.50003 .49998 L
.50003 .49999 L
.50003 .49999 L
.50003 .5 L
.50003 .50001 L
.50003 .50001 L
.50003 .50002 L
Mistroke
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.64691 .59636 m
.62299 .60797 L
s
% Start of user PostScript
4.407299 2.8907048 3.6897351 3.2390866 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59799 .6134 m
.57309 .61342 L
s
% Start of user PostScript
2.9398195 3.402008 2.1927352 3.4027282 MAarrowhead1
% End of user PostScript
1 .473 0 r
.45926 .53553 m
.45456 .52252 L
s
% Start of user PostScript
-1.2221947 1.0657997 -1.3633452 0.67565602 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47378 .47383 m
.47968 .47317 L
s
% Start of user PostScript
-0.78674258 -0.78503988 -0.60965017 -0.80494247 MAarrowhead1
% End of user PostScript
.897 1 0 r
.50872 .48992 m
.51018 .49309 L
s
% Start of user PostScript
0.26161317 -0.30251321 0.30537395 -0.2073112 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50691 .50594 m
.50553 .50627 L
s
% Start of user PostScript
0.20723504 0.17829392 0.16577705 0.18801508 MAarrowhead1
% End of user PostScript
.266 1 0 r
.4982 .50279 m
.49777 .50202 L
s
% Start of user PostScript
-0.054035575 0.083613067 -0.066922892 0.060628025 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49821 .49868 m
.49852 .49856 L
s
% Start of user PostScript
-0.053835474 -0.039739408 -0.044263621 -0.043298701 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50035 .49925 m
.50048 .49943 L
s
% Start of user PostScript
0.010603182 -0.022627883 0.014265091 -0.017139793 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50046 .50029 m
.50039 .50033 L
s
% Start of user PostScript
0.013811743 0.0086555914 0.011636493 0.0098107705 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49994 .5002 m
.4999 .50016 L
s
% Start of user PostScript
-0.001916415 0.0060175788 -0.0029294075 0.0047226363 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49988 .49994 m
.4999 .49993 L
s
% Start of user PostScript
-0.0035028244 -0.0018302044 -0.0030176294 -0.002180538 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50001 .49995 m
.50002 .49996 L
s
% Start of user PostScript
0.00029548547 -0.0015764486 0.00056981696 -0.0012748319 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50003 .50001 m
.50003 .50002 L
s
% Start of user PostScript
0.00087872509 0.00037162037 0.0007729472 0.00047326079 MAarrowhead1
% End of user PostScript
1 0 .923 r
.59205 .40875 m
.60469 .43986 L
.6111 .46838 L
.61205 .49359 L
.60836 .515 L
.60093 .53238 L
.59065 .54567 L
.57841 .55501 L
.56499 .56064 L
.55113 .56295 L
.53744 .56236 L
.52446 .55938 L
.51259 .5545 L
.50211 .54823 L
.49324 .54103 L
.48606 .53335 L
.48059 .52557 L
.47677 .51801 L
.4745 .51095 L
.47361 .50458 L
.47392 .49906 L
.47522 .49445 L
.4773 .49081 L
.47996 .48812 L
.48299 .48634 L
.48622 .48539 L
.48948 .48517 L
.49263 .48559 L
.49558 .48651 L
.49823 .48783 L
.50052 .48942 L
.50243 .49118 L
.50393 .493 L
.50503 .49482 L
.50576 .49655 L
.50614 .49814 L
.50621 .49955 L
.50602 .50075 L
.50562 .50173 L
.50506 .50248 L
.50439 .50302 L
.50365 .50334 L
.50289 .50348 L
.50213 .50346 L
.5014 .5033 L
.50074 .50304 L
.50016 .5027 L
.49966 .5023 L
.49925 .50188 L
.49894 .50145 L
Mistroke
.49873 .50103 L
.49859 .50063 L
.49854 .50028 L
.49855 .49997 L
.49862 .49971 L
.49873 .4995 L
.49888 .49935 L
.49905 .49925 L
.49922 .49919 L
.4994 .49918 L
.49958 .4992 L
.49974 .49925 L
.49989 .49932 L
.50002 .49941 L
.50013 .4995 L
.50021 .49961 L
.50027 .49971 L
.50032 .4998 L
.50034 .49989 L
.50034 .49997 L
.50033 .50004 L
.50031 .50009 L
.50028 .50013 L
.50025 .50017 L
.50021 .50018 L
.50016 .50019 L
.50012 .50019 L
.50008 .50018 L
.50004 .50017 L
.50001 .50015 L
.49998 .50013 L
.49996 .50011 L
.49994 .50008 L
.49993 .50006 L
.49992 .50004 L
.49992 .50002 L
.49992 .5 L
.49992 .49998 L
.49993 .49997 L
.49994 .49996 L
.49995 .49996 L
.49996 .49996 L
.49997 .49995 L
.49998 .49996 L
.49999 .49996 L
.49999 .49996 L
.5 .49997 L
.50001 .49997 L
.50001 .49998 L
.50002 .49998 L
Mistroke
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.59205 .40875 m
.60469 .43986 L
s
% Start of user PostScript
2.7616344 -2.7375704 3.1405577 -1.8042486 MAarrowhead1
% End of user PostScript
1 .158 0 r
.6111 .46838 m
.61205 .49359 L
s
% Start of user PostScript
3.3330575 -0.94861374 3.3613648 -0.19241024 MAarrowhead1
% End of user PostScript
1 .473 0 r
.53744 .56236 m
.52446 .55938 L
s
% Start of user PostScript
1.1233149 1.8709409 0.73384354 1.7814593 MAarrowhead1
% End of user PostScript
1 .788 0 r
.4745 .51095 m
.47361 .50458 L
s
% Start of user PostScript
-0.76512902 0.32851675 -0.79180051 0.13751524 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48948 .48517 m
.49263 .48559 L
s
% Start of user PostScript
-0.31568963 -0.44475912 -0.22099563 -0.43234994 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50576 .49655 m
.50614 .49814 L
s
% Start of user PostScript
0.17271778 -0.10349747 0.18408245 -0.055769693 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50289 .50348 m
.50213 .50346 L
s
% Start of user PostScript
0.086580412 0.1044436 0.063803737 0.10379656 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49873 .50103 m
.49859 .50063 L
s
% Start of user PostScript
-0.038214327 0.030802648 -0.042168369 0.019000409 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49922 .49919 m
.4994 .49918 L
s
% Start of user PostScript
-0.023282516 -0.024198147 -0.017865766 -0.02463529 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50027 .49971 m
.50032 .4998 L
s
% Start of user PostScript
0.0082464139 -0.0088192552 0.00949533 -0.0059309601 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50021 .50018 m
.50016 .50019 L
s
% Start of user PostScript
0.006158322 0.0055213034 0.004885711 0.0057751288 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49994 .50008 m
.49993 .50006 L
s
% Start of user PostScript
-0.0017221867 0.002453949 -0.0020945066 0.0017545371 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49995 .49996 m
.49996 .49996 L
s
% Start of user PostScript
-0.0016056942 -0.0012374693 -0.0013106961 -0.0013354229 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50001 .49998 m
.50002 .49998 L
s
% Start of user PostScript
0.00034350493 -0.00066770064 0.00045023247 -0.00050018016 MAarrowhead1
% End of user PostScript
1 .129 0 r
.30567 .77895 m
.26328 .6997 L
.23717 .6252 L
.22576 .55764 L
.22715 .49863 L
.23922 .44915 L
.25979 .40964 L
.28666 .38009 L
.31775 .36008 L
.35113 .34888 L
.38511 .34552 L
.41823 .34887 L
.4493 .35773 L
.47741 .37086 L
.50191 .38705 L
.5224 .40515 L
.53871 .42414 L
.55085 .44311 L
.559 .46132 L
.56349 .47814 L
.56472 .49314 L
.56316 .50601 L
.55933 .51657 L
.55374 .52477 L
.5469 .53067 L
.53928 .53439 L
.53131 .53614 L
.52337 .53616 L
.51577 .53474 L
.50876 .53215 L
.50253 .52869 L
.49719 .52464 L
.49283 .52026 L
.48945 .51577 L
.48703 .51137 L
.48552 .50722 L
.48484 .50345 L
.48487 .50014 L
.4855 .49736 L
.48661 .49514 L
.48807 .49346 L
.48978 .49232 L
.49162 .49166 L
.4935 .49145 L
.49534 .49161 L
.49707 .49208 L
.49864 .49279 L
.50002 .49368 L
.50117 .49467 L
.50209 .49572 L
Mistroke
.50277 .49678 L
.50324 .49779 L
.5035 .49873 L
.50358 .49956 L
.50351 .50029 L
.5033 .50088 L
.503 .50134 L
.50263 .50168 L
.50221 .50189 L
.50177 .502 L
.50133 .502 L
.5009 .50193 L
.50051 .50179 L
.50016 .5016 L
.49986 .50138 L
.49962 .50114 L
.49943 .50089 L
.49929 .50065 L
.4992 .50042 L
.49916 .50021 L
.49916 .50002 L
.49919 .49986 L
.49925 .49974 L
.49933 .49964 L
.49943 .49958 L
.49953 .49954 L
.49963 .49953 L
.49973 .49953 L
.49983 .49956 L
.49992 .4996 L
.5 .49965 L
.50006 .4997 L
.50011 .49976 L
.50015 .49982 L
.50018 .49987 L
.50019 .49993 L
.5002 .49997 L
.50019 .50001 L
.50018 .50005 L
.50017 .50007 L
.50015 .50009 L
.50012 .5001 L
.5001 .50011 L
.50008 .50011 L
.50005 .50011 L
.50003 .5001 L
.50001 .50009 L
.49999 .50008 L
.49998 .50006 L
.49997 .50005 L
Mistroke
.49996 .50004 L
.49996 .50002 L
.49995 .50001 L
.49995 .5 L
.49996 .49999 L
.49996 .49999 L
.49996 .49998 L
.49997 .49998 L
.49997 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.30567 .77895 m
.26328 .6997 L
s
% Start of user PostScript
-5.8299906 8.3683629 -7.1015232 5.9910775 MAarrowhead1
% End of user PostScript
1 .158 0 r
.23717 .6252 m
.22576 .55764 L
s
% Start of user PostScript
-7.8849323 3.7558672 -8.2272545 1.7293081 MAarrowhead1
% End of user PostScript
1 .473 0 r
.38511 .34552 m
.41823 .34887 L
s
% Start of user PostScript
-3.446669 -4.6344702 -2.4531295 -4.5337837 MAarrowhead1
% End of user PostScript
1 .788 0 r
.559 .46132 m
.56349 .47814 L
s
% Start of user PostScript
1.7701428 -1.1604961 1.9047901 -0.65566228 MAarrowhead1
% End of user PostScript
.897 1 0 r
.53131 .53614 m
.52337 .53616 L
s
% Start of user PostScript
0.93943341 1.0841736 0.70123713 1.0848682 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48703 .51137 m
.48552 .50722 L
s
% Start of user PostScript
-0.38901575 0.34098873 -0.43426213 0.21653336 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49162 .49166 m
.4935 .49145 L
s
% Start of user PostScript
-0.25132938 -0.25011414 -0.19487848 -0.25657765 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50277 .49678 m
.50324 .49779 L
s
% Start of user PostScript
0.08322333 -0.096732117 0.097235009 -0.066368583 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50221 .50189 m
.50177 .502 L
s
% Start of user PostScript
0.066184688 0.056786781 0.052972472 0.059915791 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49943 .50089 m
.49929 .50065 L
s
% Start of user PostScript
-0.017176439 0.026724886 -0.021299663 0.019395528 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49943 .49958 m
.49953 .49954 L
s
% Start of user PostScript
-0.017189354 -0.012652284 -0.014139724 -0.013794448 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50011 .49976 m
.50015 .49982 L
s
% Start of user PostScript
0.0033665942 -0.0072299531 0.0045375526 -0.0054803015 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50015 .50009 m
.50012 .5001 L
s
% Start of user PostScript
0.0044090515 0.0027544812 0.0037162238 0.0031245947 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49998 .50006 m
.49997 .50005 L
s
% Start of user PostScript
-0.00060727801 0.0019221462 -0.00093106094 0.0015093997 MAarrowhead1
% End of user PostScript
.424 0 1 r
.38121 .67914 m
.35373 .62934 L
.33651 .58237 L
.32859 .53964 L
.3288 .50219 L
.33582 .47066 L
.34828 .44537 L
.36481 .42632 L
.38409 .41328 L
.40491 .4058 L
.42619 .40329 L
.447 .40504 L
.4666 .41032 L
.48438 .41833 L
.49993 .42832 L
.51299 .43958 L
.52343 .45144 L
.53126 .46334 L
.53658 .4748 L
.53959 .48542 L
.54053 .49493 L
.5397 .50311 L
.53741 .50985 L
.53399 .51511 L
.52977 .51893 L
.52503 .52138 L
.52005 .52258 L
.51507 .52268 L
.51029 .52186 L
.50586 .5203 L
.50191 .51817 L
.49852 .51566 L
.49573 .51293 L
.49356 .51012 L
.49199 .50736 L
.491 .50474 L
.49053 .50236 L
.49051 .50026 L
.49087 .49849 L
.49154 .49707 L
.49244 .49599 L
.4935 .49524 L
.49465 .4948 L
.49583 .49465 L
.49698 .49473 L
.49808 .49501 L
.49907 .49544 L
.49994 .49599 L
.50067 .49661 L
.50126 .49726 L
Mistroke
.5017 .49792 L
.50201 .49856 L
.50218 .49915 L
.50224 .49968 L
.5022 .50014 L
.50208 .50052 L
.5019 .50082 L
.50167 .50104 L
.50141 .50118 L
.50113 .50125 L
.50085 .50126 L
.50059 .50121 L
.50034 .50113 L
.50012 .50102 L
.49993 .50088 L
.49977 .50073 L
.49965 .50057 L
.49956 .50042 L
.4995 .50027 L
.49948 .50014 L
.49947 .50002 L
.49949 .49992 L
.49953 .49984 L
.49958 .49978 L
.49964 .49974 L
.4997 .49971 L
.49976 .4997 L
.49983 .49971 L
.49989 .49972 L
.49994 .49975 L
.49999 .49978 L
.50003 .49981 L
.50007 .49985 L
.50009 .49988 L
.50011 .49992 L
.50012 .49995 L
.50012 .49998 L
.50012 .50001 L
.50012 .50003 L
.50011 .50004 L
.50009 .50006 L
.50008 .50006 L
.50006 .50007 L
.50005 .50007 L
.50003 .50007 L
.50002 .50006 L
.50001 .50006 L
.5 .50005 L
.49999 .50004 L
.49998 .50003 L
Mistroke
.49998 .50002 L
.49997 .50002 L
.49997 .50001 L
.49997 .5 L
.49997 .5 L
.49997 .49999 L
.49998 .49999 L
.49998 .49999 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.38121 .67914 m
.35373 .62934 L
s
% Start of user PostScript
-3.5638123 5.3741143 -4.3881931 3.8802529 MAarrowhead1
% End of user PostScript
1 .158 0 r
.33651 .58237 m
.32859 .53964 L
s
% Start of user PostScript
-4.9047428 2.4710502 -5.1422249 1.1892686 MAarrowhead1
% End of user PostScript
1 .473 0 r
.42619 .40329 m
.447 .40504 L
s
% Start of user PostScript
-2.2143177 -2.9014042 -1.589863 -2.848667 MAarrowhead1
% End of user PostScript
1 .788 0 r
.53658 .4748 m
.53959 .48542 L
s
% Start of user PostScript
1.0975427 -0.75604338 1.1876764 -0.43729362 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52005 .52258 m
.51507 .52268 L
s
% Start of user PostScript
0.60153384 0.67725323 0.45210221 0.68036384 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49199 .50736 m
.491 .50474 L
s
% Start of user PostScript
-0.2402382 0.22067874 -0.27001989 0.14223328 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49465 .4948 m
.49583 .49465 L
s
% Start of user PostScript
-0.16048244 -0.15585146 -0.12513876 -0.16058459 MAarrowhead1
% End of user PostScript
0 1 .049 r
.5017 .49792 m
.50201 .49856 L
s
% Start of user PostScript
0.0511283 -0.062298282 0.06025929 -0.04319317 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50141 .50118 m
.50113 .50125 L
s
% Start of user PostScript
0.04215944 0.035282806 0.033905443 0.037415902 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49965 .50057 m
.49956 .50042 L
s
% Start of user PostScript
-0.010476576 0.017146404 -0.013145558 0.012542987 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49964 .49974 m
.4997 .49971 L
s
% Start of user PostScript
-0.010926067 -0.0078337407 -0.0090255957 -0.0085924965 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50007 .49985 m
.50009 .49988 L
s
% Start of user PostScript
0.0020310892 -0.0046243113 0.0027853365 -0.003527484 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50009 .50006 m
.50008 .50006 L
s
% Start of user PostScript
0.0027970233 0.0016979796 0.0023665062 0.0019405401 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49999 .50004 m
.49998 .50003 L
s
% Start of user PostScript
-0.00035944784 0.001226188 -0.00056720913 0.00096797714 MAarrowhead1
% End of user PostScript
1 .91 0 r
.5168 .27683 m
.55672 .31497 L
.58796 .35438 L
.61067 .3933 L
.62531 .43023 L
.63259 .46402 L
.6334 .49382 L
.62874 .51909 L
.61968 .53954 L
.60729 .55512 L
.5926 .566 L
.57656 .57249 L
.56004 .57504 L
.54377 .57418 L
.52836 .5705 L
.51429 .56458 L
.50191 .55703 L
.49144 .54842 L
.48299 .53925 L
.47658 .52998 L
.47213 .521 L
.46952 .51262 L
.46854 .50509 L
.46898 .49856 L
.47058 .49313 L
.47311 .48885 L
.47631 .48571 L
.47994 .48364 L
.48379 .48256 L
.48767 .48234 L
.49142 .48287 L
.49491 .484 L
.49804 .48559 L
.50075 .4875 L
.503 .4896 L
.50476 .49178 L
.50605 .49394 L
.50689 .49599 L
.50732 .49788 L
.50739 .49955 L
.50715 .50096 L
.50667 .50212 L
.50599 .503 L
.50519 .50362 L
.5043 .504 L
.50339 .50415 L
.50249 .50412 L
.50163 .50392 L
.50084 .5036 L
.50015 .50319 L
Mistroke
.49956 .50272 L
.49909 .50221 L
.49873 .5017 L
.49847 .5012 L
.49832 .50073 L
.49826 .50031 L
.49828 .49994 L
.49836 .49964 L
.4985 .4994 L
.49867 .49922 L
.49887 .4991 L
.49909 .49904 L
.4993 .49902 L
.49951 .49905 L
.4997 .49911 L
.49988 .4992 L
.50003 .4993 L
.50016 .49942 L
.50026 .49954 L
.50033 .49966 L
.50038 .49977 L
.5004 .49988 L
.50041 .49997 L
.5004 .50005 L
.50037 .50011 L
.50033 .50016 L
.50029 .5002 L
.50024 .50022 L
.50019 .50023 L
.50014 .50023 L
.50009 .50022 L
.50005 .5002 L
.50001 .50018 L
.49998 .50015 L
.49995 .50012 L
.49993 .5001 L
.49992 .50007 L
.49991 .50004 L
.4999 .50002 L
.4999 .5 L
.49991 .49998 L
.49992 .49997 L
.49993 .49996 L
.49994 .49995 L
.49995 .49995 L
.49996 .49995 L
.49997 .49995 L
.49998 .49995 L
.49999 .49996 L
.5 .49996 L
Mistroke
.50001 .49997 L
.50001 .49997 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.5168 .27683 m
.55672 .31497 L
s
% Start of user PostScript
0.50397441 -6.6951093 1.7015991 -5.5509351 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58796 .35438 m
.61067 .3933 L
s
% Start of user PostScript
2.6389071 -4.3684698 3.3202078 -3.2011472 MAarrowhead1
% End of user PostScript
1 .473 0 r
.5926 .566 m
.57656 .57249 L
s
% Start of user PostScript
2.7779836 1.9800408 2.2969162 2.1747972 MAarrowhead1
% End of user PostScript
1 .788 0 r
.48299 .53925 m
.47658 .52998 L
s
% Start of user PostScript
-0.51029651 1.1773588 -0.70262511 0.8993471 MAarrowhead1
% End of user PostScript
.897 1 0 r
.47631 .48571 m
.47994 .48364 L
s
% Start of user PostScript
-0.710842 -0.42874685 -0.60193605 -0.49082898 MAarrowhead1
% End of user PostScript
.581 1 0 r
.503 .4896 m
.50476 .49178 L
s
% Start of user PostScript
0.089898647 -0.31200979 0.14283239 -0.24659172 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50599 .503 m
.50519 .50362 L
s
% Start of user PostScript
0.1798366 0.089953005 0.15565696 0.10856969 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49956 .50272 m
.49909 .50221 L
s
% Start of user PostScript
-0.013076511 0.081488532 -0.027352291 0.066297861 MAarrowhead1
% End of user PostScript
0 1 .364 r
.4985 .4994 m
.49867 .49922 L
s
% Start of user PostScript
-0.045008284 -0.018062221 -0.039767417 -0.023421053 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50003 .4993 m
.50016 .49942 L
s
% Start of user PostScript
0.00094908814 -0.021008019 0.0047344212 -0.017532979 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50037 .50011 m
.50033 .50016 L
s
% Start of user PostScript
0.011146891 0.0033919603 0.010045888 0.004889124 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50001 .50018 m
.49998 .50015 L
s
% Start of user PostScript
0.00032952495 0.0053520052 -0.00065959143 0.0045707648 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49991 .49998 m
.49992 .49997 L
s
% Start of user PostScript
-0.0027321292 -0.00056585914 -0.0025106333 -0.00097455331 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49999 .49996 m
.5 .49996 L
s
% Start of user PostScript
-0.0002193915 -0.0013483971 0.000035720033 -0.0011764084 MAarrowhead1
% End of user PostScript
.342 0 1 r
.3553 .54603 m
.35319 .51244 L
.35728 .48374 L
.36643 .46031 L
.37945 .44222 L
.3952 .42934 L
.41261 .42136 L
.43073 .4178 L
.4487 .41811 L
.46584 .42164 L
.48159 .42773 L
.49556 .43574 L
.50745 .44503 L
.51714 .45503 L
.52459 .46522 L
.52986 .47517 L
.53309 .48451 L
.53448 .49297 L
.53426 .50035 L
.53271 .50654 L
.5301 .51147 L
.52671 .51515 L
.52279 .51763 L
.51859 .51901 L
.51432 .51941 L
.51017 .51897 L
.50627 .51784 L
.50275 .51618 L
.49968 .51414 L
.49712 .51186 L
.49509 .50947 L
.49358 .50709 L
.49256 .5048 L
.49201 .50269 L
.49187 .50081 L
.49207 .49921 L
.49256 .49789 L
.49327 .49686 L
.49413 .49613 L
.49509 .49567 L
.49609 .49546 L
.49709 .49546 L
.49804 .49564 L
.49892 .49597 L
.4997 .49641 L
.50037 .49692 L
.50091 .49747 L
.50134 .49803 L
.50164 .49859 L
.50182 .49911 L
Mistroke
.50191 .49958 L
.5019 .49999 L
.50182 .50034 L
.50168 .50062 L
.50149 .50083 L
.50128 .50097 L
.50105 .50105 L
.50081 .50107 L
.50058 .50105 L
.50036 .50099 L
.50017 .5009 L
.49999 .50079 L
.49985 .50067 L
.49974 .50053 L
.49965 .5004 L
.49959 .50027 L
.49956 .50016 L
.49955 .50005 L
.49956 .49996 L
.49959 .49989 L
.49962 .49983 L
.49967 .49979 L
.49972 .49976 L
.49978 .49975 L
.49983 .49975 L
.49989 .49976 L
.49994 .49978 L
.49998 .4998 L
.50002 .49983 L
.50005 .49986 L
.50007 .49989 L
.50009 .49992 L
.5001 .49995 L
.50011 .49997 L
.50011 .5 L
.5001 .50002 L
.50009 .50003 L
.50008 .50005 L
.50007 .50005 L
.50006 .50006 L
.50005 .50006 L
.50003 .50006 L
.50002 .50006 L
.50001 .50005 L
.5 .50004 L
.49999 .50004 L
.49999 .50003 L
.49998 .50002 L
.49998 .50002 L
.49998 .50001 L
Mistroke
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.3553 .54603 m
.35319 .51244 L
s
% Start of user PostScript
-4.3410058 1.3810089 -4.40438 0.37324772 MAarrowhead1
% End of user PostScript
1 .158 0 r
.35728 .48374 m
.36643 .46031 L
s
% Start of user PostScript
-4.2814501 -0.48765058 -4.0070418 -1.1908367 MAarrowhead1
% End of user PostScript
1 .473 0 r
.48159 .42773 m
.49556 .43574 L
s
% Start of user PostScript
-0.55216479 -2.1680632 -0.13333189 -1.9278468 MAarrowhead1
% End of user PostScript
1 .788 0 r
.53426 .50035 m
.53271 .50654 L
s
% Start of user PostScript
1.0278761 0.010639688 0.98138332 0.19618816 MAarrowhead1
% End of user PostScript
.897 1 0 r
.50627 .51784 m
.50275 .51618 L
s
% Start of user PostScript
0.18812977 0.53517572 0.082496256 0.4853201 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49187 .50081 m
.49207 .49921 L
s
% Start of user PostScript
-0.24395962 0.024433829 -0.23783528 -0.023842474 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49804 .49564 m
.49892 .49597 L
s
% Start of user PostScript
-0.0587264 -0.13073738 -0.03236786 -0.1208839 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50191 .49958 m
.5019 .49999 L
s
% Start of user PostScript
0.057190598 -0.01263516 0.057012996 -0.00023219569 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50058 .50105 m
.50036 .50099 L
s
% Start of user PostScript
0.017373208 0.031600628 0.010864293 0.029797862 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49956 .50016 m
.49955 .50005 L
s
% Start of user PostScript
-0.013224669 0.0047134644 -0.013509952 0.0015637863 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49983 .49975 m
.49989 .49976 L
s
% Start of user PostScript
-0.0049527964 -0.0075543145 -0.0033621411 -0.0072690001 MAarrowhead1
% End of user PostScript
0 .69 1 r
.5001 .49995 m
.50011 .49997 L
s
% Start of user PostScript
0.0030107585 -0.0015442589 0.0031615292 -0.00075313284 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50005 .50006 m
.50003 .50006 L
s
% Start of user PostScript
0.0013735632 0.001784796 0.00098893516 0.0017544363 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49998 .50002 m
.49998 .50001 L
s
% Start of user PostScript
-0.00067299897 0.0004710457 -0.00072962469 0.00027442149 MAarrowhead1
% End of user PostScript
.355 1 0 r
.67357 .56902 m
.65348 .58979 L
.63047 .60363 L
.60594 .6111 L
.58111 .61294 L
.55702 .60996 L
.53452 .60306 L
.51426 .59315 L
.49667 .5811 L
.48204 .56775 L
.47048 .55383 L
.46196 .53999 L
.45632 .52678 L
.45334 .51461 L
.4527 .50382 L
.45405 .4946 L
.45703 .48708 L
.46125 .48128 L
.46633 .47717 L
.47195 .47462 L
.47779 .4735 L
.48358 .47362 L
.48909 .47478 L
.49416 .47676 L
.49865 .47935 L
.50247 .48235 L
.50558 .48557 L
.50796 .48886 L
.50965 .49206 L
.51068 .49506 L
.51111 .49778 L
.51103 .50016 L
.51053 .50214 L
.50968 .50372 L
.50858 .5049 L
.50732 .50569 L
.50596 .50613 L
.50459 .50625 L
.50325 .50611 L
.502 .50574 L
.50087 .5052 L
.49988 .50454 L
.49906 .50381 L
.49841 .50304 L
.49792 .50227 L
.4976 .50153 L
.49742 .50086 L
.49738 .50025 L
.49745 .49973 L
.49761 .49931 L
Mistroke
.49784 .49898 L
.49811 .49875 L
.49842 .4986 L
.49875 .49854 L
.49907 .49854 L
.49937 .4986 L
.49966 .4987 L
.49991 .49885 L
.50012 .49901 L
.5003 .49919 L
.50043 .49937 L
.50053 .49955 L
.50059 .49972 L
.50061 .49987 L
.50061 .5 L
.50059 .50011 L
.50054 .5002 L
.50048 .50027 L
.50041 .50031 L
.50034 .50034 L
.50026 .50035 L
.50019 .50034 L
.50012 .50032 L
.50005 .50029 L
.5 .50025 L
.49995 .50021 L
.49991 .50017 L
.49989 .50013 L
.49987 .50009 L
.49986 .50005 L
.49985 .50002 L
.49986 .49999 L
.49987 .49996 L
.49988 .49994 L
.49989 .49993 L
.49991 .49992 L
.49993 .49992 L
.49995 .49992 L
.49996 .49992 L
.49998 .49993 L
.49999 .49994 L
.50001 .49994 L
.50002 .49995 L
.50002 .49996 L
.50003 .49997 L
.50003 .49998 L
.50003 .49999 L
.50003 .5 L
.50003 .50001 L
.50003 .50001 L
Mistroke
.50003 .50001 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.67357 .56902 m
.65348 .58979 L
s
% Start of user PostScript
5.2071384 2.0705983 4.6042812 2.693575 MAarrowhead1
% End of user PostScript
1 .158 0 r
.63047 .60363 m
.60594 .6111 L
s
% Start of user PostScript
3.9140847 3.1088218 3.1781712 3.3330829 MAarrowhead1
% End of user PostScript
1 .473 0 r
.47048 .55383 m
.46196 .53999 L
s
% Start of user PostScript
-0.88554284 1.6148753 -1.1412966 1.1997435 MAarrowhead1
% End of user PostScript
1 .788 0 r
.46633 .47717 m
.47195 .47462 L
s
% Start of user PostScript
-1.0099729 -0.68498077 -0.84142933 -0.7612712 MAarrowhead1
% End of user PostScript
.897 1 0 r
.50558 .48557 m
.50796 .48886 L
s
% Start of user PostScript
0.16730972 -0.43285478 0.23889908 -0.33434163 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50858 .5049 m
.50732 .50569 L
s
% Start of user PostScript
0.25751513 0.1470298 0.21957224 0.17082344 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49906 .50381 m
.49841 .50304 L
s
% Start of user PostScript
-0.028238557 0.11417424 -0.047810602 0.091084163 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49784 .49898 m
.49811 .49875 L
s
% Start of user PostScript
-0.064930142 -0.030484654 -0.056563067 -0.037519487 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50012 .49901 m
.5003 .49919 L
s
% Start of user PostScript
0.0036807884 -0.029696272 0.0089302201 -0.024357997 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50054 .5002 m
.50048 .50027 L
s
% Start of user PostScript
0.01619767 0.0060160317 0.014399777 0.008020694 MAarrowhead1
% End of user PostScript
0 1 .995 r
.5 .50025 m
.49995 .50021 L
s
% Start of user PostScript
-0.000088745511 0.0076271705 -0.0014741377 0.0064121204 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49987 .49996 m
.49988 .49994 L
s
% Start of user PostScript
-0.0039987831 -0.0010979188 -0.003625471 -0.0016536932 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49999 .49994 m
.50001 .49994 L
s
% Start of user PostScript
-0.00018028707 -0.0019363459 0.00018022045 -0.0016648173 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50003 .50001 m
.50003 .50001 L
s
% Start of user PostScript
0.00097697277 0.00017284519 0.00090314178 0.0003236255 MAarrowhead1
% End of user PostScript
.114 0 1 r
.5361 .55345 m
.5248 .55162 L
.51432 .54802 L
.50495 .54308 L
.49689 .53721 L
.49025 .5308 L
.48506 .52418 L
.4813 .51766 L
.4789 .51148 L
.47772 .50583 L
.47762 .50085 L
.47844 .49664 L
.47998 .49325 L
.48208 .49066 L
.48456 .48887 L
.48726 .4878 L
.49003 .4874 L
.49276 .48756 L
.49534 .4882 L
.49769 .48921 L
.49976 .49048 L
.5015 .49193 L
.5029 .49347 L
.50397 .49503 L
.5047 .49653 L
.50513 .49793 L
.50528 .49919 L
.5052 .50028 L
.50492 .50118 L
.50449 .5019 L
.50395 .50242 L
.50334 .50276 L
.5027 .50293 L
.50204 .50296 L
.50142 .50287 L
.50083 .50268 L
.50031 .50241 L
.49986 .50209 L
.49948 .50173 L
.49919 .50137 L
.49898 .501 L
.49884 .50066 L
.49877 .50034 L
.49876 .50007 L
.4988 .49983 L
.49888 .49964 L
.499 .49949 L
.49913 .49939 L
.49928 .49933 L
.49944 .4993 L
Mistroke
.49959 .49931 L
.49973 .49934 L
.49986 .4994 L
.49998 .49947 L
.50008 .49955 L
.50016 .49963 L
.50022 .49972 L
.50026 .4998 L
.50028 .49988 L
.50029 .49995 L
.50029 .50001 L
.50027 .50006 L
.50025 .5001 L
.50022 .50013 L
.50019 .50015 L
.50015 .50016 L
.50012 .50016 L
.50008 .50016 L
.50005 .50015 L
.50002 .50013 L
.49999 .50012 L
.49997 .5001 L
.49996 .50008 L
.49994 .50006 L
.49994 .50004 L
.49993 .50002 L
.49993 .5 L
.49993 .49999 L
.49994 .49998 L
.49994 .49997 L
.49995 .49997 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49999 .49997 L
.5 .49997 L
.5 .49997 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
Mistroke
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.5361 .55345 m
.5248 .55162 L
s
% Start of user PostScript
1.0829146 1.6034823 0.74391029 1.5486828 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51432 .54802 m
.50495 .54308 L
s
% Start of user PostScript
0.42958196 1.4407497 0.14853798 1.2925293 MAarrowhead1
% End of user PostScript
1 .473 0 r
.47762 .50085 m
.47844 .49664 L
s
% Start of user PostScript
-0.67125239 0.025638544 -0.64682583 -0.1006557 MAarrowhead1
% End of user PostScript
1 .788 0 r
.49534 .4882 m
.49769 .48921 L
s
% Start of user PostScript
-0.13987095 -0.35398826 -0.069331393 -0.32382278 MAarrowhead1
% End of user PostScript
.897 1 0 r
.50528 .49919 m
.5052 .50028 L
s
% Start of user PostScript
0.15845717 -0.024219411 0.15600001 0.0084494787 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50142 .50287 m
.50083 .50268 L
s
% Start of user PostScript
0.042503068 0.086067939 0.024983998 0.080280904 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49877 .50034 m
.49876 .50007 L
s
% Start of user PostScript
-0.036926177 0.010323877 -0.037205982 0.0019752457 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49959 .49931 m
.49973 .49934 L
s
% Start of user PostScript
-0.01234805 -0.020702135 -0.008042047 -0.019697162 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50028 .49988 m
.50029 .49995 L
s
% Start of user PostScript
0.0084815874 -0.0035925003 0.0087682905 -0.0014829435 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50012 .50016 m
.50008 .50016 L
s
% Start of user PostScript
0.0034738058 0.0049234532 0.0024264537 0.0047822854 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49994 .50004 m
.49993 .50002 L
s
% Start of user PostScript
-0.0019159042 0.0011348208 -0.0020395566 0.00060747332 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49997 .49996 m
.49998 .49996 L
s
% Start of user PostScript
-0.00095349472 -0.0011567341 -0.00070147252 -0.0011485843 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50001 .49999 m
.50002 .49999 L
s
% Start of user PostScript
0.00042424914 -0.00033832581 0.00046748324 -0.00020787148 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50001 .50001 m
.50001 .50001 L
s
% Start of user PostScript
0.00025657819 0.00026814195 0.00019661613 0.00027272778 MAarrowhead1
% End of user PostScript
1 0 .666 r
.5054 .23544 m
.55336 .27801 L
.59148 .32262 L
.61982 .36717 L
.63882 .40987 L
.64922 .44932 L
.65198 .48447 L
.64822 .51459 L
.63914 .5393 L
.62595 .55846 L
.60984 .57222 L
.59193 .58087 L
.57321 .5849 L
.55458 .58489 L
.53675 .58149 L
.52031 .57537 L
.5057 .56723 L
.49321 .5577 L
.483 .54739 L
.4751 .53684 L
.46947 .52652 L
.46596 .51679 L
.46438 .50795 L
.46448 .50021 L
.46598 .49371 L
.4686 .4885 L
.47205 .48459 L
.47607 .48192 L
.4804 .4804 L
.48482 .47991 L
.48914 .48031 L
.4932 .48142 L
.49687 .4831 L
.50009 .48519 L
.50278 .48753 L
.50493 .49 L
.50654 .49247 L
.50763 .49484 L
.50823 .49704 L
.50842 .49901 L
.50823 .5007 L
.50775 .50209 L
.50703 .50317 L
.50615 .50395 L
.50516 .50445 L
.50413 .50469 L
.5031 .50471 L
.5021 .50453 L
.50119 .5042 L
.50037 .50376 L
Mistroke
.49967 .50323 L
.4991 .50267 L
.49865 .50208 L
.49833 .50151 L
.49813 .50097 L
.49803 .50047 L
.49803 .50004 L
.49811 .49968 L
.49825 .49938 L
.49844 .49916 L
.49866 .49901 L
.4989 .49892 L
.49914 .49889 L
.49938 .49891 L
.49961 .49897 L
.49981 .49906 L
.49999 .49917 L
.50014 .4993 L
.50027 .49944 L
.50036 .49957 L
.50042 .49971 L
.50045 .49983 L
.50047 .49994 L
.50046 .50003 L
.50043 .50011 L
.50039 .50017 L
.50034 .50022 L
.50029 .50024 L
.50023 .50026 L
.50018 .50026 L
.50012 .50025 L
.50007 .50023 L
.50002 .50021 L
.49998 .50018 L
.49995 .50015 L
.49993 .50012 L
.49991 .50009 L
.4999 .50006 L
.49989 .50003 L
.49989 .5 L
.49989 .49998 L
.4999 .49997 L
.49991 .49995 L
.49992 .49995 L
.49994 .49994 L
.49995 .49994 L
.49996 .49994 L
.49998 .49994 L
.49999 .49995 L
.5 .49995 L
Mistroke
.50001 .49996 L
.50001 .49997 L
.50002 .49998 L
.50002 .49998 L
.50003 .49999 L
.50003 .5 L
.50003 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.5054 .23544 m
.55336 .27801 L
s
% Start of user PostScript
0.16214499 -7.9367091 1.600736 -6.6596346 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59148 .32262 m
.61982 .36717 L
s
% Start of user PostScript
2.7443584 -5.3212686 3.5946342 -3.9849719 MAarrowhead1
% End of user PostScript
1 .473 0 r
.60984 .57222 m
.59193 .58087 L
s
% Start of user PostScript
3.2952996 2.1664616 2.757853 2.426141 MAarrowhead1
% End of user PostScript
1 .788 0 r
.483 .54739 m
.4751 .53684 L
s
% Start of user PostScript
-0.5101459 1.4217412 -0.74699368 1.1053434 MAarrowhead1
% End of user PostScript
.897 1 0 r
.47205 .48459 m
.47607 .48192 L
s
% Start of user PostScript
-0.83840295 -0.46236211 -0.71784488 -0.54239478 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50278 .48753 m
.50493 .49 L
s
% Start of user PostScript
0.083412251 -0.37397327 0.1479134 -0.29999685 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50703 .50317 m
.50615 .50395 L
s
% Start of user PostScript
0.2109648 0.095109661 0.18449661 0.11858559 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49967 .50323 m
.4991 .50267 L
s
% Start of user PostScript
-0.0099031982 0.097029251 -0.02714717 0.079973793 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49825 .49938 m
.49844 .49916 L
s
% Start of user PostScript
-0.052523967 -0.018548125 -0.046868817 -0.025199512 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49999 .49917 m
.50014 .4993 L
s
% Start of user PostScript
-0.00021342089 -0.024864879 0.0043248047 -0.020995338 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50043 .50011 m
.50039 .50017 L
s
% Start of user PostScript
0.012941461 0.0033167868 0.011776362 0.0051526359 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50002 .50021 m
.49998 .50018 L
s
% Start of user PostScript
0.00070692646 0.0062992947 -0.00047109152 0.0054378947 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49989 .49998 m
.4999 .49997 L
s
% Start of user PostScript
-0.0031555839 -0.00049942827 -0.0029278328 -0.00099569396 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49999 .49995 m
.5 .49995 L
s
% Start of user PostScript
-0.0003338667 -0.0015786372 -0.000031856343 -0.0013913089 MAarrowhead1
% End of user PostScript
.72 1 0 r
.33485 .61662 m
.32076 .56821 L
.31611 .52484 L
.31955 .48744 L
.32966 .45655 L
.34496 .43235 L
.364 .41475 L
.38543 .40338 L
.40799 .3977 L
.43062 .39702 L
.45238 .40057 L
.47256 .40752 L
.49059 .41706 L
.5061 .42838 L
.51888 .44075 L
.52886 .4535 L
.53607 .46607 L
.54069 .47797 L
.54294 .48885 L
.54311 .49842 L
.54153 .50652 L
.53854 .51306 L
.53449 .51803 L
.52971 .52148 L
.52451 .52351 L
.51917 .52428 L
.51391 .52396 L
.50895 .52272 L
.50442 .52078 L
.50044 .51832 L
.49709 .51552 L
.49439 .51255 L
.49234 .50956 L
.49093 .50666 L
.49011 .50396 L
.48982 .50154 L
.48998 .49944 L
.49052 .49771 L
.49135 .49634 L
.49239 .49534 L
.49357 .49469 L
.49482 .49435 L
.49607 .49429 L
.49728 .49447 L
.4984 .49485 L
.49941 .49537 L
.50028 .49599 L
.501 .49667 L
.50156 .49737 L
.50197 .49807 L
Mistroke
.50224 .49873 L
.50237 .49934 L
.50239 .49988 L
.50231 .50033 L
.50215 .5007 L
.50193 .50098 L
.50167 .50118 L
.50138 .5013 L
.50108 .50134 L
.50079 .50133 L
.50051 .50126 L
.50026 .50116 L
.50004 .50102 L
.49985 .50087 L
.4997 .50071 L
.49958 .50054 L
.4995 .50038 L
.49945 .50023 L
.49944 .50009 L
.49944 .49998 L
.49947 .49988 L
.49952 .4998 L
.49957 .49975 L
.49964 .49971 L
.49971 .49969 L
.49978 .49968 L
.49984 .49969 L
.49991 .49971 L
.49996 .49974 L
.50001 .49978 L
.50005 .49981 L
.50008 .49985 L
.50011 .49989 L
.50012 .49993 L
.50013 .49996 L
.50013 .49999 L
.50013 .50002 L
.50012 .50004 L
.50011 .50005 L
.50009 .50006 L
.50008 .50007 L
.50006 .50007 L
.50004 .50007 L
.50003 .50007 L
.50002 .50006 L
.5 .50006 L
.49999 .50005 L
.49998 .50004 L
.49998 .50003 L
.49997 .50002 L
Mistroke
.49997 .50001 L
.49997 .50001 L
.49997 .5 L
.49997 .49999 L
.49997 .49999 L
.49998 .49999 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.33485 .61662 m
.32076 .56821 L
s
% Start of user PostScript
-4.9546437 3.4986372 -5.377131 2.046244 MAarrowhead1
% End of user PostScript
1 .158 0 r
.31611 .52484 m
.31955 .48744 L
s
% Start of user PostScript
-5.516761 0.74519367 -5.4133607 -0.37678227 MAarrowhead1
% End of user PostScript
1 .473 0 r
.45238 .40057 m
.47256 .40752 L
s
% Start of user PostScript
-1.428591 -2.9829819 -0.82333594 -2.7743069 MAarrowhead1
% End of user PostScript
1 .788 0 r
.54294 .48885 m
.54311 .49842 L
s
% Start of user PostScript
1.2881895 -0.33457682 1.2932919 -0.047350718 MAarrowhead1
% End of user PostScript
.897 1 0 r
.51391 .52396 m
.50895 .52272 L
s
% Start of user PostScript
0.41741479 0.71867866 0.26841871 0.68174168 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49011 .50396 m
.48982 .50154 L
s
% Start of user PostScript
-0.29655985 0.11884076 -0.30535108 0.046144205 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49607 .49429 m
.49728 .49447 L
s
% Start of user PostScript
-0.11792676 -0.1712156 -0.081629253 -0.16578246 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50224 .49873 m
.50237 .49934 L
s
% Start of user PostScript
0.067168589 -0.03796213 0.071171617 -0.019760691 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50108 .50134 m
.50079 .50133 L
s
% Start of user PostScript
0.032476308 0.040301947 0.023727838 0.039882385 MAarrowhead1
% End of user PostScript
0 1 .679 r
.4995 .50038 m
.49945 .50023 L
s
% Start of user PostScript
-0.014921625 0.011398942 -0.016351067 0.0068893097 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49971 .49969 m
.49978 .49968 L
s
% Start of user PostScript
-0.0087629701 -0.0093620274 -0.006677894 -0.0094865637 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50011 .49989 m
.50012 .49993 L
s
% Start of user PostScript
0.0032365871 -0.0032842721 0.0036945009 -0.0021785068 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50008 .50007 m
.50006 .50007 L
s
% Start of user PostScript
0.002324558 0.0021426005 0.0018335359 0.0022292163 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49998 .50003 m
.49997 .50002 L
s
% Start of user PostScript
-0.00068060697 0.00091821764 -0.00081835235 0.00064991843 MAarrowhead1
% End of user PostScript
0 1 .303 r
.47191 .53257 m
.4672 .52233 L
.46455 .51285 L
.46375 .50437 L
.46452 .49708 L
.46659 .49108 L
.46967 .48639 L
.47346 .48301 L
.4777 .48084 L
.48216 .47979 L
.48661 .47972 L
.49089 .48047 L
.49484 .48188 L
.49836 .48379 L
.50139 .48604 L
.50387 .48849 L
.5058 .491 L
.50719 .49347 L
.50807 .49581 L
.50848 .49794 L
.50849 .4998 L
.50816 .50138 L
.50755 .50265 L
.50674 .50361 L
.50579 .50427 L
.50476 .50465 L
.50371 .50479 L
.50268 .50471 L
.5017 .50446 L
.50082 .50407 L
.50004 .50358 L
.49939 .50302 L
.49886 .50244 L
.49847 .50185 L
.4982 .50128 L
.49804 .50075 L
.49799 .50027 L
.49803 .49987 L
.49814 .49953 L
.49831 .49926 L
.49851 .49907 L
.49875 .49895 L
.49899 .49888 L
.49924 .49888 L
.49948 .49891 L
.4997 .49899 L
.4999 .49909 L
.50007 .49922 L
.50021 .49935 L
.50031 .49949 L
Mistroke
.50039 .49963 L
.50044 .49976 L
.50047 .49988 L
.50047 .49998 L
.50045 .50007 L
.50042 .50014 L
.50038 .5002 L
.50032 .50023 L
.50027 .50026 L
.50021 .50027 L
.50015 .50026 L
.5001 .50025 L
.50005 .50023 L
.50001 .5002 L
.49997 .50017 L
.49994 .50014 L
.49992 .5001 L
.4999 .50007 L
.49989 .50004 L
.49989 .50002 L
.49989 .49999 L
.4999 .49998 L
.49991 .49996 L
.49992 .49995 L
.49993 .49994 L
.49994 .49994 L
.49996 .49994 L
.49997 .49994 L
.49998 .49994 L
.49999 .49995 L
.5 .49996 L
.50001 .49996 L
.50002 .49997 L
.50002 .49998 L
.50002 .49999 L
.50003 .49999 L
.50003 .5 L
.50003 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
Mistroke
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.47191 .53257 m
.4672 .52233 L
s
% Start of user PostScript
-0.84272506 0.97699227 -0.98414859 0.66992576 MAarrowhead1
% End of user PostScript
1 .158 0 r
.46455 .51285 m
.46375 .50437 L
s
% Start of user PostScript
-1.0635118 0.3853665 -1.0876042 0.13108053 MAarrowhead1
% End of user PostScript
1 .473 0 r
.48661 .47972 m
.49089 .48047 L
s
% Start of user PostScript
-0.40159507 -0.6083795 -0.27337499 -0.58589856 MAarrowhead1
% End of user PostScript
1 .788 0 r
.50807 .49581 m
.50848 .49794 L
s
% Start of user PostScript
0.24195483 -0.12578881 0.25437854 -0.061946062 MAarrowhead1
% End of user PostScript
.897 1 0 r
.50371 .50479 m
.50268 .50471 L
s
% Start of user PostScript
0.11126494 0.14366488 0.080274374 0.14134892 MAarrowhead1
% End of user PostScript
.581 1 0 r
.4982 .50128 m
.49804 .50075 L
s
% Start of user PostScript
-0.054039967 0.038282581 -0.058670443 0.022422064 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49899 .49888 m
.49924 .49888 L
s
% Start of user PostScript
-0.030169761 -0.033491822 -0.022761691 -0.033722595 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50039 .49963 m
.50044 .49976 L
s
% Start of user PostScript
0.011800762 -0.011133656 0.013317162 -0.0072341681 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50027 .50026 m
.50021 .50027 L
s
% Start of user PostScript
0.0080363973 0.0076960836 0.0062862563 0.0079501427 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49992 .5001 m
.4999 .50007 L
s
% Start of user PostScript
-0.0025037259 0.0031346262 -0.0029661496 0.0021858691 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49993 .49994 m
.49994 .49994 L
s
% Start of user PostScript
-0.0021083351 -0.0017393496 -0.001700135 -0.0018499674 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50002 .49997 m
.50002 .49998 L
s
% Start of user PostScript
0.00051081747 -0.00086092778 0.00064548766 -0.00063255979 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50002 .50001 m
.50002 .50001 L
s
% Start of user PostScript
0.00054573508 0.00038539135 0.00045188286 0.00042421522 MAarrowhead1
% End of user PostScript
0 .06 1 r
.5 .50001 m
.5 .50001 L
s
% Start of user PostScript
-0.000098374631 0.00023178689 -0.00013632889 0.0001774349 MAarrowhead1
% End of user PostScript
1 .75 0 r
.72217 .33283 m
.74299 .39957 L
.75075 .45962 L
.74723 .51164 L
.7344 .55484 L
.71425 .58891 L
.68877 .61396 L
.65983 .63043 L
.62914 .63904 L
.59822 .64071 L
.56833 .63648 L
.54051 .62747 L
.51554 .61481 L
.49395 .5996 L
.47607 .58284 L
.46202 .56546 L
.45174 .54825 L
.44505 .53188 L
.44162 .51686 L
.44108 .50358 L
.44298 .49228 L
.44686 .48311 L
.45224 .47609 L
.45867 .47115 L
.46571 .46815 L
.473 .46691 L
.4802 .4672 L
.48703 .46875 L
.49329 .4713 L
.49881 .47459 L
.50349 .47836 L
.50728 .4824 L
.51017 .48649 L
.51219 .49047 L
.51339 .49418 L
.51387 .49754 L
.51372 .50045 L
.51304 .50288 L
.51195 .5048 L
.51056 .50623 L
.50897 .50717 L
.50727 .50768 L
.50556 .5078 L
.5039 .50758 L
.50235 .5071 L
.50095 .50641 L
.49974 .50558 L
.49874 .50466 L
.49795 .50369 L
.49736 .50274 L
Mistroke
.49698 .50183 L
.49678 .50099 L
.49674 .50025 L
.49683 .49961 L
.49704 .4991 L
.49733 .4987 L
.49768 .49842 L
.49807 .49825 L
.49848 .49817 L
.49888 .49818 L
.49926 .49826 L
.4996 .4984 L
.49991 .49858 L
.50018 .49879 L
.50039 .49901 L
.50055 .49924 L
.50067 .49946 L
.50074 .49966 L
.50077 .49985 L
.50076 .50001 L
.50073 .50015 L
.50067 .50026 L
.50059 .50034 L
.5005 .50039 L
.50041 .50042 L
.50031 .50043 L
.50022 .50042 L
.50014 .5004 L
.50006 .50036 L
.49999 .50031 L
.49993 .50026 L
.49989 .50021 L
.49986 .50016 L
.49983 .5001 L
.49982 .50006 L
.49982 .50002 L
.49982 .49998 L
.49984 .49995 L
.49985 .49993 L
.49987 .49991 L
.49989 .4999 L
.49991 .4999 L
.49994 .4999 L
.49996 .4999 L
.49998 .49991 L
.49999 .49992 L
.50001 .49993 L
.50002 .49994 L
.50003 .49996 L
.50004 .49997 L
Mistroke
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50004 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.72217 .33283 m
.74299 .39957 L
s
% Start of user PostScript
6.6650478 -5.0150903 7.289607 -3.0127928 MAarrowhead1
% End of user PostScript
1 .158 0 r
.75075 .45962 m
.74723 .51164 L
s
% Start of user PostScript
7.5223884 -1.2114694 7.4169802 0.34911053 MAarrowhead1
% End of user PostScript
1 .473 0 r
.56833 .63648 m
.54051 .62747 L
s
% Start of user PostScript
2.0499524 4.0943847 1.2153288 3.8241894 MAarrowhead1
% End of user PostScript
1 .788 0 r
.44162 .51686 m
.44108 .50358 L
s
% Start of user PostScript
-1.7513561 0.50574956 -1.7675599 0.1072547 MAarrowhead1
% End of user PostScript
.897 1 0 r
.4802 .4672 m
.48703 .46875 L
s
% Start of user PostScript
-0.59405753 -0.98409302 -0.38906112 -0.93761089 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51339 .49418 m
.51387 .49754 L
s
% Start of user PostScript
0.4018446 -0.17447032 0.41620466 -0.073852643 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50556 .5078 m
.5039 .50758 L
s
% Start of user PostScript
0.16680934 0.23385344 0.11698387 0.22747814 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49698 .50183 m
.49678 .50099 L
s
% Start of user PostScript
-0.090660071 0.05484707 -0.096720307 0.029712733 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49848 .49817 m
.49888 .49818 L
s
% Start of user PostScript
-0.045718291 -0.054894576 -0.033737876 -0.054593195 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50067 .49946 m
.50074 .49966 L
s
% Start of user PostScript
0.020045062 -0.016300494 0.022145206 -0.010087206 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50041 .50042 m
.50031 .50043 L
s
% Start of user PostScript
0.012287435 0.012712712 0.0094392804 0.012952525 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49986 .50016 m
.49983 .5001 L
s
% Start of user PostScript
-0.0043218203 0.0046623848 -0.0049837072 0.0031423312 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49989 .4999 m
.49991 .4999 L
s
% Start of user PostScript
-0.0032485478 -0.0028991941 -0.0025796654 -0.0030351825 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50003 .49996 m
.50004 .49997 L
s
% Start of user PostScript
0.00090150689 -0.0012963081 0.0010985437 -0.00092834283 MAarrowhead1
% End of user PostScript
0 .178 1 r
.49209 .34926 m
.51989 .37151 L
.54243 .39533 L
.55966 .41951 L
.57173 .44303 L
.579 .46505 L
.58194 .48493 L
.58113 .50223 L
.57721 .51665 L
.57083 .5281 L
.56264 .53658 L
.55326 .54224 L
.54326 .54531 L
.53313 .54606 L
.52331 .54486 L
.51413 .54205 L
.50585 .53802 L
.49868 .53311 L
.4927 .52766 L
.48798 .52198 L
.4845 .51634 L
.48219 .51095 L
.48097 .50598 L
.48071 .50158 L
.48126 .49782 L
.48247 .49474 L
.48418 .49238 L
.48626 .49069 L
.48855 .48965 L
.49093 .48919 L
.49329 .48924 L
.49554 .48971 L
.49761 .49052 L
.49944 .49157 L
.501 .49279 L
.50227 .49411 L
.50324 .49545 L
.50393 .49675 L
.50435 .49798 L
.50453 .49909 L
.5045 .50006 L
.5043 .50087 L
.50395 .50152 L
.5035 .502 L
.50299 .50232 L
.50244 .5025 L
.50187 .50255 L
.50133 .50249 L
.50082 .50234 L
.50036 .50212 L
Mistroke
.49995 .50185 L
.49962 .50155 L
.49935 .50124 L
.49915 .50093 L
.49902 .50063 L
.49895 .50035 L
.49893 .5001 L
.49896 .49989 L
.49902 .49972 L
.49912 .49959 L
.49923 .49949 L
.49936 .49943 L
.49949 .4994 L
.49962 .4994 L
.49974 .49943 L
.49986 .49947 L
.49996 .49953 L
.50005 .4996 L
.50012 .49967 L
.50018 .49974 L
.50022 .49982 L
.50024 .49988 L
.50025 .49995 L
.50025 .5 L
.50024 .50005 L
.50022 .50008 L
.5002 .50011 L
.50017 .50013 L
.50014 .50014 L
.50011 .50014 L
.50008 .50014 L
.50005 .50013 L
.50002 .50012 L
.5 .5001 L
.49998 .50009 L
.49997 .50007 L
.49995 .50005 L
.49995 .50004 L
.49994 .50002 L
.49994 .50001 L
.49994 .49999 L
.49995 .49999 L
.49995 .49998 L
.49996 .49997 L
.49996 .49997 L
.49997 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49997 L
Mistroke
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.49209 .34926 m
.51989 .37151 L
s
% Start of user PostScript
-0.23728961 -4.5223419 0.59671096 -3.8547131 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54243 .39533 m
.55966 .41951 L
s
% Start of user PostScript
1.2729563 -3.1401185 1.7897301 -2.4146747 MAarrowhead1
% End of user PostScript
1 .473 0 r
.56264 .53658 m
.55326 .54224 L
s
% Start of user PostScript
1.8792864 1.0975358 1.5979169 1.2673181 MAarrowhead1
% End of user PostScript
1 .788 0 r
.4927 .52766 m
.48798 .52198 L
s
% Start of user PostScript
-0.21889374 0.82983318 -0.36055413 0.65952482 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48418 .49238 m
.48626 .49069 L
s
% Start of user PostScript
-0.4744932 -0.2286941 -0.41227044 -0.27917237 MAarrowhead1
% End of user PostScript
.581 1 0 r
.501 .49279 m
.50227 .49411 L
s
% Start of user PostScript
0.02998899 -0.21619671 0.068067884 -0.17675128 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50395 .50152 m
.5035 .502 L
s
% Start of user PostScript
0.11852477 0.045464745 0.10510603 0.059906825 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49995 .50185 m
.49962 .50155 L
s
% Start of user PostScript
-0.0014027895 0.055612071 -0.011471357 0.046615114 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49902 .49972 m
.49912 .49959 L
s
% Start of user PostScript
-0.029298772 -0.0083998194 -0.0264988 -0.012416063 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49996 .49953 m
.50005 .4996 L
s
% Start of user PostScript
-0.0011353708 -0.014138448 0.0014890691 -0.01212288 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50024 .50005 m
.50022 .50008 L
s
% Start of user PostScript
0.0071675858 0.0013565549 0.0066098083 0.0024488519 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50002 .50012 m
.5 .5001 L
s
% Start of user PostScript
0.00064235953 0.0035550834 -0.000033019617 0.003113275 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49994 .49999 m
.49995 .49999 L
s
% Start of user PostScript
-0.0017350283 -0.00015478354 -0.0016316281 -0.00044647773 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49999 .49997 m
.5 .49997 L
s
% Start of user PostScript
-0.00024612389 -0.00088449835 -0.000074349712 -0.0007902973 MAarrowhead1
% End of user PostScript
1 .209 0 r
.62249 .43706 m
.62864 .46926 L
.62866 .49752 L
.62354 .52135 L
.61429 .54049 L
.60196 .55495 L
.58754 .56488 L
.57192 .57063 L
.55594 .57263 L
.54029 .5714 L
.52554 .56752 L
.51213 .56155 L
.5004 .55409 L
.49053 .54566 L
.48262 .53676 L
.47668 .52781 L
.47262 .51919 L
.47031 .51119 L
.46956 .50402 L
.47015 .49785 L
.47184 .49275 L
.47438 .48876 L
.47754 .48586 L
.48108 .48399 L
.48482 .48306 L
.48856 .48296 L
.49216 .48355 L
.4955 .48471 L
.49848 .4863 L
.50104 .48817 L
.50315 .49022 L
.50479 .49233 L
.50598 .49441 L
.50674 .49638 L
.50711 .49818 L
.50713 .49976 L
.50687 .5011 L
.50637 .50217 L
.5057 .50299 L
.50491 .50356 L
.50405 .50389 L
.50316 .50402 L
.50229 .50396 L
.50147 .50376 L
.50072 .50343 L
.50007 .50303 L
.49951 .50256 L
.49907 .50207 L
.49873 .50158 L
.4985 .5011 L
Mistroke
.49836 .50065 L
.49832 .50025 L
.49834 .4999 L
.49843 .49962 L
.49857 .49939 L
.49874 .49923 L
.49894 .49912 L
.49914 .49906 L
.49935 .49906 L
.49955 .49909 L
.49974 .49915 L
.4999 .49923 L
.50005 .49934 L
.50017 .49945 L
.50026 .49957 L
.50033 .49968 L
.50037 .49979 L
.50039 .49989 L
.5004 .49998 L
.50038 .50006 L
.50036 .50012 L
.50032 .50016 L
.50027 .5002 L
.50023 .50021 L
.50018 .50022 L
.50013 .50022 L
.50008 .50021 L
.50004 .50019 L
.50001 .50017 L
.49997 .50014 L
.49995 .50012 L
.49993 .50009 L
.49992 .50006 L
.49991 .50004 L
.49991 .50002 L
.49991 .5 L
.49991 .49998 L
.49992 .49997 L
.49993 .49996 L
.49994 .49995 L
.49995 .49995 L
.49996 .49995 L
.49997 .49995 L
.49998 .49995 L
.49999 .49996 L
.5 .49996 L
.50001 .49997 L
.50001 .49998 L
.50002 .49998 L
.50002 .49999 L
Mistroke
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.62249 .43706 m
.62864 .46926 L
s
% Start of user PostScript
3.6745532 -1.8883153 3.8592184 -0.92220249 MAarrowhead1
% End of user PostScript
1 .158 0 r
.62866 .49752 m
.62354 .52135 L
s
% Start of user PostScript
3.8599078 -0.074313722 3.70613 0.64042424 MAarrowhead1
% End of user PostScript
1 .473 0 r
.52554 .56752 m
.51213 .56155 L
s
% Start of user PostScript
0.76612807 2.0254607 0.36399471 1.8466315 MAarrowhead1
% End of user PostScript
1 .788 0 r
.46956 .50402 m
.47015 .49785 L
s
% Start of user PostScript
-0.91310746 0.12072927 -0.89551748 -0.06456423 MAarrowhead1
% End of user PostScript
.897 1 0 r
.49216 .48355 m
.4955 .48471 L
s
% Start of user PostScript
-0.23508996 -0.4933686 -0.13503578 -0.45863797 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50711 .49818 m
.50713 .49976 L
s
% Start of user PostScript
0.21328379 -0.054715322 0.21400472 -0.007266587 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50229 .50396 m
.50147 .50376 L
s
% Start of user PostScript
0.068755725 0.11889689 0.044119116 0.11273135 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49836 .50065 m
.49832 .50025 L
s
% Start of user PostScript
-0.049118967 0.01950385 -0.050542329 0.0074914171 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49935 .49906 m
.49955 .49909 L
s
% Start of user PostScript
-0.019438322 -0.028333531 -0.013434972 -0.027420455 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50037 .49979 m
.50039 .49989 L
s
% Start of user PostScript
0.011129821 -0.0062420837 0.011784336 -0.0032336907 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50018 .50022 m
.50013 .50022 L
s
% Start of user PostScript
0.0053561353 0.006671374 0.0039088185 0.0065983112 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49992 .50006 m
.49991 .50004 L
s
% Start of user PostScript
-0.0024737832 0.0018765718 -0.0027083586 0.0011310173 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49995 .49995 m
.49996 .49995 L
s
% Start of user PostScript
-0.0014458768 -0.0015502644 -0.0011008326 -0.0015699413 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50002 .49998 m
.50002 .49999 L
s
% Start of user PostScript
0.00053692644 -0.00054113556 0.00061221684 -0.00035827891 MAarrowhead1
% End of user PostScript
1 .779 0 r
.3778 .33122 m
.41384 .33549 L
.44754 .34565 L
.47792 .36036 L
.50432 .37829 L
.5263 .39821 L
.5437 .419 L
.55656 .43969 L
.56509 .45947 L
.56965 .4777 L
.5707 .49389 L
.56874 .50773 L
.56436 .51903 L
.5581 .52776 L
.55053 .53398 L
.54215 .53784 L
.53343 .53957 L
.52477 .53944 L
.51651 .53775 L
.50892 .53483 L
.50219 .53098 L
.49645 .52651 L
.49178 .52169 L
.48818 .51679 L
.48564 .512 L
.48408 .50749 L
.4834 .50342 L
.4835 .49986 L
.48424 .49687 L
.48549 .49449 L
.48712 .49272 L
.48901 .49152 L
.49103 .49085 L
.49309 .49065 L
.49509 .49086 L
.49697 .4914 L
.49866 .4922 L
.50014 .49319 L
.50138 .49428 L
.50236 .49543 L
.50309 .49658 L
.50358 .49768 L
.50384 .4987 L
.50392 .4996 L
.50382 .50038 L
.50358 .50101 L
.50324 .50151 L
.50283 .50186 L
.50237 .50208 L
.50189 .50219 L
Mistroke
.50141 .50219 L
.50095 .5021 L
.50052 .50194 L
.50015 .50173 L
.49982 .50149 L
.49956 .50122 L
.49936 .50095 L
.49921 .50068 L
.49912 .50043 L
.49908 .5002 L
.49908 .50001 L
.49912 .49984 L
.49919 .4997 L
.49928 .4996 L
.49938 .49953 L
.4995 .4995 L
.49961 .49948 L
.49972 .49949 L
.49982 .49952 L
.49992 .49956 L
.5 .49962 L
.50007 .49968 L
.50013 .49974 L
.50017 .49981 L
.5002 .49987 L
.50021 .49992 L
.50022 .49997 L
.50021 .50002 L
.5002 .50005 L
.50018 .50008 L
.50016 .5001 L
.50013 .50011 L
.50011 .50012 L
.50008 .50012 L
.50005 .50012 L
.50003 .50011 L
.50001 .5001 L
.49999 .50008 L
.49998 .50007 L
.49997 .50005 L
.49996 .50004 L
.49995 .50002 L
.49995 .50001 L
.49995 .5 L
.49995 .49999 L
.49995 .49998 L
.49996 .49998 L
.49997 .49997 L
.49997 .49997 L
.49998 .49997 L
Mistroke
.49998 .49997 L
.49999 .49997 L
.5 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.3778 .33122 m
.41384 .33549 L
s
% Start of user PostScript
-3.666035 -5.0634722 -2.5848469 -4.9353086 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44754 .34565 m
.47792 .36036 L
s
% Start of user PostScript
-1.5738687 -4.6303593 -0.66225745 -4.1892007 MAarrowhead1
% End of user PostScript
1 .473 0 r
.5707 .49389 m
.56874 .50773 L
s
% Start of user PostScript
2.1208918 -0.1832948 2.0623445 0.23182313 MAarrowhead1
% End of user PostScript
1 .788 0 r
.51651 .53775 m
.50892 .53483 L
s
% Start of user PostScript
0.49533982 1.1325655 0.26757919 1.0447648 MAarrowhead1
% End of user PostScript
.897 1 0 r
.4834 .50342 m
.4835 .49986 L
s
% Start of user PostScript
-0.49796198 0.10246046 -0.49503956 -0.0043454103 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49509 .49086 m
.49697 .4914 L
s
% Start of user PostScript
-0.14732538 -0.27410699 -0.091012547 -0.25785551 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50384 .4987 m
.50392 .4996 L
s
% Start of user PostScript
0.1153474 -0.039124807 0.11747382 -0.011965157 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50141 .50219 m
.50095 .5021 L
s
% Start of user PostScript
0.042161753 0.06561587 0.028382688 0.062981449 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49912 .50043 m
.49908 .5002 L
s
% Start of user PostScript
-0.026312695 0.012965482 -0.027533708 0.0061348027 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49961 .49948 m
.49972 .49949 L
s
% Start of user PostScript
-0.011727284 -0.015525162 -0.0083911405 -0.015220869 MAarrowhead1
% End of user PostScript
0 1 .995 r
.5002 .49987 m
.50021 .49992 L
s
% Start of user PostScript
0.0058957197 -0.0039821733 0.0063654875 -0.0022823641 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50011 .50012 m
.50008 .50012 L
s
% Start of user PostScript
0.0031899898 0.0036271262 0.0023910576 0.0036380278 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49996 .50004 m
.49995 .50002 L
s
% Start of user PostScript
-0.0012925863 0.001165373 -0.0014488222 0.00074675636 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49997 .49997 m
.49998 .49997 L
s
% Start of user PostScript
-0.0008519927 -0.00083551909 -0.00066287746 -0.00085937193 MAarrowhead1
% End of user PostScript
0 1 .545 r
.80743 .70023 m
.75763 .72475 L
.70553 .73635 L
.65357 .73663 L
.60381 .72741 L
.55789 .71057 L
.51702 .68802 L
.48204 .66156 L
.45339 .6329 L
.43121 .60352 L
.41533 .57472 L
.40539 .54755 L
.40083 .52284 L
.40097 .50119 L
.40505 .48297 L
.41226 .46835 L
.42183 .45734 L
.43299 .44981 L
.44504 .44549 L
.45735 .44405 L
.46939 .44508 L
.48072 .44813 L
.491 .45277 L
.49999 .45856 L
.50754 .46507 L
.51358 .47194 L
.5181 .47882 L
.52117 .48545 L
.52291 .49159 L
.52345 .49708 L
.52296 .50181 L
.52163 .50571 L
.51966 .50875 L
.51721 .51096 L
.51447 .51237 L
.51159 .51306 L
.50871 .51312 L
.50594 .51264 L
.50338 .51174 L
.5011 .51051 L
.49913 .50906 L
.49752 .50747 L
.49627 .50585 L
.49536 .50425 L
.49479 .50274 L
.49452 .50136 L
.49451 .50015 L
.49472 .49912 L
.49511 .4983 L
.49563 .49768 L
Mistroke
.49624 .49725 L
.49691 .49699 L
.49759 .4969 L
.49826 .49695 L
.49889 .49711 L
.49946 .49736 L
.49997 .49768 L
.50039 .49804 L
.50073 .49842 L
.50099 .4988 L
.50116 .49917 L
.50126 .49951 L
.5013 .49982 L
.50127 .50008 L
.5012 .5003 L
.5011 .50047 L
.50096 .5006 L
.50081 .50068 L
.50065 .50072 L
.50049 .50073 L
.50034 .5007 L
.5002 .50065 L
.50007 .50059 L
.49996 .50051 L
.49987 .50042 L
.4998 .50033 L
.49975 .50024 L
.49971 .50016 L
.4997 .50008 L
.4997 .50001 L
.49971 .49996 L
.49973 .49991 L
.49976 .49987 L
.49979 .49985 L
.49983 .49983 L
.49986 .49983 L
.4999 .49983 L
.49994 .49984 L
.49997 .49985 L
.5 .49987 L
.50002 .49989 L
.50004 .49991 L
.50005 .49993 L
.50006 .49995 L
.50007 .49997 L
.50007 .49999 L
.50007 .5 L
.50007 .50002 L
.50006 .50003 L
.50005 .50003 L
Mistroke
.50005 .50004 L
.50004 .50004 L
.50003 .50004 L
.50002 .50004 L
.50001 .50004 L
.5 .50003 L
.5 .50003 L
.49999 .50002 L
.49999 .50002 L
.49999 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.80743 .70023 m
.75763 .72475 L
s
% Start of user PostScript
9.2228065 6.0068946 7.7289136 6.7425676 MAarrowhead1
% End of user PostScript
1 .158 0 r
.70553 .73635 m
.65357 .73663 L
s
% Start of user PostScript
6.1657776 7.0905001 4.6070246 7.0990275 MAarrowhead1
% End of user PostScript
1 .473 0 r
.41533 .57472 m
.40539 .54755 L
s
% Start of user PostScript
-2.5400419 2.2414906 -2.8382127 1.4265074 MAarrowhead1
% End of user PostScript
1 .788 0 r
.44504 .44549 m
.45735 .44405 L
s
% Start of user PostScript
-1.6488821 -1.63517 -1.2795733 -1.6784769 MAarrowhead1
% End of user PostScript
.897 1 0 r
.5181 .47882 m
.52117 .48545 L
s
% Start of user PostScript
0.54300203 -0.6354161 0.63520165 -0.43663323 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51447 .51237 m
.51159 .51306 L
s
% Start of user PostScript
0.43406255 0.37110243 0.34765358 0.3918319 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49627 .50585 m
.49536 .50425 L
s
% Start of user PostScript
-0.11195721 0.17545397 -0.13906204 0.12748276 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49624 .49725 m
.49691 .49699 L
s
% Start of user PostScript
-0.11269887 -0.082642088 -0.092761049 -0.090179254 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50073 .49842 m
.50099 .4988 L
s
% Start of user PostScript
0.021910452 -0.047444655 0.029602442 -0.035996166 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50096 .5006 m
.50081 .50068 L
s
% Start of user PostScript
0.028898952 0.01798057 0.024371241 0.020418027 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49987 .50042 m
.4998 .50033 L
s
% Start of user PostScript
-0.0039419706 0.012608774 -0.0060677053 0.0099088449 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49976 .49987 m
.49979 .49985 L
s
% Start of user PostScript
-0.007325693 -0.0037964764 -0.0063166465 -0.0045340497 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50002 .49989 m
.50004 .49991 L
s
% Start of user PostScript
0.00060170382 -0.0033012285 0.0011769192 -0.0026727247 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50006 .50003 m
.50005 .50003 L
s
% Start of user PostScript
0.0018369147 0.00076929524 0.0016171688 0.00098295463 MAarrowhead1
% End of user PostScript
.474 0 1 r
.32344 .45886 m
.33859 .43316 L
.35776 .41427 L
.37954 .40184 L
.40264 .39533 L
.42592 .39404 L
.44843 .39721 L
.46939 .40397 L
.48821 .41349 L
.50448 .42494 L
.51796 .43756 L
.52855 .45064 L
.5363 .4636 L
.54136 .47593 L
.54395 .48725 L
.54437 .49726 L
.54294 .50577 L
.54003 .51269 L
.53598 .51798 L
.53115 .52171 L
.52584 .52397 L
.52036 .52491 L
.51494 .5247 L
.50979 .52354 L
.50508 .52162 L
.50092 .51915 L
.49739 .51631 L
.49453 .51327 L
.49235 .51019 L
.49083 .50719 L
.48992 .50439 L
.48955 .50187 L
.48967 .49967 L
.49018 .49784 L
.49099 .49639 L
.49204 .49532 L
.49324 .4946 L
.49452 .49422 L
.49581 .49413 L
.49706 .49429 L
.49823 .49465 L
.49928 .49517 L
.50019 .4958 L
.50095 .49649 L
.50154 .49721 L
.50198 .49793 L
.50227 .49862 L
.50243 .49925 L
.50246 .49981 L
.50239 .50029 L
Mistroke
.50223 .50068 L
.50201 .50098 L
.50174 .50119 L
.50145 .50132 L
.50115 .50138 L
.50085 .50137 L
.50056 .50131 L
.5003 .50121 L
.50007 .50107 L
.49987 .50091 L
.49971 .50075 L
.49958 .50058 L
.4995 .50041 L
.49944 .50025 L
.49942 .50011 L
.49943 .49999 L
.49945 .49989 L
.4995 .49981 L
.49955 .49974 L
.49962 .4997 L
.49969 .49968 L
.49976 .49967 L
.49983 .49968 L
.4999 .4997 L
.49996 .49973 L
.50001 .49976 L
.50005 .4998 L
.50008 .49984 L
.50011 .49988 L
.50013 .49992 L
.50013 .49996 L
.50014 .49999 L
.50013 .50001 L
.50012 .50004 L
.50011 .50005 L
.5001 .50007 L
.50008 .50007 L
.50006 .50008 L
.50005 .50008 L
.50003 .50007 L
.50002 .50007 L
.5 .50006 L
.49999 .50005 L
.49998 .50004 L
.49998 .50003 L
.49997 .50002 L
.49997 .50001 L
.49997 .50001 L
.49997 .5 L
.49997 .49999 L
Mistroke
.49997 .49999 L
.49998 .49999 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.32344 .45886 m
.33859 .43316 L
s
% Start of user PostScript
-5.296836 -1.2342924 -4.8424183 -2.0050626 MAarrowhead1
% End of user PostScript
1 .158 0 r
.35776 .41427 m
.37954 .40184 L
s
% Start of user PostScript
-4.2673074 -2.5719092 -3.6138781 -2.9449027 MAarrowhead1
% End of user PostScript
1 .473 0 r
.51796 .43756 m
.52855 .45064 L
s
% Start of user PostScript
0.53866834 -1.873315 0.85653098 -1.4807409 MAarrowhead1
% End of user PostScript
1 .788 0 r
.53598 .51798 m
.53115 .52171 L
s
% Start of user PostScript
1.0795392 0.53951349 0.93447606 0.65134041 MAarrowhead1
% End of user PostScript
.897 1 0 r
.49739 .51631 m
.49453 .51327 L
s
% Start of user PostScript
-0.078254373 0.48923066 -0.16397247 0.39807685 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49099 .49639 m
.49204 .49532 L
s
% Start of user PostScript
-0.27016748 -0.10830775 -0.23872912 -0.1404925 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50019 .4958 m
.50095 .49649 L
s
% Start of user PostScript
0.0056380976 -0.12611864 0.028365389 -0.1052676 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50223 .50068 m
.50201 .50098 L
s
% Start of user PostScript
0.066907534 0.020332024 0.06030398 0.029322879 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50007 .50107 m
.49987 .50091 L
s
% Start of user PostScript
0.0019923896 0.032128426 -0.0039459555 0.027441183 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49945 .49989 m
.4995 .49981 L
s
% Start of user PostScript
-0.016398463 -0.0033894587 -0.015070279 -0.0058435551 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49996 .49973 m
.50001 .49976 L
s
% Start of user PostScript
-0.0013203947 -0.0080941374 0.00021113382 -0.0070623522 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50013 .50001 m
.50012 .50004 L
s
% Start of user PostScript
0.0039770543 0.00042660486 0.0037269596 0.0010839428 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50002 .50007 m
.5 .50006 L
s
% Start of user PostScript
0.0005266782 0.0020175581 0.00013636357 0.0017963569 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49997 .5 m
.49997 .49999 L
s
% Start of user PostScript
-0.0009541016 -0.0000031952694 -0.00091216262 -0.00017647636 MAarrowhead1
% End of user PostScript
.164 0 1 r
.34746 .17408 m
.41344 .19753 L
.47228 .22931 L
.52279 .26681 L
.56428 .30761 L
.59653 .34956 L
.61975 .39079 L
.63445 .42977 L
.64142 .4653 L
.64161 .49651 L
.6361 .52285 L
.62604 .54405 L
.61255 .56008 L
.59673 .57114 L
.57958 .57758 L
.562 .57988 L
.54476 .57862 L
.5285 .57441 L
.51372 .56791 L
.50075 .55973 L
.48984 .55048 L
.48109 .54069 L
.47449 .53085 L
.46998 .52136 L
.46739 .51253 L
.46652 .50462 L
.46713 .4978 L
.46896 .49216 L
.47173 .48774 L
.47519 .48451 L
.47909 .48243 L
.48319 .48138 L
.48731 .48125 L
.49128 .48188 L
.49496 .48314 L
.49825 .48487 L
.50108 .48693 L
.50341 .48918 L
.50523 .4915 L
.50655 .49379 L
.5074 .49596 L
.50781 .49794 L
.50785 .49969 L
.50757 .50117 L
.50703 .50236 L
.50629 .50327 L
.50542 .5039 L
.50448 .50428 L
.5035 .50442 L
.50255 .50436 L
Mistroke
.50164 .50414 L
.50082 .50379 L
.50009 .50334 L
.49948 .50283 L
.49898 .50229 L
.49861 .50175 L
.49835 .50122 L
.4982 .50073 L
.49815 .50029 L
.49818 .4999 L
.49827 .49959 L
.49842 .49934 L
.49861 .49915 L
.49883 .49903 L
.49905 .49897 L
.49928 .49896 L
.4995 .49899 L
.49971 .49906 L
.49989 .49915 L
.50005 .49927 L
.50018 .49939 L
.50028 .49952 L
.50036 .49965 L
.50041 .49977 L
.50043 .49988 L
.50044 .49998 L
.50042 .50006 L
.50039 .50013 L
.50035 .50018 L
.5003 .50021 L
.50025 .50024 L
.5002 .50024 L
.50014 .50024 L
.50009 .50023 L
.50005 .50021 L
.50001 .50019 L
.49997 .50016 L
.49995 .50013 L
.49992 .5001 L
.49991 .50007 L
.4999 .50004 L
.4999 .50002 L
.4999 .5 L
.4999 .49998 L
.49991 .49996 L
.49992 .49995 L
.49993 .49995 L
.49995 .49994 L
.49996 .49994 L
.49997 .49994 L
Mistroke
.49998 .49995 L
.49999 .49995 L
.5 .49996 L
.50001 .49997 L
.50002 .49997 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.34746 .17408 m
.41344 .19753 L
s
% Start of user PostScript
-4.5760795 -9.7775267 -2.5968101 -9.0741376 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47228 .22931 m
.52279 .26681 L
s
% Start of user PostScript
-0.83145285 -8.1208006 0.68373827 -6.9957668 MAarrowhead1
% End of user PostScript
1 .473 0 r
.6361 .52285 m
.62604 .54405 L
s
% Start of user PostScript
4.0831071 0.68555209 3.7812498 1.3215039 MAarrowhead1
% End of user PostScript
1 .788 0 r
.51372 .56791 m
.50075 .55973 L
s
% Start of user PostScript
0.41146847 2.0372251 0.022565567 1.7919478 MAarrowhead1
% End of user PostScript
.897 1 0 r
.46713 .4978 m
.46896 .49216 L
s
% Start of user PostScript
-0.9860787 -0.066056543 -0.93130385 -0.23528113 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49496 .48314 m
.49825 .48487 L
s
% Start of user PostScript
-0.15132128 -0.50571322 -0.052649687 -0.45378428 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50785 .49969 m
.50757 .50117 L
s
% Start of user PostScript
0.23551347 -0.0092786291 0.22699483 0.035077077 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50164 .50414 m
.50082 .50379 L
s
% Start of user PostScript
0.049222516 0.12423823 0.024459713 0.11367526 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49815 .50029 m
.49818 .4999 L
s
% Start of user PostScript
-0.055588304 0.0085693486 -0.054739595 -0.0029026791 MAarrowhead1
% End of user PostScript
0 1 .679 r
.4995 .49899 m
.49971 .49906 L
s
% Start of user PostScript
-0.01494857 -0.03020352 -0.0087992286 -0.028178729 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50043 .49988 m
.50044 .49998 L
s
% Start of user PostScript
0.012952134 -0.0036402123 0.013053744 -0.00070887515 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50014 .50024 m
.50009 .50023 L
s
% Start of user PostScript
0.0043411091 0.0072640537 0.0028298374 0.0069129494 MAarrowhead1
% End of user PostScript
0 .375 1 r
.4999 .50004 m
.4999 .50002 L
s
% Start of user PostScript
-0.002974478 0.0012649231 -0.0030759421 0.00052431304 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49996 .49994 m
.49997 .49994 L
s
% Start of user PostScript
-0.0012208887 -0.0017273413 -0.00085334355 -0.001678204 MAarrowhead1
% End of user PostScript
1 .889 0 r
.66517 .49976 m
.65805 .52988 L
.64576 .55397 L
.62961 .57204 L
.61087 .58432 L
.59071 .59126 L
.57015 .59344 L
.55009 .59153 L
.53125 .58627 L
.51418 .5784 L
.49929 .56866 L
.48681 .55774 L
.47687 .54626 L
.46945 .53477 L
.46444 .52374 L
.46165 .51353 L
.46085 .50442 L
.46174 .4966 L
.46402 .49016 L
.46737 .48516 L
.47149 .48155 L
.47609 .47925 L
.4809 .47816 L
.48571 .47811 L
.49031 .47895 L
.49457 .4805 L
.49836 .48257 L
.5016 .48501 L
.50426 .48766 L
.50633 .49038 L
.5078 .49304 L
.50873 .49556 L
.50916 .49785 L
.50916 .49985 L
.50879 .50154 L
.50813 .5029 L
.50725 .50393 L
.50622 .50463 L
.5051 .50503 L
.50397 .50517 L
.50285 .50508 L
.5018 .5048 L
.50085 .50438 L
.50002 .50384 L
.49932 .50324 L
.49875 .50261 L
.49833 .50197 L
.49805 .50136 L
.49788 .50079 L
.49783 .50028 L
Mistroke
.49788 .49984 L
.498 .49948 L
.49818 .4992 L
.4984 .49899 L
.49866 .49886 L
.49892 .49879 L
.49919 .49879 L
.49945 .49883 L
.49968 .49891 L
.49989 .49903 L
.50008 .49916 L
.50023 .49931 L
.50034 .49946 L
.50043 .4996 L
.50048 .49974 L
.50051 .49987 L
.50051 .49998 L
.50049 .50008 L
.50045 .50016 L
.50041 .50021 L
.50035 .50025 L
.50029 .50028 L
.50022 .50029 L
.50016 .50028 L
.5001 .50027 L
.50005 .50024 L
.5 .50022 L
.49996 .50018 L
.49993 .50015 L
.49991 .50011 L
.49989 .50008 L
.49988 .50005 L
.49988 .50002 L
.49988 .49999 L
.49989 .49997 L
.4999 .49996 L
.49991 .49994 L
.49992 .49994 L
.49994 .49993 L
.49995 .49993 L
.49997 .49993 L
.49998 .49994 L
.49999 .49995 L
.5 .49995 L
.50001 .49996 L
.50002 .49997 L
.50002 .49998 L
.50003 .49999 L
.50003 .49999 L
.50003 .5 L
Mistroke
.50003 .5 L
.50003 .50001 L
.50002 .50001 L
.50002 .50001 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.66517 .49976 m
.65805 .52988 L
s
% Start of user PostScript
4.9550066 -0.0073074024 4.7415553 0.89636314 MAarrowhead1
% End of user PostScript
1 .158 0 r
.64576 .55397 m
.62961 .57204 L
s
% Start of user PostScript
4.3727587 1.6191104 3.8883045 2.161078 MAarrowhead1
% End of user PostScript
1 .473 0 r
.49929 .56866 m
.48681 .55774 L
s
% Start of user PostScript
-0.021352323 2.0597359 -0.39559414 1.7320847 MAarrowhead1
% End of user PostScript
1 .788 0 r
.46402 .49016 m
.46737 .48516 L
s
% Start of user PostScript
-1.0793886 -0.29513109 -0.97884463 -0.44534411 MAarrowhead1
% End of user PostScript
.897 1 0 r
.49836 .48257 m
.5016 .48501 L
s
% Start of user PostScript
-0.049306571 -0.52284592 0.048063649 -0.44964264 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50879 .50154 m
.50813 .5029 L
s
% Start of user PostScript
0.26368109 0.04634426 0.24381013 0.087087362 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50085 .50438 m
.50002 .50384 L
s
% Start of user PostScript
0.025490103 0.1312753 0.00047426168 0.11528349 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49788 .49984 m
.498 .49948 L
s
% Start of user PostScript
-0.063734221 -0.0047913052 -0.060098859 -0.015646948 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49968 .49891 m
.49989 .49903 L
s
% Start of user PostScript
-0.0095080723 -0.03261433 -0.0031554442 -0.029219642 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50051 .49998 m
.50049 .50008 L
s
% Start of user PostScript
0.015235954 -0.00046740194 0.014660663 0.0023811962 MAarrowhead1
% End of user PostScript
0 1 .995 r
.5001 .50027 m
.50005 .50024 L
s
% Start of user PostScript
0.0031149648 0.0080189639 0.0015193403 0.0073258641 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49988 .50002 m
.49988 .49999 L
s
% Start of user PostScript
-0.0035996528 0.00052068462 -0.0035384597 -0.00021681293 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49997 .49993 m
.49998 .49994 L
s
% Start of user PostScript
-0.00095013299 -0.0019511272 -0.00055356301 -0.0018174975 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50003 .49999 m
.50003 .5 L
s
% Start of user PostScript
0.0008396264 -0.00022704481 0.00084458624 -0.000038424071 MAarrowhead1
% End of user PostScript
0 1 .465 r
.63208 .22984 m
.67556 .29636 L
.70505 .36035 L
.72159 .41965 L
.72662 .47264 L
.72178 .51822 L
.70885 .55575 L
.68964 .58503 L
.66594 .60621 L
.6394 .61974 L
.61155 .62631 L
.58371 .62677 L
.55699 .62209 L
.53228 .61328 L
.51025 .60135 L
.49134 .58729 L
.47582 .57199 L
.46375 .55627 L
.45508 .54082 L
.44959 .52622 L
.447 .51292 L
.44694 .50123 L
.44902 .49138 L
.4528 .48345 L
.45786 .47745 L
.46379 .47332 L
.47022 .47092 L
.47681 .47006 L
.48327 .47055 L
.48936 .47213 L
.4949 .47457 L
.49975 .47764 L
.50383 .48111 L
.50711 .48477 L
.50957 .48846 L
.51126 .49202 L
.51222 .49532 L
.51255 .49829 L
.51231 .50084 L
.51163 .50295 L
.51059 .50461 L
.50929 .50581 L
.50783 .50659 L
.50629 .50698 L
.50474 .50703 L
.50326 .50679 L
.50188 .50631 L
.50065 .50566 L
.49959 .50489 L
.49872 .50405 L
Mistroke
.49804 .50318 L
.49754 .50232 L
.49723 .50151 L
.49707 .50077 L
.49706 .50011 L
.49717 .49956 L
.49737 .49911 L
.49764 .49877 L
.49797 .49854 L
.49833 .4984 L
.49869 .49834 L
.49905 .49837 L
.49939 .49845 L
.4997 .49858 L
.49997 .49875 L
.5002 .49894 L
.50038 .49914 L
.50052 .49935 L
.50062 .49954 L
.50067 .49973 L
.50069 .49989 L
.50068 .50004 L
.50065 .50016 L
.50059 .50025 L
.50052 .50032 L
.50044 .50036 L
.50035 .50039 L
.50027 .50039 L
.50019 .50038 L
.50011 .50035 L
.50004 .50032 L
.49998 .50027 L
.49993 .50023 L
.49989 .50018 L
.49987 .50013 L
.49985 .50009 L
.49984 .50005 L
.49984 .50001 L
.49984 .49998 L
.49985 .49995 L
.49987 .49993 L
.49989 .49992 L
.49991 .49991 L
.49993 .49991 L
.49995 .49991 L
.49996 .49991 L
.49998 .49992 L
.5 .49993 L
.50001 .49994 L
.50002 .49995 L
Mistroke
.50003 .49996 L
.50003 .49997 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50003 .50001 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.63208 .22984 m
.67556 .29636 L
s
% Start of user PostScript
3.9624417 -8.104845 5.2669279 -6.1091428 MAarrowhead1
% End of user PostScript
1 .158 0 r
.70505 .36035 m
.72159 .41965 L
s
% Start of user PostScript
6.1513652 -4.1895337 6.647821 -2.4105662 MAarrowhead1
% End of user PostScript
1 .473 0 r
.61155 .62631 m
.58371 .62677 L
s
% Start of user PostScript
3.3464221 3.7891854 2.5111911 3.8031067 MAarrowhead1
% End of user PostScript
1 .788 0 r
.45508 .54082 m
.44959 .52622 L
s
% Start of user PostScript
-1.3477188 1.2247008 -1.5123711 0.78671669 MAarrowhead1
% End of user PostScript
.897 1 0 r
.47022 .47092 m
.47681 .47006 L
s
% Start of user PostScript
-0.89335582 -0.87248288 -0.69571493 -0.89805954 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50957 .48846 m
.51126 .49202 L
s
% Start of user PostScript
0.28717685 -0.34611871 0.33777199 -0.23940626 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50783 .50659 m
.50629 .50698 L
s
% Start of user PostScript
0.23481799 0.19765248 0.18863835 0.2093548 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49804 .50318 m
.49754 .50232 L
s
% Start of user PostScript
-0.058944955 0.095344785 -0.073756323 0.069621467 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49797 .49854 m
.49833 .4984 L
s
% Start of user PostScript
-0.060885557 -0.043920036 -0.050246634 -0.048106318 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50038 .49914 m
.50052 .49935 L
s
% Start of user PostScript
0.01145738 -0.025732254 0.015647704 -0.019600613 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50052 .50032 m
.50044 .50036 L
s
% Start of user PostScript
0.015593459 0.0095295699 0.013181788 0.010871899 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49993 .50023 m
.49989 .50018 L
s
% Start of user PostScript
-0.0020369773 0.0068272941 -0.0031922282 0.0053831159 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49987 .49993 m
.49989 .49992 L
s
% Start of user PostScript
-0.0039482855 -0.002004787 -0.0034119823 -0.0024088165 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50001 .49994 m
.50002 .49995 L
s
% Start of user PostScript
0.00030269404 -0.0017849485 0.00061468996 -0.0014492456 MAarrowhead1
% End of user PostScript
.165 0 1 r
.79984 .46379 m
.79344 .5241 L
.77633 .57376 L
.75092 .61249 L
.71955 .64051 L
.68444 .65842 L
.64759 .66711 L
.61075 .66773 L
.5754 .66153 L
.54271 .64988 L
.51356 .6341 L
.48855 .61549 L
.46801 .59525 L
.45205 .57445 L
.44056 .55402 L
.4333 .5347 L
.42987 .5171 L
.4298 .50164 L
.43254 .48859 L
.43755 .4781 L
.44424 .47017 L
.45209 .4647 L
.4606 .46152 L
.46932 .46039 L
.47786 .46103 L
.48592 .46312 L
.49325 .46635 L
.49967 .47041 L
.50507 .475 L
.5094 .47986 L
.51266 .48473 L
.5149 .48944 L
.51617 .49381 L
.5166 .49773 L
.51629 .50111 L
.51538 .5039 L
.51401 .50609 L
.51229 .50769 L
.51036 .50872 L
.50832 .50923 L
.50628 .5093 L
.50431 .50898 L
.50249 .50835 L
.50086 .50749 L
.49946 .50647 L
.4983 .50536 L
.4974 .50421 L
.49675 .50307 L
.49633 .502 L
.49612 .50101 L
Mistroke
.49611 .50015 L
.49625 .49942 L
.49652 .49882 L
.49688 .49838 L
.49731 .49806 L
.49778 .49788 L
.49827 .49781 L
.49874 .49784 L
.49919 .49795 L
.4996 .49812 L
.49996 .49834 L
.50026 .4986 L
.50051 .49887 L
.50069 .49914 L
.50082 .4994 L
.50089 .49964 L
.50092 .49986 L
.5009 .50005 L
.50086 .50021 L
.50078 .50033 L
.50069 .50042 L
.50058 .50048 L
.50047 .50051 L
.50036 .50052 L
.50025 .5005 L
.50014 .50047 L
.50005 .50042 L
.49998 .50036 L
.49991 .5003 L
.49986 .50024 L
.49982 .50017 L
.4998 .50011 L
.49979 .50006 L
.49978 .50001 L
.49979 .49997 L
.49981 .49994 L
.49983 .49991 L
.49985 .49989 L
.49988 .49988 L
.4999 .49988 L
.49993 .49988 L
.49995 .49989 L
.49998 .4999 L
.5 .49991 L
.50001 .49992 L
.50003 .49994 L
.50004 .49995 L
.50004 .49997 L
.50005 .49998 L
.50005 .49999 L
Mistroke
.50005 .5 L
.50005 .50001 L
.50004 .50002 L
.50004 .50002 L
.50003 .50003 L
.50003 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50003 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.79984 .46379 m
.79344 .5241 L
s
% Start of user PostScript
8.99513 -1.0862986 8.8030846 0.72285638 MAarrowhead1
% End of user PostScript
1 .158 0 r
.77633 .57376 m
.75092 .61249 L
s
% Start of user PostScript
8.2898379 2.2126574 7.5274813 3.3747979 MAarrowhead1
% End of user PostScript
1 .473 0 r
.51356 .6341 m
.48855 .61549 L
s
% Start of user PostScript
0.40686603 4.0229647 -0.34352681 3.4647183 MAarrowhead1
% End of user PostScript
1 .788 0 r
.43254 .48859 m
.43755 .4781 L
s
% Start of user PostScript
-2.0236784 -0.34224058 -1.8736221 -0.65704484 MAarrowhead1
% End of user PostScript
.897 1 0 r
.49325 .46635 m
.49967 .47041 L
s
% Start of user PostScript
-0.20264555 -1.009354 -0.010014376 -0.88760805 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51629 .50111 m
.51538 .5039 L
s
% Start of user PostScript
0.48878756 0.033364324 0.46152322 0.11714936 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50249 .50835 m
.50086 .50749 L
s
% Start of user PostScript
0.074684019 0.25059047 0.025803318 0.22480431 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49611 .50015 m
.49625 .49942 L
s
% Start of user PostScript
-0.11675763 0.0044418727 -0.11250566 -0.017522965 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49919 .49795 m
.4996 .49812 L
s
% Start of user PostScript
-0.024319913 -0.061570275 -0.012051108 -0.056321992 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50092 .49986 m
.5009 .50005 L
s
% Start of user PostScript
0.027562506 -0.0042082372 0.02713427 0.001473569 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50025 .5005 m
.50014 .50047 L
s
% Start of user PostScript
0.0073907286 0.014970282 0.0043436277 0.013963333 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49979 .50006 m
.49978 .50001 L
s
% Start of user PostScript
-0.0064231681 0.0017946097 -0.0064716225 0.00034258396 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49993 .49988 m
.49995 .49989 L
s
% Start of user PostScript
-0.0021472753 -0.0036008937 -0.0013983193 -0.0034259951 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50005 .49998 m
.50005 .49999 L
s
% Start of user PostScript
0.0014753713 -0.00062460016 0.0015251859 -0.00025769246 MAarrowhead1
% End of user PostScript
1 0 .704 r
.55399 .54954 m
.54263 .55159 L
.53138 .55124 L
.52069 .5489 L
.51088 .54499 L
.50222 .5399 L
.49485 .53403 L
.48888 .52774 L
.48431 .52136 L
.4811 .51514 L
.47916 .50932 L
.47837 .50406 L
.47856 .49948 L
.47959 .49566 L
.48126 .49262 L
.48342 .49037 L
.48589 .48886 L
.48853 .48804 L
.49121 .48783 L
.4938 .48815 L
.49623 .48888 L
.49842 .48994 L
.50032 .49124 L
.5019 .49267 L
.50316 .49417 L
.50408 .49566 L
.50469 .49709 L
.50502 .4984 L
.5051 .49957 L
.50495 .50056 L
.50464 .50138 L
.50418 .502 L
.50364 .50245 L
.50303 .50273 L
.50241 .50285 L
.50178 .50284 L
.50119 .50272 L
.50064 .50251 L
.50016 .50223 L
.49974 .50191 L
.49941 .50156 L
.49915 .50121 L
.49896 .50086 L
.49885 .50054 L
.4988 .50024 L
.49881 .49999 L
.49886 .49977 L
.49895 .4996 L
.49907 .49947 L
.49921 .49939 L
Mistroke
.49935 .49934 L
.4995 .49933 L
.49965 .49934 L
.49978 .49938 L
.4999 .49944 L
.50001 .49951 L
.5001 .49959 L
.50017 .49967 L
.50022 .49975 L
.50026 .49983 L
.50028 .49991 L
.50028 .49997 L
.50028 .50003 L
.50026 .50007 L
.50023 .50011 L
.5002 .50013 L
.50017 .50015 L
.50014 .50016 L
.5001 .50016 L
.50007 .50015 L
.50004 .50014 L
.50001 .50012 L
.49999 .50011 L
.49997 .50009 L
.49995 .50007 L
.49994 .50005 L
.49994 .50003 L
.49993 .50001 L
.49993 .5 L
.49994 .49999 L
.49994 .49998 L
.49995 .49997 L
.49996 .49997 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49999 .49997 L
.49999 .49997 L
.5 .49997 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
Mistroke
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.55399 .54954 m
.54263 .55159 L
s
% Start of user PostScript
1.6196915 1.4862725 1.2787688 1.5476672 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53138 .55124 m
.52069 .5489 L
s
% Start of user PostScript
0.94144119 1.5373147 0.62062122 1.4671474 MAarrowhead1
% End of user PostScript
1 .473 0 r
.47916 .50932 m
.47837 .50406 L
s
% Start of user PostScript
-0.62521728 0.27956077 -0.64903645 0.12173846 MAarrowhead1
% End of user PostScript
1 .788 0 r
.49121 .48783 m
.4938 .48815 L
s
% Start of user PostScript
-0.26376643 -0.36496303 -0.18585745 -0.35563921 MAarrowhead1
% End of user PostScript
.897 1 0 r
.50469 .49709 m
.50502 .4984 L
s
% Start of user PostScript
0.14084112 -0.087390726 0.15065379 -0.048000828 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50241 .50285 m
.50178 .50284 L
s
% Start of user PostScript
0.072164679 0.085580452 0.053448674 0.085272712 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49896 .50086 m
.49885 .50054 L
s
% Start of user PostScript
-0.031082472 0.025877085 -0.034448497 0.016148097 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49935 .49934 m
.4995 .49933 L
s
% Start of user PostScript
-0.019367066 -0.01979558 -0.014921936 -0.020211572 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50022 .49975 m
.50026 .49983 L
s
% Start of user PostScript
0.0066856785 -0.0073820403 0.0077404678 -0.0050039333 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50017 .50015 m
.50014 .50016 L
s
% Start of user PostScript
0.0051138758 0.0045083069 0.0040710486 0.0047311223 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49995 .50007 m
.49994 .50005 L
s
% Start of user PostScript
-0.0013901194 0.0020483208 -0.0017029508 0.001473152 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49996 .49997 m
.49996 .49996 L
s
% Start of user PostScript
-0.0013313483 -0.0010081753 -0.0010900064 -0.0010922004 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50001 .49998 m
.50001 .49999 L
s
% Start of user PostScript
0.00027548861 -0.00055608126 0.00036483369 -0.00041849454 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50001 .50001 m
.50001 .50001 L
s
% Start of user PostScript
0.00034223466 0.00022049847 0.00028723763 0.00024817496 MAarrowhead1
% End of user PostScript
0 .981 1 r
.18685 .65002 m
.1731 .5694 L
.17463 .49895 L
.18892 .43985 L
.21336 .39264 L
.24534 .35731 L
.28237 .33335 L
.32216 .31991 L
.36267 .31582 L
.40217 .31976 L
.43924 .33027 L
.47279 .34588 L
.50204 .36515 L
.52651 .38672 L
.546 .40935 L
.56051 .43198 L
.57028 .45369 L
.57567 .47377 L
.57716 .49168 L
.57534 .50704 L
.57079 .51966 L
.56414 .52946 L
.55599 .53651 L
.54692 .54097 L
.53742 .54308 L
.52795 .54312 L
.51889 .54143 L
.51052 .53836 L
.50308 .53425 L
.49671 .52942 L
.49149 .5242 L
.48745 .51885 L
.48456 .5136 L
.48275 .50865 L
.48193 .50415 L
.48195 .5002 L
.4827 .49688 L
.48402 .49422 L
.48576 .49222 L
.4878 .49085 L
.48999 .49006 L
.49224 .4898 L
.49443 .48999 L
.49649 .49055 L
.49837 .4914 L
.5 .49245 L
.50138 .49364 L
.50248 .49489 L
.5033 .49614 L
.50386 .49735 L
Mistroke
.50418 .49847 L
.50427 .49947 L
.50418 .50033 L
.50394 .50104 L
.50358 .5016 L
.50313 .502 L
.50263 .50226 L
.50211 .50238 L
.50158 .50239 L
.50108 .5023 L
.50061 .50214 L
.5002 .50191 L
.49984 .50165 L
.49955 .50136 L
.49932 .50106 L
.49915 .50077 L
.49905 .5005 L
.499 .50025 L
.499 .50003 L
.49904 .49984 L
.49911 .49969 L
.4992 .49958 L
.49932 .4995 L
.49944 .49945 L
.49956 .49944 L
.49968 .49944 L
.4998 .49947 L
.4999 .49952 L
.49999 .49958 L
.50007 .49964 L
.50013 .49971 L
.50018 .49978 L
.50021 .49985 L
.50023 .49991 L
.50024 .49997 L
.50023 .50002 L
.50022 .50006 L
.5002 .50009 L
.50018 .50011 L
.50015 .50012 L
.50012 .50013 L
.50009 .50013 L
.50006 .50013 L
.50004 .50012 L
.50001 .50011 L
.49999 .50009 L
.49998 .50008 L
.49996 .50006 L
.49995 .50004 L
.49995 .50003 L
Mistroke
.49994 .50001 L
.49994 .5 L
.49995 .49999 L
.49995 .49998 L
.49996 .49998 L
.49996 .49997 L
.49997 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49998 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.18685 .65002 m
.1731 .5694 L
s
% Start of user PostScript
-9.3945646 4.5006658 -9.8071096 2.0820652 MAarrowhead1
% End of user PostScript
1 .158 0 r
.17463 .49895 m
.18892 .43985 L
s
% Start of user PostScript
-9.7612401 -0.03150733 -9.3323855 -1.8045006 MAarrowhead1
% End of user PostScript
1 .473 0 r
.43924 .33027 m
.47279 .34588 L
s
% Start of user PostScript
-1.8228792 -5.0918905 -0.81640933 -4.6235412 MAarrowhead1
% End of user PostScript
1 .788 0 r
.57716 .49168 m
.57534 .50704 L
s
% Start of user PostScript
2.3149306 -0.24966742 2.2600617 0.21122626 MAarrowhead1
% End of user PostScript
.897 1 0 r
.51889 .54143 m
.51052 .53836 L
s
% Start of user PostScript
0.56655531 1.243022 0.31558881 1.1508305 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48193 .50415 m
.48195 .5002 L
s
% Start of user PostScript
-0.54221082 0.12441224 -0.54136874 0.0060962124 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49443 .48999 m
.49649 .49055 L
s
% Start of user PostScript
-0.16712404 -0.30023538 -0.1051939 -0.28348308 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50418 .49847 m
.50427 .49947 L
s
% Start of user PostScript
0.12525804 -0.045859053 0.12818147 -0.015835714 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50158 .50239 m
.50108 .5023 L
s
% Start of user PostScript
0.047545109 0.071718581 0.032421125 0.069105441 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49905 .5005 m
.499 .50025 L
s
% Start of user PostScript
-0.028484456 0.014934669 -0.029970006 0.0073988887 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49956 .49944 m
.49968 .49944 L
s
% Start of user PostScript
-0.013164603 -0.016930514 -0.0095101818 -0.016667117 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50021 .49985 m
.50023 .49991 L
s
% Start of user PostScript
0.0063586011 -0.004538821 0.0069096944 -0.0026672037 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50012 .50013 m
.50009 .50013 L
s
% Start of user PostScript
0.003567831 0.0039455384 0.002694524 0.0039752114 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49995 .50004 m
.49995 .50003 L
s
% Start of user PostScript
-0.0013876285 0.001318739 -0.0015676793 0.00085870403 MAarrowhead1
% End of user PostScript
1 0 .627 r
.73365 .27089 m
.76525 .34946 L
.78117 .42144 L
.7833 .485 L
.77375 .53896 L
.75479 .5827 L
.72868 .61611 L
.69762 .63951 L
.66364 .65357 L
.62858 .65924 L
.594 .65763 L
.56121 .64997 L
.53124 .63755 L
.50483 .62162 L
.48247 .60338 L
.4644 .58394 L
.45066 .56426 L
.44109 .54517 L
.43542 .52734 L
.43323 .51128 L
.43407 .49735 L
.43742 .48576 L
.44272 .4766 L
.44947 .46984 L
.45715 .46538 L
.46532 .46302 L
.47356 .46251 L
.48153 .46359 L
.48896 .46595 L
.49564 .46929 L
.50143 .47332 L
.50622 .47778 L
.51 .4824 L
.51277 .48699 L
.51459 .49136 L
.51553 .49538 L
.5157 .49893 L
.51521 .50196 L
.5142 .50442 L
.51278 .50631 L
.51107 .50765 L
.5092 .50846 L
.50726 .50881 L
.50534 .50875 L
.50352 .50834 L
.50184 .50767 L
.50037 .5068 L
.49911 .5058 L
.49809 .50473 L
.49732 .50364 L
Mistroke
.49677 .50258 L
.49644 .50158 L
.49631 .50069 L
.49634 .4999 L
.49652 .49925 L
.4968 .49874 L
.49717 .49835 L
.4976 .4981 L
.49805 .49796 L
.4985 .49792 L
.49895 .49798 L
.49936 .4981 L
.49973 .49828 L
.50006 .49851 L
.50033 .49875 L
.50054 .49901 L
.5007 .49926 L
.5008 .4995 L
.50086 .49973 L
.50087 .49993 L
.50085 .5001 L
.50079 .50024 L
.50071 .50034 L
.50062 .50042 L
.50052 .50047 L
.50041 .50049 L
.5003 .50049 L
.5002 .50046 L
.50011 .50043 L
.50003 .50038 L
.49996 .50033 L
.4999 .50027 L
.49985 .50021 L
.49982 .50015 L
.4998 .50009 L
.4998 .50004 L
.4998 .5 L
.49981 .49996 L
.49982 .49993 L
.49984 .49991 L
.49987 .4999 L
.49989 .49989 L
.49992 .49988 L
.49994 .49989 L
.49996 .49989 L
.49998 .4999 L
.5 .49992 L
.50002 .49993 L
.50003 .49994 L
.50004 .49996 L
Mistroke
.50004 .49997 L
.50005 .49998 L
.50005 .5 L
.50005 .5 L
.50004 .50001 L
.50004 .50002 L
.50003 .50002 L
.50003 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.73365 .27089 m
.76525 .34946 L
s
% Start of user PostScript
7.0095054 -6.873225 7.9575806 -4.5161137 MAarrowhead1
% End of user PostScript
1 .158 0 r
.78117 .42144 m
.7833 .485 L
s
% Start of user PostScript
8.4352276 -2.356822 8.4988695 -0.44994088 MAarrowhead1
% End of user PostScript
1 .473 0 r
.594 .65763 m
.56121 .64997 L
s
% Start of user PostScript
2.8199363 4.7288818 1.8363671 4.4991999 MAarrowhead1
% End of user PostScript
1 .788 0 r
.43542 .52734 m
.43323 .51128 L
s
% Start of user PostScript
-1.9375305 0.82026912 -2.0029519 0.3384257 MAarrowhead1
% End of user PostScript
.897 1 0 r
.47356 .46251 m
.48153 .46359 L
s
% Start of user PostScript
-0.79334587 -1.1246565 -0.55410828 -1.0923788 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51459 .49136 m
.51553 .49538 L
s
% Start of user PostScript
0.43767896 -0.25913653 0.46590712 -0.1386835 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50726 .50881 m
.50534 .50875 L
s
% Start of user PostScript
0.21776496 0.2642354 0.16019687 0.26236571 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49677 .50258 m
.49644 .50158 L
s
% Start of user PostScript
-0.09692049 0.07726156 -0.10679201 0.04746368 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49805 .49796 m
.4985 .49792 L
s
% Start of user PostScript
-0.058600308 -0.061253438 -0.044903277 -0.062298907 MAarrowhead1
% End of user PostScript
0 1 .679 r
.5007 .49926 m
.5008 .4995 L
s
% Start of user PostScript
0.02093757 -0.022149332 0.024064355 -0.014854123 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50052 .50047 m
.50041 .50049 L
s
% Start of user PostScript
0.015509225 0.013985081 0.012289663 0.014611723 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49985 .50021 m
.49982 .50015 L
s
% Start of user PostScript
-0.004379022 0.0061690192 -0.005312853 0.0044017246 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49987 .4999 m
.49989 .49989 L
s
% Start of user PostScript
-0.0040459234 -0.0031367836 -0.0032992022 -0.003380663 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50003 .49994 m
.50004 .49996 L
s
% Start of user PostScript
0.00087529876 -0.0016798517 0.0011433316 -0.0012563723 MAarrowhead1
% End of user PostScript
.168 0 1 r
.71904 .8153 m
.65212 .80563 L
.58986 .7853 L
.534 .75682 L
.48574 .72264 L
.44581 .68505 L
.41445 .64609 L
.39155 .60755 L
.37666 .57089 L
.3691 .53728 L
.36798 .50758 L
.37232 .48234 L
.38107 .46186 L
.39318 .44619 L
.40761 .43519 L
.42342 .42855 L
.43975 .42583 L
.45587 .42652 L
.47117 .43003 L
.48516 .43578 L
.4975 .44317 L
.50796 .45165 L
.51642 .4607 L
.52287 .46987 L
.52737 .47877 L
.53005 .48709 L
.5311 .49459 L
.53073 .50111 L
.5292 .50653 L
.52675 .51082 L
.52361 .51399 L
.52004 .5161 L
.51624 .51722 L
.5124 .51747 L
.50868 .51698 L
.50521 .51589 L
.50209 .51434 L
.49939 .51247 L
.49714 .5104 L
.49537 .50824 L
.49407 .50611 L
.49322 .50407 L
.49277 .50219 L
.49268 .50053 L
.4929 .49911 L
.49337 .49796 L
.49403 .49707 L
.49482 .49645 L
.4957 .49606 L
.4966 .4959 L
Mistroke
.49749 .49592 L
.49834 .49611 L
.49913 .49642 L
.49982 .49682 L
.5004 .49729 L
.50088 .49779 L
.50124 .4983 L
.5015 .49879 L
.50166 .49925 L
.50172 .49967 L
.50171 .50004 L
.50162 .50034 L
.50149 .50058 L
.50132 .50076 L
.50112 .50088 L
.50091 .50095 L
.5007 .50097 L
.5005 .50094 L
.5003 .50089 L
.50013 .5008 L
.49998 .5007 L
.49985 .50058 L
.49975 .50047 L
.49968 .50035 L
.49963 .50023 L
.4996 .50013 L
.49959 .50004 L
.49961 .49996 L
.49963 .49989 L
.49967 .49984 L
.49971 .49981 L
.49976 .49978 L
.49981 .49977 L
.49986 .49977 L
.49991 .49978 L
.49995 .4998 L
.49999 .49982 L
.50002 .49985 L
.50005 .49988 L
.50007 .4999 L
.50008 .49993 L
.50009 .49996 L
.5001 .49998 L
.50009 .5 L
.50009 .50002 L
.50008 .50003 L
.50007 .50004 L
.50006 .50005 L
.50005 .50005 L
.50004 .50005 L
Mistroke
.50003 .50005 L
.50002 .50005 L
.50001 .50004 L
.5 .50004 L
.49999 .50003 L
.49999 .50003 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.71904 .8153 m
.65212 .80563 L
s
% Start of user PostScript
6.5712546 9.4588697 4.5635426 9.1689771 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58986 .7853 m
.534 .75682 L
s
% Start of user PostScript
2.6956599 8.5589601 1.019854 7.7046067 MAarrowhead1
% End of user PostScript
1 .473 0 r
.36798 .50758 m
.37232 .48234 L
s
% Start of user PostScript
-3.9605893 0.22731896 -3.8303162 -0.52980777 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47117 .43003 m
.48516 .43578 L
s
% Start of user PostScript
-0.86498198 -2.0991207 -0.44514696 -1.9267188 MAarrowhead1
% End of user PostScript
.897 1 0 r
.5311 .49459 m
.53073 .50111 L
s
% Start of user PostScript
0.93293732 -0.16218402 0.92203849 0.033237472 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50868 .51698 m
.50521 .51589 L
s
% Start of user PostScript
0.2604696 0.50943706 0.15638854 0.47680343 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49277 .50219 m
.49268 .50053 L
s
% Start of user PostScript
-0.21689062 0.06575033 -0.21946516 0.015910084 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49749 .49592 m
.49834 .49611 L
s
% Start of user PostScript
-0.075196622 -0.12230141 -0.049660711 -0.11677389 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50166 .49925 m
.50172 .49967 L
s
% Start of user PostScript
0.04968276 -0.022397176 0.051608684 -0.0098272613 MAarrowhead1
% End of user PostScript
0 1 .679 r
.5007 .50097 m
.5005 .50094 L
s
% Start of user PostScript
0.021055132 0.029026795 0.014855425 0.028299238 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49963 .50023 m
.4996 .50013 L
s
% Start of user PostScript
-0.011187107 0.0069906194 -0.011975481 0.0038541326 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49981 .49977 m
.49986 .49977 L
s
% Start of user PostScript
-0.0057577321 -0.006804486 -0.004268762 -0.0067836481 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50008 .49993 m
.50009 .49996 L
s
% Start of user PostScript
0.0024676059 -0.0020678884 0.0027372961 -0.0012933867 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50005 .50005 m
.50004 .50005 L
s
% Start of user PostScript
0.0015445971 0.0015734168 0.0011910566 0.0016074357 MAarrowhead1
% End of user PostScript
1 0 .735 r
.35161 .42984 m
.37082 .41384 L
.39211 .40385 L
.4143 .39932 L
.43636 .39953 L
.45741 .40373 L
.47679 .41111 L
.49399 .42085 L
.50867 .4322 L
.52064 .44444 L
.52987 .45693 L
.53642 .46914 L
.54046 .48062 L
.54224 .49104 L
.54204 .50014 L
.54019 .50778 L
.53703 .51387 L
.5329 .51844 L
.52811 .52153 L
.52297 .52327 L
.51774 .5238 L
.51264 .52329 L
.50785 .52193 L
.50351 .51991 L
.49973 .51742 L
.49657 .51463 L
.49406 .51171 L
.49218 .50879 L
.49092 .50598 L
.49022 .50339 L
.49003 .50107 L
.49027 .49909 L
.49085 .49746 L
.49171 .49619 L
.49277 .49528 L
.49394 .49471 L
.49517 .49443 L
.49639 .49443 L
.49756 .49465 L
.49864 .49504 L
.4996 .49558 L
.50043 .4962 L
.5011 .49687 L
.50162 .49757 L
.50199 .49824 L
.50223 .49888 L
.50234 .49946 L
.50233 .49997 L
.50224 .5004 L
.50206 .50075 L
Mistroke
.50184 .50101 L
.50158 .50118 L
.50129 .50128 L
.501 .50132 L
.50072 .50129 L
.50045 .50122 L
.50021 .50111 L
.5 .50098 L
.49982 .50082 L
.49968 .50066 L
.49957 .5005 L
.4995 .50034 L
.49946 .5002 L
.49945 .50007 L
.49946 .49996 L
.49949 .49987 L
.49954 .49979 L
.4996 .49974 L
.49966 .49971 L
.49973 .49969 L
.4998 .49969 L
.49986 .4997 L
.49992 .49972 L
.49997 .49975 L
.50002 .49979 L
.50006 .49982 L
.50009 .49986 L
.50011 .4999 L
.50012 .49994 L
.50013 .49997 L
.50013 .5 L
.50012 .50002 L
.50012 .50004 L
.5001 .50005 L
.50009 .50006 L
.50007 .50007 L
.50006 .50007 L
.50004 .50007 L
.50003 .50007 L
.50001 .50006 L
.5 .50005 L
.49999 .50005 L
.49998 .50004 L
.49998 .50003 L
.49997 .50002 L
.49997 .50001 L
.49997 .5 L
.49997 .5 L
.49997 .49999 L
.49997 .49999 L
Mistroke
.49998 .49999 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.35161 .42984 m
.37082 .41384 L
s
% Start of user PostScript
-4.4517467 -2.1047901 -3.8754053 -2.5848027 MAarrowhead1
% End of user PostScript
1 .158 0 r
.39211 .40385 m
.4143 .39932 L
s
% Start of user PostScript
-3.2366151 -2.8843871 -2.570947 -3.0205295 MAarrowhead1
% End of user PostScript
1 .473 0 r
.52987 .45693 m
.53642 .46914 L
s
% Start of user PostScript
0.89602481 -1.2921197 1.0925364 -0.9258113 MAarrowhead1
% End of user PostScript
1 .788 0 r
.52811 .52153 m
.52297 .52327 L
s
% Start of user PostScript
0.8434409 0.64595379 0.68922443 0.69804602 MAarrowhead1
% End of user PostScript
.897 1 0 r
.49406 .51171 m
.49218 .50879 L
s
% Start of user PostScript
-0.17831411 0.35129108 -0.23457018 0.26359424 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49277 .49528 m
.49394 .49471 L
s
% Start of user PostScript
-0.21700521 -0.14152958 -0.18182011 -0.15880917 MAarrowhead1
% End of user PostScript
.266 1 0 r
.5011 .49687 m
.50162 .49757 L
s
% Start of user PostScript
0.033000315 -0.093782801 0.048651788 -0.073030651 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50184 .50101 m
.50158 .50118 L
s
% Start of user PostScript
0.055181265 0.030159272 0.047296036 0.035469557 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49982 .50082 m
.49968 .50066 L
s
% Start of user PostScript
-0.0053479097 0.024651354 -0.0096061787 0.019802415 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49954 .49979 m
.4996 .49974 L
s
% Start of user PostScript
-0.013877913 -0.0061908558 -0.01214873 -0.0077455098 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50002 .49979 m
.50006 .49982 L
s
% Start of user PostScript
0.00061713539 -0.0063919478 0.0017546361 -0.0052748149 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50012 .50004 m
.5001 .50005 L
s
% Start of user PostScript
0.0034534526 0.0012034806 0.0030845513 0.0016433338 MAarrowhead1
% End of user PostScript
0 .375 1 r
.5 .50005 m
.49999 .50005 L
s
% Start of user PostScript
0.000022416781 0.0016370808 -0.00027673843 0.0013838374 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49997 .49999 m
.49997 .49999 L
s
% Start of user PostScript
-0.00085047757 -0.00021400674 -0.0007746324 -0.00033527674 MAarrowhead1
% End of user PostScript
.484 1 0 r
.77897 .29431 m
.80435 .37745 L
.81348 .45215 L
.8086 .51677 L
.79217 .57034 L
.7667 .6125 L
.73464 .6434 L
.69835 .66359 L
.65996 .67401 L
.62133 .67579 L
.58405 .67026 L
.5494 .65881 L
.51833 .64284 L
.49152 .62373 L
.46935 .60273 L
.45197 .581 L
.43929 .55952 L
.43108 .53911 L
.42695 .52041 L
.4264 .50389 L
.42888 .48988 L
.4338 .47851 L
.44059 .46983 L
.44866 .46375 L
.45749 .4601 L
.4666 .45863 L
.47558 .45905 L
.4841 .46104 L
.49188 .46426 L
.49875 .4684 L
.50455 .47314 L
.50925 .47819 L
.51282 .4833 L
.51531 .48826 L
.51678 .4929 L
.51735 .49707 L
.51713 .50069 L
.51626 .5037 L
.51488 .50608 L
.51313 .50784 L
.51113 .509 L
.50901 .50961 L
.50687 .50974 L
.5048 .50946 L
.50287 .50885 L
.50113 .50798 L
.49963 .50693 L
.49838 .50577 L
.4974 .50457 L
.49668 .50338 L
Mistroke
.49621 .50224 L
.49597 .5012 L
.49592 .50028 L
.49605 .49949 L
.49631 .49885 L
.49668 .49836 L
.49712 .49801 L
.49761 .4978 L
.49811 .49771 L
.49861 .49773 L
.49909 .49783 L
.49952 .49801 L
.4999 .49823 L
.50023 .49849 L
.5005 .49877 L
.5007 .49906 L
.50084 .49933 L
.50092 .49959 L
.50096 .49982 L
.50095 .50002 L
.5009 .50019 L
.50083 .50033 L
.50073 .50043 L
.50062 .50049 L
.50051 .50053 L
.50039 .50054 L
.50027 .50053 L
.50017 .50049 L
.50007 .50045 L
.49999 .50039 L
.49991 .50032 L
.49986 .50026 L
.49982 .50019 L
.49979 .50013 L
.49978 .50007 L
.49977 .50002 L
.49978 .49997 L
.49979 .49994 L
.49981 .49991 L
.49984 .49989 L
.49987 .49988 L
.49989 .49987 L
.49992 .49987 L
.49995 .49988 L
.49997 .49989 L
.49999 .4999 L
.50001 .49992 L
.50003 .49993 L
.50004 .49995 L
.50005 .49996 L
Mistroke
.50005 .49998 L
.50005 .49999 L
.50005 .5 L
.50005 .50001 L
.50005 .50002 L
.50004 .50002 L
.50004 .50003 L
.50003 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.77897 .29431 m
.80435 .37745 L
s
% Start of user PostScript
8.369199 -6.1708202 9.1303978 -3.676458 MAarrowhead1
% End of user PostScript
1 .158 0 r
.81348 .45215 m
.8086 .51677 L
s
% Start of user PostScript
9.4042695 -1.4355276 9.2580991 0.50304343 MAarrowhead1
% End of user PostScript
1 .473 0 r
.58405 .67026 m
.5494 .65881 L
s
% Start of user PostScript
2.5215372 5.1077855 1.4818877 4.7641938 MAarrowhead1
% End of user PostScript
1 .788 0 r
.42695 .52041 m
.4264 .50389 L
s
% Start of user PostScript
-2.1915798 0.61223742 -2.2080975 0.11682028 MAarrowhead1
% End of user PostScript
.897 1 0 r
.47558 .45905 m
.4841 .46104 L
s
% Start of user PostScript
-0.73260583 -1.2286108 -0.47706654 -1.1689295 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51678 .4929 m
.51735 .49707 L
s
% Start of user PostScript
0.50339767 -0.21309229 0.52039049 -0.087906549 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50687 .50974 m
.5048 .50946 L
s
% Start of user PostScript
0.20610928 0.29219811 0.14395319 0.28381006 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49621 .50224 m
.49597 .5012 L
s
% Start of user PostScript
-0.11371581 0.067320935 -0.1210487 0.036026426 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49811 .49771 m
.49861 .49773 L
s
% Start of user PostScript
-0.056575193 -0.068651539 -0.041618428 -0.068165267 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50084 .49933 m
.50092 .49959 L
s
% Start of user PostScript
0.025181632 -0.020072039 0.027746086 -0.012330323 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50051 .50053 m
.50039 .50054 L
s
% Start of user PostScript
0.01522441 0.015914454 0.011665771 0.016185948 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49982 .50019 m
.49979 .50013 L
s
% Start of user PostScript
-0.0054399946 0.0057543108 -0.0062522997 0.0038589534 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49987 .49988 m
.49989 .49987 L
s
% Start of user PostScript
-0.0040293298 -0.0036335282 -0.0031928491 -0.0037963038 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50004 .49995 m
.50005 .49996 L
s
% Start of user PostScript
0.0011377703 -0.0016027004 0.0013803733 -0.0011435407 MAarrowhead1
% End of user PostScript
1 0 .31 r
.37337 .30719 m
.41398 .31443 L
.45151 .32793 L
.48495 .34614 L
.51363 .36759 L
.53716 .39088 L
.55542 .4148 L
.56854 .43829 L
.57681 .46047 L
.58068 .48067 L
.5807 .49841 L
.57749 .51336 L
.5717 .52537 L
.56397 .53444 L
.55492 .54068 L
.54513 .54429 L
.53511 .54555 L
.52529 .54478 L
.51604 .54235 L
.50763 .53862 L
.50026 .53394 L
.49407 .52865 L
.48911 .52307 L
.48538 .51746 L
.48284 .51205 L
.48138 .50703 L
.48091 .50253 L
.48128 .49866 L
.48233 .49546 L
.48393 .49296 L
.48591 .49113 L
.48813 .48996 L
.49047 .48938 L
.49282 .48931 L
.49508 .48968 L
.49717 .49041 L
.49904 .4914 L
.50065 .49258 L
.50197 .49386 L
.503 .49519 L
.50375 .49649 L
.50423 .49773 L
.50446 .49885 L
.50447 .49985 L
.50431 .50069 L
.504 .50136 L
.50358 .50188 L
.50308 .50223 L
.50254 .50244 L
.50198 .50252 L
Mistroke
.50144 .50249 L
.50092 .50236 L
.50045 .50215 L
.50004 .5019 L
.49969 .50161 L
.49941 .5013 L
.4992 .50099 L
.49906 .50069 L
.49897 .50041 L
.49894 .50016 L
.49896 .49994 L
.49902 .49976 L
.4991 .49962 L
.49921 .49952 L
.49933 .49945 L
.49946 .49941 L
.49959 .49941 L
.49972 .49943 L
.49984 .49947 L
.49994 .49952 L
.50003 .49958 L
.5001 .49966 L
.50016 .49973 L
.50021 .4998 L
.50023 .49987 L
.50025 .49993 L
.50025 .49999 L
.50024 .50003 L
.50022 .50007 L
.5002 .5001 L
.50017 .50012 L
.50014 .50013 L
.50011 .50014 L
.50008 .50014 L
.50005 .50013 L
.50003 .50012 L
.5 .50011 L
.49998 .50009 L
.49997 .50007 L
.49996 .50006 L
.49995 .50004 L
.49994 .50002 L
.49994 .50001 L
.49994 .5 L
.49995 .49999 L
.49995 .49998 L
.49996 .49997 L
.49996 .49997 L
.49997 .49997 L
.49998 .49997 L
Mistroke
.49998 .49997 L
.49999 .49997 L
.5 .49997 L
.5 .49998 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.37337 .30719 m
.41398 .31443 L
s
% Start of user PostScript
-3.7988861 -5.7844213 -2.5806232 -5.5671324 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45151 .32793 m
.48495 .34614 L
s
% Start of user PostScript
-1.4547456 -5.1620998 -0.45144481 -4.6156615 MAarrowhead1
% End of user PostScript
1 .473 0 r
.5807 .49841 m
.57749 .51336 L
s
% Start of user PostScript
2.4209542 -0.047788926 2.3247188 0.40068376 MAarrowhead1
% End of user PostScript
1 .788 0 r
.51604 .54235 m
.50763 .53862 L
s
% Start of user PostScript
0.48113503 1.270542 0.22885861 1.158466 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48091 .50253 m
.48128 .49866 L
s
% Start of user PostScript
-0.57267463 0.076020976 -0.5616979 -0.040237394 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49508 .48968 m
.49717 .49041 L
s
% Start of user PostScript
-0.14759986 -0.30946832 -0.084834298 -0.28770853 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50446 .49885 m
.50447 .49985 L
s
% Start of user PostScript
0.13375743 -0.034392716 0.13422392 -0.0046236185 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50144 .50249 m
.50092 .50236 L
s
% Start of user PostScript
0.043160219 0.074575112 0.027706006 0.070714287 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49897 .50041 m
.49894 .50016 L
s
% Start of user PostScript
-0.030802072 0.012251526 -0.031698445 0.0047153604 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49959 .49941 m
.49972 .49943 L
s
% Start of user PostScript
-0.012200478 -0.017770581 -0.0084348347 -0.017199528 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50023 .49987 m
.50025 .49993 L
s
% Start of user PostScript
0.0069788628 -0.0039196385 0.0073902898 -0.0020323715 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50011 .50014 m
.50008 .50014 L
s
% Start of user PostScript
0.0033614398 0.0041840012 0.0024536447 0.0041385983 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49995 .50004 m
.49994 .50002 L
s
% Start of user PostScript
-0.0015510179 0.0011781067 -0.0016983711 0.00071041689 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49997 .49997 m
.49998 .49997 L
s
% Start of user PostScript
-0.00090733758 -0.00097219899 -0.00069092799 -0.00098464834 MAarrowhead1
% End of user PostScript
.424 0 1 r
.50839 .20757 m
.5613 .25506 L
.60325 .30473 L
.63434 .35423 L
.65507 .40161 L
.66627 .44532 L
.66902 .4842 L
.66457 .51747 L
.65426 .5447 L
.63943 .56577 L
.62141 .58083 L
.60142 .59024 L
.58059 .59453 L
.55988 .59435 L
.5401 .59042 L
.52189 .58351 L
.50573 .57437 L
.49193 .56373 L
.48068 .55224 L
.472 .54051 L
.46583 .52904 L
.46203 .51825 L
.46035 .50847 L
.46052 .49991 L
.46225 .49274 L
.46521 .487 L
.46908 .48271 L
.47357 .4798 L
.4784 .47816 L
.48331 .47766 L
.48811 .47813 L
.49261 .4794 L
.49668 .48129 L
.50023 .48363 L
.5032 .48624 L
.50557 .48899 L
.50733 .49173 L
.50852 .49437 L
.50918 .49681 L
.50936 .49898 L
.50914 .50085 L
.50859 .50238 L
.50779 .50357 L
.5068 .50443 L
.5057 .50497 L
.50455 .50522 L
.5034 .50523 L
.5023 .50503 L
.50128 .50466 L
.50038 .50416 L
Mistroke
.4996 .50357 L
.49897 .50294 L
.49848 .50229 L
.49813 .50165 L
.49791 .50105 L
.49781 .50051 L
.49781 .50003 L
.4979 .49962 L
.49806 .4993 L
.49827 .49906 L
.49852 .49889 L
.49878 .4988 L
.49906 .49876 L
.49932 .49879 L
.49957 .49885 L
.4998 .49896 L
.5 .49908 L
.50017 .49923 L
.5003 .49938 L
.5004 .49953 L
.50047 .49968 L
.50051 .49981 L
.50052 .49994 L
.50051 .50004 L
.50048 .50013 L
.50043 .50019 L
.50038 .50024 L
.50032 .50027 L
.50026 .50029 L
.50019 .50029 L
.50013 .50028 L
.50007 .50026 L
.50002 .50023 L
.49998 .5002 L
.49995 .50017 L
.49992 .50013 L
.4999 .50009 L
.49988 .50006 L
.49988 .50003 L
.49988 .5 L
.49988 .49998 L
.49989 .49996 L
.4999 .49995 L
.49992 .49994 L
.49993 .49993 L
.49995 .49993 L
.49996 .49993 L
.49998 .49994 L
.49999 .49994 L
.5 .49995 L
Mistroke
.50001 .49996 L
.50002 .49997 L
.50002 .49997 L
.50003 .49998 L
.50003 .49999 L
.50003 .5 L
.50003 .5 L
.50003 .50001 L
.50002 .50001 L
.50002 .50001 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.50839 .20757 m
.5613 .25506 L
s
% Start of user PostScript
0.25184254 -8.773015 1.8388731 -7.3481469 MAarrowhead1
% End of user PostScript
1 .158 0 r
.60325 .30473 m
.63434 .35423 L
s
% Start of user PostScript
3.0975811 -5.8581812 4.030341 -4.3731521 MAarrowhead1
% End of user PostScript
1 .473 0 r
.62141 .58083 m
.60142 .59024 L
s
% Start of user PostScript
3.6421741 2.4249013 3.0426186 2.7071385 MAarrowhead1
% End of user PostScript
1 .788 0 r
.48068 .55224 m
.472 .54051 L
s
% Start of user PostScript
-0.57971218 1.5672085 -0.84004041 1.2152742 MAarrowhead1
% End of user PostScript
.897 1 0 r
.46908 .48271 m
.47357 .4798 L
s
% Start of user PostScript
-0.9274583 -0.51873799 -0.79277149 -0.60613 MAarrowhead1
% End of user PostScript
.581 1 0 r
.5032 .48624 m
.50557 .48899 L
s
% Start of user PostScript
0.096064601 -0.41269533 0.16707028 -0.3303278 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50779 .50357 m
.5068 .50443 L
s
% Start of user PostScript
0.23356526 0.10705406 0.20394182 0.13276902 MAarrowhead1
% End of user PostScript
0 1 .049 r
.4996 .50357 m
.49897 .50294 L
s
% Start of user PostScript
-0.01188059 0.10718188 -0.030888084 0.0881704 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49806 .4993 m
.49827 .49906 L
s
% Start of user PostScript
-0.058197145 -0.020980279 -0.051853081 -0.028282698 MAarrowhead1
% End of user PostScript
0 1 .679 r
.5 .49908 m
.50017 .49923 L
s
% Start of user PostScript
-0.000012627991 -0.027491452 0.004995307 -0.023172476 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50048 .50013 m
.50043 .50019 L
s
% Start of user PostScript
0.014350601 0.0037837537 0.013039366 0.0058028677 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50002 .50023 m
.49998 .5002 L
s
% Start of user PostScript
0.00072865519 0.0069706086 -0.00057258008 0.0060076451 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49988 .49998 m
.49989 .49996 L
s
% Start of user PostScript
-0.0035019751 -0.00058064044 -0.0032444168 -0.0011272336 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49999 .49994 m
.5 .49995 L
s
% Start of user PostScript
-0.00035673786 -0.0017482871 -0.000022835504 -0.001538458 MAarrowhead1
% End of user PostScript
0 1 .938 r
.45128 .22242 m
.50395 .25718 L
.54801 .29607 L
.58307 .33687 L
.60919 .37764 L
.62674 .41676 L
.63641 .45293 L
.63907 .48518 L
.63574 .51284 L
.62752 .53554 L
.61552 .55318 L
.60082 .56586 L
.58446 .57388 L
.56734 .57765 L
.55028 .57771 L
.53394 .57465 L
.51888 .5691 L
.50547 .56168 L
.494 .55298 L
.48461 .54356 L
.47734 .53391 L
.47215 .52445 L
.4689 .51554 L
.46742 .50743 L
.46748 .50033 L
.46883 .49435 L
.47121 .48956 L
.47436 .48596 L
.47803 .4835 L
.48199 .48209 L
.48603 .48162 L
.48998 .48197 L
.4937 .48298 L
.49707 .48451 L
.50002 .48641 L
.5025 .48855 L
.50448 .4908 L
.50596 .49306 L
.50696 .49524 L
.50753 .49726 L
.5077 .49906 L
.50754 .50061 L
.5071 .50189 L
.50645 .50288 L
.50564 .5036 L
.50474 .50407 L
.5038 .50429 L
.50285 .50431 L
.50194 .50415 L
.5011 .50385 L
Mistroke
.50035 .50345 L
.49971 .50297 L
.49918 .50245 L
.49877 .50192 L
.49848 .50139 L
.49829 .50089 L
.4982 .50044 L
.4982 .50004 L
.49827 .49971 L
.49839 .49944 L
.49857 .49923 L
.49877 .49909 L
.49899 .49901 L
.49921 .49898 L
.49943 .499 L
.49964 .49905 L
.49983 .49914 L
.49999 .49924 L
.50013 .49936 L
.50024 .49948 L
.50032 .49961 L
.50038 .49973 L
.50042 .49984 L
.50043 .49994 L
.50042 .50003 L
.5004 .5001 L
.50036 .50016 L
.50032 .5002 L
.50027 .50022 L
.50021 .50024 L
.50016 .50024 L
.50011 .50023 L
.50006 .50021 L
.50002 .50019 L
.49999 .50017 L
.49996 .50014 L
.49993 .50011 L
.49992 .50008 L
.49991 .50005 L
.4999 .50003 L
.4999 .5 L
.4999 .49999 L
.49991 .49997 L
.49992 .49996 L
.49993 .49995 L
.49994 .49995 L
.49996 .49994 L
.49997 .49994 L
.49998 .49995 L
.49999 .49995 L
Mistroke
.5 .49996 L
.50001 .49996 L
.50001 .49997 L
.50002 .49998 L
.50002 .49998 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.45128 .22242 m
.50395 .25718 L
s
% Start of user PostScript
-1.4614788 -8.3273184 0.1186376 -7.2845779 MAarrowhead1
% End of user PostScript
1 .158 0 r
.54801 .29607 m
.58307 .33687 L
s
% Start of user PostScript
1.4403331 -6.117934 2.4922412 -4.8939322 MAarrowhead1
% End of user PostScript
1 .473 0 r
.61552 .55318 m
.60082 .56586 L
s
% Start of user PostScript
3.4655097 1.5954837 3.024685 1.9759156 MAarrowhead1
% End of user PostScript
1 .788 0 r
.494 .55298 m
.48461 .54356 L
s
% Start of user PostScript
-0.17997169 1.5893288 -0.46165635 1.3067276 MAarrowhead1
% End of user PostScript
.897 1 0 r
.47121 .48956 m
.47436 .48596 L
s
% Start of user PostScript
-0.86368322 -0.31308776 -0.76921868 -0.42118892 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50002 .48641 m
.5025 .48855 L
s
% Start of user PostScript
0.00071416631 -0.40775282 0.07495271 -0.34352964 MAarrowhead1
% End of user PostScript
.266 1 0 r
.5071 .50189 m
.50645 .50288 L
s
% Start of user PostScript
0.21301777 0.056591224 0.19347647 0.086495655 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50035 .50345 m
.49971 .50297 L
s
% Start of user PostScript
0.010593693 0.10341176 -0.0087012803 0.089086434 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49827 .49971 m
.49839 .49944 L
s
% Start of user PostScript
-0.051993936 -0.0087269071 -0.048150631 -0.016825512 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49983 .49914 m
.49999 .49924 L
s
% Start of user PostScript
-0.0052410946 -0.025942243 -0.00028870203 -0.022819113 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50042 .50003 m
.5004 .5001 L
s
% Start of user PostScript
0.012556566 0.00084043455 0.011859203 0.002995426 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50006 .50021 m
.50002 .50019 L
s
% Start of user PostScript
0.0019272759 0.0064397693 0.00067077352 0.0057785673 MAarrowhead1
% End of user PostScript
0 .375 1 r
.4999 .5 m
.4999 .49999 L
s
% Start of user PostScript
-0.0029989714 0.00011833481 -0.0028905304 -0.00044650874 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49998 .49995 m
.49999 .49995 L
s
% Start of user PostScript
-0.00062688312 -0.0015820448 -0.00031155085 -0.0014475519 MAarrowhead1
% End of user PostScript
1 .657 0 r
.30134 .79737 m
.25579 .71444 L
.22731 .63625 L
.21432 .56517 L
.21483 .50289 L
.22666 .45049 L
.24753 .40849 L
.27514 .37689 L
.30731 .35528 L
.34203 .34293 L
.37748 .33885 L
.41215 .34186 L
.44476 .35072 L
.47434 .36412 L
.5002 .38081 L
.52191 .39958 L
.53925 .41935 L
.55224 .43918 L
.56105 .45825 L
.56601 .47594 L
.56753 .49174 L
.56611 .50534 L
.56227 .51654 L
.55656 .52528 L
.5495 .53161 L
.5416 .53566 L
.5333 .53763 L
.525 .53778 L
.51704 .5364 L
.50967 .53378 L
.5031 .53023 L
.49746 .52604 L
.49282 .52149 L
.48922 .5168 L
.48663 .5122 L
.48499 .50784 L
.48421 .50388 L
.48419 .50039 L
.4848 .49745 L
.48592 .49508 L
.48743 .49329 L
.4892 .49206 L
.49111 .49134 L
.49308 .49108 L
.495 .49122 L
.49682 .49169 L
.49847 .49242 L
.49992 .49333 L
.50113 .49436 L
.50211 .49546 L
Mistroke
.50285 .49655 L
.50335 .49761 L
.50364 .4986 L
.50374 .49948 L
.50367 .50025 L
.50347 .50088 L
.50316 .50137 L
.50277 .50173 L
.50234 .50196 L
.50188 .50208 L
.50142 .50209 L
.50097 .50202 L
.50056 .50188 L
.5002 .50169 L
.49988 .50146 L
.49962 .50121 L
.49942 .50095 L
.49927 .50069 L
.49917 .50045 L
.49913 .50023 L
.49912 .50003 L
.49916 .49987 L
.49922 .49974 L
.4993 .49963 L
.49939 .49956 L
.4995 .49952 L
.49961 .49951 L
.49972 .49951 L
.49982 .49954 L
.49991 .49958 L
.49999 .49963 L
.50006 .49968 L
.50011 .49974 L
.50016 .4998 L
.50018 .49986 L
.5002 .49992 L
.50021 .49997 L
.5002 .50001 L
.50019 .50005 L
.50018 .50007 L
.50016 .50009 L
.50013 .50011 L
.50011 .50011 L
.50008 .50012 L
.50006 .50011 L
.50003 .5001 L
.50001 .50009 L
.49999 .50008 L
.49998 .50007 L
.49997 .50005 L
Mistroke
.49996 .50004 L
.49995 .50003 L
.49995 .50001 L
.49995 .5 L
.49995 .49999 L
.49996 .49999 L
.49996 .49998 L
.49997 .49998 L
.49997 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.30134 .79737 m
.25579 .71444 L
s
% Start of user PostScript
-5.9598766 8.9210088 -7.3264399 6.4331972 MAarrowhead1
% End of user PostScript
1 .158 0 r
.22731 .63625 m
.21432 .56517 L
s
% Start of user PostScript
-8.1806289 4.0875247 -8.5705429 1.9549745 MAarrowhead1
% End of user PostScript
1 .473 0 r
.37748 .33885 m
.41215 .34186 L
s
% Start of user PostScript
-3.6755423 -4.8345769 -2.6356339 -4.7441242 MAarrowhead1
% End of user PostScript
1 .788 0 r
.56105 .45825 m
.56601 .47594 L
s
% Start of user PostScript
1.8314893 -1.2523989 1.9802168 -0.72194536 MAarrowhead1
% End of user PostScript
.897 1 0 r
.5333 .53763 m
.525 .53778 L
s
% Start of user PostScript
0.99897446 1.1288729 0.7500556 1.1333863 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48663 .5122 m
.48499 .50784 L
s
% Start of user PostScript
-0.4011333 0.36591159 -0.45039397 0.23533156 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49111 .49134 m
.49308 .49108 L
s
% Start of user PostScript
-0.26662466 -0.25987678 -0.20773256 -0.26759168 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50285 .49655 m
.50335 .49761 L
s
% Start of user PostScript
0.08543818 -0.1033716 0.10056319 -0.071561012 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50234 .50196 m
.50188 .50208 L
s
% Start of user PostScript
0.070068437 0.058858539 0.056310517 0.062369297 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49942 .50095 m
.49927 .50069 L
s
% Start of user PostScript
-0.017526259 0.028466908 -0.021951617 0.02080001 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49939 .49956 m
.4995 .49952 L
s
% Start of user PostScript
-0.018164761 -0.0130751 -0.014995838 -0.014328467 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50011 .49974 m
.50016 .4998 L
s
% Start of user PostScript
0.0034035438 -0.0076809071 0.0046550389 -0.0058536416 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50016 .50009 m
.50013 .50011 L
s
% Start of user PostScript
0.004651452 0.0028359469 0.0039332787 0.0032374067 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49998 .50007 m
.49997 .50005 L
s
% Start of user PostScript
-0.00060413434 0.0020374689 -0.00094905879 0.0016071678 MAarrowhead1
% End of user PostScript
0 1 .636 r
.75524 .48637 m
.74666 .535 L
.72959 .57443 L
.70608 .60455 L
.67811 .62565 L
.6475 .63834 L
.61591 .64346 L
.58475 .64202 L
.55521 .63514 L
.5282 .62395 L
.5044 .60961 L
.48425 .59318 L
.46796 .57566 L
.45557 .55793 L
.44694 .54074 L
.44182 .52467 L
.43985 .51019 L
.4406 .49764 L
.44361 .48719 L
.44838 .47893 L
.45446 .47284 L
.46138 .46881 L
.46873 .46668 L
.47616 .46622 L
.48334 .46719 L
.49004 .46931 L
.49606 .47232 L
.50127 .47596 L
.5056 .47997 L
.509 .48414 L
.5115 .48827 L
.51314 .49221 L
.51399 .49583 L
.51414 .49903 L
.51371 .50176 L
.51279 .50398 L
.51151 .50568 L
.50998 .50689 L
.50829 .50762 L
.50654 .50794 L
.50481 .50788 L
.50317 .50752 L
.50166 .50691 L
.50033 .50613 L
.4992 .50523 L
.49828 .50426 L
.49758 .50328 L
.49709 .50232 L
.49679 .50143 L
.49667 .50062 L
Mistroke
.4967 .49992 L
.49686 .49933 L
.49712 .49886 L
.49745 .49852 L
.49783 .49829 L
.49824 .49816 L
.49865 .49813 L
.49905 .49818 L
.49942 .49829 L
.49976 .49845 L
.50005 .49865 L
.50029 .49887 L
.50049 .49911 L
.50063 .49933 L
.50072 .49955 L
.50077 .49976 L
.50078 .49993 L
.50076 .50009 L
.50071 .50021 L
.50064 .50031 L
.50056 .50038 L
.50047 .50042 L
.50037 .50044 L
.50027 .50044 L
.50018 .50042 L
.5001 .50039 L
.50002 .50034 L
.49996 .50029 L
.49991 .50024 L
.49987 .50019 L
.49984 .50013 L
.49982 .50008 L
.49982 .50004 L
.49982 .5 L
.49983 .49996 L
.49984 .49994 L
.49986 .49992 L
.49988 .49991 L
.4999 .4999 L
.49992 .4999 L
.49995 .4999 L
.49997 .4999 L
.49999 .49991 L
.5 .49992 L
.50002 .49994 L
.50003 .49995 L
.50003 .49996 L
.50004 .49997 L
.50004 .49999 L
.50004 .5 L
Mistroke
.50004 .5 L
.50004 .50001 L
.50004 .50002 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.75524 .48637 m
.74666 .535 L
s
% Start of user PostScript
7.6572499 -0.4088825 7.39981 1.050106 MAarrowhead1
% End of user PostScript
1 .158 0 r
.72959 .57443 m
.70608 .60455 L
s
% Start of user PostScript
6.8877841 2.2328707 6.1825199 3.136459 MAarrowhead1
% End of user PostScript
1 .473 0 r
.5044 .60961 m
.48425 .59318 L
s
% Start of user PostScript
0.13212128 3.2881812 -0.47252634 2.7953896 MAarrowhead1
% End of user PostScript
1 .788 0 r
.44361 .48719 m
.44838 .47893 L
s
% Start of user PostScript
-1.6918268 -0.38437446 -1.5484807 -0.63211127 MAarrowhead1
% End of user PostScript
.897 1 0 r
.49606 .47232 m
.50127 .47596 L
s
% Start of user PostScript
-0.1181165 -0.8302888 0.038235094 -0.72129303 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51371 .50176 m
.51279 .50398 L
s
% Start of user PostScript
0.4112276 0.052807633 0.38378375 0.11940941 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50166 .50691 m
.50033 .50613 L
s
% Start of user PostScript
0.049918115 0.20741656 0.0099747739 0.1839058 MAarrowhead1
% End of user PostScript
0 1 .049 r
.4967 .49992 m
.49686 .49933 L
s
% Start of user PostScript
-0.098883705 -0.0025355852 -0.094135601 -0.020148044 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49942 .49829 m
.49976 .49845 L
s
% Start of user PostScript
-0.017309042 -0.051276488 -0.0072190795 -0.046369262 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50078 .49993 m
.50076 .50009 L
s
% Start of user PostScript
0.023509307 -0.0019671815 0.022848569 0.0026240981 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50018 .50042 m
.5001 .50039 L
s
% Start of user PostScript
0.0054569464 0.012545169 0.0029353866 0.011567189 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49982 .50004 m
.49982 .5 L
s
% Start of user PostScript
-0.00552143 0.0011193627 -0.0054859798 -0.00006227787 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49995 .4999 m
.49997 .4999 L
s
% Start of user PostScript
-0.0016248202 -0.0030370076 -0.0010012189 -0.0028555824 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50004 .49999 m
.50004 .5 L
s
% Start of user PostScript
0.0012794198 -0.00042957721 0.0013022061 -0.00012901569 MAarrowhead1
% End of user PostScript
.488 0 1 r
.22034 .3529 m
.25926 .32508 L
.30155 .30873 L
.345 .30265 L
.38766 .30544 L
.42797 .31556 L
.46469 .33143 L
.49692 .35149 L
.5241 .37428 L
.54596 .39843 L
.56247 .42277 L
.57383 .44628 L
.58041 .46817 L
.58272 .48782 L
.58135 .5048 L
.57695 .51887 L
.57018 .52992 L
.56169 .538 L
.55209 .54326 L
.54196 .54595 L
.53177 .54637 L
.52195 .54487 L
.51282 .54181 L
.50465 .53758 L
.4976 .53252 L
.49179 .52697 L
.48723 .52123 L
.48392 .51557 L
.48178 .51019 L
.48071 .50527 L
.48059 .50093 L
.48126 .49725 L
.48257 .49427 L
.48437 .49199 L
.48651 .49041 L
.48884 .48946 L
.49124 .48908 L
.49361 .4892 L
.49586 .48974 L
.49791 .49059 L
.49971 .49169 L
.50124 .49294 L
.50247 .49428 L
.5034 .49563 L
.50405 .49693 L
.50443 .49815 L
.50458 .49925 L
.50452 .5002 L
.50428 .50099 L
.50392 .50162 L
Mistroke
.50345 .50208 L
.50292 .50238 L
.50236 .50254 L
.5018 .50257 L
.50125 .50249 L
.50074 .50233 L
.50029 .5021 L
.49989 .50182 L
.49957 .50152 L
.49931 .5012 L
.49912 .50088 L
.499 .50059 L
.49893 .50031 L
.49892 .50007 L
.49896 .49986 L
.49903 .49969 L
.49913 .49956 L
.49924 .49947 L
.49937 .49942 L
.49951 .4994 L
.49964 .4994 L
.49976 .49943 L
.49988 .49948 L
.49998 .49954 L
.50006 .4996 L
.50013 .49968 L
.50019 .49975 L
.50022 .49983 L
.50024 .49989 L
.50025 .49995 L
.50025 .50001 L
.50024 .50005 L
.50022 .50009 L
.50019 .50011 L
.50016 .50013 L
.50013 .50014 L
.5001 .50014 L
.50007 .50014 L
.50004 .50013 L
.50002 .50012 L
.5 .5001 L
.49998 .50009 L
.49996 .50007 L
.49995 .50005 L
.49994 .50003 L
.49994 .50002 L
.49994 .5 L
.49994 .49999 L
.49995 .49998 L
.49995 .49998 L
Mistroke
.49996 .49997 L
.49996 .49997 L
.49997 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49997 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.22034 .3529 m
.25926 .32508 L
s
% Start of user PostScript
-8.3896945 -4.4130356 -7.222225 -5.2474952 MAarrowhead1
% End of user PostScript
1 .158 0 r
.30155 .30873 m
.345 .30265 L
s
% Start of user PostScript
-5.9533699 -5.7381424 -4.6501471 -5.9205531 MAarrowhead1
% End of user PostScript
1 .473 0 r
.56247 .42277 m
.57383 .44628 L
s
% Start of user PostScript
1.8740154 -2.3170494 2.2148187 -1.6115017 MAarrowhead1
% End of user PostScript
1 .788 0 r
.55209 .54326 m
.54196 .54595 L
s
% Start of user PostScript
1.5628299 1.2978626 1.2586895 1.3785157 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48723 .52123 m
.48392 .51557 L
s
% Start of user PostScript
-0.38311258 0.63699499 -0.48253044 0.46708675 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48651 .49041 m
.48884 .48946 L
s
% Start of user PostScript
-0.4047586 -0.28784362 -0.3347849 -0.31632271 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50247 .49428 m
.5034 .49563 L
s
% Start of user PostScript
0.074010515 -0.1716339 0.10206441 -0.13117489 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50345 .50208 m
.50292 .50238 L
s
% Start of user PostScript
0.10355408 0.062303854 0.087717136 0.071372247 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49957 .50152 m
.49931 .5012 L
s
% Start of user PostScript
-0.013015256 0.045474372 -0.020733948 0.035955786 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49913 .49956 m
.49924 .49947 L
s
% Start of user PostScript
-0.026194151 -0.013064837 -0.022679051 -0.015782318 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50006 .4996 m
.50013 .49968 L
s
% Start of user PostScript
0.0018851923 -0.011874377 0.0039663157 -0.009664514 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50022 .50009 m
.50019 .50011 L
s
% Start of user PostScript
0.0065547101 0.0026214015 0.0057931152 0.0034032508 MAarrowhead1
% End of user PostScript
0 .375 1 r
.5 .5001 m
.49998 .50009 L
s
% Start of user PostScript
-0.00013348807 0.0030607188 -0.00068519167 0.0025553022 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49995 .49998 m
.49995 .49998 L
s
% Start of user PostScript
-0.0016231205 -0.00049168508 -0.0014632067 -0.00071003974 MAarrowhead1
% End of user PostScript
.929 0 1 r
.34633 .55468 m
.34303 .5181 L
.34654 .48666 L
.35562 .46081 L
.36902 .44067 L
.3855 .42614 L
.40392 .41689 L
.42322 .41245 L
.44249 .41223 L
.46097 .41555 L
.47805 .42172 L
.49326 .43002 L
.50629 .43979 L
.51699 .4504 L
.52529 .46129 L
.53124 .47198 L
.53499 .48208 L
.53674 .49127 L
.53673 .49933 L
.53526 .50613 L
.53262 .51159 L
.52909 .51571 L
.52497 .51854 L
.52051 .52017 L
.51595 .52074 L
.51148 .52038 L
.50727 .51927 L
.50345 .51757 L
.5001 .51543 L
.49728 .51302 L
.49503 .51048 L
.49333 .50793 L
.49218 .50547 L
.49152 .50318 L
.49131 .50114 L
.49148 .49938 L
.49196 .49792 L
.49269 .49679 L
.49359 .49596 L
.4946 .49543 L
.49567 .49516 L
.49674 .49513 L
.49777 .49531 L
.49872 .49564 L
.49957 .49609 L
.5003 .49663 L
.5009 .49721 L
.50137 .49781 L
.50171 .49841 L
.50193 .49897 L
Mistroke
.50203 .49948 L
.50204 .49993 L
.50196 .50031 L
.50182 .50062 L
.50163 .50086 L
.5014 .50102 L
.50115 .50111 L
.5009 .50115 L
.50065 .50113 L
.50042 .50107 L
.50021 .50098 L
.50002 .50086 L
.49986 .50073 L
.49973 .50059 L
.49964 .50045 L
.49957 .50031 L
.49953 .50019 L
.49952 .50007 L
.49953 .49997 L
.49955 .49989 L
.49959 .49983 L
.49964 .49978 L
.4997 .49975 L
.49976 .49973 L
.49982 .49973 L
.49987 .49974 L
.49993 .49976 L
.49997 .49978 L
.50001 .49981 L
.50005 .49984 L
.50007 .49988 L
.50009 .49991 L
.50011 .49994 L
.50011 .49997 L
.50011 .49999 L
.50011 .50002 L
.5001 .50003 L
.50009 .50005 L
.50008 .50006 L
.50006 .50006 L
.50005 .50006 L
.50004 .50006 L
.50002 .50006 L
.50001 .50005 L
.5 .50005 L
.49999 .50004 L
.49999 .50003 L
.49998 .50003 L
.49998 .50002 L
.49997 .50001 L
Mistroke
.49997 .5 L
.49997 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.34633 .55468 m
.34303 .5181 L
s
% Start of user PostScript
-4.6101862 1.6405025 -4.7091574 0.54292308 MAarrowhead1
% End of user PostScript
1 .158 0 r
.34654 .48666 m
.35562 .46081 L
s
% Start of user PostScript
-4.6039217 -0.40015902 -4.3314714 -1.1758337 MAarrowhead1
% End of user PostScript
1 .473 0 r
.47805 .42172 m
.49326 .43002 L
s
% Start of user PostScript
-0.65860708 -2.3484847 -0.20229767 -2.0992964 MAarrowhead1
% End of user PostScript
1 .788 0 r
.53673 .49933 m
.53526 .50613 L
s
% Start of user PostScript
1.1020151 -0.020057262 1.0578999 0.18382028 MAarrowhead1
% End of user PostScript
.897 1 0 r
.50727 .51927 m
.50345 .51757 L
s
% Start of user PostScript
0.21812645 0.57811515 0.10337155 0.52697375 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49131 .50114 m
.49148 .49938 L
s
% Start of user PostScript
-0.26072549 0.034174546 -0.25564861 -0.018686656 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49777 .49531 m
.49872 .49564 L
s
% Start of user PostScript
-0.066971144 -0.14083364 -0.038416255 -0.13089489 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50203 .49948 m
.50204 .49993 L
s
% Start of user PostScript
0.06090817 -0.01554764 0.061099914 -0.0020097431 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50065 .50113 m
.50042 .50107 L
s
% Start of user PostScript
0.019594291 0.033943086 0.012562436 0.032176674 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49953 .50019 m
.49952 .50007 L
s
% Start of user PostScript
-0.014029117 0.0055501037 -0.014431919 0.0021223926 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49982 .49973 m
.49987 .49974 L
s
% Start of user PostScript
-0.0055411801 -0.0080896583 -0.0038275111 -0.0078273656 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50011 .49994 m
.50011 .49997 L
s
% Start of user PostScript
0.0031793853 -0.0017776376 0.0033653551 -0.00091911343 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50005 .50006 m
.50004 .50006 L
s
% Start of user PostScript
0.0015271823 0.001905011 0.0011139991 0.0018837358 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49998 .50002 m
.49997 .50001 L
s
% Start of user PostScript
-0.00070681511 0.00053467405 -0.0007735645 0.00032188895 MAarrowhead1
% End of user PostScript
.476 0 1 r
.69886 .33194 m
.72085 .39458 L
.73048 .45138 L
.72935 .501 L
.71922 .54262 L
.70196 .57585 L
.67939 .60071 L
.65327 .61755 L
.62521 .62699 L
.59666 .62984 L
.56882 .62704 L
.54269 .6196 L
.51906 .60858 L
.49846 .59498 L
.48122 .57977 L
.46751 .56381 L
.45729 .54786 L
.45043 .53256 L
.44664 .51841 L
.4456 .5058 L
.4469 .49498 L
.45012 .4861 L
.45481 .4792 L
.46056 .47424 L
.46696 .4711 L
.47366 .46963 L
.48033 .4696 L
.48672 .4708 L
.49262 .47297 L
.49786 .47587 L
.50235 .47928 L
.50602 .48296 L
.50886 .48674 L
.51089 .49043 L
.51216 .49392 L
.51274 .49709 L
.51272 .49987 L
.51219 .50221 L
.51126 .50408 L
.51003 .50549 L
.50859 .50646 L
.50705 .50701 L
.50546 .50719 L
.50392 .50705 L
.50246 .50666 L
.50114 .50606 L
.49999 .50532 L
.49902 .50448 L
.49825 .5036 L
.49767 .50271 L
Mistroke
.49728 .50186 L
.49706 .50107 L
.49699 .50037 L
.49705 .49976 L
.49722 .49926 L
.49748 .49887 L
.49779 .49859 L
.49814 .49841 L
.49851 .49832 L
.49888 .49831 L
.49924 .49838 L
.49957 .49849 L
.49986 .49865 L
.50011 .49884 L
.50032 .49904 L
.50048 .49925 L
.5006 .49946 L
.50067 .49965 L
.5007 .49983 L
.50071 .49998 L
.50068 .50011 L
.50063 .50022 L
.50056 .5003 L
.50048 .50035 L
.5004 .50039 L
.50031 .5004 L
.50022 .50039 L
.50014 .50037 L
.50007 .50034 L
.5 .5003 L
.49995 .50025 L
.49991 .5002 L
.49987 .50015 L
.49985 .50011 L
.49984 .50006 L
.49983 .50002 L
.49984 .49999 L
.49985 .49996 L
.49986 .49994 L
.49988 .49992 L
.4999 .49991 L
.49992 .49991 L
.49994 .49991 L
.49996 .49991 L
.49997 .49992 L
.49999 .49992 L
.50001 .49993 L
.50002 .49995 L
.50003 .49996 L
.50003 .49997 L
Mistroke
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50003 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.69886 .33194 m
.72085 .39458 L
s
% Start of user PostScript
5.9658192 -5.0417961 6.6255518 -3.1626607 MAarrowhead1
% End of user PostScript
1 .158 0 r
.73048 .45138 m
.72935 .501 L
s
% Start of user PostScript
6.9144151 -1.4587334 6.880398 0.029974587 MAarrowhead1
% End of user PostScript
1 .473 0 r
.56882 .62704 m
.54269 .6196 L
s
% Start of user PostScript
2.0644847 3.8110598 1.2808369 3.5880463 MAarrowhead1
% End of user PostScript
1 .788 0 r
.44664 .51841 m
.4456 .5058 L
s
% Start of user PostScript
-1.600697 0.55239973 -1.6319284 0.17401367 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48033 .4696 m
.48672 .4708 L
s
% Start of user PostScript
-0.59002409 -0.91186742 -0.39835793 -0.87600349 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51216 .49392 m
.51274 .49709 L
s
% Start of user PostScript
0.36489645 -0.18232251 0.38228831 -0.087200441 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50546 .50719 m
.50392 .50705 L
s
% Start of user PostScript
0.16394667 0.21564583 0.11756168 0.2116111 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49728 .50186 m
.49706 .50107 L
s
% Start of user PostScript
-0.081693501 0.055862852 -0.088327424 0.032202049 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49851 .49832 m
.49888 .49831 L
s
% Start of user PostScript
-0.044559032 -0.05035328 -0.033456033 -0.050554576 MAarrowhead1
% End of user PostScript
0 1 .679 r
.5006 .49946 m
.50067 .49965 L
s
% Start of user PostScript
0.017892543 -0.016321383 0.020089796 -0.010496878 MAarrowhead1
% End of user PostScript
0 1 .995 r
.5004 .50039 m
.50031 .5004 L
s
% Start of user PostScript
0.011892737 0.011591785 0.009265861 0.011935901 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49987 .50015 m
.49985 .50011 L
s
% Start of user PostScript
-0.0038109709 0.0046108638 -0.0044856171 0.0031919565 MAarrowhead1
% End of user PostScript
0 .375 1 r
.4999 .49991 m
.49992 .49991 L
s
% Start of user PostScript
-0.0031253889 -0.0026253819 -0.0025117181 -0.0027819773 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50003 .49996 m
.50003 .49997 L
s
% Start of user PostScript
0.00078175967 -0.0012697597 0.00097915151 -0.00092777866 MAarrowhead1
% End of user PostScript
.205 1 0 r
.45129 .32561 m
.48517 .34415 L
.5142 .36595 L
.538 .38961 L
.55646 .41388 L
.5697 .4377 L
.57802 .46019 L
.58189 .48066 L
.58187 .49861 L
.57857 .51374 L
.57266 .52589 L
.5648 .53506 L
.5556 .54135 L
.54566 .54498 L
.53549 .54622 L
.52553 .54542 L
.51615 .54293 L
.50763 .53913 L
.50017 .53437 L
.49391 .529 L
.48889 .52333 L
.48512 .51764 L
.48255 .51215 L
.4811 .50707 L
.48063 .50251 L
.48101 .49859 L
.48209 .49535 L
.48371 .49282 L
.48573 .49098 L
.48799 .4898 L
.49037 .48922 L
.49275 .48916 L
.49504 .48954 L
.49716 .49028 L
.49905 .49129 L
.50068 .49249 L
.50202 .49379 L
.50306 .49514 L
.50382 .49646 L
.50429 .49771 L
.50453 .49885 L
.50454 .49986 L
.50437 .50071 L
.50405 .50139 L
.50362 .50191 L
.50312 .50227 L
.50257 .50248 L
.50201 .50256 L
.50145 .50252 L
.50093 .50239 L
Mistroke
.50045 .50218 L
.50004 .50192 L
.49969 .50163 L
.4994 .50131 L
.49919 .501 L
.49904 .50069 L
.49896 .50041 L
.49893 .50016 L
.49895 .49994 L
.499 .49975 L
.49909 .49961 L
.4992 .49951 L
.49933 .49944 L
.49946 .4994 L
.49959 .4994 L
.49972 .49942 L
.49983 .49946 L
.49994 .49951 L
.50003 .49958 L
.50011 .49965 L
.50017 .49973 L
.50021 .4998 L
.50024 .49987 L
.50025 .49993 L
.50025 .49999 L
.50024 .50004 L
.50023 .50007 L
.5002 .5001 L
.50017 .50012 L
.50014 .50014 L
.50011 .50014 L
.50008 .50014 L
.50005 .50013 L
.50003 .50012 L
.5 .50011 L
.49998 .50009 L
.49997 .50007 L
.49996 .50006 L
.49995 .50004 L
.49994 .50002 L
.49994 .50001 L
.49994 .5 L
.49994 .49999 L
.49995 .49998 L
.49996 .49997 L
.49996 .49997 L
.49997 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
Mistroke
.5 .49997 L
.5 .49998 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.45129 .32561 m
.48517 .34415 L
s
% Start of user PostScript
-1.4612521 -5.2315651 -0.44501666 -4.6753929 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5142 .36595 m
.538 .38961 L
s
% Start of user PostScript
0.42586539 -4.0215427 1.1399032 -3.3118432 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57266 .52589 m
.5648 .53506 L
s
% Start of user PostScript
2.1798492 0.7768043 1.9438705 1.0517466 MAarrowhead1
% End of user PostScript
1 .788 0 r
.50017 .53437 m
.49391 .529 L
s
% Start of user PostScript
0.0051922316 1.0309741 -0.182818 0.86986495 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48209 .49535 m
.48371 .49282 L
s
% Start of user PostScript
-0.53728168 -0.13943334 -0.48859552 -0.21537868 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49905 .49129 m
.50068 .49249 L
s
% Start of user PostScript
-0.028444406 -0.26128458 0.020379832 -0.22539522 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50437 .50071 m
.50405 .50139 L
s
% Start of user PostScript
0.13105393 0.02117375 0.12151654 0.041716142 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50045 .50218 m
.50004 .50192 L
s
% Start of user PostScript
0.013640161 0.065502493 0.0011180582 0.057690873 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49895 .49994 m
.499 .49975 L
s
% Start of user PostScript
-0.031627879 -0.0019096914 -0.029909083 -0.0073703249 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49983 .49946 m
.49994 .49951 L
s
% Start of user PostScript
-0.0049626722 -0.016249266 -0.0017878604 -0.014599025 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50025 .49999 m
.50024 .50004 L
s
% Start of user PostScript
0.0075484349 -0.00035061025 0.0072850979 0.0010793987 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50005 .50013 m
.50003 .50012 L
s
% Start of user PostScript
0.0016054155 0.0039892935 0.0008092027 0.0036546477 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49994 .50001 m
.49994 .5 L
s
% Start of user PostScript
-0.0017802542 0.0002881511 -0.0017555712 -0.000081403879 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49998 .49997 m
.49999 .49997 L
s
% Start of user PostScript
-0.00048589711 -0.00096917926 -0.00028830552 -0.00090534066 MAarrowhead1
% End of user PostScript
1 .653 0 r
.2266 .31234 m
.27263 .29204 L
.32036 .28332 L
.36762 .28466 L
.41258 .29439 L
.45382 .31079 L
.49028 .33212 L
.52128 .35674 L
.54646 .38313 L
.56573 .40996 L
.57928 .43609 L
.58748 .46057 L
.59087 .48271 L
.59008 .50198 L
.58582 .51807 L
.57881 .53086 L
.56977 .54037 L
.55939 .54673 L
.54831 .5502 L
.53707 .55111 L
.52615 .54983 L
.51594 .54676 L
.50673 .54231 L
.49874 .53689 L
.49207 .53086 L
.48679 .52457 L
.48289 .5183 L
.4803 .51231 L
.47891 .50678 L
.47859 .50188 L
.47918 .49768 L
.4805 .49425 L
.48239 .49161 L
.48469 .48972 L
.48722 .48855 L
.48986 .48802 L
.49248 .48806 L
.49499 .48856 L
.49729 .48945 L
.49933 .49061 L
.50107 .49197 L
.50248 .49342 L
.50357 .49491 L
.50435 .49636 L
.50482 .49772 L
.50503 .49896 L
.505 .50004 L
.50477 .50094 L
.5044 .50166 L
.5039 .5022 L
Mistroke
.50333 .50257 L
.50272 .50277 L
.5021 .50283 L
.50149 .50277 L
.50092 .5026 L
.50041 .50236 L
.49996 .50207 L
.49959 .50173 L
.49929 .50139 L
.49907 .50104 L
.49892 .5007 L
.49884 .5004 L
.49881 .50012 L
.49884 .49989 L
.49891 .49969 L
.49902 .49954 L
.49914 .49944 L
.49928 .49937 L
.49943 .49934 L
.49957 .49934 L
.49971 .49936 L
.49984 .49941 L
.49996 .49948 L
.50005 .49955 L
.50013 .49963 L
.50019 .49971 L
.50024 .49979 L
.50027 .49987 L
.50028 .49994 L
.50028 .5 L
.50027 .50005 L
.50025 .50009 L
.50022 .50012 L
.50019 .50014 L
.50015 .50015 L
.50012 .50016 L
.50008 .50015 L
.50005 .50014 L
.50002 .50013 L
.5 .50012 L
.49998 .5001 L
.49996 .50008 L
.49995 .50006 L
.49994 .50004 L
.49994 .50002 L
.49993 .50001 L
.49994 .49999 L
.49994 .49998 L
.49995 .49998 L
.49995 .49997 L
Mistroke
.49996 .49997 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49999 .49997 L
.5 .49997 L
.5 .49997 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50002 .5 L
.50002 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.2266 .31234 m
.27263 .29204 L
s
% Start of user PostScript
-8.2020556 -5.6296899 -6.821114 -6.2387311 MAarrowhead1
% End of user PostScript
1 .158 0 r
.32036 .28332 m
.36762 .28466 L
s
% Start of user PostScript
-5.3890985 -6.50051 -3.9714746 -6.4603087 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57928 .43609 m
.58748 .46057 L
s
% Start of user PostScript
2.3783657 -1.9173392 2.6245026 -1.1827563 MAarrowhead1
% End of user PostScript
1 .788 0 r
.54831 .5502 m
.53707 .55111 L
s
% Start of user PostScript
1.4491813 1.5060687 1.1120438 1.5332944 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48289 .5183 m
.4803 .51231 L
s
% Start of user PostScript
-0.51322971 0.54895422 -0.5909714 0.36918478 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48722 .48855 m
.48986 .48802 L
s
% Start of user PostScript
-0.38331171 -0.34363782 -0.30410511 -0.35944042 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50357 .49491 m
.50435 .49636 L
s
% Start of user PostScript
0.10718132 -0.15274417 0.13035673 -0.10921252 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50333 .50257 m
.50272 .50277 L
s
% Start of user PostScript
0.099942403 0.077017566 0.081582004 0.083115323 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49929 .50139 m
.49907 .50104 L
s
% Start of user PostScript
-0.021377676 0.041560121 -0.028020932 0.031133641 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49914 .49944 m
.49928 .49937 L
s
% Start of user PostScript
-0.025726311 -0.016891091 -0.021534563 -0.018921924 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50013 .49963 m
.50019 .49971 L
s
% Start of user PostScript
0.003970993 -0.011102583 0.005821127 -0.0086341206 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50022 .50012 m
.50019 .50014 L
s
% Start of user PostScript
0.0065447966 0.0036039647 0.0056046639 0.004229563 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49998 .5001 m
.49996 .50008 L
s
% Start of user PostScript
-0.0006483414 0.0029200735 -0.0011521103 0.0023429872 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49995 .49998 m
.49995 .49997 L
s
% Start of user PostScript
-0.001646706 -0.00074109297 -0.0014403418 -0.00092454009 MAarrowhead1
% End of user PostScript
0 .045 1 r
.18843 .71068 m
.16356 .62081 L
.15614 .54054 L
.16366 .47154 L
.18342 .41475 L
.21267 .37049 L
.24872 .33851 L
.28902 .31812 L
.3313 .30829 L
.37353 .30769 L
.41404 .31488 L
.45148 .32832 L
.48486 .34647 L
.51348 .36785 L
.53696 .39107 L
.5552 .41493 L
.5683 .43835 L
.57657 .46049 L
.58045 .48064 L
.58049 .49834 L
.5773 .51326 L
.57154 .52526 L
.56383 .53432 L
.55482 .54055 L
.54505 .54416 L
.53506 .54542 L
.52527 .54467 L
.51603 .54225 L
.50764 .53853 L
.50029 .53387 L
.49411 .5286 L
.48916 .52303 L
.48543 .51743 L
.48289 .51204 L
.48144 .50703 L
.48096 .50255 L
.48132 .49868 L
.48237 .49548 L
.48396 .49298 L
.48593 .49117 L
.48815 .48999 L
.49049 .48941 L
.49283 .48934 L
.49508 .48971 L
.49717 .49043 L
.49904 .49142 L
.50064 .49259 L
.50196 .49387 L
.50299 .49519 L
.50374 .4965 L
Mistroke
.50421 .49773 L
.50445 .49885 L
.50446 .49984 L
.5043 .50068 L
.50399 .50136 L
.50357 .50187 L
.50307 .50223 L
.50253 .50243 L
.50198 .50251 L
.50144 .50248 L
.50092 .50235 L
.50045 .50215 L
.50004 .50189 L
.4997 .50161 L
.49942 .5013 L
.49921 .50099 L
.49906 .50069 L
.49898 .50041 L
.49895 .50016 L
.49896 .49994 L
.49902 .49976 L
.4991 .49962 L
.49921 .49952 L
.49933 .49945 L
.49946 .49941 L
.49959 .49941 L
.49972 .49943 L
.49984 .49947 L
.49994 .49952 L
.50003 .49959 L
.5001 .49966 L
.50016 .49973 L
.5002 .4998 L
.50023 .49987 L
.50025 .49993 L
.50025 .49999 L
.50024 .50003 L
.50022 .50007 L
.5002 .5001 L
.50017 .50012 L
.50014 .50013 L
.50011 .50014 L
.50008 .50014 L
.50005 .50013 L
.50003 .50012 L
.5 .50011 L
.49998 .50009 L
.49997 .50007 L
.49996 .50006 L
.49995 .50004 L
Mistroke
.49994 .50002 L
.49994 .50001 L
.49994 .5 L
.49995 .49999 L
.49995 .49998 L
.49996 .49997 L
.49996 .49997 L
.49997 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.5 .49997 L
.5 .49998 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.18843 .71068 m
.16356 .62081 L
s
% Start of user PostScript
-9.3471394 6.3203688 -10.093187 3.6243742 MAarrowhead1
% End of user PostScript
1 .158 0 r
.15614 .54054 m
.16366 .47154 L
s
% Start of user PostScript
-10.315839 1.2162649 -10.090218 -0.85387738 MAarrowhead1
% End of user PostScript
1 .473 0 r
.41404 .31488 m
.45148 .32832 L
s
% Start of user PostScript
-2.5788312 -5.553475 -1.4555188 -5.1502628 MAarrowhead1
% End of user PostScript
1 .788 0 r
.58045 .48064 m
.58049 .49834 L
s
% Start of user PostScript
2.4134733 -0.58070118 2.4146285 -0.049824667 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52527 .54467 m
.51603 .54225 L
s
% Start of user PostScript
0.75795292 1.3401109 0.48100591 1.2675201 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48144 .50703 m
.48096 .50255 L
s
% Start of user PostScript
-0.55683442 0.2109528 -0.57112125 0.076370202 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49283 .48934 m
.49508 .48971 L
s
% Start of user PostScript
-0.21506146 -0.31980186 -0.14748948 -0.30870547 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50421 .49773 m
.50445 .49885 L
s
% Start of user PostScript
0.12644055 -0.06818894 0.13337996 -0.034440266 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50198 .50251 m
.50144 .50248 L
s
% Start of user PostScript
0.059426115 0.075414656 0.043113915 0.074384592 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49906 .50069 m
.49898 .50041 L
s
% Start of user PostScript
-0.028175375 0.020628018 -0.030711329 0.012253619 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49946 .49941 m
.49959 .49941 L
s
% Start of user PostScript
-0.016078797 -0.017554109 -0.012184471 -0.017723493 MAarrowhead1
% End of user PostScript
0 .69 1 r
.5002 .4998 m
.50023 .49987 L
s
% Start of user PostScript
0.0061350463 -0.0059743115 0.006957295 -0.003917774 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50014 .50013 m
.50011 .50014 L
s
% Start of user PostScript
0.0042751597 0.0040267392 0.0033564023 0.0041724838 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49996 .50006 m
.49995 .50004 L
s
% Start of user PostScript
-0.0012967392 0.0016768319 -0.001545954 0.0011770646 MAarrowhead1
% End of user PostScript
1 .11 0 r
.56275 .74659 m
.51512 .71926 L
.47453 .68755 L
.44147 .65343 L
.41606 .61865 L
.39809 .58471 L
.38707 .55283 L
.38235 .52396 L
.38308 .49876 L
.38837 .47766 L
.39728 .46084 L
.40887 .44829 L
.42224 .43982 L
.43657 .43511 L
.45114 .43376 L
.46532 .43527 L
.47861 .43913 L
.49063 .4448 L
.50109 .45177 L
.50983 .45955 L
.51677 .4677 L
.52192 .47583 L
.52538 .48362 L
.52726 .49082 L
.52775 .49723 L
.52705 .50272 L
.52539 .50722 L
.52297 .51071 L
.52002 .51321 L
.51675 .51478 L
.51333 .51551 L
.50993 .5155 L
.50668 .51487 L
.50368 .51375 L
.50102 .51226 L
.49874 .51052 L
.49688 .50863 L
.49544 .50671 L
.49442 .50482 L
.49378 .50305 L
.49349 .50144 L
.49351 .50003 L
.49379 .49884 L
.49427 .49789 L
.4949 .49718 L
.49564 .49669 L
.49643 .49642 L
.49724 .49633 L
.49802 .49641 L
.49876 .49661 L
Mistroke
.49944 .49692 L
.50002 .4973 L
.50051 .49773 L
.5009 .49818 L
.5012 .49863 L
.50139 .49906 L
.5015 .49946 L
.50154 .49982 L
.5015 .50013 L
.50141 .50038 L
.50128 .50058 L
.50112 .50072 L
.50094 .50081 L
.50075 .50086 L
.50056 .50086 L
.50038 .50083 L
.50022 .50077 L
.50007 .50069 L
.49994 .50059 L
.49983 .50049 L
.49975 .50038 L
.49969 .50027 L
.49966 .50018 L
.49964 .50009 L
.49964 .50001 L
.49965 .49994 L
.49968 .49989 L
.49972 .49985 L
.49976 .49982 L
.4998 .4998 L
.49984 .4998 L
.49989 .4998 L
.49993 .49981 L
.49997 .49983 L
.5 .49985 L
.50003 .49987 L
.50005 .4999 L
.50007 .49992 L
.50008 .49995 L
.50008 .49997 L
.50009 .49999 L
.50008 .50001 L
.50008 .50002 L
.50007 .50003 L
.50006 .50004 L
.50005 .50004 L
.50004 .50005 L
.50003 .50005 L
.50002 .50005 L
.50001 .50004 L
Mistroke
.5 .50004 L
.5 .50003 L
.49999 .50003 L
.49999 .50002 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.56275 .74659 m
.51512 .71926 L
s
% Start of user PostScript
1.8826435 7.3978052 0.45357582 6.5778837 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47453 .68755 m
.44147 .65343 L
s
% Start of user PostScript
-0.76420346 5.6265473 -1.7559166 4.6029372 MAarrowhead1
% End of user PostScript
1 .473 0 r
.39728 .46084 m
.40887 .44829 L
s
% Start of user PostScript
-3.0815578 -1.1747346 -2.7340128 -1.5513681 MAarrowhead1
% End of user PostScript
1 .788 0 r
.50109 .45177 m
.50983 .45955 L
s
% Start of user PostScript
0.032652103 -1.446882 0.29477681 -1.2135048 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52539 .50722 m
.52297 .51071 L
s
% Start of user PostScript
0.76155364 0.21653419 0.68910266 0.32121 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50102 .51226 m
.49874 .51052 L
s
% Start of user PostScript
0.030450904 0.3677443 -0.037851246 0.31548641 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49379 .49884 m
.49427 .49789 L
s
% Start of user PostScript
-0.18625727 -0.034804167 -0.17184432 -0.063258973 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49944 .49692 m
.50002 .4973 L
s
% Start of user PostScript
-0.016925941 -0.092444264 0.00064585565 -0.080996254 MAarrowhead1
% End of user PostScript
0 1 .364 r
.5015 .50013 m
.50141 .50038 L
s
% Start of user PostScript
0.045074731 0.0039087824 0.04240894 0.011504442 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50022 .50077 m
.50007 .50069 L
s
% Start of user PostScript
0.0064527849 0.022994096 0.0019848554 0.020555075 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49964 .50001 m
.49965 .49994 L
s
% Start of user PostScript
-0.01078905 0.00019864722 -0.010357565 -0.0017977321 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49993 .49981 m
.49997 .49983 L
s
% Start of user PostScript
-0.0021367126 -0.005660231 -0.0010131196 -0.0051597092 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50009 .49999 m
.50008 .50001 L
s
% Start of user PostScript
0.0025525187 -0.00033515714 0.0025029225 0.00018244945 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50002 .50005 m
.50001 .50004 L
s
% Start of user PostScript
0.0006559577 0.0013788508 0.00037637559 0.0012815929 MAarrowhead1
% End of user PostScript
1 0 .08 r
.24458 .74857 m
.21038 .66298 L
.19325 .5846 L
.19113 .51543 L
.20171 .45675 L
.22252 .40922 L
.25108 .37294 L
.28501 .34758 L
.3221 .33238 L
.36034 .32632 L
.39803 .32818 L
.43374 .33662 L
.46637 .35023 L
.49511 .36765 L
.51943 .38756 L
.53907 .40877 L
.55399 .43023 L
.56436 .45103 L
.57049 .47045 L
.57282 .48793 L
.57186 .50309 L
.56818 .5157 L
.56237 .52565 L
.55499 .53297 L
.5466 .53781 L
.53769 .54035 L
.52871 .54088 L
.52002 .53968 L
.51193 .53709 L
.50465 .53343 L
.49836 .52902 L
.49315 .52416 L
.48904 .51912 L
.48603 .51412 L
.48407 .50935 L
.48306 .50498 L
.48288 .50111 L
.48342 .49782 L
.48454 .49514 L
.48609 .49309 L
.48795 .49164 L
.49 .49076 L
.49211 .49039 L
.49421 .49047 L
.49619 .49091 L
.49801 .49165 L
.49962 .4926 L
.50099 .49369 L
.50209 .49486 L
.50294 .49605 L
Mistroke
.50353 .49721 L
.50389 .49829 L
.50403 .49927 L
.50399 .50012 L
.50379 .50082 L
.50348 .50139 L
.50308 .5018 L
.50261 .50208 L
.50212 .50223 L
.50163 .50226 L
.50114 .5022 L
.50069 .50207 L
.50028 .50187 L
.49993 .50163 L
.49964 .50136 L
.49941 .50108 L
.49924 .5008 L
.49912 .50054 L
.49906 .50029 L
.49905 .50008 L
.49908 .49989 L
.49914 .49974 L
.49922 .49962 L
.49933 .49954 L
.49944 .49949 L
.49955 .49947 L
.49967 .49947 L
.49978 .49949 L
.49988 .49953 L
.49997 .49959 L
.50005 .49965 L
.50011 .49971 L
.50016 .49978 L
.50019 .49984 L
.50021 .4999 L
.50022 .49996 L
.50022 .5 L
.50021 .50004 L
.50019 .50007 L
.50017 .5001 L
.50015 .50011 L
.50012 .50012 L
.50009 .50013 L
.50007 .50012 L
.50004 .50012 L
.50002 .5001 L
.5 .50009 L
.49998 .50008 L
.49997 .50006 L
.49996 .50005 L
Mistroke
.49995 .50003 L
.49995 .50002 L
.49995 .50001 L
.49995 .49999 L
.49995 .49999 L
.49996 .49998 L
.49996 .49997 L
.49997 .49997 L
.49997 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49998 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.24458 .74857 m
.21038 .66298 L
s
% Start of user PostScript
-7.6625927 7.4571029 -8.6887084 4.8892585 MAarrowhead1
% End of user PostScript
1 .158 0 r
.19325 .5846 m
.19113 .51543 L
s
% Start of user PostScript
-9.2026295 2.5381435 -9.2660337 0.46298395 MAarrowhead1
% End of user PostScript
1 .473 0 r
.39803 .32818 m
.43374 .33662 L
s
% Start of user PostScript
-3.0592052 -5.1545332 -1.9877349 -4.901526 MAarrowhead1
% End of user PostScript
1 .788 0 r
.57049 .47045 m
.57282 .48793 L
s
% Start of user PostScript
2.1146724 -0.88650264 2.1844794 -0.36198298 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52871 .54088 m
.52002 .53968 L
s
% Start of user PostScript
0.86130484 1.2262722 0.60061284 1.1904002 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48407 .50935 m
.48306 .50498 L
s
% Start of user PostScript
-0.47792574 0.28060703 -0.50832006 0.14944845 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49211 .49039 m
.49421 .49047 L
s
% Start of user PostScript
-0.23655824 -0.28820801 -0.17380907 -0.28599323 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50353 .49721 m
.50389 .49829 L
s
% Start of user PostScript
0.10589507 -0.083768132 0.1165627 -0.051312849 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50212 .50223 m
.50163 .50226 L
s
% Start of user PostScript
0.063688414 0.06683605 0.048753995 0.067930774 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49924 .5008 m
.49912 .50054 L
s
% Start of user PostScript
-0.022893428 0.02403608 -0.026279092 0.016088053 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49944 .49949 m
.49955 .49947 L
s
% Start of user PostScript
-0.016862821 -0.015266345 -0.013351212 -0.015938139 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50016 .49978 m
.50019 .49984 L
s
% Start of user PostScript
0.0047928953 -0.006699064 0.0058053305 -0.0047730694 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50015 .50011 m
.50012 .50012 L
s
% Start of user PostScript
0.0044006408 0.0034259414 0.0035858756 0.0036889787 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49997 .50006 m
.49996 .50005 L
s
% Start of user PostScript
-0.00095942475 0.0018251784 -0.0012502813 0.0013635327 MAarrowhead1
% End of user PostScript
1 0 .31 r
.62628 .75647 m
.57409 .73915 L
.52732 .71506 L
.48696 .68623 L
.45361 .65458 L
.42746 .62183 L
.40841 .58947 L
.39609 .55872 L
.3899 .53057 L
.3891 .50571 L
.39287 .48461 L
.40031 .46752 L
.41055 .45447 L
.42272 .44533 L
.43603 .43985 L
.44976 .43765 L
.46329 .4383 L
.47612 .44131 L
.48785 .44619 L
.49818 .45243 L
.50692 .45958 L
.51398 .46719 L
.51935 .4749 L
.52308 .48237 L
.5253 .48934 L
.52614 .49563 L
.5258 .50107 L
.52449 .50561 L
.52241 .50919 L
.51976 .51182 L
.51675 .51356 L
.51356 .51448 L
.51033 .51468 L
.50721 .51425 L
.5043 .51332 L
.50169 .51201 L
.49943 .51043 L
.49755 .50869 L
.49608 .50688 L
.49499 .50508 L
.49428 .50337 L
.49392 .5018 L
.49385 .50041 L
.49405 .49923 L
.49445 .49826 L
.495 .49752 L
.49567 .497 L
.4964 .49669 L
.49716 .49655 L
.49791 .49658 L
Mistroke
.49863 .49674 L
.49928 .497 L
.49986 .49734 L
.50035 .49773 L
.50075 .49815 L
.50105 .49858 L
.50127 .49899 L
.50139 .49938 L
.50145 .49973 L
.50143 .50004 L
.50136 .50029 L
.50125 .5005 L
.50111 .50065 L
.50094 .50075 L
.50076 .5008 L
.50058 .50081 L
.50041 .50079 L
.50025 .50074 L
.5001 .50067 L
.49998 .50058 L
.49987 .50049 L
.49979 .50039 L
.49973 .50029 L
.49969 .50019 L
.49966 .50011 L
.49966 .50003 L
.49967 .49996 L
.49969 .49991 L
.49972 .49987 L
.49976 .49984 L
.4998 .49982 L
.49984 .49981 L
.49988 .49981 L
.49992 .49982 L
.49996 .49983 L
.49999 .49985 L
.50002 .49987 L
.50004 .4999 L
.50006 .49992 L
.50007 .49994 L
.50008 .49996 L
.50008 .49998 L
.50008 .5 L
.50008 .50002 L
.50007 .50003 L
.50006 .50004 L
.50005 .50004 L
.50004 .50004 L
.50003 .50005 L
.50002 .50004 L
Mistroke
.50001 .50004 L
.50001 .50004 L
.5 .50003 L
.49999 .50003 L
.49999 .50002 L
.49999 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.62628 .75647 m
.57409 .73915 L
s
% Start of user PostScript
3.7882809 7.6940238 2.2226561 7.1746402 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52732 .71506 m
.48696 .68623 L
s
% Start of user PostScript
0.81949812 6.4517282 -0.39116422 5.586872 MAarrowhead1
% End of user PostScript
1 .473 0 r
.39287 .48461 m
.40031 .46752 L
s
% Start of user PostScript
-3.2139557 -0.46167243 -2.9905513 -0.97450485 MAarrowhead1
% End of user PostScript
1 .788 0 r
.48785 .44619 m
.49818 .45243 L
s
% Start of user PostScript
-0.3645777 -1.6143179 -0.054737112 -1.4269749 MAarrowhead1
% End of user PostScript
.897 1 0 r
.5258 .50107 m
.52449 .50561 L
s
% Start of user PostScript
0.77411931 0.032229942 0.73469346 0.16816459 MAarrowhead1
% End of user PostScript
.581 1 0 r
.5043 .51332 m
.50169 .51201 L
s
% Start of user PostScript
0.12904187 0.39971539 0.050642816 0.36038979 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49385 .50041 m
.49405 .49923 L
s
% Start of user PostScript
-0.18437134 0.012261102 -0.17861277 -0.023248203 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49863 .49674 m
.49928 .497 L
s
% Start of user PostScript
-0.041142824 -0.097948702 -0.021518712 -0.090046417 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50145 .49973 m
.50143 .50004 L
s
% Start of user PostScript
0.043385304 -0.0079756649 0.042957417 0.0011803477 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50041 .50079 m
.50025 .50074 L
s
% Start of user PostScript
0.01233918 0.023750617 0.0074783007 0.022264849 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49966 .50011 m
.49966 .50003 L
s
% Start of user PostScript
-0.010074837 0.0031675642 -0.010215079 0.00083460149 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49988 .49981 m
.49992 .49982 L
s
% Start of user PostScript
-0.0035521704 -0.0056966836 -0.0023605827 -0.0054482482 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50008 .49996 m
.50008 .49998 L
s
% Start of user PostScript
0.0023048327 -0.001069126 0.0023996605 -0.00048126405 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50003 .50005 m
.50002 .50004 L
s
% Start of user PostScript
0.00099248274 0.0013507317 0.00070343515 0.0013191896 MAarrowhead1
% End of user PostScript
.867 1 0 r
.47062 .43061 m
.48454 .43617 L
.49683 .44339 L
.50728 .45171 L
.51576 .46063 L
.52225 .46969 L
.52681 .4785 L
.52956 .48677 L
.53069 .49423 L
.53041 .50073 L
.52896 .50615 L
.52658 .51046 L
.52353 .51366 L
.52002 .5158 L
.51627 .51696 L
.51248 .51726 L
.5088 .51682 L
.50535 .51578 L
.50225 .51427 L
.49955 .51244 L
.4973 .5104 L
.49553 .50827 L
.49421 .50616 L
.49334 .50414 L
.49288 .50227 L
.49277 .50062 L
.49297 .4992 L
.49342 .49805 L
.49406 .49716 L
.49484 .49652 L
.49569 .49613 L
.49659 .49595 L
.49747 .49597 L
.49832 .49614 L
.49909 .49644 L
.49978 .49683 L
.50036 .49729 L
.50084 .49778 L
.50121 .49829 L
.50147 .49878 L
.50163 .49924 L
.5017 .49965 L
.50169 .50002 L
.50161 .50032 L
.50148 .50056 L
.50132 .50075 L
.50112 .50087 L
.50092 .50094 L
.50071 .50096 L
.5005 .50093 L
Mistroke
.50031 .50088 L
.50014 .5008 L
.49998 .5007 L
.49986 .50058 L
.49976 .50047 L
.49968 .50035 L
.49963 .50024 L
.49961 .50013 L
.4996 .50004 L
.49961 .49996 L
.49963 .4999 L
.49967 .49985 L
.49971 .49981 L
.49976 .49979 L
.49981 .49978 L
.49986 .49978 L
.4999 .49979 L
.49995 .4998 L
.49999 .49982 L
.50002 .49985 L
.50004 .49988 L
.50007 .4999 L
.50008 .49993 L
.50009 .49996 L
.50009 .49998 L
.50009 .5 L
.50009 .50002 L
.50008 .50003 L
.50007 .50004 L
.50006 .50005 L
.50005 .50005 L
.50004 .50005 L
.50003 .50005 L
.50002 .50005 L
.50001 .50004 L
.5 .50004 L
.49999 .50003 L
.49999 .50003 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
Mistroke
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.47062 .43061 m
.48454 .43617 L
s
% Start of user PostScript
-0.88127131 -2.0815642 -0.46392802 -1.9148888 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49683 .44339 m
.50728 .45171 L
s
% Start of user PostScript
-0.095033918 -1.6983963 0.2184372 -1.4487417 MAarrowhead1
% End of user PostScript
1 .473 0 r
.52896 .50615 m
.52658 .51046 L
s
% Start of user PostScript
0.86880631 0.18454793 0.79753238 0.31378691 MAarrowhead1
% End of user PostScript
1 .788 0 r
.50225 .51427 m
.49955 .51244 L
s
% Start of user PostScript
0.067360396 0.42814978 -0.013544115 0.37311981 MAarrowhead1
% End of user PostScript
.897 1 0 r
.49297 .4992 m
.49342 .49805 L
s
% Start of user PostScript
-0.21083937 -0.023862458 -0.19735383 -0.058514618 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49909 .49644 m
.49978 .49683 L
s
% Start of user PostScript
-0.027270537 -0.10678688 -0.0066379254 -0.094968609 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50169 .50002 m
.50161 .50032 L
s
% Start of user PostScript
0.050613599 0.00048545262 0.048331254 0.009628081 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50031 .50088 m
.50014 .5008 L
s
% Start of user PostScript
0.0092837664 0.026357864 0.0040804355 0.023905749 MAarrowhead1
% End of user PostScript
0 1 .364 r
.4996 .50004 m
.49961 .49996 L
s
% Start of user PostScript
-0.012011789 0.0012128961 -0.011712041 -0.0011656229 MAarrowhead1
% End of user PostScript
0 1 .679 r
.4999 .49979 m
.49995 .4998 L
s
% Start of user PostScript
-0.0028966435 -0.0064384473 -0.0015983632 -0.0059540171 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50009 .49998 m
.50009 .5 L
s
% Start of user PostScript
0.0028156215 -0.00062461309 0.0028073433 -0.000013585585 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50003 .50005 m
.50002 .50005 L
s
% Start of user PostScript
0.00085665638 0.0015561222 0.00053608586 0.0014675557 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49998 .50001 m
.49998 .5 L
s
% Start of user PostScript
-0.00065101267 0.0002327025 -0.00066517877 0.0000775472 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49999 .49999 m
.49999 .49999 L
s
% Start of user PostScript
-0.00024416292 -0.00037196999 -0.00016582742 -0.00035797412 MAarrowhead1
% End of user PostScript
0 1 .13 r
.75234 .38887 m
.76164 .4523 L
.75899 .50745 L
.74641 .55345 L
.72599 .58993 L
.69981 .61696 L
.66985 .63497 L
.6379 .64469 L
.60557 .64707 L
.57421 .64318 L
.54491 .63419 L
.51852 .62128 L
.49563 .60559 L
.47659 .5882 L
.46154 .57007 L
.45044 .55205 L
.44311 .53484 L
.43923 .519 L
.4384 .50495 L
.44017 .49295 L
.44405 .48316 L
.44954 .47562 L
.45617 .47026 L
.46349 .46695 L
.47109 .4655 L
.47863 .46565 L
.48581 .46716 L
.49241 .46974 L
.49825 .47311 L
.50322 .47702 L
.50727 .48122 L
.51037 .48549 L
.51257 .48966 L
.5139 .49358 L
.51447 .49712 L
.51437 .50021 L
.51371 .50279 L
.51261 .50485 L
.51118 .50638 L
.50953 .50742 L
.50776 .50799 L
.50597 .50815 L
.50423 .50795 L
.5026 .50747 L
.50112 .50677 L
.49984 .50591 L
.49877 .50495 L
.49792 .50395 L
.49729 .50295 L
.49687 .502 L
Mistroke
.49665 .50111 L
.49659 .50033 L
.49668 .49965 L
.49688 .4991 L
.49718 .49868 L
.49755 .49837 L
.49795 .49818 L
.49837 .49809 L
.49879 .4981 L
.49919 .49817 L
.49955 .49831 L
.49988 .4985 L
.50016 .49871 L
.50039 .49894 L
.50056 .49918 L
.50069 .49941 L
.50077 .49963 L
.5008 .49983 L
.5008 .5 L
.50076 .50015 L
.5007 .50026 L
.50062 .50035 L
.50053 .50041 L
.50044 .50044 L
.50034 .50045 L
.50024 .50044 L
.50015 .50042 L
.50007 .50038 L
.5 .50033 L
.49994 .50028 L
.49989 .50022 L
.49985 .50017 L
.49983 .50011 L
.49981 .50006 L
.49981 .50002 L
.49982 .49998 L
.49983 .49995 L
.49984 .49993 L
.49986 .49991 L
.49988 .4999 L
.49991 .49989 L
.49993 .49989 L
.49995 .4999 L
.49997 .49991 L
.49999 .49992 L
.50001 .49993 L
.50002 .49994 L
.50003 .49995 L
.50004 .49997 L
.50004 .49998 L
Mistroke
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50004 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.75234 .38887 m
.76164 .4523 L
s
% Start of user PostScript
7.5701821 -3.3340443 7.8493154 -1.4311197 MAarrowhead1
% End of user PostScript
1 .158 0 r
.75899 .50745 m
.74641 .55345 L
s
% Start of user PostScript
7.7697439 0.22353377 7.3922374 1.6036052 MAarrowhead1
% End of user PostScript
1 .473 0 r
.54491 .63419 m
.51852 .62128 L
s
% Start of user PostScript
1.347363 4.0256772 0.55570883 3.6383097 MAarrowhead1
% End of user PostScript
1 .788 0 r
.4384 .50495 m
.44017 .49295 L
s
% Start of user PostScript
-1.847875 0.14840841 -1.7948076 -0.21149763 MAarrowhead1
% End of user PostScript
.897 1 0 r
.48581 .46716 m
.49241 .46974 L
s
% Start of user PostScript
-0.42568093 -0.9852165 -0.22777843 -0.90788908 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51447 .49712 m
.51437 .50021 L
s
% Start of user PostScript
0.43415867 -0.08640788 0.43107804 0.0062533965 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50423 .50795 m
.5026 .50747 L
s
% Start of user PostScript
0.12692193 0.23858277 0.077964018 0.22419885 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49665 .50111 m
.49659 .50033 L
s
% Start of user PostScript
-0.10064526 0.033370246 -0.10236081 0.0097930315 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49879 .4981 m
.49919 .49817 L
s
% Start of user PostScript
-0.036387009 -0.057146645 -0.024400873 -0.054791638 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50077 .49963 m
.5008 .49983 L
s
% Start of user PostScript
0.022979153 -0.011118235 0.0240082 -0.0051851008 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50034 .50045 m
.50024 .50044 L
s
% Start of user PostScript
0.010134712 0.013530071 0.0072309936 0.013249302 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49983 .50011 m
.49981 .50006 L
s
% Start of user PostScript
-0.0051541961 0.0034257797 -0.0055547629 0.0019484915 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49991 .49989 m
.49993 .49989 L
s
% Start of user PostScript
-0.0027597762 -0.0031632729 -0.0020639801 -0.0031687253 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50004 .49997 m
.50004 .49998 L
s
% Start of user PostScript
0.0011314797 -0.0010047164 0.0012654365 -0.00064069728 MAarrowhead1
% End of user PostScript
0 1 .908 r
.42442 .23498 m
.47597 .26287 L
.5202 .29577 L
.55652 .33155 L
.58476 .36832 L
.60507 .40446 L
.61791 .43861 L
.62398 .46974 L
.62412 .49708 L
.61927 .52015 L
.61043 .5387 L
.5986 .55274 L
.58472 .56241 L
.56968 .56803 L
.55427 .57003 L
.53916 .5689 L
.52491 .56521 L
.51196 .55949 L
.5006 .55232 L
.49105 .54421 L
.48338 .53563 L
.47761 .527 L
.47367 .51868 L
.47141 .51095 L
.47065 .50402 L
.47119 .49804 L
.4728 .4931 L
.47523 .48923 L
.47827 .48641 L
.48169 .48459 L
.48529 .48368 L
.4889 .48356 L
.49237 .48412 L
.49559 .48523 L
.49848 .48675 L
.50096 .48855 L
.503 .49053 L
.50459 .49256 L
.50575 .49457 L
.50649 .49647 L
.50685 .49821 L
.50688 .49974 L
.50663 .50103 L
.50616 .50208 L
.50551 .50287 L
.50475 .50342 L
.50392 .50375 L
.50307 .50388 L
.50223 .50382 L
.50143 .50363 L
Mistroke
.50071 .50332 L
.50008 .50293 L
.49954 .50248 L
.49911 .50201 L
.49878 .50153 L
.49855 .50107 L
.49842 .50064 L
.49838 .50025 L
.4984 .49991 L
.49849 .49964 L
.49862 .49942 L
.49878 .49926 L
.49897 .49915 L
.49917 .4991 L
.49937 .49909 L
.49956 .49912 L
.49974 .49918 L
.4999 .49926 L
.50004 .49936 L
.50016 .49947 L
.50025 .49958 L
.50031 .49969 L
.50036 .4998 L
.50038 .49989 L
.50038 .49998 L
.50037 .50005 L
.50034 .50011 L
.50031 .50016 L
.50027 .50019 L
.50022 .50021 L
.50017 .50021 L
.50013 .50021 L
.50008 .5002 L
.50004 .50019 L
.50001 .50016 L
.49998 .50014 L
.49995 .50011 L
.49993 .50009 L
.49992 .50006 L
.49991 .50004 L
.49991 .50002 L
.49991 .5 L
.49992 .49998 L
.49992 .49997 L
.49993 .49996 L
.49994 .49995 L
.49995 .49995 L
.49996 .49995 L
.49998 .49995 L
.49999 .49995 L
Mistroke
.49999 .49996 L
.5 .49996 L
.50001 .49997 L
.50001 .49998 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.42442 .23498 m
.47597 .26287 L
s
% Start of user PostScript
-2.267436 -7.950615 -0.72099826 -7.1138869 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5202 .29577 m
.55652 .33155 L
s
% Start of user PostScript
0.6060023 -6.1270074 1.6957284 -5.0535472 MAarrowhead1
% End of user PostScript
1 .473 0 r
.61043 .5387 m
.5986 .55274 L
s
% Start of user PostScript
3.3130323 1.1611398 2.9579299 1.5820718 MAarrowhead1
% End of user PostScript
1 .788 0 r
.5006 .55232 m
.49105 .54421 L
s
% Start of user PostScript
0.018062764 1.5696066 -0.26861373 1.3261762 MAarrowhead1
% End of user PostScript
.897 1 0 r
.4728 .4931 m
.47523 .48923 L
s
% Start of user PostScript
-0.81607049 -0.20697701 -0.74299717 -0.32308497 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49848 .48675 m
.50096 .48855 L
s
% Start of user PostScript
-0.045713313 -0.39752462 0.0286747 -0.34336563 MAarrowhead1
% End of user PostScript
.266 1 0 r
.50663 .50103 m
.50616 .50208 L
s
% Start of user PostScript
0.19892932 0.030941756 0.18467059 0.06231181 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50071 .50332 m
.50008 .50293 L
s
% Start of user PostScript
0.021330281 0.099592725 0.0022655266 0.087823297 MAarrowhead1
% End of user PostScript
0 1 .364 r
.4984 .49991 m
.49849 .49964 L
s
% Start of user PostScript
-0.047976945 -0.0025949098 -0.045424665 -0.010925711 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49974 .49918 m
.4999 .49926 L
s
% Start of user PostScript
-0.0076856126 -0.024690458 -0.0028552633 -0.022209343 MAarrowhead1
% End of user PostScript
0 1 .995 r
.50038 .49998 m
.50037 .50005 L
s
% Start of user PostScript
0.011442398 -0.00060840927 0.011057227 0.0015713819 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50008 .5002 m
.50004 .50019 L
s
% Start of user PostScript
0.0024737563 0.0060578318 0.0012631332 0.0055562029 MAarrowhead1
% End of user PostScript
0 .375 1 r
.49991 .50002 m
.49991 .5 L
s
% Start of user PostScript
-0.0026965918 0.00045630521 -0.0026628169 -0.00010658615 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49998 .49995 m
.49999 .49995 L
s
% Start of user PostScript
-0.00074635573 -0.0014707729 -0.00044611217 -0.0013755316 MAarrowhead1
% End of user PostScript
1 .003 0 r
.64518 .81237 m
.58199 .78972 L
.52567 .75911 L
.47736 .72306 L
.43771 .68387 L
.40692 .64363 L
.3848 .6041 L
.37083 .56675 L
.36427 .53273 L
.36419 .50286 L
.36956 .47768 L
.37928 .45743 L
.39226 .44213 L
.40748 .4316 L
.42394 .4255 L
.44081 .42336 L
.45734 .42462 L
.47291 .4287 L
.48708 .43497 L
.49948 .44284 L
.50991 .45173 L
.51827 .46112 L
.52456 .47056 L
.52886 .47966 L
.53131 .48812 L
.53212 .49569 L
.53151 .50222 L
.52974 .50761 L
.52707 .51183 L
.52374 .5149 L
.52 .51688 L
.51606 .51787 L
.5121 .51799 L
.5083 .51736 L
.50478 .51615 L
.50163 .51448 L
.49892 .5125 L
.49669 .51034 L
.49495 .50811 L
.49369 .50592 L
.49289 .50384 L
.4925 .50194 L
.49247 .50027 L
.49275 .49886 L
.49327 .49771 L
.49398 .49685 L
.49481 .49625 L
.49572 .49589 L
.49666 .49576 L
.49757 .49582 L
Mistroke
.49844 .49603 L
.49923 .49637 L
.49993 .4968 L
.50051 .49729 L
.50098 .49781 L
.50134 .49833 L
.50158 .49884 L
.50173 .49931 L
.50178 .49973 L
.50175 .5001 L
.50166 .5004 L
.50151 .50064 L
.50133 .50081 L
.50112 .50093 L
.5009 .50099 L
.50069 .501 L
.50047 .50097 L
.50028 .5009 L
.5001 .50081 L
.49995 .5007 L
.49982 .50058 L
.49973 .50046 L
.49966 .50034 L
.49961 .50022 L
.49959 .50011 L
.49958 .50002 L
.4996 .49994 L
.49962 .49988 L
.49966 .49983 L
.49971 .49979 L
.49976 .49977 L
.49981 .49977 L
.49986 .49977 L
.49991 .49978 L
.49995 .4998 L
.49999 .49982 L
.50003 .49985 L
.50005 .49988 L
.50007 .49991 L
.50009 .49993 L
.5001 .49996 L
.5001 .49998 L
.5001 .5 L
.50009 .50002 L
.50008 .50003 L
.50007 .50004 L
.50006 .50005 L
.50005 .50005 L
.50004 .50006 L
.50003 .50005 L
Mistroke
.50002 .50005 L
.50001 .50005 L
.5 .50004 L
.49999 .50003 L
.49999 .50003 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.64518 .81237 m
.58199 .78972 L
s
% Start of user PostScript
4.3555137 9.3712394 2.4598076 8.6915385 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52567 .75911 m
.47736 .72306 L
s
% Start of user PostScript
0.77007681 7.7733867 -0.6791747 6.6917823 MAarrowhead1
% End of user PostScript
1 .473 0 r
.36956 .47768 m
.37928 .45743 L
s
% Start of user PostScript
-3.9132914 -0.66969661 -3.621683 -1.2772099 MAarrowhead1
% End of user PostScript
1 .788 0 r
.48708 .43497 m
.49948 .44284 L
s
% Start of user PostScript
-0.38774774 -1.9507522 -0.01562351 -1.7147467 MAarrowhead1
% End of user PostScript
.897 1 0 r
.53151 .50222 m
.52974 .50761 L
s
% Start of user PostScript
0.94540193 0.066518545 0.89230613 0.22826151 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50478 .51615 m
.50163 .51448 L
s
% Start of user PostScript
0.14341528 0.48441264 0.04896614 0.43439183 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49247 .50027 m
.49275 .49886 L
s
% Start of user PostScript
-0.22588242 0.0080877807 -0.21756434 -0.034326507 MAarrowhead1
% End of user PostScript
0 1 .049 r
.49844 .49603 m
.49923 .49637 L
s
% Start of user PostScript
-0.04678599 -0.11904578 -0.023074572 -0.10885519 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50178 .49973 m
.50175 .5001 L
s
% Start of user PostScript
0.053336502 -0.0080131678 0.052484096 0.0029612851 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50047 .50097 m
.50028 .5009 L
s
% Start of user PostScript
0.014233883 0.028951197 0.0083436232 0.026993078 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49959 .50011 m
.49958 .50002 L
s
% Start of user PostScript
-0.012432979 0.0034397445 -0.01252058 0.00063447867 MAarrowhead1
% End of user PostScript
0 .69 1 r
.49986 .49977 m
.49991 .49978 L
s
% Start of user PostScript
-0.0041386219 -0.0069653698 -0.0026905307 -0.0066243328 MAarrowhead1
% End of user PostScript
0 .375 1 r
.5001 .49996 m
.5001 .49998 L
s
% Start of user PostScript
0.0028566935 -0.0012003874 0.0029515085 -0.00049137514 MAarrowhead1
% End of user PostScript
0 .06 1 r
.50004 .50006 m
.50003 .50005 L
s
% Start of user PostScript
0.001165001 0.0016569496 0.00081269977 0.0016086973 MAarrowhead1
% End of user PostScript
1 0 .031 r
.27163 .60426 m
.26254 .54628 L
.2644 .49575 L
.27539 .45351 L
.29359 .4199 L
.31713 .3949 L
.3442 .37811 L
.37315 .36889 L
.40253 .3664 L
.43109 .36964 L
.45782 .37758 L
.48195 .38914 L
.50292 .40328 L
.52041 .41902 L
.53428 .43546 L
.54455 .45185 L
.55139 .46753 L
.55507 .482 L
.55597 .49486 L
.55448 .50586 L
.55105 .51486 L
.54613 .52182 L
.54015 .52679 L
.53353 .5299 L
.52663 .5313 L
.51978 .53124 L
.51323 .52993 L
.50721 .52763 L
.50186 .5246 L
.4973 .52107 L
.49358 .51727 L
.49071 .51338 L
.48867 .50959 L
.48742 .50602 L
.48687 .50278 L
.48693 .49995 L
.48751 .49758 L
.48849 .49568 L
.48977 .49427 L
.49126 .4933 L
.49286 .49277 L
.49449 .4926 L
.49607 .49276 L
.49756 .49318 L
.49891 .49381 L
.50008 .49459 L
.50107 .49545 L
.50185 .49636 L
.50243 .49727 L
.50282 .49814 L
Mistroke
.50304 .49895 L
.5031 .49967 L
.50303 .50028 L
.50284 .50079 L
.50258 .50118 L
.50225 .50147 L
.50188 .50165 L
.5015 .50173 L
.50112 .50173 L
.50076 .50166 L
.50042 .50154 L
.50012 .50138 L
.49987 .50118 L
.49966 .50097 L
.4995 .50076 L
.49938 .50055 L
.49931 .50035 L
.49927 .50017 L
.49928 .50001 L
.49931 .49987 L
.49936 .49977 L
.49943 .49969 L
.49951 .49963 L
.4996 .4996 L
.49969 .49959 L
.49978 .4996 L
.49986 .49962 L
.49993 .49965 L
.5 .4997 L
.50006 .49974 L
.5001 .49979 L
.50013 .49985 L
.50016 .49989 L
.50017 .49994 L
.50017 .49998 L
.50017 .50001 L
.50016 .50004 L
.50014 .50006 L
.50013 .50008 L
.50011 .50009 L
.50008 .5001 L
.50006 .5001 L
.50004 .50009 L
.50002 .50009 L
.50001 .50008 L
.49999 .50007 L
.49998 .50005 L
.49997 .50004 L
.49997 .50003 L
.49996 .50002 L
Mistroke
.49996 .50001 L
.49996 .5 L
.49996 .49999 L
.49996 .49999 L
.49997 .49998 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 0 r
.27163 .60426 m
.26254 .54628 L
s
% Start of user PostScript
-6.8510659 3.1279324 -7.1238284 1.388388 MAarrowhead1
% End of user PostScript
1 .158 0 r
.2644 .49575 m
.27539 .45351 L
s
% Start of user PostScript
-7.067921 -0.127406 -6.7383451 -1.394755 MAarrowhead1
% End of user PostScript
1 .473 0 r
.45782 .37758 m
.48195 .38914 L
s
% Start of user PostScript
-1.2653044 -3.6725167 -0.54153306 -3.3257148 MAarrowhead1
% End of user PostScript
1 .788 0 r
.55597 .49486 m
.55448 .50586 L
s
% Start of user PostScript
1.6789563 -0.15425806 1.6342765 0.17580004 MAarrowhead1
% End of user PostScript
.897 1 0 r
.51323 .52993 m
.50721 .52763 L
s
% Start of user PostScript
0.39690531 0.89783246 0.21616656 0.82899932 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48687 .50278 m
.48693 .49995 L
s
% Start of user PostScript
-0.39395869 0.083432401 -0.39207862 -0.0014390076 MAarrowhead1
% End of user PostScript
.266 1 0 r
.49607 .49276 m
.49756 .49318 L
s
% Start of user PostScript
-0.1177935 -0.21718456 -0.073128823 -0.20450147 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50304 .49895 m
.5031 .49967 L
s
% Start of user PostScript
0.091193585 -0.031554647 0.092988132 -0.0099843801 MAarrowhead1
% End of user PostScript
0 1 .364 r
.50112 .50173 m
.50076 .50166 L
s
% Start of user PostScript
0.033658108 0.051961707 0.022734662 0.049924649 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49931 .50035 m
.49927 .50017 L
s
% Start of user PostScript
-0.020786366 0.010408373 -0.021781166 0.0049862203 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49969 .49959 m
.49978 .4996 L
s
% Start of user PostScript
-0.0093509093 -0.01228737 -0.0067075162 -0.012059172 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50016 .49989 m
.50017 .49994 L
s
% Start of user PostScript
0.0046530893 -0.0031879009 0.0050320493 -0.0018392774 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50008 .5001 m
.50006 .5001 L
s
% Start of user PostScript
0.0025411579 0.0028688535 0.0019084647 0.0028807646 MAarrowhead1
% End of user PostScript
0 .06 1 r
.49997 .50003 m
.49996 .50002 L
s
% Start of user PostScript
-0.0010189612 0.00093117089 -0.0011443995 0.00059920661 MAarrowhead1
% End of user PostScript
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0333333 0.5 0.0333333 [
[0 .4875 -18.4688 -20 ]
[0 .4875 18.4688 0 ]
[.16667 .4875 -18.4688 -20 ]
[.16667 .4875 18.4688 0 ]
[.33333 .4875 -13.4688 -20 ]
[.33333 .4875 13.4688 0 ]
[.66667 .4875 -7 -20 ]
[.66667 .4875 7 0 ]
[.83333 .4875 -12 -20 ]
[.83333 .4875 12 0 ]
[1 .4875 -12 -20 ]
[1 .4875 12 0 ]
[.4875 0 -36.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .16667 -36.9375 -10 ]
[.4875 .16667 0 10 ]
[.4875 .33333 -26.9375 -10 ]
[.4875 .33333 0 10 ]
[.4875 .66667 -14 -10 ]
[.4875 .66667 0 10 ]
[.4875 .83333 -24 -10 ]
[.4875 .83333 0 10 ]
[.4875 1 -24 -10 ]
[.4875 1 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.16667 .5 m
.16667 .50625 L
s
gsave
.16667 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.33333 .5 m
.33333 .50625 L
s
gsave
.33333 .4875 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.66667 .5 m
.66667 .50625 L
s
gsave
.66667 .4875 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.83333 .5 m
.83333 .50625 L
s
gsave
.83333 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.5 .16667 m
.50625 .16667 L
s
gsave
.4875 .16667 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 .33333 m
.50625 .33333 L
s
gsave
.4875 .33333 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .66667 m
.50625 .66667 L
s
gsave
.4875 .66667 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .83333 m
.50625 .83333 L
s
gsave
.4875 .83333 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.01 w
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.305 0 1 r
.5 Mabswid
.20188 .66639 m
.18449 .58594 L
.18252 .51496 L
.19355 .45478 L
.21507 .40607 L
.24453 .36894 L
.27948 .34301 L
.31763 .32752 L
.35695 .32141 L
.39568 .32343 L
.43236 .33218 L
.46586 .34624 L
.49535 .36419 L
.52029 .38469 L
.54041 .40651 L
.55569 .42857 L
.56628 .44994 L
.57253 .46988 L
.57487 .48783 L
.57384 .50338 L
.57003 .5163 L
.56402 .52649 L
.55642 .53399 L
.54779 .53892 L
.53863 .54151 L
.52939 .54202 L
.52046 .54077 L
.51215 .53809 L
.50469 .53431 L
.49823 .52977 L
.49289 .52477 L
.48868 .51958 L
.48561 .51444 L
.4836 .50955 L
.48257 .50506 L
.4824 .50109 L
.48297 .49772 L
.48412 .49497 L
.48573 .49287 L
.48764 .49139 L
.48975 .49049 L
.49192 .49012 L
.49407 .4902 L
.49611 .49066 L
.49798 .49142 L
.49963 .4924 L
.50103 .49353 L
.50217 .49474 L
.50303 .49596 L
.50364 .49715 L
Mistroke
.504 .49826 L
.50414 .49926 L
.5041 .50013 L
.5039 .50086 L
.50357 .50143 L
.50316 .50186 L
.50268 .50214 L
.50218 .50229 L
.50166 .50233 L
.50117 .50226 L
.5007 .50212 L
.50029 .50192 L
.49993 .50167 L
.49963 .50139 L
.49939 .5011 L
.49921 .50082 L
.4991 .50055 L
.49904 .5003 L
.49903 .50008 L
.49905 .49989 L
.49912 .49973 L
.4992 .49961 L
.49931 .49953 L
.49942 .49948 L
.49954 .49945 L
.49966 .49946 L
.49978 .49948 L
.49988 .49952 L
.49997 .49958 L
.50005 .49964 L
.50012 .4997 L
.50016 .49977 L
.5002 .49984 L
.50022 .4999 L
.50023 .49996 L
.50023 .5 L
.50022 .50004 L
.5002 .50008 L
.50018 .5001 L
.50015 .50012 L
.50012 .50013 L
.50009 .50013 L
.50007 .50013 L
.50004 .50012 L
.50002 .50011 L
.5 .50009 L
.49998 .50008 L
.49997 .50006 L
.49996 .50005 L
.49995 .50003 L
Mistroke
.49995 .50002 L
.49995 .50001 L
.49995 .49999 L
.49995 .49999 L
.49996 .49998 L
.49996 .49997 L
.49997 .49997 L
.49997 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49998 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .962 r
.57482 .19513 m
.62711 .25668 L
.66592 .31808 L
.69186 .3769 L
.70597 .43119 L
.70957 .47952 L
.70422 .52091 L
.69156 .55482 L
.67327 .5811 L
.65099 .59991 L
.62624 .61171 L
.60042 .61714 L
.57473 .61702 L
.55018 .61224 L
.52756 .60374 L
.50747 .59245 L
.49031 .57928 L
.47629 .56505 L
.46547 .55051 L
.45776 .53628 L
.45299 .52288 L
.45086 .51072 L
.45103 .50009 L
.45314 .49115 L
.45678 .48401 L
.46157 .47865 L
.46712 .47501 L
.4731 .47295 L
.47919 .4723 L
.48514 .47286 L
.49073 .47442 L
.49579 .47675 L
.5002 .47964 L
.5039 .48288 L
.50685 .48628 L
.50906 .48969 L
.51054 .49296 L
.51137 .49598 L
.51161 .49869 L
.51134 .50101 L
.51067 .50291 L
.50967 .5044 L
.50845 .50547 L
.50709 .50615 L
.50566 .50647 L
.50424 .50649 L
.50287 .50624 L
.50161 .50578 L
.50049 .50517 L
.49953 .50444 L
Mistroke
.49874 .50366 L
.49813 .50285 L
.49769 .50206 L
.49741 .50132 L
.49728 .50064 L
.49728 .50004 L
.49739 .49954 L
.49759 .49914 L
.49785 .49884 L
.49816 .49863 L
.49849 .49851 L
.49882 .49847 L
.49915 .49849 L
.49947 .49858 L
.49975 .4987 L
.49999 .49886 L
.5002 .49904 L
.50037 .49923 L
.50049 .49942 L
.50058 .4996 L
.50063 .49977 L
.50064 .49992 L
.50063 .50005 L
.50059 .50015 L
.50054 .50024 L
.50047 .5003 L
.5004 .50034 L
.50032 .50036 L
.50024 .50036 L
.50016 .50035 L
.50009 .50032 L
.50003 .50029 L
.49998 .50025 L
.49993 .50021 L
.4999 .50016 L
.49987 .50012 L
.49986 .50008 L
.49985 .50004 L
.49985 .5 L
.49986 .49998 L
.49987 .49995 L
.49988 .49994 L
.4999 .49992 L
.49991 .49992 L
.49993 .49992 L
.49995 .49992 L
.49997 .49992 L
.49998 .49993 L
.5 .49994 L
.50001 .49995 L
Mistroke
.50002 .49996 L
.50003 .49997 L
.50003 .49998 L
.50003 .49999 L
.50004 .49999 L
.50003 .5 L
.50003 .50001 L
.50003 .50001 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .664 r
.49407 .73789 m
.45099 .69942 L
.41679 .65915 L
.39141 .61898 L
.37445 .5805 L
.36523 .54497 L
.36288 .51336 L
.36639 .48628 L
.37468 .4641 L
.38665 .44692 L
.40123 .43462 L
.41742 .4269 L
.43432 .42335 L
.45112 .42344 L
.46719 .42657 L
.48199 .43213 L
.49513 .43952 L
.50635 .44814 L
.51552 .45745 L
.5226 .46697 L
.52764 .47627 L
.53076 .48504 L
.53215 .49299 L
.53204 .49995 L
.53066 .50579 L
.52827 .51047 L
.52514 .51397 L
.52151 .51636 L
.51759 .5177 L
.51361 .51812 L
.50972 .51775 L
.50606 .51673 L
.50275 .51521 L
.49986 .51332 L
.49744 .5112 L
.49551 .50897 L
.49407 .50675 L
.4931 .50461 L
.49256 .50263 L
.49241 .50086 L
.49258 .49934 L
.49302 .49809 L
.49367 .49712 L
.49447 .49642 L
.49536 .49598 L
.4963 .49576 L
.49723 .49575 L
.49812 .49592 L
.49895 .49622 L
.49968 .49662 L
Mistroke
.50031 .49709 L
.50083 .49761 L
.50123 .49813 L
.50151 .49865 L
.50169 .49914 L
.50178 .49958 L
.50178 .49997 L
.5017 .5003 L
.50158 .50056 L
.50141 .50076 L
.50121 .5009 L
.50099 .50098 L
.50077 .501 L
.50055 .50099 L
.50035 .50093 L
.50016 .50085 L
.5 .50075 L
.49987 .50063 L
.49976 .50051 L
.49968 .50038 L
.49962 .50026 L
.49959 .50015 L
.49958 .50005 L
.49959 .49997 L
.49961 .4999 L
.49965 .49984 L
.49969 .4998 L
.49974 .49978 L
.49979 .49977 L
.49984 .49976 L
.49989 .49977 L
.49994 .49979 L
.49998 .49981 L
.50001 .49984 L
.50004 .49987 L
.50007 .49989 L
.50008 .49992 L
.50009 .49995 L
.5001 .49998 L
.5001 .5 L
.50009 .50002 L
.50009 .50003 L
.50008 .50004 L
.50007 .50005 L
.50006 .50005 L
.50004 .50006 L
.50003 .50005 L
.50002 .50005 L
.50001 .50005 L
.5 .50004 L
Mistroke
.49999 .50004 L
.49999 .50003 L
.49998 .50002 L
.49998 .50002 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.35 0 1 r
.38783 .17375 m
.45212 .2046 L
.508 .24231 L
.55459 .28427 L
.59152 .32813 L
.61886 .37181 L
.63705 .41361 L
.64685 .45215 L
.6492 .48642 L
.6452 .51573 L
.63604 .53971 L
.62291 .55824 L
.60698 .57148 L
.58932 .57973 L
.57093 .58346 L
.55265 .58326 L
.5352 .57977 L
.51915 .57364 L
.50491 .56555 L
.49275 .55614 L
.48284 .546 L
.47521 .53564 L
.46979 .52552 L
.46645 .51601 L
.46499 .50738 L
.46516 .49984 L
.4667 .49352 L
.46932 .48848 L
.47275 .4847 L
.47672 .48214 L
.48098 .48071 L
.48532 .48028 L
.48955 .4807 L
.49352 .48183 L
.49711 .48351 L
.50024 .48557 L
.50285 .48788 L
.50494 .49031 L
.50649 .49273 L
.50753 .49506 L
.50811 .4972 L
.50826 .49912 L
.50807 .50076 L
.50758 .50211 L
.50686 .50316 L
.50599 .50391 L
.50502 .50439 L
.504 .50461 L
.50299 .50462 L
.50202 .50444 L
Mistroke
.50112 .50411 L
.50032 .50366 L
.49964 .50315 L
.49909 .50259 L
.49865 .50201 L
.49835 .50145 L
.49815 .50092 L
.49806 .50044 L
.49807 .50002 L
.49815 .49966 L
.49829 .49938 L
.49848 .49917 L
.49869 .49902 L
.49893 .49894 L
.49917 .49891 L
.4994 .49893 L
.49963 .49899 L
.49983 .49908 L
.5 .49919 L
.50015 .49932 L
.50027 .49945 L
.50035 .49959 L
.50041 .49972 L
.50045 .49984 L
.50046 .49994 L
.50045 .50004 L
.50042 .50011 L
.50038 .50017 L
.50034 .50021 L
.50028 .50024 L
.50023 .50025 L
.50017 .50026 L
.50012 .50025 L
.50007 .50023 L
.50002 .5002 L
.49998 .50018 L
.49995 .50015 L
.49993 .50011 L
.49991 .50008 L
.4999 .50005 L
.49989 .50003 L
.49989 .5 L
.4999 .49998 L
.4999 .49997 L
.49991 .49995 L
.49993 .49995 L
.49994 .49994 L
.49995 .49994 L
.49997 .49994 L
.49998 .49994 L
Mistroke
.49999 .49995 L
.5 .49995 L
.50001 .49996 L
.50001 .49997 L
.50002 .49998 L
.50002 .49998 L
.50002 .49999 L
.50003 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .338 r
.73979 .59102 m
.71281 .62039 L
.68166 .64023 L
.64824 .65127 L
.61427 .6545 L
.58117 .65103 L
.55014 .64207 L
.52209 .62887 L
.49766 .61264 L
.47725 .59451 L
.46102 .57551 L
.44896 .55654 L
.44087 .53836 L
.43645 .52156 L
.43527 .50659 L
.43688 .49377 L
.44075 .48325 L
.44637 .47509 L
.45323 .46924 L
.46086 .46555 L
.46883 .46384 L
.47677 .46385 L
.48436 .4653 L
.49136 .46791 L
.49758 .47138 L
.5029 .47543 L
.50725 .47982 L
.51061 .48432 L
.51301 .48871 L
.5145 .49286 L
.51517 .49662 L
.51513 .49991 L
.51449 .50268 L
.51337 .5049 L
.5119 .50657 L
.51019 .5077 L
.50834 .50835 L
.50646 .50855 L
.50462 .50839 L
.5029 .50791 L
.50133 .50719 L
.49996 .50631 L
.49881 .50531 L
.4979 .50426 L
.49721 .50321 L
.49675 .50219 L
.49649 .50126 L
.49642 .50042 L
.49649 .4997 L
.4967 .49911 L
Mistroke
.49701 .49865 L
.49738 .49832 L
.4978 .4981 L
.49824 .498 L
.49868 .498 L
.4991 .49807 L
.4995 .49821 L
.49984 .4984 L
.50014 .49862 L
.50039 .49887 L
.50058 .49911 L
.50071 .49936 L
.5008 .49959 L
.50084 .4998 L
.50084 .49998 L
.50081 .50014 L
.50075 .50026 L
.50067 .50036 L
.50057 .50042 L
.50047 .50046 L
.50037 .50047 L
.50026 .50047 L
.50017 .50044 L
.50008 .5004 L
.5 .50035 L
.49994 .5003 L
.49989 .50024 L
.49985 .50018 L
.49982 .50013 L
.49981 .50007 L
.4998 .50003 L
.49981 .49999 L
.49982 .49995 L
.49983 .49993 L
.49985 .49991 L
.49988 .4999 L
.4999 .49989 L
.49993 .49989 L
.49995 .49989 L
.49997 .4999 L
.49999 .49991 L
.50001 .49992 L
.50002 .49994 L
.50003 .49995 L
.50004 .49996 L
.50004 .49998 L
.50005 .49999 L
.50005 .5 L
.50004 .50001 L
.50004 .50001 L
Mistroke
.50004 .50002 L
.50003 .50002 L
.50003 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .153 0 r
.72509 .40722 m
.73223 .4628 L
.72894 .51095 L
.71702 .55093 L
.69834 .58245 L
.67472 .60562 L
.64791 .62084 L
.61949 .62879 L
.59085 .63031 L
.56318 .62638 L
.53742 .61802 L
.5143 .60628 L
.49433 .59218 L
.47778 .57666 L
.46478 .56056 L
.45528 .54463 L
.44909 .52947 L
.44593 .51556 L
.44544 .50327 L
.44721 .49281 L
.4508 .48433 L
.45579 .47783 L
.46174 .47326 L
.46827 .4705 L
.47502 .46936 L
.48169 .46962 L
.48801 .47106 L
.4938 .47343 L
.49891 .47648 L
.50324 .47998 L
.50675 .48371 L
.50942 .4875 L
.51129 .49118 L
.51241 .49463 L
.51285 .49773 L
.51271 .50043 L
.51208 .50268 L
.51107 .50445 L
.50977 .50577 L
.5083 .50664 L
.50673 .50711 L
.50514 .50722 L
.50361 .50702 L
.50217 .50657 L
.50088 .50594 L
.49976 .50516 L
.49883 .50431 L
.4981 .50342 L
.49756 .50253 L
.4972 .50169 L
Mistroke
.49701 .50091 L
.49698 .50023 L
.49707 .49964 L
.49726 .49916 L
.49753 .49879 L
.49786 .49853 L
.49822 .49837 L
.49859 .49831 L
.49896 .49831 L
.49931 .49839 L
.49963 .49852 L
.49992 .49868 L
.50016 .49888 L
.50036 .49908 L
.50051 .49929 L
.50062 .4995 L
.50068 .49969 L
.50071 .49986 L
.5007 .50001 L
.50067 .50014 L
.50062 .50024 L
.50055 .50032 L
.50047 .50037 L
.50038 .50039 L
.50029 .5004 L
.50021 .50039 L
.50013 .50037 L
.50005 .50033 L
.49999 .50029 L
.49994 .50024 L
.4999 .50019 L
.49987 .50014 L
.49985 .5001 L
.49984 .50005 L
.49983 .50002 L
.49984 .49998 L
.49985 .49996 L
.49986 .49993 L
.49988 .49992 L
.4999 .49991 L
.49992 .49991 L
.49994 .49991 L
.49996 .49991 L
.49998 .49992 L
.49999 .49993 L
.50001 .49994 L
.50002 .49995 L
.50003 .49996 L
.50003 .49997 L
.50004 .49998 L
Mistroke
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50003 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .052 0 r
.62507 .34817 m
.6473 .39481 L
.66008 .43818 L
.6644 .47705 L
.66145 .5106 L
.65252 .53834 L
.63893 .5601 L
.62196 .57596 L
.60284 .58623 L
.58267 .59141 L
.56244 .5921 L
.54296 .58899 L
.52489 .58283 L
.50872 .57434 L
.4948 .56425 L
.48333 .5532 L
.47436 .5418 L
.46786 .53056 L
.46368 .5199 L
.46163 .51016 L
.46144 .50157 L
.46283 .4943 L
.46548 .48843 L
.46908 .48396 L
.47334 .48085 L
.47799 .479 L
.48277 .4783 L
.48747 .47857 L
.49191 .47965 L
.49597 .48138 L
.49954 .48357 L
.50255 .48607 L
.50498 .48872 L
.50681 .4914 L
.50808 .494 L
.50883 .49641 L
.5091 .49858 L
.50896 .50046 L
.50849 .50202 L
.50775 .50325 L
.50682 .50415 L
.50577 .50474 L
.50466 .50505 L
.50354 .5051 L
.50245 .50495 L
.50145 .50462 L
.50054 .50415 L
.49976 .5036 L
.49912 .50299 L
.49861 .50236 L
Mistroke
.49824 .50174 L
.498 .50114 L
.49788 .5006 L
.49786 .50012 L
.49793 .49971 L
.49808 .49938 L
.49827 .49913 L
.49851 .49895 L
.49876 .49884 L
.49903 .4988 L
.49929 .49881 L
.49954 .49887 L
.49976 .49896 L
.49996 .49908 L
.50013 .49922 L
.50027 .49936 L
.50037 .49951 L
.50044 .49966 L
.50049 .49979 L
.5005 .49991 L
.5005 .50002 L
.50047 .50011 L
.50043 .50018 L
.50038 .50023 L
.50032 .50026 L
.50026 .50028 L
.5002 .50028 L
.50014 .50027 L
.50008 .50026 L
.50003 .50023 L
.49999 .5002 L
.49995 .50017 L
.49992 .50013 L
.4999 .5001 L
.49989 .50007 L
.49988 .50004 L
.49988 .50001 L
.49989 .49999 L
.49989 .49997 L
.4999 .49995 L
.49992 .49994 L
.49993 .49994 L
.49995 .49993 L
.49996 .49993 L
.49997 .49994 L
.49999 .49994 L
.5 .49995 L
.50001 .49996 L
.50001 .49996 L
.50002 .49997 L
Mistroke
.50002 .49998 L
.50003 .49999 L
.50003 .49999 L
.50003 .5 L
.50003 .50001 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.721 1 0 r
.51978 .72642 m
.47768 .69443 L
.44323 .6598 L
.41659 .62435 L
.39755 .58961 L
.38567 .55686 L
.38027 .5271 L
.38052 .50103 L
.38552 .47911 L
.39428 .46154 L
.40587 .44833 L
.41936 .43931 L
.43391 .43416 L
.44877 .43247 L
.46329 .43375 L
.47695 .43748 L
.48933 .44311 L
.50016 .45011 L
.50924 .45798 L
.51649 .46627 L
.52192 .47457 L
.5256 .48256 L
.52767 .48997 L
.5283 .49658 L
.52769 .50228 L
.52608 .50696 L
.52368 .51062 L
.52072 .51326 L
.51741 .51495 L
.51393 .51577 L
.51045 .51583 L
.50712 .51524 L
.50403 .51414 L
.50128 .51265 L
.49892 .5109 L
.49698 .50899 L
.49547 .50703 L
.49439 .5051 L
.49371 .50327 L
.49338 .50161 L
.49337 .50015 L
.49363 .49892 L
.49411 .49793 L
.49474 .49718 L
.49548 .49667 L
.49628 .49637 L
.4971 .49626 L
.49791 .49632 L
.49867 .49652 L
.49936 .49682 L
Mistroke
.49997 .49721 L
.50048 .49764 L
.50089 .4981 L
.5012 .49856 L
.50141 .499 L
.50153 .49942 L
.50157 .49979 L
.50154 .50011 L
.50145 .50037 L
.50132 .50058 L
.50116 .50073 L
.50098 .50082 L
.50079 .50087 L
.50059 .50088 L
.50041 .50085 L
.50023 .50079 L
.50008 .50071 L
.49995 .50061 L
.49984 .50051 L
.49975 .5004 L
.49969 .50029 L
.49965 .50019 L
.49963 .5001 L
.49963 .50001 L
.49965 .49994 L
.49967 .49989 L
.49971 .49985 L
.49975 .49982 L
.49979 .4998 L
.49984 .49979 L
.49988 .4998 L
.49992 .49981 L
.49996 .49982 L
.5 .49984 L
.50002 .49987 L
.50005 .49989 L
.50007 .49992 L
.50008 .49994 L
.50008 .49997 L
.50009 .49999 L
.50009 .5 L
.50008 .50002 L
.50007 .50003 L
.50006 .50004 L
.50005 .50005 L
.50004 .50005 L
.50003 .50005 L
.50002 .50005 L
.50001 .50004 L
.50001 .50004 L
Mistroke
.5 .50003 L
.49999 .50003 L
.49999 .50002 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .592 r
.49863 .39106 m
.51853 .40794 L
.5345 .42578 L
.54652 .44373 L
.55475 .46105 L
.55947 .47715 L
.56106 .49157 L
.55995 .50402 L
.55662 .5143 L
.55156 .52237 L
.54525 .52824 L
.53814 .53205 L
.53065 .53396 L
.52314 .5342 L
.51591 .53304 L
.5092 .53074 L
.5032 .52759 L
.49804 .52383 L
.49378 .51973 L
.49046 .5155 L
.48805 .51132 L
.4865 .50737 L
.48575 .50375 L
.48568 .50056 L
.4862 .49787 L
.48719 .49569 L
.48853 .49403 L
.49011 .49288 L
.49184 .4922 L
.49361 .49194 L
.49536 .49204 L
.49701 .49245 L
.49851 .49309 L
.49984 .4939 L
.50095 .49483 L
.50185 .49582 L
.50253 .49681 L
.50301 .49778 L
.50328 .49867 L
.50338 .49948 L
.50333 .50018 L
.50315 .50075 L
.50288 .50121 L
.50253 .50154 L
.50214 .50176 L
.50173 .50188 L
.50131 .5019 L
.50091 .50184 L
.50053 .50171 L
.5002 .50154 L
Mistroke
.49991 .50134 L
.49967 .50111 L
.49948 .50087 L
.49935 .50064 L
.49926 .50042 L
.49921 .50022 L
.49921 .50004 L
.49923 .49989 L
.49929 .49977 L
.49936 .49968 L
.49945 .49961 L
.49954 .49957 L
.49964 .49955 L
.49974 .49956 L
.49983 .49958 L
.49991 .49961 L
.49999 .49966 L
.50005 .49971 L
.5001 .49976 L
.50014 .49982 L
.50016 .49987 L
.50018 .49992 L
.50019 .49997 L
.50018 .50001 L
.50018 .50004 L
.50016 .50007 L
.50014 .50008 L
.50012 .5001 L
.5001 .5001 L
.50007 .50011 L
.50005 .5001 L
.50003 .5001 L
.50001 .50009 L
.5 .50007 L
.49998 .50006 L
.49997 .50005 L
.49996 .50004 L
.49996 .50002 L
.49996 .50001 L
.49996 .5 L
.49996 .49999 L
.49996 .49999 L
.49996 .49998 L
.49997 .49998 L
.49997 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
Mistroke
.5 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .145 1 r
.70401 .20139 m
.74956 .28549 L
.77781 .36466 L
.79042 .43654 L
.78939 .49941 L
.77696 .55222 L
.75544 .59445 L
.72716 .62613 L
.69434 .64768 L
.65902 .65987 L
.62301 .6637 L
.58786 .66038 L
.55484 .65117 L
.52493 .6374 L
.49882 .62034 L
.47695 .60121 L
.45952 .5811 L
.4465 .56098 L
.43771 .54165 L
.43282 .52376 L
.43141 .50779 L
.43296 .49407 L
.43695 .48279 L
.44282 .47401 L
.45003 .46768 L
.45808 .46366 L
.46652 .46174 L
.47494 .46165 L
.48301 .46312 L
.49046 .46582 L
.4971 .46945 L
.50279 .47373 L
.50746 .47837 L
.51107 .48313 L
.51367 .48779 L
.5153 .4922 L
.51606 .49621 L
.51605 .49973 L
.5154 .5027 L
.51424 .50508 L
.5127 .50688 L
.5109 .50811 L
.50895 .50882 L
.50695 .50906 L
.505 .5089 L
.50316 .50842 L
.50149 .50767 L
.50003 .50674 L
.4988 .50568 L
.49782 .50457 L
Mistroke
.49708 .50346 L
.49658 .50238 L
.49629 .50138 L
.4962 .50049 L
.49628 .49972 L
.49649 .49909 L
.49681 .49859 L
.4972 .49823 L
.49765 .498 L
.49811 .49789 L
.49858 .49787 L
.49903 .49795 L
.49944 .49809 L
.49981 .49829 L
.50013 .49853 L
.5004 .49878 L
.5006 .49905 L
.50075 .49931 L
.50084 .49955 L
.50089 .49978 L
.50089 .49997 L
.50086 .50014 L
.50079 .50027 L
.50071 .50037 L
.50061 .50044 L
.5005 .50049 L
.50039 .5005 L
.50028 .50049 L
.50018 .50047 L
.50009 .50043 L
.50001 .50038 L
.49994 .50032 L
.49988 .50026 L
.49984 .5002 L
.49981 .50014 L
.4998 .50008 L
.49979 .50003 L
.49979 .49999 L
.4998 .49995 L
.49982 .49992 L
.49984 .4999 L
.49987 .49989 L
.49989 .49988 L
.49992 .49988 L
.49994 .49989 L
.49997 .49989 L
.49999 .4999 L
.50001 .49992 L
.50002 .49993 L
.50003 .49995 L
Mistroke
.50004 .49996 L
.50005 .49997 L
.50005 .49999 L
.50005 .5 L
.50005 .50001 L
.50004 .50001 L
.50004 .50002 L
.50003 .50002 L
.50003 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .654 r
.54545 .42978 m
.55627 .44909 L
.56311 .46734 L
.56632 .48397 L
.56636 .49857 L
.56375 .51088 L
.559 .52078 L
.55266 .52826 L
.54523 .53341 L
.53718 .5364 L
.52894 .53745 L
.52086 .53683 L
.51325 .53485 L
.50633 .53178 L
.50027 .52794 L
.49517 .5236 L
.49108 .51901 L
.488 .51439 L
.4859 .50995 L
.4847 .50581 L
.4843 .50211 L
.4846 .49892 L
.48546 .49629 L
.48677 .49422 L
.4884 .49272 L
.49022 .49175 L
.49215 .49127 L
.49408 .49121 L
.49594 .49151 L
.49766 .49211 L
.4992 .49292 L
.50052 .49389 L
.50161 .49495 L
.50246 .49603 L
.50308 .49711 L
.50347 .49812 L
.50367 .49905 L
.50368 .49987 L
.50354 .50056 L
.50329 .50112 L
.50294 .50154 L
.50254 .50183 L
.50209 .50201 L
.50164 .50207 L
.50119 .50204 L
.50076 .50194 L
.50038 .50177 L
.50004 .50156 L
.49975 .50132 L
.49952 .50107 L
Mistroke
.49935 .50082 L
.49923 .50057 L
.49916 .50034 L
.49913 .50013 L
.49915 .49995 L
.49919 .4998 L
.49926 .49969 L
.49935 .4996 L
.49945 .49955 L
.49956 .49952 L
.49966 .49951 L
.49977 .49953 L
.49986 .49956 L
.49995 .4996 L
.50002 .49966 L
.50009 .49972 L
.50013 .49978 L
.50017 .49984 L
.50019 .49989 L
.5002 .49994 L
.5002 .49999 L
.5002 .50003 L
.50018 .50006 L
.50016 .50008 L
.50014 .5001 L
.50012 .50011 L
.50009 .50011 L
.50007 .50011 L
.50004 .50011 L
.50002 .5001 L
.5 .50009 L
.49999 .50007 L
.49997 .50006 L
.49996 .50005 L
.49996 .50003 L
.49995 .50002 L
.49995 .50001 L
.49995 .5 L
.49995 .49999 L
.49996 .49998 L
.49996 .49998 L
.49997 .49998 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49999 L
Mistroke
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .012 1 r
.5783 .19481 m
.63049 .25705 L
.66909 .319 L
.69472 .37825 L
.70846 .43286 L
.71165 .48138 L
.70587 .52286 L
.69278 .55676 L
.67409 .58296 L
.65143 .60162 L
.62636 .61323 L
.60026 .61845 L
.57434 .61809 L
.5496 .61307 L
.52686 .60433 L
.50669 .59282 L
.48949 .57945 L
.47548 .56505 L
.46469 .55036 L
.45705 .53601 L
.45235 .52253 L
.45031 .51031 L
.45059 .49964 L
.4528 .4907 L
.45654 .48356 L
.46142 .47823 L
.46706 .47462 L
.47311 .47261 L
.47926 .47202 L
.48526 .47264 L
.49088 .47425 L
.49596 .47664 L
.50039 .47958 L
.5041 .48286 L
.50704 .4863 L
.50923 .48973 L
.5107 .49303 L
.51151 .49607 L
.51172 .49879 L
.51144 .50111 L
.51074 .50302 L
.50972 .5045 L
.50848 .50557 L
.5071 .50623 L
.50566 .50655 L
.50422 .50655 L
.50284 .50629 L
.50157 .50582 L
.50045 .50519 L
.49948 .50445 L
Mistroke
.49869 .50366 L
.49808 .50285 L
.49765 .50205 L
.49738 .5013 L
.49725 .50062 L
.49726 .50002 L
.49737 .49952 L
.49758 .49912 L
.49784 .49881 L
.49815 .49861 L
.49849 .49849 L
.49883 .49845 L
.49916 .49848 L
.49947 .49857 L
.49976 .4987 L
.50001 .49886 L
.50021 .49904 L
.50038 .49923 L
.5005 .49942 L
.50059 .4996 L
.50063 .49977 L
.50065 .49992 L
.50064 .50005 L
.5006 .50016 L
.50054 .50024 L
.50047 .5003 L
.5004 .50034 L
.50032 .50036 L
.50024 .50036 L
.50016 .50035 L
.50009 .50032 L
.50003 .50029 L
.49997 .50025 L
.49993 .50021 L
.4999 .50016 L
.49987 .50012 L
.49986 .50007 L
.49985 .50004 L
.49985 .5 L
.49985 .49998 L
.49986 .49995 L
.49988 .49994 L
.4999 .49992 L
.49991 .49992 L
.49993 .49991 L
.49995 .49992 L
.49997 .49992 L
.49999 .49993 L
.5 .49994 L
.50001 .49995 L
Mistroke
.50002 .49996 L
.50003 .49997 L
.50003 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .5 L
.50003 .50001 L
.50003 .50001 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .043 r
.45885 .23817 m
.50833 .27183 L
.54953 .30921 L
.58213 .34822 L
.60622 .38704 L
.62219 .42414 L
.63071 .45832 L
.63263 .48868 L
.62895 .51462 L
.62069 .53581 L
.60894 .55216 L
.59472 .56381 L
.57899 .57103 L
.56263 .57425 L
.54639 .57399 L
.5309 .57081 L
.51667 .56531 L
.50405 .55808 L
.49329 .54969 L
.48454 .54065 L
.4778 .53145 L
.47304 .52246 L
.47011 .51402 L
.46886 .50637 L
.46904 .4997 L
.47044 .49411 L
.4728 .48965 L
.47586 .48632 L
.4794 .48407 L
.48319 .48283 L
.48705 .48246 L
.4908 .48286 L
.49433 .48388 L
.49751 .48538 L
.50028 .48722 L
.50259 .48928 L
.50443 .49144 L
.5058 .49359 L
.50672 .49566 L
.50722 .49756 L
.50735 .49926 L
.50716 .50071 L
.50672 .50191 L
.50608 .50283 L
.5053 .50349 L
.50444 .50391 L
.50353 .5041 L
.50263 .5041 L
.50177 .50394 L
.50098 .50364 L
Mistroke
.50027 .50325 L
.49967 .50279 L
.49918 .50229 L
.49879 .50178 L
.49852 .50128 L
.49835 .50081 L
.49828 .50038 L
.49828 .50001 L
.49836 .49969 L
.49848 .49944 L
.49865 .49925 L
.49884 .49913 L
.49905 .49905 L
.49927 .49903 L
.49948 .49905 L
.49967 .4991 L
.49985 .49918 L
.50001 .49928 L
.50014 .4994 L
.50024 .49952 L
.50032 .49964 L
.50037 .49975 L
.5004 .49986 L
.50041 .49995 L
.5004 .50003 L
.50037 .5001 L
.50034 .50015 L
.5003 .50019 L
.50025 .50022 L
.5002 .50023 L
.50015 .50023 L
.5001 .50022 L
.50006 .5002 L
.50002 .50018 L
.49998 .50016 L
.49996 .50013 L
.49993 .5001 L
.49992 .50007 L
.49991 .50005 L
.4999 .50002 L
.4999 .5 L
.49991 .49998 L
.49992 .49997 L
.49992 .49996 L
.49994 .49995 L
.49995 .49995 L
.49996 .49995 L
.49997 .49995 L
.49998 .49995 L
.49999 .49995 L
Mistroke
.5 .49996 L
.50001 .49997 L
.50001 .49997 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .607 0 r
.64634 .81195 m
.58318 .78957 L
.52683 .75921 L
.47846 .72335 L
.43871 .68432 L
.40779 .64418 L
.38553 .60472 L
.37142 .56741 L
.36471 .53339 L
.36449 .5035 L
.36973 .47827 L
.37933 .45796 L
.39222 .44259 L
.40735 .43198 L
.42376 .4258 L
.44058 .42357 L
.45707 .42476 L
.47264 .42877 L
.4868 .43498 L
.49921 .4428 L
.50967 .45165 L
.51805 .46101 L
.52437 .47042 L
.5287 .47951 L
.53119 .48796 L
.53203 .49553 L
.53146 .50207 L
.52972 .50748 L
.52707 .51171 L
.52376 .5148 L
.52003 .5168 L
.51611 .51781 L
.51216 .51794 L
.50837 .51734 L
.50485 .51614 L
.5017 .51448 L
.49899 .51252 L
.49675 .51036 L
.495 .50814 L
.49374 .50595 L
.49292 .50388 L
.49252 .50198 L
.49249 .50031 L
.49276 .49889 L
.49327 .49774 L
.49398 .49687 L
.49481 .49627 L
.49571 .49591 L
.49664 .49577 L
.49756 .49582 L
Mistroke
.49843 .49604 L
.49922 .49637 L
.49991 .4968 L
.5005 .49729 L
.50097 .4978 L
.50133 .49833 L
.50158 .49883 L
.50172 .4993 L
.50177 .49972 L
.50175 .50009 L
.50165 .50039 L
.50151 .50063 L
.50133 .50081 L
.50112 .50092 L
.50091 .50098 L
.50069 .50099 L
.50048 .50096 L
.50028 .5009 L
.50011 .50081 L
.49995 .5007 L
.49983 .50058 L
.49973 .50046 L
.49966 .50034 L
.49961 .50022 L
.49959 .50012 L
.49958 .50002 L
.4996 .49994 L
.49963 .49988 L
.49966 .49983 L
.49971 .4998 L
.49976 .49977 L
.49981 .49977 L
.49986 .49977 L
.49991 .49978 L
.49995 .4998 L
.49999 .49982 L
.50003 .49985 L
.50005 .49988 L
.50007 .49991 L
.50009 .49993 L
.50009 .49996 L
.5001 .49998 L
.5001 .5 L
.50009 .50002 L
.50008 .50003 L
.50007 .50004 L
.50006 .50005 L
.50005 .50005 L
.50004 .50006 L
.50003 .50005 L
Mistroke
.50002 .50005 L
.50001 .50005 L
.5 .50004 L
.49999 .50003 L
.49999 .50003 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.617 1 0 r
.41239 .68646 m
.38222 .64119 L
.36161 .59755 L
.34984 .55701 L
.34597 .5207 L
.34887 .48939 L
.35736 .46353 L
.37018 .44328 L
.38614 .42855 L
.40409 .41904 L
.42299 .4143 L
.44194 .41374 L
.46017 .41673 L
.47706 .42256 L
.49216 .43056 L
.50515 .44004 L
.51585 .45041 L
.52419 .46109 L
.53023 .47161 L
.53409 .48158 L
.53597 .49069 L
.53611 .4987 L
.53478 .50548 L
.53227 .51096 L
.52888 .51511 L
.52487 .518 L
.52052 .5197 L
.51604 .52034 L
.51164 .52006 L
.50748 .51903 L
.50369 .5174 L
.50036 .51534 L
.49755 .51299 L
.49529 .51051 L
.49358 .508 L
.4924 .50557 L
.49172 .50331 L
.49147 .50128 L
.49161 .49953 L
.49206 .49807 L
.49275 .49693 L
.49363 .49609 L
.49462 .49555 L
.49566 .49527 L
.49671 .49522 L
.49772 .49537 L
.49867 .49568 L
.49951 .49612 L
.50024 .49664 L
.50084 .49721 L
Mistroke
.50131 .4978 L
.50165 .49839 L
.50188 .49894 L
.50199 .49945 L
.502 .4999 L
.50193 .50028 L
.5018 .50059 L
.50161 .50082 L
.50139 .50099 L
.50115 .50109 L
.50091 .50113 L
.50066 .50111 L
.50043 .50106 L
.50022 .50097 L
.50003 .50086 L
.49987 .50073 L
.49975 .50059 L
.49965 .50045 L
.49958 .50032 L
.49954 .50019 L
.49953 .50008 L
.49953 .49998 L
.49956 .4999 L
.4996 .49983 L
.49964 .49979 L
.4997 .49976 L
.49976 .49974 L
.49981 .49974 L
.49987 .49974 L
.49992 .49976 L
.49997 .49978 L
.50001 .49981 L
.50004 .49984 L
.50007 .49988 L
.50009 .49991 L
.5001 .49994 L
.50011 .49997 L
.50011 .49999 L
.50011 .50001 L
.5001 .50003 L
.50009 .50004 L
.50008 .50005 L
.50006 .50006 L
.50005 .50006 L
.50004 .50006 L
.50002 .50006 L
.50001 .50005 L
.5 .50005 L
.49999 .50004 L
.49999 .50003 L
Mistroke
.49998 .50003 L
.49998 .50002 L
.49997 .50001 L
.49997 .5 L
.49997 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .225 r
.50393 .40014 m
.52194 .41655 L
.53619 .43367 L
.54671 .45068 L
.55366 .46694 L
.55736 .48191 L
.55817 .4952 L
.55652 .50655 L
.55288 .51582 L
.5477 .52296 L
.54145 .52804 L
.53455 .53118 L
.52737 .53258 L
.52025 .53244 L
.51346 .53103 L
.50723 .5286 L
.50171 .52542 L
.497 .52174 L
.49317 .51778 L
.49023 .51374 L
.48815 .5098 L
.48688 .5061 L
.48634 .50275 L
.48643 .49983 L
.48705 .49738 L
.48809 .49544 L
.48943 .49398 L
.49099 .493 L
.49265 .49246 L
.49434 .49231 L
.49599 .49249 L
.49753 .49294 L
.49892 .4936 L
.50014 .49441 L
.50115 .49531 L
.50195 .49626 L
.50255 .4972 L
.50295 .49811 L
.50317 .49894 L
.50322 .49968 L
.50314 .50032 L
.50295 .50084 L
.50266 .50125 L
.50232 .50154 L
.50194 .50172 L
.50154 .5018 L
.50115 .5018 L
.50077 .50173 L
.50042 .50159 L
.50012 .50142 L
Mistroke
.49985 .50122 L
.49964 .501 L
.49947 .50078 L
.49935 .50056 L
.49928 .50035 L
.49924 .50016 L
.49925 .5 L
.49928 .49986 L
.49934 .49975 L
.49941 .49967 L
.49949 .49962 L
.49959 .49958 L
.49968 .49957 L
.49977 .49958 L
.49986 .49961 L
.49994 .49964 L
.5 .49969 L
.50006 .49974 L
.50011 .49979 L
.50014 .49984 L
.50016 .49989 L
.50017 .49994 L
.50018 .49998 L
.50017 .50002 L
.50016 .50004 L
.50015 .50007 L
.50013 .50008 L
.50011 .50009 L
.50009 .5001 L
.50007 .5001 L
.50004 .5001 L
.50002 .50009 L
.50001 .50008 L
.49999 .50007 L
.49998 .50006 L
.49997 .50004 L
.49996 .50003 L
.49996 .50002 L
.49996 .50001 L
.49996 .5 L
.49996 .49999 L
.49996 .49999 L
.49997 .49998 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
Mistroke
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .548 1 r
.71862 .59048 m
.69266 .61608 L
.66316 .63292 L
.63188 .64175 L
.60035 .64349 L
.56986 .63921 L
.54148 .63005 L
.51599 .61717 L
.49395 .60166 L
.4757 .58458 L
.46135 .56686 L
.45084 .54931 L
.44399 .53261 L
.44048 .51728 L
.43992 .50372 L
.44184 .49219 L
.44578 .48283 L
.45126 .47565 L
.45781 .4706 L
.46499 .46754 L
.47242 .46626 L
.47976 .46654 L
.48673 .46812 L
.49312 .47071 L
.49875 .47406 L
.50353 .47791 L
.5074 .48203 L
.51035 .4862 L
.51242 .49025 L
.51365 .49405 L
.51415 .49747 L
.51399 .50044 L
.51331 .50292 L
.5122 .50489 L
.51078 .50634 L
.50916 .50731 L
.50743 .50783 L
.50568 .50795 L
.50399 .50773 L
.5024 .50724 L
.50098 .50654 L
.49975 .50569 L
.49872 .50475 L
.49791 .50377 L
.49731 .5028 L
.49692 .50187 L
.49671 .50101 L
.49667 .50026 L
.49677 .49961 L
.49698 .49908 L
Mistroke
.49728 .49868 L
.49764 .49839 L
.49803 .49821 L
.49844 .49813 L
.49885 .49814 L
.49924 .49823 L
.49959 .49837 L
.49991 .49855 L
.50018 .49876 L
.5004 .49899 L
.50056 .49922 L
.50068 .49944 L
.50075 .49966 L
.50078 .49985 L
.50078 .50001 L
.50074 .50015 L
.50068 .50026 L
.5006 .50035 L
.50051 .5004 L
.50042 .50043 L
.50032 .50044 L
.50023 .50043 L
.50014 .5004 L
.50006 .50037 L
.49999 .50032 L
.49993 .50027 L
.49989 .50021 L
.49985 .50016 L
.49983 .50011 L
.49982 .50006 L
.49982 .50002 L
.49982 .49998 L
.49983 .49995 L
.49985 .49993 L
.49987 .49991 L
.49989 .4999 L
.49991 .4999 L
.49993 .4999 L
.49996 .4999 L
.49998 .49991 L
.49999 .49992 L
.50001 .49993 L
.50002 .49994 L
.50003 .49996 L
.50004 .49997 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50004 .50001 L
Mistroke
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.216 1 0 r
.62802 .48587 m
.62504 .5114 L
.61755 .53239 L
.60655 .54871 L
.59306 .56046 L
.57802 .56791 L
.56227 .57144 L
.54655 .57155 L
.5315 .56879 L
.51761 .56371 L
.50524 .5569 L
.49465 .54891 L
.48597 .54025 L
.47925 .53137 L
.47443 .52266 L
.47141 .51444 L
.47002 .50696 L
.47005 .50041 L
.47128 .49489 L
.47345 .49046 L
.47634 .48713 L
.47971 .48484 L
.48335 .48353 L
.48707 .48308 L
.49072 .48339 L
.49414 .48431 L
.49726 .48571 L
.49998 .48746 L
.50226 .48942 L
.50409 .4915 L
.50546 .49358 L
.5064 .49558 L
.50692 .49744 L
.50709 .49911 L
.50694 .50054 L
.50655 .50172 L
.50595 .50264 L
.50521 .50331 L
.50438 .50374 L
.50351 .50395 L
.50264 .50397 L
.5018 .50382 L
.50103 .50355 L
.50034 .50318 L
.49974 .50274 L
.49925 .50226 L
.49887 .50177 L
.4986 .50129 L
.49843 .50083 L
.49834 .50041 L
Mistroke
.49834 .50005 L
.4984 .49974 L
.49852 .49949 L
.49868 .4993 L
.49886 .49917 L
.49906 .49909 L
.49927 .49906 L
.49947 .49908 L
.49966 .49913 L
.49984 .4992 L
.49999 .4993 L
.50012 .49941 L
.50022 .49952 L
.5003 .49964 L
.50035 .49975 L
.50038 .49985 L
.50039 .49994 L
.50039 .50002 L
.50036 .50009 L
.50033 .50014 L
.50029 .50018 L
.50025 .50021 L
.5002 .50022 L
.50015 .50022 L
.5001 .50021 L
.50006 .5002 L
.50002 .50018 L
.49999 .50015 L
.49996 .50013 L
.49994 .5001 L
.49992 .50007 L
.49991 .50005 L
.49991 .50002 L
.49991 .5 L
.49991 .49999 L
.49992 .49997 L
.49993 .49996 L
.49994 .49995 L
.49995 .49995 L
.49996 .49995 L
.49997 .49995 L
.49998 .49995 L
.49999 .49996 L
.5 .49996 L
.50001 .49997 L
.50001 .49997 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
Mistroke
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.331 0 1 r
.7069 .20956 m
.75083 .2929 L
.77768 .37114 L
.78911 .44197 L
.78715 .50375 L
.77402 .55547 L
.75204 .59666 L
.72351 .62737 L
.69062 .64806 L
.65539 .65951 L
.6196 .66274 L
.58477 .65894 L
.55215 .6494 L
.52268 .63542 L
.49703 .61826 L
.47562 .59913 L
.45862 .57911 L
.446 .55914 L
.43757 .54 L
.43299 .52235 L
.43183 .50663 L
.43357 .49317 L
.4377 .48214 L
.44365 .4736 L
.4509 .46749 L
.45895 .46366 L
.46735 .46189 L
.47571 .46193 L
.48369 .46349 L
.49105 .46626 L
.49758 .46993 L
.50316 .47422 L
.50772 .47885 L
.51124 .48358 L
.51374 .48821 L
.5153 .49257 L
.51599 .49652 L
.51593 .49998 L
.51524 .50288 L
.51406 .50521 L
.5125 .50695 L
.51069 .50813 L
.50875 .5088 L
.50676 .50901 L
.50483 .50883 L
.50301 .50832 L
.50137 .50756 L
.49993 .50662 L
.49873 .50557 L
.49777 .50446 L
Mistroke
.49705 .50335 L
.49657 .50229 L
.4963 .5013 L
.49622 .50043 L
.49631 .49967 L
.49653 .49905 L
.49685 .49857 L
.49725 .49822 L
.49769 .498 L
.49816 .49789 L
.49862 .49789 L
.49907 .49797 L
.49948 .49812 L
.49984 .49832 L
.50015 .49855 L
.50041 .49881 L
.50061 .49907 L
.50075 .49933 L
.50084 .49957 L
.50088 .49979 L
.50088 .49999 L
.50085 .50015 L
.50078 .50028 L
.5007 .50038 L
.5006 .50045 L
.50049 .50049 L
.50038 .5005 L
.50027 .50049 L
.50017 .50046 L
.50008 .50042 L
.5 .50037 L
.49993 .50031 L
.49988 .50025 L
.49984 .50019 L
.49981 .50013 L
.4998 .50008 L
.49979 .50003 L
.4998 .49998 L
.49981 .49995 L
.49982 .49992 L
.49985 .4999 L
.49987 .49989 L
.4999 .49988 L
.49992 .49988 L
.49995 .49989 L
.49997 .4999 L
.49999 .49991 L
.50001 .49992 L
.50002 .49993 L
.50003 .49995 L
Mistroke
.50004 .49996 L
.50005 .49998 L
.50005 .49999 L
.50005 .5 L
.50005 .50001 L
.50004 .50002 L
.50004 .50002 L
.50003 .50002 L
.50003 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .097 r
.3509 .30831 m
.39228 .31128 L
.43132 .32132 L
.46685 .3369 L
.49799 .3565 L
.52422 .37869 L
.54526 .40217 L
.56112 .42579 L
.57199 .44859 L
.57823 .46978 L
.58034 .48878 L
.57891 .50518 L
.57454 .51874 L
.5679 .52937 L
.55961 .53712 L
.55026 .54214 L
.54041 .54467 L
.53052 .54501 L
.521 .54349 L
.51216 .54048 L
.50426 .53633 L
.49746 .5314 L
.49185 .526 L
.48747 .52043 L
.48429 .51494 L
.48225 .50973 L
.48125 .50497 L
.48116 .50077 L
.48183 .49722 L
.48313 .49435 L
.48489 .49216 L
.48697 .49064 L
.48924 .48974 L
.49158 .48939 L
.49387 .48953 L
.49605 .49006 L
.49803 .4909 L
.49977 .49197 L
.50125 .49319 L
.50243 .49449 L
.50333 .4958 L
.50395 .49706 L
.50431 .49825 L
.50445 .49931 L
.50438 .50023 L
.50415 .50099 L
.50379 .50159 L
.50334 .50203 L
.50282 .50232 L
.50228 .50247 L
Mistroke
.50173 .50249 L
.5012 .50242 L
.50071 .50226 L
.50027 .50203 L
.49988 .50176 L
.49957 .50146 L
.49932 .50115 L
.49914 .50085 L
.49902 .50056 L
.49896 .50029 L
.49896 .50006 L
.49899 .49986 L
.49906 .4997 L
.49916 .49957 L
.49927 .49949 L
.4994 .49943 L
.49952 .49941 L
.49965 .49942 L
.49977 .49945 L
.49988 .49949 L
.49998 .49955 L
.50006 .49962 L
.50013 .49969 L
.50018 .49976 L
.50022 .49983 L
.50024 .4999 L
.50025 .49996 L
.50024 .50001 L
.50023 .50005 L
.50021 .50009 L
.50019 .50011 L
.50016 .50013 L
.50013 .50014 L
.5001 .50014 L
.50007 .50013 L
.50004 .50013 L
.50002 .50011 L
.5 .5001 L
.49998 .50008 L
.49996 .50007 L
.49995 .50005 L
.49995 .50003 L
.49994 .50002 L
.49994 .5 L
.49994 .49999 L
.49995 .49998 L
.49995 .49998 L
.49996 .49997 L
.49997 .49997 L
.49997 .49997 L
Mistroke
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49997 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .591 r
.21349 .20538 m
.27957 .1995 L
.34386 .20659 L
.40407 .22427 L
.45845 .25014 L
.50576 .28184 L
.54525 .31719 L
.57659 .35416 L
.59983 .39104 L
.61535 .42635 L
.62377 .45894 L
.62588 .48793 L
.62262 .51276 L
.61498 .53309 L
.60397 .54883 L
.59057 .56009 L
.5757 .56714 L
.56019 .57038 L
.54476 .57028 L
.53002 .56738 L
.51645 .56226 L
.50439 .55547 L
.4941 .54755 L
.48569 .539 L
.47921 .53026 L
.4746 .52172 L
.47174 .51368 L
.47048 .50638 L
.47059 .5 L
.47187 .49465 L
.47406 .49036 L
.47694 .48715 L
.48028 .48497 L
.48387 .48374 L
.48753 .48336 L
.4911 .48371 L
.49446 .48465 L
.49749 .48605 L
.50014 .48779 L
.50236 .48973 L
.50413 .49178 L
.50545 .49382 L
.50634 .49579 L
.50683 .4976 L
.50697 .49922 L
.50681 .50062 L
.5064 .50176 L
.50581 .50265 L
.50507 .50329 L
.50425 .5037 L
Mistroke
.50339 .50389 L
.50254 .5039 L
.50172 .50375 L
.50096 .50347 L
.50029 .5031 L
.49971 .50267 L
.49924 .50219 L
.49887 .50171 L
.49861 .50124 L
.49844 .50079 L
.49837 .50038 L
.49837 .50002 L
.49844 .49972 L
.49855 .49948 L
.49871 .4993 L
.49889 .49917 L
.49909 .4991 L
.4993 .49908 L
.49949 .4991 L
.49968 .49915 L
.49985 .49922 L
.5 .49932 L
.50012 .49942 L
.50022 .49954 L
.5003 .49965 L
.50035 .49976 L
.50038 .49986 L
.50039 .49995 L
.50038 .50003 L
.50036 .50009 L
.50032 .50014 L
.50028 .50018 L
.50024 .5002 L
.50019 .50021 L
.50014 .50022 L
.5001 .50021 L
.50006 .50019 L
.50002 .50017 L
.49999 .50015 L
.49996 .50012 L
.49994 .5001 L
.49992 .50007 L
.49991 .50005 L
.49991 .50002 L
.49991 .5 L
.49991 .49999 L
.49992 .49997 L
.49993 .49996 L
.49994 .49995 L
.49995 .49995 L
Mistroke
.49996 .49995 L
.49997 .49995 L
.49998 .49995 L
.49999 .49996 L
.5 .49996 L
.50001 .49997 L
.50001 .49997 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.925 1 0 r
.70762 .82676 m
.6391 .81321 L
.57602 .78931 L
.52003 .75769 L
.47223 .72083 L
.43321 .68106 L
.40312 .64043 L
.38174 .60071 L
.36853 .56334 L
.36269 .52944 L
.36328 .4998 L
.36924 .47493 L
.37947 .45505 L
.39289 .44017 L
.40843 .43006 L
.42514 .42437 L
.44216 .42263 L
.45876 .42425 L
.47434 .42865 L
.48845 .43519 L
.50076 .44327 L
.51106 .45233 L
.51926 .46183 L
.52538 .47134 L
.5295 .48047 L
.53178 .48891 L
.53242 .49644 L
.53166 .50291 L
.52976 .50822 L
.52697 .51234 L
.52356 .51532 L
.51974 .5172 L
.51576 .51809 L
.51178 .51812 L
.50797 .51742 L
.50445 .51613 L
.50132 .5144 L
.49864 .51238 L
.49644 .51019 L
.49474 .50794 L
.49352 .50573 L
.49276 .50365 L
.49241 .50176 L
.49242 .5001 L
.49273 .4987 L
.49328 .49758 L
.49401 .49674 L
.49487 .49616 L
.49579 .49583 L
.49673 .49572 L
Mistroke
.49765 .49579 L
.49852 .49603 L
.49931 .49638 L
.5 .49682 L
.50057 .49732 L
.50104 .49785 L
.50138 .49838 L
.50162 .49888 L
.50175 .49935 L
.50179 .49977 L
.50176 .50014 L
.50166 .50044 L
.50151 .50067 L
.50132 .50084 L
.50111 .50095 L
.50089 .501 L
.50067 .501 L
.50046 .50097 L
.50026 .5009 L
.50008 .50081 L
.49993 .50069 L
.49981 .50057 L
.49971 .50045 L
.49965 .50033 L
.4996 .50021 L
.49958 .5001 L
.49958 .50001 L
.4996 .49993 L
.49963 .49987 L
.49967 .49982 L
.49971 .49979 L
.49976 .49977 L
.49982 .49976 L
.49987 .49977 L
.49991 .49978 L
.49996 .4998 L
.5 .49982 L
.50003 .49985 L
.50006 .49988 L
.50008 .49991 L
.50009 .49994 L
.5001 .49996 L
.5001 .49999 L
.5001 .50001 L
.50009 .50002 L
.50008 .50004 L
.50007 .50005 L
.50006 .50005 L
.50005 .50006 L
.50004 .50006 L
Mistroke
.50003 .50005 L
.50002 .50005 L
.50001 .50004 L
.5 .50004 L
.49999 .50003 L
.49998 .50003 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .612 0 r
.74673 .64173 m
.71022 .66439 L
.67117 .67684 L
.63154 .68022 L
.59301 .67585 L
.55695 .66515 L
.5244 .64956 L
.4961 .6305 L
.4725 .60928 L
.45379 .58709 L
.43993 .56498 L
.43069 .54383 L
.42572 .52431 L
.42451 .50696 L
.42651 .49212 L
.43113 .47997 L
.43777 .47058 L
.44582 .46387 L
.45475 .45968 L
.46406 .45777 L
.47331 .45786 L
.48214 .45963 L
.49027 .46272 L
.49748 .46681 L
.50364 .47157 L
.50866 .4767 L
.51253 .48194 L
.51527 .48706 L
.51697 .49187 L
.51771 .49624 L
.51763 .50006 L
.51686 .50326 L
.51553 .50582 L
.5138 .50773 L
.51179 .50903 L
.50964 .50976 L
.50744 .50998 L
.5053 .50977 L
.50329 .5092 L
.50147 .50835 L
.49989 .50731 L
.49856 .50614 L
.49751 .50491 L
.49672 .50368 L
.49619 .50251 L
.4959 .50142 L
.49582 .50045 L
.49592 .49962 L
.49616 .49893 L
.49652 .4984 L
Mistroke
.49697 .49802 L
.49746 .49778 L
.49797 .49767 L
.49849 .49766 L
.49898 .49775 L
.49943 .49792 L
.49983 .49814 L
.50018 .49841 L
.50046 .49869 L
.50068 .49898 L
.50084 .49926 L
.50093 .49953 L
.50098 .49978 L
.50098 .49999 L
.50094 .50017 L
.50087 .50031 L
.50077 .50042 L
.50066 .5005 L
.50054 .50054 L
.50042 .50055 L
.5003 .50054 L
.50019 .50051 L
.50009 .50047 L
.5 .50041 L
.49993 .50034 L
.49987 .50028 L
.49982 .50021 L
.49979 .50014 L
.49977 .50008 L
.49977 .50003 L
.49977 .49998 L
.49979 .49994 L
.49981 .49991 L
.49983 .49989 L
.49986 .49988 L
.49989 .49987 L
.49991 .49987 L
.49994 .49988 L
.49997 .49988 L
.49999 .4999 L
.50001 .49991 L
.50002 .49993 L
.50004 .49994 L
.50005 .49996 L
.50005 .49997 L
.50005 .49999 L
.50005 .5 L
.50005 .50001 L
.50005 .50002 L
.50004 .50002 L
Mistroke
.50004 .50003 L
.50003 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50003 L
.5 .50002 L
.5 .50002 L
.49999 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.689 1 0 r
.23471 .7838 m
.19452 .69087 L
.173 .60523 L
.168 .52913 L
.17709 .46408 L
.19763 .41091 L
.22696 .36984 L
.26251 .34056 L
.30184 .32237 L
.34279 .3142 L
.38344 .31477 L
.42223 .32265 L
.45791 .33636 L
.48954 .35442 L
.51651 .3754 L
.53849 .39799 L
.5554 .42103 L
.56738 .44354 L
.57475 .46469 L
.57794 .48385 L
.5775 .50059 L
.57403 .51461 L
.56816 .5258 L
.56051 .53416 L
.55167 .53981 L
.54218 .54296 L
.53252 .54389 L
.52312 .54292 L
.5143 .54038 L
.50632 .53664 L
.49938 .53203 L
.49357 .52688 L
.48895 .52149 L
.48552 .5161 L
.48321 .51093 L
.48195 .50615 L
.48161 .5019 L
.48206 .49825 L
.48316 .49526 L
.48475 .49294 L
.4867 .49127 L
.48887 .49022 L
.49113 .48973 L
.49339 .48973 L
.49554 .49014 L
.49753 .49088 L
.4993 .49186 L
.50082 .49301 L
.50205 .49426 L
.50301 .49554 L
Mistroke
.50369 .49679 L
.50412 .49796 L
.50431 .49903 L
.5043 .49997 L
.50412 .50076 L
.5038 .50139 L
.50338 .50186 L
.5029 .50219 L
.50237 .50237 L
.50184 .50243 L
.50132 .50238 L
.50083 .50225 L
.50038 .50205 L
.49999 .50179 L
.49966 .50151 L
.4994 .50121 L
.49921 .50091 L
.49908 .50063 L
.499 .50036 L
.49898 .50012 L
.499 .49992 L
.49906 .49975 L
.49915 .49962 L
.49926 .49952 L
.49937 .49946 L
.4995 .49943 L
.49962 .49943 L
.49974 .49945 L
.49986 .49949 L
.49995 .49955 L
.50004 .49961 L
.50011 .49968 L
.50016 .49975 L
.5002 .49982 L
.50023 .49988 L
.50024 .49994 L
.50024 .49999 L
.50023 .50004 L
.50021 .50007 L
.50019 .5001 L
.50016 .50012 L
.50013 .50013 L
.5001 .50013 L
.50007 .50013 L
.50005 .50013 L
.50002 .50011 L
.5 .5001 L
.49998 .50008 L
.49997 .50007 L
.49996 .50005 L
Mistroke
.49995 .50004 L
.49995 .50002 L
.49994 .50001 L
.49994 .5 L
.49995 .49999 L
.49995 .49998 L
.49996 .49997 L
.49996 .49997 L
.49997 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49997 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.033 0 1 r
.78687 .61496 m
.75349 .64914 L
.71534 .67187 L
.6747 .68408 L
.6336 .68696 L
.59376 .68191 L
.55656 .67039 L
.52307 .65391 L
.49404 .63392 L
.4699 .61178 L
.45085 .58873 L
.43682 .56583 L
.42756 .54397 L
.42269 .52387 L
.4217 .50604 L
.42399 .49082 L
.42896 .47842 L
.43597 .46887 L
.44441 .4621 L
.45372 .45794 L
.46339 .45612 L
.47297 .45635 L
.48209 .45829 L
.49047 .46158 L
.49788 .46588 L
.50418 .47086 L
.50931 .4762 L
.51324 .48164 L
.51601 .48694 L
.5177 .49191 L
.5184 .4964 L
.51826 .50032 L
.51741 .5036 L
.516 .5062 L
.51418 .50814 L
.51208 .50944 L
.50984 .51016 L
.50756 .51036 L
.50535 .5101 L
.50327 .50949 L
.5014 .50859 L
.49978 .5075 L
.49842 .50628 L
.49735 .50501 L
.49655 .50373 L
.49602 .50252 L
.49573 .5014 L
.49566 .5004 L
.49578 .49955 L
.49604 .49885 L
Mistroke
.49642 .49831 L
.49689 .49792 L
.4974 .49768 L
.49793 .49757 L
.49847 .49758 L
.49897 .49768 L
.49944 .49786 L
.49985 .49809 L
.50021 .49837 L
.5005 .49866 L
.50072 .49896 L
.50088 .49926 L
.50097 .49953 L
.50102 .49978 L
.50101 .5 L
.50097 .50019 L
.50089 .50033 L
.50079 .50044 L
.50068 .50052 L
.50055 .50056 L
.50043 .50057 L
.5003 .50056 L
.50019 .50053 L
.50008 .50048 L
.49999 .50042 L
.49992 .50035 L
.49986 .50028 L
.49981 .50021 L
.49978 .50014 L
.49976 .50008 L
.49976 .50003 L
.49977 .49998 L
.49978 .49994 L
.4998 .49991 L
.49983 .49989 L
.49985 .49987 L
.49988 .49987 L
.49991 .49987 L
.49994 .49987 L
.49997 .49988 L
.49999 .49989 L
.50001 .49991 L
.50003 .49992 L
.50004 .49994 L
.50005 .49996 L
.50005 .49997 L
.50006 .49999 L
.50006 .5 L
.50005 .50001 L
.50005 .50002 L
Mistroke
.50004 .50002 L
.50004 .50003 L
.50003 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50003 L
.5 .50002 L
.5 .50002 L
.49999 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.884 1 0 r
.69092 .42152 m
.69693 .46863 L
.69411 .50943 L
.68398 .54331 L
.66812 .57001 L
.64808 .58963 L
.62533 .60251 L
.60123 .60922 L
.57695 .61049 L
.55348 .60714 L
.53165 .60004 L
.51206 .59008 L
.49513 .57812 L
.48111 .56495 L
.4701 .5513 L
.46205 .53779 L
.45681 .52494 L
.45414 .51315 L
.45373 .50273 L
.45524 .49388 L
.4583 .48669 L
.46253 .48118 L
.46758 .47732 L
.47312 .47498 L
.47884 .47401 L
.48449 .47424 L
.48986 .47547 L
.49476 .47748 L
.49909 .48006 L
.50276 .48303 L
.50573 .4862 L
.508 .48942 L
.50958 .49254 L
.51052 .49545 L
.5109 .49809 L
.51077 .50037 L
.51024 .50228 L
.50938 .50378 L
.50828 .5049 L
.50703 .50564 L
.5057 .50603 L
.50436 .50612 L
.50305 .50595 L
.50184 .50557 L
.50074 .50503 L
.49979 .50438 L
.499 .50365 L
.49838 .50289 L
.49793 .50215 L
.49762 .50143 L
Mistroke
.49747 .50077 L
.49744 .50019 L
.49751 .49969 L
.49768 .49929 L
.49791 .49898 L
.49818 .49876 L
.49849 .49862 L
.49881 .49856 L
.49912 .49857 L
.49942 .49864 L
.49969 .49874 L
.49993 .49889 L
.50014 .49905 L
.50031 .49922 L
.50044 .4994 L
.50053 .49957 L
.50058 .49974 L
.5006 .49988 L
.5006 .50001 L
.50057 .50012 L
.50052 .5002 L
.50046 .50027 L
.50039 .50031 L
.50032 .50033 L
.50025 .50034 L
.50017 .50033 L
.50011 .50031 L
.50005 .50028 L
.49999 .50025 L
.49995 .50021 L
.49991 .50016 L
.49989 .50012 L
.49987 .50008 L
.49986 .50005 L
.49986 .50001 L
.49986 .49998 L
.49987 .49996 L
.49988 .49994 L
.4999 .49993 L
.49992 .49992 L
.49993 .49992 L
.49995 .49992 L
.49997 .49992 L
.49998 .49993 L
.5 .49994 L
.50001 .49995 L
.50002 .49996 L
.50002 .49997 L
.50003 .49998 L
.50003 .49998 L
Mistroke
.50003 .49999 L
.50003 .5 L
.50003 .50001 L
.50003 .50001 L
.50003 .50001 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .716 0 r
.47289 .73736 m
.43084 .69511 L
.3983 .65184 L
.37505 .60945 L
.36053 .56949 L
.35392 .53316 L
.35421 .50134 L
.36028 .47458 L
.37097 .45312 L
.3851 .43699 L
.40156 .42597 L
.41931 .41967 L
.43744 .4176 L
.45516 .41916 L
.47183 .4237 L
.48695 .43056 L
.50016 .4391 L
.51125 .4487 L
.5201 .45881 L
.52673 .46895 L
.53123 .4787 L
.53376 .48774 L
.53453 .49581 L
.53379 .50276 L
.53183 .50848 L
.5289 .51294 L
.52529 .51617 L
.52125 .51824 L
.51701 .51924 L
.51276 .51931 L
.50869 .5186 L
.50493 .51726 L
.50157 .51545 L
.49869 .5133 L
.49632 .51097 L
.49448 .50858 L
.49316 .50623 L
.49232 .504 L
.49193 .50197 L
.49192 .50019 L
.49223 .49869 L
.49281 .49748 L
.49358 .49657 L
.49448 .49594 L
.49546 .49557 L
.49646 .49544 L
.49745 .49551 L
.49838 .49575 L
.49922 .49612 L
.49996 .49659 L
Mistroke
.50058 .49712 L
.50108 .49768 L
.50146 .49824 L
.50171 .49878 L
.50186 .49929 L
.50191 .49974 L
.50188 .50013 L
.50177 .50045 L
.50161 .5007 L
.50142 .50088 L
.50119 .501 L
.50096 .50106 L
.50072 .50107 L
.5005 .50103 L
.50029 .50096 L
.5001 .50086 L
.49994 .50075 L
.4998 .50062 L
.4997 .50048 L
.49963 .50035 L
.49958 .50023 L
.49955 .50012 L
.49955 .50002 L
.49957 .49993 L
.4996 .49986 L
.49964 .49981 L
.49969 .49978 L
.49974 .49976 L
.4998 .49975 L
.49985 .49975 L
.49991 .49976 L
.49995 .49978 L
.5 .49981 L
.50003 .49984 L
.50006 .49987 L
.50008 .4999 L
.50009 .49993 L
.5001 .49996 L
.50011 .49998 L
.5001 .50001 L
.5001 .50002 L
.50009 .50004 L
.50008 .50005 L
.50007 .50006 L
.50005 .50006 L
.50004 .50006 L
.50003 .50006 L
.50002 .50005 L
.50001 .50005 L
.5 .50004 L
Mistroke
.49999 .50003 L
.49998 .50003 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .928 r
.29076 .25239 m
.34493 .2532 L
.39661 .26375 L
.44412 .28205 L
.48624 .30613 L
.52215 .3341 L
.5514 .36421 L
.57391 .39492 L
.58985 .4249 L
.59963 .45307 L
.60386 .47859 L
.60326 .50087 L
.59862 .51954 L
.59079 .53444 L
.58058 .54556 L
.56879 .55308 L
.55614 .55726 L
.54328 .55849 L
.53075 .55718 L
.519 .55379 L
.50838 .5488 L
.49913 .54265 L
.4914 .53579 L
.48525 .5286 L
.48068 .52142 L
.47762 .51453 L
.47594 .50817 L
.4755 .5025 L
.4761 .49765 L
.47757 .49366 L
.47969 .49057 L
.48229 .48836 L
.48518 .48696 L
.4882 .48631 L
.4912 .48631 L
.49408 .48686 L
.49673 .48785 L
.49908 .48916 L
.50109 .4907 L
.50274 .49236 L
.50401 .49406 L
.50492 .49572 L
.50549 .49729 L
.50574 .49872 L
.50573 .49997 L
.50549 .50101 L
.50506 .50185 L
.50451 .50248 L
.50386 .50291 L
.50316 .50316 L
Mistroke
.50245 .50324 L
.50175 .50317 L
.5011 .50299 L
.5005 .50272 L
.49999 .50239 L
.49955 .50201 L
.49921 .50161 L
.49895 .50121 L
.49877 .50083 L
.49867 .50048 L
.49864 .50016 L
.49867 .49989 L
.49875 .49966 L
.49887 .49949 L
.49901 .49936 L
.49917 .49928 L
.49933 .49924 L
.4995 .49924 L
.49966 .49927 L
.49981 .49932 L
.49994 .49939 L
.50005 .49948 L
.50015 .49957 L
.50022 .49966 L
.50027 .49976 L
.5003 .49984 L
.50032 .49992 L
.50032 .49999 L
.50031 .50005 L
.50028 .5001 L
.50025 .50014 L
.50022 .50016 L
.50018 .50017 L
.50014 .50018 L
.5001 .50018 L
.50006 .50017 L
.50003 .50015 L
.5 .50013 L
.49998 .50011 L
.49996 .50009 L
.49994 .50007 L
.49993 .50005 L
.49993 .50003 L
.49992 .50001 L
.49993 .49999 L
.49993 .49998 L
.49994 .49997 L
.49994 .49997 L
.49995 .49996 L
.49996 .49996 L
Mistroke
.49997 .49996 L
.49998 .49996 L
.49999 .49996 L
.5 .49997 L
.5 .49997 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .255 0 r
.82161 .45241 m
.81634 .51847 L
.79926 .57319 L
.77296 .61619 L
.73996 .64765 L
.70267 .66815 L
.66326 .67863 L
.62365 .68029 L
.58545 .67447 L
.54996 .66261 L
.51818 .64615 L
.49077 .62649 L
.46813 .60493 L
.4504 .58263 L
.4375 .56061 L
.42917 .5397 L
.42501 .52056 L
.42452 .50367 L
.42712 .48934 L
.43222 .47774 L
.43921 .4689 L
.44751 .46271 L
.45658 .45901 L
.46593 .45755 L
.47514 .45802 L
.48386 .46009 L
.49183 .46342 L
.49885 .46768 L
.50479 .47255 L
.50958 .47774 L
.51322 .48298 L
.51574 .48806 L
.51724 .49281 L
.5178 .49708 L
.51756 .50078 L
.51666 .50385 L
.51523 .50628 L
.51343 .50807 L
.51138 .50925 L
.5092 .50987 L
.507 .50999 L
.50488 .50969 L
.5029 .50906 L
.50113 .50816 L
.49959 .50709 L
.49832 .5059 L
.49732 .50466 L
.49658 .50344 L
.4961 .50228 L
.49586 .50121 L
Mistroke
.49582 .50027 L
.49595 .49946 L
.49622 .49881 L
.4966 .49831 L
.49706 .49796 L
.49756 .49774 L
.49808 .49765 L
.49859 .49767 L
.49907 .49778 L
.49952 .49796 L
.49991 .49819 L
.50024 .49846 L
.50051 .49875 L
.50072 .49904 L
.50086 .49932 L
.50095 .49958 L
.50098 .49982 L
.50097 .50003 L
.50093 .5002 L
.50085 .50034 L
.50075 .50044 L
.50064 .50051 L
.50052 .50054 L
.5004 .50055 L
.50028 .50054 L
.50017 .5005 L
.50007 .50046 L
.49998 .5004 L
.49991 .50033 L
.49985 .50026 L
.49981 .5002 L
.49979 .50013 L
.49977 .50007 L
.49977 .50002 L
.49977 .49997 L
.49979 .49994 L
.49981 .49991 L
.49984 .49989 L
.49986 .49988 L
.49989 .49987 L
.49992 .49987 L
.49995 .49988 L
.49997 .49989 L
.49999 .4999 L
.50001 .49991 L
.50003 .49993 L
.50004 .49995 L
.50005 .49996 L
.50005 .49998 L
.50005 .49999 L
Mistroke
.50005 .5 L
.50005 .50001 L
.50005 .50002 L
.50004 .50002 L
.50004 .50003 L
.50003 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.5 .50003 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .298 1 r
.55622 .65577 m
.52541 .64153 L
.49853 .62391 L
.47602 .60416 L
.45809 .58342 L
.44471 .56268 L
.43569 .54275 L
.43069 .52432 L
.42927 .50787 L
.4309 .49375 L
.43503 .48215 L
.4411 .47312 L
.44855 .46662 L
.45686 .46249 L
.46556 .46053 L
.47424 .46046 L
.48256 .46198 L
.49024 .46478 L
.49708 .46854 L
.50294 .47295 L
.50773 .47774 L
.51145 .48265 L
.51412 .48746 L
.51579 .492 L
.51656 .49614 L
.51655 .49976 L
.51587 .50281 L
.51467 .50526 L
.51308 .50711 L
.51122 .50837 L
.50921 .5091 L
.50715 .50935 L
.50514 .50918 L
.50324 .50867 L
.50152 .5079 L
.50002 .50694 L
.49875 .50585 L
.49774 .5047 L
.49698 .50355 L
.49647 .50244 L
.49618 .50142 L
.49608 .5005 L
.49616 .49971 L
.49638 .49905 L
.49671 .49854 L
.49712 .49817 L
.49758 .49794 L
.49806 .49782 L
.49854 .49781 L
.499 .49789 L
Mistroke
.49943 .49804 L
.49981 .49824 L
.50014 .49848 L
.50041 .49875 L
.50062 .49902 L
.50077 .49929 L
.50087 .49954 L
.50092 .49977 L
.50092 .49997 L
.50088 .50014 L
.50082 .50028 L
.50073 .50039 L
.50063 .50046 L
.50052 .5005 L
.5004 .50052 L
.50029 .50051 L
.50019 .50048 L
.50009 .50044 L
.50001 .50039 L
.49994 .50033 L
.49988 .50026 L
.49984 .5002 L
.49981 .50014 L
.49979 .50008 L
.49978 .50003 L
.49979 .49999 L
.4998 .49995 L
.49982 .49992 L
.49984 .4999 L
.49986 .49989 L
.49989 .49988 L
.49992 .49988 L
.49994 .49988 L
.49997 .49989 L
.49999 .4999 L
.50001 .49992 L
.50002 .49993 L
.50003 .49994 L
.50004 .49996 L
.50005 .49997 L
.50005 .49999 L
.50005 .5 L
.50005 .50001 L
.50005 .50002 L
.50004 .50002 L
.50004 .50003 L
.50003 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
Mistroke
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .706 r
.33993 .82915 m
.28691 .74826 L
.25093 .67042 L
.23069 .59827 L
.22446 .53377 L
.23025 .47827 L
.2459 .43256 L
.2692 .39688 L
.29799 .37105 L
.33024 .35452 L
.36409 .34647 L
.39795 .34585 L
.43045 .35149 L
.46051 .36216 L
.48733 .37664 L
.51035 .39372 L
.52926 .41231 L
.54396 .43143 L
.55455 .45021 L
.56125 .46797 L
.56443 .48416 L
.56452 .49839 L
.56202 .51039 L
.55744 .52006 L
.55129 .52737 L
.54409 .53241 L
.53627 .53534 L
.52826 .53639 L
.52041 .53582 L
.513 .53391 L
.50626 .53095 L
.50035 .52722 L
.49538 .52301 L
.49139 .51855 L
.48838 .51406 L
.48632 .50974 L
.48514 .50572 L
.48475 .50211 L
.48502 .499 L
.48585 .49643 L
.48712 .49441 L
.48869 .49295 L
.49047 .492 L
.49234 .49152 L
.49422 .49146 L
.49602 .49175 L
.4977 .49232 L
.4992 .49311 L
.50049 .49404 L
.50155 .49507 L
Mistroke
.50238 .49613 L
.50299 .49717 L
.50337 .49816 L
.50356 .49906 L
.50358 .49986 L
.50345 .50053 L
.5032 .50108 L
.50287 .50149 L
.50247 .50178 L
.50204 .50195 L
.5016 .50201 L
.50116 .50199 L
.50075 .50189 L
.50037 .50173 L
.50004 .50152 L
.49976 .50129 L
.49954 .50104 L
.49937 .5008 L
.49925 .50056 L
.49918 .50033 L
.49916 .50013 L
.49917 .49996 L
.49921 .49981 L
.49928 .4997 L
.49937 .49961 L
.49946 .49956 L
.49957 .49953 L
.49967 .49953 L
.49977 .49954 L
.49987 .49957 L
.49995 .49961 L
.50002 .49967 L
.50008 .49972 L
.50013 .49978 L
.50016 .49984 L
.50019 .49989 L
.5002 .49994 L
.5002 .49999 L
.50019 .50003 L
.50018 .50006 L
.50016 .50008 L
.50014 .5001 L
.50011 .50011 L
.50009 .50011 L
.50007 .50011 L
.50004 .50011 L
.50002 .5001 L
.5 .50009 L
.49999 .50007 L
.49998 .50006 L
Mistroke
.49997 .50005 L
.49996 .50003 L
.49995 .50002 L
.49995 .50001 L
.49995 .5 L
.49996 .49999 L
.49996 .49998 L
.49996 .49998 L
.49997 .49998 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .709 r
.52338 .68512 m
.48865 .66028 L
.45995 .63302 L
.43746 .60481 L
.42108 .57695 L
.41048 .55048 L
.40517 .52624 L
.4045 .50484 L
.40776 .48668 L
.41418 .47198 L
.42301 .46075 L
.43349 .4529 L
.44496 .44819 L
.45678 .4463 L
.46843 .44687 L
.47948 .44947 L
.48957 .45368 L
.49846 .45906 L
.50598 .46521 L
.51206 .47177 L
.51668 .47841 L
.51989 .48484 L
.52179 .49084 L
.52251 .49625 L
.52222 .50094 L
.52108 .50484 L
.51929 .50792 L
.51701 .51019 L
.51442 .51169 L
.51166 .51247 L
.50889 .51264 L
.5062 .51227 L
.5037 .51147 L
.50145 .51034 L
.4995 .50898 L
.49789 .50748 L
.49662 .50592 L
.49568 .50437 L
.49508 .5029 L
.49476 .50154 L
.49471 .50035 L
.49487 .49933 L
.49522 .4985 L
.4957 .49787 L
.49627 .49742 L
.49691 .49714 L
.49756 .49703 L
.49821 .49705 L
.49882 .49719 L
.49938 .49742 L
Mistroke
.49988 .49771 L
.5003 .49805 L
.50065 .49841 L
.50091 .49878 L
.50109 .49914 L
.5012 .49947 L
.50125 .49977 L
.50123 .50003 L
.50117 .50025 L
.50108 .50043 L
.50095 .50056 L
.50081 .50064 L
.50066 .50069 L
.5005 .5007 L
.50035 .50068 L
.50021 .50064 L
.50009 .50058 L
.49998 .5005 L
.49989 .50042 L
.49982 .50033 L
.49976 .50025 L
.49973 .50017 L
.49971 .50009 L
.49971 .50002 L
.49972 .49997 L
.49973 .49992 L
.49976 .49988 L
.49979 .49986 L
.49983 .49984 L
.49986 .49984 L
.4999 .49984 L
.49993 .49984 L
.49996 .49986 L
.49999 .49987 L
.50002 .49989 L
.50003 .49991 L
.50005 .49993 L
.50006 .49995 L
.50007 .49997 L
.50007 .49999 L
.50007 .5 L
.50007 .50001 L
.50006 .50002 L
.50005 .50003 L
.50005 .50004 L
.50004 .50004 L
.50003 .50004 L
.50002 .50004 L
.50001 .50004 L
.50001 .50003 L
Mistroke
.5 .50003 L
.49999 .50002 L
.49999 .50002 L
.49999 .50001 L
.49999 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .635 1 r
.69991 .60301 m
.67248 .62323 L
.64256 .63528 L
.61174 .63998 L
.5814 .63833 L
.55267 .63141 L
.52646 .62035 L
.50339 .60625 L
.48389 .59017 L
.46816 .57306 L
.45623 .55578 L
.44797 .53904 L
.44312 .52343 L
.44132 .50938 L
.44215 .49722 L
.44517 .48712 L
.44989 .47916 L
.45586 .4733 L
.46263 .46946 L
.46982 .46745 L
.47705 .46707 L
.48404 .46807 L
.49055 .47018 L
.49639 .47315 L
.50144 .47671 L
.50562 .48063 L
.5089 .4847 L
.5113 .48873 L
.51287 .49256 L
.51366 .49607 L
.51379 .49918 L
.51334 .50182 L
.51243 .50396 L
.51117 .5056 L
.50966 .50676 L
.50801 .50746 L
.50631 .50774 L
.50463 .50768 L
.50303 .50731 L
.50156 .50671 L
.50027 .50594 L
.49918 .50506 L
.49829 .50411 L
.49762 .50316 L
.49715 .50223 L
.49686 .50136 L
.49675 .50057 L
.49679 .49989 L
.49695 .49932 L
.4972 .49887 L
Mistroke
.49753 .49854 L
.4979 .49832 L
.4983 .4982 L
.4987 .49818 L
.49909 .49823 L
.49945 .49834 L
.49978 .4985 L
.50006 .4987 L
.5003 .49891 L
.50048 .49914 L
.50062 .49936 L
.50071 .49957 L
.50075 .49977 L
.50076 .49994 L
.50074 .50009 L
.50069 .50021 L
.50062 .5003 L
.50054 .50037 L
.50045 .50041 L
.50036 .50043 L
.50026 .50043 L
.50017 .50041 L
.50009 .50037 L
.50002 .50033 L
.49996 .50028 L
.49991 .50023 L
.49987 .50018 L
.49984 .50013 L
.49983 .50008 L
.49982 .50003 L
.49982 .5 L
.49983 .49996 L
.49984 .49994 L
.49986 .49992 L
.49988 .49991 L
.4999 .4999 L
.49993 .4999 L
.49995 .4999 L
.49997 .49991 L
.49999 .49992 L
.5 .49993 L
.50002 .49994 L
.50003 .49995 L
.50003 .49996 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .5 L
.50004 .50001 L
.50003 .50002 L
Mistroke
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .753 r
.36043 .79038 m
.31359 .71931 L
.28172 .65089 L
.2637 .58741 L
.25802 .53063 L
.26293 .48174 L
.27653 .44143 L
.29689 .40994 L
.3221 .3871 L
.35037 .37244 L
.38009 .36524 L
.40984 .36458 L
.43841 .36944 L
.46486 .37875 L
.48847 .39141 L
.50875 .40638 L
.52542 .42269 L
.5384 .43947 L
.54776 .45598 L
.55371 .4716 L
.55656 .48585 L
.55668 .49837 L
.55452 .50895 L
.55053 .51748 L
.54516 .52393 L
.53884 .5284 L
.53198 .53101 L
.52495 .53196 L
.51805 .53148 L
.51153 .52982 L
.5056 .52723 L
.5004 .52397 L
.49601 .52028 L
.49249 .51636 L
.48984 .51242 L
.48802 .50862 L
.48697 .50508 L
.4866 .50191 L
.48684 .49917 L
.48756 .4969 L
.48866 .49512 L
.49004 .49382 L
.4916 .49298 L
.49324 .49255 L
.49489 .49249 L
.49648 .49274 L
.49795 .49324 L
.49927 .49393 L
.50041 .49475 L
.50135 .49565 L
Mistroke
.50208 .49658 L
.50261 .4975 L
.50296 .49837 L
.50313 .49916 L
.50314 .49986 L
.50303 .50046 L
.50282 .50094 L
.50252 .5013 L
.50218 .50156 L
.5018 .50171 L
.50141 .50177 L
.50103 .50175 L
.50066 .50166 L
.50033 .50152 L
.50004 .50134 L
.4998 .50114 L
.4996 .50092 L
.49945 .5007 L
.49934 .50049 L
.49928 .50029 L
.49926 .50012 L
.49927 .49996 L
.49931 .49984 L
.49937 .49974 L
.49944 .49966 L
.49953 .49961 L
.49962 .49959 L
.49971 .49958 L
.4998 .4996 L
.49988 .49962 L
.49995 .49966 L
.50002 .49971 L
.50007 .49976 L
.50011 .49981 L
.50014 .49986 L
.50016 .49991 L
.50017 .49995 L
.50017 .49999 L
.50017 .50002 L
.50016 .50005 L
.50014 .50007 L
.50012 .50009 L
.5001 .50009 L
.50008 .5001 L
.50006 .5001 L
.50004 .50009 L
.50002 .50008 L
.5 .50008 L
.49999 .50006 L
.49998 .50005 L
Mistroke
.49997 .50004 L
.49996 .50003 L
.49996 .50002 L
.49996 .50001 L
.49996 .5 L
.49996 .49999 L
.49996 .49999 L
.49997 .49998 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .037 r
.2068 .80657 m
.16367 .70497 L
.14092 .61149 L
.13617 .52856 L
.14674 .45781 L
.16974 .40009 L
.20225 .35564 L
.24145 .3241 L
.2847 .30466 L
.32961 .29615 L
.37413 .29715 L
.41653 .30611 L
.45546 .32138 L
.48993 .34135 L
.51926 .36445 L
.54312 .38927 L
.56142 .41453 L
.57432 .43915 L
.58219 .46225 L
.5855 .48315 L
.58486 .50137 L
.58093 .51662 L
.5744 .52874 L
.56594 .53778 L
.5562 .54385 L
.54578 .54719 L
.5352 .54811 L
.52491 .54696 L
.51527 .54412 L
.50658 .53996 L
.49901 .53488 L
.4927 .52922 L
.4877 .52329 L
.48399 .51739 L
.48151 .51174 L
.48018 .50653 L
.47985 .50189 L
.48037 .49792 L
.4816 .49468 L
.48337 .49216 L
.48552 .49036 L
.4879 .48924 L
.49039 .48873 L
.49286 .48875 L
.49521 .48922 L
.49739 .49004 L
.49931 .49113 L
.50096 .4924 L
.5023 .49377 L
.50334 .49517 L
Mistroke
.50407 .49653 L
.50453 .49782 L
.50473 .49899 L
.50471 .50001 L
.5045 .50086 L
.50415 .50155 L
.50369 .50206 L
.50315 .50241 L
.50258 .5026 L
.50199 .50266 L
.50142 .50261 L
.50088 .50246 L
.5004 .50223 L
.49997 .50195 L
.49962 .50164 L
.49934 .50131 L
.49913 .50099 L
.49898 .50067 L
.49891 .50038 L
.49888 .50012 L
.49891 .4999 L
.49898 .49972 L
.49907 .49957 L
.49919 .49947 L
.49932 .49941 L
.49946 .49938 L
.49959 .49938 L
.49973 .4994 L
.49985 .49944 L
.49995 .4995 L
.50005 .49957 L
.50012 .49965 L
.50018 .49973 L
.50022 .4998 L
.50025 .49987 L
.50026 .49994 L
.50026 .5 L
.50025 .50004 L
.50023 .50008 L
.50021 .50011 L
.50018 .50013 L
.50014 .50014 L
.50011 .50015 L
.50008 .50014 L
.50005 .50014 L
.50002 .50012 L
.5 .50011 L
.49998 .50009 L
.49996 .50007 L
.49995 .50006 L
Mistroke
.49994 .50004 L
.49994 .50002 L
.49994 .50001 L
.49994 .5 L
.49994 .49998 L
.49995 .49998 L
.49995 .49997 L
.49996 .49997 L
.49997 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.5 .49997 L
.5 .49998 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.214 1 0 r
.62287 .47106 m
.62281 .49798 L
.61786 .52067 L
.60898 .53889 L
.59718 .55263 L
.58338 .56205 L
.56846 .56749 L
.5532 .56935 L
.53826 .56814 L
.52419 .5644 L
.51142 .55868 L
.50023 .55154 L
.49084 .54348 L
.48331 .53498 L
.47767 .52644 L
.47382 .51821 L
.47164 .51058 L
.47094 .50375 L
.47151 .49787 L
.47314 .49302 L
.47557 .48922 L
.4786 .48647 L
.48199 .48469 L
.48556 .48382 L
.48913 .48373 L
.49256 .48431 L
.49574 .48542 L
.49858 .48694 L
.50103 .48873 L
.50303 .49069 L
.5046 .49271 L
.50573 .49469 L
.50645 .49657 L
.50679 .49828 L
.50681 .49979 L
.50655 .50106 L
.50608 .50209 L
.50543 .50287 L
.50467 .50341 L
.50385 .50372 L
.50301 .50384 L
.50218 .50378 L
.50139 .50358 L
.50068 .50327 L
.50005 .50288 L
.49953 .50244 L
.4991 .50197 L
.49878 .5015 L
.49856 .50104 L
.49844 .50062 L
Mistroke
.49839 .50023 L
.49842 .4999 L
.4985 .49963 L
.49864 .49942 L
.4988 .49926 L
.49899 .49916 L
.49919 .49911 L
.49938 .4991 L
.49957 .49913 L
.49975 .49919 L
.49991 .49927 L
.50005 .49937 L
.50016 .49948 L
.50025 .49959 L
.50031 .4997 L
.50035 .4998 L
.50038 .4999 L
.50038 .49998 L
.50036 .50005 L
.50034 .50011 L
.5003 .50016 L
.50026 .50019 L
.50022 .50021 L
.50017 .50021 L
.50012 .50021 L
.50008 .5002 L
.50004 .50018 L
.50001 .50016 L
.49998 .50014 L
.49995 .50011 L
.49993 .50008 L
.49992 .50006 L
.49991 .50004 L
.49991 .50001 L
.49991 .5 L
.49992 .49998 L
.49992 .49997 L
.49993 .49996 L
.49994 .49995 L
.49995 .49995 L
.49997 .49995 L
.49998 .49995 L
.49999 .49995 L
.49999 .49996 L
.5 .49996 L
.50001 .49997 L
.50001 .49998 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
Mistroke
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .506 1 r
.51936 .28906 m
.55694 .32575 L
.58621 .36351 L
.60734 .40067 L
.62078 .43583 L
.62723 .46792 L
.62756 .49613 L
.62273 .51998 L
.61378 .53919 L
.60171 .55375 L
.58751 .56383 L
.57209 .56973 L
.55626 .5719 L
.54072 .57085 L
.52606 .56713 L
.5127 .56132 L
.50098 .554 L
.4911 .54569 L
.48316 .53689 L
.47718 .52802 L
.47306 .51946 L
.47068 .51149 L
.46986 .50435 L
.47038 .49817 L
.47199 .49307 L
.47447 .48905 L
.47757 .48612 L
.48107 .48422 L
.48476 .48325 L
.48848 .48311 L
.49205 .48367 L
.49537 .48479 L
.49834 .48633 L
.5009 .48818 L
.50302 .4902 L
.50467 .49229 L
.50587 .49435 L
.50665 .49631 L
.50703 .4981 L
.50707 .49968 L
.50682 .50102 L
.50634 .5021 L
.50568 .50293 L
.5049 .5035 L
.50405 .50384 L
.50318 .50398 L
.50232 .50393 L
.5015 .50374 L
.50075 .50342 L
.5001 .50302 L
Mistroke
.49954 .50256 L
.4991 .50208 L
.49876 .50159 L
.49852 .50111 L
.49838 .50067 L
.49833 .50027 L
.49836 .49992 L
.49844 .49963 L
.49858 .49941 L
.49874 .49924 L
.49894 .49913 L
.49914 .49908 L
.49935 .49906 L
.49955 .49909 L
.49973 .49915 L
.4999 .49924 L
.50004 .49934 L
.50016 .49945 L
.50025 .49956 L
.50032 .49968 L
.50037 .49979 L
.50039 .49989 L
.50039 .49998 L
.50038 .50005 L
.50035 .50011 L
.50032 .50016 L
.50027 .50019 L
.50023 .50021 L
.50018 .50022 L
.50013 .50022 L
.50009 .50021 L
.50004 .50019 L
.50001 .50017 L
.49998 .50014 L
.49995 .50012 L
.49993 .50009 L
.49992 .50006 L
.49991 .50004 L
.49991 .50002 L
.49991 .5 L
.49991 .49998 L
.49992 .49997 L
.49993 .49996 L
.49994 .49995 L
.49995 .49995 L
.49996 .49995 L
.49997 .49995 L
.49998 .49995 L
.49999 .49996 L
.5 .49996 L
Mistroke
.50001 .49997 L
.50001 .49998 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.823 1 0 r
.43318 .6642 m
.40617 .62622 L
.38724 .58929 L
.37587 .55472 L
.37128 .52351 L
.37258 .49637 L
.37877 .47373 L
.38881 .45578 L
.40168 .44247 L
.41642 .43361 L
.43214 .42882 L
.44804 .42765 L
.46347 .42956 L
.47789 .43398 L
.49087 .44033 L
.50214 .44804 L
.51151 .4566 L
.51891 .46552 L
.52437 .47438 L
.52798 .48285 L
.52989 .49064 L
.5303 .49756 L
.52943 .50346 L
.52753 .50828 L
.52483 .51199 L
.52157 .51463 L
.51797 .51626 L
.51423 .51697 L
.51052 .5169 L
.50698 .51616 L
.50374 .51489 L
.50086 .51323 L
.49842 .51131 L
.49643 .50924 L
.4949 .50714 L
.49382 .50509 L
.49316 .50316 L
.49288 .50142 L
.49293 .4999 L
.49326 .49863 L
.4938 .49761 L
.4945 .49686 L
.49531 .49635 L
.49618 .49607 L
.49706 .49599 L
.49792 .49609 L
.49872 .49632 L
.49945 .49667 L
.50008 .49709 L
.5006 .49756 L
Mistroke
.50102 .49806 L
.50133 .49855 L
.50154 .49902 L
.50165 .49945 L
.50168 .49984 L
.50164 .50017 L
.50153 .50044 L
.50139 .50065 L
.50121 .5008 L
.50101 .5009 L
.5008 .50094 L
.5006 .50094 L
.5004 .5009 L
.50022 .50083 L
.50006 .50074 L
.49992 .50063 L
.49981 .50052 L
.49972 .5004 L
.49966 .50029 L
.49962 .50018 L
.49961 .50009 L
.49961 .5 L
.49962 .49993 L
.49965 .49987 L
.49969 .49983 L
.49974 .4998 L
.49978 .49978 L
.49983 .49978 L
.49988 .49978 L
.49993 .4998 L
.49997 .49981 L
.5 .49984 L
.50003 .49986 L
.50006 .49989 L
.50007 .49992 L
.50008 .49994 L
.50009 .49997 L
.50009 .49999 L
.50009 .50001 L
.50009 .50002 L
.50008 .50004 L
.50007 .50004 L
.50006 .50005 L
.50005 .50005 L
.50003 .50005 L
.50002 .50005 L
.50001 .50005 L
.5 .50004 L
.5 .50004 L
.49999 .50003 L
Mistroke
.49998 .50002 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .947 r
.51539 .54839 m
.5059 .54359 L
.49771 .53781 L
.49092 .53145 L
.48559 .52485 L
.48168 .51832 L
.47914 .51211 L
.47784 .5064 L
.47763 .50136 L
.47836 .49707 L
.47983 .49359 L
.48187 .49092 L
.48431 .48905 L
.48698 .48791 L
.48975 .48744 L
.49248 .48755 L
.49508 .48814 L
.49745 .4891 L
.49955 .49035 L
.50132 .49179 L
.50276 .49332 L
.50386 .49487 L
.50463 .49638 L
.50508 .49779 L
.50527 .49906 L
.50521 .50017 L
.50495 .50109 L
.50454 .50182 L
.50401 .50236 L
.5034 .50272 L
.50276 .50291 L
.50211 .50296 L
.50148 .50288 L
.50089 .5027 L
.50036 .50243 L
.4999 .50212 L
.49952 .50177 L
.49922 .5014 L
.499 .50104 L
.49885 .50069 L
.49878 .50038 L
.49876 .50009 L
.4988 .49985 L
.49888 .49966 L
.49899 .49951 L
.49912 .4994 L
.49927 .49933 L
.49942 .49931 L
.49957 .49931 L
.49972 .49934 L
Mistroke
.49985 .49939 L
.49997 .49946 L
.50007 .49954 L
.50015 .49962 L
.50021 .49971 L
.50025 .49979 L
.50028 .49987 L
.50029 .49994 L
.50029 .50001 L
.50028 .50006 L
.50025 .5001 L
.50022 .50013 L
.50019 .50015 L
.50016 .50016 L
.50012 .50016 L
.50008 .50016 L
.50005 .50015 L
.50002 .50014 L
.5 .50012 L
.49997 .5001 L
.49996 .50008 L
.49995 .50006 L
.49994 .50004 L
.49993 .50002 L
.49993 .50001 L
.49993 .49999 L
.49994 .49998 L
.49994 .49997 L
.49995 .49997 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49999 .49997 L
.5 .49997 L
.5 .49997 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
Mistroke
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .128 0 r
.43212 .57005 m
.42231 .54667 L
.41717 .52519 L
.41618 .50614 L
.41869 .48991 L
.42405 .47668 L
.43159 .46652 L
.44066 .45932 L
.45064 .4549 L
.46099 .453 L
.47124 .45328 L
.481 .45539 L
.48995 .45894 L
.49786 .46356 L
.50459 .4689 L
.51006 .47463 L
.51424 .48045 L
.51719 .48611 L
.51897 .49143 L
.51971 .49623 L
.51954 .50041 L
.51862 .50391 L
.5171 .50668 L
.51514 .50875 L
.51289 .51013 L
.51049 .51089 L
.50805 .51109 L
.50568 .51081 L
.50347 .51015 L
.50147 .50918 L
.49973 .50801 L
.49829 .5067 L
.49714 .50533 L
.49629 .50397 L
.49573 .50267 L
.49543 .50148 L
.49536 .50041 L
.49548 .4995 L
.49577 .49876 L
.49618 .49818 L
.49668 .49777 L
.49723 .49752 L
.4978 .4974 L
.49837 .49741 L
.49891 .49752 L
.49941 .49771 L
.49985 .49796 L
.50023 .49826 L
.50054 .49857 L
.50077 .49889 L
Mistroke
.50094 .49921 L
.50105 .4995 L
.50109 .49977 L
.50108 .50001 L
.50104 .5002 L
.50095 .50036 L
.50085 .50048 L
.50072 .50056 L
.50059 .5006 L
.50046 .50061 L
.50032 .5006 L
.5002 .50056 L
.50009 .50051 L
.49999 .50045 L
.49991 .50038 L
.49985 .5003 L
.4998 .50023 L
.49977 .50015 L
.49975 .50009 L
.49974 .50003 L
.49975 .49998 L
.49976 .49993 L
.49979 .4999 L
.49981 .49988 L
.49984 .49986 L
.49988 .49986 L
.49991 .49986 L
.49994 .49986 L
.49997 .49987 L
.49999 .49989 L
.50001 .4999 L
.50003 .49992 L
.50004 .49994 L
.50005 .49995 L
.50006 .49997 L
.50006 .49999 L
.50006 .5 L
.50006 .50001 L
.50005 .50002 L
.50005 .50003 L
.50004 .50003 L
.50003 .50003 L
.50003 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50003 L
.5 .50003 L
.5 .50002 L
.49999 .50002 L
.49999 .50001 L
Mistroke
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .861 r
.35165 .54341 m
.35017 .50956 L
.35493 .48077 L
.36472 .45737 L
.37835 .43943 L
.39465 .42679 L
.41255 .41911 L
.43108 .4159 L
.44938 .41656 L
.46678 .42046 L
.4827 .42691 L
.49677 .43525 L
.5087 .44484 L
.51837 .45509 L
.52575 .4655 L
.53092 .47561 L
.53402 .48508 L
.53527 .49362 L
.5349 .50105 L
.5332 .50724 L
.53044 .51215 L
.52691 .51578 L
.52287 .5182 L
.51856 .51951 L
.5142 .51982 L
.50998 .51929 L
.50603 .51808 L
.50248 .51633 L
.49939 .51422 L
.49683 .51187 L
.49481 .50943 L
.49331 .507 L
.49233 .50468 L
.49181 .50255 L
.4917 .50066 L
.49194 .49904 L
.49246 .49772 L
.4932 .49671 L
.4941 .49599 L
.49509 .49554 L
.49611 .49535 L
.49713 .49537 L
.49809 .49558 L
.49898 .49592 L
.49977 .49638 L
.50044 .49691 L
.50098 .49747 L
.5014 .49805 L
.5017 .49861 L
.50187 .49914 L
Mistroke
.50195 .49961 L
.50194 .50003 L
.50185 .50038 L
.5017 .50066 L
.5015 .50086 L
.50128 .501 L
.50104 .50108 L
.5008 .5011 L
.50057 .50107 L
.50035 .50101 L
.50015 .50091 L
.49998 .5008 L
.49983 .50067 L
.49972 .50053 L
.49963 .5004 L
.49958 .50027 L
.49955 .50015 L
.49954 .50004 L
.49955 .49995 L
.49958 .49988 L
.49962 .49982 L
.49967 .49978 L
.49972 .49975 L
.49978 .49974 L
.49984 .49974 L
.49989 .49975 L
.49994 .49977 L
.49998 .4998 L
.50002 .49983 L
.50005 .49986 L
.50008 .49989 L
.50009 .49992 L
.5001 .49995 L
.50011 .49998 L
.50011 .5 L
.5001 .50002 L
.50009 .50004 L
.50008 .50005 L
.50007 .50005 L
.50006 .50006 L
.50005 .50006 L
.50003 .50006 L
.50002 .50006 L
.50001 .50005 L
.5 .50004 L
.49999 .50004 L
.49998 .50003 L
.49998 .50002 L
.49998 .50002 L
.49998 .50001 L
Mistroke
.49997 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .709 r
.8005 .19601 m
.84284 .29853 L
.86468 .39264 L
.86842 .47594 L
.85684 .54683 L
.83284 .60446 L
.79938 .64867 L
.75933 .67983 L
.71533 .6988 L
.66979 .70677 L
.62477 .7052 L
.58198 .69567 L
.54279 .67984 L
.50818 .65937 L
.4788 .63581 L
.45498 .6106 L
.43679 .58501 L
.42404 .56014 L
.41638 .53685 L
.41329 .51583 L
.41417 .49754 L
.41834 .4823 L
.4251 .47021 L
.43377 .46125 L
.4437 .45528 L
.45429 .45205 L
.46501 .45126 L
.4754 .45255 L
.48511 .45553 L
.49385 .45981 L
.50144 .465 L
.50775 .47077 L
.51274 .47677 L
.51642 .48275 L
.51885 .48845 L
.52014 .4937 L
.52041 .49836 L
.51983 .50233 L
.51854 .50558 L
.51672 .50808 L
.51453 .50985 L
.5121 .51095 L
.50958 .51143 L
.50708 .51138 L
.5047 .51088 L
.50252 .51003 L
.50058 .50891 L
.49893 .50762 L
.49759 .50623 L
.49656 .50481 L
Mistroke
.49584 .50343 L
.49539 .50213 L
.4952 .50096 L
.49524 .49993 L
.49546 .49908 L
.49582 .49839 L
.4963 .49788 L
.49684 .49754 L
.49743 .49735 L
.49802 .4973 L
.4986 .49736 L
.49914 .49752 L
.49963 .49776 L
.50005 .49804 L
.50041 .49836 L
.50069 .49869 L
.5009 .49902 L
.50104 .49934 L
.50111 .49963 L
.50113 .49989 L
.5011 .50011 L
.50103 .5003 L
.50093 .50044 L
.50081 .50054 L
.50068 .5006 L
.50054 .50063 L
.5004 .50063 L
.50027 .50061 L
.50015 .50056 L
.50004 .5005 L
.49995 .50043 L
.49987 .50035 L
.49981 .50027 L
.49977 .5002 L
.49975 .50012 L
.49973 .50006 L
.49974 .5 L
.49975 .49995 L
.49977 .49991 L
.49979 .49988 L
.49982 .49987 L
.49986 .49985 L
.49989 .49985 L
.49992 .49985 L
.49995 .49986 L
.49998 .49987 L
.5 .49989 L
.50002 .49991 L
.50004 .49993 L
.50005 .49994 L
Mistroke
.50006 .49996 L
.50006 .49998 L
.50006 .49999 L
.50006 .50001 L
.50006 .50002 L
.50005 .50002 L
.50005 .50003 L
.50004 .50003 L
.50003 .50003 L
.50002 .50004 L
.50002 .50003 L
.50001 .50003 L
.5 .50003 L
.5 .50002 L
.49999 .50002 L
.49999 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .282 r
.52665 .6072 m
.50597 .5952 L
.48837 .58132 L
.47406 .56642 L
.46309 .55126 L
.45535 .53648 L
.45064 .52261 L
.44866 .51007 L
.44906 .49913 L
.45142 .48999 L
.45535 .48272 L
.46043 .4773 L
.46628 .47366 L
.47254 .47166 L
.47889 .47111 L
.48507 .47181 L
.49085 .47352 L
.49607 .47602 L
.50061 .47907 L
.5044 .48247 L
.5074 .48603 L
.50962 .48957 L
.5111 .49296 L
.5119 .49609 L
.5121 .49888 L
.51178 .50126 L
.51104 .5032 L
.50998 .50471 L
.50869 .50579 L
.50726 .50646 L
.50577 .50677 L
.50428 .50675 L
.50287 .50647 L
.50156 .50598 L
.50041 .50532 L
.49942 .50456 L
.49861 .50374 L
.49799 .5029 L
.49755 .50208 L
.49728 .50131 L
.49716 .5006 L
.49717 .49999 L
.4973 .49948 L
.49751 .49907 L
.49779 .49876 L
.49811 .49855 L
.49845 .49844 L
.49881 .4984 L
.49915 .49843 L
.49947 .49853 L
Mistroke
.49976 .49866 L
.50002 .49883 L
.50023 .49902 L
.5004 .49921 L
.50053 .49941 L
.50061 .4996 L
.50066 .49977 L
.50067 .49993 L
.50065 .50006 L
.50061 .50017 L
.50056 .50026 L
.50049 .50032 L
.50041 .50036 L
.50033 .50037 L
.50024 .50037 L
.50016 .50036 L
.50009 .50033 L
.50003 .5003 L
.49997 .50026 L
.49993 .50021 L
.49989 .50016 L
.49987 .50012 L
.49985 .50008 L
.49984 .50004 L
.49984 .5 L
.49985 .49997 L
.49986 .49995 L
.49988 .49993 L
.49989 .49992 L
.49991 .49991 L
.49993 .49991 L
.49995 .49991 L
.49997 .49992 L
.49999 .49993 L
.5 .49993 L
.50001 .49994 L
.50002 .49996 L
.50003 .49997 L
.50003 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .5 L
.50003 .50001 L
.50003 .50001 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
Mistroke
.5 .50002 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.592 1 0 r
.67038 .27193 m
.70454 .33881 L
.72503 .4014 L
.73324 .45789 L
.7308 .50699 L
.71952 .54793 L
.70127 .58038 L
.67791 .60441 L
.65118 .6204 L
.6227 .62901 L
.59388 .63108 L
.56593 .62758 L
.53984 .61953 L
.51634 .608 L
.49596 .594 L
.47901 .57849 L
.46563 .56233 L
.45576 .54627 L
.44925 .53094 L
.44582 .51683 L
.4451 .50432 L
.44669 .49364 L
.45016 .48493 L
.45507 .47822 L
.46098 .47346 L
.46751 .47053 L
.47428 .46924 L
.481 .46939 L
.4874 .47074 L
.49328 .47305 L
.49848 .47606 L
.5029 .47954 L
.5065 .48329 L
.50927 .4871 L
.51121 .49081 L
.5124 .4943 L
.5129 .49746 L
.51281 .50021 L
.51221 .50251 L
.51123 .50434 L
.50995 .5057 L
.50848 .50662 L
.50691 .50712 L
.50531 .50726 L
.50376 .50709 L
.50231 .50666 L
.50099 .50603 L
.49985 .50526 L
.4989 .50441 L
.49814 .50352 L
Mistroke
.49758 .50263 L
.49721 .50177 L
.49701 .50099 L
.49696 .50029 L
.49704 .49969 L
.49722 .4992 L
.49749 .49882 L
.49781 .49855 L
.49817 .49838 L
.49855 .4983 L
.49892 .4983 L
.49928 .49837 L
.49961 .4985 L
.4999 .49866 L
.50014 .49885 L
.50035 .49906 L
.5005 .49927 L
.50061 .49948 L
.50068 .49967 L
.50071 .49985 L
.50071 .5 L
.50068 .50013 L
.50063 .50023 L
.50056 .50031 L
.50048 .50036 L
.50039 .50039 L
.5003 .5004 L
.50021 .50039 L
.50013 .50037 L
.50006 .50034 L
.5 .50029 L
.49994 .50025 L
.4999 .5002 L
.49987 .50015 L
.49985 .5001 L
.49983 .50006 L
.49983 .50002 L
.49984 .49998 L
.49985 .49996 L
.49986 .49994 L
.49988 .49992 L
.4999 .49991 L
.49992 .49991 L
.49994 .49991 L
.49996 .49991 L
.49998 .49992 L
.49999 .49993 L
.50001 .49994 L
.50002 .49995 L
.50003 .49996 L
Mistroke
.50003 .49997 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50003 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.558 1 0 r
.34023 .37022 m
.37079 .36152 L
.40161 .35975 L
.43142 .36387 L
.45919 .37278 L
.48413 .38535 L
.5057 .40048 L
.52358 .41716 L
.53765 .43448 L
.54795 .45163 L
.55468 .46797 L
.55815 .48297 L
.55873 .49623 L
.55687 .50752 L
.55303 .5167 L
.54769 .52373 L
.5413 .52869 L
.53429 .5317 L
.52703 .53297 L
.51985 .53271 L
.51303 .53118 L
.50679 .52865 L
.50127 .52539 L
.4966 .52163 L
.4928 .51761 L
.48991 .51353 L
.48788 .50957 L
.48666 .50585 L
.48618 .50251 L
.48632 .49959 L
.48699 .49717 L
.48807 .49524 L
.48945 .49382 L
.49103 .49287 L
.49272 .49235 L
.49443 .49223 L
.49609 .49244 L
.49763 .49291 L
.49903 .4936 L
.50024 .49443 L
.50124 .49535 L
.50204 .4963 L
.50262 .49725 L
.50301 .49816 L
.50321 .499 L
.50325 .49974 L
.50316 .50038 L
.50295 .50089 L
.50266 .50129 L
.50231 .50157 L
Mistroke
.50193 .50175 L
.50153 .50182 L
.50113 .50181 L
.50075 .50173 L
.5004 .5016 L
.50009 .50142 L
.49983 .50121 L
.49962 .50099 L
.49945 .50077 L
.49934 .50055 L
.49927 .50034 L
.49924 .50015 L
.49924 .49999 L
.49928 .49985 L
.49933 .49974 L
.49941 .49966 L
.4995 .49961 L
.49959 .49958 L
.49968 .49957 L
.49978 .49958 L
.49986 .49961 L
.49994 .49964 L
.50001 .49969 L
.50007 .49974 L
.50011 .49979 L
.50014 .49984 L
.50017 .49989 L
.50018 .49994 L
.50018 .49998 L
.50018 .50002 L
.50016 .50005 L
.50015 .50007 L
.50013 .50009 L
.50011 .5001 L
.50009 .5001 L
.50006 .5001 L
.50004 .5001 L
.50002 .50009 L
.50001 .50008 L
.49999 .50007 L
.49998 .50006 L
.49997 .50004 L
.49996 .50003 L
.49996 .50002 L
.49996 .50001 L
.49996 .5 L
.49996 .49999 L
.49996 .49999 L
.49997 .49998 L
.49997 .49998 L
Mistroke
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .041 0 r
.4291 .51401 m
.42963 .49889 L
.43288 .48625 L
.43829 .47619 L
.4453 .46869 L
.45338 .46365 L
.46202 .46087 L
.47079 .4601 L
.47933 .46105 L
.48732 .46341 L
.49453 .46685 L
.50081 .47107 L
.50604 .47576 L
.51019 .48067 L
.51327 .48557 L
.51533 .49025 L
.51644 .49458 L
.51671 .49842 L
.51628 .50171 L
.51526 .50441 L
.51379 .5065 L
.51201 .50799 L
.51004 .50892 L
.50798 .50935 L
.50593 .50933 L
.50397 .50894 L
.50217 .50826 L
.50057 .50736 L
.49921 .50631 L
.49809 .50517 L
.49723 .50401 L
.49662 .50288 L
.49625 .50181 L
.49608 .50084 L
.4961 .49999 L
.49627 .49928 L
.49656 .49872 L
.49694 .49829 L
.49739 .498 L
.49786 .49784 L
.49835 .49779 L
.49882 .49784 L
.49927 .49796 L
.49967 .49815 L
.50002 .49838 L
.50032 .49864 L
.50055 .49891 L
.50072 .49918 L
.50084 .49944 L
.50091 .49968 L
Mistroke
.50093 .4999 L
.5009 .50008 L
.50085 .50023 L
.50077 .50035 L
.50067 .50044 L
.50056 .50049 L
.50045 .50052 L
.50034 .50052 L
.50023 .5005 L
.50013 .50046 L
.50004 .50041 L
.49996 .50035 L
.4999 .50029 L
.49985 .50023 L
.49982 .50016 L
.49979 .5001 L
.49978 .50005 L
.49978 .5 L
.49979 .49996 L
.49981 .49993 L
.49983 .49991 L
.49985 .49989 L
.49988 .49988 L
.49991 .49988 L
.49993 .49988 L
.49996 .49989 L
.49998 .4999 L
.5 .49991 L
.50002 .49992 L
.50003 .49994 L
.50004 .49995 L
.50005 .49997 L
.50005 .49998 L
.50005 .49999 L
.50005 .5 L
.50005 .50001 L
.50004 .50002 L
.50004 .50002 L
.50003 .50003 L
.50003 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50003 L
.5 .50002 L
.5 .50002 L
.49999 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
Mistroke
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .104 0 r
.47923 .31583 m
.51367 .341 L
.54204 .36848 L
.56417 .39681 L
.58019 .42472 L
.59042 .45116 L
.5954 .4753 L
.59576 .49656 L
.59224 .51455 L
.58559 .52906 L
.57659 .54008 L
.56597 .54773 L
.55441 .55224 L
.54254 .55394 L
.53087 .55321 L
.51984 .55047 L
.50979 .54615 L
.50096 .54068 L
.49351 .53446 L
.48751 .52786 L
.48298 .52121 L
.47985 .51477 L
.47804 .50878 L
.47739 .5034 L
.47775 .49875 L
.47894 .49489 L
.48079 .49186 L
.4831 .48964 L
.48572 .48819 L
.48849 .48744 L
.49128 .48732 L
.49396 .48773 L
.49646 .48856 L
.4987 .48971 L
.50063 .49109 L
.50223 .49261 L
.50348 .49417 L
.50439 .49572 L
.50498 .49719 L
.50527 .49854 L
.50531 .49973 L
.50513 .50074 L
.50477 .50156 L
.50428 .50218 L
.5037 .50262 L
.50306 .50288 L
.5024 .50298 L
.50175 .50295 L
.50114 .50281 L
.50058 .50257 L
Mistroke
.50009 .50228 L
.49967 .50193 L
.49933 .50157 L
.49907 .5012 L
.49889 .50084 L
.49879 .50051 L
.49875 .50021 L
.49876 .49995 L
.49883 .49973 L
.49893 .49956 L
.49905 .49943 L
.4992 .49935 L
.49935 .49931 L
.49951 .4993 L
.49966 .49932 L
.49979 .49936 L
.49992 .49943 L
.50003 .4995 L
.50012 .49958 L
.50019 .49967 L
.50024 .49976 L
.50027 .49984 L
.50029 .49991 L
.50029 .49998 L
.50028 .50004 L
.50027 .50008 L
.50024 .50012 L
.50021 .50014 L
.50017 .50016 L
.50014 .50017 L
.5001 .50016 L
.50007 .50016 L
.50003 .50014 L
.50001 .50013 L
.49998 .50011 L
.49996 .50009 L
.49995 .50007 L
.49994 .50005 L
.49993 .50003 L
.49993 .50001 L
.49993 .5 L
.49993 .49999 L
.49994 .49998 L
.49995 .49997 L
.49996 .49996 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49999 .49996 L
.5 .49997 L
Mistroke
.5 .49997 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.383 1 0 r
.64364 .35981 m
.66295 .40801 L
.67264 .45215 L
.67387 .49112 L
.66796 .52419 L
.65627 .55098 L
.64021 .57143 L
.62112 .58574 L
.60026 .59432 L
.57873 .59776 L
.55751 .59673 L
.5374 .592 L
.51902 .58435 L
.50283 .57456 L
.48913 .56336 L
.47806 .55142 L
.46965 .53934 L
.4638 .52763 L
.46033 .51669 L
.45901 .50684 L
.45954 .4983 L
.46161 .4912 L
.46487 .48559 L
.46902 .48146 L
.47374 .47873 L
.47875 .47729 L
.48381 .47699 L
.48871 .47766 L
.49326 .47911 L
.49736 .48117 L
.5009 .48365 L
.50384 .48638 L
.50616 .48922 L
.50785 .49204 L
.50896 .49472 L
.50954 .49718 L
.50964 .49936 L
.50933 .50122 L
.50871 .50273 L
.50783 .50388 L
.50679 .5047 L
.50564 .5052 L
.50445 .50541 L
.50327 .50537 L
.50215 .50512 L
.50112 .50471 L
.50022 .50417 L
.49945 .50355 L
.49882 .5029 L
.49835 .50223 L
Mistroke
.49801 .50158 L
.49781 .50097 L
.49773 .50042 L
.49776 .49994 L
.49786 .49954 L
.49804 .49922 L
.49827 .49899 L
.49853 .49883 L
.4988 .49875 L
.49908 .49873 L
.49936 .49876 L
.49961 .49884 L
.49984 .49895 L
.50004 .49908 L
.5002 .49923 L
.50033 .49939 L
.50043 .49955 L
.50049 .4997 L
.50053 .49983 L
.50053 .49996 L
.50052 .50006 L
.50049 .50015 L
.50044 .50021 L
.50038 .50026 L
.50032 .50029 L
.50025 .5003 L
.50019 .5003 L
.50012 .50028 L
.50007 .50026 L
.50002 .50023 L
.49997 .5002 L
.49994 .50016 L
.49991 .50013 L
.49989 .50009 L
.49988 .50006 L
.49987 .50003 L
.49988 .5 L
.49988 .49998 L
.49989 .49996 L
.4999 .49994 L
.49992 .49994 L
.49993 .49993 L
.49995 .49993 L
.49996 .49993 L
.49998 .49994 L
.49999 .49994 L
.5 .49995 L
.50001 .49996 L
.50002 .49997 L
.50002 .49997 L
Mistroke
.50003 .49998 L
.50003 .49999 L
.50003 .5 L
.50003 .5 L
.50003 .50001 L
.50002 .50001 L
.50002 .50001 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .221 r
.82936 .42599 m
.82856 .49762 L
.81475 .55784 L
.79058 .60608 L
.75866 .64233 L
.72152 .66707 L
.68149 .68116 L
.64063 .68574 L
.6007 .68216 L
.56316 .67187 L
.52911 .65635 L
.49937 .63708 L
.47443 .61542 L
.45452 .59262 L
.43962 .56978 L
.42953 .54781 L
.42387 .52746 L
.42217 .50928 L
.42385 .49364 L
.42831 .48077 L
.43492 .47074 L
.44307 .46348 L
.45219 .45885 L
.46176 .45661 L
.47132 .45647 L
.48049 .45809 L
.48897 .46112 L
.49653 .46522 L
.50301 .47006 L
.50834 .47531 L
.51247 .48071 L
.51545 .48602 L
.51732 .49103 L
.51821 .49559 L
.51822 .4996 L
.5175 .50298 L
.5162 .5057 L
.51446 .50776 L
.51242 .50917 L
.51021 .50999 L
.50795 .51028 L
.50573 .51011 L
.50364 .50957 L
.50174 .50873 L
.50008 .50767 L
.49867 .50648 L
.49755 .50522 L
.49671 .50395 L
.49613 .50273 L
.4958 .5016 L
Mistroke
.49569 .50058 L
.49577 .49971 L
.49601 .49898 L
.49637 .49841 L
.49681 .498 L
.49732 .49774 L
.49784 .4976 L
.49837 .49759 L
.49888 .49767 L
.49936 .49783 L
.49978 .49806 L
.50014 .49832 L
.50044 .49861 L
.50068 .49891 L
.50085 .49921 L
.50095 .49948 L
.50101 .49974 L
.50101 .49996 L
.50097 .50015 L
.5009 .50031 L
.50081 .50042 L
.5007 .5005 L
.50057 .50055 L
.50045 .50057 L
.50033 .50056 L
.50021 .50053 L
.5001 .50049 L
.50001 .50043 L
.49993 .50036 L
.49987 .50029 L
.49982 .50022 L
.49979 .50016 L
.49977 .50009 L
.49976 .50004 L
.49977 .49999 L
.49978 .49995 L
.4998 .49991 L
.49982 .49989 L
.49985 .49988 L
.49988 .49987 L
.49991 .49987 L
.49994 .49987 L
.49996 .49988 L
.49999 .49989 L
.50001 .49991 L
.50002 .49992 L
.50004 .49994 L
.50005 .49995 L
.50005 .49997 L
.50006 .49998 L
Mistroke
.50006 .5 L
.50005 .50001 L
.50005 .50002 L
.50005 .50002 L
.50004 .50003 L
.50003 .50003 L
.50003 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50003 L
.5 .50002 L
.5 .50002 L
.49999 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .586 r
.83228 .73918 m
.77431 .76211 L
.71468 .77087 L
.65603 .7674 L
.60057 .75379 L
.54998 .73221 L
.50552 .70482 L
.46798 .67363 L
.43774 .6405 L
.41485 .60708 L
.39903 .57473 L
.3898 .5446 L
.38645 .51751 L
.38818 .49408 L
.39411 .47464 L
.40332 .45934 L
.41491 .44812 L
.42805 .44078 L
.44196 .43698 L
.45595 .43632 L
.46946 .4383 L
.48202 .44244 L
.49329 .44821 L
.50301 .45513 L
.51105 .46273 L
.51736 .4706 L
.52196 .47838 L
.52495 .48578 L
.52646 .49256 L
.52666 .49855 L
.52577 .50363 L
.52399 .50776 L
.52154 .51091 L
.51862 .51312 L
.51542 .51445 L
.51212 .51499 L
.50887 .51484 L
.50578 .51412 L
.50296 .51295 L
.50047 .51146 L
.49836 .50974 L
.49666 .50791 L
.49536 .50606 L
.49446 .50426 L
.49392 .50258 L
.49372 .50107 L
.49379 .49976 L
.49411 .49867 L
.49461 .4978 L
.49524 .49717 L
Mistroke
.49596 .49674 L
.49673 .49652 L
.49751 .49647 L
.49826 .49657 L
.49896 .49679 L
.49959 .49711 L
.50013 .49749 L
.50058 .49791 L
.50094 .49834 L
.5012 .49877 L
.50137 .49918 L
.50146 .49956 L
.50148 .4999 L
.50143 .50018 L
.50134 .50041 L
.5012 .50059 L
.50104 .50072 L
.50087 .5008 L
.50068 .50083 L
.5005 .50082 L
.50033 .50079 L
.50017 .50072 L
.50004 .50064 L
.49992 .50055 L
.49982 .50045 L
.49975 .50034 L
.4997 .50024 L
.49967 .50015 L
.49965 .50007 L
.49966 .49999 L
.49967 .49993 L
.4997 .49988 L
.49973 .49985 L
.49977 .49982 L
.49982 .49981 L
.49986 .4998 L
.4999 .49981 L
.49994 .49982 L
.49997 .49984 L
.50001 .49986 L
.50003 .49988 L
.50005 .49991 L
.50007 .49993 L
.50008 .49995 L
.50008 .49997 L
.50008 .49999 L
.50008 .50001 L
.50007 .50002 L
.50007 .50003 L
.50006 .50004 L
Mistroke
.50005 .50004 L
.50004 .50005 L
.50003 .50005 L
.50002 .50004 L
.50001 .50004 L
.5 .50004 L
.5 .50003 L
.49999 .50003 L
.49999 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.578 0 1 r
.6696 .82835 m
.60244 .80763 L
.54197 .77793 L
.48952 .74189 L
.44592 .70196 L
.41148 .66036 L
.38611 .61903 L
.36936 .57958 L
.36053 .54327 L
.35869 .51107 L
.3628 .48359 L
.37174 .46118 L
.38437 .44392 L
.3996 .43167 L
.41639 .42413 L
.43384 .42082 L
.45113 .42122 L
.46759 .4247 L
.48271 .43063 L
.4961 .43839 L
.50749 .44736 L
.51675 .457 L
.52386 .46681 L
.52887 .47637 L
.53192 .48535 L
.53321 .49346 L
.53296 .50054 L
.53143 .50646 L
.52889 .51117 L
.52561 .51467 L
.52182 .51703 L
.51778 .51833 L
.51367 .51869 L
.50967 .51824 L
.50593 .51713 L
.50255 .51552 L
.49961 .51354 L
.49716 .51135 L
.49522 .50905 L
.49378 .50675 L
.49282 .50456 L
.4923 .50253 L
.49217 .50073 L
.49238 .49919 L
.49286 .49793 L
.49354 .49695 L
.49438 .49626 L
.4953 .49582 L
.49627 .49562 L
.49723 .49563 L
Mistroke
.49814 .49581 L
.49899 .49613 L
.49973 .49656 L
.50037 .49705 L
.50089 .49758 L
.5013 .49812 L
.50158 .49865 L
.50176 .49915 L
.50184 .49961 L
.50183 .5 L
.50175 .50034 L
.50161 .5006 L
.50143 .5008 L
.50122 .50094 L
.501 .50101 L
.50077 .50103 L
.50055 .50101 L
.50034 .50095 L
.50015 .50087 L
.49999 .50076 L
.49985 .50064 L
.49974 .50051 L
.49966 .50038 L
.49961 .50026 L
.49958 .50015 L
.49957 .50005 L
.49958 .49996 L
.4996 .49989 L
.49964 .49983 L
.49969 .4998 L
.49974 .49977 L
.49979 .49976 L
.49984 .49976 L
.49989 .49977 L
.49994 .49978 L
.49998 .49981 L
.50002 .49983 L
.50005 .49986 L
.50007 .49989 L
.50009 .49992 L
.5001 .49995 L
.5001 .49998 L
.5001 .5 L
.5001 .50002 L
.50009 .50003 L
.50008 .50004 L
.50007 .50005 L
.50006 .50006 L
.50004 .50006 L
.50003 .50006 L
Mistroke
.50002 .50005 L
.50001 .50005 L
.5 .50004 L
.49999 .50004 L
.49999 .50003 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .219 r
.53504 .4593 m
.54094 .47208 L
.54425 .48392 L
.54526 .49451 L
.5443 .50362 L
.54172 .51112 L
.53789 .51697 L
.53315 .5212 L
.52785 .52391 L
.52229 .52522 L
.51673 .52532 L
.5114 .52439 L
.50646 .52263 L
.50206 .52025 L
.49828 .51744 L
.49518 .51439 L
.49277 .51125 L
.49103 .50816 L
.48993 .50524 L
.48942 .50259 L
.4894 .50025 L
.48982 .49828 L
.49057 .4967 L
.49158 .4955 L
.49277 .49467 L
.49405 .49419 L
.49537 .49402 L
.49665 .49412 L
.49787 .49443 L
.49898 .49492 L
.49995 .49553 L
.50076 .49623 L
.50142 .49696 L
.50191 .49769 L
.50225 .4984 L
.50244 .49906 L
.50251 .49966 L
.50246 .50017 L
.50232 .50059 L
.50211 .50092 L
.50186 .50116 L
.50156 .50132 L
.50126 .50139 L
.50095 .5014 L
.50065 .50136 L
.50038 .50126 L
.50013 .50113 L
.49992 .50098 L
.49974 .50081 L
.49961 .50064 L
Mistroke
.49951 .50046 L
.49945 .5003 L
.49942 .50015 L
.49941 .50002 L
.49943 .49991 L
.49947 .49982 L
.49953 .49975 L
.49959 .49971 L
.49967 .49968 L
.49974 .49967 L
.49981 .49967 L
.49988 .49969 L
.49994 .49972 L
.49999 .49975 L
.50004 .49979 L
.50008 .49983 L
.5001 .49987 L
.50012 .49991 L
.50013 .49995 L
.50014 .49998 L
.50014 .50001 L
.50013 .50003 L
.50012 .50005 L
.5001 .50006 L
.50009 .50007 L
.50007 .50008 L
.50005 .50008 L
.50004 .50008 L
.50002 .50007 L
.50001 .50006 L
.5 .50005 L
.49999 .50005 L
.49998 .50004 L
.49997 .50003 L
.49997 .50002 L
.49997 .50001 L
.49997 .5 L
.49997 .5 L
.49997 .49999 L
.49997 .49999 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
Mistroke
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .89 1 r
.34167 .23046 m
.39763 .24399 L
.44869 .26558 L
.49362 .29308 L
.53158 .32445 L
.56219 .35779 L
.5854 .39147 L
.60146 .42409 L
.61089 .4545 L
.61437 .48185 L
.61272 .50553 L
.60683 .5252 L
.59761 .54069 L
.58596 .55207 L
.57275 .55955 L
.55875 .56344 L
.54465 .56417 L
.53103 .56221 L
.51835 .55809 L
.50698 .5523 L
.49715 .54535 L
.48901 .5377 L
.48262 .52977 L
.47795 .52193 L
.47491 .51446 L
.47337 .50762 L
.47313 .50157 L
.47401 .49643 L
.47579 .49226 L
.47825 .48906 L
.48118 .48682 L
.4844 .48546 L
.48772 .48491 L
.491 .48504 L
.49412 .48576 L
.49697 .48692 L
.49948 .48843 L
.50161 .49015 L
.50333 .49199 L
.50465 .49386 L
.50557 .49567 L
.50611 .49736 L
.50633 .49889 L
.50626 .50022 L
.50594 .50132 L
.50545 .5022 L
.50481 .50284 L
.50408 .50327 L
.50331 .5035 L
.50253 .50355 L
Mistroke
.50177 .50346 L
.50106 .50324 L
.50043 .50292 L
.49988 .50254 L
.49942 .50212 L
.49906 .50168 L
.49879 .50124 L
.49862 .50083 L
.49853 .50045 L
.49851 .50011 L
.49856 .49982 L
.49865 .49959 L
.49878 .49941 L
.49895 .49928 L
.49912 .4992 L
.49931 .49917 L
.49949 .49917 L
.49966 .49921 L
.49982 .49927 L
.49996 .49935 L
.50008 .49945 L
.50018 .49955 L
.50025 .49965 L
.50031 .49975 L
.50034 .49985 L
.50035 .49993 L
.50035 .50001 L
.50033 .50007 L
.5003 .50012 L
.50027 .50016 L
.50023 .50018 L
.50019 .50019 L
.50014 .5002 L
.5001 .50019 L
.50006 .50018 L
.50003 .50016 L
.5 .50014 L
.49997 .50012 L
.49995 .50009 L
.49993 .50007 L
.49992 .50005 L
.49992 .50003 L
.49992 .50001 L
.49992 .49999 L
.49992 .49998 L
.49993 .49997 L
.49994 .49996 L
.49995 .49996 L
.49996 .49995 L
.49997 .49995 L
Mistroke
.49998 .49996 L
.49999 .49996 L
.5 .49996 L
.5 .49997 L
.50001 .49997 L
.50001 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .949 r
.70322 .24258 m
.7413 .32006 L
.76361 .3923 L
.7718 .45724 L
.76781 .51347 L
.75375 .56013 L
.7318 .5969 L
.7041 .62389 L
.67269 .64159 L
.63941 .65079 L
.6059 .65248 L
.57354 .6478 L
.54343 .63796 L
.51642 .62419 L
.49309 .60766 L
.47378 .58948 L
.45862 .57064 L
.44755 .552 L
.44035 .53427 L
.43669 .51802 L
.43615 .50365 L
.43826 .49145 L
.44249 .48155 L
.44834 .47397 L
.45532 .46866 L
.46297 .46545 L
.47087 .46413 L
.47866 .46446 L
.48606 .46616 L
.49283 .46894 L
.4988 .47252 L
.50385 .47662 L
.50795 .481 L
.51106 .48543 L
.51324 .48974 L
.51453 .49376 L
.51504 .49739 L
.51486 .50054 L
.51412 .50316 L
.51293 .50524 L
.51142 .50677 L
.50969 .50778 L
.50785 .50833 L
.506 .50845 L
.5042 .50821 L
.50252 .50769 L
.50101 .50694 L
.4997 .50603 L
.49862 .50503 L
.49776 .50399 L
Mistroke
.49713 .50295 L
.49672 .50197 L
.4965 .50106 L
.49646 .50026 L
.49657 .49957 L
.4968 .49901 L
.49711 .49859 L
.4975 .49828 L
.49792 .4981 L
.49836 .49802 L
.49879 .49803 L
.4992 .49812 L
.49958 .49827 L
.49991 .49846 L
.50019 .49869 L
.50043 .49893 L
.5006 .49918 L
.50073 .49941 L
.5008 .49964 L
.50083 .49984 L
.50082 .50002 L
.50079 .50017 L
.50072 .50028 L
.50064 .50037 L
.50054 .50043 L
.50044 .50046 L
.50034 .50047 L
.50024 .50046 L
.50015 .50043 L
.50006 .50039 L
.49999 .50034 L
.49993 .50028 L
.49988 .50022 L
.49984 .50017 L
.49982 .50011 L
.49981 .50006 L
.4998 .50002 L
.49981 .49998 L
.49982 .49995 L
.49984 .49992 L
.49986 .49991 L
.49988 .4999 L
.49991 .49989 L
.49993 .49989 L
.49995 .4999 L
.49998 .4999 L
.49999 .49991 L
.50001 .49993 L
.50002 .49994 L
.50003 .49995 L
Mistroke
.50004 .49997 L
.50004 .49998 L
.50005 .49999 L
.50005 .5 L
.50004 .50001 L
.50004 .50002 L
.50004 .50002 L
.50003 .50002 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .743 r
.64691 .59636 m
.62299 .60797 L
.59799 .6134 L
.57309 .61342 L
.54926 .60891 L
.52729 .60076 L
.50775 .5899 L
.49104 .57718 L
.47738 .56341 L
.46681 .54933 L
.45926 .53553 L
.45456 .52252 L
.45242 .5107 L
.45254 .50036 L
.45453 .49165 L
.45802 .48468 L
.46263 .47944 L
.46799 .47587 L
.47378 .47383 L
.47968 .47317 L
.48545 .47368 L
.49087 .47517 L
.49579 .47741 L
.50009 .48019 L
.50369 .48332 L
.50657 .48662 L
.50872 .48992 L
.51018 .49309 L
.511 .49603 L
.51124 .49866 L
.511 .50092 L
.51036 .50278 L
.5094 .50423 L
.50822 .50527 L
.50691 .50594 L
.50553 .50627 L
.50414 .50629 L
.50282 .50606 L
.50159 .50562 L
.5005 .50502 L
.49957 .50433 L
.4988 .50357 L
.4982 .50279 L
.49777 .50202 L
.4975 .5013 L
.49737 .50064 L
.49737 .50006 L
.49747 .49957 L
.49766 .49918 L
.49791 .49888 L
Mistroke
.49821 .49868 L
.49852 .49856 L
.49885 .49851 L
.49917 .49854 L
.49947 .49862 L
.49975 .49874 L
.49999 .49889 L
.50019 .49906 L
.50035 .49925 L
.50048 .49943 L
.50056 .49961 L
.50061 .49977 L
.50062 .49992 L
.50061 .50004 L
.50058 .50015 L
.50052 .50023 L
.50046 .50029 L
.50039 .50033 L
.50031 .50035 L
.50023 .50035 L
.50016 .50034 L
.50009 .50031 L
.50003 .50028 L
.49998 .50024 L
.49994 .5002 L
.4999 .50016 L
.49988 .50011 L
.49986 .50007 L
.49985 .50004 L
.49985 .50001 L
.49986 .49998 L
.49987 .49996 L
.49988 .49994 L
.4999 .49993 L
.49992 .49992 L
.49994 .49992 L
.49995 .49992 L
.49997 .49992 L
.49999 .49993 L
.5 .49994 L
.50001 .49995 L
.50002 .49996 L
.50003 .49997 L
.50003 .49998 L
.50003 .49999 L
.50003 .49999 L
.50003 .5 L
.50003 .50001 L
.50003 .50001 L
.50003 .50002 L
Mistroke
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .923 r
.59205 .40875 m
.60469 .43986 L
.6111 .46838 L
.61205 .49359 L
.60836 .515 L
.60093 .53238 L
.59065 .54567 L
.57841 .55501 L
.56499 .56064 L
.55113 .56295 L
.53744 .56236 L
.52446 .55938 L
.51259 .5545 L
.50211 .54823 L
.49324 .54103 L
.48606 .53335 L
.48059 .52557 L
.47677 .51801 L
.4745 .51095 L
.47361 .50458 L
.47392 .49906 L
.47522 .49445 L
.4773 .49081 L
.47996 .48812 L
.48299 .48634 L
.48622 .48539 L
.48948 .48517 L
.49263 .48559 L
.49558 .48651 L
.49823 .48783 L
.50052 .48942 L
.50243 .49118 L
.50393 .493 L
.50503 .49482 L
.50576 .49655 L
.50614 .49814 L
.50621 .49955 L
.50602 .50075 L
.50562 .50173 L
.50506 .50248 L
.50439 .50302 L
.50365 .50334 L
.50289 .50348 L
.50213 .50346 L
.5014 .5033 L
.50074 .50304 L
.50016 .5027 L
.49966 .5023 L
.49925 .50188 L
.49894 .50145 L
Mistroke
.49873 .50103 L
.49859 .50063 L
.49854 .50028 L
.49855 .49997 L
.49862 .49971 L
.49873 .4995 L
.49888 .49935 L
.49905 .49925 L
.49922 .49919 L
.4994 .49918 L
.49958 .4992 L
.49974 .49925 L
.49989 .49932 L
.50002 .49941 L
.50013 .4995 L
.50021 .49961 L
.50027 .49971 L
.50032 .4998 L
.50034 .49989 L
.50034 .49997 L
.50033 .50004 L
.50031 .50009 L
.50028 .50013 L
.50025 .50017 L
.50021 .50018 L
.50016 .50019 L
.50012 .50019 L
.50008 .50018 L
.50004 .50017 L
.50001 .50015 L
.49998 .50013 L
.49996 .50011 L
.49994 .50008 L
.49993 .50006 L
.49992 .50004 L
.49992 .50002 L
.49992 .5 L
.49992 .49998 L
.49993 .49997 L
.49994 .49996 L
.49995 .49996 L
.49996 .49996 L
.49997 .49995 L
.49998 .49996 L
.49999 .49996 L
.49999 .49996 L
.5 .49997 L
.50001 .49997 L
.50001 .49998 L
.50002 .49998 L
Mistroke
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .129 0 r
.30567 .77895 m
.26328 .6997 L
.23717 .6252 L
.22576 .55764 L
.22715 .49863 L
.23922 .44915 L
.25979 .40964 L
.28666 .38009 L
.31775 .36008 L
.35113 .34888 L
.38511 .34552 L
.41823 .34887 L
.4493 .35773 L
.47741 .37086 L
.50191 .38705 L
.5224 .40515 L
.53871 .42414 L
.55085 .44311 L
.559 .46132 L
.56349 .47814 L
.56472 .49314 L
.56316 .50601 L
.55933 .51657 L
.55374 .52477 L
.5469 .53067 L
.53928 .53439 L
.53131 .53614 L
.52337 .53616 L
.51577 .53474 L
.50876 .53215 L
.50253 .52869 L
.49719 .52464 L
.49283 .52026 L
.48945 .51577 L
.48703 .51137 L
.48552 .50722 L
.48484 .50345 L
.48487 .50014 L
.4855 .49736 L
.48661 .49514 L
.48807 .49346 L
.48978 .49232 L
.49162 .49166 L
.4935 .49145 L
.49534 .49161 L
.49707 .49208 L
.49864 .49279 L
.50002 .49368 L
.50117 .49467 L
.50209 .49572 L
Mistroke
.50277 .49678 L
.50324 .49779 L
.5035 .49873 L
.50358 .49956 L
.50351 .50029 L
.5033 .50088 L
.503 .50134 L
.50263 .50168 L
.50221 .50189 L
.50177 .502 L
.50133 .502 L
.5009 .50193 L
.50051 .50179 L
.50016 .5016 L
.49986 .50138 L
.49962 .50114 L
.49943 .50089 L
.49929 .50065 L
.4992 .50042 L
.49916 .50021 L
.49916 .50002 L
.49919 .49986 L
.49925 .49974 L
.49933 .49964 L
.49943 .49958 L
.49953 .49954 L
.49963 .49953 L
.49973 .49953 L
.49983 .49956 L
.49992 .4996 L
.5 .49965 L
.50006 .4997 L
.50011 .49976 L
.50015 .49982 L
.50018 .49987 L
.50019 .49993 L
.5002 .49997 L
.50019 .50001 L
.50018 .50005 L
.50017 .50007 L
.50015 .50009 L
.50012 .5001 L
.5001 .50011 L
.50008 .50011 L
.50005 .50011 L
.50003 .5001 L
.50001 .50009 L
.49999 .50008 L
.49998 .50006 L
.49997 .50005 L
Mistroke
.49996 .50004 L
.49996 .50002 L
.49995 .50001 L
.49995 .5 L
.49996 .49999 L
.49996 .49999 L
.49996 .49998 L
.49997 .49998 L
.49997 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.424 0 1 r
.38121 .67914 m
.35373 .62934 L
.33651 .58237 L
.32859 .53964 L
.3288 .50219 L
.33582 .47066 L
.34828 .44537 L
.36481 .42632 L
.38409 .41328 L
.40491 .4058 L
.42619 .40329 L
.447 .40504 L
.4666 .41032 L
.48438 .41833 L
.49993 .42832 L
.51299 .43958 L
.52343 .45144 L
.53126 .46334 L
.53658 .4748 L
.53959 .48542 L
.54053 .49493 L
.5397 .50311 L
.53741 .50985 L
.53399 .51511 L
.52977 .51893 L
.52503 .52138 L
.52005 .52258 L
.51507 .52268 L
.51029 .52186 L
.50586 .5203 L
.50191 .51817 L
.49852 .51566 L
.49573 .51293 L
.49356 .51012 L
.49199 .50736 L
.491 .50474 L
.49053 .50236 L
.49051 .50026 L
.49087 .49849 L
.49154 .49707 L
.49244 .49599 L
.4935 .49524 L
.49465 .4948 L
.49583 .49465 L
.49698 .49473 L
.49808 .49501 L
.49907 .49544 L
.49994 .49599 L
.50067 .49661 L
.50126 .49726 L
Mistroke
.5017 .49792 L
.50201 .49856 L
.50218 .49915 L
.50224 .49968 L
.5022 .50014 L
.50208 .50052 L
.5019 .50082 L
.50167 .50104 L
.50141 .50118 L
.50113 .50125 L
.50085 .50126 L
.50059 .50121 L
.50034 .50113 L
.50012 .50102 L
.49993 .50088 L
.49977 .50073 L
.49965 .50057 L
.49956 .50042 L
.4995 .50027 L
.49948 .50014 L
.49947 .50002 L
.49949 .49992 L
.49953 .49984 L
.49958 .49978 L
.49964 .49974 L
.4997 .49971 L
.49976 .4997 L
.49983 .49971 L
.49989 .49972 L
.49994 .49975 L
.49999 .49978 L
.50003 .49981 L
.50007 .49985 L
.50009 .49988 L
.50011 .49992 L
.50012 .49995 L
.50012 .49998 L
.50012 .50001 L
.50012 .50003 L
.50011 .50004 L
.50009 .50006 L
.50008 .50006 L
.50006 .50007 L
.50005 .50007 L
.50003 .50007 L
.50002 .50006 L
.50001 .50006 L
.5 .50005 L
.49999 .50004 L
.49998 .50003 L
Mistroke
.49998 .50002 L
.49997 .50002 L
.49997 .50001 L
.49997 .5 L
.49997 .5 L
.49997 .49999 L
.49998 .49999 L
.49998 .49999 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .91 0 r
.5168 .27683 m
.55672 .31497 L
.58796 .35438 L
.61067 .3933 L
.62531 .43023 L
.63259 .46402 L
.6334 .49382 L
.62874 .51909 L
.61968 .53954 L
.60729 .55512 L
.5926 .566 L
.57656 .57249 L
.56004 .57504 L
.54377 .57418 L
.52836 .5705 L
.51429 .56458 L
.50191 .55703 L
.49144 .54842 L
.48299 .53925 L
.47658 .52998 L
.47213 .521 L
.46952 .51262 L
.46854 .50509 L
.46898 .49856 L
.47058 .49313 L
.47311 .48885 L
.47631 .48571 L
.47994 .48364 L
.48379 .48256 L
.48767 .48234 L
.49142 .48287 L
.49491 .484 L
.49804 .48559 L
.50075 .4875 L
.503 .4896 L
.50476 .49178 L
.50605 .49394 L
.50689 .49599 L
.50732 .49788 L
.50739 .49955 L
.50715 .50096 L
.50667 .50212 L
.50599 .503 L
.50519 .50362 L
.5043 .504 L
.50339 .50415 L
.50249 .50412 L
.50163 .50392 L
.50084 .5036 L
.50015 .50319 L
Mistroke
.49956 .50272 L
.49909 .50221 L
.49873 .5017 L
.49847 .5012 L
.49832 .50073 L
.49826 .50031 L
.49828 .49994 L
.49836 .49964 L
.4985 .4994 L
.49867 .49922 L
.49887 .4991 L
.49909 .49904 L
.4993 .49902 L
.49951 .49905 L
.4997 .49911 L
.49988 .4992 L
.50003 .4993 L
.50016 .49942 L
.50026 .49954 L
.50033 .49966 L
.50038 .49977 L
.5004 .49988 L
.50041 .49997 L
.5004 .50005 L
.50037 .50011 L
.50033 .50016 L
.50029 .5002 L
.50024 .50022 L
.50019 .50023 L
.50014 .50023 L
.50009 .50022 L
.50005 .5002 L
.50001 .50018 L
.49998 .50015 L
.49995 .50012 L
.49993 .5001 L
.49992 .50007 L
.49991 .50004 L
.4999 .50002 L
.4999 .5 L
.49991 .49998 L
.49992 .49997 L
.49993 .49996 L
.49994 .49995 L
.49995 .49995 L
.49996 .49995 L
.49997 .49995 L
.49998 .49995 L
.49999 .49996 L
.5 .49996 L
Mistroke
.50001 .49997 L
.50001 .49997 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.342 0 1 r
.3553 .54603 m
.35319 .51244 L
.35728 .48374 L
.36643 .46031 L
.37945 .44222 L
.3952 .42934 L
.41261 .42136 L
.43073 .4178 L
.4487 .41811 L
.46584 .42164 L
.48159 .42773 L
.49556 .43574 L
.50745 .44503 L
.51714 .45503 L
.52459 .46522 L
.52986 .47517 L
.53309 .48451 L
.53448 .49297 L
.53426 .50035 L
.53271 .50654 L
.5301 .51147 L
.52671 .51515 L
.52279 .51763 L
.51859 .51901 L
.51432 .51941 L
.51017 .51897 L
.50627 .51784 L
.50275 .51618 L
.49968 .51414 L
.49712 .51186 L
.49509 .50947 L
.49358 .50709 L
.49256 .5048 L
.49201 .50269 L
.49187 .50081 L
.49207 .49921 L
.49256 .49789 L
.49327 .49686 L
.49413 .49613 L
.49509 .49567 L
.49609 .49546 L
.49709 .49546 L
.49804 .49564 L
.49892 .49597 L
.4997 .49641 L
.50037 .49692 L
.50091 .49747 L
.50134 .49803 L
.50164 .49859 L
.50182 .49911 L
Mistroke
.50191 .49958 L
.5019 .49999 L
.50182 .50034 L
.50168 .50062 L
.50149 .50083 L
.50128 .50097 L
.50105 .50105 L
.50081 .50107 L
.50058 .50105 L
.50036 .50099 L
.50017 .5009 L
.49999 .50079 L
.49985 .50067 L
.49974 .50053 L
.49965 .5004 L
.49959 .50027 L
.49956 .50016 L
.49955 .50005 L
.49956 .49996 L
.49959 .49989 L
.49962 .49983 L
.49967 .49979 L
.49972 .49976 L
.49978 .49975 L
.49983 .49975 L
.49989 .49976 L
.49994 .49978 L
.49998 .4998 L
.50002 .49983 L
.50005 .49986 L
.50007 .49989 L
.50009 .49992 L
.5001 .49995 L
.50011 .49997 L
.50011 .5 L
.5001 .50002 L
.50009 .50003 L
.50008 .50005 L
.50007 .50005 L
.50006 .50006 L
.50005 .50006 L
.50003 .50006 L
.50002 .50006 L
.50001 .50005 L
.5 .50004 L
.49999 .50004 L
.49999 .50003 L
.49998 .50002 L
.49998 .50002 L
.49998 .50001 L
Mistroke
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.355 1 0 r
.67357 .56902 m
.65348 .58979 L
.63047 .60363 L
.60594 .6111 L
.58111 .61294 L
.55702 .60996 L
.53452 .60306 L
.51426 .59315 L
.49667 .5811 L
.48204 .56775 L
.47048 .55383 L
.46196 .53999 L
.45632 .52678 L
.45334 .51461 L
.4527 .50382 L
.45405 .4946 L
.45703 .48708 L
.46125 .48128 L
.46633 .47717 L
.47195 .47462 L
.47779 .4735 L
.48358 .47362 L
.48909 .47478 L
.49416 .47676 L
.49865 .47935 L
.50247 .48235 L
.50558 .48557 L
.50796 .48886 L
.50965 .49206 L
.51068 .49506 L
.51111 .49778 L
.51103 .50016 L
.51053 .50214 L
.50968 .50372 L
.50858 .5049 L
.50732 .50569 L
.50596 .50613 L
.50459 .50625 L
.50325 .50611 L
.502 .50574 L
.50087 .5052 L
.49988 .50454 L
.49906 .50381 L
.49841 .50304 L
.49792 .50227 L
.4976 .50153 L
.49742 .50086 L
.49738 .50025 L
.49745 .49973 L
.49761 .49931 L
Mistroke
.49784 .49898 L
.49811 .49875 L
.49842 .4986 L
.49875 .49854 L
.49907 .49854 L
.49937 .4986 L
.49966 .4987 L
.49991 .49885 L
.50012 .49901 L
.5003 .49919 L
.50043 .49937 L
.50053 .49955 L
.50059 .49972 L
.50061 .49987 L
.50061 .5 L
.50059 .50011 L
.50054 .5002 L
.50048 .50027 L
.50041 .50031 L
.50034 .50034 L
.50026 .50035 L
.50019 .50034 L
.50012 .50032 L
.50005 .50029 L
.5 .50025 L
.49995 .50021 L
.49991 .50017 L
.49989 .50013 L
.49987 .50009 L
.49986 .50005 L
.49985 .50002 L
.49986 .49999 L
.49987 .49996 L
.49988 .49994 L
.49989 .49993 L
.49991 .49992 L
.49993 .49992 L
.49995 .49992 L
.49996 .49992 L
.49998 .49993 L
.49999 .49994 L
.50001 .49994 L
.50002 .49995 L
.50002 .49996 L
.50003 .49997 L
.50003 .49998 L
.50003 .49999 L
.50003 .5 L
.50003 .50001 L
.50003 .50001 L
Mistroke
.50003 .50001 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.114 0 1 r
.5361 .55345 m
.5248 .55162 L
.51432 .54802 L
.50495 .54308 L
.49689 .53721 L
.49025 .5308 L
.48506 .52418 L
.4813 .51766 L
.4789 .51148 L
.47772 .50583 L
.47762 .50085 L
.47844 .49664 L
.47998 .49325 L
.48208 .49066 L
.48456 .48887 L
.48726 .4878 L
.49003 .4874 L
.49276 .48756 L
.49534 .4882 L
.49769 .48921 L
.49976 .49048 L
.5015 .49193 L
.5029 .49347 L
.50397 .49503 L
.5047 .49653 L
.50513 .49793 L
.50528 .49919 L
.5052 .50028 L
.50492 .50118 L
.50449 .5019 L
.50395 .50242 L
.50334 .50276 L
.5027 .50293 L
.50204 .50296 L
.50142 .50287 L
.50083 .50268 L
.50031 .50241 L
.49986 .50209 L
.49948 .50173 L
.49919 .50137 L
.49898 .501 L
.49884 .50066 L
.49877 .50034 L
.49876 .50007 L
.4988 .49983 L
.49888 .49964 L
.499 .49949 L
.49913 .49939 L
.49928 .49933 L
.49944 .4993 L
Mistroke
.49959 .49931 L
.49973 .49934 L
.49986 .4994 L
.49998 .49947 L
.50008 .49955 L
.50016 .49963 L
.50022 .49972 L
.50026 .4998 L
.50028 .49988 L
.50029 .49995 L
.50029 .50001 L
.50027 .50006 L
.50025 .5001 L
.50022 .50013 L
.50019 .50015 L
.50015 .50016 L
.50012 .50016 L
.50008 .50016 L
.50005 .50015 L
.50002 .50013 L
.49999 .50012 L
.49997 .5001 L
.49996 .50008 L
.49994 .50006 L
.49994 .50004 L
.49993 .50002 L
.49993 .5 L
.49993 .49999 L
.49994 .49998 L
.49994 .49997 L
.49995 .49997 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49999 .49997 L
.5 .49997 L
.5 .49997 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
Mistroke
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .666 r
.5054 .23544 m
.55336 .27801 L
.59148 .32262 L
.61982 .36717 L
.63882 .40987 L
.64922 .44932 L
.65198 .48447 L
.64822 .51459 L
.63914 .5393 L
.62595 .55846 L
.60984 .57222 L
.59193 .58087 L
.57321 .5849 L
.55458 .58489 L
.53675 .58149 L
.52031 .57537 L
.5057 .56723 L
.49321 .5577 L
.483 .54739 L
.4751 .53684 L
.46947 .52652 L
.46596 .51679 L
.46438 .50795 L
.46448 .50021 L
.46598 .49371 L
.4686 .4885 L
.47205 .48459 L
.47607 .48192 L
.4804 .4804 L
.48482 .47991 L
.48914 .48031 L
.4932 .48142 L
.49687 .4831 L
.50009 .48519 L
.50278 .48753 L
.50493 .49 L
.50654 .49247 L
.50763 .49484 L
.50823 .49704 L
.50842 .49901 L
.50823 .5007 L
.50775 .50209 L
.50703 .50317 L
.50615 .50395 L
.50516 .50445 L
.50413 .50469 L
.5031 .50471 L
.5021 .50453 L
.50119 .5042 L
.50037 .50376 L
Mistroke
.49967 .50323 L
.4991 .50267 L
.49865 .50208 L
.49833 .50151 L
.49813 .50097 L
.49803 .50047 L
.49803 .50004 L
.49811 .49968 L
.49825 .49938 L
.49844 .49916 L
.49866 .49901 L
.4989 .49892 L
.49914 .49889 L
.49938 .49891 L
.49961 .49897 L
.49981 .49906 L
.49999 .49917 L
.50014 .4993 L
.50027 .49944 L
.50036 .49957 L
.50042 .49971 L
.50045 .49983 L
.50047 .49994 L
.50046 .50003 L
.50043 .50011 L
.50039 .50017 L
.50034 .50022 L
.50029 .50024 L
.50023 .50026 L
.50018 .50026 L
.50012 .50025 L
.50007 .50023 L
.50002 .50021 L
.49998 .50018 L
.49995 .50015 L
.49993 .50012 L
.49991 .50009 L
.4999 .50006 L
.49989 .50003 L
.49989 .5 L
.49989 .49998 L
.4999 .49997 L
.49991 .49995 L
.49992 .49995 L
.49994 .49994 L
.49995 .49994 L
.49996 .49994 L
.49998 .49994 L
.49999 .49995 L
.5 .49995 L
Mistroke
.50001 .49996 L
.50001 .49997 L
.50002 .49998 L
.50002 .49998 L
.50003 .49999 L
.50003 .5 L
.50003 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.72 1 0 r
.33485 .61662 m
.32076 .56821 L
.31611 .52484 L
.31955 .48744 L
.32966 .45655 L
.34496 .43235 L
.364 .41475 L
.38543 .40338 L
.40799 .3977 L
.43062 .39702 L
.45238 .40057 L
.47256 .40752 L
.49059 .41706 L
.5061 .42838 L
.51888 .44075 L
.52886 .4535 L
.53607 .46607 L
.54069 .47797 L
.54294 .48885 L
.54311 .49842 L
.54153 .50652 L
.53854 .51306 L
.53449 .51803 L
.52971 .52148 L
.52451 .52351 L
.51917 .52428 L
.51391 .52396 L
.50895 .52272 L
.50442 .52078 L
.50044 .51832 L
.49709 .51552 L
.49439 .51255 L
.49234 .50956 L
.49093 .50666 L
.49011 .50396 L
.48982 .50154 L
.48998 .49944 L
.49052 .49771 L
.49135 .49634 L
.49239 .49534 L
.49357 .49469 L
.49482 .49435 L
.49607 .49429 L
.49728 .49447 L
.4984 .49485 L
.49941 .49537 L
.50028 .49599 L
.501 .49667 L
.50156 .49737 L
.50197 .49807 L
Mistroke
.50224 .49873 L
.50237 .49934 L
.50239 .49988 L
.50231 .50033 L
.50215 .5007 L
.50193 .50098 L
.50167 .50118 L
.50138 .5013 L
.50108 .50134 L
.50079 .50133 L
.50051 .50126 L
.50026 .50116 L
.50004 .50102 L
.49985 .50087 L
.4997 .50071 L
.49958 .50054 L
.4995 .50038 L
.49945 .50023 L
.49944 .50009 L
.49944 .49998 L
.49947 .49988 L
.49952 .4998 L
.49957 .49975 L
.49964 .49971 L
.49971 .49969 L
.49978 .49968 L
.49984 .49969 L
.49991 .49971 L
.49996 .49974 L
.50001 .49978 L
.50005 .49981 L
.50008 .49985 L
.50011 .49989 L
.50012 .49993 L
.50013 .49996 L
.50013 .49999 L
.50013 .50002 L
.50012 .50004 L
.50011 .50005 L
.50009 .50006 L
.50008 .50007 L
.50006 .50007 L
.50004 .50007 L
.50003 .50007 L
.50002 .50006 L
.5 .50006 L
.49999 .50005 L
.49998 .50004 L
.49998 .50003 L
.49997 .50002 L
Mistroke
.49997 .50001 L
.49997 .50001 L
.49997 .5 L
.49997 .49999 L
.49997 .49999 L
.49998 .49999 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .303 r
.47191 .53257 m
.4672 .52233 L
.46455 .51285 L
.46375 .50437 L
.46452 .49708 L
.46659 .49108 L
.46967 .48639 L
.47346 .48301 L
.4777 .48084 L
.48216 .47979 L
.48661 .47972 L
.49089 .48047 L
.49484 .48188 L
.49836 .48379 L
.50139 .48604 L
.50387 .48849 L
.5058 .491 L
.50719 .49347 L
.50807 .49581 L
.50848 .49794 L
.50849 .4998 L
.50816 .50138 L
.50755 .50265 L
.50674 .50361 L
.50579 .50427 L
.50476 .50465 L
.50371 .50479 L
.50268 .50471 L
.5017 .50446 L
.50082 .50407 L
.50004 .50358 L
.49939 .50302 L
.49886 .50244 L
.49847 .50185 L
.4982 .50128 L
.49804 .50075 L
.49799 .50027 L
.49803 .49987 L
.49814 .49953 L
.49831 .49926 L
.49851 .49907 L
.49875 .49895 L
.49899 .49888 L
.49924 .49888 L
.49948 .49891 L
.4997 .49899 L
.4999 .49909 L
.50007 .49922 L
.50021 .49935 L
.50031 .49949 L
Mistroke
.50039 .49963 L
.50044 .49976 L
.50047 .49988 L
.50047 .49998 L
.50045 .50007 L
.50042 .50014 L
.50038 .5002 L
.50032 .50023 L
.50027 .50026 L
.50021 .50027 L
.50015 .50026 L
.5001 .50025 L
.50005 .50023 L
.50001 .5002 L
.49997 .50017 L
.49994 .50014 L
.49992 .5001 L
.4999 .50007 L
.49989 .50004 L
.49989 .50002 L
.49989 .49999 L
.4999 .49998 L
.49991 .49996 L
.49992 .49995 L
.49993 .49994 L
.49994 .49994 L
.49996 .49994 L
.49997 .49994 L
.49998 .49994 L
.49999 .49995 L
.5 .49996 L
.50001 .49996 L
.50002 .49997 L
.50002 .49998 L
.50002 .49999 L
.50003 .49999 L
.50003 .5 L
.50003 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
Mistroke
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .75 0 r
.72217 .33283 m
.74299 .39957 L
.75075 .45962 L
.74723 .51164 L
.7344 .55484 L
.71425 .58891 L
.68877 .61396 L
.65983 .63043 L
.62914 .63904 L
.59822 .64071 L
.56833 .63648 L
.54051 .62747 L
.51554 .61481 L
.49395 .5996 L
.47607 .58284 L
.46202 .56546 L
.45174 .54825 L
.44505 .53188 L
.44162 .51686 L
.44108 .50358 L
.44298 .49228 L
.44686 .48311 L
.45224 .47609 L
.45867 .47115 L
.46571 .46815 L
.473 .46691 L
.4802 .4672 L
.48703 .46875 L
.49329 .4713 L
.49881 .47459 L
.50349 .47836 L
.50728 .4824 L
.51017 .48649 L
.51219 .49047 L
.51339 .49418 L
.51387 .49754 L
.51372 .50045 L
.51304 .50288 L
.51195 .5048 L
.51056 .50623 L
.50897 .50717 L
.50727 .50768 L
.50556 .5078 L
.5039 .50758 L
.50235 .5071 L
.50095 .50641 L
.49974 .50558 L
.49874 .50466 L
.49795 .50369 L
.49736 .50274 L
Mistroke
.49698 .50183 L
.49678 .50099 L
.49674 .50025 L
.49683 .49961 L
.49704 .4991 L
.49733 .4987 L
.49768 .49842 L
.49807 .49825 L
.49848 .49817 L
.49888 .49818 L
.49926 .49826 L
.4996 .4984 L
.49991 .49858 L
.50018 .49879 L
.50039 .49901 L
.50055 .49924 L
.50067 .49946 L
.50074 .49966 L
.50077 .49985 L
.50076 .50001 L
.50073 .50015 L
.50067 .50026 L
.50059 .50034 L
.5005 .50039 L
.50041 .50042 L
.50031 .50043 L
.50022 .50042 L
.50014 .5004 L
.50006 .50036 L
.49999 .50031 L
.49993 .50026 L
.49989 .50021 L
.49986 .50016 L
.49983 .5001 L
.49982 .50006 L
.49982 .50002 L
.49982 .49998 L
.49984 .49995 L
.49985 .49993 L
.49987 .49991 L
.49989 .4999 L
.49991 .4999 L
.49994 .4999 L
.49996 .4999 L
.49998 .49991 L
.49999 .49992 L
.50001 .49993 L
.50002 .49994 L
.50003 .49996 L
.50004 .49997 L
Mistroke
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50004 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .178 1 r
.49209 .34926 m
.51989 .37151 L
.54243 .39533 L
.55966 .41951 L
.57173 .44303 L
.579 .46505 L
.58194 .48493 L
.58113 .50223 L
.57721 .51665 L
.57083 .5281 L
.56264 .53658 L
.55326 .54224 L
.54326 .54531 L
.53313 .54606 L
.52331 .54486 L
.51413 .54205 L
.50585 .53802 L
.49868 .53311 L
.4927 .52766 L
.48798 .52198 L
.4845 .51634 L
.48219 .51095 L
.48097 .50598 L
.48071 .50158 L
.48126 .49782 L
.48247 .49474 L
.48418 .49238 L
.48626 .49069 L
.48855 .48965 L
.49093 .48919 L
.49329 .48924 L
.49554 .48971 L
.49761 .49052 L
.49944 .49157 L
.501 .49279 L
.50227 .49411 L
.50324 .49545 L
.50393 .49675 L
.50435 .49798 L
.50453 .49909 L
.5045 .50006 L
.5043 .50087 L
.50395 .50152 L
.5035 .502 L
.50299 .50232 L
.50244 .5025 L
.50187 .50255 L
.50133 .50249 L
.50082 .50234 L
.50036 .50212 L
Mistroke
.49995 .50185 L
.49962 .50155 L
.49935 .50124 L
.49915 .50093 L
.49902 .50063 L
.49895 .50035 L
.49893 .5001 L
.49896 .49989 L
.49902 .49972 L
.49912 .49959 L
.49923 .49949 L
.49936 .49943 L
.49949 .4994 L
.49962 .4994 L
.49974 .49943 L
.49986 .49947 L
.49996 .49953 L
.50005 .4996 L
.50012 .49967 L
.50018 .49974 L
.50022 .49982 L
.50024 .49988 L
.50025 .49995 L
.50025 .5 L
.50024 .50005 L
.50022 .50008 L
.5002 .50011 L
.50017 .50013 L
.50014 .50014 L
.50011 .50014 L
.50008 .50014 L
.50005 .50013 L
.50002 .50012 L
.5 .5001 L
.49998 .50009 L
.49997 .50007 L
.49995 .50005 L
.49995 .50004 L
.49994 .50002 L
.49994 .50001 L
.49994 .49999 L
.49995 .49999 L
.49995 .49998 L
.49996 .49997 L
.49996 .49997 L
.49997 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49997 L
Mistroke
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .209 0 r
.62249 .43706 m
.62864 .46926 L
.62866 .49752 L
.62354 .52135 L
.61429 .54049 L
.60196 .55495 L
.58754 .56488 L
.57192 .57063 L
.55594 .57263 L
.54029 .5714 L
.52554 .56752 L
.51213 .56155 L
.5004 .55409 L
.49053 .54566 L
.48262 .53676 L
.47668 .52781 L
.47262 .51919 L
.47031 .51119 L
.46956 .50402 L
.47015 .49785 L
.47184 .49275 L
.47438 .48876 L
.47754 .48586 L
.48108 .48399 L
.48482 .48306 L
.48856 .48296 L
.49216 .48355 L
.4955 .48471 L
.49848 .4863 L
.50104 .48817 L
.50315 .49022 L
.50479 .49233 L
.50598 .49441 L
.50674 .49638 L
.50711 .49818 L
.50713 .49976 L
.50687 .5011 L
.50637 .50217 L
.5057 .50299 L
.50491 .50356 L
.50405 .50389 L
.50316 .50402 L
.50229 .50396 L
.50147 .50376 L
.50072 .50343 L
.50007 .50303 L
.49951 .50256 L
.49907 .50207 L
.49873 .50158 L
.4985 .5011 L
Mistroke
.49836 .50065 L
.49832 .50025 L
.49834 .4999 L
.49843 .49962 L
.49857 .49939 L
.49874 .49923 L
.49894 .49912 L
.49914 .49906 L
.49935 .49906 L
.49955 .49909 L
.49974 .49915 L
.4999 .49923 L
.50005 .49934 L
.50017 .49945 L
.50026 .49957 L
.50033 .49968 L
.50037 .49979 L
.50039 .49989 L
.5004 .49998 L
.50038 .50006 L
.50036 .50012 L
.50032 .50016 L
.50027 .5002 L
.50023 .50021 L
.50018 .50022 L
.50013 .50022 L
.50008 .50021 L
.50004 .50019 L
.50001 .50017 L
.49997 .50014 L
.49995 .50012 L
.49993 .50009 L
.49992 .50006 L
.49991 .50004 L
.49991 .50002 L
.49991 .5 L
.49991 .49998 L
.49992 .49997 L
.49993 .49996 L
.49994 .49995 L
.49995 .49995 L
.49996 .49995 L
.49997 .49995 L
.49998 .49995 L
.49999 .49996 L
.5 .49996 L
.50001 .49997 L
.50001 .49998 L
.50002 .49998 L
.50002 .49999 L
Mistroke
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .779 0 r
.3778 .33122 m
.41384 .33549 L
.44754 .34565 L
.47792 .36036 L
.50432 .37829 L
.5263 .39821 L
.5437 .419 L
.55656 .43969 L
.56509 .45947 L
.56965 .4777 L
.5707 .49389 L
.56874 .50773 L
.56436 .51903 L
.5581 .52776 L
.55053 .53398 L
.54215 .53784 L
.53343 .53957 L
.52477 .53944 L
.51651 .53775 L
.50892 .53483 L
.50219 .53098 L
.49645 .52651 L
.49178 .52169 L
.48818 .51679 L
.48564 .512 L
.48408 .50749 L
.4834 .50342 L
.4835 .49986 L
.48424 .49687 L
.48549 .49449 L
.48712 .49272 L
.48901 .49152 L
.49103 .49085 L
.49309 .49065 L
.49509 .49086 L
.49697 .4914 L
.49866 .4922 L
.50014 .49319 L
.50138 .49428 L
.50236 .49543 L
.50309 .49658 L
.50358 .49768 L
.50384 .4987 L
.50392 .4996 L
.50382 .50038 L
.50358 .50101 L
.50324 .50151 L
.50283 .50186 L
.50237 .50208 L
.50189 .50219 L
Mistroke
.50141 .50219 L
.50095 .5021 L
.50052 .50194 L
.50015 .50173 L
.49982 .50149 L
.49956 .50122 L
.49936 .50095 L
.49921 .50068 L
.49912 .50043 L
.49908 .5002 L
.49908 .50001 L
.49912 .49984 L
.49919 .4997 L
.49928 .4996 L
.49938 .49953 L
.4995 .4995 L
.49961 .49948 L
.49972 .49949 L
.49982 .49952 L
.49992 .49956 L
.5 .49962 L
.50007 .49968 L
.50013 .49974 L
.50017 .49981 L
.5002 .49987 L
.50021 .49992 L
.50022 .49997 L
.50021 .50002 L
.5002 .50005 L
.50018 .50008 L
.50016 .5001 L
.50013 .50011 L
.50011 .50012 L
.50008 .50012 L
.50005 .50012 L
.50003 .50011 L
.50001 .5001 L
.49999 .50008 L
.49998 .50007 L
.49997 .50005 L
.49996 .50004 L
.49995 .50002 L
.49995 .50001 L
.49995 .5 L
.49995 .49999 L
.49995 .49998 L
.49996 .49998 L
.49997 .49997 L
.49997 .49997 L
.49998 .49997 L
Mistroke
.49998 .49997 L
.49999 .49997 L
.5 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .545 r
.80743 .70023 m
.75763 .72475 L
.70553 .73635 L
.65357 .73663 L
.60381 .72741 L
.55789 .71057 L
.51702 .68802 L
.48204 .66156 L
.45339 .6329 L
.43121 .60352 L
.41533 .57472 L
.40539 .54755 L
.40083 .52284 L
.40097 .50119 L
.40505 .48297 L
.41226 .46835 L
.42183 .45734 L
.43299 .44981 L
.44504 .44549 L
.45735 .44405 L
.46939 .44508 L
.48072 .44813 L
.491 .45277 L
.49999 .45856 L
.50754 .46507 L
.51358 .47194 L
.5181 .47882 L
.52117 .48545 L
.52291 .49159 L
.52345 .49708 L
.52296 .50181 L
.52163 .50571 L
.51966 .50875 L
.51721 .51096 L
.51447 .51237 L
.51159 .51306 L
.50871 .51312 L
.50594 .51264 L
.50338 .51174 L
.5011 .51051 L
.49913 .50906 L
.49752 .50747 L
.49627 .50585 L
.49536 .50425 L
.49479 .50274 L
.49452 .50136 L
.49451 .50015 L
.49472 .49912 L
.49511 .4983 L
.49563 .49768 L
Mistroke
.49624 .49725 L
.49691 .49699 L
.49759 .4969 L
.49826 .49695 L
.49889 .49711 L
.49946 .49736 L
.49997 .49768 L
.50039 .49804 L
.50073 .49842 L
.50099 .4988 L
.50116 .49917 L
.50126 .49951 L
.5013 .49982 L
.50127 .50008 L
.5012 .5003 L
.5011 .50047 L
.50096 .5006 L
.50081 .50068 L
.50065 .50072 L
.50049 .50073 L
.50034 .5007 L
.5002 .50065 L
.50007 .50059 L
.49996 .50051 L
.49987 .50042 L
.4998 .50033 L
.49975 .50024 L
.49971 .50016 L
.4997 .50008 L
.4997 .50001 L
.49971 .49996 L
.49973 .49991 L
.49976 .49987 L
.49979 .49985 L
.49983 .49983 L
.49986 .49983 L
.4999 .49983 L
.49994 .49984 L
.49997 .49985 L
.5 .49987 L
.50002 .49989 L
.50004 .49991 L
.50005 .49993 L
.50006 .49995 L
.50007 .49997 L
.50007 .49999 L
.50007 .5 L
.50007 .50002 L
.50006 .50003 L
.50005 .50003 L
Mistroke
.50005 .50004 L
.50004 .50004 L
.50003 .50004 L
.50002 .50004 L
.50001 .50004 L
.5 .50003 L
.5 .50003 L
.49999 .50002 L
.49999 .50002 L
.49999 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.474 0 1 r
.32344 .45886 m
.33859 .43316 L
.35776 .41427 L
.37954 .40184 L
.40264 .39533 L
.42592 .39404 L
.44843 .39721 L
.46939 .40397 L
.48821 .41349 L
.50448 .42494 L
.51796 .43756 L
.52855 .45064 L
.5363 .4636 L
.54136 .47593 L
.54395 .48725 L
.54437 .49726 L
.54294 .50577 L
.54003 .51269 L
.53598 .51798 L
.53115 .52171 L
.52584 .52397 L
.52036 .52491 L
.51494 .5247 L
.50979 .52354 L
.50508 .52162 L
.50092 .51915 L
.49739 .51631 L
.49453 .51327 L
.49235 .51019 L
.49083 .50719 L
.48992 .50439 L
.48955 .50187 L
.48967 .49967 L
.49018 .49784 L
.49099 .49639 L
.49204 .49532 L
.49324 .4946 L
.49452 .49422 L
.49581 .49413 L
.49706 .49429 L
.49823 .49465 L
.49928 .49517 L
.50019 .4958 L
.50095 .49649 L
.50154 .49721 L
.50198 .49793 L
.50227 .49862 L
.50243 .49925 L
.50246 .49981 L
.50239 .50029 L
Mistroke
.50223 .50068 L
.50201 .50098 L
.50174 .50119 L
.50145 .50132 L
.50115 .50138 L
.50085 .50137 L
.50056 .50131 L
.5003 .50121 L
.50007 .50107 L
.49987 .50091 L
.49971 .50075 L
.49958 .50058 L
.4995 .50041 L
.49944 .50025 L
.49942 .50011 L
.49943 .49999 L
.49945 .49989 L
.4995 .49981 L
.49955 .49974 L
.49962 .4997 L
.49969 .49968 L
.49976 .49967 L
.49983 .49968 L
.4999 .4997 L
.49996 .49973 L
.50001 .49976 L
.50005 .4998 L
.50008 .49984 L
.50011 .49988 L
.50013 .49992 L
.50013 .49996 L
.50014 .49999 L
.50013 .50001 L
.50012 .50004 L
.50011 .50005 L
.5001 .50007 L
.50008 .50007 L
.50006 .50008 L
.50005 .50008 L
.50003 .50007 L
.50002 .50007 L
.5 .50006 L
.49999 .50005 L
.49998 .50004 L
.49998 .50003 L
.49997 .50002 L
.49997 .50001 L
.49997 .50001 L
.49997 .5 L
.49997 .49999 L
Mistroke
.49997 .49999 L
.49998 .49999 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.164 0 1 r
.34746 .17408 m
.41344 .19753 L
.47228 .22931 L
.52279 .26681 L
.56428 .30761 L
.59653 .34956 L
.61975 .39079 L
.63445 .42977 L
.64142 .4653 L
.64161 .49651 L
.6361 .52285 L
.62604 .54405 L
.61255 .56008 L
.59673 .57114 L
.57958 .57758 L
.562 .57988 L
.54476 .57862 L
.5285 .57441 L
.51372 .56791 L
.50075 .55973 L
.48984 .55048 L
.48109 .54069 L
.47449 .53085 L
.46998 .52136 L
.46739 .51253 L
.46652 .50462 L
.46713 .4978 L
.46896 .49216 L
.47173 .48774 L
.47519 .48451 L
.47909 .48243 L
.48319 .48138 L
.48731 .48125 L
.49128 .48188 L
.49496 .48314 L
.49825 .48487 L
.50108 .48693 L
.50341 .48918 L
.50523 .4915 L
.50655 .49379 L
.5074 .49596 L
.50781 .49794 L
.50785 .49969 L
.50757 .50117 L
.50703 .50236 L
.50629 .50327 L
.50542 .5039 L
.50448 .50428 L
.5035 .50442 L
.50255 .50436 L
Mistroke
.50164 .50414 L
.50082 .50379 L
.50009 .50334 L
.49948 .50283 L
.49898 .50229 L
.49861 .50175 L
.49835 .50122 L
.4982 .50073 L
.49815 .50029 L
.49818 .4999 L
.49827 .49959 L
.49842 .49934 L
.49861 .49915 L
.49883 .49903 L
.49905 .49897 L
.49928 .49896 L
.4995 .49899 L
.49971 .49906 L
.49989 .49915 L
.50005 .49927 L
.50018 .49939 L
.50028 .49952 L
.50036 .49965 L
.50041 .49977 L
.50043 .49988 L
.50044 .49998 L
.50042 .50006 L
.50039 .50013 L
.50035 .50018 L
.5003 .50021 L
.50025 .50024 L
.5002 .50024 L
.50014 .50024 L
.50009 .50023 L
.50005 .50021 L
.50001 .50019 L
.49997 .50016 L
.49995 .50013 L
.49992 .5001 L
.49991 .50007 L
.4999 .50004 L
.4999 .50002 L
.4999 .5 L
.4999 .49998 L
.49991 .49996 L
.49992 .49995 L
.49993 .49995 L
.49995 .49994 L
.49996 .49994 L
.49997 .49994 L
Mistroke
.49998 .49995 L
.49999 .49995 L
.5 .49996 L
.50001 .49997 L
.50002 .49997 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .889 0 r
.66517 .49976 m
.65805 .52988 L
.64576 .55397 L
.62961 .57204 L
.61087 .58432 L
.59071 .59126 L
.57015 .59344 L
.55009 .59153 L
.53125 .58627 L
.51418 .5784 L
.49929 .56866 L
.48681 .55774 L
.47687 .54626 L
.46945 .53477 L
.46444 .52374 L
.46165 .51353 L
.46085 .50442 L
.46174 .4966 L
.46402 .49016 L
.46737 .48516 L
.47149 .48155 L
.47609 .47925 L
.4809 .47816 L
.48571 .47811 L
.49031 .47895 L
.49457 .4805 L
.49836 .48257 L
.5016 .48501 L
.50426 .48766 L
.50633 .49038 L
.5078 .49304 L
.50873 .49556 L
.50916 .49785 L
.50916 .49985 L
.50879 .50154 L
.50813 .5029 L
.50725 .50393 L
.50622 .50463 L
.5051 .50503 L
.50397 .50517 L
.50285 .50508 L
.5018 .5048 L
.50085 .50438 L
.50002 .50384 L
.49932 .50324 L
.49875 .50261 L
.49833 .50197 L
.49805 .50136 L
.49788 .50079 L
.49783 .50028 L
Mistroke
.49788 .49984 L
.498 .49948 L
.49818 .4992 L
.4984 .49899 L
.49866 .49886 L
.49892 .49879 L
.49919 .49879 L
.49945 .49883 L
.49968 .49891 L
.49989 .49903 L
.50008 .49916 L
.50023 .49931 L
.50034 .49946 L
.50043 .4996 L
.50048 .49974 L
.50051 .49987 L
.50051 .49998 L
.50049 .50008 L
.50045 .50016 L
.50041 .50021 L
.50035 .50025 L
.50029 .50028 L
.50022 .50029 L
.50016 .50028 L
.5001 .50027 L
.50005 .50024 L
.5 .50022 L
.49996 .50018 L
.49993 .50015 L
.49991 .50011 L
.49989 .50008 L
.49988 .50005 L
.49988 .50002 L
.49988 .49999 L
.49989 .49997 L
.4999 .49996 L
.49991 .49994 L
.49992 .49994 L
.49994 .49993 L
.49995 .49993 L
.49997 .49993 L
.49998 .49994 L
.49999 .49995 L
.5 .49995 L
.50001 .49996 L
.50002 .49997 L
.50002 .49998 L
.50003 .49999 L
.50003 .49999 L
.50003 .5 L
Mistroke
.50003 .5 L
.50003 .50001 L
.50002 .50001 L
.50002 .50001 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .465 r
.63208 .22984 m
.67556 .29636 L
.70505 .36035 L
.72159 .41965 L
.72662 .47264 L
.72178 .51822 L
.70885 .55575 L
.68964 .58503 L
.66594 .60621 L
.6394 .61974 L
.61155 .62631 L
.58371 .62677 L
.55699 .62209 L
.53228 .61328 L
.51025 .60135 L
.49134 .58729 L
.47582 .57199 L
.46375 .55627 L
.45508 .54082 L
.44959 .52622 L
.447 .51292 L
.44694 .50123 L
.44902 .49138 L
.4528 .48345 L
.45786 .47745 L
.46379 .47332 L
.47022 .47092 L
.47681 .47006 L
.48327 .47055 L
.48936 .47213 L
.4949 .47457 L
.49975 .47764 L
.50383 .48111 L
.50711 .48477 L
.50957 .48846 L
.51126 .49202 L
.51222 .49532 L
.51255 .49829 L
.51231 .50084 L
.51163 .50295 L
.51059 .50461 L
.50929 .50581 L
.50783 .50659 L
.50629 .50698 L
.50474 .50703 L
.50326 .50679 L
.50188 .50631 L
.50065 .50566 L
.49959 .50489 L
.49872 .50405 L
Mistroke
.49804 .50318 L
.49754 .50232 L
.49723 .50151 L
.49707 .50077 L
.49706 .50011 L
.49717 .49956 L
.49737 .49911 L
.49764 .49877 L
.49797 .49854 L
.49833 .4984 L
.49869 .49834 L
.49905 .49837 L
.49939 .49845 L
.4997 .49858 L
.49997 .49875 L
.5002 .49894 L
.50038 .49914 L
.50052 .49935 L
.50062 .49954 L
.50067 .49973 L
.50069 .49989 L
.50068 .50004 L
.50065 .50016 L
.50059 .50025 L
.50052 .50032 L
.50044 .50036 L
.50035 .50039 L
.50027 .50039 L
.50019 .50038 L
.50011 .50035 L
.50004 .50032 L
.49998 .50027 L
.49993 .50023 L
.49989 .50018 L
.49987 .50013 L
.49985 .50009 L
.49984 .50005 L
.49984 .50001 L
.49984 .49998 L
.49985 .49995 L
.49987 .49993 L
.49989 .49992 L
.49991 .49991 L
.49993 .49991 L
.49995 .49991 L
.49996 .49991 L
.49998 .49992 L
.5 .49993 L
.50001 .49994 L
.50002 .49995 L
Mistroke
.50003 .49996 L
.50003 .49997 L
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50003 .50001 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.165 0 1 r
.79984 .46379 m
.79344 .5241 L
.77633 .57376 L
.75092 .61249 L
.71955 .64051 L
.68444 .65842 L
.64759 .66711 L
.61075 .66773 L
.5754 .66153 L
.54271 .64988 L
.51356 .6341 L
.48855 .61549 L
.46801 .59525 L
.45205 .57445 L
.44056 .55402 L
.4333 .5347 L
.42987 .5171 L
.4298 .50164 L
.43254 .48859 L
.43755 .4781 L
.44424 .47017 L
.45209 .4647 L
.4606 .46152 L
.46932 .46039 L
.47786 .46103 L
.48592 .46312 L
.49325 .46635 L
.49967 .47041 L
.50507 .475 L
.5094 .47986 L
.51266 .48473 L
.5149 .48944 L
.51617 .49381 L
.5166 .49773 L
.51629 .50111 L
.51538 .5039 L
.51401 .50609 L
.51229 .50769 L
.51036 .50872 L
.50832 .50923 L
.50628 .5093 L
.50431 .50898 L
.50249 .50835 L
.50086 .50749 L
.49946 .50647 L
.4983 .50536 L
.4974 .50421 L
.49675 .50307 L
.49633 .502 L
.49612 .50101 L
Mistroke
.49611 .50015 L
.49625 .49942 L
.49652 .49882 L
.49688 .49838 L
.49731 .49806 L
.49778 .49788 L
.49827 .49781 L
.49874 .49784 L
.49919 .49795 L
.4996 .49812 L
.49996 .49834 L
.50026 .4986 L
.50051 .49887 L
.50069 .49914 L
.50082 .4994 L
.50089 .49964 L
.50092 .49986 L
.5009 .50005 L
.50086 .50021 L
.50078 .50033 L
.50069 .50042 L
.50058 .50048 L
.50047 .50051 L
.50036 .50052 L
.50025 .5005 L
.50014 .50047 L
.50005 .50042 L
.49998 .50036 L
.49991 .5003 L
.49986 .50024 L
.49982 .50017 L
.4998 .50011 L
.49979 .50006 L
.49978 .50001 L
.49979 .49997 L
.49981 .49994 L
.49983 .49991 L
.49985 .49989 L
.49988 .49988 L
.4999 .49988 L
.49993 .49988 L
.49995 .49989 L
.49998 .4999 L
.5 .49991 L
.50001 .49992 L
.50003 .49994 L
.50004 .49995 L
.50004 .49997 L
.50005 .49998 L
.50005 .49999 L
Mistroke
.50005 .5 L
.50005 .50001 L
.50004 .50002 L
.50004 .50002 L
.50003 .50003 L
.50003 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50003 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .704 r
.55399 .54954 m
.54263 .55159 L
.53138 .55124 L
.52069 .5489 L
.51088 .54499 L
.50222 .5399 L
.49485 .53403 L
.48888 .52774 L
.48431 .52136 L
.4811 .51514 L
.47916 .50932 L
.47837 .50406 L
.47856 .49948 L
.47959 .49566 L
.48126 .49262 L
.48342 .49037 L
.48589 .48886 L
.48853 .48804 L
.49121 .48783 L
.4938 .48815 L
.49623 .48888 L
.49842 .48994 L
.50032 .49124 L
.5019 .49267 L
.50316 .49417 L
.50408 .49566 L
.50469 .49709 L
.50502 .4984 L
.5051 .49957 L
.50495 .50056 L
.50464 .50138 L
.50418 .502 L
.50364 .50245 L
.50303 .50273 L
.50241 .50285 L
.50178 .50284 L
.50119 .50272 L
.50064 .50251 L
.50016 .50223 L
.49974 .50191 L
.49941 .50156 L
.49915 .50121 L
.49896 .50086 L
.49885 .50054 L
.4988 .50024 L
.49881 .49999 L
.49886 .49977 L
.49895 .4996 L
.49907 .49947 L
.49921 .49939 L
Mistroke
.49935 .49934 L
.4995 .49933 L
.49965 .49934 L
.49978 .49938 L
.4999 .49944 L
.50001 .49951 L
.5001 .49959 L
.50017 .49967 L
.50022 .49975 L
.50026 .49983 L
.50028 .49991 L
.50028 .49997 L
.50028 .50003 L
.50026 .50007 L
.50023 .50011 L
.5002 .50013 L
.50017 .50015 L
.50014 .50016 L
.5001 .50016 L
.50007 .50015 L
.50004 .50014 L
.50001 .50012 L
.49999 .50011 L
.49997 .50009 L
.49995 .50007 L
.49994 .50005 L
.49994 .50003 L
.49993 .50001 L
.49993 .5 L
.49994 .49999 L
.49994 .49998 L
.49995 .49997 L
.49996 .49997 L
.49996 .49996 L
.49997 .49996 L
.49998 .49996 L
.49999 .49997 L
.49999 .49997 L
.5 .49997 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
Mistroke
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .981 1 r
.18685 .65002 m
.1731 .5694 L
.17463 .49895 L
.18892 .43985 L
.21336 .39264 L
.24534 .35731 L
.28237 .33335 L
.32216 .31991 L
.36267 .31582 L
.40217 .31976 L
.43924 .33027 L
.47279 .34588 L
.50204 .36515 L
.52651 .38672 L
.546 .40935 L
.56051 .43198 L
.57028 .45369 L
.57567 .47377 L
.57716 .49168 L
.57534 .50704 L
.57079 .51966 L
.56414 .52946 L
.55599 .53651 L
.54692 .54097 L
.53742 .54308 L
.52795 .54312 L
.51889 .54143 L
.51052 .53836 L
.50308 .53425 L
.49671 .52942 L
.49149 .5242 L
.48745 .51885 L
.48456 .5136 L
.48275 .50865 L
.48193 .50415 L
.48195 .5002 L
.4827 .49688 L
.48402 .49422 L
.48576 .49222 L
.4878 .49085 L
.48999 .49006 L
.49224 .4898 L
.49443 .48999 L
.49649 .49055 L
.49837 .4914 L
.5 .49245 L
.50138 .49364 L
.50248 .49489 L
.5033 .49614 L
.50386 .49735 L
Mistroke
.50418 .49847 L
.50427 .49947 L
.50418 .50033 L
.50394 .50104 L
.50358 .5016 L
.50313 .502 L
.50263 .50226 L
.50211 .50238 L
.50158 .50239 L
.50108 .5023 L
.50061 .50214 L
.5002 .50191 L
.49984 .50165 L
.49955 .50136 L
.49932 .50106 L
.49915 .50077 L
.49905 .5005 L
.499 .50025 L
.499 .50003 L
.49904 .49984 L
.49911 .49969 L
.4992 .49958 L
.49932 .4995 L
.49944 .49945 L
.49956 .49944 L
.49968 .49944 L
.4998 .49947 L
.4999 .49952 L
.49999 .49958 L
.50007 .49964 L
.50013 .49971 L
.50018 .49978 L
.50021 .49985 L
.50023 .49991 L
.50024 .49997 L
.50023 .50002 L
.50022 .50006 L
.5002 .50009 L
.50018 .50011 L
.50015 .50012 L
.50012 .50013 L
.50009 .50013 L
.50006 .50013 L
.50004 .50012 L
.50001 .50011 L
.49999 .50009 L
.49998 .50008 L
.49996 .50006 L
.49995 .50004 L
.49995 .50003 L
Mistroke
.49994 .50001 L
.49994 .5 L
.49995 .49999 L
.49995 .49998 L
.49996 .49998 L
.49996 .49997 L
.49997 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49998 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .627 r
.73365 .27089 m
.76525 .34946 L
.78117 .42144 L
.7833 .485 L
.77375 .53896 L
.75479 .5827 L
.72868 .61611 L
.69762 .63951 L
.66364 .65357 L
.62858 .65924 L
.594 .65763 L
.56121 .64997 L
.53124 .63755 L
.50483 .62162 L
.48247 .60338 L
.4644 .58394 L
.45066 .56426 L
.44109 .54517 L
.43542 .52734 L
.43323 .51128 L
.43407 .49735 L
.43742 .48576 L
.44272 .4766 L
.44947 .46984 L
.45715 .46538 L
.46532 .46302 L
.47356 .46251 L
.48153 .46359 L
.48896 .46595 L
.49564 .46929 L
.50143 .47332 L
.50622 .47778 L
.51 .4824 L
.51277 .48699 L
.51459 .49136 L
.51553 .49538 L
.5157 .49893 L
.51521 .50196 L
.5142 .50442 L
.51278 .50631 L
.51107 .50765 L
.5092 .50846 L
.50726 .50881 L
.50534 .50875 L
.50352 .50834 L
.50184 .50767 L
.50037 .5068 L
.49911 .5058 L
.49809 .50473 L
.49732 .50364 L
Mistroke
.49677 .50258 L
.49644 .50158 L
.49631 .50069 L
.49634 .4999 L
.49652 .49925 L
.4968 .49874 L
.49717 .49835 L
.4976 .4981 L
.49805 .49796 L
.4985 .49792 L
.49895 .49798 L
.49936 .4981 L
.49973 .49828 L
.50006 .49851 L
.50033 .49875 L
.50054 .49901 L
.5007 .49926 L
.5008 .4995 L
.50086 .49973 L
.50087 .49993 L
.50085 .5001 L
.50079 .50024 L
.50071 .50034 L
.50062 .50042 L
.50052 .50047 L
.50041 .50049 L
.5003 .50049 L
.5002 .50046 L
.50011 .50043 L
.50003 .50038 L
.49996 .50033 L
.4999 .50027 L
.49985 .50021 L
.49982 .50015 L
.4998 .50009 L
.4998 .50004 L
.4998 .5 L
.49981 .49996 L
.49982 .49993 L
.49984 .49991 L
.49987 .4999 L
.49989 .49989 L
.49992 .49988 L
.49994 .49989 L
.49996 .49989 L
.49998 .4999 L
.5 .49992 L
.50002 .49993 L
.50003 .49994 L
.50004 .49996 L
Mistroke
.50004 .49997 L
.50005 .49998 L
.50005 .5 L
.50005 .5 L
.50004 .50001 L
.50004 .50002 L
.50003 .50002 L
.50003 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.168 0 1 r
.71904 .8153 m
.65212 .80563 L
.58986 .7853 L
.534 .75682 L
.48574 .72264 L
.44581 .68505 L
.41445 .64609 L
.39155 .60755 L
.37666 .57089 L
.3691 .53728 L
.36798 .50758 L
.37232 .48234 L
.38107 .46186 L
.39318 .44619 L
.40761 .43519 L
.42342 .42855 L
.43975 .42583 L
.45587 .42652 L
.47117 .43003 L
.48516 .43578 L
.4975 .44317 L
.50796 .45165 L
.51642 .4607 L
.52287 .46987 L
.52737 .47877 L
.53005 .48709 L
.5311 .49459 L
.53073 .50111 L
.5292 .50653 L
.52675 .51082 L
.52361 .51399 L
.52004 .5161 L
.51624 .51722 L
.5124 .51747 L
.50868 .51698 L
.50521 .51589 L
.50209 .51434 L
.49939 .51247 L
.49714 .5104 L
.49537 .50824 L
.49407 .50611 L
.49322 .50407 L
.49277 .50219 L
.49268 .50053 L
.4929 .49911 L
.49337 .49796 L
.49403 .49707 L
.49482 .49645 L
.4957 .49606 L
.4966 .4959 L
Mistroke
.49749 .49592 L
.49834 .49611 L
.49913 .49642 L
.49982 .49682 L
.5004 .49729 L
.50088 .49779 L
.50124 .4983 L
.5015 .49879 L
.50166 .49925 L
.50172 .49967 L
.50171 .50004 L
.50162 .50034 L
.50149 .50058 L
.50132 .50076 L
.50112 .50088 L
.50091 .50095 L
.5007 .50097 L
.5005 .50094 L
.5003 .50089 L
.50013 .5008 L
.49998 .5007 L
.49985 .50058 L
.49975 .50047 L
.49968 .50035 L
.49963 .50023 L
.4996 .50013 L
.49959 .50004 L
.49961 .49996 L
.49963 .49989 L
.49967 .49984 L
.49971 .49981 L
.49976 .49978 L
.49981 .49977 L
.49986 .49977 L
.49991 .49978 L
.49995 .4998 L
.49999 .49982 L
.50002 .49985 L
.50005 .49988 L
.50007 .4999 L
.50008 .49993 L
.50009 .49996 L
.5001 .49998 L
.50009 .5 L
.50009 .50002 L
.50008 .50003 L
.50007 .50004 L
.50006 .50005 L
.50005 .50005 L
.50004 .50005 L
Mistroke
.50003 .50005 L
.50002 .50005 L
.50001 .50004 L
.5 .50004 L
.49999 .50003 L
.49999 .50003 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .735 r
.35161 .42984 m
.37082 .41384 L
.39211 .40385 L
.4143 .39932 L
.43636 .39953 L
.45741 .40373 L
.47679 .41111 L
.49399 .42085 L
.50867 .4322 L
.52064 .44444 L
.52987 .45693 L
.53642 .46914 L
.54046 .48062 L
.54224 .49104 L
.54204 .50014 L
.54019 .50778 L
.53703 .51387 L
.5329 .51844 L
.52811 .52153 L
.52297 .52327 L
.51774 .5238 L
.51264 .52329 L
.50785 .52193 L
.50351 .51991 L
.49973 .51742 L
.49657 .51463 L
.49406 .51171 L
.49218 .50879 L
.49092 .50598 L
.49022 .50339 L
.49003 .50107 L
.49027 .49909 L
.49085 .49746 L
.49171 .49619 L
.49277 .49528 L
.49394 .49471 L
.49517 .49443 L
.49639 .49443 L
.49756 .49465 L
.49864 .49504 L
.4996 .49558 L
.50043 .4962 L
.5011 .49687 L
.50162 .49757 L
.50199 .49824 L
.50223 .49888 L
.50234 .49946 L
.50233 .49997 L
.50224 .5004 L
.50206 .50075 L
Mistroke
.50184 .50101 L
.50158 .50118 L
.50129 .50128 L
.501 .50132 L
.50072 .50129 L
.50045 .50122 L
.50021 .50111 L
.5 .50098 L
.49982 .50082 L
.49968 .50066 L
.49957 .5005 L
.4995 .50034 L
.49946 .5002 L
.49945 .50007 L
.49946 .49996 L
.49949 .49987 L
.49954 .49979 L
.4996 .49974 L
.49966 .49971 L
.49973 .49969 L
.4998 .49969 L
.49986 .4997 L
.49992 .49972 L
.49997 .49975 L
.50002 .49979 L
.50006 .49982 L
.50009 .49986 L
.50011 .4999 L
.50012 .49994 L
.50013 .49997 L
.50013 .5 L
.50012 .50002 L
.50012 .50004 L
.5001 .50005 L
.50009 .50006 L
.50007 .50007 L
.50006 .50007 L
.50004 .50007 L
.50003 .50007 L
.50001 .50006 L
.5 .50005 L
.49999 .50005 L
.49998 .50004 L
.49998 .50003 L
.49997 .50002 L
.49997 .50001 L
.49997 .5 L
.49997 .5 L
.49997 .49999 L
.49997 .49999 L
Mistroke
.49998 .49999 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.484 1 0 r
.77897 .29431 m
.80435 .37745 L
.81348 .45215 L
.8086 .51677 L
.79217 .57034 L
.7667 .6125 L
.73464 .6434 L
.69835 .66359 L
.65996 .67401 L
.62133 .67579 L
.58405 .67026 L
.5494 .65881 L
.51833 .64284 L
.49152 .62373 L
.46935 .60273 L
.45197 .581 L
.43929 .55952 L
.43108 .53911 L
.42695 .52041 L
.4264 .50389 L
.42888 .48988 L
.4338 .47851 L
.44059 .46983 L
.44866 .46375 L
.45749 .4601 L
.4666 .45863 L
.47558 .45905 L
.4841 .46104 L
.49188 .46426 L
.49875 .4684 L
.50455 .47314 L
.50925 .47819 L
.51282 .4833 L
.51531 .48826 L
.51678 .4929 L
.51735 .49707 L
.51713 .50069 L
.51626 .5037 L
.51488 .50608 L
.51313 .50784 L
.51113 .509 L
.50901 .50961 L
.50687 .50974 L
.5048 .50946 L
.50287 .50885 L
.50113 .50798 L
.49963 .50693 L
.49838 .50577 L
.4974 .50457 L
.49668 .50338 L
Mistroke
.49621 .50224 L
.49597 .5012 L
.49592 .50028 L
.49605 .49949 L
.49631 .49885 L
.49668 .49836 L
.49712 .49801 L
.49761 .4978 L
.49811 .49771 L
.49861 .49773 L
.49909 .49783 L
.49952 .49801 L
.4999 .49823 L
.50023 .49849 L
.5005 .49877 L
.5007 .49906 L
.50084 .49933 L
.50092 .49959 L
.50096 .49982 L
.50095 .50002 L
.5009 .50019 L
.50083 .50033 L
.50073 .50043 L
.50062 .50049 L
.50051 .50053 L
.50039 .50054 L
.50027 .50053 L
.50017 .50049 L
.50007 .50045 L
.49999 .50039 L
.49991 .50032 L
.49986 .50026 L
.49982 .50019 L
.49979 .50013 L
.49978 .50007 L
.49977 .50002 L
.49978 .49997 L
.49979 .49994 L
.49981 .49991 L
.49984 .49989 L
.49987 .49988 L
.49989 .49987 L
.49992 .49987 L
.49995 .49988 L
.49997 .49989 L
.49999 .4999 L
.50001 .49992 L
.50003 .49993 L
.50004 .49995 L
.50005 .49996 L
Mistroke
.50005 .49998 L
.50005 .49999 L
.50005 .5 L
.50005 .50001 L
.50005 .50002 L
.50004 .50002 L
.50004 .50003 L
.50003 .50003 L
.50002 .50003 L
.50002 .50003 L
.50001 .50003 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .31 r
.37337 .30719 m
.41398 .31443 L
.45151 .32793 L
.48495 .34614 L
.51363 .36759 L
.53716 .39088 L
.55542 .4148 L
.56854 .43829 L
.57681 .46047 L
.58068 .48067 L
.5807 .49841 L
.57749 .51336 L
.5717 .52537 L
.56397 .53444 L
.55492 .54068 L
.54513 .54429 L
.53511 .54555 L
.52529 .54478 L
.51604 .54235 L
.50763 .53862 L
.50026 .53394 L
.49407 .52865 L
.48911 .52307 L
.48538 .51746 L
.48284 .51205 L
.48138 .50703 L
.48091 .50253 L
.48128 .49866 L
.48233 .49546 L
.48393 .49296 L
.48591 .49113 L
.48813 .48996 L
.49047 .48938 L
.49282 .48931 L
.49508 .48968 L
.49717 .49041 L
.49904 .4914 L
.50065 .49258 L
.50197 .49386 L
.503 .49519 L
.50375 .49649 L
.50423 .49773 L
.50446 .49885 L
.50447 .49985 L
.50431 .50069 L
.504 .50136 L
.50358 .50188 L
.50308 .50223 L
.50254 .50244 L
.50198 .50252 L
Mistroke
.50144 .50249 L
.50092 .50236 L
.50045 .50215 L
.50004 .5019 L
.49969 .50161 L
.49941 .5013 L
.4992 .50099 L
.49906 .50069 L
.49897 .50041 L
.49894 .50016 L
.49896 .49994 L
.49902 .49976 L
.4991 .49962 L
.49921 .49952 L
.49933 .49945 L
.49946 .49941 L
.49959 .49941 L
.49972 .49943 L
.49984 .49947 L
.49994 .49952 L
.50003 .49958 L
.5001 .49966 L
.50016 .49973 L
.50021 .4998 L
.50023 .49987 L
.50025 .49993 L
.50025 .49999 L
.50024 .50003 L
.50022 .50007 L
.5002 .5001 L
.50017 .50012 L
.50014 .50013 L
.50011 .50014 L
.50008 .50014 L
.50005 .50013 L
.50003 .50012 L
.5 .50011 L
.49998 .50009 L
.49997 .50007 L
.49996 .50006 L
.49995 .50004 L
.49994 .50002 L
.49994 .50001 L
.49994 .5 L
.49995 .49999 L
.49995 .49998 L
.49996 .49997 L
.49996 .49997 L
.49997 .49997 L
.49998 .49997 L
Mistroke
.49998 .49997 L
.49999 .49997 L
.5 .49997 L
.5 .49998 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.424 0 1 r
.50839 .20757 m
.5613 .25506 L
.60325 .30473 L
.63434 .35423 L
.65507 .40161 L
.66627 .44532 L
.66902 .4842 L
.66457 .51747 L
.65426 .5447 L
.63943 .56577 L
.62141 .58083 L
.60142 .59024 L
.58059 .59453 L
.55988 .59435 L
.5401 .59042 L
.52189 .58351 L
.50573 .57437 L
.49193 .56373 L
.48068 .55224 L
.472 .54051 L
.46583 .52904 L
.46203 .51825 L
.46035 .50847 L
.46052 .49991 L
.46225 .49274 L
.46521 .487 L
.46908 .48271 L
.47357 .4798 L
.4784 .47816 L
.48331 .47766 L
.48811 .47813 L
.49261 .4794 L
.49668 .48129 L
.50023 .48363 L
.5032 .48624 L
.50557 .48899 L
.50733 .49173 L
.50852 .49437 L
.50918 .49681 L
.50936 .49898 L
.50914 .50085 L
.50859 .50238 L
.50779 .50357 L
.5068 .50443 L
.5057 .50497 L
.50455 .50522 L
.5034 .50523 L
.5023 .50503 L
.50128 .50466 L
.50038 .50416 L
Mistroke
.4996 .50357 L
.49897 .50294 L
.49848 .50229 L
.49813 .50165 L
.49791 .50105 L
.49781 .50051 L
.49781 .50003 L
.4979 .49962 L
.49806 .4993 L
.49827 .49906 L
.49852 .49889 L
.49878 .4988 L
.49906 .49876 L
.49932 .49879 L
.49957 .49885 L
.4998 .49896 L
.5 .49908 L
.50017 .49923 L
.5003 .49938 L
.5004 .49953 L
.50047 .49968 L
.50051 .49981 L
.50052 .49994 L
.50051 .50004 L
.50048 .50013 L
.50043 .50019 L
.50038 .50024 L
.50032 .50027 L
.50026 .50029 L
.50019 .50029 L
.50013 .50028 L
.50007 .50026 L
.50002 .50023 L
.49998 .5002 L
.49995 .50017 L
.49992 .50013 L
.4999 .50009 L
.49988 .50006 L
.49988 .50003 L
.49988 .5 L
.49988 .49998 L
.49989 .49996 L
.4999 .49995 L
.49992 .49994 L
.49993 .49993 L
.49995 .49993 L
.49996 .49993 L
.49998 .49994 L
.49999 .49994 L
.5 .49995 L
Mistroke
.50001 .49996 L
.50002 .49997 L
.50002 .49997 L
.50003 .49998 L
.50003 .49999 L
.50003 .5 L
.50003 .5 L
.50003 .50001 L
.50002 .50001 L
.50002 .50001 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .938 r
.45128 .22242 m
.50395 .25718 L
.54801 .29607 L
.58307 .33687 L
.60919 .37764 L
.62674 .41676 L
.63641 .45293 L
.63907 .48518 L
.63574 .51284 L
.62752 .53554 L
.61552 .55318 L
.60082 .56586 L
.58446 .57388 L
.56734 .57765 L
.55028 .57771 L
.53394 .57465 L
.51888 .5691 L
.50547 .56168 L
.494 .55298 L
.48461 .54356 L
.47734 .53391 L
.47215 .52445 L
.4689 .51554 L
.46742 .50743 L
.46748 .50033 L
.46883 .49435 L
.47121 .48956 L
.47436 .48596 L
.47803 .4835 L
.48199 .48209 L
.48603 .48162 L
.48998 .48197 L
.4937 .48298 L
.49707 .48451 L
.50002 .48641 L
.5025 .48855 L
.50448 .4908 L
.50596 .49306 L
.50696 .49524 L
.50753 .49726 L
.5077 .49906 L
.50754 .50061 L
.5071 .50189 L
.50645 .50288 L
.50564 .5036 L
.50474 .50407 L
.5038 .50429 L
.50285 .50431 L
.50194 .50415 L
.5011 .50385 L
Mistroke
.50035 .50345 L
.49971 .50297 L
.49918 .50245 L
.49877 .50192 L
.49848 .50139 L
.49829 .50089 L
.4982 .50044 L
.4982 .50004 L
.49827 .49971 L
.49839 .49944 L
.49857 .49923 L
.49877 .49909 L
.49899 .49901 L
.49921 .49898 L
.49943 .499 L
.49964 .49905 L
.49983 .49914 L
.49999 .49924 L
.50013 .49936 L
.50024 .49948 L
.50032 .49961 L
.50038 .49973 L
.50042 .49984 L
.50043 .49994 L
.50042 .50003 L
.5004 .5001 L
.50036 .50016 L
.50032 .5002 L
.50027 .50022 L
.50021 .50024 L
.50016 .50024 L
.50011 .50023 L
.50006 .50021 L
.50002 .50019 L
.49999 .50017 L
.49996 .50014 L
.49993 .50011 L
.49992 .50008 L
.49991 .50005 L
.4999 .50003 L
.4999 .5 L
.4999 .49999 L
.49991 .49997 L
.49992 .49996 L
.49993 .49995 L
.49994 .49995 L
.49996 .49994 L
.49997 .49994 L
.49998 .49995 L
.49999 .49995 L
Mistroke
.5 .49996 L
.50001 .49996 L
.50001 .49997 L
.50002 .49998 L
.50002 .49998 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .657 0 r
.30134 .79737 m
.25579 .71444 L
.22731 .63625 L
.21432 .56517 L
.21483 .50289 L
.22666 .45049 L
.24753 .40849 L
.27514 .37689 L
.30731 .35528 L
.34203 .34293 L
.37748 .33885 L
.41215 .34186 L
.44476 .35072 L
.47434 .36412 L
.5002 .38081 L
.52191 .39958 L
.53925 .41935 L
.55224 .43918 L
.56105 .45825 L
.56601 .47594 L
.56753 .49174 L
.56611 .50534 L
.56227 .51654 L
.55656 .52528 L
.5495 .53161 L
.5416 .53566 L
.5333 .53763 L
.525 .53778 L
.51704 .5364 L
.50967 .53378 L
.5031 .53023 L
.49746 .52604 L
.49282 .52149 L
.48922 .5168 L
.48663 .5122 L
.48499 .50784 L
.48421 .50388 L
.48419 .50039 L
.4848 .49745 L
.48592 .49508 L
.48743 .49329 L
.4892 .49206 L
.49111 .49134 L
.49308 .49108 L
.495 .49122 L
.49682 .49169 L
.49847 .49242 L
.49992 .49333 L
.50113 .49436 L
.50211 .49546 L
Mistroke
.50285 .49655 L
.50335 .49761 L
.50364 .4986 L
.50374 .49948 L
.50367 .50025 L
.50347 .50088 L
.50316 .50137 L
.50277 .50173 L
.50234 .50196 L
.50188 .50208 L
.50142 .50209 L
.50097 .50202 L
.50056 .50188 L
.5002 .50169 L
.49988 .50146 L
.49962 .50121 L
.49942 .50095 L
.49927 .50069 L
.49917 .50045 L
.49913 .50023 L
.49912 .50003 L
.49916 .49987 L
.49922 .49974 L
.4993 .49963 L
.49939 .49956 L
.4995 .49952 L
.49961 .49951 L
.49972 .49951 L
.49982 .49954 L
.49991 .49958 L
.49999 .49963 L
.50006 .49968 L
.50011 .49974 L
.50016 .4998 L
.50018 .49986 L
.5002 .49992 L
.50021 .49997 L
.5002 .50001 L
.50019 .50005 L
.50018 .50007 L
.50016 .50009 L
.50013 .50011 L
.50011 .50011 L
.50008 .50012 L
.50006 .50011 L
.50003 .5001 L
.50001 .50009 L
.49999 .50008 L
.49998 .50007 L
.49997 .50005 L
Mistroke
.49996 .50004 L
.49995 .50003 L
.49995 .50001 L
.49995 .5 L
.49995 .49999 L
.49996 .49999 L
.49996 .49998 L
.49997 .49998 L
.49997 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .636 r
.75524 .48637 m
.74666 .535 L
.72959 .57443 L
.70608 .60455 L
.67811 .62565 L
.6475 .63834 L
.61591 .64346 L
.58475 .64202 L
.55521 .63514 L
.5282 .62395 L
.5044 .60961 L
.48425 .59318 L
.46796 .57566 L
.45557 .55793 L
.44694 .54074 L
.44182 .52467 L
.43985 .51019 L
.4406 .49764 L
.44361 .48719 L
.44838 .47893 L
.45446 .47284 L
.46138 .46881 L
.46873 .46668 L
.47616 .46622 L
.48334 .46719 L
.49004 .46931 L
.49606 .47232 L
.50127 .47596 L
.5056 .47997 L
.509 .48414 L
.5115 .48827 L
.51314 .49221 L
.51399 .49583 L
.51414 .49903 L
.51371 .50176 L
.51279 .50398 L
.51151 .50568 L
.50998 .50689 L
.50829 .50762 L
.50654 .50794 L
.50481 .50788 L
.50317 .50752 L
.50166 .50691 L
.50033 .50613 L
.4992 .50523 L
.49828 .50426 L
.49758 .50328 L
.49709 .50232 L
.49679 .50143 L
.49667 .50062 L
Mistroke
.4967 .49992 L
.49686 .49933 L
.49712 .49886 L
.49745 .49852 L
.49783 .49829 L
.49824 .49816 L
.49865 .49813 L
.49905 .49818 L
.49942 .49829 L
.49976 .49845 L
.50005 .49865 L
.50029 .49887 L
.50049 .49911 L
.50063 .49933 L
.50072 .49955 L
.50077 .49976 L
.50078 .49993 L
.50076 .50009 L
.50071 .50021 L
.50064 .50031 L
.50056 .50038 L
.50047 .50042 L
.50037 .50044 L
.50027 .50044 L
.50018 .50042 L
.5001 .50039 L
.50002 .50034 L
.49996 .50029 L
.49991 .50024 L
.49987 .50019 L
.49984 .50013 L
.49982 .50008 L
.49982 .50004 L
.49982 .5 L
.49983 .49996 L
.49984 .49994 L
.49986 .49992 L
.49988 .49991 L
.4999 .4999 L
.49992 .4999 L
.49995 .4999 L
.49997 .4999 L
.49999 .49991 L
.5 .49992 L
.50002 .49994 L
.50003 .49995 L
.50003 .49996 L
.50004 .49997 L
.50004 .49999 L
.50004 .5 L
Mistroke
.50004 .5 L
.50004 .50001 L
.50004 .50002 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.488 0 1 r
.22034 .3529 m
.25926 .32508 L
.30155 .30873 L
.345 .30265 L
.38766 .30544 L
.42797 .31556 L
.46469 .33143 L
.49692 .35149 L
.5241 .37428 L
.54596 .39843 L
.56247 .42277 L
.57383 .44628 L
.58041 .46817 L
.58272 .48782 L
.58135 .5048 L
.57695 .51887 L
.57018 .52992 L
.56169 .538 L
.55209 .54326 L
.54196 .54595 L
.53177 .54637 L
.52195 .54487 L
.51282 .54181 L
.50465 .53758 L
.4976 .53252 L
.49179 .52697 L
.48723 .52123 L
.48392 .51557 L
.48178 .51019 L
.48071 .50527 L
.48059 .50093 L
.48126 .49725 L
.48257 .49427 L
.48437 .49199 L
.48651 .49041 L
.48884 .48946 L
.49124 .48908 L
.49361 .4892 L
.49586 .48974 L
.49791 .49059 L
.49971 .49169 L
.50124 .49294 L
.50247 .49428 L
.5034 .49563 L
.50405 .49693 L
.50443 .49815 L
.50458 .49925 L
.50452 .5002 L
.50428 .50099 L
.50392 .50162 L
Mistroke
.50345 .50208 L
.50292 .50238 L
.50236 .50254 L
.5018 .50257 L
.50125 .50249 L
.50074 .50233 L
.50029 .5021 L
.49989 .50182 L
.49957 .50152 L
.49931 .5012 L
.49912 .50088 L
.499 .50059 L
.49893 .50031 L
.49892 .50007 L
.49896 .49986 L
.49903 .49969 L
.49913 .49956 L
.49924 .49947 L
.49937 .49942 L
.49951 .4994 L
.49964 .4994 L
.49976 .49943 L
.49988 .49948 L
.49998 .49954 L
.50006 .4996 L
.50013 .49968 L
.50019 .49975 L
.50022 .49983 L
.50024 .49989 L
.50025 .49995 L
.50025 .50001 L
.50024 .50005 L
.50022 .50009 L
.50019 .50011 L
.50016 .50013 L
.50013 .50014 L
.5001 .50014 L
.50007 .50014 L
.50004 .50013 L
.50002 .50012 L
.5 .5001 L
.49998 .50009 L
.49996 .50007 L
.49995 .50005 L
.49994 .50003 L
.49994 .50002 L
.49994 .5 L
.49994 .49999 L
.49995 .49998 L
.49995 .49998 L
Mistroke
.49996 .49997 L
.49996 .49997 L
.49997 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49997 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.929 0 1 r
.34633 .55468 m
.34303 .5181 L
.34654 .48666 L
.35562 .46081 L
.36902 .44067 L
.3855 .42614 L
.40392 .41689 L
.42322 .41245 L
.44249 .41223 L
.46097 .41555 L
.47805 .42172 L
.49326 .43002 L
.50629 .43979 L
.51699 .4504 L
.52529 .46129 L
.53124 .47198 L
.53499 .48208 L
.53674 .49127 L
.53673 .49933 L
.53526 .50613 L
.53262 .51159 L
.52909 .51571 L
.52497 .51854 L
.52051 .52017 L
.51595 .52074 L
.51148 .52038 L
.50727 .51927 L
.50345 .51757 L
.5001 .51543 L
.49728 .51302 L
.49503 .51048 L
.49333 .50793 L
.49218 .50547 L
.49152 .50318 L
.49131 .50114 L
.49148 .49938 L
.49196 .49792 L
.49269 .49679 L
.49359 .49596 L
.4946 .49543 L
.49567 .49516 L
.49674 .49513 L
.49777 .49531 L
.49872 .49564 L
.49957 .49609 L
.5003 .49663 L
.5009 .49721 L
.50137 .49781 L
.50171 .49841 L
.50193 .49897 L
Mistroke
.50203 .49948 L
.50204 .49993 L
.50196 .50031 L
.50182 .50062 L
.50163 .50086 L
.5014 .50102 L
.50115 .50111 L
.5009 .50115 L
.50065 .50113 L
.50042 .50107 L
.50021 .50098 L
.50002 .50086 L
.49986 .50073 L
.49973 .50059 L
.49964 .50045 L
.49957 .50031 L
.49953 .50019 L
.49952 .50007 L
.49953 .49997 L
.49955 .49989 L
.49959 .49983 L
.49964 .49978 L
.4997 .49975 L
.49976 .49973 L
.49982 .49973 L
.49987 .49974 L
.49993 .49976 L
.49997 .49978 L
.50001 .49981 L
.50005 .49984 L
.50007 .49988 L
.50009 .49991 L
.50011 .49994 L
.50011 .49997 L
.50011 .49999 L
.50011 .50002 L
.5001 .50003 L
.50009 .50005 L
.50008 .50006 L
.50006 .50006 L
.50005 .50006 L
.50004 .50006 L
.50002 .50006 L
.50001 .50005 L
.5 .50005 L
.49999 .50004 L
.49999 .50003 L
.49998 .50003 L
.49998 .50002 L
.49997 .50001 L
Mistroke
.49997 .5 L
.49997 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.476 0 1 r
.69886 .33194 m
.72085 .39458 L
.73048 .45138 L
.72935 .501 L
.71922 .54262 L
.70196 .57585 L
.67939 .60071 L
.65327 .61755 L
.62521 .62699 L
.59666 .62984 L
.56882 .62704 L
.54269 .6196 L
.51906 .60858 L
.49846 .59498 L
.48122 .57977 L
.46751 .56381 L
.45729 .54786 L
.45043 .53256 L
.44664 .51841 L
.4456 .5058 L
.4469 .49498 L
.45012 .4861 L
.45481 .4792 L
.46056 .47424 L
.46696 .4711 L
.47366 .46963 L
.48033 .4696 L
.48672 .4708 L
.49262 .47297 L
.49786 .47587 L
.50235 .47928 L
.50602 .48296 L
.50886 .48674 L
.51089 .49043 L
.51216 .49392 L
.51274 .49709 L
.51272 .49987 L
.51219 .50221 L
.51126 .50408 L
.51003 .50549 L
.50859 .50646 L
.50705 .50701 L
.50546 .50719 L
.50392 .50705 L
.50246 .50666 L
.50114 .50606 L
.49999 .50532 L
.49902 .50448 L
.49825 .5036 L
.49767 .50271 L
Mistroke
.49728 .50186 L
.49706 .50107 L
.49699 .50037 L
.49705 .49976 L
.49722 .49926 L
.49748 .49887 L
.49779 .49859 L
.49814 .49841 L
.49851 .49832 L
.49888 .49831 L
.49924 .49838 L
.49957 .49849 L
.49986 .49865 L
.50011 .49884 L
.50032 .49904 L
.50048 .49925 L
.5006 .49946 L
.50067 .49965 L
.5007 .49983 L
.50071 .49998 L
.50068 .50011 L
.50063 .50022 L
.50056 .5003 L
.50048 .50035 L
.5004 .50039 L
.50031 .5004 L
.50022 .50039 L
.50014 .50037 L
.50007 .50034 L
.5 .5003 L
.49995 .50025 L
.49991 .5002 L
.49987 .50015 L
.49985 .50011 L
.49984 .50006 L
.49983 .50002 L
.49984 .49999 L
.49985 .49996 L
.49986 .49994 L
.49988 .49992 L
.4999 .49991 L
.49992 .49991 L
.49994 .49991 L
.49996 .49991 L
.49997 .49992 L
.49999 .49992 L
.50001 .49993 L
.50002 .49995 L
.50003 .49996 L
.50003 .49997 L
Mistroke
.50004 .49998 L
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50003 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.205 1 0 r
.45129 .32561 m
.48517 .34415 L
.5142 .36595 L
.538 .38961 L
.55646 .41388 L
.5697 .4377 L
.57802 .46019 L
.58189 .48066 L
.58187 .49861 L
.57857 .51374 L
.57266 .52589 L
.5648 .53506 L
.5556 .54135 L
.54566 .54498 L
.53549 .54622 L
.52553 .54542 L
.51615 .54293 L
.50763 .53913 L
.50017 .53437 L
.49391 .529 L
.48889 .52333 L
.48512 .51764 L
.48255 .51215 L
.4811 .50707 L
.48063 .50251 L
.48101 .49859 L
.48209 .49535 L
.48371 .49282 L
.48573 .49098 L
.48799 .4898 L
.49037 .48922 L
.49275 .48916 L
.49504 .48954 L
.49716 .49028 L
.49905 .49129 L
.50068 .49249 L
.50202 .49379 L
.50306 .49514 L
.50382 .49646 L
.50429 .49771 L
.50453 .49885 L
.50454 .49986 L
.50437 .50071 L
.50405 .50139 L
.50362 .50191 L
.50312 .50227 L
.50257 .50248 L
.50201 .50256 L
.50145 .50252 L
.50093 .50239 L
Mistroke
.50045 .50218 L
.50004 .50192 L
.49969 .50163 L
.4994 .50131 L
.49919 .501 L
.49904 .50069 L
.49896 .50041 L
.49893 .50016 L
.49895 .49994 L
.499 .49975 L
.49909 .49961 L
.4992 .49951 L
.49933 .49944 L
.49946 .4994 L
.49959 .4994 L
.49972 .49942 L
.49983 .49946 L
.49994 .49951 L
.50003 .49958 L
.50011 .49965 L
.50017 .49973 L
.50021 .4998 L
.50024 .49987 L
.50025 .49993 L
.50025 .49999 L
.50024 .50004 L
.50023 .50007 L
.5002 .5001 L
.50017 .50012 L
.50014 .50014 L
.50011 .50014 L
.50008 .50014 L
.50005 .50013 L
.50003 .50012 L
.5 .50011 L
.49998 .50009 L
.49997 .50007 L
.49996 .50006 L
.49995 .50004 L
.49994 .50002 L
.49994 .50001 L
.49994 .5 L
.49994 .49999 L
.49995 .49998 L
.49996 .49997 L
.49996 .49997 L
.49997 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
Mistroke
.5 .49997 L
.5 .49998 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .653 0 r
.2266 .31234 m
.27263 .29204 L
.32036 .28332 L
.36762 .28466 L
.41258 .29439 L
.45382 .31079 L
.49028 .33212 L
.52128 .35674 L
.54646 .38313 L
.56573 .40996 L
.57928 .43609 L
.58748 .46057 L
.59087 .48271 L
.59008 .50198 L
.58582 .51807 L
.57881 .53086 L
.56977 .54037 L
.55939 .54673 L
.54831 .5502 L
.53707 .55111 L
.52615 .54983 L
.51594 .54676 L
.50673 .54231 L
.49874 .53689 L
.49207 .53086 L
.48679 .52457 L
.48289 .5183 L
.4803 .51231 L
.47891 .50678 L
.47859 .50188 L
.47918 .49768 L
.4805 .49425 L
.48239 .49161 L
.48469 .48972 L
.48722 .48855 L
.48986 .48802 L
.49248 .48806 L
.49499 .48856 L
.49729 .48945 L
.49933 .49061 L
.50107 .49197 L
.50248 .49342 L
.50357 .49491 L
.50435 .49636 L
.50482 .49772 L
.50503 .49896 L
.505 .50004 L
.50477 .50094 L
.5044 .50166 L
.5039 .5022 L
Mistroke
.50333 .50257 L
.50272 .50277 L
.5021 .50283 L
.50149 .50277 L
.50092 .5026 L
.50041 .50236 L
.49996 .50207 L
.49959 .50173 L
.49929 .50139 L
.49907 .50104 L
.49892 .5007 L
.49884 .5004 L
.49881 .50012 L
.49884 .49989 L
.49891 .49969 L
.49902 .49954 L
.49914 .49944 L
.49928 .49937 L
.49943 .49934 L
.49957 .49934 L
.49971 .49936 L
.49984 .49941 L
.49996 .49948 L
.50005 .49955 L
.50013 .49963 L
.50019 .49971 L
.50024 .49979 L
.50027 .49987 L
.50028 .49994 L
.50028 .5 L
.50027 .50005 L
.50025 .50009 L
.50022 .50012 L
.50019 .50014 L
.50015 .50015 L
.50012 .50016 L
.50008 .50015 L
.50005 .50014 L
.50002 .50013 L
.5 .50012 L
.49998 .5001 L
.49996 .50008 L
.49995 .50006 L
.49994 .50004 L
.49994 .50002 L
.49993 .50001 L
.49994 .49999 L
.49994 .49998 L
.49995 .49998 L
.49995 .49997 L
Mistroke
.49996 .49997 L
.49997 .49996 L
.49998 .49996 L
.49998 .49996 L
.49999 .49997 L
.5 .49997 L
.5 .49997 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50002 .5 L
.50002 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 .045 1 r
.18843 .71068 m
.16356 .62081 L
.15614 .54054 L
.16366 .47154 L
.18342 .41475 L
.21267 .37049 L
.24872 .33851 L
.28902 .31812 L
.3313 .30829 L
.37353 .30769 L
.41404 .31488 L
.45148 .32832 L
.48486 .34647 L
.51348 .36785 L
.53696 .39107 L
.5552 .41493 L
.5683 .43835 L
.57657 .46049 L
.58045 .48064 L
.58049 .49834 L
.5773 .51326 L
.57154 .52526 L
.56383 .53432 L
.55482 .54055 L
.54505 .54416 L
.53506 .54542 L
.52527 .54467 L
.51603 .54225 L
.50764 .53853 L
.50029 .53387 L
.49411 .5286 L
.48916 .52303 L
.48543 .51743 L
.48289 .51204 L
.48144 .50703 L
.48096 .50255 L
.48132 .49868 L
.48237 .49548 L
.48396 .49298 L
.48593 .49117 L
.48815 .48999 L
.49049 .48941 L
.49283 .48934 L
.49508 .48971 L
.49717 .49043 L
.49904 .49142 L
.50064 .49259 L
.50196 .49387 L
.50299 .49519 L
.50374 .4965 L
Mistroke
.50421 .49773 L
.50445 .49885 L
.50446 .49984 L
.5043 .50068 L
.50399 .50136 L
.50357 .50187 L
.50307 .50223 L
.50253 .50243 L
.50198 .50251 L
.50144 .50248 L
.50092 .50235 L
.50045 .50215 L
.50004 .50189 L
.4997 .50161 L
.49942 .5013 L
.49921 .50099 L
.49906 .50069 L
.49898 .50041 L
.49895 .50016 L
.49896 .49994 L
.49902 .49976 L
.4991 .49962 L
.49921 .49952 L
.49933 .49945 L
.49946 .49941 L
.49959 .49941 L
.49972 .49943 L
.49984 .49947 L
.49994 .49952 L
.50003 .49959 L
.5001 .49966 L
.50016 .49973 L
.5002 .4998 L
.50023 .49987 L
.50025 .49993 L
.50025 .49999 L
.50024 .50003 L
.50022 .50007 L
.5002 .5001 L
.50017 .50012 L
.50014 .50013 L
.50011 .50014 L
.50008 .50014 L
.50005 .50013 L
.50003 .50012 L
.5 .50011 L
.49998 .50009 L
.49997 .50007 L
.49996 .50006 L
.49995 .50004 L
Mistroke
.49994 .50002 L
.49994 .50001 L
.49994 .5 L
.49995 .49999 L
.49995 .49998 L
.49996 .49997 L
.49996 .49997 L
.49997 .49997 L
.49998 .49997 L
.49998 .49997 L
.49999 .49997 L
.5 .49997 L
.5 .49998 L
.50001 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .11 0 r
.56275 .74659 m
.51512 .71926 L
.47453 .68755 L
.44147 .65343 L
.41606 .61865 L
.39809 .58471 L
.38707 .55283 L
.38235 .52396 L
.38308 .49876 L
.38837 .47766 L
.39728 .46084 L
.40887 .44829 L
.42224 .43982 L
.43657 .43511 L
.45114 .43376 L
.46532 .43527 L
.47861 .43913 L
.49063 .4448 L
.50109 .45177 L
.50983 .45955 L
.51677 .4677 L
.52192 .47583 L
.52538 .48362 L
.52726 .49082 L
.52775 .49723 L
.52705 .50272 L
.52539 .50722 L
.52297 .51071 L
.52002 .51321 L
.51675 .51478 L
.51333 .51551 L
.50993 .5155 L
.50668 .51487 L
.50368 .51375 L
.50102 .51226 L
.49874 .51052 L
.49688 .50863 L
.49544 .50671 L
.49442 .50482 L
.49378 .50305 L
.49349 .50144 L
.49351 .50003 L
.49379 .49884 L
.49427 .49789 L
.4949 .49718 L
.49564 .49669 L
.49643 .49642 L
.49724 .49633 L
.49802 .49641 L
.49876 .49661 L
Mistroke
.49944 .49692 L
.50002 .4973 L
.50051 .49773 L
.5009 .49818 L
.5012 .49863 L
.50139 .49906 L
.5015 .49946 L
.50154 .49982 L
.5015 .50013 L
.50141 .50038 L
.50128 .50058 L
.50112 .50072 L
.50094 .50081 L
.50075 .50086 L
.50056 .50086 L
.50038 .50083 L
.50022 .50077 L
.50007 .50069 L
.49994 .50059 L
.49983 .50049 L
.49975 .50038 L
.49969 .50027 L
.49966 .50018 L
.49964 .50009 L
.49964 .50001 L
.49965 .49994 L
.49968 .49989 L
.49972 .49985 L
.49976 .49982 L
.4998 .4998 L
.49984 .4998 L
.49989 .4998 L
.49993 .49981 L
.49997 .49983 L
.5 .49985 L
.50003 .49987 L
.50005 .4999 L
.50007 .49992 L
.50008 .49995 L
.50008 .49997 L
.50009 .49999 L
.50008 .50001 L
.50008 .50002 L
.50007 .50003 L
.50006 .50004 L
.50005 .50004 L
.50004 .50005 L
.50003 .50005 L
.50002 .50005 L
.50001 .50004 L
Mistroke
.5 .50004 L
.5 .50003 L
.49999 .50003 L
.49999 .50002 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .08 r
.24458 .74857 m
.21038 .66298 L
.19325 .5846 L
.19113 .51543 L
.20171 .45675 L
.22252 .40922 L
.25108 .37294 L
.28501 .34758 L
.3221 .33238 L
.36034 .32632 L
.39803 .32818 L
.43374 .33662 L
.46637 .35023 L
.49511 .36765 L
.51943 .38756 L
.53907 .40877 L
.55399 .43023 L
.56436 .45103 L
.57049 .47045 L
.57282 .48793 L
.57186 .50309 L
.56818 .5157 L
.56237 .52565 L
.55499 .53297 L
.5466 .53781 L
.53769 .54035 L
.52871 .54088 L
.52002 .53968 L
.51193 .53709 L
.50465 .53343 L
.49836 .52902 L
.49315 .52416 L
.48904 .51912 L
.48603 .51412 L
.48407 .50935 L
.48306 .50498 L
.48288 .50111 L
.48342 .49782 L
.48454 .49514 L
.48609 .49309 L
.48795 .49164 L
.49 .49076 L
.49211 .49039 L
.49421 .49047 L
.49619 .49091 L
.49801 .49165 L
.49962 .4926 L
.50099 .49369 L
.50209 .49486 L
.50294 .49605 L
Mistroke
.50353 .49721 L
.50389 .49829 L
.50403 .49927 L
.50399 .50012 L
.50379 .50082 L
.50348 .50139 L
.50308 .5018 L
.50261 .50208 L
.50212 .50223 L
.50163 .50226 L
.50114 .5022 L
.50069 .50207 L
.50028 .50187 L
.49993 .50163 L
.49964 .50136 L
.49941 .50108 L
.49924 .5008 L
.49912 .50054 L
.49906 .50029 L
.49905 .50008 L
.49908 .49989 L
.49914 .49974 L
.49922 .49962 L
.49933 .49954 L
.49944 .49949 L
.49955 .49947 L
.49967 .49947 L
.49978 .49949 L
.49988 .49953 L
.49997 .49959 L
.50005 .49965 L
.50011 .49971 L
.50016 .49978 L
.50019 .49984 L
.50021 .4999 L
.50022 .49996 L
.50022 .5 L
.50021 .50004 L
.50019 .50007 L
.50017 .5001 L
.50015 .50011 L
.50012 .50012 L
.50009 .50013 L
.50007 .50012 L
.50004 .50012 L
.50002 .5001 L
.5 .50009 L
.49998 .50008 L
.49997 .50006 L
.49996 .50005 L
Mistroke
.49995 .50003 L
.49995 .50002 L
.49995 .50001 L
.49995 .49999 L
.49995 .49999 L
.49996 .49998 L
.49996 .49997 L
.49997 .49997 L
.49997 .49997 L
.49998 .49997 L
.49999 .49997 L
.49999 .49997 L
.5 .49998 L
.5 .49998 L
.50001 .49998 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .31 r
.62628 .75647 m
.57409 .73915 L
.52732 .71506 L
.48696 .68623 L
.45361 .65458 L
.42746 .62183 L
.40841 .58947 L
.39609 .55872 L
.3899 .53057 L
.3891 .50571 L
.39287 .48461 L
.40031 .46752 L
.41055 .45447 L
.42272 .44533 L
.43603 .43985 L
.44976 .43765 L
.46329 .4383 L
.47612 .44131 L
.48785 .44619 L
.49818 .45243 L
.50692 .45958 L
.51398 .46719 L
.51935 .4749 L
.52308 .48237 L
.5253 .48934 L
.52614 .49563 L
.5258 .50107 L
.52449 .50561 L
.52241 .50919 L
.51976 .51182 L
.51675 .51356 L
.51356 .51448 L
.51033 .51468 L
.50721 .51425 L
.5043 .51332 L
.50169 .51201 L
.49943 .51043 L
.49755 .50869 L
.49608 .50688 L
.49499 .50508 L
.49428 .50337 L
.49392 .5018 L
.49385 .50041 L
.49405 .49923 L
.49445 .49826 L
.495 .49752 L
.49567 .497 L
.4964 .49669 L
.49716 .49655 L
.49791 .49658 L
Mistroke
.49863 .49674 L
.49928 .497 L
.49986 .49734 L
.50035 .49773 L
.50075 .49815 L
.50105 .49858 L
.50127 .49899 L
.50139 .49938 L
.50145 .49973 L
.50143 .50004 L
.50136 .50029 L
.50125 .5005 L
.50111 .50065 L
.50094 .50075 L
.50076 .5008 L
.50058 .50081 L
.50041 .50079 L
.50025 .50074 L
.5001 .50067 L
.49998 .50058 L
.49987 .50049 L
.49979 .50039 L
.49973 .50029 L
.49969 .50019 L
.49966 .50011 L
.49966 .50003 L
.49967 .49996 L
.49969 .49991 L
.49972 .49987 L
.49976 .49984 L
.4998 .49982 L
.49984 .49981 L
.49988 .49981 L
.49992 .49982 L
.49996 .49983 L
.49999 .49985 L
.50002 .49987 L
.50004 .4999 L
.50006 .49992 L
.50007 .49994 L
.50008 .49996 L
.50008 .49998 L
.50008 .5 L
.50008 .50002 L
.50007 .50003 L
.50006 .50004 L
.50005 .50004 L
.50004 .50004 L
.50003 .50005 L
.50002 .50004 L
Mistroke
.50001 .50004 L
.50001 .50004 L
.5 .50003 L
.49999 .50003 L
.49999 .50002 L
.49999 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
.867 1 0 r
.47062 .43061 m
.48454 .43617 L
.49683 .44339 L
.50728 .45171 L
.51576 .46063 L
.52225 .46969 L
.52681 .4785 L
.52956 .48677 L
.53069 .49423 L
.53041 .50073 L
.52896 .50615 L
.52658 .51046 L
.52353 .51366 L
.52002 .5158 L
.51627 .51696 L
.51248 .51726 L
.5088 .51682 L
.50535 .51578 L
.50225 .51427 L
.49955 .51244 L
.4973 .5104 L
.49553 .50827 L
.49421 .50616 L
.49334 .50414 L
.49288 .50227 L
.49277 .50062 L
.49297 .4992 L
.49342 .49805 L
.49406 .49716 L
.49484 .49652 L
.49569 .49613 L
.49659 .49595 L
.49747 .49597 L
.49832 .49614 L
.49909 .49644 L
.49978 .49683 L
.50036 .49729 L
.50084 .49778 L
.50121 .49829 L
.50147 .49878 L
.50163 .49924 L
.5017 .49965 L
.50169 .50002 L
.50161 .50032 L
.50148 .50056 L
.50132 .50075 L
.50112 .50087 L
.50092 .50094 L
.50071 .50096 L
.5005 .50093 L
Mistroke
.50031 .50088 L
.50014 .5008 L
.49998 .5007 L
.49986 .50058 L
.49976 .50047 L
.49968 .50035 L
.49963 .50024 L
.49961 .50013 L
.4996 .50004 L
.49961 .49996 L
.49963 .4999 L
.49967 .49985 L
.49971 .49981 L
.49976 .49979 L
.49981 .49978 L
.49986 .49978 L
.4999 .49979 L
.49995 .4998 L
.49999 .49982 L
.50002 .49985 L
.50004 .49988 L
.50007 .4999 L
.50008 .49993 L
.50009 .49996 L
.50009 .49998 L
.50009 .5 L
.50009 .50002 L
.50008 .50003 L
.50007 .50004 L
.50006 .50005 L
.50005 .50005 L
.50004 .50005 L
.50003 .50005 L
.50002 .50005 L
.50001 .50004 L
.5 .50004 L
.49999 .50003 L
.49999 .50003 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
Mistroke
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .13 r
.75234 .38887 m
.76164 .4523 L
.75899 .50745 L
.74641 .55345 L
.72599 .58993 L
.69981 .61696 L
.66985 .63497 L
.6379 .64469 L
.60557 .64707 L
.57421 .64318 L
.54491 .63419 L
.51852 .62128 L
.49563 .60559 L
.47659 .5882 L
.46154 .57007 L
.45044 .55205 L
.44311 .53484 L
.43923 .519 L
.4384 .50495 L
.44017 .49295 L
.44405 .48316 L
.44954 .47562 L
.45617 .47026 L
.46349 .46695 L
.47109 .4655 L
.47863 .46565 L
.48581 .46716 L
.49241 .46974 L
.49825 .47311 L
.50322 .47702 L
.50727 .48122 L
.51037 .48549 L
.51257 .48966 L
.5139 .49358 L
.51447 .49712 L
.51437 .50021 L
.51371 .50279 L
.51261 .50485 L
.51118 .50638 L
.50953 .50742 L
.50776 .50799 L
.50597 .50815 L
.50423 .50795 L
.5026 .50747 L
.50112 .50677 L
.49984 .50591 L
.49877 .50495 L
.49792 .50395 L
.49729 .50295 L
.49687 .502 L
Mistroke
.49665 .50111 L
.49659 .50033 L
.49668 .49965 L
.49688 .4991 L
.49718 .49868 L
.49755 .49837 L
.49795 .49818 L
.49837 .49809 L
.49879 .4981 L
.49919 .49817 L
.49955 .49831 L
.49988 .4985 L
.50016 .49871 L
.50039 .49894 L
.50056 .49918 L
.50069 .49941 L
.50077 .49963 L
.5008 .49983 L
.5008 .5 L
.50076 .50015 L
.5007 .50026 L
.50062 .50035 L
.50053 .50041 L
.50044 .50044 L
.50034 .50045 L
.50024 .50044 L
.50015 .50042 L
.50007 .50038 L
.5 .50033 L
.49994 .50028 L
.49989 .50022 L
.49985 .50017 L
.49983 .50011 L
.49981 .50006 L
.49981 .50002 L
.49982 .49998 L
.49983 .49995 L
.49984 .49993 L
.49986 .49991 L
.49988 .4999 L
.49991 .49989 L
.49993 .49989 L
.49995 .4999 L
.49997 .49991 L
.49999 .49992 L
.50001 .49993 L
.50002 .49994 L
.50003 .49995 L
.50004 .49997 L
.50004 .49998 L
Mistroke
.50004 .49999 L
.50004 .5 L
.50004 .50001 L
.50004 .50001 L
.50003 .50002 L
.50003 .50002 L
.50002 .50002 L
.50002 .50002 L
.50001 .50002 L
.50001 .50002 L
.5 .50002 L
.5 .50002 L
.5 .50002 L
.49999 .50001 L
.49999 .50001 L
.49999 .50001 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .5 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
0 1 .908 r
.42442 .23498 m
.47597 .26287 L
.5202 .29577 L
.55652 .33155 L
.58476 .36832 L
.60507 .40446 L
.61791 .43861 L
.62398 .46974 L
.62412 .49708 L
.61927 .52015 L
.61043 .5387 L
.5986 .55274 L
.58472 .56241 L
.56968 .56803 L
.55427 .57003 L
.53916 .5689 L
.52491 .56521 L
.51196 .55949 L
.5006 .55232 L
.49105 .54421 L
.48338 .53563 L
.47761 .527 L
.47367 .51868 L
.47141 .51095 L
.47065 .50402 L
.47119 .49804 L
.4728 .4931 L
.47523 .48923 L
.47827 .48641 L
.48169 .48459 L
.48529 .48368 L
.4889 .48356 L
.49237 .48412 L
.49559 .48523 L
.49848 .48675 L
.50096 .48855 L
.503 .49053 L
.50459 .49256 L
.50575 .49457 L
.50649 .49647 L
.50685 .49821 L
.50688 .49974 L
.50663 .50103 L
.50616 .50208 L
.50551 .50287 L
.50475 .50342 L
.50392 .50375 L
.50307 .50388 L
.50223 .50382 L
.50143 .50363 L
Mistroke
.50071 .50332 L
.50008 .50293 L
.49954 .50248 L
.49911 .50201 L
.49878 .50153 L
.49855 .50107 L
.49842 .50064 L
.49838 .50025 L
.4984 .49991 L
.49849 .49964 L
.49862 .49942 L
.49878 .49926 L
.49897 .49915 L
.49917 .4991 L
.49937 .49909 L
.49956 .49912 L
.49974 .49918 L
.4999 .49926 L
.50004 .49936 L
.50016 .49947 L
.50025 .49958 L
.50031 .49969 L
.50036 .4998 L
.50038 .49989 L
.50038 .49998 L
.50037 .50005 L
.50034 .50011 L
.50031 .50016 L
.50027 .50019 L
.50022 .50021 L
.50017 .50021 L
.50013 .50021 L
.50008 .5002 L
.50004 .50019 L
.50001 .50016 L
.49998 .50014 L
.49995 .50011 L
.49993 .50009 L
.49992 .50006 L
.49991 .50004 L
.49991 .50002 L
.49991 .5 L
.49992 .49998 L
.49992 .49997 L
.49993 .49996 L
.49994 .49995 L
.49995 .49995 L
.49996 .49995 L
.49998 .49995 L
.49999 .49995 L
Mistroke
.49999 .49996 L
.5 .49996 L
.50001 .49997 L
.50001 .49998 L
.50002 .49998 L
.50002 .49999 L
.50002 .49999 L
.50002 .5 L
.50002 .5 L
.50002 .50001 L
.50002 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.50001 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 .003 0 r
.64518 .81237 m
.58199 .78972 L
.52567 .75911 L
.47736 .72306 L
.43771 .68387 L
.40692 .64363 L
.3848 .6041 L
.37083 .56675 L
.36427 .53273 L
.36419 .50286 L
.36956 .47768 L
.37928 .45743 L
.39226 .44213 L
.40748 .4316 L
.42394 .4255 L
.44081 .42336 L
.45734 .42462 L
.47291 .4287 L
.48708 .43497 L
.49948 .44284 L
.50991 .45173 L
.51827 .46112 L
.52456 .47056 L
.52886 .47966 L
.53131 .48812 L
.53212 .49569 L
.53151 .50222 L
.52974 .50761 L
.52707 .51183 L
.52374 .5149 L
.52 .51688 L
.51606 .51787 L
.5121 .51799 L
.5083 .51736 L
.50478 .51615 L
.50163 .51448 L
.49892 .5125 L
.49669 .51034 L
.49495 .50811 L
.49369 .50592 L
.49289 .50384 L
.4925 .50194 L
.49247 .50027 L
.49275 .49886 L
.49327 .49771 L
.49398 .49685 L
.49481 .49625 L
.49572 .49589 L
.49666 .49576 L
.49757 .49582 L
Mistroke
.49844 .49603 L
.49923 .49637 L
.49993 .4968 L
.50051 .49729 L
.50098 .49781 L
.50134 .49833 L
.50158 .49884 L
.50173 .49931 L
.50178 .49973 L
.50175 .5001 L
.50166 .5004 L
.50151 .50064 L
.50133 .50081 L
.50112 .50093 L
.5009 .50099 L
.50069 .501 L
.50047 .50097 L
.50028 .5009 L
.5001 .50081 L
.49995 .5007 L
.49982 .50058 L
.49973 .50046 L
.49966 .50034 L
.49961 .50022 L
.49959 .50011 L
.49958 .50002 L
.4996 .49994 L
.49962 .49988 L
.49966 .49983 L
.49971 .49979 L
.49976 .49977 L
.49981 .49977 L
.49986 .49977 L
.49991 .49978 L
.49995 .4998 L
.49999 .49982 L
.50003 .49985 L
.50005 .49988 L
.50007 .49991 L
.50009 .49993 L
.5001 .49996 L
.5001 .49998 L
.5001 .5 L
.50009 .50002 L
.50008 .50003 L
.50007 .50004 L
.50006 .50005 L
.50005 .50005 L
.50004 .50006 L
.50003 .50005 L
Mistroke
.50002 .50005 L
.50001 .50005 L
.5 .50004 L
.49999 .50003 L
.49999 .50003 L
.49998 .50002 L
.49998 .50001 L
.49998 .50001 L
.49998 .5 L
.49998 .5 L
.49998 .49999 L
.49998 .49999 L
.49998 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.49999 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .49999 L
.5 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
1 0 .031 r
.27163 .60426 m
.26254 .54628 L
.2644 .49575 L
.27539 .45351 L
.29359 .4199 L
.31713 .3949 L
.3442 .37811 L
.37315 .36889 L
.40253 .3664 L
.43109 .36964 L
.45782 .37758 L
.48195 .38914 L
.50292 .40328 L
.52041 .41902 L
.53428 .43546 L
.54455 .45185 L
.55139 .46753 L
.55507 .482 L
.55597 .49486 L
.55448 .50586 L
.55105 .51486 L
.54613 .52182 L
.54015 .52679 L
.53353 .5299 L
.52663 .5313 L
.51978 .53124 L
.51323 .52993 L
.50721 .52763 L
.50186 .5246 L
.4973 .52107 L
.49358 .51727 L
.49071 .51338 L
.48867 .50959 L
.48742 .50602 L
.48687 .50278 L
.48693 .49995 L
.48751 .49758 L
.48849 .49568 L
.48977 .49427 L
.49126 .4933 L
.49286 .49277 L
.49449 .4926 L
.49607 .49276 L
.49756 .49318 L
.49891 .49381 L
.50008 .49459 L
.50107 .49545 L
.50185 .49636 L
.50243 .49727 L
.50282 .49814 L
Mistroke
.50304 .49895 L
.5031 .49967 L
.50303 .50028 L
.50284 .50079 L
.50258 .50118 L
.50225 .50147 L
.50188 .50165 L
.5015 .50173 L
.50112 .50173 L
.50076 .50166 L
.50042 .50154 L
.50012 .50138 L
.49987 .50118 L
.49966 .50097 L
.4995 .50076 L
.49938 .50055 L
.49931 .50035 L
.49927 .50017 L
.49928 .50001 L
.49931 .49987 L
.49936 .49977 L
.49943 .49969 L
.49951 .49963 L
.4996 .4996 L
.49969 .49959 L
.49978 .4996 L
.49986 .49962 L
.49993 .49965 L
.5 .4997 L
.50006 .49974 L
.5001 .49979 L
.50013 .49985 L
.50016 .49989 L
.50017 .49994 L
.50017 .49998 L
.50017 .50001 L
.50016 .50004 L
.50014 .50006 L
.50013 .50008 L
.50011 .50009 L
.50008 .5001 L
.50006 .5001 L
.50004 .50009 L
.50002 .50009 L
.50001 .50008 L
.49999 .50007 L
.49998 .50005 L
.49997 .50004 L
.49997 .50003 L
.49996 .50002 L
Mistroke
.49996 .50001 L
.49996 .5 L
.49996 .49999 L
.49996 .49999 L
.49997 .49998 L
.49997 .49998 L
.49998 .49998 L
.49998 .49998 L
.49999 .49998 L
.49999 .49998 L
.5 .49998 L
.5 .49998 L
.5 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .49999 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.50001 .5 L
.5 .50001 L
.5 .50001 L
.5 .50001 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mistroke
.5 .5 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{1000, 1000},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000?X0003j2000`400?l00000o`00003ooooonf[o
oookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00
oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[
oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Z
oooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooook
J_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z
003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooook
J^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooo
nf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oo
oo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]Zjooo
nfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oo
oo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[o
oookJ_oooo]ZjooonfX00?3ooo]Z0ol007oooookJ_3ooo]Z0ol007oooookJPCooo]Z003`oookJP?o
001ooooonf[`oookJP?o001ooooonfX4oookJP00l?oonfX3o`00Oooooo]Zl?oonfX3o`00Oooooo]Z
1?oonfX00>3ooo]Z2_l007l6oookJP?o001o2?oonfX4o`000?oooo]Ze?oonfX:o`00O`Kooo]Z0ol0
07l8oookJPCo0000mooonfX0033ooo]Z1Ol0oj82oookJPGo08co??oonfX5o`3oXP?o08co4_oonfX4
o`3o8AGooo]Z0_oo0?82oookJP;o0?mF3_oonfX2ool0X0Oooo]Z0_mD0?l00ol09Ooooo]ZoookJP07
oookJP;oiOl000Cooo]Zool:0?oo2P3oo`X01_oonfX2o`00O`;oNol01?l007l9onGo00;o001o0_l0
ocP00ooonf[o203oo`P0o`03oookJPKo00002?oonfX2oolP00Oooo]Z0_oo0;DIoookJP03ooo90?oo
nf[ooo]Z00Oooo]Z00?o0?n;oookJ_oonfX06ooonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00[ooo]Z
00?ooa`0oookJ_oonfX00ooonfX00onho`3ooo]ZoookJP0?oookJP04om;o0?oonf[ooo]Zomgo00?o
oo]Z00?o:`3ooookJ_oonfX01OoonfX01OooV`3oo`00oookJ_o/o`3oolT000Oooo]Z0_nC0?l8oook
JP03ooo90?mG0?oooo]Z00;oolT00_oonfX00ooo0=cooo]ZoookJP04oookJP03oigo0?oonf[ooo]Z
00?ooo]Z00?ok@3ooookJ_oonfX06_oonfX00om/0?oooo]ZoookJP1>oookJPCo0?nR0_oonfX5o`2<
occooo]Z1Ol0oj801?oonf[o08coo`2<ool0S?lAoookJPCo0?lQ5OoonfX2ool0lP?ooo]Z0_l0oeH=
oookJP;oo`2P1ooonfX2oe@0o`;o02Go2?oonfX00ol0C?oo:P3oobX0o`03ool:00Kooo]Z0ol007l2
og_o00Go001o00?ooo]Zoom10?oo@@000_ooW0001?oonf[o001oo`00Ool007l2o`3o>003oookJ_l8
0?oo203o00?ooo]Z1_l00008oookJP;oob002?oonfX2ool0]ASooo]Z00?o0?neoookJ_oonfX01ooo
nfX00ol0oh_ooo]ZoookJP0KoookJP03ool0Cooonf[ooo]Z00;ooo]Z00?o0?nFoookJ_oonfX01ooo
nfX00ooo703ooo]ZoookJP03oookJP03okSo0?oonf[ooo]Z013ooo]Z00Cod_l0oookJ_oonf[ogOl0
0_oonfX00ol[0?oooo]ZoookJP05oookJP05oonK0?oo003ooo]ZoookJ_o/o`002?oonfX00onC0?oo
oo]ZoookJP06oookJP03oong0?mG0?oooo]Z00Cooo]Z00?oo`3LoookJ_oonfX01?oonfX00onMo`3o
oo]ZoookJP03oookJP03ond0oooonf[ooo]Z01[ooo]Z00?oK03ooookJ_oonfX08OoonfX002gooo]Z
0ol0oj87o`2<oaCooo]Z4?oo_`0RoookJPWo0?nR4?oonfX5o`3o8A;ooo]Z0ooo0?801?oonf[o0?mF
o`3oE_l0oeH=oookJP;oo`2P1ooonfX2oe@0o`03o`0Uoooonf[ooo]Z00Oooo]Z00CoiOl0o`1<oooo
nf[ooo]Z0_ooN@08oookJP;oNol00_oonfX:onGo0004o`00Oooonf[ooo]Zo`3o>0;ooo]Z00?o203o
oookJ_oonfX01?l0000<oookJP03oolP0?oonf[ooo]Z00Kooo]Z00?oo`2eoookJ_oonfX05_oonfX0
0ooob@3ooo]ZoookJP07oookJP03o`3oRooonf[ooo]Z01cooo]Z00Coo`1?oookJ_oonf[o0?nF2ooo
nfX00ooo703ooo]ZoookJP02oookJP03okSo0?oonf[ooo]Z00oooo]Z00Cod_l0oookJ_oonf[ogOl0
0ooonfX00ol[0?oooo]ZoookJP05oookJP06oonK0?oo003ooo]Zonco0?oonf[oolT01ooonfX00onC
0?oooo]ZoookJP06oookJP03ooo90?mG0?ooolT000;oolT00_oonfX00ooo0=cooo]ZoookJP04oook
JP03oigo0?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX06_oonfX00om/0?oooo]ZoookJP1;oook
JP?o0?nR1_l0S?lDoookJQ3ookl08_oonfX9o`3oXQ3ooo]Z1Ol0ob4BoookJP?oo`3b0_oonfX3o`3o
EPcooo]Z0_oo0:07oookJP;oE03o0_l09Ol8oookJP04o`1<oolZ0?oooo]ZoookJP;oo`X02OoonfX0
0omko`3ooo]ZoookJP05oookJP;ood4000Cooi`0o`00Ool007oo001o0_oonfX01?l0ocSooo]Zoook
J_l80?l2oookJPCo00003?oonfX00ooo803ooo]ZoookJP07oookJP03ool0]Ooonf[ooo]Z01Gooo]Z
00?o0?neoookJ_oonfX01ooonfX00ol0oh_ooo]ZoookJP0LoookJP05ool0Cooonf[ooo]ZoookJ_l0
oiH02_oonfX00ooo703ooo]ZoookJP02oookJP03okSo0?oonf[ooo]Z013ooo]Z00Cod_l0oookJ_oo
nf[ogOl00_oonfX00ol[0?oooo]ZoookJP05oookJP06oonK0?oo003ooo]ZoookJ_o/o`3oo`2Y1ooo
nfX00onC0?oooo]ZoookJP06oookJP03oong0?mG0?oooo]Z00Cooo]Z00?oo`3LoookJ_oonfX01?oo
nfX00onMo`3ooo]ZoookJP03oookJP03ond0oooonf[ooo]Z01[ooo]Z00?oK03ooookJ_oonfX08Ooo
nfX002Wooo]Z00Co08coo`3oX_l0oj;o0?nR0ol0S?lEoookJPKookl04?oonfXGoono01?ooo]Z00?o
08coo`3oX_l0oj801_l0oj8=oookJPGo0?lQ4?oonfX2ool0lP;ooo]Z0ol0oeH<oookJP;oo`2P1ooo
nfX00omD0?oo02Goo`0Uo`08oookJP;oiOl000Co04cooookJ_oonf[oogT02OoonfX00omko`3oiOl0
onGo000:onGo00?ooo]Z00Go0?lhoookJ_oonf[o203ooookJP04o`0000gooo]Z00?oob00oookJ_oo
nfX01_oonfX00ooo0;Gooo]ZoookJP0FoookJP03ooo90?oonf[ooo]Z00Oooo]Z00?o0?n;oookJ_oo
nfX07?oonfX01?oo04oooo]ZoookJ_l0oiH;oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oook
J_oonfX03ooonfX01?oBo`3ooo]ZoookJ_oMo`03oookJP03ob/0oooonf[ooo]Z00Gooo]Z00Gooi/0
ool00?oonf[ok?l0ool0Z@08oookJP03oi<0oooonf[ooo]Z00Gooo]Z0_oob@001?mG0?ooolT0ooo9
0?oob@02oookJP03ool0g?oonf[ooo]Z00Cooo]Z00?oWOl0oookJ_oonfX00ooonfX00oo]0?oooo]Z
oookJP0JoookJP03of`0oooonf[ooo]Z04Gooo]Z00?o08coo`3oX_l0oj800_l0oj82o`2<oaGooo]Z
1_oo_`0@oookJQOookl05?oonfX8o`3oXPgooo]Z1Ol0ob4@oookJP;oo`3b0ooonfX3o`3oEP_ooo]Z
0_oo0:07oookJP;oE03o0_l09Ol8oookJP;o:P3o0_oonfX00ooo2P3ooo]ZoookJP07oookJP;oNol0
1ooonfX2oom100;o001o0ooonfX01Ol0ocSooo]ZoookJ_l80?oooo]Z00Co00003OoonfX00ooo803o
oo]ZoookJP07oookJP03ool0]Ooonf[ooo]Z01Gooo]Z00?o0?neoookJ_oonfX01ooonfX00ol0oh_o
oo]ZoookJP0LoookJP05ool0Cooonf[ooo]ZoookJ_l0oiH02_oonfX00ooo703ooo]ZoookJP02oook
JP03okSo0?oonf[ooo]Z013ooo]Z00Cod_l0oookJ_oonf[ogOl00_oonfX00ol[0?oooo]ZoookJP05
oookJP05oonK0?oo003ooo]ZoookJ_o/o`002?oonfX00onC0?oooo]ZoookJP06oookJP03oong0?mG
0?oooo]Z00Cooo]Z00?oo`3LoookJ_oonfX01?oonfX00onMo`3ooo]ZoookJP03oookJP03ond0oooo
nf[ooo]Z01[ooo]Z00?oK03ooookJ_oonfX08?oonfX002Gooo]Z0_l0S?l3o`3oXQGooo]Z1_oo_`0;
oookJQ3o0:;o3?oonfX6o`2Ro`_ookl00ooUo`0:oookJPCo08co1_l0oj8<oookJP03o`3o8OoUo`3o
iOl000oooo]Z0ooo0?82oookJP?o0?mF2ooonfX2ool0X0Kooo]Z0_mD0?l00ol09Ooooo]ZoookJP07
oookJP;oiOl00_oonfX2oomi00Sooo]Z0_mko`000ooonf[oiOl0onGo0008onGo00?ooo]Z0_l0ocP0
0ooonf[o203oo`000003o`0000kooo]Z0_oo8007oookJP03ool0]Ooonf[ooo]Z01Kooo]Z00?oolT0
oookJ_oonfX01ooonfX00ol0oh_ooo]ZoookJP0LoookJP04ool0Cooonf[ooo]Zo`3oUP_ooo]Z00?o
oa`0oookJ_oonfX00_oonfX00onho`3ooo]ZoookJP0?oookJP04om;o0?oonf[ooo]Zomgo00?ooo]Z
00?o:`3ooookJ_oonfX01OoonfX01OooV`3oo`00oookJ_o/o`3oo`2Y00Oooo]Z00?oT`3ooookJ_oo
nfX01?oonfX3ooo90004oeL0oooob@3oolT0ooo900;ooo]Z00?oo`3LoookJ_oonfX01?oonfX00onM
o`3ooo]ZoookJP03oookJP03ond0oooonf[ooo]Z01[ooo]Z00?oK03ooookJ_oonfX0@OoonfX2o`2<
o`?o0?nR5OoonfX6oono00cooo]Z3ol0X_l<oookJPKo0:;o3_oo_`0:oookJPCo08co1_l0oj8<oook
JP?o0?lQ3ooonfX3ool0lP?ooo]Z0_l0oeH;oookJP;oo`2P1ooonfX00omD0?oooo]Zo`0Uo`09oook
JP;o:P3o00?ooo]Zool:0?oo2P002OoonfX2og_o00Kooo]Z00?o001ooom10?ooW0001?oonfX2o`3o
>003oookJ_l80?oo203o00?o00003_oonfX2oolP00Sooo]Z00?oo`2eoookJ_oonfX05OoonfX00ol0
okGooo]ZoookJP07oookJP03o`3oRooonf[ooo]Z01cooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP0:
oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX04?oonfX01?oBo`3ooo]ZoookJ_oM
o`02oookJP03ob/0oooonf[ooo]Z00Gooo]Z00Gooi/0ool00?oonf[ooo]Zonco0007oookJP03oi<0
oooonf[ooo]Z00Oooo]Z00?oE`3ooookJ_oonfX00ooonfX00ooo0=cooo]ZoookJP04oookJP03oigo
0?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX06_oonfX00om/0?oooo]ZoookJP0PoookJP009Ooo
nfX2o`3oXQ;ooo]Z1_oo_`02oookJPoo0:;o8ooonfX6o`2Ro`Oooo]Z1OoUo`09oookJPGo08co00Co
oo]Zo`3oX_l0oj;o0?nR3?oonfX3onGo00oooo]Z0_oo0?83oookJP;o0?mF2ooonfX2ool0X0Kooo]Z
0_mD0?l00ol09Ooooo]ZoookJP07oookJP05onGo0?l0C?oooo]ZoookJ_ooN@002OoonfX2og_o00?o
oo]Z1ooUo`04oookJP04o`3o>?oonf[o203oo`P0o`;o00004?oonfX00ooo803ooo]ZoookJP05oook
JP03ool0]Ooonf[ooo]Z01Kooo]Z00?oolT0oookJ_oonfX01ooonfX00ol0oh_ooo]ZoookJP0Koook
JP05ool0Cooonf[ooo]ZoookJ_l0oiH02ooonfX01Ooo703ooo]ZoookJ_oonf[o^?l0017ooo]Z00Go
d_l0oookJ_oonf[ooo]Zomgo0002oookJP03ob/0oooonf[ooo]Z00Gooo]Z00Gooi/0ool00?oonf[o
k?l0ool0Z@08oookJP03oi<0oooonf[ooo]Z00;ooo]Z1Ooob@000omG0?ooolT0ooo90003oookJP03
ool0g?oonf[ooo]Z00Cooo]Z00?oWOl0oookJ_oonfX00ooonfX00oo]0?oooo]ZoookJP0JoookJP03
of`0oooonf[ooo]Z043ooo]Z0_l0oj8BoookJPKookl00ooonfX?o`2Rob;ooo]Z1_l0X_l7oookJPGo
okl02_oonfX5o`2<o`?o0?nR3?oonfX3o`3o8@oooo]Z0ooo0?82oookJP?o0?mF2_oonfX2ool0X0Ko
oo]Z0_mD0?l2o`0Uo`Sooo]Z00Go04coobX0oooonf[ooo]Zool:000:oookJP03og_o0?oonf[ooo]Z
00?ooo]Z0_l007l2oom100Gooo]Z00Co0?lhoookJ_l0003o203o0_l0000@oookJP03oolP0?oonf[o
oo]Z00Kooo]Z00?oo`2eoookJ_oonfX05OoonfX00ol0okGooo]ZoookJP07oookJP03o`3oRooonf[o
oo]Z01_ooo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP08oookJP05oolL0?oonf[o
oo]ZoookJ_nho`004_oonfX01OoBo`3ooo]ZoookJ_oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX0
1?oonfX01OooV`3oo`00oookJ_oonf[ok?l000Sooo]Z00?oT`3ooookJ_oonfX01ooonfX00omG0?oo
oo]ZoookJP03oookJP03ool0g?oonf[ooo]Z00Cooo]Z00?oWOl0oookJ_oonfX00ooonfX00oo]0?oo
oo]ZoookJP0JoookJP03of`0oooonf[ooo]Z01oooo]Z000ZoookJP[oolT01Ooo_`000ooob@3o0:;o
o`2Ro`05o`2RocSooo]Z1ol0X_l5oookJPCoiOl02_oonfX4o`2<o`?o0?nR3?oonfX3onGo00kooo]Z
0ooo0?82oookJP?o0?mF2_oonfX2ool0X0Kooo]Z0_mD0?l00ol09Ooooo]ZoookJP06oookJP;oiOl0
00Co04cooookJ_ooN@3oogT02OoonfX2og_o00Co001o1OoUo`04oookJP;o0?lh00?o0000o`P0ool0
00004OoonfX00ooo803ooo]ZoookJP05oookJP03ool0]Ooonf[ooo]Z01Kooo]Z00?oolT0oookJ_oo
nfX01ooonfX00ol0oh_ooo]ZoookJP0KoookJP05ool0Cooonf[ooo]ZoookJ_l0oiH02ooonfX01Ooo
703ooo]ZoookJ_oonf[o^?l0017ooo]Z00Cod_l0oookJ_oonf[ogOl00ooonfX00ol[0?oooo]Zoook
JP05oookJP05oonK0?oo003ooo]Zonco0?oo0:T01ooonfX00onC0?oooo]ZoookJP04oookJP?oolT0
00CoE`3oooo90?oob@3oolT00_oonfX00ooo0=cooo]ZoookJP05oookJP03oigo0?oonf[ooo]Z00?o
oo]Z00?ok@3ooookJ_oonfX06OoonfX00om/0?oooo]ZoookJP1?oookJPGookl02Ol0X_lgoookJPOo
0:;o1OoonfX4oono00_ooo]Z0ol0S?l3o`3oXPcooo]Z0ol0ob4?oookJP;oo`3b0ooonfX2o`3oEP[o
oo]Z0_oo0:06oookJP;oE03o0_l09Ol8oookJP;o:P3o00?ooo]Zool:0?oo2P002OoonfX2og_o00Ko
001o00?ooo]Zoom10?oo@@001?oonfX2o`3o>003o`000?l80?oo0000017ooo]Z00?oob00oookJ_oo
nfX01_oonfX00ooo0;Gooo]ZoookJP0EoookJP03o`3o]Ooonf[ooo]Z00Oooo]Z00?o0?n;oookJ_oo
nfX06ooonfX00ooo04oooo]ZoookJP02oookJP03o`3oU_oonf[ooo]Z00Sooo]Z00Gooa`0oookJ_oo
nf[ooo]ZokSo000BoookJP04om;o0?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX01OoonfX0
1OooV`3oo`00oookJ_oonf[ok?l000Oooo]Z00?oT`3ooookJ_oonfX01ooonfX00omG0?oooo]Zoook
JP03oookJP03ool0g?oonf[ooo]Z00Gooo]Z00?oWOl0oookJ_oonfX00ooonfX00oo]0?oooo]Zoook
JP0JoookJP03of`0oooonf[ooo]Z01kooo]Z000ZoookJPCoolT01_oo_`04ooo904Sooo]Z1_l0X_l3
oookJPCoiOl02ooonfX2o`2<o`?o0?nR3?oonfX2onGo00oooo]Z0_oo0?83oookJP?o0?mF2OoonfX2
ool0X0Kooo]Z00?oE03oo`0Uool09Ol02?oonfX2onGo0003o`1<oooonf[oogT000[ooo]Z00?oNol0
o`00Ool007l00ol007l2oookJP;oiOl000Sood40oookJ_oonf[ooo]Zo`000?l0ocSo0000o`P0oa;o
oo]Z00?oob00oookJ_oonfX01OoonfX00ooo0;Gooo]ZoookJP0FoookJP03ooo90?oonf[ooo]Z00Oo
oo]Z00?o0?n;oookJ_oonfX06ooonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00_ooo]Z00Gooa`0oook
J_oonf[ooo]ZokSo000@oookJP05om;o0?oonf[ooo]ZoookJ_oMo`000ooonfX00ol[0?oooo]Zoook
JP05oookJP04oonK0?oo003ooo]Zonco00Sooo]Z00?oT`3ooookJ_oonfX01?oonfX3ooo90003oeL0
oooob@3oolT000?ooo]Z00?oo`3LoookJ_oonfX01?oonfX00onMo`3ooo]ZoookJP03oookJP03ond0
oooonf[ooo]Z01Wooo]Z00?oK03ooookJ_oonfX0BOoonfX6oono00Co0:;oB?oonfX7o`2Ro`;ooo]Z
1?oo_`0;oookJP;o08co0ol0oj8<oookJP;o0?lQ3ooonfX3ool0lP;ooo]Z0ol0oeH9oookJP;oo`2P
1_oonfX2oe@0o`;o02Go2?oonfX01?lZ0?oo04cooookJ_oo2P0:oookJP;oNol01?l007l2oookJP03
oonL0?oo@@3ood4000?ooo]Z00Co0000o`3o>?l0003o203o4_oonfX00ooo803ooo]ZoookJP06oook
JP03ool0]Ooonf[ooo]Z01Gooo]Z00?o0?neoookJ_oonfX01ooonfX00ol0oh_ooo]ZoookJP0Koook
JP05ool0Cooonf[ooo]ZoookJ_l0oiH02ooonfX01Ooo703ooo]ZoookJ_oonf[o^?l0017ooo]Z00Go
d_l0oookJ_oonf[ooo]Zomgo0002oookJP03ob/0oooonf[ooo]Z00Gooo]Z00Cooi/0ool00?oonf[o
k?l02?oonfX00onC0?oooo]ZoookJP07oookJP03oeL0oooonf[ooo]Z00?ooo]Z00?oo`3LoookJ_oo
nfX01?oonfX00onMo`3ooo]ZoookJP03oookJP03ond0oooonf[ooo]Z01[ooo]Z00?oK03ooookJ_oo
nfX07_oonfX002Sooo]Z1_oo_`08ooo9053ooo]Z1_l0X_l00ooonf[oiOl0onGo0003onGo00Wooo]Z
0_oUo`03o`3oXP03o`2<oooonf[ooo]Z00Sooo]Z0ooUo`0>oookJP?oo`3b0ooonfX3o`3oEPSooo]Z
0_oo0:05oookJP;oE03o0_l09Ol8oookJP03onGo0?l0C?oo04co00;oogT02OoonfX2og_o00?o001o
0ooonfX2oonL0003oom10?oonf[ooo]Z00;o000000?o0?lho`000?l80?l04_oonfX2oolP00Kooo]Z
00?oo`2eoookJ_oonfX05_oonfX00ooob@3ooo]ZoookJP07oookJP03o`3oRooonf[ooo]Z01[ooo]Z
00Goo`1?oookJ_oonf[ooo]Zo`3oUP0;oookJP05oolL0?oonf[ooo]ZoookJ_nho`004OoonfX01OoB
o`3ooo]ZoookJ_oonf[ogOl000?ooo]Z00?o:`3ooookJ_oonfX01?oonfX01OooV`3oo`00oookJ_o/
o`3oo`2Y00Oooo]Z00?oT`3ooookJ_oonfX01OoonfX2ooo90003oeL0oooob@3oolT000?ooo]Z00?o
o`3LoookJ_oonfX01OoonfX00onMo`3ooo]ZoookJP03oookJP03ond0oooonf[ooo]Z01Wooo]Z00?o
K03ooookJ_oonfX0@_oonfX6oono0003oookJ_l0X_oo0:;o00?o0:;oDooonfX6o`2Ro`Gookl02ooo
nfX3o`3oXP03o`2<oooonf[ooo]Z00Sooo]Z0ol0ob4?oookJP;oo`3b0ooonfX3o`3oEPSooo]Z0_oo
0:06oookJP;oE03o0_l09Ol7oookJP;o:P3o00?o04coool:0?oo2P002_oonfX01?mko`3o001oo`00
Ool007l3oookJP;ooi`000?ood40oookJ_oonfX00_l000001?l0ocSo0000o`P0ool80?lAoookJP;o
ob001ooonfX00ooo0;Gooo]ZoookJP0EoookJP03o`3o]Ooonf[ooo]Z00Oooo]Z00?o0?n;oookJ_oo
nfX06_oonfX00ooo04oooo]ZoookJP02oookJP03o`3oU_oonf[ooo]Z00Sooo]Z00Gooa`0oookJ_oo
nf[ooo]ZokSo000BoookJP05om;o0?oonf[ooo]ZoookJ_oMo`000_oonfX00ol[0?oooo]ZoookJP05
oookJP04ool00?oonf[ooo]Zonco00Oooo]Z00?oT`3ooookJ_oonfX01ooonfX00omG0?oookL0oook
JP03oookJP03ool0g?oonf[ooo]Z00Gooo]Z00?oWOl0oookJ_oonfX00ooonfX00oo]0?oooo]Zoook
JP0JoookJP03of`0oooonf[ooo]Z01gooo]Z000UoookJP?ookl00ooonfX9ooo905Sooo]Z1_l0X_l4
onGo00Gooo]Z1OoUo`03o`3oXP?o08co2?oonfX3onGo00kooo]Z0_oo0?84oookJP;o0?mF2?oonfX2
ool0X0Gooo]Z0_mD0?l2o`0Uo`Oooo]Z0_oUo`02o`1<o`03oomi0?oonf[ooo]Z00Sooo]Z0_mko`00
0ol007oooo]ZoookJP03oookJP03oonL0?oo@@3ooo]Z00?o00000_l0ocP2o`P0oa;ooo]Z00?oob00
oookJ_oonfX01?oonfX00ooo0;Gooo]ZoookJP0FoookJP03ooo90?oonf[ooo]Z00Oooo]Z00?o0?n;
oookJ_oonfX06_oonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00_ooo]Z00Gooa`0oookJ_oonf[ooo]Z
okSo000AoookJP05om;o0?oonf[ooo]ZoookJ_oMo`000_oonfX00ol[0?oooo]ZoookJP05oookJP04
oonK0?oo003ooo]Zonco00Sooo]Z00?oT`3ooookJ_oonfX01OoonfX2ooo90003oeL0oooob@3oolT0
00?ooo]Z00?oo`3LoookJ_oonfX01?oonfX00onMo`3ooo]ZoookJP03oookJP03ond0oooonf[ooo]Z
05_ooo]Z0ooo_`03oookJPCo0:;oG_oonfX5o`2Ro`Cookl02_oonfX3o`3oXP?o08co2?oonfX3o`3o
8@kooo]Z0ooo0?83oookJP;o0?mF2?oonfX2ool0X0Kooo]Z00CoE03ooookJ_l09Ooo02Go1ooonfX0
1?lZ0?oo04coo`1<oooo2P0:oookJP;oNol000?o001ooookJ_oonfX00ooonfX00oooW03ood40oook
JP03o`0000;o0?lh00?ooo]Zo`P0oooonfX04OoonfX00ooo803ooo]ZoookJP05oookJP03ool0]Ooo
nf[ooo]Z01Gooo]Z00?o0?neoookJ_oonfX01ooonfX00ol0oh_ooo]ZoookJP0JoookJP03ool0Cooo
nf[ooo]Z00;ooo]Z00?o0?nFoookJ_oonfX02?oonfX01Ooo703ooo]ZoookJ_oonf[o^?l001;ooo]Z
00God_l0oookJ_oonf[ooo]Zomgo0002oookJP03ob/0oooonf[ooo]Z00Cooo]Z00Gooi/0ool00?oo
nf[ooo]Zonco0007oookJP03oi<0oooonf[ooo]Z00Oooo]Z00?oE`3ooookJ_oonfX00ooonfX00ooo
0=cooo]ZoookJP04oookJP03oigo0?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX0>_oonfX002Oo
oo]Z2ooob@1QoookJP?o0:;o3OoUo`03o`3oXP?o08co2?oonfX2onGo00kooo]Z0ooo0?83oookJP;o
0?mF2?oonfX2ool0X0Gooo]Z0_mD0?l00ol09Ooooo]ZoookJP06oookJP03onGo0?oonf[o04co00;o
ogT02_oonfX00omko`3ooo]ZoookJP04oookJP03oonL0?oo@@3o000000?o000000Cooo]Zo`3o>?oo
nf[o203o4_oonfX00ooo803ooo]ZoookJP04oookJP;oo`2e5ooonfX00ooob@3ooo]ZoookJP07oook
JP03o`3oRooonf[ooo]Z01[ooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP0;oookJP05oolL0?oonf[o
oo]ZoookJ_nho`004?oonfX01OoBo`3ooo]ZoookJ_oonf[ogOl000?ooo]Z00?o:`3ooookJ_oonfX0
1OoonfX01?oo003ooo]ZoookJ_o/o`07oookJP03oi<0oooonf[ooo]Z00Kooo]Z00CoolT0oeL0oooo
b@3oolT00ooonfX00ooo0=cooo]ZoookJP05oookJP03oigo0?oonf[ooo]Z00?ooo]Z00?ok@3ooook
J_oonfX0G?oonfX4o`2RofWooo]Z0_l0X_l5oono00Sooo]Z0ol0oj83o`2<o`Sooo]Z0_l0ob4?oook
JP;oo`3b0ooonfX2o`3oEPSooo]Z0_oo0:05oookJP;oE03o00?ooo]Zo`0UoooonfX01_oonfX2obX0
o`03o`1<oooo2P3oo`X000[ooo]Z0_mko`05oookJP03oonL0?oo@@3o000000?o000000Cooo]Zo`3o
>?oonf[o203o4_oonfX00ooo803ooo]ZoookJP05oookJP;oo`2e5_oonfX00ol0okGooo]ZoookJP07
oookJP03o`3oRooonf[ooo]Z01[ooo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP08
oookJP05oolL0?oonf[ooo]ZoookJ_nho`004OoonfX01OoBo`3ooo]ZoookJ_oonf[ogOl000;ooo]Z
00?o:`3ooookJ_oonfX01OoonfX01?ooV`3oo`00oookJ_o/o`07oookJP03oi<0oooonf[ooo]Z00Oo
oo]Z00?oE`3ooong0?oonfX00ooonfX00ooo0=cooo]ZoookJP05oookJP03oigo0?oonf[ooo]Z00?o
oo]Z00?ok@3ooookJ_oonfX0>OoonfX002Gooo]Z0_oob@04oookJPKoolT0IooonfX2o`2Ro`_oiOl0
00Cooo]Zo`3oX_l0oj;o0?nR0ol0S?l7oookJP?oiOl03_oonfX2ool0lP?ooo]Z0_l0oeH8oookJP;o
o`2P1OoonfX2oe@0o`03o`0Uoooonf[ooo]Z00Gooo]Z0_oUo`02o`1<o`03oomi0?oonf[ooo]Z00So
oo]Z0_mko`05oookJP03oonL0?oo@@3o000000?o000000Cooo]Zo`3o>?oonf[o203o4_oonfX2oolP
00Kooo]Z00?oo`2eoookJ_oonfX05OoonfX00ooob@3ooo]ZoookJP06oookJP03o`3oRooonf[ooo]Z
01_ooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP0:oookJP05oolL0?oonf[ooo]ZoookJ_nho`004Ooo
nfX01OoBo`3ooo]ZoookJ_oonf[ogOl000?ooo]Z00?o:`3ooookJ_oonfX01?oonfX01?ooV`3oo`00
oookJ_o/o`08oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?oolT0oeL0oooob@001?oonfX00ooo0=co
oo]ZoookJP04oookJP03oigo0?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX0F_oonfX2o`2Rog;o
oo]Z0_l0X_l4oono00Oooo]Z1?l0oj82o`2<o`Oooo]Z0ol0ob4>oookJP?oo`3b0_oonfX2o`3oEPSo
oo]Z0_oo0:05oookJP;oE03o0_l09Ol7oookJP;o:P3o00?o04coool:0?oonfX02_oonfX00omko`3o
oo]ZoookJP03oookJP03oonL0?oo@@3o000000?o000000?ooo]Zo`3o>?oonfX00_l80?lAoookJP;o
ob001ooonfX00ooo0;Gooo]ZoookJP0DoookJP03o`3o]Ooonf[ooo]Z00Kooo]Z00?o0?n;oookJ_oo
nfX06ooonfX00ooo04oooo]ZoookJP02oookJP03o`3oU_oonf[ooo]Z00Oooo]Z00Gooa`0oookJ_oo
nf[ooo]ZokSo000BoookJP05om;o0?oonf[ooo]ZoookJ_oMo`000_oonfX00ol[0?oooo]ZoookJP05
oookJP04ool00?oonf[ooo]Zonco00Oooo]Z00?oT`3ooookJ_oonfX01ooonfX00omG0?oookL0oook
JP03oookJP03ool0g?oonf[ooo]Z00Gooo]Z00?oWOl0oookJ_oonfX00_oonfX00oo]0?oooo]Zoook
JP0ioookJP00;?oonfX3ooo906_ooo]Z3OoUo`02oookJP?o0?nR0_l0S?l8oookJP?oiOl01_oonfX2
onGo00Gooo]Z0ooo0?82oookJP03o`3oE_oonf[ooo]Z00Oooo]Z0_oo0:05oookJP03oe@0ool09Ooo
02Go00Oooo]Z0_oUo`000ol0C?ooogT0oomi000:oookJP;oNol01?oonfX01?l0003ood40oom10?l0
0003oookJP;o0?lh00?o203ooookJ_oonfX04OoonfX00ooo803ooo]ZoookJP04oookJP03ool0]Ooo
nf[ooo]Z01Gooo]Z00?oolT0oookJ_oonfX01_oonfX00ol0oh_ooo]ZoookJP0JoookJP03ool0Cooo
nf[ooo]Z00;ooo]Z00?o0?nFoookJ_oonfX02?oonfX01Ooo703ooo]ZoookJ_oonf[o^?l0017ooo]Z
00God_l0oookJ_oonf[ooo]Zomgo0002oookJP03ob/0oooonf[ooo]Z00Gooo]Z00Cooi/0ool00?oo
nf[ok?l01ooonfX00onC0?oooo]ZoookJP07oookJP03ooo90?mG0?ooolT000?ooo]Z00?oo`3Loook
J_oonfX01OoonfX00onMo`3ooo]ZoookJP03oookJP03ond0oooonf[ooo]Z0=3ooo]Z0ol0X_l4oono
00Oooo]Z0ol0oj800ol0S?oooo]ZoookJP06oookJP?o0?lQ3_oonfX3ool0lP03oookJ_l0oeKo0?mF
00Sooo]Z0_oo0:05oookJP;oE03o0_l09Ol7oookJP04obX0ool0C?ooo`X0ool:00[ooo]Z0_mko`04
oookJP04o`000?oo@@3ood40o`0000?ooo]Z0_l0ocP00ooonf[o203ooookJP0AoookJP03oolP0?oo
nf[ooo]Z00Gooo]Z00?oo`2eoookJ_oonfX05?oonfX00ol0okGooo]ZoookJP06oookJP03o`3oRooo
nf[ooo]Z01[ooo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP08oookJP05oolL0?oo
nf[ooo]ZoookJ_nho`004_oonfX01OoBo`3ooo]ZoookJ_oonf[ogOl000;ooo]Z00?o:`3ooookJ_oo
nfX01?oonfX01OooV`3oo`00oookJ_oo0:Wok?l000Oooo]Z00?oT`3ooookJ_oonfX01ooonfX00omG
0?oookL0oookJP02oookJP03ool0g?oonf[ooo]Z00Gooo]Z00?oWOl0oookJ_oonfX00ooonfX00oo]
0?oooo]ZoookJP0hoookJP00;?oonfX00ooob@3ooo]ZoookJP1ZoookJQ3oiOl00ooonfX3o`3oXP03
o`2<oooonf[ooo]Z00Oooo]Z0ooUo`03oookJP?oiOl01ooonfX2ool0lP03oookJ_l0oeKo0?mF00Wo
oo]Z0_oo0:04oookJP;oE03o0_l09Ol7oookJP04onGo0?oonf[oolT0oomi00_ooo]Z00CoNol0oook
J_oonf[ooo]Z0_l000000oooW03ood40oookJP04oookJP03o`3o>?l80?oo203o01;ooo]Z00?oob00
oookJ_oonfX01?oonfX00ooo0;Gooo]ZoookJP0DoookJP03ooo90?oonf[ooo]Z00Oooo]Z00?o0?n;
oookJ_oonfX06_oonfX00ooo04oooo]ZoookJP02oookJP03o`3oU_oonf[ooo]Z00Oooo]Z00Gooa`0
oookJ_oonf[ooo]ZokSo000AoookJP05om;o0?oonf[ooo]ZoookJ_oMo`000ooonfX00ol[0?oooo]Z
oookJP05oookJP04ool00?oonf[ooo]Zonco00Oooo]Z00?oT`3ooookJ_oonfX01ooonfX00omG0?oo
olT0oookJP03oookJP03ool0g?oonf[ooo]Z00Cooo]Z00?oWOl0oookJ_oonfX00ooonfX00oo]0?oo
oo]ZoookJP3CoookJP?o0:;o00?ooo]Zoono0?oo_`000ooo_`05oookJP?o0?nR00?o08cooookJ_oo
nfX01_oonfX3o`3o8@kooo]Z0_oo0?800ooonf[o0?mFoookJP08oookJP;oo`2P1OoonfX2oe@0o`;o
02Go1_oonfX2obX0o`03o`1<oooo2P3ooo]Z00[ooo]Z00CoNol0oookJ_oonf[ooo]Z0_l000000ooo
W03ood40oookJP04oookJP03o`3o>?oonf[o203o01;ooo]Z00?oob00oookJ_oonfX01OoonfX00ooo
0;Gooo]ZoookJP0DoookJP03o`3o]Ooonf[ooo]Z00Kooo]Z00?o0?n;oookJ_oonfX06_oonfX00ooo
04oooo]ZoookJP02oookJP03o`3oU_oonf[ooo]Z00Sooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000A
oookJP05om;o0?oonf[ooo]ZoookJ_oMo`000ooonfX00ol[0?oooo]ZoookJP04oookJP04oonK0?oo
003ooo]Zonco00Oooo]Z00?oT`3ooookJ_oonfX01ooonfX00omG0?oookL0oookJP03oookJP03ool0
g?oonf[ooo]Z00Gooo]Z00?oWOl0oookJ_oonfX00_oonfX00oo]0?oooo]ZoookJP0hoookJP00Looo
nfX3onGo02?ooo]Z4OoUo`000ooo_`3ooo]ZoookJP02oookJP?o0?nR00?o08cooookJ_oonfX01ooo
nfX8onGo00Oooo]Z0ooo0?82o`3oEPWooo]Z0_oo0:04oookJP;oE03o0_l09Ol6oookJP;oiOl000?o
oo]Zoomi0?ooN@000_oonfX00ooUo`3ooo]ZoookJP05oookJP03og_o0?oonf[ooo]Z00?o000000?o
oi`0oom10?oonfX01?oonfX00ol0ocSooo]Zo`P0o`0BoookJP03oolP0?oonf[ooo]Z00Cooo]Z00?o
o`2eoookJ_oonfX05?oonfX00ooob@3ooo]ZoookJP07oookJP03o`3oRooonf[ooo]Z01[ooo]Z00?o
o`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP07oookJP05oolL0?oonf[ooo]ZoookJ_nho`00
4OoonfX01OoBo`3ooo]ZoookJ_oonf[ogOl000?ooo]Z00?o:`3ooookJ_oonfX01?oonfX01?ooV`3o
o`00oookJ_o/o`07oookJP03oi<0oooonf[ooo]Z00Sooo]Z00?oE`3ooookJ_oonfX00_oonfX00ooo
0=cooo]ZoookJP05oookJP03oigo0?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX0eOoonfX4o`2R
o`;ooo]Z0ooo_`05oookJP?o0?nR2OoonfX2o`3o8@kooo]Z0ooo0?800ol0oeKooo]ZoookJP07oook
JP;oo`2P1OoonfX01?mD0?oooo]Zo`0Uool09Ol6oookJP04obX0oooonf[oo`X0ool:00[ooo]Z00?o
Nol0oookJ_oonfX00ol000000oooW03ood40oookJP04oookJP04o`3o>?oonf[o203oo`P0oa7ooo]Z
00?oob00oookJ_oonfX01OoonfX00ooo0;Gooo]ZoookJP0DoookJP03o`3o]Ooonf[ooo]Z00Kooo]Z
00?o0?n;oookJ_oonfX06_oonfX00ooo04oooo]ZoookJP02oookJP03o`3oU_oonf[ooo]Z00Oooo]Z
00Gooa`0oookJ_oonf[ooo]ZokSo000BoookJP05om;o0?oonf[ooo]ZoookJ_oMo`000_oonfX00ol[
0?oooo]ZoookJP05oookJP04oonK0?oo003oo`2Yonco00Oooo]Z00?oT`3ooookJ_oonfX01ooonfX0
0omG0?oookL0oookJP02oookJP03ool0g?oonf[ooo]Z00Gooo]Z00?oWOl0oookJ_oonfX00ooonfX0
0oo]0?oooo]ZoookJP0goookJP00LooonfX7onGo02_ooo]Z0ol0X_l3oookJP?ookl01?oonfX3o`3o
XPWooo]Z2?oUo`08oookJP;oo`3b0_l0oeH9oookJP;oo`2P1?oonfX2oe@0o`;o02Go1_oonfX2onGo
0003ooo90?ooN@3ooo]Z00;oiOl01ooonfX00omko`3ooo]Zo`000003o`000003oonL0?oo@@3ooo]Z
00Cooo]Z0_l0ocP00ol80?oooo]ZoookJP0@oookJP03oolP0?oonf[ooo]Z00Cooo]Z00?oo`2eoook
J_oonfX05?oonfX00ooob@3ooo]ZoookJP07oookJP03o`3oRooonf[ooo]Z01Wooo]Z00?oo`1?oook
J_oonfX00_oonfX00ol0oiKooo]ZoookJP08oookJP05oolL0?oonf[ooo]ZoookJ_nho`004?oonfX0
0ooBo`3ooo]ZoookJP02oookJP04omgo0?oonf[ooo]Zob/0o`Oooo]Z00Cooi/0ool00?oonf[ok?l0
1ooonfX00onC0?oooo]ZoookJP07oookJP03oeL0oooob@3ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX0
1OoonfX00onMo`3ooo]ZoookJP03oookJP03ond0oooonf[ooo]Z0=Sooo]Z0ol0X_l2oookJP?ookl0
1OoonfX3o`3oXPSooo]Z0ol0ob4>oookJP;oo`3b00?o0?mFoookJ_oonfX01ooonfX2ool0X0Cooo]Z
0_mD0?l00ooonf[o02Goo`0Uo`05oookJP;o:P3o00?o04coool:0?oo2P002OoonfX00omko`3ooo]Z
o`000003o`000003oonL0?oo@@3ooo]Z00Cooo]Z0_l0ocP00ooonf[o203ooookJP0@oookJP03oolP
0?oonf[ooo]Z00Gooo]Z00?oo`2eoookJ_oonfX05?oonfX00ol0okGooo]ZoookJP06oookJP03o`3o
Rooonf[ooo]Z01Wooo]Z00?oo`1?oookJ_oonfX00ooonfX00ol0oiKooo]ZoookJP07oookJP05oolL
0?oonf[ooo]ZoookJ_nho`004OoonfX00ooBo`3ooo]ZoookJP02oookJP04omgo0?oonf[ooo]Zob/0
o`Oooo]Z00Coo`00oookJ_oo0:Wok?l01_oonfX00onC0?oooo]ZoookJP07oookJP03oeL0oooonf[o
okL000?ooo]Z00?oo`3LoookJ_oonfX01OoonfX00onMo`3ooo]ZoookJP03oookJP03ond0oooonf[o
oo]Z03Kooo]Z001coookJP[oiOl0:ooonfX4o`2Ro`;ooo]Z0_oo_`05oookJP?o0?nR1OoonfX:onGo
00Wooo]Z00Coo`3boookJ_l0oeKo0?mF2OoonfX2ool0X0Cooo]Z00?oE03ooookJ_l09Ol01ooonfX0
0ooUo`3oolT0onGo0003onGo00Oooo]Z0_mko`03o`0000;ooo]Z00?ood40oookJ_oonfX01?oonfX0
0ol0ocSo203oo`P0o`0@oookJP03oolP0?oonf[ooo]Z00Gooo]Z00?oo`2eoookJ_oonfX05?oonfX0
0ooob@3ooo]ZoookJP07oookJP03o`3oRooonf[ooo]Z01Wooo]Z00?oo`1?oookJ_oonfX00_oonfX0
0ol0oiKooo]ZoookJP07oookJP05oolL0?oonf[ooo]ZoookJ_nho`004OoonfX00ooBo`3ooo]Zoook
JP02oookJP04omgo0?oonf[ooo]Zob/0o`Oooo]Z00Coo`00oookJ_oo0:Wok?l01_oonfX00onC0?oo
oo]ZoookJP08oookJP03oeL0oooonf[ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX01?oonfX00onMo`3o
oo]ZoookJP03oookJP03ond0oooonf[ooo]Z0=_ooo]Z0ol0X_l2oookJP;ookl01_oonfX3o`3oXPSo
oo]Z0ol0ob4=oookJP03ool0l_l0oeKo0?mF00Wooo]Z0_oo0:04oookJP;oE03o00?ooo]Zo`0Uoooo
nfX01OoonfX2obX0o`03o`1<oooo2P3ooo]Z00Sooo]Z0_mko`03o`0000;ooo]Z00?ood40oookJ_oo
nfX01?oonfX00ol0ocSooo]Zo`P0o`0@oookJP03oolP0?oonf[ooo]Z00Kooo]Z00?oo`2eoookJ_oo
nfX05?oonfX00ol0okGooo]ZoookJP06oookJP03o`3oRooonf[ooo]Z01Wooo]Z00?oo`1?oookJ_oo
nfX00ooonfX00ol0oiKooo]ZoookJP06oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oo
nfX03ooonfX00ooBo`3ooo]ZoookJP02oookJP04omgo0?oonf[ooo]Zob/0o`Kooo]Z00Cooi/0ool0
0?oo0:Wok?l01ooonfX00onC0?oooo]ZoookJP07oookJP03oeL0oooo]`3ooo]Z00?ooo]Z00?oo`3L
oookJ_oonfX01OoonfX00onMo`3ooo]ZoookJP02oookJP03ond0oooonf[ooo]Z03Kooo]Z001Doook
JP;oUol05ooUo`06oookJPkoiOl0:ooonfX3o`2Ro`03oookJ_oo_`3ookl000Kooo]Z0ol0oj82oook
JPcoiOl02?oonfX2ool0lP03oookJ_l0oeKooo]Z00Wooo]Z0_oo0:03oookJP;oE03o0_l09Ol6oook
JPKoiOl01ooonfX01?l0003oNol0o`000?l00003oookJP03oom10?oonf[ooo]Z00Cooo]Z0_l0ocP0
0ol80?oooo]ZoookJP0>oookJP03oolP0?oonf[ooo]Z00Gooo]Z00?oo`2eoookJ_oonfX05?oonfX0
0ooob@3ooo]ZoookJP07oookJP03o`3oRooonf[ooo]Z01Wooo]Z00?oo`1?oookJ_oonfX00_oonfX0
0ol0oiKooo]ZoookJP07oookJP05oolL0?oonf[ooo]ZoookJ_nho`004OoonfX01OoBo`3ooo]Zoook
J_oonf[ogOl000?ooo]Z00?o:`3ooookJ_oonfX01?oonfX01?ooV`3oo`00oookJ_o/o`07oookJP03
oi<0oooonf[ooo]Z00Oooo]Z00?oE`3ooong0?oonfX00ooonfX00ooo0=cooo]ZoookJP05oookJP03
oigo0?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX0Q_oonfXIoiOo03kooo]Z0ol0X_l00ooonf[o
okl0oono0006oookJP04o`2<ool0oj;o0?nRo`3oXPSooo]Z0_l0ob4<oookJP;oo`3b0_l0oeH9oook
JP;oo`2P1?oonfX2oe@0o`;o02Go1_oonfX01?lZ0?oo04coool:0?oo2P08oookJP04o`000?mko`3o
0000o`0000?ooo]Z00?ood40oookJ_oonfX01?oonfX2o`3o>003o`P0oooonf[ooo]Z00kooo]Z00?o
ob00oookJ_oonfX01_oonfX00ooo0;Gooo]ZoookJP0DoookJP03o`3o]Ooonf[ooo]Z00Kooo]Z00?o
0?n;oookJ_oonfX06OoonfX00ooo04oooo]ZoookJP02oookJP03o`3oU_oonf[ooo]Z00Oooo]Z00Go
oa`0oookJ_oonf[ooo]ZokSo000BoookJP05om;o0?oonf[ooo]ZoookJ_oMo`000ooonfX00ol[0?oo
oo]ZoookJP04oookJP04oonK0?oo003oo`2Yonco00Kooo]Z00?oT`3ooookJ_oonfX01ooonfX00omG
0?oooo]Zoong0003oookJP03ool0g?oonf[ooo]Z00Gooo]Z00?oWOl0oookJ_oonfX00ooonfX00oo]
0?oooo]ZoookJP0eoookJP00CooonfX5oiOo00Cooo]Z3ooo9`06oookJQKoiOl00_nGo`0ZoookJP?o
0:;o0ooo_`05oookJP03o`2<ool0oj;o0?nR00koiOl02?oonfX2ool0lP;o0?mF2_oonfX2ool0X0?o
oo]Z0_mD0?l2o`0Uo`Cooo]Z1ooUo`03oookJP03oomi0?oonf[ooo]Z00;o000000?oNol0o`000?oo
nfX00ooonfX2oom100Kooo]Z00?o0?lho`P0oooonfX03ooonfX00ooo803ooo]ZoookJP05oookJP;o
o`2e5OoonfX00ooob@3ooo]ZoookJP07oookJP03o`3oRooonf[ooo]Z01Sooo]Z00?oo`1?oookJ_oo
nfX00ooonfX00ol0oiKooo]ZoookJP07oookJP05oolL0?oonf[ooo]ZoookJ_nho`004?oonfX00ooB
o`3ooo]ZoookJP02oookJP05omgo0?oonf[ooo]ZoookJ_l[0?l01_oonfX01?ooV`3oo`00ool0ZOo/
o`06oookJP03oi<0oooonf[ooo]Z00Sooo]Z00?oE`3ooookJ_oonfX00ooonfX00ooo0=cooo]Zoook
JP04oookJP03oigo0?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX0POoonfX5oiOo00?ooo]Z3ooo
9`07oookJQOoUol0:_oonfX3o`2Ro`?ookl01_oonfX01?l0S?oo0?nRo`3oX_l0oj87oookJP?o0?lQ
2ooonfX2ool0lP;o0?mF2OoonfX2ool0X0Cooo]Z0_mD0?l2o`0Uo`Gooo]Z0_lZ0?l00ooonf[oo`X0
oookJP06oookJP;o000000?oNol0o`000?oonfX00ooonfX2oom100Kooo]Z00?o0?lho`P0ool80?l0
3ooonfX00ooo803ooo]ZoookJP06oookJP;oo`2e5OoonfX00ol0okGooo]ZoookJP06oookJP03o`3o
Rooonf[ooo]Z01Sooo]Z00?oo`1?oookJ_oonfX00ooonfX00ol0oiKooo]ZoookJP07oookJP05oolL
0?oonf[ooo]ZoookJ_nho`004OoonfX00ooBo`3ooo]ZoookJP02oookJP04omgo0?oonf[ooo]Zob/0
o`Oooo]Z00?oo`00ool0ZOo/o`001ooonfX00onC0?oooo]ZoookJP07oookJP03oeL0oooo]`3ooo]Z
00?ooo]Z00?oo`3LoookJ_oonfX01OoonfX00onMo`3ooo]ZoookJP02oookJP03ond0oooonf[ooo]Z
03Gooo]Z001:oookJPGoUol00ooonfX6oolW00oooo]Z3?oo9`0=onGo00Gooo]Z1OnGo`0XoookJP?o
0:;o0_oo_`05oookJQ3oiOl02OoonfX01?oo0?;ooo]Zo`3oE_l0oeH:oookJP03ool0X?oonf[ooo]Z
00;ooo]Z0_mD0?l2o`0Uo`03oookJ_oUo`3oiOl000OoiOl00_oonfX00oooN@3ooo]ZoookJP03o`00
0003og_o0?oonf[ooo]Z00Cooo]Z00?ood40oookJ_oonfX01?oonfX00ol0ocSo203ooookJP0?oook
JP03oolP0?oonf[ooo]Z00Kooo]Z00?oo`2eoookJ_oonfX04ooonfX00ooob@3ooo]ZoookJP06oook
JP03o`3oRooonf[ooo]Z01Wooo]Z00?oo`1?oookJ_oonfX00ooonfX00ol0oiKooo]ZoookJP06oook
JP05oolL0?oonf[ooo]ZoookJ_nho`004OoonfX00ooBo`3ooo]ZoookJP02oookJP04omgo0?oonf[o
oo]Zob/0o`Oooo]Z00Coo`00oookJ_oo0:Wok?l01_oonfX00onC0?oooo]ZoookJP07oookJP03oeL0
oooo]`3ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX01OoonfX00onMo`3ooo]ZoookJP03oookJP03ond0
oooonf[ooo]Z07_ooo]Z1OnGo`02oookJPKoobL03ooonfXFoolW00Sooo]Z1OnGo`0XoookJP?o0:;o
0_oo_`06oookJP;o08co0_l0oj88oookJP?o0?lQ2_oonfX01?oo0?;ooo]Zo`3oE_l0oeH9oookJP03
ool0X?oonf[ooo]Z00?ooo]Z00CoE03ooookJ_l09Ooo02Go1OoonfX01?lZ0?oo04coool:0?oo2P05
oookJP?o000000?oNol0oookJ_oonfX01?oonfX00ooo@@3ooo]ZoookJP04oookJP03o`3o>?oonf[o
203o00oooo]Z00?oob00oookJ_oonfX01ooonfX00ooo0;Gooo]ZoookJP0BoookJP03o`3o]Ooonf[o
oo]Z00Kooo]Z00?o0?n;oookJ_oonfX06OoonfX00ooo04oooo]ZoookJP03oookJP03o`3oU_oonf[o
oo]Z00Kooo]Z00?ooa`0oookJ_oonfX00_oonfX00onho`3ooo]ZoookJP0?oookJP03om;o0?oonf[o
oo]Z00;ooo]Z00CogOl0oookJ_oonf[o:`3o1_oonfX01?ooV`3oo`00ool0ZOo/o`06oookJP03oi<0
oooonf[ooo]Z00Oooo]Z00?oE`3ooookJ_oo]`000ooonfX00ooo0=cooo]ZoookJP05oookJP03oigo
0?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX0=?oonfX004Gooo]Z1OnGo`000ooonf[oobL0oolW
0003oolW02goN@3o1?oUo`08oolW0003oookJ_nGo`3oUol000;oUol09ooonfX2o`2Ro`;ookl01_oo
nfX00ol0S?oo0?nRo`3oXP03oookJPSoiOl000?o0?lQoookJ_oonfX01_oonfX2ool0lP03oookJ_l0
oeKo0?mF00Wooo]Z0_oo0:04oookJP03oe@0oooonf[oiOl000[oiOl00oooN@000ooonf[o0000o`00
0002o`000003og_o0?oonf[ooo]Z00Cooo]Z00?ood40oookJ_oonfX01?oonfX2o`3o>003o`P0oooo
nf[ooo]Z00gooo]Z00?oob00oookJ_oonfX01_oonfX00ooo0;Gooo]ZoookJP0CoookJP03ooo90?oo
nf[ooo]Z00;ooo]Z0_oob@02oookJP03o`3oRooonf[ooo]Z01Wooo]Z00?oo`1?oookJ_oonfX00ooo
nfX00ol0oiKooo]ZoookJP06oookJP05oolL0?oonf[ooo]ZoookJ_nho`004?oonfX00ooBo`3ooo]Z
oookJP03oookJP04omgo0?oonf[ooo]Zob/0o`Kooo]Z00Cooi/0ool00?oo0:Wok?l01_oonfX00onC
0?oooo]ZoookJP08oookJP03oeL0oooonf[ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX01?oonfX00onM
o`3ooo]ZoookJP03oookJP03ond0oooonf[ooo]Z07Kooo]Z1OnGo`000ooonf[oobL0oolW0002oolW
03;oN@3o2?oo9`05oiOo02Oooo]Z00Co0:;ooono0?oo_`3ookl01OoonfX2o`2<o`;o0?nR2OoonfX2
o`3o8@Wooo]Z0_oo0?800ooonf[o0?mFoookJP08oookJP;oo`2P1?oonfX2oe@0o`03oookJ_l09Ooo
oo]Z00Cooo]Z0_lZ0?l00ooonf[oo`X0oookJP03oookJPCo000000?oNol0oookJ_oonfX01?oonfX0
0ooo@@3ooo]ZoookJP04oookJP;o0?lh00?o203ooookJ_oonfX03OoonfX00ooo803ooo]ZoookJP07
oookJP03ool0]Ooonf[ooo]Z01;ooo]Z00?o0?neoookJ_oonfX01_oonfX00ol0oh_ooo]ZoookJP0I
oookJP03ool0Cooonf[ooo]Z00?ooo]Z00?o0?nFoookJ_oonfX01_oonfX01Ooo703ooo]ZoookJ_oo
nf[o^?l0017ooo]Z00?od_l0oookJ_oonfX00ooonfX01?oMo`3ooo]ZoookJ_l[0?l6oookJP04oonK
0?oo003ooo]Zonco00Kooo]Z00?oT`3ooookJ_oonfX01ooonfX00omG0?oookL0oookJP03oookJP03
ool0g?oonf[ooo]Z00Gooo]Z00?oWOl0oookJ_oonfX00_oonfX00oo]0?oooo]ZoookJP0doookJP00
@?oonfX5oiOo00KoobL01Omi0?l7oookJPGoiOl05ooonfX6onGo00Sooo]Z1_oUo`02oookJPGoobL0
1OnGo`06oookJP;oiOl07_oonfX3oono00Gooo]Z00?o08coo`3oX_l0oj802_oonfX2o`3o8@Sooo]Z
0_oo0?800ooonf[o0?mFo`3oEP09oookJP03ool0X?oonf[ooo]Z00;ooo]Z0_mD0?l00ol09Ooooo]Z
onGo0008onGo00?oogT01?l000000ooonf[oNol0og_o0005oookJP03oom10?oonf[ooo]Z00Gooo]Z
00?o0?lho`P0oooonfX03_oonfX00ooo803ooo]ZoookJP06oookJP03ool0]Ooonf[ooo]Z01?ooo]Z
00?oolT0oookJ_oonfX00ooob@03oookJP03o`3oRooonf[ooo]Z01Wooo]Z00?oo`1?oookJ_oonfX0
0_oonfX00ol0oiKooo]ZoookJP06oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX0
3_oonfX00ooBo`3ooo]ZoookJP02oookJP05omgo0?oonf[ooo]ZoookJ_l[0?l01_oonfX01?oo003o
oo]Zool0ZOo/o`06oookJP03oi<0oooonf[ooo]Z00Oooo]Z00?oE`3ooong0?oonfX00ooonfX00ooo
0=cooo]ZoookJP05oookJP03oigo0?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX0L?oonfX5oiOo
00GoobL01Omi0?lboookJPKoN@3o0_oonfX5oolW00CoUol09_oonfX00ol0X_oookl0oono0006oook
JP03o`2<ool0oj;o0?nR00Wooo]Z0_l0ob49oookJP;oo`3b0_l0oeH9oookJP03ool0X?oonf[ooo]Z
00?ooo]Z0_mD0?l00ol09Ooooo]ZoookJP04oookJP04obX0ool0C?ooo`X0ool:00;ooo]Z1?l00000
0ooonf[oNol0og_o0005oookJP03oom10?oonf[ooo]Z00Gooo]Z00?o0?lho`P0ool80?l03_oonfX0
0ooo803ooo]ZoookJP07oookJP03ool0]Ooonf[ooo]Z01;ooo]Z00?o0?neoookJ_oonfX01_oonfX0
0ol0oh_ooo]ZoookJP0IoookJP03ool0Cooonf[ooo]Z00?ooo]Z00?o0?nFoookJ_oonfX01_oonfX0
1Ooo703ooo]ZoookJ_oonf[o^?l0017ooo]Z00?od_l0oookJ_oonfX00_oonfX01OoMo`3ooo]Zoook
J_oonf[o:`3o00Kooo]Z00?oo`00ool0ZOo/o`001_oonfX00onC0?oooo]ZoookJP07oookJP03oeL0
oooo]`3ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX01_oonfX00onMo`3ooo]ZoookJP02oookJP03ond0
oooonf[ooo]Z03?ooo]Z000koookJPGoUol01Ooo9`000ooonf[oN@3oogT0o`03ogT0o`cooo]Z3OoU
o`0?oookJP;oiOl04_oonfX6onGo0003oookJ_oo9`3oobL000;oobL000?ooo]ZoiOo0?nGo`000onG
o`000ooonf[oiOl0onGo0003onGo01kooo]Z0_oo_`000ol0X_oooo]ZoookJP03oookJP;o0?nR2_oo
nfX00ol0ob7ooo]ZoookJP07oookJP03ool0l_oonf[ooo]Z00;o0?mF2?oonfX00ooo0:3ooo]Zoook
JP03oookJP;oE03o00?o02GooookJ_oonfX01ooUo`03oomi00Co00000_oonfX00omko`3ooo]Zoook
JP03oookJP03oom10?ooW03ooo]Z00Gooo]Z00?o0?lho`P0oooonfX03_oonfX00ooo803ooo]Zoook
JP06oookJP03ool0]Ooonf[ooo]Z01?ooo]Z1_oob@03oookJP03o`3oRooonf[ooo]Z01Sooo]Z00?o
o`1?oookJ_oonfX00ooonfX00ol0oiKooo]ZoookJP06oookJP05oolL0?oonf[ooo]ZoookJ_nho`00
4OoonfX00ooBo`3ooo]ZoookJP02oookJP04omgo0?oonf[ooo]Zob/0o`Oooo]Z00Coo`00ool0ZOoo
nf[ok?l01OoonfX00onC0?oooo]ZoookJP08oookJP03oeL0oooonf[ooo]Z00?ooo]Z00?oo`3Loook
J_oonfX01OoonfX00onMo`3ooo]ZoookJP02oookJP03ond0oooonf[ooo]Z06_ooo]Z1OnGo`04oolW
0003oookJ_mi0?ooN@3o00?oN@3o?OoonfX6ogT0o`03oookJ_oo9`3oobL000;oobL01OnGo`0Toook
JP?ookl01OoonfX00ol0S?oo0?nRo`3oXP09oookJP03o`3o8Ooonf[ooo]Z00Sooo]Z00Coo`3boook
J_l0oeKo0?mF2?oonfX2ool0X0Gooo]Z0_mD0?l00ol09Ooooo]ZoookJP03oookJP;o:P3o00?ooo]Z
ool:0?oonfX01Ol00002oookJP03og_o0?oonf[ooo]Z00?ooo]Z00?ood40oonL0?oonfX01OoonfX0
0ol0ocSooo]Zo`P0o`0>oookJP03oolP0?oonf[ooo]Z00Oooo]Z00?oo`2eoookJ_oonfX04_oonfX0
0ol0okGooo]ZoookJP06oookJP03o`3oRooonf[ooo]Z01Sooo]Z00?oo`1?oookJ_oonfX00ooonfX0
0ol0oiKooo]ZoookJP06oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX03ooonfX0
0ooBo`3ooo]ZoookJP02oookJP04omgo0?oonf[ooo]Zob/0o`Oooo]Z00?oo`00ool0ZOo/o`001_oo
nfX00onC0?oooo]ZoookJP07oookJP03oeL0oooo]`3ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX01Ooo
nfX00onMo`3ooo]ZoookJP02oookJP03ond0oooonf[ooo]Z03?ooo]Z000foookJPGoUol01?oo9`02
oookJPGoN@3o4OoonfXAonGo00Oo0?mg7_oonfX6onGo00CoobL000?ooo]ZoiOo0?oUo`001_oUo`0N
oookJP;ookl00_l0X_l4oookJP;o0?nR00?o08cooookJ_oonfX01_oonfX2o`3o8@Sooo]Z0_oo0?82
oookJP03o`3oE_oonf[ooo]Z00Kooo]Z0_oo0:05oookJP03oe@0ool09Ooooo]Z00?ooo]Z1OoUo`03
oomi00;o00001?oonfX00omko`3ooo]ZoookJP03oookJP;ood401_oonfX00ol0ocSo203ooookJP0>
oookJP03oolP0?oonf[ooo]Z00Kooo]Z00?oo`2eoookJ_oonfX04_oonfX6ooo900Cooo]Z00?o0?n;
oookJ_oonfX06?oonfX00ooo04oooo]ZoookJP03oookJP03o`3oU_oonf[ooo]Z00Kooo]Z00Gooa`0
oookJ_oonf[ooo]ZokSo000@oookJP03om;o0?oonf[ooo]Z00;ooo]Z00GogOl0oookJ_oonf[ooo]Z
ob/0o`06oookJP04oonK0?oo003oo`2Yonco00Kooo]Z00?oT`3ooookJ_oonfX01ooonfX00omG0?oo
okL0oookJP03oookJP03ool0g?oonf[ooo]Z00Gooo]Z00?oWOl0oookJ_oonfX00ooonfX00oo]0?oo
oo]ZoookJP1UoookJPGoUol00ooo9`02oookJPGoN@3o7OoonfX<o`3oMaoooo]Z1_mi0?l4oolW00Go
Uol08_oonfX2oono0003o`2Roooonf[ooo]Z00?ooo]Z0_l0oj88oookJP;o0?lQ2OoonfX2ool0lP03
oookJ_l0oeKo0?mF00Sooo]Z00?oo`2PoookJ_oonfX01?oonfX00omD0?oo02GooookJP05oookJP;o
:P3o0_oo2P03o`0000Cooo]Z00?oNol0oookJ_oonfX00ooonfX2oom100Kooo]Z00?o0?lhoookJ_l8
0?l03_oonfX00ooo803ooo]ZoookJP07oookJP03ool0]Ooonf[ooo]Z01;ooo]Z00?o0?neoookJ_oo
nfX01_oonfX00ol0oh_ooo]ZoookJP0HoookJP03ool0Cooonf[ooo]Z00?ooo]Z00?o0?nFoookJ_oo
nfX01_oonfX01Ooo703ooo]ZoookJ_oonf[o^?l0017ooo]Z00?od_l0oookJ_oonfX00_oonfX01OoM
o`3ooo]ZoookJ_oonf[o:`3o00Kooo]Z00Cooi/0ool00?oonf[ok?l01OoonfX00onC0?oooo]Zoook
JP07oookJP03oeL0oooo]`3ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX01_oonfX00onMo`3ooo]Zoook
JP02oookJP03ond0oooonf[ooo]Z03;ooo]Z000aoookJPGoUol00_oo9`04oookJPGoN@3o5_oonfX?
onGo00Wooo]Z3_l0ogLFoookJPooiOl07_oonfX3oono0003o`2Roooonf[ooo]Z00;ooo]Z0_l0oj80
0ol0S?oooo]ZoookJP06oookJP;o0?lQ2?oonfX00ooo0?;ooo]ZoookJP02o`3oEPSooo]Z00?oo`2P
oookJ_oonfX00ooonfX01?mD0?oo02Goo`0UoooonfX4oomi00?oiOl00oooN@000ol0003ooo]Zoook
JP03oookJP03og_o0?oonf[ooo]Z00Cooo]Z00?ood40oookJ_oonfX01?oonfX00ol0ocSo203oo`P0
o`0>oookJP03oolP0?oonf[ooo]Z00Kooo]Z00?oo`2eoookJ_oonfX04?oonfX8ooo900Cooo]Z00?o
0?n;oookJ_oonfX06?oonfX00ooo04oooo]ZoookJP03oookJP03o`3oU_oonf[ooo]Z00Gooo]Z00?o
oa`0oookJ_oonfX00_oonfX00onho`3ooo]ZoookJP0>oookJP03om;o0?oonf[ooo]Z00;ooo]Z00Co
gOl0oookJ_oonf[o:`3o1ooonfX01?oo003oo`2YoookJ_o/o`05oookJP03oi<0oooonf[ooo]Z00So
oo]Z00?oE`3ooookJ_oonfX00ooonfX00ooo0=cooo]ZoookJP05oookJP03oigo0?oonf[ooo]Z00?o
oo]Z00?ok@3ooookJ_oonfX0GooonfX5oiOo00;oobL00ooonfX5ogT0oaWooo]Z2Ol0ogL<oookJPko
0?mg5ooonfX5ogT0o`CoobL01?nGo`0PoookJP;ookl000?o0:;ooookJ_oonfX00ooonfX2o`3oXP03
o`2<oooonf[ooo]Z00Gooo]Z0_l0ob49oookJP03ool0l_oonf[ooo]Z00;o0?mF1ooonfX2ool0X0Go
oo]Z00?oE03oo`0Uool09Ol01OoonfX01?l0C?oo:P3oo`000?oo2P02o`0000Gooo]Z00?oNol0oook
J_oonfX01?oonfX00ooo@@3ooo]ZoookJP04oookJP03o`3o>?oonf[o203o00kooo]Z00?oob00oook
J_oonfX01ooonfX00ooo0;Gooo]ZoookJP0BoookJP03o`3o]Ooonf[ooo]Z00Kooo]Z00?o0?n;oook
J_oonfX06?oonfX00ooo04oooo]ZoookJP03oookJP03o`3oU_oonf[ooo]Z00Kooo]Z00Gooa`0oook
J_oonf[ooo]ZokSo000AoookJP03om;o0?oonf[ooo]Z00;ooo]Z00CogOl0oookJ_oonf[o:`3o1ooo
nfX00ooo003oo`2Yonco0006oookJP03oi<0oooonf[ooo]Z00Oooo]Z00?oE`3ooong0?oonfX00ooo
nfX00ooo0=cooo]ZoookJP05oookJP03oigo0?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX0<Ooo
nfX002cooo]Z1OnGo`000ooo9`3ooo]ZoookJP04oookJPCoN@3o5OoonfXBonGo01[ooo]Z3Ol0ogL>
oookJPgoiOl07_oonfX2oono0003o`2Roooonf[ooo]Z00;ooo]Z0_l0oj800ol0S?oooo]ZoookJP06
oookJP;o0?lQ1ooonfX2ool0lP;ooo]Z0_l0oeH7oookJP;oo`2P1?oonfX2oe@0o`03o`0Uoooonf[o
oo]Z00GoogT000CoiOl0obX0ooooN@3oogT01_oonfX2og_o00Gooo]Z00?ood40oonL0?oonfX01?oo
nfX00ol0ocSooo]Zo`P0o`0>oookJP03oolP0?oonf[ooo]Z00Kooo]Z00?oo`2eoookJ_oonfX03_oo
nfX9ooo900Gooo]Z00?o0?n;oookJ_oonfX05ooonfX00ooo04oooo]ZoookJP04oookJP03o`3oU_oo
nf[ooo]Z00Gooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000AoookJP05om;o0?oonf[ooo]ZoookJ_oM
o`000ooonfX00ol[0?oooo]ZoookJP05oookJP04ool00?oo0:Wooo]Zonco00Gooo]Z00?oT`3ooook
J_oonfX01ooonfX00omG0?oooo]ZoookJP03oookJP03ool0g?oonf[ooo]Z00Gooo]Z00?oWOl0oook
J_oonfX00ooonfX00oo]0?oooo]ZoookJP1JoookJPGoUol000?oobL0oookJ_oonfX00ooonfX4ogT0
oaGooo]Z2Ol0ogLSoookJPko0?mg3_oonfX6ogT0o`;oobL01OnGo`0MoookJP?ookl01OoonfX2o`3o
XP03o`2<oooonf[ooo]Z00Gooo]Z0_l0ob48oookJP;oo`3b0_oonfX2o`3oEPOooo]Z00?oo`2Poook
J_oonfX00ooonfX2oe@0o`03o`0Uoooonf[ooo]Z00Cooo]Z0_lZ0?l2ool:00Kooo]Z0_mko`05oook
JP03oom10?ooW03ooo]Z00Cooo]Z00Co0?lhoookJ_l80?oo203o3OoonfX00ooo803ooo]ZoookJP07
oookJP03ool0]Ooonf[ooo]Z01;ooo]Z00?o0?neoookJ_oonfX01_oonfX00ol0oh_ooo]ZoookJP0G
oookJP03ool0Cooonf[ooo]Z00Cooo]Z00?o0?nFoookJ_oonfX01OoonfX00ooo703ooo]ZoookJP02
oookJP03okSo0?oonf[ooo]Z00oooo]Z00God_l0oookJ_oonf[ooo]Zomgo0003oookJP03ob/0oooo
nf[ooo]Z00Gooo]Z00?oo`00oookJ_o/o`001OoonfX00onC0?oooo]ZoookJP07oookJP03oeL0oooo
]`3ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX01_oonfX00onMo`3ooo]ZoookJP02oookJP03ond0oooo
nf[ooo]Z037ooo]Z000YoookJP?oUol00_oo9`05oookJPGoN@3o4OoonfX8onGo00Oooo]Z2?oUo`0Z
oookJPWo0?mg1OoonfX?onGo00?oUol06ooonfX2oono0003o`2Roooonf[ooo]Z00;ooo]Z0_l0oj82
o`2<o`Oooo]Z00?o0?lQoookJ_oonfX01_oonfX2ool0lP;ooo]Z0_l0oeH7oookJP03ool0X?oonf[o
oo]Z00?ooo]Z00?oE03oo`0UoooonfX00ooonfX4oomi0003obX0ooooN@3oogT000Oooo]Z00?oNol0
oookJ_oonfX00ooonfX00ooo@@3ooi`0oookJP04oookJP03o`3o>?oonf[o203o00kooo]Z00?oob00
oookJ_oonfX01_oonfX00ooo0;Gooo]ZoookJP0?oookJPSoolT01OoonfX00ol0oh_ooo]ZoookJP0G
oookJP03ool0Cooonf[ooo]Z00Cooo]Z00?o0?nFoookJ_oonfX01OoonfX01Ooo703ooo]ZoookJ_oo
nf[o^?l0013ooo]Z00?od_l0oookJ_oonfX00_oonfX01?oMo`3ooo]ZoookJ_l[0?l7oookJP04oonK
0?oo003ooo]Zonco00Gooo]Z00?oT`3ooookJ_oonfX02?oonfX00omG0?oooo]ZoookJP03oookJP03
ool0g?oonf[ooo]Z00Gooo]Z00?oWOl0oookJ_oonfX00ooonfX00oo]0?oooo]ZoookJP1FoookJP?o
Uol00_oo9`04oookJPGoN@3o4OoonfX8o`3oMc[ooo]Z2Ol0ogL;oookJPKoN@3o00?oobL0oiOo0?nG
o`000onGo`0KoookJP;ookl01OoonfX2o`3oXP;o08co1_oonfX00ol0ob7ooo]ZoookJP07oookJP;o
o`3b0_oonfX2o`3oEPKooo]Z00?oo`2PoookJ_oonfX01?oonfX00omD0?oo02GooookJP04oookJP05
o`000?l0C?oo:P3oo`000?oo2P001ooonfX00omko`3ooo]ZoookJP03oookJP03oom10?ooW03ooo]Z
00Cooo]Z00Co0?lhoookJ_oonf[o203o3OoonfX00ooo803ooo]ZoookJP07oookJP03ool0]Ooonf[o
oo]Z01;ooo]Z00?o0?neoookJ_oonfX01_oonfX00ol0oh_ooo]ZoookJP0GoookJP03ool0Cooonf[o
oo]Z00Cooo]Z00?o0?nFoookJ_oonfX01OoonfX01Ooo703ooo]ZoookJ_oonf[o^?l0017ooo]Z00?o
d_l0oookJ_oonfX00_oonfX01?oMo`3ooo]ZoookJ_l[0?l7oookJP04oonK0?oo003ooo]Zonco00Go
oo]Z00?oT`3ooookJ_oonfX01ooonfX00omG0?oookL0oookJP03oookJP03ool0g?oonf[ooo]Z00Ko
oo]Z00?oWOl0oookJ_oonfX00_oonfX00oo]0?oooo]ZoookJP0`oookJP009_oonfX3oiOo0003oook
J_oo9`3oobL000;ooo]Z1Omi0?l=oookJPWoiOl03ooonfX5onGo03Kooo]Z1?l0ogLAonGo0003ogT0
oooonf[oUol000;oUol06_oonfX3oono00Cooo]Z0ol0oj800ol0S?oooo]ZoookJP04oookJP;o0?lQ
2?oonfX01?oo0?;ooo]ZoookJ_oonfX2o`3oEPKooo]Z0_oo0:04oookJP03oe@0ool09Ooo02Go00Co
oo]Z00Co0000oomi0?ooN@3o:P3o0_ooN@07oookJP03og_o0?oonf[ooo]Z00?ooo]Z00?ood40oonL
0?oonfX01?oonfX00ol0ocSooo]Zo`P0o`0>oookJP03oolP0?oonf[ooo]Z00Kooo]Z00?oo`2eoook
J_oonfX03ooonfX7ooo900Kooo]Z00?o0?n;oookJ_oonfX05ooonfX00ooo04oooo]ZoookJP03oook
JP03o`3oU_oonf[ooo]Z00Gooo]Z00?ooa`0oookJ_oonfX00_oonfX00onho`3ooo]ZoookJP0>oook
JP05om;o0?oonf[ooo]ZoookJ_oMo`000ooonfX00ol[0?oooo]ZoookJP05oookJP04ool00?oo0:Wo
oo]Zonco00Gooo]Z00?oT`3ooookJ_oonfX01ooonfX00omG0?oooo]ZoookJP03oookJP03ool0g?oo
nf[ooo]Z00Gooo]Z00?oWOl0oookJ_oonfX00ooonfX00oo]0?oooo]ZoookJP1CoookJP?oUol00ooo
9`000ooonf[oN@3oogT0o`03ogT0o`gooo]Z2Ol0ogM;oookJPCo0?mg3OoonfX4ogT0o`03oolW0?oo
nf[oUol000;oUol06_oonfX3oono00Cooo]Z0ol0oj800ol0S?oooo]ZoookJP03oookJP;o0?lQ2Ooo
nfX01Ooo0?;ooo]ZoookJ_oonf[o0?mF00Kooo]Z0_oo0:05oookJP03oe@0ool09Ooo02Go00?ooo]Z
0_l000000ol0C?oo:P3ooookJP02ool:00Kooo]Z00?oNol0oookJ_oonfX00ooonfX00ooo@@3ooi`0
oookJP04oookJP04o`3o>?oonf[ooo]Zo`P0o`gooo]Z00?oob00oookJ_oonfX01ooonfX00ooo0;Go
oo]ZoookJP0BoookJP03o`3o]Ooonf[ooo]Z00Kooo]Z00?o0?n;oookJ_oonfX05ooonfX00ooo04oo
oo]ZoookJP03oookJP03o`3oU_oonf[ooo]Z00Kooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000Aoook
JP05om;o0?oonf[ooo]ZoookJ_oMo`000ooonfX00ol[0?oooo]ZoookJP05oookJP03ool00?oonf[o
k?l000Gooo]Z00?oT`3ooookJ_oonfX01ooonfX00omG0?oookL0oookJP03oookJP03ool0g?oonf[o
oo]Z00Kooo]Z00?oWOl0oookJ_oonfX00_oonfX00oo]0?oooo]ZoookJP0`oookJP009OoonfX01?nG
o`3ooo]ZoookJ_oo9`05ogT0o`gooo]Z00?o0?mgonGo0?oUo`000_oUo`0HoookJP;oiOl0?OoonfX8
onGo00[ooo]Z0omi0?l01?oo9`3oUol0oiOo0?nGo`0JoookJP;ookl01OoonfX2o`3oXP03o`2<oooo
nf[ooo]Z00Cooo]Z0_l0ob47oookJP;oo`3b0ooonfX00ol0oeKooo]ZoookJP05oookJP03ool0X?oo
nf[ooo]Z00;ooo]Z0_mD0?l01?l09Ooooo]ZoookJ_oonfX4o`000003obX0ooooN@3oogT000Oooo]Z
00?oNol0oookJ_oonfX00ooonfX2oom100Gooo]Z00?o0?lhoookJ_l80?l03_oonfX00ooo803ooo]Z
oookJP05oookJP03ool0]Ooonf[ooo]Z017ooo]Z1_oob@05oookJP03o`3oRooonf[ooo]Z01Oooo]Z
00?oo`1?oookJ_oonfX01?oonfX00ol0oiKooo]ZoookJP05oookJP05oolL0?oonf[ooo]ZoookJ_nh
o`004?oonfX00ooBo`3ooo]ZoookJP02oookJP04omgo0?oonf[ooo]Zob/0o`Oooo]Z00Gooi/0ool0
0?oonf[ooo]Zonco0004oookJP03oi<0oooonf[ooo]Z00Sooo]Z00?oE`3ooookJ_oonfX00ooonfX0
0ooo0=cooo]ZoookJP05oookJP03oigo0?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX0D?oonfX2
oiOo0003oookJ_oo9`3oN@3o00CoN@3o3OoonfX5o`3oMeSooo]Z1?l0ogL=oookJP?oN@3o0_oo9`03
oiOo01Wooo]Z00?o0:;ooono0?oo_`001OoonfX2o`3oXPKooo]Z0_l0ob48oookJP;oo`3b0_oonfX2
o`3oEPKooo]Z00?oo`2PoookJ_oonfX00ooonfX00omD0?oooo]Zo`0Uo`02oookJPCo000000Co:P3o
oookJ_oonf[oo`X01_oonfX00omko`3ooo]ZoookJP03oookJP;ood401OoonfX01?l0ocSooo]Zoook
J_l80?l=oookJP03oolP0?oonf[ooo]Z00Kooo]Z00?oo`2eoookJ_oonfX04ooonfX00ol0okGooo]Z
oookJP05oookJP03o`3oRooonf[ooo]Z01Oooo]Z00?oo`1?oookJ_oonfX01?oonfX00ol0oiKooo]Z
oookJP05oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX03_oonfX00ooBo`3ooo]Z
oookJP02oookJP04omgo0?oonf[ooo]Zob/0o`Oooo]Z00Cooi/0ool00?oonf[ok?l01OoonfX00onC
0?oooo]ZoookJP07oookJP03oeL0oooo]`3ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX01_oonfX00onM
o`3ooo]ZoookJP02oookJP03ond0oooonf[ooo]Z02oooo]Z000VoookJP?oN@3o3ooonfX3o`3oMcCo
oo]Z2_l0odPRoookJPCo0?mg3OoonfX3ogT0o`03onGo0?nGo`3oUol001Wooo]Z00?o0:;ooono0?oo
_`001OoonfX2o`3oXPOooo]Z00?o0?lQoookJ_oonfX01_oonfX2ool0lP;ooo]Z0_l0oeH6oookJP03
ool0X?oonf[ooo]Z00?ooo]Z00CoE03oo`0Uoooonf[ooo]Z1?l000001Ooonf[o:P3ooookJ_ooN@3o
o`X000;ooo]Z00GoolT0oookJ_oonf[ooo]Zog_o0006oookJP03oom10?ooW03ooo]Z00?ooo]Z00?o
0?lho`P0oooonfX03_oonfX00ooo803ooo]ZoookJP05oookJP03ool0]Ooonf[ooo]Z017ooo]Z1Ooo
b@06oookJP03o`3oRooonf[ooo]Z01Oooo]Z00?oo`1?oookJ_oonfX00ooonfX00ol0oiKooo]Zoook
JP05oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX03_oonfX01OoBo`3ooo]Zoook
J_oonf[ogOl000?ooo]Z00?o:`3ooookJ_oonfX01OoonfX01?oo003oo`2YoookJ_o/o`05oookJP03
oi<0oooonf[ooo]Z00Oooo]Z00?ookL0oeL0oooonfX00ooonfX00ooo0=cooo]ZoookJP05oookJP03
oigo0?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX0DOoonfX3ogT0o`oooo]Z0ol0ogLdoookJP[o
0?m88ooonfX4o`3oM`cooo]Z0omi0?l2oolW00;oUol06?oonfX2o`2Ro`;ookl01OoonfX2o`3oXPKo
oo]Z00?o0?lQoookJ_oonfX01ooonfX2ool0lP;ooo]Z0_l0oeH5oookJP;oo`2P1?oonfX2oe@0o`03
o`0Uoooonf[o000000?o000000Cooo]ZobX0oooonf[ooo]Z0_oo2P05oookJP03og_o0?oonf[ooo]Z
00Cooo]Z00?ood40oonL0?oonfX00ooonfX00ol0ocSooo]Zo`P0o`0>oookJP03oolP0?oonf[ooo]Z
00Kooo]Z00?oo`2eoookJ_oonfX04ooonfX00ol0okGooo]ZoookJP05oookJP03o`3oRooonf[ooo]Z
01Oooo]Z00?oo`1?oookJ_oonfX00ooonfX00ol0oiKooo]ZoookJP06oookJP05oolL0?oonf[ooo]Z
oookJ_nho`004OoonfX01OoBo`3ooo]ZoookJ_oonf[ogOl000?ooo]Z00?o:`3ooookJ_oonfX01Ooo
nfX00ooo003ooo]Zonco0005oookJP03oi<0oooonf[ooo]Z00Sooo]Z00?oE`3ooookJ_oonfX00_oo
nfX00ooo0=cooo]ZoookJP06oookJP03oigo0?oonf[ooo]Z00;ooo]Z00?ok@3ooookJ_oonfX0;ooo
nfX002Gooo]Z00?oN@3ooookJ_oonfX03_oonfX2o`3oMbgooo]Z2_l0odP:oookJPSo0?m87_oonfX4
o`3oM`cooo]Z0omi0?l3oiOo01Sooo]Z00Co0:;ooono0?oo_`3ookl01?oonfX2o`3oXPKooo]Z0_l0
ob48oookJP04ool0l_oonf[ooo]ZoookJP;o0?mF1OoonfX2ool0X0Cooo]Z00?oE03oo`0Uool09Ol0
1?l00002oookJP06obX0oooob@3ooo]Zool:0?oonf[oolT01?oonfX2og_o00Gooo]Z00?ood40oonL
0?oonfX00ooonfX00ol0ocSo203ooookJP0>oookJP03oolP0?oonf[ooo]Z00Gooo]Z00?oo`2eoook
J_oonfX04_oonfX4ooo900Kooo]Z00?o0?n;oookJ_oonfX05ooonfX00ooo04oooo]ZoookJP03oook
JP03o`3oU_oonf[ooo]Z00Gooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000AoookJP05om;o0?oonf[o
oo]ZoookJ_oMo`000_oonfX00ol[0?oooo]ZoookJP05oookJP05oonK0?oo003ooo]ZoookJ_o/o`00
1?oonfX00onC0?oooo]ZoookJP08oookJP03oeL0oooonf[ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX0
1OoonfX00onMo`3ooo]ZoookJP03oookJP03ond0oooonf[ooo]Z04oooo]Z00?oN@3ooookJ_oonfX0
3_oonfX2o`3oMbgooo]Z2_l0odP:oookJPSo0?m87ooonfX4o`3oM`_ooo]Z0omi0?l01?oo9`3oUol0
oiOo0?nGo`0GoookJP;o0:;o0ooo_`04oookJP;o0?nR1OoonfX2o`3o8@Wooo]Z00Coo`3boookJ_oo
nf[ooo]Z0_l0oeH5oookJP03ool0X?oonf[ooo]Z00?ooo]Z00?oE03oo`0Uool09Ol00ol00002oook
JP05obX0ool0C?oooo]ZoookJ_oo2P001OoonfX2og_o00Gooo]Z00?ood40oonL0?oonfX00ooonfX0
0ol0ocSooo]Zo`P0o`0>oookJP03oolP0?oonf[ooo]Z00Kooo]Z00?oo`2eoookJ_oonfX04ooonfX0
0ol0okGooo]ZoookJP05oookJP03o`3oRooonf[ooo]Z01Oooo]Z00?oo`1?oookJ_oonfX00ooonfX0
0ol0oiKooo]ZoookJP05oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX03ooonfX0
1OoBo`3ooo]ZoookJ_oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX01OoonfX01?ooV`3oo`00oook
J_o/o`05oookJP03oi<0oooonf[ooo]Z00Oooo]Z00?oE`3ooong0?oonfX00ooonfX00ooo0=cooo]Z
oookJP06oookJP03oigo0?oonf[ooo]Z00;ooo]Z00?ok@3ooookJ_oonfX0;_oonfX003?ooo]Z0ol0
ogLToookJP_o0?m87?oonfX8o`3oB1[ooo]Z1?l0ogL;oookJP;oN@3o00?oiOl0oiOo0?nGo`006?oo
nfX2o`2Ro`;ookl01?oonfX2o`3oXPKooo]Z0_l0ob47oookJP;oo`3b0ooonfX2o`3oEPGooo]Z00?o
o`2PoookJ_oonfX00_oonfX2oe@0o`04o`0Uool0003o0000o`0000?ooo]Z0_lZ0?l01?oonf[oo`X0
ooo90?oob@05oookJP03og_o0?oonf[ooo]Z00?ooo]Z00?ood40oonL0?oonfX00ooonfX00ol0ocSo
203ooookJP0>oookJP03oolP0?oonf[ooo]Z00Gooo]Z00?oo`2eoookJ_oonfX04_oonfX3ooo900Oo
oo]Z00?o0?n;oookJ_oonfX05ooonfX00ooo04oooo]ZoookJP03oookJP03o`3oU_oonf[ooo]Z00Go
oo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000@oookJP03om;o0?oonf[ooo]Z00;ooo]Z00CogOl0oook
J_oonf[o:`3o1ooonfX01Ooo003oo`2YoookJ_oonf[ok?l000Cooo]Z00?oT`3ooookJ_oonfX01ooo
nfX00ooo]`3oE`3ooookJP03oookJP03ool0g?oonf[ooo]Z00Kooo]Z00?oWOl0oookJ_oonfX00_oo
nfX00oo]0?oooo]ZoookJP1MoookJP?o0?mg9?oonfX;o`3oB1cooo]Z2Ol0odPJoookJP?o0?mg2ooo
nfX2ogT0o`04oookJ_oo9`3oUol0oiOo01Oooo]Z0_l0X_l00ooonf[ookl0oono0004oookJP;o0?nR
1OoonfX2o`3o8@Sooo]Z0_oo0?83oookJP;o0?mF1?oonfX2ool0X0Cooo]Z00?oE03oo`000?l09Ol0
0_l00003oookJP;o:P3o0_oonfX00ooo2P3ooo]ZoookJP04oookJP03og_o0?oonf[ooo]Z00?ooo]Z
00?ood40oonL0?oonfX00ooonfX00ol0ocSooo]Zo`P0o`0>oookJP03oolP0?oonf[ooo]Z00Kooo]Z
00?oo`2eoookJ_oonfX04ooonfX00ol0okGooo]ZoookJP05oookJP03o`3oRooonf[ooo]Z01Oooo]Z
00?oo`1?oookJ_oonfX00ooonfX00ol0oiKooo]ZoookJP05oookJP03oolL0?oonf[ooo]Z00;ooo]Z
00?o^?l0oookJ_oonfX03_oonfX01OoBo`3ooo]ZoookJ_oonf[ogOl000?ooo]Z00?o:`3ooookJ_oo
nfX01OoonfX01?oo003ooo]ZoookJ_o/o`04oookJP03oi<0oooonf[ooo]Z00Sooo]Z00?oE`3ooook
J_oonfX00_oonfX00ooo0=cooo]ZoookJP07oookJP05oigo0?oonf[ooo]ZoookJ_o]0?l0<?oonfX0
033ooo]Z0ol0ogLMoookJP[o0?m8;ooonfX8o`3oB1Kooo]Z1?l0ogL9oookJP?oN@3o0onGo`0Goook
JP;o0:;o0_oo_`04oookJP;o0?nR1_oonfX2o`3o8@Oooo]Z00?oo`3boookJ_oonfX00_oonfX00ol0
oeKooo]ZoookJP03oookJP;oo`2P1?oonfX01?mD0?oo02Goo`0Uool00005oookJP03obX0oooob@3o
o`X000;oolT01OoonfX00omko`3ooo]ZoookJP03oookJP03oom10?ooW03ooo]Z00?ooo]Z00?o0?lh
o`P0oooonfX03_oonfX00ooo803ooo]ZoookJP05oookJP03ool0]Ooonf[ooo]Z01;ooo]Z0ooob@07
oookJP03o`3oRooonf[ooo]Z01Kooo]Z00?oo`1?oookJ_oonfX00ooonfX00ol0oiKooo]ZoookJP05
oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX03_oonfX01OoBo`3ooo]ZoookJ_oo
nf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX01OoonfX01OooV`3oo`00oookJ_oonf[ok?l000Cooo]Z
00?oT`3ooookJ_oonfX02?oonfX00omG0?oooo]ZoookJP03oookJP03ool0g?oonf[ooo]Z00Gooo]Z
00?oWOl0ooo90?oonfX00ooonfX00oo]0?oooo]ZoookJP1IoookJP?o0?mg7OoonfX:o`3oB33ooo]Z
2?l0odPEoookJPCo0?mg2OoonfX3ogT0o`04oolW0?nGo`3oUol0oiOo01Kooo]Z0_l0X_l00ooonf[o
okl0oono0003oookJP03o`2<ool0oj;o0?nR00Gooo]Z0_l0ob48oookJP03ool0l_oonf[ooo]Z00;o
oo]Z00?o0?mFoookJ_oonfX00ooonfX00ooo0:3ooo]ZoookJP02oookJP;oE03o0_l09Ol5oookJP04
obX0oooonf[ooo]Zool:00Kooo]Z00?oNol0oookJ_oonfX00ooonfX00ooo@@3ooi`0oookJP03oook
JP03o`3o>?oonf[o203o00kooo]Z00?oob00oookJ_oonfX01_oonfX00ooo0;Gooo]ZoookJP0Coook
JP03o`3o]Ooonf[ooo]Z00Gooo]Z00?o0?n;oookJ_oonfX05_oonfX00ooo04oooo]ZoookJP03oook
JP03o`3oU_oonf[ooo]Z00Kooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000AoookJP05om;o0?oonf[o
oo]ZoookJ_oMo`000_oonfX00ol[0?oooo]ZoookJP05oookJP04oonK0?oo003ooo]Zonco00Gooo]Z
00?oT`3ooookJ_oonfX01ooonfX00omG0?oooo]ZoookJP03oookJP03ool0g?oonf[ooo]Z00Kooo]Z
00?oWOl0oookJ_oonfX00_oonfX00oo]0?oooo]ZoookJP0]oookJP00;_oonfX2o`3oMaWooo]Z1ol0
odQ1oookJPSo0?m84_oonfX4o`3oM`Sooo]Z0omi0?l2oiOo01Oooo]Z0_l0X_l00ooo_`3ooo]Zoook
JP02oookJP03o`2<ool0oj;o0?nR00Kooo]Z00?o0?lQoookJ_oonfX01OoonfX2ool0lP?ooo]Z00?o
0?mFoookJ_oonfX01?oonfX02Ooo0:3ooo]ZoookJ_oonf[o0000oe@0ool0003o02Goo`000004oook
JP04ooo90?lZ0?ooolT0ool:00;oolT01OoonfX00omko`3ooo]ZoookJP03oookJP03oom10?oonf[o
oo]Z00?ooo]Z00?o0?lho`P0oooonfX03_oonfX00ooo803ooo]ZoookJP05oookJP03ool0]Ooonf[o
oo]Z01?ooo]Z00?oolT0oookJ_oonfX01_oonfX00ol0oh_ooo]ZoookJP0FoookJP03ool0Cooonf[o
oo]Z00?ooo]Z00?o0?nFoookJ_oonfX01OoonfX01Ooo703ooo]ZoookJ_oonf[o^?l0017ooo]Z00Go
d_l0oookJ_oonf[ooo]Zomgo0002oookJP03ob/0oooonf[ooo]Z00Gooo]Z00Goo`00ool0ZOoonf[o
oo]Zonco0004oookJP03oi<0oooonf[ooo]Z00Oooo]Z00?ookL0oeL0oooonfX00ooonfX00ooo0=co
oo]ZoookJP06oookJP03ooo90?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX0E_oonfX2o`3oMaWo
oo]Z1ol0odQ2oookJPSo0?m84OoonfX4o`3oM`Sooo]Z0omi0?l00ooo9`3oUol0oiOo000FoookJP;o
0:;o00?ooo]Zoono0?oonfX00ooonfX00ol0S?oo0?nRo`3oXP05oookJP03o`3o8Ooonf[ooo]Z00Ko
oo]Z0_oo0?83oookJP03o`3oE_oonf[ooo]Z00?ooo]Z0_oo0:02oookJP;o000000?oE03oo`000?l0
9Ol01OoonfX01?lZ0?oo04cooookJ_oo2P06oookJP03og_o0?oonf[ooo]Z00?ooo]Z00?ood40oook
J_oonfX00ooonfX00ol0ocSooo]Zo`P0o`0>oookJP03oolP0?oonf[ooo]Z00Kooo]Z00?oo`2eoook
J_oonfX04ooonfX00ol0okGooo]ZoookJP05oookJP03o`3oRooonf[ooo]Z01Kooo]Z00?oo`1?oook
J_oonfX00ooonfX00ol0oiKooo]ZoookJP05oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oook
J_oonfX03ooonfX01?oBo`3ooo]ZoookJ_oMo`03oookJP03ob/0oooonf[ooo]Z00Gooo]Z00Coo`00
ool0ZOoonf[ok?l01OoonfX00onC0?oooo]ZoookJP07oookJP03oeL0oooonf[ooo]Z00;ooo]Z00?o
o`3LoookJ_oonfX01ooonfX00onMo`3ooo]ZoookJP02oookJP03ond0oooonf[ooo]Z02cooo]Z000[
oookJP?o0?mg6?oonfX3o`3oB53ooo]Z1_l0odP@oookJPCo0?mg1ooonfX2ogT0o`?oUol05_oonfX0
0ol0X_oookl0oono0004oookJP03o`2<ool0oj;o0?nR00Gooo]Z0_l0ob47oookJP;oo`3b0_oonfX2
o`3oEPGooo]Z00?oo`2PoookJ_oonfX00_l00002oe@0o`04o`0Uoooonf[ooo]ZoookJP?oolT000?o
:P3oooo90?oo2P000_oob@05oookJP;oNol01?oonfX2oom100Cooo]Z00?o0?lho`P0oooonfX03_oo
nfX00ooo803ooo]ZoookJP05oookJP03ool0]Ooonf[ooo]Z01?ooo]Z00?oolT0oookJ_oonfX01_oo
nfX00ol0oh_ooo]ZoookJP0FoookJP03ool0Cooonf[ooo]Z00;ooo]Z00?o0?nFoookJ_oonfX01_oo
nfX01Ooo703ooo]ZoookJ_oonf[o^?l0013ooo]Z00God_l0oookJ_oonf[ooo]Zomgo0002oookJP03
ob/0oooonf[ooo]Z00Gooo]Z00Gooi/0ool00?oo0:Wooo]Zonco0005oookJP03oi<0oooonf[ooo]Z
00Oooo]Z00?oE`3ooookJ_oonfX00ooonfX00ooo0=cooo]ZoookJP05oookJP03ooo90?oonf[ooo]Z
00?ooo]Z00?ok@3ooookJ_oonfX0DooonfX3o`3oMaSooo]Z0ol0odQAoookJPKo0?m83ooonfX4o`3o
M`Oooo]Z0_mi0?l01?oo9`3oUol0oiOo0?nGo`0EoookJP;o0:;o0_oo_`04oookJP03o`2<ool0oj;o
0?nR00Cooo]Z0_l0ob48oookJP;oo`3b0_oonfX2o`3oEPGooo]Z00?oo`2PoookJ_l000000_l00000
0omD0?oooo]Zo`0Uo`05oookJP04obX0ool0C?oooo]Zool:00Kooo]Z0_mko`04oookJP;ood401?oo
nfX00ol0ocSooo]Zo`P0o`0>oookJP03oolP0?oonf[ooo]Z00Gooo]Z00?oo`2eoookJ_oonfX05?oo
nfX00ol0okGooo]ZoookJP05oookJP03o`3oRooonf[ooo]Z01Kooo]Z00?oo`1?oookJ_oonfX00_oo
nfX00ol0oiKooo]ZoookJP06oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX03_oo
nfX01OoBo`3ooo]ZoookJ_oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX01OoonfX01?ooV`3oo`00
oookJ_o/o`05oookJP03oi<0oooonf[ooo]Z00Oooo]Z00?oE`3ooookJ_oonfX00ooonfX00ooo0=co
oo]ZoookJP06oookJP03oigo0?oonf[ooo]Z00;ooo]Z00?ok@3ooookJ_oonfX0;?oonfX002Wooo]Z
0_l0ogLHoookJP?o0?m8:ooonfX;o`03ob?ooo]Z0ol0odPAoookJPCo0?mg1OoonfX3ogT0o`?oUol0
1_oonfX2onGo00gooo]Z00?o0:;ooono0?oo_`001?oonfX00ol0S?oo0?nRo`3oXP05oookJP;o0?lQ
1ooonfX01Ooo0?;ooo]ZoookJ_oonf[o0?mF00Gooo]Z0_oo0:04o`000003oe@0ool09Ooo02Go00Go
olT000?o:P3oooo90?oo2P000_oob@06oookJP03og_o0?oonf[ooo]Z00;ooo]Z00?ooi`0oom10?oo
nfX00ooonfX00ol0ocSo203ooookJP0=oookJP03oolP0?oonf[ooo]Z00Gooo]Z00?oo`2eoookJ_oo
nfX04ooonfX00ol0okGooo]ZoookJP07oookJP03o`3oRooonf[ooo]Z01Gooo]Z00?oo`1?oookJ_oo
nfX00ooonfX00ol0oiKooo]ZoookJP05oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oo
nfX03_oonfX01OoBo`3ooo]ZoookJ_oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX01OoonfX01Ooo
003oo`2YoookJ_oonf[ok?l000Cooo]Z00?oT`3ooookJ_oonfX01ooonfX00ooo]`3oE`3ooookJP03
oookJP03ool0g?oonf[ooo]Z00Kooo]Z00?oolT0oookJ_oonfX00ooonfX00oo]0?oooo]ZoookJP1@
oookJP;o0?mg6?oonfX3o`3oB2cooo]Z2ol00olSoookJP?o0?m84?oonfX4o`3oM`Gooo]Z0omi0?l0
1?oo9`3oUol0oiOo0?nGo`0DoookJP;o0:;o0_oo_`03oookJP;o08co0_l0oj84oookJP;o0?lQ2?oo
nfX01Ooo0?;ooo]ZoookJ_oonf[o0?mF00Gooo]Z0_oo0:03o`000004oe@0oooonf[o02Goo`0Uo`Co
oo]Z00Co:P3oo`1<ool0C?ooo`X01ooonfX00omko`3ooo]ZoookJP02oookJP03oonL0?oo@@3ooo]Z
00?ooo]Z00?o0?lhoookJ_l80?l03_oonfX00ooo803ooo]ZoookJP05oookJP03ool0]Ooonf[ooo]Z
01?ooo]Z00?o0?neoookJ_oonfX01_oonfX00ol0oh_ooo]ZoookJP0EoookJP03ool0Cooonf[ooo]Z
00?ooo]Z00?o0?nFoookJ_oonfX01_oonfX01Ooo703ooo]ZoookJ_oonf[o^?l0017ooo]Z00Cod_l0
oookJ_oonf[ogOl00ooonfX00ol[0?oooo]ZoookJP05oookJP04ool00?oo0:Wooo]Zonco00Gooo]Z
00?oT`3ooookJ_oonfX01ooonfX00omG0?oooo]ZoookJP02oookJP03ool0g?oonf[ooo]Z00Oooo]Z
00?oWOl0oookJ_oonfX00_oonfX00oo]0?oooo]ZoookJP0[oookJP009_oonfX3o`3oMaOooo]Z0ol0
odPToookJP[o00?o2ooonfX:o`03oacooo]Z1?l0odPAoookJP?o0?mg1OoonfX3ogT0o`;oUol01?oo
nfX3onGo00kooo]Z00?o0:;ooono0?oonfX00ooonfX2o`2<o`;o0?nR1OoonfX2o`3o8@Kooo]Z0_oo
0?82oookJP03o`3oE_oonf[ooo]Z00Cooo]Z00Woo`2Po`000?l0003o0000oookJ_mD0?oooo]Zo`0U
oooonfX01?oob@001?lZ0?ooolT0ool:0?oob@07oookJP03og_o0?oonf[ooo]Z00;ooo]Z00?ooi`0
oom10?oonfX00ooonfX00ol0ocSo203ooookJP0=oookJP03oolP0?oonf[ooo]Z00Gooo]Z00?oo`2e
oookJ_oonfX04ooonfX00ol0okGooo]ZoookJP06oookJP03o`3oRooonf[ooo]Z01Kooo]Z00?oo`1?
oookJ_oonfX00ooonfX00ol0oiKooo]ZoookJP05oookJP05oolL0?oonf[ooo]ZoookJ_nho`004?oo
nfX01OoBo`3ooo]ZoookJ_oonf[ogOl000?ooo]Z00?o:`3ooookJ_oonfX01?oonfX01OooV`3oo`00
ool0ZOoonf[ok?l000Gooo]Z00?oT`3ooookJ_oonfX01ooonfX00omG0?oooo]ZoookJP03oookJP03
ool0g?oonf[ooo]Z00Gooo]Z00?oolT0oookJ_oonfX00ooonfX00oo]0?oooo]ZoookJP1=oookJP?o
0?mg5ooonfX3o`3oB2Gooo]Z2_l00ol;oookJP[o00?o7?oonfX3o`3oB17ooo]Z0ol0ogL5oookJP?o
N@3o00?oobL0oiOo0?nGo`005?oonfX2o`2Ro`03oono0?oonf[ooo]Z00;ooo]Z0_l0S?l2o`3oXPCo
oo]Z0_l0ob47oookJP;oo`3b0_oonfX00ol0oeKooo]ZoookJP03oookJP05o`000?oo0:3o0000o`00
0?oonfX00_mD0?l00ooonf[o02GooookJP03oookJP04obX0oooonf[o04coool:00Oooo]Z00?oNol0
oookJ_oonfX00_oonfX00oooW03ood40oookJP03oookJP03o`3o>?oonf[o203o00kooo]Z00?oob00
oookJ_oonfX01OoonfX00ooo0;Gooo]ZoookJP0CoookJP03o`3o]Ooonf[ooo]Z00Gooo]Z00?o0?n;
oookJ_oonfX05_oonfX00ooo04oooo]ZoookJP03oookJP03o`3oU_oonf[ooo]Z00Gooo]Z00?ooa`0
oookJ_oonfX00_oonfX00onho`3ooo]ZoookJP0>oookJP05om;o0?oonf[ooo]ZoookJ_oMo`000_oo
nfX00ol[0?oooo]ZoookJP05oookJP04oonK0?oo003ooo]Zonco00Gooo]Z00?oT`3ooookJ_oonfX0
1ooonfX00omG0?oooo]ZoookJP03oookJP03ool0g?oonf[ooo]Z00Kooo]Z00?oWOl0oookJ_oonfX0
0_oonfX00oo]0?oooo]ZoookJP0[oookJP009OoonfX00ol0ogOooo]ZoookJP0EoookJP?o0?m87_oo
nfX9o`03o`[ooo]Z2ooo0?H:oookJPWo00?o5ooonfX3o`3oB17ooo]Z0_l0ogL6oookJP?oN@3o0_nG
o`06onGo00kooo]Z0_oo_`04oookJP;o08co0_oUo`05oookJP03o`3o8Ooonf[ooo]Z00Gooo]Z0_oo
0?800ooonf[o0?mFo`3oEP04oookJP04o`000?oo0:3oo`2Po`0000;ooo]Z00?oE03ooookJ_l09Ol0
0ooonfX2ooo900;o:P3o00?oo`X0ooo90?oonfX01_oonfX00omko`3ooo]ZoookJP02oookJP03oonL
0?oo@@3ooo]Z00?ooo]Z00?o0?lho`P0oooonfX03OoonfX00ooo803ooo]ZoookJP05oookJP03ool0
]Ooonf[ooo]Z01?ooo]Z00?o0?neoookJ_oonfX01_oonfX00ol0oh_ooo]ZoookJP0FoookJP03ool0
Cooonf[ooo]Z00;ooo]Z00?o0?nFoookJ_oonfX01OoonfX00ooo703ooo]ZoookJP02oookJP03okSo
0?oonf[ooo]Z00kooo]Z00God_l0oookJ_oonf[ooo]Zomgo0002oookJP03ob/0oooonf[ooo]Z00Co
oo]Z00Gooi/0ool00?oo0:Wooo]Zonco0005oookJP03oi<0oooonf[ooo]Z00Oooo]Z00?ookL0oeL0
oooonfX00ooonfX00ooo0=cooo]ZoookJP05oookJP03ooo90?oonf[ooo]Z00Cooo]Z00?ok@3ooook
J_oonfX0BooonfX00ol0ogOooo]ZoookJP0EoookJP?o0?m87_oonfX:o`03o`Wooo]Z2ooo0?H;oook
JPWo00?o5_oonfX4o`3oB13ooo]Z0_l0ogL6oookJP?oN@3o0onGo`0CoookJP03o`2Roooo_`3ookl0
00Cooo]Z00Co08cooookJ_l0oj;o0?nR1?oonfX00ol0ob7ooo]ZoookJP06oookJP;oo`3b00?ooo]Z
o`3oE_l0oeH00ooonfX2o`0000;oo`2P0ooonfX00omD0?oooo]Zo`0Uo`04oookJP;o:P3o00?o04co
ool:0?oonfX01_oonfX00omko`3ooo]ZoookJP02oookJP03oonL0?oo@@3ooo]Z00?ooo]Z00?o0?lh
oookJ_l80?l03_oonfX00ooo803ooo]ZoookJP05oookJP03ool0]Ooonf[ooo]Z01?ooo]Z00?o0?ne
oookJ_oonfX01OoonfX00ol0oh_ooo]ZoookJP0FoookJP03ool0Cooonf[ooo]Z00;ooo]Z00?o0?nF
oookJ_oonfX01_oonfX00ooo703ooo]ZoookJP02oookJP03okSo0?oonf[ooo]Z00kooo]Z00Cod_l0
oookJ_oonf[ogOl00ooonfX00ol[0?oooo]ZoookJP04oookJP05oonK0?oo003oo`2YoookJ_o/o`00
1OoonfX00onC0?oooo]ZoookJP07oookJP03oeL0oooonf[ooo]Z00;ooo]Z00?oo`3LoookJ_oonfX0
1_oonfX00onMo`3ooo]ZoookJP03oookJP03ond0oooonf[ooo]Z02[ooo]Z000joookJP?o0?m85ooo
nfX:o`03o`Wooo]Z2_oo0?H;oookJP[oo`3f2OoonfX:o`03oa3ooo]Z1?l0odP?oookJP?o0?mg1_oo
nfX2ogT0o`;oUol01OoUo`0?oookJP;ookl01?oonfX00ol0S?oooo]ZonGo0005oookJP;o0?lQ1ooo
nfX01?oo0?;ooo]ZoookJ_l0oeH3oookJP?o000000Coo`2PoookJ_oonf[ooo]Z0_mD0?l2o`0Uo`?o
oo]Z0_oob@000olZ0?ooo`X0ooo90007oookJP03og_o0?oonf[ooo]Z00;ooo]Z00?ooi`0oom10?oo
nfX00ooonfX00ol0ocSo203ooookJP0=oookJP03oolP0?oonf[ooo]Z00Gooo]Z00?oo`2eoookJ_oo
nfX04_oonfX00ol0okGooo]ZoookJP07oookJP03o`3oRooonf[ooo]Z01Gooo]Z00?oo`1?oookJ_oo
nfX00ooonfX00ol0oiKooo]ZoookJP05oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oo
nfX03_oonfX01?oBo`3ooo]ZoookJ_oMo`03oookJP03ob/0oooonf[ooo]Z00Cooo]Z00Goo`00oook
J_oo0:Wooo]Zonco0005oookJP03oi<0oooonf[ooo]Z00Oooo]Z00?oE`3ooookJ_oonfX00ooonfX0
0ooo0=cooo]ZoookJP05oookJP03ooo90?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX0H?oonfX3
o`3oB1Oooo]Z2_l00ol9oookJP[oo`3f2ooonfX:ool0mP[ooo]Z2_l00ol@oookJP?o0?m83ooonfX3
o`3oM`Kooo]Z0_mi0?l00ooo9`3oUol0oiOo000CoookJP03o`2Roooo_`3ookl000?ooo]Z0_l0S?l0
0ooonf[o0?nRoookJP03oookJP;o0?lQ2?oonfX01?oo0?;ooo]ZoookJ_l0oeH2oookJPCo000000Ko
o`2PoookJ_oonf[ooo]Zoe@0oooonfX2o`0Uo`Cooo]Z00?o:P3oo`1<oooo2P001ooonfX00omko`3o
oo]ZoookJP02oookJP03oonL0?oo@@3ooo]Z00?ooo]Z00?o0?lhoookJ_l80?l03_oonfX00ooo803o
oo]ZoookJP05oookJP03ool0]Ooonf[ooo]Z01;ooo]Z00?o0?neoookJ_oonfX01_oonfX00ol0oh_o
oo]ZoookJP0EoookJP03ool0Cooonf[ooo]Z00?ooo]Z00?o0?nFoookJ_oonfX01_oonfX01Ooo703o
oo]ZoookJ_oonf[o^?l0017ooo]Z00Cod_l0oookJ_oonf[ogOl00_oonfX00ol[0?oooo]ZoookJP05
oookJP04ool00?oo0:Wooo]Zonco00Gooo]Z00?oT`3ooookJ_oonfX01ooonfX00omG0?oooo]Zoook
JP03oookJP03ool0g?oonf[ooo]Z00Kooo]Z00?oWOl0oookJ_oonfX00_oonfX00oo]0?oooo]Zoook
JP0ZoookJP00=_oonfX4o`3oB0gooo]Z2OoUo`04o`03o`Wooo]Z2_oo0?HOoookJPWoo`3f2_oonfX7
o`03o`gooo]Z0ol0odP?oookJP;o0?mg1OoonfX01?oUo`3oN@3oogT0oomi0?l2oiOo00CoiOl03_oo
nfX00ol0X_oookl0oono0003oookJP;o08co0_oUo`05oookJP;o0?lQ1_oonfX2ool0lP04oookJ_l0
oeKooo]ZoookJPCo00000_oo0:03oookJP03oe@0oooonf[o02Go00Cooo]Z00CoolT0obX0oooo2P3o
o`X01ooonfX2og_o00?ooo]Z00?ooi`0oom10?oonfX00ooonfX00ol0ocSo203ooookJP0=oookJP03
oolP0?oonf[ooo]Z00Gooo]Z00?oo`2eoookJ_oonfX04_oonfX00ol0okGooo]ZoookJP06oookJP03
o`3oRooonf[ooo]Z01Kooo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP06oookJP05
oolL0?oonf[ooo]ZoookJ_nho`004?oonfX01OoBo`3ooo]ZoookJ_oonf[ogOl000;ooo]Z00?o:`3o
oookJ_oonfX01?oonfX01OooV`3oo`00ool0ZOoonf[ok?l000Gooo]Z00?oT`3ooookJ_oonfX01ooo
nfX00ooo]`3oE`3ooookJP03oookJP03ool0g?oonf[ooo]Z00Gooo]Z00?oolT0oookJ_oonfX00ooo
nfX00oo]0?oooo]ZoookJP1LoookJPCo0?m85?oonfX6o`03o`[ooo]Z2Ooo0?HOoookJPWoo`3f2ooo
nfX7o`03o`cooo]Z1?l0odP>oookJP;o0?mg1_oonfX3ogT0o`?oUol04OoonfX2o`2Ro`;ookl00ooo
nfX01?l0S?oooo]Zo`3oX_l0oj84oookJP;o0?lQ1ooonfX2ool0lP03oookJ_l0oeKooo]Z00Co0000
00?ooo]Zool0X?oonfX00_oonfX2oe@0o`03oookJ_l09Ooooo]Z00?ooo]Z00Co:P3ooookJ_oo2P3o
o`X01_oonfX2og_o00?ooo]Z00?ooi`0oom10?oonfX00ooonfX00ol0ocSooo]Zo`P0o`0>oookJP03
oolP0?oonf[ooo]Z00Cooo]Z00?oo`2eoookJ_oonfX04ooonfX00ol0okGooo]ZoookJP05oookJP03
o`3oRooonf[ooo]Z01Kooo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP06oookJP03
oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX03_oonfX01?oBo`3ooo]ZoookJ_oMo`03oook
JP03ob/0oooonf[ooo]Z00Cooo]Z00Cooi/0ool00?oo0:Wok?l01_oonfX00onC0?oooo]ZoookJP07
oookJP03oeL0oooonf[ooo]Z00;ooo]Z00?oo`3LoookJ_oonfX01_oonfX00onMo`3ooo]ZoookJP02
oookJP03ond0oooonf[ooo]Z02[ooo]Z000coookJP?o0?m82OoonfX?onGo00Gooo]Z2_oo0?Hboook
JP[oo`3f1ooonfX3o`03o`gooo]Z0ol0odP>oookJP;o0?mg0ooonfX4onGo00?oN@3o00CoUol0onGo
0?oUo`3oiOl03ooonfX00ol0X_oookl0oookJP03oookJP;o08co00?oiOl0oookJ_oonfX01?oonfX0
0ol0ob7ooo]ZoookJP05oookJP04ool0l_oonf[o0?mFo`3oEPCo00000_oonfX01ooo0:3ooo]Zoook
J_oonf[oE03ooookJ_l09Ol01OoonfX00olZ0?ooolT0ool:0008oookJP05og_o0?oonf[ooo]Zoook
J_oo@@001OoonfX00ol0ocSo203ooookJP0=oookJP03oolP0?oonf[ooo]Z00Gooo]Z00?oo`2eoook
J_oonfX04_oonfX00ol0okGooo]ZoookJP06oookJP03o`3oRooonf[ooo]Z01Kooo]Z00?oo`1?oook
J_oonfX00_oonfX00ol0oiKooo]ZoookJP05oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oook
J_oonfX03_oonfX01?oBo`3ooo]ZoookJ_oMo`03oookJP03ob/0oooonf[ooo]Z00Cooo]Z00Goo`00
oookJ_oo0:Wooo]Zonco0005oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?ookL0oeL0oooonfX01?oo
nfX00ooo0=cooo]ZoookJP05oookJP03ooo90?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX0F?oo
nfX3o`3oB1Gooo]Z0ol00ol6oookJP[oo`3f<OoonfX:ool0mPSooo]Z0ol00ol=oookJP?o0?m83Ooo
nfX2o`3oM`Oooo]Z0omi0?l2oiOo017ooo]Z0_l0X_l01?oo_`3ooo]ZoookJ_oonfX2o`2<o`03oook
J_l0oj;ooo]Z00Cooo]Z00?o0?lQoookJ_oonfX01_oonfX00ooo0?;ooo]Zo`3oEP04o`0000;ooo]Z
0_oo0:03oookJP03oe@0oooonf[o02Go00Cooo]Z00Co:P3ooookJ_l0C?ooo`X01ooonfX01Omko`3o
oo]ZoookJ_oonf[ood4000Gooo]Z00?o0?lhoookJ_l80?l03_oonfX00ooo803ooo]ZoookJP04oook
JP03ool0]Ooonf[ooo]Z01?ooo]Z00?o0?neoookJ_oonfX01OoonfX00ol0oh_ooo]ZoookJP0Foook
JP03ool0Cooonf[ooo]Z00;ooo]Z00?o0?nFoookJ_oonfX01_oonfX00ooo703ooo]ZoookJP02oook
JP03okSo0?oonf[ooo]Z00kooo]Z00Cod_l0oookJ_oonf[ogOl00_oonfX00ol[0?oooo]ZoookJP05
oookJP04ool00?oo0:Wooo]Zonco00Gooo]Z00?oT`3ooookJ_oonfX01ooonfX00omG0?oooo]Zoook
JP03oookJP03ool0g?oonf[ooo]Z00Kooo]Z00?oWOl0oookJ_oonfX00_oonfX00oo]0?oooo]Zoook
JP0YoookJP00<?oonfX3o`3oB0cooo]Z4?oUo`04ool0mQOooo]Z1Ooob@0ZoookJPOoo`3f0ooonfX3
o`03o`gooo]Z1?l0odP<oookJP;o0?mg00?ooo]ZonGo0?oUo`001OoUo`02ogT0o`;oUol000?oiOl0
oookJ_oonfX03_oonfX2oono00Cooo]Z00?o08coonGo0?oonfX01OoonfX2o`3o8@Kooo]Z00Coo`3b
oookJ_oonf[o0?mF0ol00003oookJP04ool0X?oonf[ooo]ZoookJP;oE03o0_l09Ol4oookJP03obX0
oooonf[oo`X000Sooo]Z00GoNol0oookJ_oonf[ooo]Zoom10005oookJP03o`3o>?l80?oooo]Z00go
oo]Z00?oob00oookJ_oonfX01?oonfX00ooo0;Gooo]ZoookJP0CoookJP03o`3o]Ooonf[ooo]Z00Ko
oo]Z00?o0?n;oookJ_oonfX05_oonfX00ooo04oooo]ZoookJP02oookJP03o`3oU_oonf[ooo]Z00Go
oo]Z00?ooa`0oookJ_oonfX00_oonfX00onho`3ooo]ZoookJP0=oookJP05om;o0?oonf[ooo]Zoook
J_oMo`000_oonfX00ol[0?oooo]ZoookJP04oookJP05oonK0?oo003oo`2YoookJ_o/o`001OoonfX0
0onC0?oooo]ZoookJP07oookJP03oong0?mG0?oooo]Z00?ooo]Z00?oo`3LoookJ_oonfX01OoonfX0
0ooob@3ooo]ZoookJP03oookJP03ond0oooonf[ooo]Z05Gooo]Z0ol0odPEoookJP?o00?o0ooonfX6
ool0mTGooo]Z1ooo0?H4oookJP?o00?o3OoonfX3o`3oB0cooo]Z0_l0ogL8oookJP;oN@3o0onGo`0@
oookJP03o`2Roooo_`3ookl000?ooo]Z0_l0S?l00ol0oj;ooo]ZoookJP03oookJP;o0?lQ1ooonfX0
1?oo0?;ooo]Zo`3oE_l0oeH2o`0000Cooo]Z00Koo`2PoookJ_oonf[ooo]Zoe@0oooonfX2o`0Uo`?o
oo]Z00Co:P3ooookJ_l0C?ooo`X01ooonfX01Omko`3ooo]ZoookJ_oonf[ood4000Gooo]Z00?o0?lh
oookJ_l80?l03_oonfX00ooo803ooo]ZoookJP04oookJP03ool0]Ooonf[ooo]Z01?ooo]Z00?o0?ne
oookJ_oonfX01OoonfX00ol0oh_ooo]ZoookJP0FoookJP03ool0Cooonf[ooo]Z00;ooo]Z00?o0?nF
oookJ_oonfX01OoonfX00ooo703ooo]ZoookJP02oookJP03okSo0?oonf[ooo]Z00kooo]Z00Cod_l0
oookJ_oonf[ogOl00ooonfX00ol[0?oooo]ZoookJP04oookJP04oonK0?oo003oo`2Yonco00Kooo]Z
00?oT`3ooookJ_oonfX01ooonfX00omG0?oooo]ZoookJP02oookJP03ool0g?oonf[ooo]Z00Kooo]Z
00?oWOl0oookJ_oonfX00_oonfX00oo]0?oooo]ZoookJP0YoookJP00;OoonfX3o`3oB0oooo]Z3_oU
o`0MoookJPcoolT0:_oonfX3ool0mP?ooo]Z1?l00ol=oookJP?o0?m82ooonfX3o`3oM`OoiOl00_mi
0?l2oiOo0003onGo0?oonf[ooo]Z00kooo]Z0_oo_`03oookJP03o`2<oooUo`3oiOl000Kooo]Z0_l0
ob45oookJP04ool0l_oonf[o0000o`3oEP;o00001?oonfX2ool0X0?ooo]Z00?oE03ooookJ_l09Ol0
1?oonfX00olZ0?oooo]Zool:0008oookJP05og_o0?oonf[ooo]ZoookJ_oo@@001OoonfX00ol0ocSo
203ooookJP0=oookJP03oolP0?oonf[ooo]Z00Cooo]Z00?oo`2eoookJ_oonfX04_oonfX00ol0okGo
oo]ZoookJP06oookJP03o`3oRooonf[ooo]Z01Kooo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKo
oo]ZoookJP05oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX03_oonfX01?oBo`3o
oo]ZoookJ_oMo`03oookJP03ob/0oooonf[ooo]Z00Cooo]Z00Goo`00oookJ_oo0:Wooo]Zonco0005
oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?ookL0oeL0oooonfX01?oonfX00ooo0=cooo]ZoookJP04
oookJP03ooo90?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX0D_oonfX3o`3oB1Gooo]Z0ol00ol3
oookJP?oo`3fD_oonfX3ool0mPCooo]Z0ol00ol=oookJPCo0?m82_oonfX3o`3oM`Oooo]Z0_mi0?l0
0ooo9`3oUol0oiOo000@oookJP03o`2Roooo_`3ookl000?ooo]Z00?o08coo`3oX_l0oj801OoonfX2
o`3o8@Kooo]Z00Goo`3bo`000?l0003o0?mFo`000005oookJP;oo`2P0_oonfX01?mD0?oooo]Zoook
J_l09Ol3oookJP04obX0oooonf[ooo]Zool:00Oooo]Z00GoNol0oookJ_oonf[ooo]Zoom10005oook
JP03o`3o>?oonf[o203o00kooo]Z00?oob00oookJ_oonfX01?oonfX00ooo0;Gooo]ZoookJP0Boook
JP03o`3o]Ooonf[ooo]Z00Gooo]Z00?o0?n;oookJ_oonfX05_oonfX00ooo04oooo]ZoookJP02oook
JP03o`3oU_oonf[ooo]Z00Kooo]Z00?ooa`0oookJ_oonfX00_oonfX00onho`3ooo]ZoookJP0>oook
JP04om;o0?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX01OoonfX01?oo003oo`2YoookJ_o/
o`05oookJP03oi<0oooonf[ooo]Z00Oooo]Z00?oE`3ooookJ_oonfX00ooonfX00ooo0=cooo]Zoook
JP05oookJP03oigo0?oonf[ooo]Z00;ooo]Z00?ok@3ooookJ_oonfX0:OoonfX002[ooo]Z0ol0odPB
oookJPgoiOl07_oonfX@ooo900Ko0?nn8ooonfX4ool0mP?ooo]Z0ol00ol=oookJPCo0?m82_oonfX2
o`3oM`OoiOl000CoN@3oonGo0?nGo`3oUol04OoonfX00ooo_`3o0:;ooookJP02oookJP03o`2<oooU
o`3ooo]Z00Kooo]Z00?o0?lQoookJ_oonfX00ooonfX2ool0lP03o`000?l0oeKo0?mF00Kooo]Z00Ko
o`2PoookJ_oonf[ooo]Zoe@0oooonfX2o`0Uo`?ooo]Z0_lZ0?l00ooo2P3ooo]ZoookJP06oookJP05
og_o0?oonf[ooo]ZoookJ_oo@@001OoonfX00ol0ocSo203ooookJP0=oookJP03oolP0?oonf[ooo]Z
00Cooo]Z00?oo`2eoookJ_oonfX04_oonfX00ol0okGooo]ZoookJP06oookJP03o`3oRooonf[ooo]Z
01Kooo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP05oookJP03oolL0?oonf[ooo]Z
00;ooo]Z00?o^?l0oookJ_oonfX03_oonfX01?oBo`3ooo]ZoookJ_oMo`02oookJP03ob/0oooonf[o
oo]Z00Cooo]Z00Gooi/0ool00?oo0:Wooo]Zonco0005oookJP03oi<0oooonf[ooo]Z00Oooo]Z00?o
okL0oeL0oooonfX00ooonfX00ooo0=cooo]ZoookJP05oookJP03ooo90?oonf[ooo]Z00?ooo]Z00?o
k@3ooookJ_oonfX0C_oonfX3o`3oB1Gooo]Z0ol00ol3oookJP?oo`3f:_oonfX<o`3o_R;ooo]Z1?oo
0?H3oookJPCo00?o3OoonfX3o`3oB0[ooo]Z0_l0ogL7oookJP03ogT0oooo9`3oobL000;oUol04?oo
nfX00ol0X_oookl0oookJP02oookJP;o08co00?o0?nRoookJ_oonfX01?oonfX00ol0ob7ooo]Zoook
JP04oookJP;oo`3b00?o0000o`3oE_oonfX01_oonfX00ooo0:3ooo]ZoookJP02oe@0o`03oookJ_l0
9Ooo02Go00;ooo]Z0_lZ0?l00ooonf[oo`X0oookJP06oookJP05og_o0?oonf[ooo]ZoookJ_oo@@00
1OoonfX00ol0ocSooo]Zo`P0o`0>oookJP03oolP0?oonf[ooo]Z00Cooo]Z00?oo`2eoookJ_oonfX0
4_oonfX00ol0okGooo]ZoookJP05oookJP03o`3oRooonf[ooo]Z01Kooo]Z00?oo`1?oookJ_oonfX0
0_oonfX00ol0oiKooo]ZoookJP06oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX0
3_oonfX00ooBo`3ooo]Zomgo0003oookJP03ob/0oooonf[ooo]Z00Cooo]Z00Cooi/0ool00?oo0:Wo
k?l01_oonfX00onC0?oooo]ZoookJP06oookJP03oong0?mG0?oooo]Z00?ooo]Z00?oo`3LoookJ_oo
nfX01_oonfX00onMo`3ooo]ZoookJP02oookJP03ond0oooonf[ooo]Z02Sooo]Z000WoookJP?o0?m8
5?oonfX<onGo023ooo]Z3_oob@08oookJPgo0?nn6_oonfX4ool0mP;ooo]Z1?l00ol=oookJP?o0?m8
2OoonfX2o`3oM`Kooo]Z0_mi0?l00ooUo`3oUol0oolW000@oookJP;ookl01?oonfX2onGo00Kooo]Z
00?o0?lQoookJ_oonfX00ooonfX01Ol0003oo`3bo`000?l0003o0?mF00Kooo]Z0_oo0:02oookJP;o
E03o00?ooo]Zo`0UoooonfX00ooonfX00olZ0?ooo`X0oookJP06oookJP03og_o0?oonf[ooo]Z00;o
oo]Z00?ood40oookJ_oonfX00ooonfX00ol0ocSo203ooookJP0=oookJP03oolP0?oonf[ooo]Z00Co
oo]Z00?oo`2eoookJ_oonfX04_oonfX00ol0okGooo]ZoookJP06oookJP03o`3oRooonf[ooo]Z01Ko
oo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP08oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oook
J_oonfX03OoonfX01?oBo`3ooo]ZoookJ_oMo`03oookJP03ob/0oooonf[ooo]Z00Cooo]Z00Goo`00
oookJ_oo0:Wooo]Zonco0005oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?ookL0oeL0oooonfX01?oo
nfX00ooo0=cooo]ZoookJP04oookJP03ooo90?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX0Booo
nfX3o`3oB1Gooo]Z0ol00ol3oookJP?oo`3f8ooonfX:o`3o_Pcooo]Z3Ol0okhIoookJPCoo`3f0ooo
nfX3o`03o`gooo]Z0ol0odP9oookJP;o0?mg1_oonfX2ogT0o`03oookJ_oo9`3oUol0017ooo]Z0_oo
_`03oookJP03o`2<ool0oj;o0?nR00Gooo]Z00?o0?lQoookJ_oonfX00ooonfX2o`000004ool0l_l0
003o0?mFo`3oEPKooo]Z0_oo0:02oookJP04oe@0oooonf[ooo]Zo`0Uo`?ooo]Z00?o:P3ooookJ_oo
2P001_oonfX00omko`3ooo]ZoookJP02oookJP03oom10?oonf[ooo]Z00?ooo]Z00?o0?lhoookJ_l8
0?l03_oonfX00ooo803ooo]ZoookJP04oookJP03ool0]Ooonf[ooo]Z01;ooo]Z00?o0?neoookJ_oo
nfX01OoonfX00ol0oh_ooo]ZoookJP0FoookJP05ool0Cooonf[ooo]ZoookJ_l0oiH02?oonfX00ooo
703ooo]ZoookJP02oookJP03okSo0?oonf[ooo]Z00kooo]Z00Cod_l0oookJ_oonf[ogOl00_oonfX0
0ol[0?oooo]ZoookJP05oookJP04ool00?oo0:Wooo]Zonco00Gooo]Z00?oT`3ooookJ_oonfX01ooo
nfX00omG0?oooo]ZoookJP03oookJP03ool0g?oonf[ooo]Z00Gooo]Z00?oWOl0oookJ_oonfX00_oo
nfX00oo]0?oooo]ZoookJP0XoookJP009OoonfX2o`3oB1Cooo]Z0ooUo`000ooonf[oiOl0onGo0008
onGo01Sooo]Z2Ooob@0Goe[o00cooo]Z3Ol0okhAoookJP?oo`3f0ooonfX3o`03o`gooo]Z0ol0odP8
oookJP;o0?mg1_oonfX2ogT0o`;oUol04OoonfX2oono00?ooo]Z00?o08coonGo0?oonfX01OoonfX0
0ol0ob7ooo]ZoookJP02oookJP;o000000?oo`3bo`000?oonfX00_l0oeH6oookJP07ool0X?oonf[o
oo]ZoookJ_mD0?oooo]Zo`0Uo`04oookJP03obX0oooo2P3ooo]Z00Kooo]Z00?oNol0oookJ_oonfX0
0_oonfX00ooo@@3ooo]ZoookJP03oookJP03o`3o>?l80?oooo]Z00gooo]Z00?oob00oookJ_oonfX0
1?oonfX00ooo0;Gooo]ZoookJP0AoookJP03o`3o]Ooonf[ooo]Z00Kooo]Z00?o0?n;oookJ_oonfX0
5_oonfX00ooo04oooo]ZoookJP02oookJP03o`3oU_oonf[ooo]Z00Gooo]Z00?ooa`0oookJ_oonfX0
0_oonfX00onho`3ooo]ZoookJP0>oookJP04om;o0?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oo
nfX01?oonfX01OooV`3oo`00ool0ZOoonf[ok?l000Gooo]Z00?oT`3ooookJ_oonfX01ooonfX00ooo
]`3oE`3ooookJP04oookJP03ool0g?oonf[ooo]Z00?ooo]Z00?oolT0oookJ_oonfX00ooonfX00oo]
0?oooo]ZoookJP19oookJP;o0?m85OoonfX3o`03o`?ooo]Z0ooo0?HMoookJPSo0?nn5omJo`0=oook
JPco0?nn4OoonfX3ool0mP?ooo]Z0ol00ol=oookJP?o0?m82?oonfX2o`3oM`Kooo]Z0_mi0?l00ooo
nf[oUol0oiOo000@oookJP03o`2Roooo_`3ookl000?ooo]Z00?o08coo`3oX_oonfX01?oonfX00ol0
ob7ooo]ZoookJP02oookJP?o000000Coo`3boookJ_oonf[o0?mF1ooonfX01?oo0:3ooo]ZoookJ_mD
0?l2oookJP07o`0Uoooonf[ooo]ZoookJ_lZ0?oooo]Zool:0006oookJP03og_o0?oonf[ooo]Z00;o
oo]Z00?ood40oookJ_oonfX00ooonfX00ol0ocSooo]Zo`P0o`0>oookJP03oolP0?oonf[ooo]Z00?o
oo]Z00?oo`2eoookJ_oonfX04_oonfX00ol0okGooo]ZoookJP05oookJP03o`3oRooonf[ooo]Z01Ko
oo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP06oookJP03oolL0?oonf[ooo]Z00;o
oo]Z00?o^?l0oookJ_oonfX03_oonfX00ooBo`3ooo]Zomgo0003oookJP03ob/0oooonf[ooo]Z00Co
oo]Z00Cooi/0ool00?oo0:Wok?l01_oonfX00onC0?oooo]ZoookJP06oookJP03oong0?mG0?oooo]Z
00Cooo]Z00?oo`3LoookJ_oonfX01?oonfX00onMo`3ooo]ZoookJP03oookJP03ond0oooonf[ooo]Z
02Oooo]Z000hoookJP?oiOl01?oonfX8onGo017ooo]Z2Ooob@04oookJPGoF_l000?ooo]Zooo90?oo
b@001Ooob@0?oookJQGoF_l01?oonfX8o`3o_Pcooo]Z1?oo0?H2oookJP?o00?o3OoonfX2o`3oB0So
oo]Z0ol0ogL5oookJP;oN@3o0_nGo`0@oookJP03o`2Roooo_`3ookl000?ooo]Z00?oiOl0o`2<oooo
nfX01?oonfX2o`3o8@;ooo]Z0ol00002ool0lP;ooo]Z00?o0?mFoookJ_oonfX01?oonfX01ooo0:3o
oo]ZoookJ_oonf[oE03ooookJ_l09Ol01?oonfX00olZ0?ooo`X0oookJP06oookJP03og_o0?oonf[o
oo]Z00;ooo]Z00?ood40oookJ_oonfX00ooonfX00ol0ocSo203ooookJP0=oookJP03oolP0?oonf[o
oo]Z00Cooo]Z00?oo`2eoookJ_oonfX04OoonfX00ol0okGooo]ZoookJP06oookJP03o`3oRooonf[o
oo]Z01Kooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP08oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o
^?l0oookJ_oonfX03_oonfX00ooBo`3ooo]Zomgo0003oookJP03ob/0oooonf[ooo]Z00Cooo]Z00Co
o`00oookJ_oo0:Wok?l01_oonfX00onC0?oooo]ZoookJP06oookJP03oong0?mG0?oooo]Z00Cooo]Z
00?oo`3LoookJ_oonfX01?oonfX00ooob@3ooo]ZoookJP03oookJP03ond0oooonf[ooo]Z05cooo]Z
0ol00ol4oookJP;oo`3f5_oonfX:o`3o_P?ooo]Z1OmJo`0GoookJQKoF_l00ooonfX8o`3o_Pcooo]Z
1?oo0?H2oookJPCo00?o3?oonfX2o`3oB0Sooo]Z0ol0ogL5oookJP;oN@3o00?oobL0oiOo0?nGo`00
4?oonfX00ol0X_oookl0oono0002oookJP03o`2<ool0oj;ooo]Z00Cooo]Z0_l0ob42oookJPCo0000
00Coo`3boookJ_oonf[o0?mF1ooonfX00ooo0:3ooo]ZoookJP02oe@0o`03oookJ_l09Ooooo]Z00;o
oo]Z00?o:P3ooookJ_oo2P001_oonfX00omko`3ooo]ZoookJP02oookJP03oom10?oonf[ooo]Z00?o
oo]Z00?o0?lhoookJ_l80?l03_oonfX00ooo803ooo]ZoookJP03oookJP03ool0]Ooonf[ooo]Z01;o
oo]Z00?o0?neoookJ_oonfX01OoonfX00ol0oh_ooo]ZoookJP0FoookJP05ool0Cooonf[ooo]Zoook
J_l0oiH02OoonfX00ooo703ooo]ZoookJP02oookJP03okSo0?oonf[ooo]Z00kooo]Z00?od_l0oook
J_oMo`000_oonfX00ol[0?oooo]ZoookJP05oookJP04ool00?oonf[oo`2Yonco00Gooo]Z00?oT`3o
oookJ_oonfX01ooonfX00omG0?oooo]ZoookJP03oookJP03ool0g?oonf[ooo]Z00Gooo]Z00?oWOl0
oookJ_oonfX00_oonfX00oo]0?oooo]ZoookJP0WoookJP00=OoonfX3onGo00Cooo]Z0ooUo`000ooo
nf[oiOl0onGo0004onGo00cooo]Z00?o0?nnooo90?oob@000ooob@07oookJPKoF_l01_oonfX4ooo9
02Oooo]Z1OmJo`07oookJP?o0?nn3OoonfX3ool0mP;ooo]Z1?l00ol;oookJP;o0?m82OoonfX2o`3o
M`Gooo]Z0_mi0?l2oiOo013ooo]Z00?o0:;ooono0?oonfX00_oonfX2onGo00Kooo]Z00?o0?lQoook
J_l000000ol000001Ooonf[oo`3boookJ_oonf[o0?mF00Kooo]Z00Coo`2PoookJ_oonf[ooo]Z0_mD
0?l00ol09Ooooo]ZoookJP02oookJP03obX0oooo2P3ooo]Z00Kooo]Z00?oNol0oookJ_oonfX00_oo
nfX00ooo@@3ooo]ZoookJP03oookJP03o`3o>?l80?oooo]Z00gooo]Z00?oob00oookJ_oonfX01?oo
nfX00ooo0;Gooo]ZoookJP0AoookJP03o`3o]Ooonf[ooo]Z00Kooo]Z00?o0?n;oookJ_oonfX05_oo
nfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Sooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000@oookJP04
om;o0?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX01?oonfX01OooV`3oo`00ool0ZOoonf[o
k?l000Gooo]Z00?oT`3ooookJ_oonfX01ooonfX00ooo]`3oE`3ooookJP04oookJP03ool0g?oonf[o
oo]Z00?ooo]Z00?oolT0oookJ_oonfX00ooonfX00oo]0?oooo]ZoookJP1IoookJP?o00?o1?oonfX3
ool0mQ;ooo]Z1_l0okh7oookJPKoF_l0<_oonfX5oe[o00Kooo]Z0ol0okh=oookJP?oo`3f0ooonfX3
o`03o`_ooo]Z0_l0odP9oookJP;o0?mg1OoonfX2ogT0o`03oolW0?nGo`3oUol000oooo]Z00?o0:;o
oookJ_oo_`000ooonfX2o`3oXPGooo]Z00?o0?lQoookJ_l000000ol000001?oonf[oo`3boookJ_oo
nfX2o`3oEPKooo]Z00Ooo`2PoookJ_oonf[ooo]Zoe@0oooonf[o02Go00?ooo]Z00?o:P3ooookJ_oo
2P001_oonfX00omko`3ooo]ZoookJP02oookJP03oom10?oonf[ooo]Z00?ooo]Z00?o0?lhoookJ_l8
0?l03_oonfX00ooo803ooo]ZoookJP03oookJP03ool0]Ooonf[ooo]Z01;ooo]Z00?o0?neoookJ_oo
nfX01OoonfX00ol0oh_ooo]ZoookJP0FoookJP05ool0Cooonf[ooo]ZoookJ_l0oiH02?oonfX00ooo
703ooo]ZoookJP02oookJP03okSo0?oonf[ooo]Z00kooo]Z00?od_l0oookJ_oMo`000ooonfX00ol[
0?oooo]ZoookJP04oookJP04oonK0?oo003oo`2Yonco00Kooo]Z00?oT`3ooookJ_oonfX01_oonfX0
0ooo]`3oE`3ooookJP04oookJP03ool0g?oonf[ooo]Z00Cooo]Z00?oWOl0oookJ_oonfX00_oonfX0
0oo]0?oooo]ZoookJP0WoookJP00<_oonfX3onGo00Gooo]Z0_oUo`04oookJPGoiOl02_oonfX3o`3o
_PSooo]Z1OmJo`0<oookJP03ooo90?oonf[ooo]Z00?ooo]Z3OoRo`0MoookJPGoF_l01OoonfX4o`3o
_Pcooo]Z1?oo0?H2oookJP?o00?o2_oonfX2o`3oB0Wooo]Z0_l0ogL5oookJP04ogT0oooonf[oUol0
oiOo00oooo]Z00?o0:;ooono0?oo_`000ooonfX00ooUo`3o08cooookJP04oookJP03o`3o8Ol0003o
000000;o00000_oonfX00ooo0?;ooo]ZoookJP02o`3oEPGooo]Z00?oo`2PoookJ_oonfX00_oonfX0
0omD0?oo02GooookJP03oookJP03obX0oooo2P3ooo]Z00Kooo]Z00?oNol0oookJ_oonfX00_oonfX0
0ooo@@3ooo]ZoookJP03oookJP03o`3o>?l80?oooo]Z00gooo]Z00?oob00oookJ_oonfX00ooonfX0
0ooo0;Gooo]ZoookJP0AoookJP03o`3o]Ooonf[ooo]Z00Kooo]Z00?o0?n;oookJ_oonfX05_oonfX0
0ooo04oooo]ZoookJP02oookJP03o`3oU_oonf[ooo]Z00Gooo]Z00?ooa`0oookJ_oonfX00_oonfX0
0onho`3ooo]ZoookJP0>oookJP03om;o0?oonf[ogOl000?ooo]Z00?o:`3ooookJ_oonfX01?oonfX0
1?oo003ooo]Zool0ZOo/o`06oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?ookL0oookJ_mG0?l01?oo
nfX00ooo0=cooo]ZoookJP04oookJP03ooo90?oonf[ooo]Z00;ooo]Z00?ok@3ooookJ_oonfX0E_oo
nfX3o`03o`Cooo]Z0ooo0?HBoookJP?o0?nn2?oonfX5oe[o01;ooo]Z3OoRo`0NoookJPGoF_l01?oo
nfX4o`3o_Pcooo]Z1?oo0?H2oookJP?o00?o2_oonfX2o`3oB0Wooo]Z0_l0ogL5oookJP03ogT0oooo
nf[oobL000;oUol03_oonfX2o`2Ro`;ookl00ooonfX00ol0oj;ooo]ZoookJP03oookJP03o`3o8Ol0
003o000000;o00000_oonfX2ool0lP;ooo]Z00?o0?mFoookJ_oonfX01?oonfX01ooo0:3ooo]Zoook
J_oonf[oE03ooookJ_l09Ol00ooonfX00olZ0?oooo]Zool:0006oookJP03og_o0?oonf[ooo]Z00;o
oo]Z00?ood40oookJ_oonfX00ooonfX00ol0ocSooo]Zo`P0o`0>oookJP03oolP0?oonf[ooo]Z00?o
oo]Z00?oo`2eoookJ_oonfX04OoonfX00ol0okGooo]ZoookJP06oookJP03o`3oRooonf[ooo]Z01Go
oo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP06oookJP03oolL0?oonf[ooo]Z00;o
oo]Z00?o^?l0oookJ_oonfX03_oonfX00ooBo`3ooo]Zomgo0002oookJP03ob/0oooonf[ooo]Z00Go
oo]Z00Coo`00oookJ_oo0:Wok?l01OoonfX00onC0?oooo]ZoookJP07oookJP03oong0?mG0?oooo]Z
00?ooo]Z00?oo`3LoookJ_oonfX01OoonfX00onMo`3ooo]ZoookJP02oookJP03ond0oooonf[ooo]Z
02Kooo]Z000_oookJP?oiOl01OoonfX3onGo00Oooo]Z0_oUo`09oookJP?o0?nn1_oonfX5oe[o017o
oo]Z1_oRo`0=oookJQ;oh_l04?oonfX5oe[o00Cooo]Z0ol0okh=oookJPCoo`3f00Cooo]Zo`03ool0
0ooo00?o2OoonfX3o`3oB0Sooo]Z0_l0ogL4oookJP;oN@3o00?oobL0oiOo0?oonfX03ooonfX00ol0
X_oookl0oono0002oookJP;oiOl000?o08cooookJ_oonfX00_oonfX01?l0ob7o0000o`000?l00003
oookJP05ool0l_oonf[ooo]ZoookJ_l0oeH01OoonfX00ooo0:3ooo]ZoookJP02oookJP03oe@0ool0
9Ooooo]Z00?ooo]Z0_lZ0?l7oookJP03og_o0?oonf[ooo]Z00;ooo]Z00?ood40oookJ_oonfX00ooo
nfX00ol0ocSo203ooookJP0=oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?oo`2eoookJ_oonfX04Ooo
nfX00ol0okGooo]ZoookJP06oookJP03o`3oRooonf[ooo]Z01Kooo]Z00Goo`1?oookJ_oonf[ooo]Z
o`3oUP08oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX03OoonfX01?oBo`3ooo]Z
oookJ_oMo`02oookJP03ob/0oooonf[ooo]Z00Cooo]Z00Gooi/0ool00?oo0:Wooo]Zonco0005oook
JP03oi<0oooonf[ooo]Z00Oooo]Z00?ookL0oeL0oooonfX01?oonfX00ooo0=cooo]ZoookJP03oook
JP03ooo90?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX0D_oonfX3o`03o`Cooo]Z0ooo0?HBoook
JP?o0?nn1_oonfX5oe[o017ooo]Z1_oRo`0=oookJQ?oh_l04?oonfX5oe[o00?ooo]Z0ol0okh=oook
JPCoo`3f00Cooo]Zo`03ool00ooo00?o2OoonfX3o`3oB0Sooo]Z0_l0ogL4oookJP;oN@3o0_oo9`00
0onGo`3ooo]ZoookJP0=oookJP04o`2Roooonf[ookl0oono00;ooo]Z0_l0oj84oookJP04o`3o8Ol0
003o0000o`0000Cooo]Z00Coo`3boookJ_oonf[o0?mF1_oonfX01ooo0:3ooo]ZoookJ_oonf[oE03o
oookJ_l09Ol00ooonfX2obX0o`03ool:0?oonf[ooo]Z00Cooo]Z00?oNol0oookJ_oonfX00_oonfX0
0ooo@@3ooo]ZoookJP03oookJP03o`3o>?oonf[o203o00kooo]Z00?oob00oookJ_oonfX00ooonfX0
0ooo0;Gooo]ZoookJP0AoookJP03o`3o]Ooonf[ooo]Z00Gooo]Z00?o0?n;oookJ_oonfX05_oonfX0
1Ooo04oooo]ZoookJ_oonf[o0?nF00Wooo]Z00?ooa`0oookJ_oonfX00_oonfX00onho`3ooo]Zoook
JP0=oookJP04om;o0?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX01?oonfX01?ooV`3oo`00
ool0ZOo/o`06oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?ookL0oeL0oooonfX01?oonfX00ooo0=co
oo]ZoookJP04oookJP03oigo0?oonf[ooo]Z00;ooo]Z00?ok@3ooookJ_oonfX09_oonfX002cooo]Z
0ooUo`05oookJP?oiOl02_oonfX00ooUo`3ooo]ZoookJP05oookJP?o0?nn0ooonfX6oe[o013ooo]Z
1_oRo`0UoookJP_oh_l02_oonfX5oe[o00;ooo]Z1?l0okh=oookJP?oo`3f00Cooo]Zo`03ool00ooo
00?o2OoonfX2o`3oB0Sooo]Z0ol0ogL3oookJP;oN@3o0_nGo`0?oookJP03o`2Roooonf[ookl000?o
oo]Z00?oiOl0o`2<oooonfX00_oonfX01?oUo`3o0?lQo`000?l00004oookJP;oo`3b0_oonfX00ol0
oeKooo]ZoookJP03oookJP03ool0X?oonf[ooo]Z00;ooo]Z00?oE03oo`0UoooonfX01?oonfX00olZ
0?ooo`X0oookJP05oookJP06og_o0?oonf[ooo]ZoookJ_ooW03ood401OoonfX00ol0ocSo203ooook
JP0=oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?oo`2eoookJ_oonfX04OoonfX00ol0okGooo]Zoook
JP06oookJP03o`3oRooonf[ooo]Z01Kooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP07oookJP03oolL
0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX03_oonfX01?oBo`3ooo]ZoookJ_oMo`02oookJP03
ob/0oooonf[ooo]Z00Cooo]Z00Coo`00oookJ_oo0:Wok?l01_oonfX00onC0?oooo]ZoookJP06oook
JP03oong0?oonf[oE`3o00Cooo]Z00?oo`3LoookJ_oonfX00ooonfX00ooob@3ooo]ZoookJP03oook
JP03ond0oooonf[ooo]Z04oooo]Z0ol00ol5oookJP;oo`3f4_oonfX3o`3o_P?ooo]Z1_mJo`0@oook
JPKoh_l09_oonfX;on;o00[ooo]Z1OmJo`000ooonf[o0?nno`3o_P02o`3o_Pgooo]Z0ooo0?H01?oo
nf[o00?oo`03ool00ol9oookJP;o0?m82?oonfX3o`3oM`?ooo]Z0_mi0?l00ooo9`3oUol0oiOo000>
oookJP;o0:;o00?ooo]Zoono0?oonfX00_oonfX01_l0oj;ooo]ZoookJ_oonf[o0000o`3o8@;o0000
1OoonfX00ooo0?;ooo]ZoookJP02o`3oEPGooo]Z00Ooo`2PoookJ_oonf[ooo]Zoe@0oooonf[o02Go
00Cooo]Z00?o:P3oool:0?oo2P001OoonfX00omko`3ooo]ZoookJP02oookJP03oom10?oonf[ooo]Z
00?ooo]Z00?o0?lhoookJ_l80?l03_oonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z
01;ooo]Z00?o0?neoookJ_oonfX01OoonfX00ol0oh_ooo]ZoookJP0FoookJP05ool0Cooonf[ooo]Z
oookJ_l0oiH02?oonfX00ooo703ooo]ZoookJP02oookJP03okSo0?oonf[ooo]Z00kooo]Z00?od_l0
oookJ_oMo`000_oonfX00ol[0?oooo]ZoookJP05oookJP03ool00?oonf[ok?l000Kooo]Z00?oT`3o
oookJ_oonfX01ooonfX00ooo]`3oE`3ooookJP03oookJP03ool0g?oonf[ooo]Z00Cooo]Z00?oWOl0
oookJ_oonfX00_oonfX00oo]0?oooo]ZoookJP0VoookJP00:OoonfX3onGo00Gooo]Z0ooUo`0Boook
JP?o0?nn00?ooo]Zoe[o0?mJo`000omJo`0?oookJPOoh_l0=_oonfX5on;o00[ooo]Z1OmJo`001?oo
nf[o0?nno`3o__l0okh=oookJP?oo`3f00?ooo]Zo`03ool00ol02OoonfX2o`3oB0Cooo]Z1Ol007l2
o`3oM`;ooo]Z00?o001oogT0oomi0?l00_nGo`001?oonf[o001oo`00Ool007l7oookJP?o001o0_l0
X_l2oono00;ooo]Z0_oUo`001?oonf[oiOl0onGo0?oUo`02o`3o8@Kooo]Z00?oo`3boookJ_oonfX0
0_l0oeH4oookJP07ool0X?oonf[ooo]ZoookJ_mD0?oooo]Zo`0Uo`05oookJP03obX0oooo2P3ooo]Z
00Gooo]Z00KoNol0oookJ_oonf[ooo]ZoonL0?oo@@05oookJP03o`3o>?l80?oooo]Z00gooo]Z00?o
ob00oookJ_oonfX00ooonfX00ooo0;Gooo]ZoookJP0AoookJP03o`3o]Ooonf[ooo]Z00Gooo]Z00?o
0?n;oookJ_oonfX05ooonfX01?oo04oooo]ZoookJ_l0oiH8oookJP03oolL0?oonf[ooo]Z00;ooo]Z
00?o^?l0oookJ_oonfX03_oonfX00ooob@3ooo]Zomgo0002oookJP03ob/0oooonf[ooo]Z00Cooo]Z
00Gooi/0ool00?oo0:Wooo]Zonco0005oookJP03oi<0oooonf[ooo]Z00Oooo]Z00?ookL0oeL0oooo
nfX01?oonfX00ooo0=cooo]ZoookJP03oookJP03ooo90?oonf[ooo]Z00;ooo]Z00?ok@3ooookJ_oo
nfX0C?oonfX3o`03o`Gooo]Z0ooo0?HAoookJP?o0?nn00?ooo]Zoe[o0?mJo`000omJo`0?oookJPOo
h_l0=ooonfX5on;o00[ooo]Z1OmJo`03o`3o_Pgooo]Z0ooo0?H00ooonf[o00?oo`03o`09oookJP;o
0?m81?oonfX5o`00O`;o0?mg0_oonfX01?l007ooN@3oogT0oooo9`02oiOo00?o001o1ooonfX4o`00
O`04o`2Roooonf[ookl0oono00;ooo]Z0_l0oj800ooonf[o0000o`000002o`3o8@Kooo]Z00Goo`3b
oookJ_oonf[ooo]Zo`3oEP05oookJP07ool0X?oonf[ooo]ZoookJ_mD0?oooo]Zo`0Uo`04oookJP03
obX0ool0C?ooo`X000Gooo]Z00?oNol0oookJ_oonfX00_oonfX00ooo@@3ooo]ZoookJP03oookJP03
o`3o>?oonf[o203o00kooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP0BoookJP03
o`3o]Ooonf[ooo]Z00Gooo]Z00?o0?n;oookJ_oonfX05_oonfX01?oo04oooo]ZoookJ_l0oiH9oook
JP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX03_oonfX00ooBo`3ooo]Zomgo0002oook
JP03ob/0oooonf[ooo]Z00Cooo]Z00Cooi/0ool00?oo0:Wok?l01_oonfX00onC0?oooo]ZoookJP06
oookJP03oong0?mG0?oooo]Z00Cooo]Z00?oo`3LoookJ_oonfX01?oonfX00onMo`3ooo]ZoookJP02
oookJP03ond0oooonf[ooo]Z02Gooo]Z000WoookJP;oiOl01_oonfX2onGo01;ooo]Z0_l0okh3ooo9
00;oF_l03_oonfX6on;o04;ooo]Z1?oRo`0;oookJPGoF_l00ol0okh<oookJP;oo`3f00Cooo]Zo`03
ool00ooo00?o2?oonfX2o`3oB003oookJ_l007oo001o00Go001o00?ooo]Zo`3oMol0ogL00ol007l2
ogT0o`;oUol00_l007l6oookJPKo001o00Co0:;ooookJ_oo_`3ookl00_oonfX5onGo0003o`000?l0
ob7ooo]Z00Gooo]Z00Goo`3boookJ_oonf[ooo]Zo`3oEP04oookJP07ool0X?oonf[ooo]ZoookJ_mD
0?oooo]Zo`0Uo`05oookJP03obX0oooo2P3ooo]Z00Gooo]Z00KoNol0oookJ_oonf[ooo]ZoonL0?oo
@@05oookJP03o`3o>?l80?oooo]Z00gooo]Z00?oob00oookJ_oonfX00ooonfX00ooo0;Gooo]Zoook
JP0@oookJP03o`3o]Ooonf[ooo]Z00Kooo]Z00?o0?n;oookJ_oonfX05_oonfX01Ooo04oooo]Zoook
J_oonf[o0?nF00Sooo]Z00?ooa`0oookJ_oonfX00_oonfX00onho`3ooo]ZoookJP0=oookJP04ooo9
0?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX01?oonfX01?oo003ooo]Zool0ZOo/o`06oook
JP03oi<0oooonf[ooo]Z00Kooo]Z00?ookL0oookJ_mG0?l01?oonfX00ooo0=cooo]ZoookJP03oook
JP03ooo90?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX0B?oonfX3o`03o`Gooo]Z0ooo0?HAoook
JP?o0?nn1?mJo`0>oookJPKoh_l0@ooonfX4on;o00_ooo]Z1OmJo`02o`3o_Pcooo]Z0_oo0?H01?oo
nf[o00?oo`03ool00ol8oookJP;o0?m800?ooo]Zo`00Ool007l01Ol007l00ooonf[o0?mgo`3oM`03
o`00O`;oN@3o00CoobL0oiOo0?nGo`3o001o1_oonfX6o`00O`;o0:;o00Kooo]Zoono0?oo_`3ooo]Z
o`2<ool0oj84o`000003o`3o8Ooonf[ooo]Z00Cooo]Z0_oo0?82oookJP03o`3oE_oonf[ooo]Z00?o
oo]Z00Ooo`2PoookJ_oonf[ooo]Zoe@0oooonf[o02Go00Cooo]Z00?o:P3oo`1<oooo2P001OoonfX0
0omko`3ooo]ZoookJP02oookJP03oom10?oonf[ooo]Z00?ooo]Z00?o0?lhoookJ_l80?l03_oonfX0
0ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z017ooo]Z00?o0?neoookJ_oonfX01OoonfX0
0ol0oh_ooo]ZoookJP0FoookJP05ool0Cooonf[ooo]ZoookJ_l0oiH02OoonfX00ooo703ooo]Zoook
JP02oookJP03okSo0?oonf[ooo]Z00gooo]Z00?od_l0oookJ_oMo`000_oonfX00ol[0?oooo]Zoook
JP05oookJP03ool00?oonf[ok?l000Kooo]Z00?oT`3ooookJ_oonfX01ooonfX00ooo]`3oE`3ooook
JP03oookJP03ool0g?oonf[ooo]Z00Cooo]Z00?oWOl0oookJ_oonfX00_oonfX00oo]0?oooo]Zoook
JP0UoookJP009_oonfX00ol00ooooo]ZoookJP03oookJP?oiOl04OoonfX6ooo900cooo]Z1_oRo`1<
oookJPCoh_l03?oonfX4oe[o00;o0?nn2ooonfX3ool0mP03oookJ_l00ooo00?o00Sooo]Z0_l0odP2
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z00?o0?mgo`00Ool007l00_oonfX01?mi0?ooobL0oiOo
0?nGo`05oookJPCo001o00Cooo]Zo`00Ool007oo001o0_l0X_l00ooonf[ookl0oookJP06onGo0003
oookJ_l0ob7ooo]Z00Gooo]Z00Goo`3boookJ_oonf[ooo]Zo`3oEP04oookJP07ool0X?oonf[ooo]Z
oookJ_mD0?oooo]Zo`0Uo`05oookJP03obX0oooo2P3ooo]Z00Gooo]Z00KoNol0oookJ_oonf[ooo]Z
oonL0?oo@@05oookJP03o`3o>?l80?oooo]Z00cooo]Z00?oob00oookJ_oonfX01?oonfX00ooo0;Go
oo]ZoookJP0@oookJP03o`3o]Ooonf[ooo]Z00Kooo]Z00?o0?n;oookJ_oonfX05_oonfX01Ooo04oo
oo]ZoookJ_oonf[o0?nF00Oooo]Z00?ooa`0oookJ_oonfX00_oonfX00onho`3ooo]ZoookJP0>oook
JP03ooo90?oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX01?oonfX01?ooV`3oo`00ool0ZOo/o`06
oookJP03oi<0oooonf[ooo]Z00Oooo]Z00?ookL0oeL0oooonfX01?oonfX00ooo0=cooo]ZoookJP03
oookJP03ooo90?oonf[ooo]Z00;ooo]Z00?ok@3ooookJ_oonfX0AooonfX00ol00ooooo]ZoookJP03
oookJP?oo`3f4OoonfX3o`3o_P03oookJ_mJo`3oF_l000cooo]Z1_oRo`1=oookJPCoh_l03?oonfX4
oe[o0003o`3o__oonf[ooo]Z00Wooo]Z0ooo0?H00ooonf[o00?oo`03o`08oookJP;o0?m80_l007l0
1?oonf[o001oo`00Ool007l3oookJP03o`3oMol007oo001o00;ooo]Z00?oN@3ooolW0?oo9`000_nG
o`04oookJPCo001o00Kooo]Zo`00Ool007oo001ooookJ_l0X_l2oookJP04oono0?oonf[o08coo`3o
XP?o000000?ooo]Zo`3o8OoonfX01_oonfX01?oo0?;ooo]ZoookJ_l0oeH5oookJP07ool0X?oonf[o
oo]ZoookJ_mD0?oooo]Zo`0Uo`04oookJP03obX0ool0C?ooo`X000Gooo]Z00?oNol0oookJ_oonfX0
0_oonfX00ooo@@3ooo]ZoookJP03oookJP03o`3o>?oonf[o203o00gooo]Z00?oob00oookJ_oonfX0
0ooonfX00ooo0;Gooo]ZoookJP0AoookJP03o`3o]Ooonf[ooo]Z00Gooo]Z00?o0?n;oookJ_oonfX0
5_oonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Sooo]Z00?ooa`0oookJ_oonfX00_oonfX00onho`3o
oo]ZoookJP0>oookJP03om;o0?oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX01?oonfX01?ooV`3o
o`00ool0ZOo/o`06oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?ookL0oeL0oooonfX01?oonfX00ooo
0=cooo]ZoookJP04oookJP03oigo0?oonf[ooo]Z00;ooo]Z00?ok@3ooookJ_oonfX09?oonfX002Go
oo]Z00Co00?ooookJ_oonf[ooo]Z0ooUo`0?oookJP[oolT02OoonfX4on;o05Kooo]Z1OoRo`0;oook
JP?oF_l00ol0okh9oookJP04o`00Oooo0?Koo`3fo`00O`;o00?o1?l007l2oookJP;o001o0_l0odP2
oookJP?o001o0ooonfX2o`3oM`?ooo]Z0_mi0?l00ooo9`3oUol0oookJP03oookJP?o001o0ooonfX3
o`00O`03oookJ_l0X_oooo]Z00SoiOl000?ooo]Zo`3o8OoonfX01OoonfX2ool0lP;ooo]Z0_l0oeH3
oookJP07ool0X?oonf[ooo]ZoookJ_mD0?oooo]Zo`0Uo`05oookJP03obX0oooo2P3ooo]Z00Gooo]Z
00KoNol0oookJ_oonf[ooo]ZoonL0?oo@@05oookJP03o`3o>?l80?oooo]Z00cooo]Z00?oob00oook
J_oonfX00ooonfX00ooo0;Gooo]ZoookJP0AoookJP03o`3o]Ooonf[ooo]Z00Gooo]Z00?o0?n;oook
J_oonfX05ooonfX01?oo04oooo]ZoookJ_l0oiH8oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0
oookJ_oonfX03OoonfX01?oob@3ooo]ZoookJ_oMo`02oookJP03ob/0oooonf[ooo]Z00Cooo]Z00Co
o`00oookJ_oo0:Wok?l01_oonfX00onC0?oooo]ZoookJP06oookJP03oong0?oonf[oE`3o00Cooo]Z
00?oo`3LoookJ_oonfX00ooonfX00ooob@3ooo]ZoookJP03oookJP03ond0oooonf[ooo]Z04Gooo]Z
00Co00?ooookJ_oonf[ooo]Z0ooo0?HBoookJP;o0?nn0_oonfX2oe[o00[ooo]Z1?oRo`1GoookJPGo
h_l02ooonfX3oe[o00;o0?nn2OoonfX01?l007ooo`3fool0m_l007l2o`03o`Co001o0_oonfX2o`00
O`;o0?m80_oonfX3o`00O`?ooo]Z0_l0ogL3oookJP;oN@3o00?oobL0oookJ_nGo`000ooonfX3o`00
O`?ooo]Z0ol007l01ooonf[o0:;oo`2Roooonf[ookl0oookJ_l000000_l0oj801?l0003ooo]Zoook
J_l0ob47oookJP03ool0l_oonf[ooo]Z00;o0?mF1?oonfX01ooo0:3ooo]ZoookJ_oonf[oE03ooook
J_l09Ol01?oonfX00olZ0?oo04coool:0005oookJP03og_o0?oonf[ooo]Z00;ooo]Z00?ood40oook
J_oonfX00ooonfX00ol0ocSooo]Zo`P0o`0=oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?oo`2eoook
J_oonfX04OoonfX00ol0okGooo]ZoookJP05oookJP03o`3oRooonf[ooo]Z01Kooo]Z00Coo`1?oook
J_oonf[o0?nF2OoonfX00ooo703ooo]ZoookJP02oookJP03okSo0?oonf[ooo]Z00gooo]Z00?od_l0
oookJ_oMo`000_oonfX00ol[0?oooo]ZoookJP05oookJP03ool00?oonf[ok?l000Oooo]Z00?oT`3o
oookJ_oonfX01OoonfX00ooo]`3ooo]ZoeL0o`04oookJP03ool0g?oonf[ooo]Z00Cooo]Z00?oWOl0
oookJ_oonfX00_oonfX00oo]0?oooo]ZoookJP0ToookJP009ooonfX00ooo0?KoiOl0oookJP0>oook
JPcoolT02?oonfX2on;o05oooo]Z1?oRo`0:oookJP;oF_l000Cooo]Zo`3o__l0okko0?nn1_oonfX3
o`00O`;oo`3f00?o001oo`03ool00ol00_l007l2oookJP?o001o00?ooo]Zo`3oB?l0odP00ol007l5
oookJP05o`3oMooonf[ooo]ZoookJ_l007l00_mi0?l2oiOo00Sooo]Z0ol007l2oookJP[oiOl000?o
oo]Zo`3o8Ol0ob401_oonfX01Ooo0?;ooo]ZoookJ_oonf[o0?mF00?ooo]Z00Ooo`2PoookJ_oonf[o
oo]Zoe@0oooonf[o02Go00Gooo]Z00?o:P3oool:0?oonfX01OoonfX01_mko`3ooo]ZoookJ_oonf[o
oi`0oom100Gooo]Z00?o0?lho`P0oooonfX03?oonfX00ooo803ooo]ZoookJP03oookJP03ool0]Ooo
nf[ooo]Z013ooo]Z00?o0?neoookJ_oonfX01_oonfX00ol0oh_ooo]ZoookJP0FoookJP05ool0Cooo
nf[ooo]ZoookJ_l0oiH02?oonfX01Ooo703ooo]ZoookJ_oonf[o^?l0013ooo]Z00?oolT0oookJ_oM
o`000_oonfX00ol[0?oooo]ZoookJP04oookJP04oonK0?oo003ooo]Zonco00Kooo]Z00?oT`3ooook
J_oonfX01ooonfX00ooo]`3oE`3ooookJP04oookJP03ool0g?oonf[ooo]Z00;ooo]Z00?oolT0oook
J_oonfX00ooonfX00oo]0?oooo]ZoookJP17oookJP;oo`3f4_oonfX3o`3o_P;ooo]Z0_mJo`0:oook
JP;oh_l0H?oonfX4on;o00[ooo]Z0_mJo`03o`3o_PKooo]Z0ol007l2ool0mP03o`00Ool00ooo00?o
00;o001o0_oonfX3o`00O`03oookJ_l0odSo0?m800?o001o1OoonfX2o`3oM`;ooo]Z00Co001oogT0
oomi0?ooobL00_nGo`07oookJP?o001o0ooonfX00ol0X_oooo]Zoono0002o`000005o`2<ool0oj;o
0000o`000?oonfX00_l0ob46oookJP05ool0l_oonf[ooo]ZoookJ_l0oeH01?oonfX01ooo0:3ooo]Z
oookJ_oonf[oE03ooookJ_l09Ol01?oonfX00olZ0?oo04coool:0005oookJP03og_o0?oonf[ooo]Z
00;ooo]Z00?ood40oookJ_oonfX00ooonfX00ol0ocSooo]Zo`P0o`0=oookJP03oolP0?oonf[ooo]Z
00?ooo]Z00?oo`2eoookJ_oonfX04?oonfX00ol0okGooo]ZoookJP05oookJP03o`3oRooonf[ooo]Z
01Kooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP08oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0
oookJ_oonfX03OoonfX01?oBo`3ooo]ZoookJ_oMo`02oookJP03ob/0oooonf[ooo]Z00Cooo]Z00Co
oi/0ool00?oo0:Wok?l01_oonfX00onC0?oooo]ZoookJP06oookJP03oong0?mG0?oooo]Z00Cooo]Z
00?oo`3LoookJ_oonfX00ooonfX00onMo`3ooo]ZoookJP02oookJP03ond0oooonf[ooo]Z02Cooo]Z
000VoookJP03ool0m_oonf[ooo]Z00kooo]Z00?o0?nnooo90?oob@002Ooob@06oookJP?oh_l0IOoo
nfX4on;o00Sooo]Z0omJo`001?oonf[o0?nno`3o__l0okh8oookJP;oo`3f00?ooo]Zo`03ool00ol0
0_oonfX3o`00O`?ooo]Z0_l0odP00ol007oooo]ZoookJP04oookJP;o0?mg00Cooo]Zo`00Ool007oo
001o0_mi0?l2oiOo00Kooo]Z0ol007l3oookJP03o`2RoooUo`3oiOl000KoiOl00ooonfX00ol0ob7o
oo]ZoookJP04oookJP05ool0l_oonf[ooo]ZoookJ_l0oeH00ooonfX01ooo0:3ooo]ZoookJ_oonf[o
E03ooookJ_l09Ol01?oonfX00olZ0?oo04coool:0006oookJP06og_o0?oonf[ooo]ZoookJ_ooW03o
od401OoonfX00ol0ocSo203ooookJP0;oookJP03oolP0?oonf[ooo]Z00Cooo]Z00?oo`2eoookJ_oo
nfX04?oonfX00ol0okGooo]ZoookJP06oookJP03o`3oRooonf[ooo]Z01Kooo]Z00Coo`1?oookJ_oo
nf[o0?nF2?oonfX00ooo703ooo]ZoookJP02oookJP03okSo0?oonf[ooo]Z00gooo]Z00CoolT0oook
J_oonf[ogOl00_oonfX00ol[0?oooo]ZoookJP03oookJP05oonK0?oo003ooo]Zool0ZOo/o`001_oo
nfX00onC0?oooo]ZoookJP06oookJP03oong0?oonf[oE`3o00Cooo]Z00?oo`3LoookJ_oonfX00ooo
nfX00ooob@3ooo]ZoookJP02oookJP03ond0oooonf[ooo]Z04Kooo]Z00?oo`3foookJ_oonfX03ooo
nfX3o`3o_P;ooo]Z0omJo`09oookJP?oh_l0I_oonfX4on;o00Sooo]Z0omJo`03o`3o_PSooo]Z0_oo
0?H00ooonf[o00?oo`03o`02oookJP?o001o0ooonfX2o`3oB003o`00Oooonf[ooo]Z00Gooo]Z00?o
0?mgoookJ_l007l00_l007l2ogT0o`03oolW0?nGo`3oUol000Gooo]Z0ol007l4oookJP06o`2Roooo
nf[ookl0oono0?l0003o08co0_l0oj83oookJP03o`3o8Ooonf[ooo]Z00Cooo]Z0_oo0?82oookJP03
o`3oE_oonf[ooo]Z00;ooo]Z00Ooo`2PoookJ_oonf[ooo]Zoe@0oooonf[o02Go00?ooo]Z00Co:P3o
oookJ_l0C?ooo`X01OoonfX00omko`3ooo]ZoookJP02oookJP03oom10?oonf[ooo]Z00?ooo]Z00?o
0?lhoookJ_l80?l03?oonfX00ooo803ooo]ZoookJP03oookJP03ool0]Ooonf[ooo]Z017ooo]Z00?o
0?neoookJ_oonfX01OoonfX00ol0oh_ooo]ZoookJP0FoookJP04ool0Cooonf[ooo]Zo`3oUPWooo]Z
00?ooa`0oookJ_oonfX00_oonfX00onho`3ooo]ZoookJP0=oookJP03om;o0?oonf[ogOl000;ooo]Z
00?o:`3ooookJ_oonfX01?oonfX01?ooV`3oo`00oookJ_o/o`07oookJP03oi<0oooonf[ooo]Z00Go
oo]Z00?ookL0oookJ_mG0?l01?oonfX00ooo0=cooo]ZoookJP04oookJP03oigo0?oonf[ooo]Z00;o
oo]Z00?ok@3ooookJ_oonfX08ooonfX002Gooo]Z00?oo`3foookJ_oonfX03?oonfX3o`3o_P;ooo]Z
2Ooob@05oookJP;oh_l0K?oonfX5on;o00Kooo]Z0_mJo`02oookJP;o0?nn2?oonfX2ool0mP04oook
J_l00ooo00?oo`03o`;o001o0ooonfX2o`00O`?o0?m81_oonfX2o`3oM`;o001o0_oonfX2ogT0o`;o
Uol000?o001ooookJ_oonfX01?l007l5oookJP03o`2Rool0003oiOl000GoiOl00ooonfX00ol0ob7o
oo]ZoookJP04oookJP05ool0l_oonf[ooo]ZoookJ_l0oeH00ooonfX01ooo0:3ooo]ZoookJ_oonf[o
E03ooookJ_l09Ol01?oonfX00olZ0?oo04coool:0006oookJP05og_o0?oonf[ooo]ZoookJ_oo@@00
1_oonfX00ol0ocSo203ooookJP0;oookJP03oolP0?oonf[ooo]Z00Cooo]Z00?oo`2eoookJ_oonfX0
4?oonfX00ol0okGooo]ZoookJP05oookJP03o`3oRooonf[ooo]Z01Kooo]Z00Goo`1?oookJ_oonf[o
oo]Zo`3oUP08oookJP05oolL0?oonf[ooo]ZoookJ_nho`003ooonfX01?oob@3ooo]ZoookJ_oMo`02
oookJP03ob/0oooonf[ooo]Z00Cooo]Z00Coo`00oookJ_oonf[ok?l01_oonfX00onC0?oooo]Zoook
JP06oookJP03oong0?oonf[oE`3o00Gooo]Z00?oo`3LoookJ_oonfX00_oonfX00ooob@3ooo]Zoook
JP03oookJP03ond0oooonf[ooo]Z04Cooo]Z00?oo`3foookJ_oonfX03OoonfX3o`3o_P?ooo]Z0_mJ
o`0:oookJP;oh_l0KOoonfX5on;o00Kooo]Z0_mJo`000ooonf[o0?nno`3o_P08oookJP;oo`3f00Co
oo]Zo`03ool00ooo00?o0_l007l3oookJP;o001o0ol0odP6oookJP;o0?mg0_l007l2oookJP;oN@3o
00?ooo]ZoiOo0?nGo`000_oonfX4o`00O`Gooo]Z0_l0X_l00ol0003ookl0o`000002o`2<o`05o`3o
X_oonf[ooo]ZoookJ_l0ob401ooonfX01?oo0?;ooo]ZoookJ_l0oeH4oookJP07ool0X?oonf[ooo]Z
oookJ_mD0?oooo]Zo`0Uo`03oookJP04obX0oooonf[o04coool:00Gooo]Z00?oNol0oookJ_oonfX0
0_oonfX00ooo@@3ooo]ZoookJP03oookJP03o`3o>?oonf[o203o00cooo]Z00?oob00oookJ_oonfX0
0ooonfX00ooo0;Gooo]ZoookJP0AoookJP03o`3o]Ooonf[ooo]Z00Gooo]Z00?o0?n;oookJ_oonfX0
5OoonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Wooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000?oook
JP04om;o0?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX01?oonfX01?oo003ooo]Zool0ZOo/
o`06oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?ookL0oeL0oooonfX01?oonfX00ooo0=cooo]Zoook
JP03oookJP03oigo0?oonf[ooo]Z00;ooo]Z00?ok@3ooookJ_oonfX08ooonfX0037ooo]Z0ol0okh5
oookJPOoolT01OoonfX2on;o07?ooo]Z00?oh_l0onGo0?oUo`001OoonfX3oe[o0004oookJ_l0okko
0?nno`3o_POooo]Z0ooo0?H00ol007oo00?oo`03o`03oookJP?o001o0_oonfX2o`3oB0Kooo]Z00?o
0?mgo`00Ool007l00ooonfX01?mi0?ooobL0oiOo0?nGo`04o`00O`Oooo]Z0_l0X_l00ooo_`3oiOl0
onGo0003onGo00?ooo]Z00?o0?lQoookJ_oonfX01?oonfX2ool0lP03oookJ_l0oeKooo]Z00?ooo]Z
0_oo0:02oookJP03oe@0oooonf[o02Go00Cooo]Z00?o:P3oo`1<oooo2P001_oonfX01Omko`3ooo]Z
oookJ_oonf[ood4000Gooo]Z00?o0?lhoookJ_l80?l03?oonfX00ooo803ooo]ZoookJP04oookJP03
ool0]Ooonf[ooo]Z00oooo]Z00?o0?neoookJ_oonfX01_oonfX00ol0oh_ooo]ZoookJP0FoookJP05
ool0Cooonf[ooo]ZoookJ_l0oiH01ooonfX00ooo703ooo]ZoookJP02oookJP03okSo0?oonf[ooo]Z
00gooo]Z00CoolT0oookJ_oonf[ogOl00_oonfX00ol[0?oooo]ZoookJP03oookJP05oonK0?oo003o
oo]Zool0ZOo/o`001_oonfX00onC0?oooo]ZoookJP06oookJP03oong0?oonf[oE`3o00Cooo]Z00?o
o`3LoookJ_oonfX00_oonfX00ooob@3ooo]ZoookJP03oookJP03ond0oooonf[ooo]Z057ooo]Z0ol0
okh4oookJP;oF_l02_oonfX2on;o07Cooo]Z0ooRo`05oookJP?oF_l00ol0okh7oookJP?oo`3f00?o
001oo`03ool00ol00ooonfX3o`00O`;ooo]Z0_l0odP6oookJP03o`3oMol007oo001o00?ooo]Z00?o
N@3ooolW0?l007l00_nGo`03o`00O`Oooo]Z00Co0000o`2Rool0003ookl00_oonfX00ol0S?oo0?nR
oookJP02oookJP03o`3o8Ooonf[ooo]Z00Gooo]Z00?oo`3boookJ_l0oeH01OoonfX2ool0X0;ooo]Z
00?oE03ooookJ_l09Ol00ooonfX01?lZ0?oooo]Zo`1<oooo2P05oookJP03og_o0?oonf[ooo]Z00;o
oo]Z00?ood40oookJ_oonfX00_oonfX01?l0ocSooo]ZoookJ_l80?l<oookJP03oolP0?oonf[ooo]Z
00?ooo]Z00?oo`2eoookJ_oonfX04?oonfX00ol0okGooo]ZoookJP05oookJP03o`3oRooonf[ooo]Z
01Kooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP08oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0
oookJ_oonfX03OoonfX00ooBo`3ooo]Zomgo0002oookJP03ob/0oooonf[ooo]Z00Cooo]Z00Cooi/0
ool00?oonf[ok?l01ooonfX00onC0?oooo]ZoookJP05oookJP03oong0?oonf[oE`3o00Cooo]Z00?o
o`3LoookJ_oonfX00ooonfX00onMo`3ooo]ZoookJP03oookJP03ond0oooonf[ooo]Z02;ooo]Z000^
oookJP?o0?nn1_oonfX2ooo90003oookJ_oob@3oolT000?oolT01?oonfX2on;o07Sooo]Z0ooUo`05
oookJP?oF_l000?ooo]Zo`3o__l0okh02?oonfX2ool0mP04o`00Ool00ooo00?ooookJP?o001o1?oo
nfX2o`3oB0Gooo]Z0_l0ogL4oookJP;oN@3o00CoobL0oiOo0?l007oo001o2?oonfX2o`000003o`2R
oooo_`3ookl000CoiOl00ooonfX2o`3o8@Kooo]Z00?oo`3boookJ_l0oeH01OoonfX01_oo0:3ooo]Z
oookJ_mD0?oooo]Zo`0Uo`Cooo]Z00?o:P3oo`1<oooo2P001_oonfX01Omko`3ooo]ZoookJ_oonf[o
od4000Gooo]Z00?o0?lhoookJ_l80?l03?oonfX00ooo803ooo]ZoookJP04oookJP03ool0]Ooonf[o
oo]Z00oooo]Z00?o0?neoookJ_oonfX01OoonfX00ol0oh_ooo]ZoookJP0FoookJP05ool0Cooonf[o
oo]ZoookJ_l0oiH02?oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000oooo]Z00CoolT0oookJ_oonf[o
gOl00_oonfX00ol[0?oooo]ZoookJP04oookJP04ool00?oonf[ooo]Zonco00Kooo]Z00?oT`3ooook
J_oonfX01_oonfX00ooo]`3ooo]ZoeL0o`05oookJP03ool0g?oonf[ooo]Z00;ooo]Z00?oolT0oook
J_oonfX00_oonfX00oo]0?oooo]ZoookJP1>oookJP?o0?nn1OoonfX2oe[o00[ooo]Z0_oRo`1ioook
JP?oh_l01OoonfX3oe[o00;o0?nn2?oonfX2ool0mP04o`00Ool00ooo00?ooookJP?o001o1?oonfX2
o`3oB0Gooo]Z0_l0ogL4oookJP;oN@3o00CoobL0o`00OonGo`3o001o2?oonfX2o`0000;o0:;o00Co
okl0oookJ_oonf[o08co0_l0oj82oookJP;o0?lQ1_oonfX00ooo0?;ooo]Zo`3oEP06oookJP06ool0
X?oonf[ooo]Zoe@0oooonf[o02Go0ooonfX01?lZ0?oooo]Zo`1<oooo2P05oookJP03og_o0?oonf[o
oo]Z00;ooo]Z00?ood40oookJ_oonfX00_oonfX01?l0ocSooo]ZoookJ_l80?l<oookJP03oolP0?oo
nf[ooo]Z00?ooo]Z00?oo`2eoookJ_oonfX04?oonfX00ol0okGooo]ZoookJP05oookJP03o`3oRooo
nf[ooo]Z01Gooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP09oookJP05oolL0?oonf[ooo]ZoookJ_nh
o`003ooonfX01?oBo`3ooo]ZoookJ_oMo`02oookJP03ob/0oooonf[ooo]Z00Cooo]Z00Coo`00oook
J_oonf[ok?l01_oonfX00onC0?oooo]ZoookJP06oookJP03oong0?mG0?oooo]Z00Cooo]Z00?oo`3L
oookJ_oonfX00ooonfX00onMo`3ooo]ZoookJP02oookJP03ond0oooonf[ooo]Z02;ooo]Z000/oook
JP;o0?nn1ooonfX2ooo900?ooo]Z1?oob@02oookJP?oh_l0OOoonfX2onGo00Kooo]Z0_mJo`000ooo
nf[o0?nno`3o_P06oookJP;o001o0_oo0?H00ooonf[o00?oo`03o`02o`00O`Kooo]Z0_l0odP4oook
JP03o`00Ool0ogOooo]Z00;ooo]Z0_l007l2ogT0o`;oUol02?oonfX3o`000003o`2Roooonf[ookl0
00;ooo]Z0_oUo`04oookJP03o`3o8Ooonf[ooo]Z00Cooo]Z00?oo`3boookJ_l0oeH01OoonfX01_oo
0:3ooo]ZoookJ_mD0?oooo]Zo`0Uo`Cooo]Z00?o:P3oo`1<oooo2P001OoonfX00omko`3ooo]Zoook
JP02oookJP03oom10?oonf[ooo]Z00?ooo]Z00?o0?lhoookJ_l80?l02ooonfX00ooo803ooo]Zoook
JP05oookJP03ool0]Ooonf[ooo]Z00oooo]Z00?o0?neoookJ_oonfX01OoonfX00ol0oh_ooo]Zoook
JP0FoookJP05ool0Cooonf[ooo]ZoookJ_l0oiH02?oonfX01?oo703ooo]ZoookJ_nho`0@oookJP04
ooo90?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX00ooonfX01OooV`3oo`00oookJ_oo0:Wo
k?l000Kooo]Z00?oT`3ooookJ_oonfX01_oonfX00ooo]`3oE`3ooookJP04oookJP03ool0g?oonf[o
oo]Z00;ooo]Z00?oolT0oookJ_oonfX00ooonfX00oo]0?oooo]ZoookJP1;oookJP;o0?nn1_oonfX2
oe[o00Wooo]Z0ooRo`1noookJP;oh_l01_oonfX2oe[o00;o0?nn1_oonfX2o`00O`;oo`3f00?ooo]Z
o`03ool00ol00_l007l6oookJP;o0?m81?oonfX00ol007oo0?mgo`3oM`02oookJP;o001o0_mi0?l0
0ooonf[oUol0oiOo0007oookJPCo000000Oo0:;ooono0?oo_`3ooo]Zo`2<oooonf[o0?nR00?ooo]Z
00?o0?lQoookJ_oonfX01?oonfX00ooo0?;ooo]Zo`3oEP06oookJP06ool0X?oonf[ooo]Zoe@0oooo
nf[o02Go0ooonfX01?lZ0?oooo]Zo`1<oooo2P04oookJP03og_o0?oonf[ooo]Z00?ooo]Z00?ood40
oookJ_oonfX00_oonfX01?l0ocSooo]ZoookJ_l80?l;oookJP03oolP0?oonf[ooo]Z00Cooo]Z00?o
o`2eoookJ_oonfX04?oonfX00ol0okGooo]ZoookJP05oookJP03o`3oRooonf[ooo]Z01Gooo]Z00Go
o`1?oookJ_oonf[ooo]Zo`3oUP09oookJP04oolL0?oonf[ooo]ZokSo013ooo]Z00?od_l0oookJ_oM
o`000_oonfX00ol[0?oooo]ZoookJP04oookJP04oonK0?oo003ooo]Zonco00Oooo]Z00?oT`3ooook
J_oonfX01OoonfX00ooo]`3oE`3ooookJP04oookJP03ool0g?oonf[ooo]Z00?ooo]Z00?oWOl0oook
J_oonfX00_oonfX00oo]0?oooo]ZoookJP0RoookJP00:ooonfX00ol0okkooo]ZoookJP05oookJP;o
olT01OoonfX3ooo90003oookJ_oRo`3oh_l008;ooo]Z0ooUo`05oookJP?oF_l00ol0okh4oookJP?o
001o0_oo0?H00ol007oo00?oo`03o`08oookJP;o0?m80_oonfX2o`00O`;o0?mg00?ooo]Zo`00Ool0
07l00_oonfX01?mi0?ooobL0oiOo0?nGo`06oookJPCo00000_l0X_l01_oo_`3ooo]ZoookJ_l0S?oo
iOl0o`3oXP?ooo]Z00?o0?lQoookJ_oonfX01?oonfX2ool0lP03o`3oE_oonf[ooo]Z00?ooo]Z00Ko
o`2PoookJ_oonf[oE03ooookJ_l09Ol4oookJP03obX0oooo2P3ooo]Z00Gooo]Z00?oNol0oookJ_oo
nfX00_oonfX00ooo@@3ooo]ZoookJP03oookJP03o`3o>?oonf[o203o00_ooo]Z00?oob00oookJ_oo
nfX01?oonfX00ooo0;Gooo]ZoookJP0?oookJP03o`3o]Ooonf[ooo]Z00Kooo]Z00?o0?n;oookJ_oo
nfX05OoonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Sooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000?
oookJP04ooo90?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX01?oonfX01?oo003ooo]Zoook
J_o/o`06oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?ookL0oookJ_mG0?l01?oonfX00ooo0=cooo]Z
oookJP03oookJP03ooo90?oonf[ooo]Z00;ooo]Z00?ok@3ooookJ_oonfX0B_oonfX00ol0okkooo]Z
oookJP04oookJP;oF_l02OoonfX2on;o08?ooo]Z0_oRo`06oookJP?oF_l00_l0okh4oookJP?o001o
0_oo0?H00ol007oo00?oo`03o`08oookJP;o0?m80_oonfX2o`00O`03oookJ_l0ogOooo]Z00;o001o
0_oonfX00omi0?ooobL0oookJP02oiOo00Gooo]Z1?l000001Ooonf[o0:;oo`2Roooo_`3ooo]Z00;o
08co0_l0oj82oookJP03o`3o8Ooonf[ooo]Z00Cooo]Z0_oo0?800ol0oeKooo]ZoookJP04oookJP06
ool0X?oonf[ooo]Zoe@0oooonf[o02Go0ooonfX00olZ0?oooo]Zool:0005oookJP03og_o0?oonf[o
oo]Z00?ooo]Z00?ood40oookJ_oonfX00_oonfX01?l0ocSooo]ZoookJ_l80?l;oookJP03oolP0?oo
nf[ooo]Z00?ooo]Z00?oo`2eoookJ_oonfX04?oonfX00ol0okGooo]ZoookJP05oookJP03o`3oRooo
nf[ooo]Z01Gooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP09oookJP05oolL0?oonf[ooo]ZoookJ_nh
o`003ooonfX01?oBo`3ooo]ZoookJ_oMo`02oookJP03ob/0oooonf[ooo]Z00Cooo]Z00Coo`00oook
J_oonf[ok?l01_oonfX00onC0?oooo]ZoookJP06oookJP03oong0?mG0?oooo]Z00Cooo]Z00?oo`3L
oookJ_oonfX00ooonfX00onMo`3ooo]ZoookJP02oookJP03ond0oooonf[ooo]Z027ooo]Z000Zoook
JP03o`3o__oonf[ooo]Z00Cooo]Z0_oob@08oookJP03ooo90?oRo`3oh_l008Oooo]Z0_oUo`06oook
JP;oF_l000?oiOl0o`3o__l0okh00_oonfX5o`00O`;oo`3f00Cooo]Zo`03ool00ooo00?o0ooonfX4
o`00O`03o`3oB?l007oo001o00;o001o00?ooo]Zo`3oMooonfX01?l007l01?mi0?ooobL0oolW0?nG
o`05oookJPCo00000_oonfX00ol0X_oookl0oono0002oookJP03o`2<ool0oj;ooo]Z00;ooo]Z00?o
0?lQoookJ_oonfX01OoonfX00ooo0?;o0?mFoookJP04oookJP06ool0X?oonf[ooo]Zoe@0oooonf[o
02Go1?oonfX00olZ0?ooo`X0oookJP05oookJP03og_o0?oonf[ooo]Z00;ooo]Z00?ood40oookJ_oo
nfX00_oonfX01?l0ocSooo]ZoookJ_oUo`0;oookJP03oolP0?oonf[ooo]Z00Cooo]Z00?oo`2eoook
J_oonfX03ooonfX00ol0okGooo]ZoookJP05oookJP03o`3oRooonf[ooo]Z01Kooo]Z00Goo`1?oook
J_oonf[ooo]Zo`3oUP08oookJP04oolL0?oonf[ooo]ZokSo013ooo]Z00CoolT0oookJ_oonf[ogOl0
0_oonfX00ol[0?oooo]ZoookJP03oookJP04oonK0?oo003ooo]Zonco00Oooo]Z00?oT`3ooookJ_oo
nfX01_oonfX00ooo]`3oE`3ooookJP04oookJP03ool0g?oonf[ooo]Z00;ooo]Z00?oolT0oookJ_oo
nfX00_oonfX00oo]0?oooo]ZoookJP18oookJP;o0?nn1OoonfX2oe[o00Wooo]Z0_oRo`27oookJP?o
h_l01_oonfX2oe[o00;o0?nn0_oonfX5o`00O`;oo`3f00Cooo]Zo`03ool00ooo00?o0ooonfX4o`00
O`03o`3oB?l007oo001o00;o001o00?ooo]Zo`3oMol0ogL01?l007l01Omi0?ooobL0oolW0?oonf[o
Uol000Cooo]Z1?l00003oookJP07o`2Roooo_`3ooo]ZoookJ_l0S?oooo]Zo`3oXP02oookJP03o`3o
8Ooonf[ooo]Z00Gooo]Z00?oo`3bo`3oE_oonfX01OoonfX01_oo0:3ooo]ZoookJ_mD0?oooo]Zo`0U
o`?ooo]Z00?o:P3ooookJ_oo2P001OoonfX00omko`3ooo]ZoookJP03oookJP05oom10?oonf[ooo]Z
oookJ_l0ocP00ooonfX00ol80?oooo]ZoookJP09oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?oo`2e
oookJ_oonfX04?oonfX00ol0okGooo]ZoookJP05oookJP03o`3oRooonf[ooo]Z01Gooo]Z00Goo`1?
oookJ_oonf[ooo]Zo`3oUP09oookJP04oolL0?oonf[ooo]ZokSo00oooo]Z00Cod_l0oookJ_oonf[o
gOl00_oonfX00ol[0?oooo]ZoookJP04oookJP04oonK0?oo003ooo]Zonco00Oooo]Z00?oT`3ooook
J_oonfX01OoonfX00ooo]`3oE`3ooookJP04oookJP03ool0g?oonf[ooo]Z00?ooo]Z00?oWOl0oook
J_oonfX00_oonfX00oo]0?oooo]ZoookJP0QoookJP00:?oonfX2o`3o_PGooo]Z0_oob@09oookJP;o
h_l0RooonfX3onGo00Gooo]Z0omJo`02o`3o_P03oookJ_l007oo001o00?o001o00Gooo]Zool0m_oo
0?Koo`3foookJP02o`03o`03oookJ_l007oo001o00?o001o0_l0odP2o`00O`;ooo]Z0_l0ogL4o`00
O`;oN@3o00?oobL0oiOo0?oonfX00ooonfX4o`0000?ooo]Z0_l0X_l01Ooo_`3ooo]ZoookJ_l0S?oo
0?nR00?ooo]Z00?o0?lQoookJ_oonfX01OoonfX00ooo0?;o0?mFoookJP04oookJP06ool0X?oonf[o
oo]Zoe@0oooonf[o02Go1?oonfX00olZ0?ooo`X0oookJP05oookJP03og_o0?oonf[ooo]Z00;ooo]Z
00?ood40oookJ_oonfX00_oonfX00ol0ocSooo]ZonGo000;oookJP03oolP0?oonf[ooo]Z00Gooo]Z
00?oo`2eoookJ_oonfX03ooonfX00ol0okGooo]ZoookJP05oookJP03o`3oRooonf[ooo]Z01Gooo]Z
00Goo`1?oookJ_oonf[ooo]Zo`3oUP08oookJP05oolL0?oonf[ooo]ZoookJ_nho`003ooonfX01?oo
b@3ooo]ZoookJ_oMo`02oookJP03ob/0oooonf[ooo]Z00Cooo]Z00Coo`00oookJ_oonf[ok?l01_oo
nfX00onC0?oooo]ZoookJP06oookJP03oong0?mG0?oooo]Z00Cooo]Z00?oo`3LoookJ_oonfX00_oo
nfX00ooob@3ooo]ZoookJP03oookJP03ond0oooonf[ooo]Z04Kooo]Z00?o0?nnoookJ_oonfX00ooo
nfX2oe[o00Wooo]Z0_oRo`2<oookJP;oh_l01_oonfX3oe[o0003o`3o__oonf[o001o00Co001o00Go
oo]Zool0m_oo0?Koo`3foookJP02o`03o`03oookJ_l007oo001o00?o001o0_l0odP2o`00O`?ooo]Z
00?o0?mgo`00Ool007l00_l007l2ogT0o`03oolW0?oonf[oUol000?ooo]Z1?l00004oookJP07o`2R
oooo_`3ooo]ZoookJ_l0S?oooo]Zo`3oXP02oookJP03o`3o8Ooonf[ooo]Z00Gooo]Z00?oo`3bo`3o
E_oonfX01OoonfX01_oo0:3ooo]ZoookJ_mD0?oooo]Zo`0Uo`?ooo]Z00?o:P3ooookJ_oo2P001Ooo
nfX00omko`3ooo]ZoookJP03oookJP05oom10?oonf[ooo]ZoookJ_l0ocP00_oonfX00ol80?oooo]Z
oookJP09oookJP03oolP0?oonf[ooo]Z00Cooo]Z00?oo`2eoookJ_oonfX04?oonfX00ol0okGooo]Z
oookJP05oookJP03o`3oRooonf[ooo]Z01Cooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP09oookJP05
oolL0?oonf[ooo]ZoookJ_nho`003ooonfX01?oBo`3ooo]ZoookJ_oMo`02oookJP03ob/0oooonf[o
oo]Z00Cooo]Z00Coo`00oookJ_o/o`3oo`2Y1_oonfX00onC0?oooo]ZoookJP06oookJP03oeL0oooo
nf[ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX00ooonfX00onMo`3ooo]ZoookJP02oookJP03ond0oooo
nf[ooo]Z027ooo]Z000WoookJP03o`3o__oonf[ooo]Z00;ooo]Z0ooob@08oookJP?oh_l0T?oonfX2
onGo00;ooo]Z1?oUo`02oe[o00;o0?nn2?oonfX2ool0mP03oookJ_l00ooo00?o00Kooo]Z00?o0?m8
oookJ_oonfX00ooonfX00ol0ogOooo]ZoookJP03oookJP03ogT0oooo9`3oUol000?ooo]Z1?l00005
oookJP06o`2Roooo_`3ooo]ZoookJ_l0S?oo0?nR0ooonfX2o`3o8@Kooo]Z00?oo`3bo`3oE_oonfX0
1?oonfX01_oo0:3ooo]ZoookJ_mD0?oooo]Zo`0Uo`Cooo]Z00?o:P3oool:0?oonfX01OoonfX00omk
o`3ooo]ZoookJP02oookJP03oom10?oonf[ooo]Z00;ooo]Z00?o0?lhoookJ_oUo`002ooonfX00ooo
803ooo]ZoookJP05oookJP03ool0]Ooonf[ooo]Z00oooo]Z00?o0?neoookJ_oonfX01OoonfX00ol0
oh_ooo]ZoookJP0EoookJP05ool0Cooonf[ooo]ZoookJ_l0oiH02?oonfX01?oo703ooo]ZoookJ_nh
o`0?oookJP05ooo90?oonf[ooo]ZoookJ_oMo`000_oonfX00ol[0?oooo]ZoookJP03oookJP04oonK
0?oo003ooo]Zonco00Oooo]Z00?oT`3ooookJ_oonfX01_oonfX00ooo]`3oE`3ooookJP03oookJP03
ool0g?oonf[ooo]Z00?ooo]Z00?oolT0oookJ_oonfX00_oonfX00oo]0?oooo]ZoookJP14oookJP;o
0?nn0ooonfX3oe[o00Sooo]Z0ooRo`2@oookJP?oh_l01_oonfX2oe[o0003o`3o__oonf[ooo]Z00Ko
oo]Z0_oo0?H00ooonf[o00?oo`03o`06oookJP03o`3oB?oonf[ooo]Z00?ooo]Z0_l0ogL4oookJP04
ogT0oooo9`3oobL0oiOo00;ooo]Z1?l00005oookJP07o`2Roooo_`3ookl0oookJ_l0S?oooo]Zo`3o
XP02oookJP;o0?lQ1_oonfX00ooo0?;o0?mFoookJP05oookJP06ool0X?oonf[ooo]Zoe@0oooonf[o
02Go0ooonfX00olZ0?oooo]Zool:0005oookJP03og_o0?oonf[ooo]Z00?ooo]Z00Good40oookJ_oo
nf[ooo]Zo`3o>002oookJP03o`P0oooonf[ooo]Z00Wooo]Z00?oob00oookJ_oonfX01?oonfX00ooo
0;Gooo]ZoookJP0@oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX05OoonfX01Ooo
04oooo]ZoookJ_oonf[o0?nF00Wooo]Z00Cooa`0oookJ_oonf[o^?l03ooonfX01?oBo`3ooo]Zoook
J_oMo`02oookJP03ob/0oooonf[ooo]Z00Cooo]Z00Cooi/0ool00?oonf[ok?l01ooonfX00onC0?oo
oo]ZoookJP05oookJP03oong0?mG0?oooo]Z00Cooo]Z00?oo`3LoookJ_oonfX00ooonfX00onMo`3o
oo]ZoookJP02oookJP03ond0oooonf[ooo]Z023ooo]Z000VoookJP04o`3o__oonf[ooo]ZoookJP;o
olT02OoonfX2on;o09Gooo]Z2?oUo`03oe[o00;o0?nn1ooonfX2ool0mP03oookJ_l00ooo00?o00Go
oo]Z0_l0odP4oookJP;o0?mg1?oonfX01Omi0?oooo]ZoiOo0?nGo`3ooo]Z00Go00001OoonfX01_l0
X_oookl0oookJ_oonf[o08coo`3oXPCooo]Z00?o0?lQoookJ_oonfX01?oonfX00ooo0?;o0?mFoook
JP04oookJP06ool0X?oonf[ooo]Zoe@0oooonf[o02Go1?oonfX00olZ0?ooo`X0oookJP05oookJP03
og_o0?oonf[ooo]Z00;ooo]Z00?ood40oookJ_oonfX00_oonfX00ol0ocSooo]ZonGo000;oookJP03
oolP0?oonf[ooo]Z00Gooo]Z00?oo`2eoookJ_oonfX03_oonfX00ol0okGooo]ZoookJP05oookJP03
o`3oRooonf[ooo]Z01Gooo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP05oookJP05
oolL0?oonf[ooo]ZoookJ_nho`003ooonfX01?oob@3ooo]ZoookJ_oMo`03oookJP03ob/0oooonf[o
oo]Z00?ooo]Z00Coo`00oookJ_oonf[ok?l01_oonfX00onC0?oooo]ZoookJP06oookJP03oong0?mG
0?oooo]Z00Cooo]Z00?oo`3LoookJ_oonfX00_oonfX00ooob@3ooo]ZoookJP02oookJP03ond0oooo
nf[ooo]Z04?ooo]Z00Co0?nnoookJ_oonf[ooo]Z0_mJo`09oookJP;oh_l0U_oonfX2on;o00Kooo]Z
0omJo`000ol0okkooo]ZoookJP05oookJP;oo`3f00?ooo]Zo`03ool00ol01OoonfX2o`3oB0Gooo]Z
0_l0ogL3oookJP;oN@3o00?oobL0oiOo0?oonfX01Ol00006oookJP06o`2Roooo_`3ooo]Zo`2<oooo
nf[o0?nR0ooonfX00ol0ob7ooo]ZoookJP04oookJP03ool0l_l0oeKooo]Z00Gooo]Z00Koo`2Poook
J_oonf[oE03ooookJ_l09Ol3oookJP03obX0oooonf[oo`X000Gooo]Z00?oNol0oookJ_oonfX00ooo
nfX01Ooo@@3ooo]ZoookJ_oonf[o0?lh00;ooo]Z00?o203ooookJ_oonfX02OoonfX00ooo803ooo]Z
oookJP04oookJP03ool0]Ooonf[ooo]Z00oooo]Z00?o0?neoookJ_oonfX01OoonfX00ol0oh_ooo]Z
oookJP0DoookJP03ool0Cooonf[ooo]Z00;ooo]Z00?o0?nFoookJ_oonfX01_oonfX01Ooo703ooo]Z
oookJ_oonf[o^?l000oooo]Z00Cod_l0oookJ_oonf[ogOl00_oonfX00ol[0?oooo]ZoookJP04oook
JP04ool00?oonf[ok?l0ool0Z@Kooo]Z00?oT`3ooookJ_oonfX01OoonfX00ooo]`3oE`3ooookJP04
oookJP03ool0g?oonf[ooo]Z00?ooo]Z00?oWOl0oookJ_oonfX00_oonfX00oo]0?oooo]ZoookJP0P
oookJP009OoonfX00ol0okkooo]ZoookJP02ooo900Wooo]Z0_oRo`1`oookJP;oiOl09_oonfX9onGo
0003oookJ_mJo`3oF_l000;o0?nn1ooonfX2ool0mP03oookJ_l00ooooo]Z00Gooo]Z00?o0?m8oook
J_oonfX00ooonfX00ol0ogOooo]ZoookJP02oookJP;oN@3o00?oobL0oiOo0?l000000ol00007oook
JP06o`2Roooo_`3ookl0oookJ_l0S?oo0?nR1?oonfX00ol0ob7ooo]ZoookJP03oookJP03ool0l_oo
nf[o0?mF00Gooo]Z00Koo`2PoookJ_oonf[oE03ooookJ_l09Ol3oookJP03obX0oooonf[oo`X000Ko
oo]Z00?oNol0oookJ_oonfX00_oonfX00ooo@@3ooo]ZoookJP02oookJP03o`3o>?oonf[oiOl000_o
oo]Z00?oob00oookJ_oonfX01OoonfX00ooo0;Gooo]ZoookJP0>oookJP03o`3o]Ooonf[ooo]Z00Go
oo]Z00?o0?n;oookJ_oonfX05OoonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Oooo]Z00Gooa`0oook
J_oonf[ooo]ZokSo000?oookJP05ooo90?oonf[ooo]ZoookJ_oMo`000_oonfX00ol[0?oooo]Zoook
JP03oookJP04oonK0?oo003ooo]Zonco00Oooo]Z00?oT`3ooookJ_oonfX01_oonfX00omG0?oooo]Z
oookJP03oookJP03ool0g?oonf[ooo]Z00?ooo]Z00?oolT0oookJ_oonfX00_oonfX00oo]0?oooo]Z
oookJP11oookJP03o`3o__oonf[ooo]Z00;oF_l02OoonfX2on;o09[ooo]Z0_oRo`07oookJP;oF_l0
00?o0?nnoookJ_oonfX01OoonfX2ool0mP03oookJ_l00ooooo]Z00Gooo]Z00?o0?m8oookJ_oonfX0
1?oonfX00ol0ogOooo]ZoookJP02oookJP04ogT0oooo9`3oUol0oiOo00?o00002?oonfX00ol0X_oo
okl0oookJP02o`2<o`05o`3oX_oonf[ooo]ZoookJ_l0ob401OoonfX00ooo0?;ooo]Zo`3oEP06oook
JP06ool0X?oonf[ooo]Zoe@0oooonf[o02Go0_oonfX01?lZ0?oooo]ZoookJ_oo2P05oookJP03og_o
0?oonf[ooo]Z00?ooo]Z00Oood40oookJ_oonf[ooo]Zo`3o>?oonf[o203o00cooo]Z00?oob00oook
J_oonfX01?oonfX00ooo0;Gooo]ZoookJP0?oookJP03o`3o]Ooonf[ooo]Z00Gooo]Z00?o0?n;oook
J_oonfX05?oonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Sooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo
000?oookJP04om;o0?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX01?oonfX01?ooV`3oo`00
oookJ_o/o`07oookJP03oi<0oooonf[ooo]Z00Gooo]Z00?oE`3ooookJ_oonfX00ooonfX00ooo0=co
oo]ZoookJP04oookJP03oigo0?oonf[ooo]Z00;ooo]Z00?ok@3ooookJ_oonfX07ooonfX002Kooo]Z
0_oob@09oookJP;oh_l0L_oonfX5onGo02?ooo]Z2_oUo`02oookJP;oF_l00_l0okh7oookJP04ool0
m_oonf[o00?oo`03o`Gooo]Z00?o0?m8oookJ_oonfX00ooonfX2o`3oM`Cooo]Z00?oN@3ooolW0?nG
o`000ol00009oookJP05o`2Roooo_`3ooo]ZoookJ_l0oj801?oonfX00ol0ob7ooo]ZoookJP03oook
JP03ool0l_oonf[o0?mF00Gooo]Z00Koo`2PoookJ_oonf[oE03ooookJ_l09Ol3oookJP03obX0oooo
nf[oo`X000Kooo]Z00KoNol0oookJ_oonf[ooo]ZoonL0?oo@@03oookJP03o`3o>?oonf[oiOl000_o
oo]Z00?oob00oookJ_oonfX01OoonfX00ooo0;Gooo]ZoookJP0?oookJP03o`3o]Ooonf[ooo]Z00Go
oo]Z00?o0?n;oookJ_oonfX05?oonfX00ooo04oooo]ZoookJP02oookJP03o`3oU_oonf[ooo]Z00Go
oo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000?oookJP04ooo90?oonf[ooo]Zomgo00?ooo]Z00?o:`3o
oookJ_oonfX00ooonfX01?oo003ooo]Zool0ZOo/o`06oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?o
okL0oeL0oooonfX00ooonfX00ooo0=cooo]ZoookJP03oookJP03ooo90?oonf[ooo]Z00;ooo]Z00?o
k@3ooookJ_oonfX0@_oonfX2oe[o00Wooo]Z0_oRo`2NoookJP?oh_l01_oonfX2oe[o0003o`3o__oo
nf[ooo]Z00Gooo]Z00Coo`3foookJ_l00ooo00?o1OoonfX00ol0odSooo]ZoookJP04oookJP;o0?mg
0ooonfX01?mi0?ooobL0o`000?nGo`02o`0000[ooo]Z00Gookl0oookJ_oonf[o08coo`3oXP03oook
JP03o`3o8Ooonf[ooo]Z00?ooo]Z00?oo`3boookJ_l0oeH01_oonfX01_oo0:3ooo]ZoookJ_mD0?oo
oo]Zo`0Uo`;ooo]Z00Co:P3ooookJ_oonf[oo`X01OoonfX00omko`3ooo]ZoookJP02oookJP05oonL
0?oo@@3ooo]ZoookJ_l0ocP00_oonfX00ol80?oooo]ZoookJP09oookJP03oolP0?oonf[ooo]Z00Co
oo]Z00?oo`2eoookJ_oonfX04?oonfX00ol0okGooo]ZoookJP04oookJP03o`3oRooonf[ooo]Z01Co
oo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP06oookJP05oolL0?oonf[ooo]Zoook
J_nho`003_oonfX01OoBo`3ooo]ZoookJ_oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX01?oonfX0
0ooo003ooo]Zonco0007oookJP03oi<0oooonf[ooo]Z00Gooo]Z00?ookL0oeL0oooonfX01?oonfX0
0ooo0=cooo]ZoookJP03oookJP03oigo0?oonf[ooo]Z00;ooo]Z00?ok@3ooookJ_oonfX07ooonfX0
02Gooo]Z00?oolT0oookJ_oonfX01_oonfX3on;o05?ooo]Z4?mRo`05onGo00cooo]Z1ooUo`0Qoook
JPcoiOl00_oonfX00omJo`3ooo]Zo`3o_P02o`3o_PGooo]Z0_oo0?H00ooonf[o00?ooookJP04oook
JP;o0?m81OoonfX2o`3oM`?ooo]Z00?oN@3ooolW0?nGo`000_l0000:oookJP05o`2Roooo_`3ooo]Z
oookJ_l0oj801?oonfX00ol0ob7ooo]ZoookJP03oookJP03ool0l_oonf[o0?mF00Gooo]Z00Koo`2P
oookJ_oonf[oE03ooookJ_l09Ol3oookJP03obX0oooonf[oo`X000Kooo]Z00KoNol0oookJ_oonf[o
oo]ZoonL0?oo@@03oookJP03o`3o>?oonf[oiOl000_ooo]Z00?oob00oookJ_oonfX01OoonfX00ooo
0;Gooo]ZoookJP0>oookJP03o`3o]Ooonf[ooo]Z00Gooo]Z00?o0?n;oookJ_oonfX05OoonfX01Ooo
04oooo]ZoookJ_oonf[o0?nF00Oooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000?oookJP05ooo90?oo
nf[ooo]ZoookJ_oMo`000_oonfX00ol[0?oooo]ZoookJP03oookJP04oonK0?oo003ooo]Zonco00Ko
oo]Z00?oT`3ooookJ_oonfX01ooonfX00omG0?oooo]ZoookJP03oookJP03ool0g?oonf[ooo]Z00;o
oo]Z00?oolT0oookJ_oonfX00_oonfX00oo]0?oooo]ZoookJP11oookJP03oe[o0?oonf[ooo]Z00Ko
oo]Z0ooRo`1CoookJQGoH_l0>ooonfX2on;o00Kooo]Z00CoF_l0o`3o__l0okko0?nn1OoonfX2ool0
mP03oookJ_l00ooooo]Z00Cooo]Z0_l0odP6oookJP04o`3oMooonf[ooo]ZoookJP;oN@3o00?o0000
oiOo0?l000002ooonfX2oono0003oookJ_l0S?oo0?nR00?ooo]Z00?o0?lQoookJ_oonfX00ooonfX0
0ooo0?;ooo]Zo`3oEP06oookJP06ool0X?oonf[ooo]Zoe@0oooonf[o02Go0_oonfX01?lZ0?oooo]Z
oookJ_oo2P05oookJP03og_o0?oonf[ooo]Z00;ooo]Z00Gooi`0oom10?oonf[ooo]Zo`3o>002oook
JP03o`P0oooonf[ooo]Z00Wooo]Z00?oob00oookJ_oonfX01?oonfX00ooo0;Gooo]ZoookJP0?oook
JP03o`3o]Ooonf[ooo]Z00Gooo]Z00?o0?n;oookJ_oonfX05?oonfX01Ooo04oooo]ZoookJ_oonf[o
0?nF00Sooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000?oookJP04om;o0?oonf[ooo]Zomgo00;ooo]Z
00?o:`3ooookJ_oonfX01?oonfX01?ooV`3oo`00oookJ_o/o`06oookJP03oi<0oooonf[ooo]Z00Ko
oo]Z00?oE`3ooookJ_oonfX00ooonfX00ooo0=cooo]ZoookJP03oookJP03oigo0?oonf[ooo]Z00;o
oo]Z00?ok@3ooookJ_oonfX07ooonfX002cooo]Z0_oRo`13oookJQ?oH_l05OoonfX8onGo00Cooo]Z
2_oUo`0MoookJPkoiOl00_oonfX2oe[o00;ooo]Z0_l0okh5oookJP04ool0m_oonf[o00?oo`03o`Go
oo]Z00?o0?m8oookJ_oonfX01?oonfX01?l0ogOooo]ZoookJ_oonfX2ogT0o`;oUol02ooonfX01Ol0
X_oookl0oono0?oonf[o0?nR00?ooo]Z00?o0?lQoookJ_oonfX01?oonfX00ooo0?;ooo]Zo`3oEP05
oookJP06ool0X?oonf[ooo]Zoe@0oooonf[o02Go0ooonfX00olZ0?ooo`X0o`1<o`06oookJP06og_o
0?oonf[ooo]ZoookJ_ooW03ood400ooonfX00ol0ocSooo]ZonGo000;oookJP03oolP0?oonf[ooo]Z
00Gooo]Z00?oo`2eoookJ_oonfX03_oonfX00ol0okGooo]ZoookJP05oookJP03o`3oRooonf[ooo]Z
01Cooo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP05oookJP05oolL0?oonf[ooo]Z
oookJ_nho`003ooonfX01Ooob@3ooo]ZoookJ_oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX00ooo
nfX01?oo003ooo]Zool0ZOo/o`06oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?oE`3ooookJ_oonfX0
0ooonfX00ooo0=cooo]ZoookJP03oookJP03ooo90?oonf[ooo]Z00;ooo]Z00?ok@3ooookJ_oonfX0
AooonfX2on;o04Cooo]Z4_mRo`0EoookJPSoH_l0=OoonfX2on;o00Gooo]Z0_mJo`000ooonf[o0?nn
o`3o_P05oookJP04ool0m_oonf[o00?oo`03o`Gooo]Z00?o0?m8oookJ_oonfX01?oonfX2o`3oM`;o
oo]Z00Co0000ogT0oooo9`3oUol03?oonfX01Ol0X_oookl0oookJ_l0S?oo0?nR00?ooo]Z00?o0?lQ
oookJ_oonfX00ooonfX00ooo0?;ooo]Zo`3oEP06oookJP06ool0X?oonf[ooo]Zoe@0oooonf[o02Go
0_oonfX01?lZ0?oooo]Zool:0?l0C?l5oookJP03og_o0?oonf[ooo]Z00;ooo]Z00Gooi`0oom10?oo
nf[ooo]Zo`3o>002oookJP03o`P0oooonf[ooo]Z00Wooo]Z00?oob00oookJ_oonfX01?oonfX00ooo
0;Gooo]ZoookJP0?oookJP03o`3o]Ooonf[ooo]Z00Gooo]Z00?o0?n;oookJ_oonfX04ooonfX00ooo
04oooo]ZoookJP02oookJP03o`3oU_oonf[ooo]Z00Kooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000>
oookJP05om;o0?oonf[ooo]ZoookJ_oMo`000_oonfX00ol[0?oooo]ZoookJP04oookJP03ool00?oo
nf[ok?l000Oooo]Z00?oT`3ooookJ_oonfX01OoonfX00omG0?oooo]ZoookJP03oookJP03ool0g?oo
nf[ooo]Z00Cooo]Z00?oWOl0oookJ_oonfX00_oonfX00oo]0?oooo]ZoookJP0NoookJP00:_oonfX2
on;o04;ooo]Z0omRo`0`oookJQ3oiOl08?oonfX:onGo00?ooo]Z0_mJo`02oookJP;o0?nn1?oonfX2
ool0mP03oookJ_l00ooooo]Z00Cooo]Z0_l0odP5oookJP;o0?mg00Kooo]Zo`000?l0003oN@3ooolW
0?nGo`0;oookJP06o`2Roooonf[ookl0oookJ_l0oj;o08co0_oonfX00ol0ob7ooo]ZoookJP04oook
JP03ool0l_oonf[o0?mF00Gooo]Z00Koo`2PoookJ_oonf[oE03ooookJ_l09Ol3oookJP03obX0oooo
2P3o04co00Kooo]Z00KoNol0oookJ_oonf[ooo]ZoonL0?oo@@03oookJP03o`3o>?oUo`3ooo]Z00[o
oo]Z00?oob00oookJ_oonfX01OoonfX00ooo0;Gooo]ZoookJP0?oookJP03o`3o]Ooonf[ooo]Z00Go
oo]Z00?o0?n;oookJ_oonfX05?oonfX00ooo04oooo]ZoookJP02oookJP03o`3oU_oonf[ooo]Z00Co
oo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000?oookJP05ooo90?oonf[ooo]ZoookJ_oMo`000_oonfX0
0ol[0?oooo]ZoookJP03oookJP04oonK0?oo003oo`2Yonco00Kooo]Z00?oT`3ooookJ_oonfX01ooo
nfX00omG0?oooo]ZoookJP02oookJP03ool0g?oonf[ooo]Z00?ooo]Z00?oolT0oookJ_oonfX00_oo
nfX00oo]0?oooo]ZoookJP15oookJP;oh_l0@ooonfX3of;o02oooo]Z2?mRo`0_oookJP?oh_l01?oo
nfX2oe[o0003oookJ_l0okko0?nn00Cooo]Z0_oo0?H00ooonf[o00?ooookJP04oookJP;o0?m81_oo
nfX2o`3oM`;o000000CoN@3ooolW0?nGo`3oUol02ooonfX01Ol0X_oookl0oookJ_l0S?oo0?nR00?o
oo]Z00?o0?lQoookJ_oonfX00ooonfX00ooo0?;ooo]Zo`3oEP06oookJP06ool0X?oonf[ooo]Zoe@0
oooonf[o02Go0_oonfX01?lZ0?oooo]Zool:0?l0C?l5oookJP03og_o0?oonf[ooo]Z00;ooo]Z00Oo
oi`0oom10?oonf[ooo]Zo`3o>?oonf[o203o00_ooo]Z00?oob00oookJ_oonfX01?oonfX00ooo0;Go
oo]ZoookJP0@oookJP03o`3o]Ooonf[ooo]Z00Gooo]Z00?o0?n;oookJ_oonfX04ooonfX00ooo04oo
oo]ZoookJP02oookJP03o`3oU_oonf[ooo]Z00Gooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000?oook
JP04om;o0?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX01?oonfX01?ooV`3oo`00ool0ZOo/
o`06oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?oE`3ooookJ_oonfX00ooonfX00ooo0=cooo]Zoook
JP03oookJP03oigo0?oonf[ooo]Z00;ooo]Z00?ok@3ooookJ_oonfX07_oonfX002Wooo]Z00?oh_l0
oookJ_oonfX0?ooonfX3of;o03Kooo]Z4?oUo`0ToookJPCoiOl000Goh_l0oookJ_oonf[ooo]Zoe[o
0003oookJP03o`3o__oonf[ooo]Z00?ooo]Z00Coo`3foookJ_l00ooo00?o1OoonfX00ol0odSooo]Z
oookJP04oookJP07o`3oMol0003o0000o`000?mi0?ooobL0oiOo000;oookJP06o`2Roooonf[ookl0
oookJ_l0oj;o08co0_oonfX00ol0ob7ooo]ZoookJP04oookJP03ool0l_oonf[o0?mF00Gooo]Z00Ko
o`2PoookJ_oonf[oE03ooookJ_l09Ol3oookJP03obX0oooo2P3o04co00Kooo]Z00KoNol0oookJ_oo
nf[ooi`0oookJ_oo@@02oookJP03o`3o>?oonf[oiOl000_ooo]Z00?oob00oookJ_oonfX01OoonfX0
0ooo0;Gooo]ZoookJP0>oookJP03o`3o]Ooonf[ooo]Z00Gooo]Z00?o0?n;oookJ_oonfX05?oonfX0
0ooo04oooo]ZoookJP02oookJP03o`3oU_oonf[ooo]Z00Gooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo
000?oookJP05ooo90?oonf[ooo]ZoookJ_oMo`000_oonfX00ol[0?oooo]ZoookJP03oookJP03ool0
0?oonf[ok?l000Kooo]Z00?oT`3ooookJ_oonfX01ooonfX00omG0?oooo]ZoookJP03oookJP03ool0
g?oonf[ooo]Z00;ooo]Z00?oolT0oookJ_oonfX00_oonfX00oo]0?oooo]ZoookJP14oookJP03on;o
0?oonf[ooo]Z043ooo]Z0omRo`0joookJPSoH_l0:_oonfX2on;o00Cooo]Z00CoF_l0oookJ_oonf[o
0?nn1OoonfX01?oo0?Kooo]Zo`03ool00ol5oookJP03o`3oB?oonf[ooo]Z00Gooo]Z00?o0?mgo`00
0?l000000_mi0?l00ooonf[oUol0oookJP0:oookJP05o`2Roooo_`3ooo]ZoookJ_l0oj800ooonfX0
0ol0ob7ooo]ZoookJP03oookJP03ool0l_oonf[o0?mF00Kooo]Z00Koo`2PoookJ_oonf[oE03ooook
J_l09Ol2oookJP04obX0oooonf[oo`X0o`1<o`Gooo]Z00WoNol0oookJ_oonf[ooo]ZoonL0?oonf[o
od40oookJ_l0ocP00_oonfX00ol80?oooo]ZoookJP09oookJP03oolP0?oonf[ooo]Z00Cooo]Z00?o
o`2eoookJ_oonfX03ooonfX00ol0okGooo]ZoookJP05oookJP03o`3oRooonf[ooo]Z01?ooo]Z00?o
o`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP06oookJP05oolL0?oonf[ooo]ZoookJ_nho`00
3_oonfX01OoBo`3ooo]ZoookJ_oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX01?oonfX00ooo003o
oo]Zonco0006oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?oE`3ooookJ_oonfX00ooonfX00ooo0=co
oo]ZoookJP03oookJP03oigo0?oonf[ooo]Z00;ooo]Z00?ok@3ooookJ_oonfX07_oonfX002Oooo]Z
0_oRo`0ooookJP?oH_l08OoonfX;of`0o`gooo]Z4OoUo`02of;o02Kooo]Z0_oRo`02oookJP;oF_l0
0_oonfX2o`3o_PCooo]Z0_oo0?H00ooonf[o00?ooookJP04oookJP;o0?m81OoonfX2o`3oM`;o0000
00CoN@3ooolW0?nGo`3oUol02_oonfX01_l0X_oooo]Zoono0?oonf[o0?nRo`2<o`;ooo]Z00?o0?lQ
oookJ_oonfX01?oonfX00ooo0?;ooo]Zo`3oEP05oookJP06ool0X?oonf[ooo]Zoe@0oooonf[o02Go
0ooonfX00olZ0?ooo`X0o`1<o`06oookJP06og_o0?oonf[ooo]ZoonL0?oonf[ood400_oonfX00ol0
ocSooo]ZonGo000;oookJP03oolP0?oonf[ooo]Z00Cooo]Z00?oo`2eoookJ_oonfX03ooonfX00ol0
okGooo]ZoookJP05oookJP03o`3oRooonf[ooo]Z01Cooo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0
oiKooo]ZoookJP04oookJP05oolL0?oonf[ooo]ZoookJ_nho`003ooonfX01Ooob@3ooo]ZoookJ_oo
nf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX00ooonfX01?ooV`3oo`00ool0ZOo/o`06oookJP03oi<0
oooonf[ooo]Z00Kooo]Z00?oE`3ooookJ_oonfX00ooonfX00ooo0=cooo]ZoookJP03oookJP03ooo9
0?oonf[ooo]Z00;ooo]Z00?ok@3ooookJ_oonfX0@OoonfX2on;o03oooo]Z1?mRo`0PoookJP_oK03o
6_oonfX6of;o02Kooo]Z0_oRo`03oookJP;oF_l000?ooo]Zo`3o__l0okh01?oonfX2ool0mP03oook
J_l00ooooo]Z00Cooo]Z0_l0odP5oookJP08o`000?l0ogOo0?mgo`000?oonf[oN@3ooookJ_nGo`0;
oookJP05o`2Roooo_`3ookl0oookJ_l0oj800ooonfX00ol0ob7ooo]ZoookJP03oookJP03ool0l_oo
nf[o0?mF00Kooo]Z00Koo`2PoookJ_oonf[oE03ooookJ_l09Ol2oookJP04obX0oooonf[oo`X0o`1<
o`Gooo]Z00WoNol0oookJ_oonf[ooo]ZoonL0?oonf[ood40oookJ_l0ocP00_oonfX00ol80?oooo]Z
oookJP09oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?oo`2eoookJ_oonfX04?oonfX00ol0okGooo]Z
oookJP05oookJP03o`3oRooonf[ooo]Z01?ooo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]Z
oookJP05oookJP05oolL0?oonf[ooo]ZoookJ_nho`003ooonfX01?oBo`3ooo]ZoookJ_oMo`02oook
JP03ob/0oooonf[ooo]Z00Cooo]Z00Cooi/0ool00?oo0:Wok?l01_oonfX00onC0?oooo]ZoookJP05
oookJP03oeL0oooo]`3ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX01?oonfX00onMo`3ooo]ZoookJP02
oookJP03ond0oooonf[ooo]Z01gooo]Z000VoookJP03on;o0?oonf[ooo]Z03cooo]Z0omRo`0Ioook
JP_oK03o2ooonfX;of`0o`;ooo]Z3?oUo`07oookJP?oH_l09OoonfX01?oRo`3ooo]ZoookJ_oonfX2
oe[o00;ooo]Z00?o0?nnoookJ_oonfX00ooonfX01?oo0?Kooo]Zo`03ool00ol5oookJP03o`3oB?oo
nf[ooo]Z00;ooo]Z0_l000000ol0ogOo0000oookJP02ogT0o`03oolW0?nGo`3ooo]Z00Wooo]Z00Ko
0:;ooookJ_oo_`3ookl0o`3oX_l0S?l2oookJP03o`3o8Ooonf[ooo]Z00Cooo]Z00?oo`3boookJ_l0
oeH01OoonfX01_oo0:3ooo]ZoookJ_mD0?oooo]Zo`0Uo`?ooo]Z00?o:P3oool:0?oonfX01_oonfX0
1Omko`3ooo]ZoookJ_ooW03ood4000?ooo]Z00?o0?lhoookJ_oUo`002ooonfX00ooo803ooo]Zoook
JP04oookJP03ool0]Ooonf[ooo]Z00oooo]Z00?o0?neoookJ_oonfX01OoonfX00ol0oh_ooo]Zoook
JP0CoookJP03ool0Cooonf[ooo]Z00;ooo]Z00?o0?nFoookJ_oonfX01OoonfX01?oo703ooo]Zoook
J_nho`0?oookJP03ooo90?oonf[ooo]Z00;ooo]Z00CogOl0oookJ_oonf[o:`3o1OoonfX00ooo003o
oo]Zonco0006oookJP03oi<0oooonf[ooo]Z00Oooo]Z00?oE`3ooookJ_oonfX00_oonfX00ooo0=co
oo]ZoookJP03oookJP03ooo90?oonf[ooo]Z04Gooo]Z00?oh_l0oookJ_oonfX0??oonfX3of;o01Wo
oo]Z2om/0?l;oookJP_oK03o5OoonfX3of;o02Gooo]Z0_oRo`03oookJP;oF_l000?ooo]Zo`3o__oo
nfX01?oonfX01?oo0?Kooo]Zo`03ool00ol5oookJP03o`3oB?oonf[ooo]Z00;ooo]Z0ol000001_l0
ogOooo]ZoookJ_mi0?ooobL0oiOo00_ooo]Z00Go0:;ooookJ_oo_`3ooo]Zo`3oXP03oookJP03o`3o
8Ooonf[ooo]Z00?ooo]Z00?oo`3boookJ_l0oeH01_oonfX01_oo0:3ooo]ZoookJ_mD0?oooo]Zo`0U
o`;ooo]Z00?o:P3ooookJ_oo2P001_oonfX01_mko`3ooo]ZoookJ_oonf[ooi`0oom100;ooo]Z00?o
0?lhoookJ_l80?l03?oonfX00ooo803ooo]ZoookJP03oookJP03ool0]Ooonf[ooo]Z013ooo]Z00?o
0?neoookJ_oonfX01OoonfX00ol0oh_ooo]ZoookJP0BoookJP03ool0Cooonf[ooo]Z00;ooo]Z00?o
0?nFoookJ_oonfX01OoonfX01Ooo703ooo]ZoookJ_oonf[o^?l000oooo]Z00God_l0oookJ_oonf[o
oo]Zomgo0002oookJP03ob/0oooonf[ooo]Z00Cooo]Z00?oo`00ool0ZOo/o`001_oonfX00onC0?oo
oo]ZoookJP06oookJP03oeL0oooonf[ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX00ooonfX00onMo`3o
oo]ZoookJP0RoookJP009OoonfX00ooRo`3ooo]ZoookJP0ioookJPCoH_l04OoonfX;of`0oacooo]Z
1OoUo`0:of`0o`kooo]Z0omRo`0SoookJP;oh_l00ooonfX2oe[o0003oookJ_l0okko0?nn00Cooo]Z
0_oo0?H00ooonf[o00?oo`03o`04oookJP;o0?m80_oonfX3o`000007o`3oMooonf[ooo]ZoookJ_mi
0?ooobL0oiOo000:oookJP04o`2Roooonf[ooo]Zoono00;o0?nR0_oonfX00ol0ob7ooo]ZoookJP04
oookJP03ool0l_oonf[o0?mF00Cooo]Z00Ooo`2PoookJ_oonf[ooo]Zoe@0oooonf[o02Go00?ooo]Z
00?o:P3oool:0?oonfX01_oonfX01Omko`3ooo]ZoookJ_ooW03ood4000?ooo]Z00?o0?lhonGo0?oo
nfX02_oonfX00ooo803ooo]ZoookJP05oookJP03ool0]Ooonf[ooo]Z00oooo]Z00?o0?neoookJ_oo
nfX01?oonfX00ol0oh_ooo]ZoookJP0DoookJP03ool0Cooonf[ooo]Z00;ooo]Z00?o0?nFoookJ_oo
nfX01?oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000oooo]Z00GoolT0oookJ_oonf[ooo]Zomgo0002
oookJP03ob/0oooonf[ooo]Z00?ooo]Z00Cooi/0ool00?oo0:Wok?l01OoonfX00onC0?oooo]Zoook
JP07oookJP03oeL0oooonf[ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX00ooonfX00ooob@3ooo]Zoook
JP13oookJP03on;o0?oonf[ooo]Z03[ooo]Z0omRo`0AoookJP_oK03o8OoonfX:of`0o`kooo]Z0omR
o`0ToookJP03on;o0?oonf[ooo]Z00;ooo]Z0_mJo`02o`3o_PCooo]Z0_oo0?H00ooonf[o00?oo`03
o`04oookJP;o0?m80_oonfX4o`000003o`3oMooonf[ooo]Z00;oN@3o00?oUol0oookJ_oonfX02Ooo
nfX01?l0X_oooo]Zoono0?oonfX2o`3oXP;ooo]Z00?o0?lQoookJ_oonfX00ooonfX00ooo0?;ooo]Z
o`3oEP05oookJP07ool0X?oonf[ooo]ZoookJ_mD0?oooo]Zo`0Uo`02oookJP03obX0oooonf[oo`X0
00Kooo]Z00KoNol0oookJ_oonf[ooo]ZoonL0?oo@@02oookJP03o`3o>?oonf[o203o00_ooo]Z00?o
ob00oookJ_oonfX01?oonfX00ooo0;Gooo]ZoookJP0@oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o
0?n;oookJ_oonfX04ooonfX00ooo04oooo]ZoookJP02oookJP03o`3oU_oonf[ooo]Z00Gooo]Z00Go
oa`0oookJ_oonf[ooo]ZokSo000>oookJP05om;o0?oonf[ooo]ZoookJ_oMo`000_oonfX00ol[0?oo
oo]ZoookJP04oookJP03oonK0?oo003ok?l000Kooo]Z00?oT`3ooookJ_oonfX01_oonfX00omG0?oo
okL0oookJP03oookJP03ool0g?oonf[ooo]Z00Cooo]Z00?oWOl0oookJ_oonfX08OoonfX005kooo]Z
0omRo`0?oookJPKoK03o2OoonfXUoooS00;oiOl01_oonfX7of`0o`[ooo]Z0omRo`0RoookJP;oh_l0
0ooonfX00omJo`3ooo]ZoookJP02o`3o_PCooo]Z00Coo`3foookJ_oonf[o00?o1OoonfX00ol0odSo
oo]Zo`000003o`000007o`3oMooonf[ooo]ZoookJ_mi0?ooobL0oiOo000:oookJP06o`2Roooonf[o
oo]Zoono0?l0S?oo0?nR0_oonfX00ol0ob7ooo]ZoookJP04oookJP03ool0l_oonf[o0?mF00Cooo]Z
00Ooo`2PoookJ_oonf[ooo]Zoe@0oooonf[o02Go00?ooo]Z00?o:P3oool:0?oonfX01_oonfX01Omk
o`3ooo]ZoonL0?oonf[ood4000?ooo]Z00?o0?lhonGo0?oonfX02_oonfX00ooo803ooo]ZoookJP04
oookJP03ool0]Ooonf[ooo]Z00oooo]Z00?o0?neoookJ_oonfX01OoonfX00ol0oh_ooo]ZoookJP0C
oookJP03ool0Cooonf[ooo]Z00?ooo]Z00?o0?nFoookJ_oonfX01?oonfX01?oo703ooo]ZoookJ_nh
o`0?oookJP03ooo90?oonf[ooo]Z00;ooo]Z00CogOl0oookJ_oonf[o:`3o1?oonfX01?ooV`3oo`00
ool0ZOo/o`06oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?oE`3ooong0?oonfX00ooonfX00ooo0=co
oo]ZoookJP03oookJP03ooo90?oonf[ooo]Z07gooo]Z0omRo`0>oookJPKoK03o2OoonfXVoooS00Oo
oo]Z1om/0?l:oookJPCoH_l08OoonfX2on;o00Cooo]Z00CoF_l0oookJ_l0okko0?nn1?oonfX2ool0
mP03oookJ_l00ooooo]Z00Cooo]Z00?o0?m8oookJ_l000000ol000000ooonf[o0?mgoookJP02oook
JP03ogT0oonGo`3oUol000[ooo]Z00Ko0:;ooookJ_oo_`3o08cooookJ_l0oj82oookJP03o`3o8Ooo
nf[ooo]Z00?ooo]Z00?oo`3boookJ_l0oeH01OoonfX01ooo0:3ooo]ZoookJ_oonf[oE03ooookJ_l0
9Ol00_oonfX00olZ0?oooo]Zool:0006oookJP06og_o0?oonf[ooo]ZoonL0?oonf[ood400_oonfX0
0ol0ocSooo]Zo`P0o`0;oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?oo`2eoookJ_oonfX04?oonfX0
0ol0okGooo]ZoookJP05oookJP03o`3oRooonf[ooo]Z01;ooo]Z00?oo`1?oookJ_oonfX00ooonfX0
0ol0oiKooo]ZoookJP04oookJP05oolL0?oonf[ooo]ZoookJ_nho`003ooonfX01OoBo`3ooo]Zoook
J_oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX00ooonfX01?ooV`3oo`00ool0ZOo/o`06oookJP03
oi<0oooonf[ooo]Z00Gooo]Z00?oE`3ooong0?oonfX00ooonfX00ooo0=cooo]ZoookJP04oookJP03
oigo0?oonf[ooo]Z027ooo]Z001KoookJP?oH_l03ooonfX3of`0o`[ooo]Z1Oooh`0;oookJP?oo`d0
2OoUo`07oookJPOoiOl01_ooh`09oookJP?oK03o2_oonfX4of;o023ooo]Z0_oRo`02oookJP;oF_l0
0_oonfX00ol0okkooo]ZoookJP02oookJP03ool0m_oonf[ooo]Z00;o00?o1?oonfX00ol0odSo0000
o`000003o`0000;o0?mg0_oonfX2ogT0o`;oUol02OoonfX01_l0X_oooo]ZoookJ_oo_`3o08coo`3o
XP;ooo]Z00?o0?lQoookJ_oonfX01?oonfX00ooo0?;ooo]Zo`3oEP04oookJP07ool0X?oonf[ooo]Z
oookJ_mD0?oooo]Zo`0Uo`03oookJP03obX0oooo2P3ooo]Z00Gooo]Z00GoNol0oookJ_oonf[ooi`0
oom10003oookJP03o`3o>?oonf[oiOl000_ooo]Z00?oob00oookJ_oonfX01?oonfX00ooo0;Gooo]Z
oookJP0?oookJP03o`3o]Ooonf[ooo]Z00Gooo]Z00?o0?n;oookJ_oonfX04ooonfX00ooo04oooo]Z
oookJP02oookJP03o`3oU_oonf[ooo]Z00Cooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000?oookJP05
ooo90?oonf[ooo]ZoookJ_oMo`000_oonfX00ol[0?oooo]ZoookJP03oookJP04ool00?oonf[oo`2Y
onco00Gooo]Z00?oT`3ooookJ_oonfX01ooonfX00omG0?oooo]ZoookJP02oookJP03ool0g?oonf[o
oo]Z00?ooo]Z00?oolT0oookJ_oonfX0NOoonfX4of;o00kooo]Z0om/0?l:oookJPGoon<03?oonfX<
ool=00kooo]Z1_ooh`08oookJP?oK03o2ooonfX3of;o023ooo]Z0_oRo`03oookJP;oF_l000?ooo]Z
o`3o__oonfX01?oonfX01?oo0?Kooo]Zo`03ool00ol4oookJP03o`3oB?l0003o000000?o000000?o
oo]Zo`3oMooonfX00_oonfX2ogT0o`03oiOo0?oonf[ooo]Z00Sooo]Z00Ko0:;ooookJ_oo_`3o08co
oookJ_l0oj82oookJP03o`3o8Ooonf[ooo]Z00?ooo]Z00?oo`3boookJ_l0oeH01OoonfX01ooo0:3o
oo]ZoookJ_oonf[oE03ooookJ_l09Ol00_oonfX00olZ0?oooo]Zool:0005oookJP06og_o0?oonf[o
oo]ZoookJ_ooW03ood400_oonfX00ol0ocSooo]Zo`P0o`0<oookJP03oolP0?oonf[ooo]Z00?ooo]Z
00?oo`2eoookJ_oonfX04?oonfX00ol0okGooo]ZoookJP05oookJP03o`3oRooonf[ooo]Z01;ooo]Z
00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP05oookJP05oolL0?oonf[ooo]ZoookJ_nh
o`003_oonfX01OoBo`3ooo]ZoookJ_oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX01?oonfX00ooo
003oo`2Yonco0006oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?oE`3ooookJ_oonfX00ooonfX00ooo
0=cooo]ZoookJP03oookJP03oigo0?oonf[ooo]Z027ooo]Z001HoookJP?oH_l03ooonfX3of`0o`Wo
oo]Z1?ooh`0:oookJPKoo`d03?oonfXDonGo00Koon<01_oonfX4of`0o`[ooo]Z0omRo`0OoookJP04
on;o0?oonf[ooo]ZoookJP;oF_l000?ooo]Zo`3o__l0okh00ooonfX2ool0mP;ooo]Z00?o00?ooook
J_oonfX00_oonfX2o`3oB0;o00000ooonfX01ol0ogOooo]ZoookJ_oonf[oN@3ooookJ_nGo`002Ooo
nfX01_l0X_oooo]Zoono0?oonf[o08coo`3oXP;ooo]Z00?o0?lQoookJ_oonfX01?oonfX00ooo0?;o
oo]Zo`3oEP04oookJP06ool0X?oonf[ooo]ZoookJ_mD0?oo02Go0ooonfX00olZ0?ooo`X0oookJP06
oookJP05og_o0?oonf[ooo]ZoonL0?oo@@000ooonfX00ol0ocSoiOl0oookJP0:oookJP03oolP0?oo
nf[ooo]Z00Cooo]Z00?oo`2eoookJ_oonfX04?oonfX00ol0okGooo]ZoookJP04oookJP03o`3oRooo
nf[ooo]Z01?ooo]Z00?oo`1?oookJ_oonfX00ooonfX00ooUo`3ooo]ZoookJP03oookJP05oolL0?oo
nf[ooo]ZoookJ_nho`003ooonfX00ooob@3ooo]ZoookJP02oookJP04omgo0?oonf[ooo]Zob/0o`Co
oo]Z00Cooi/0ool00?oo0:Wok?l01OoonfX00onC0?oooo]ZoookJP07oookJP03oeL0oooo]`3ooo]Z
00?ooo]Z00?oo`3LoookJ_oonfX00ooonfX00ooob@3ooo]ZoookJP1eoookJP?oH_l03ooonfX3of`0
o`Wooo]Z1?ooh`0;oookJPKoo`d03?oonfX?ool=00Gooo]Z1_ooh`05oookJPCoK03o2_oonfX3of;o
01oooo]Z0_oRo`03oookJP;oF_l00_l0okh4oookJP;oo`3f00?ooo]Zo`03oooonfX00ooonfX2o`3o
B0;o00000ooonfX2o`3oM`;ooo]Z00?oobL0ogT0oonGo`002_oonfX01_l0X_oookl0oookJ_l0S?oo
oo]Zo`3oXP;ooo]Z00?o0?lQoookJ_oonfX00ooonfX00ooo0?;ooo]Zo`3oEP05oookJP06ool0X?oo
nf[ooo]ZoookJ_mD0?oo02Go0_oonfX00olZ0?oooo]Zool:0006oookJP06og_o0?oonf[ooo]Zoook
J_ooW03ood400_oonfX00ol0ocSooo]Zo`P0o`0;oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?oo`2e
oookJ_oonfX04OoonfX00ol0okGooo]ZoookJP04oookJP03o`3oRooonf[ooo]Z01;ooo]Z00?oo`1?
oookJ_oonfX00ooonfX00ol0oiKooo]ZoookJP04oookJP05oolL0?oonf[ooo]ZoookJ_nho`003ooo
nfX01OoBo`3ooo]ZoookJ_oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX00ooonfX01?ooV`3oo`00
ool0ZOo/o`05oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?oE`3ooong0?oonfX00ooonfX00ooo0=co
oo]ZoookJP04oookJP03oigo0?oonf[ooo]Z023ooo]Z001EoookJP?oH_l03ooonfX3of`0o`Oooo]Z
1Oooh`07oookJPOoo`d06?oonfXAonGo00;oo`d000?ooo]ZoooS0?ooh`001?ooh`04oookJPCoK03o
2OoonfX3of;o01gooo]Z0_oRo`03oookJP04oe[o0?oonf[ooo]Zo`3o_PCooo]Z00?oo`3foookJ_oo
nfX00_l00ol2oookJP;o000000?o0?m8o`000?oonfX00ooonfX01ol0ogOooo]ZoookJ_oonf[oN@3o
oolW0?nGo`002OoonfX2o`2Ro`04oono0?oonf[o08coo`3oXP;ooo]Z00?o0?lQoookJ_oonfX01?oo
nfX00ooo0?;ooo]Zo`3oEP04oookJP06ool0X?oonf[ooo]ZoookJ_mD0?oo02Go0ooonfX00olZ0?oo
o`X0oookJP06oookJP05og_o0?oonf[ooi`0oookJ_oo@@000ooonfX00ol0ocSoiOl0oookJP0:oook
JP03oolP0?oonf[ooo]Z00Cooo]Z00?oo`2eoookJ_oonfX03ooonfX00ol0okGooo]ZoookJP05oook
JP03o`3oRooonf[ooo]Z01?ooo]Z00?oo`1?oookJ_oonfX00_oonfX00ooUo`3ooo]ZoookJP04oook
JP05oolL0?oonf[ooo]ZoookJ_nho`003ooonfX01Ooob@3ooo]ZoookJ_oonf[ogOl000;ooo]Z00?o
:`3ooookJ_oonfX00ooonfX00ooo003oo`2Yonco0006oookJP03oi<0oooonf[ooo]Z00Oooo]Z00?o
E`3ooookJ_oonfX00_oonfX00ooo0=cooo]ZoookJP03oookJP03ooo90?oonf[ooo]Z07;ooo]Z0omR
o`0?oookJP?oK03o1ooonfX5oooS00Sooo]Z1ooo3@0QoookJPWoo`d00_oonfX6oooS00?ooo]Z1?m/
0?l9oookJPCoH_l07OoonfX2on;o00?ooo]Z00?oF_l0oookJ_l0okh01OoonfX01?oo0?Kooo]Zo`03
ool00ol2oookJP;o000000?o0?m8o`000?oonfX01?oonfX01_l0ogOooo]ZoookJ_oo9`3oN@3ooiOo
00[ooo]Z00Ko0:;ooono0?oonf[o08cooookJ_l0oj82oookJP03o`3o8Ooonf[ooo]Z00?ooo]Z00?o
o`3boookJ_l0oeH01OoonfX01_oo0:3ooo]ZoookJ_oonf[oE03oo`0Uo`;ooo]Z00?o:P3ooookJ_oo
2P001_oonfX01_mko`3ooo]ZoookJ_ooW03ooo]Zoom100;ooo]Z00?o0?lhoookJ_l80?l02ooonfX0
0ooo803ooo]ZoookJP03oookJP03ool0]Ooonf[ooo]Z013ooo]Z00?o0?neoookJ_oonfX01OoonfX0
0ol0oh_ooo]ZoookJP0BoookJP03ool0Cooonf[ooo]Z00;ooo]Z00?o0?nFoookJ_oonfX01OoonfX0
1Ooo703ooo]ZoookJ_oonf[o^?l000kooo]Z00God_l0oookJ_oonf[ooo]Zomgo0002oookJP03ob/0
oooonf[ooo]Z00Cooo]Z00?oo`00ool0ZOo/o`001_oonfX00onC0?oooo]ZoookJP06oookJP03oeL0
oooonf[ooo]Z00;ooo]Z00?oo`3LoookJ_oonfX01?oonfX00onMo`3ooo]ZoookJP0PoookJP00D_oo
nfX3of;o00oooo]Z0om/0?l6oookJPCoon<01_oonfX6ool=01oooo]Z3OoUo`06oookJPCoo`d00ooo
nfX6oooS00;ooo]Z0om/0?l9oookJP?oH_l07?oonfX2on;o00;ooo]Z0_mJo`000ooonf[o0?nno`3o
_P03oookJP;oo`3f0_oonfX00ol00ooooo]Zo`000002o`0000;o0?m81?oonfX01?l0ogOooo]Zoook
J_oonfX2ogT0o`03oiOo0?oonf[ooo]Z00Sooo]Z00Go0:;ooono0?oonf[o08coo`3oXP02oookJP03
o`3o8Ooonf[ooo]Z00Cooo]Z00?oo`3boookJ_l0oeH01?oonfX01_oo0:3ooo]ZoookJ_oonf[oE03o
o`0Uo`?ooo]Z00?o:P3oool:0?oonfX01OoonfX01_mko`3ooo]ZoookJ_ooW03ooo]Zoom100?ooo]Z
00?o0?lhonGo0?oonfX02_oonfX00ooo803ooo]ZoookJP04oookJP03ool0]Ooonf[ooo]Z00oooo]Z
00?o0?neoookJ_oonfX01OoonfX00ooUo`3ooo]ZoookJP0BoookJP03ool0Cooonf[ooo]Z00?ooo]Z
00?oiOl0oookJ_oonfX00ooonfX01Ooo703ooo]ZoookJ_oonf[o^?l000oooo]Z00?oolT0oookJ_oo
nfX00_oonfX01?oMo`3ooo]ZoookJ_l[0?l4oookJP04oonK0?oo003oo`2Yonco00Gooo]Z00?oT`3o
oookJ_oonfX01ooonfX00omG0?oookL0oookJP02oookJP03ool0g?oonf[ooo]Z00Cooo]Z00?oolT0
oookJ_oonfX0K_oonfX3of;o00oooo]Z0om/0?l6oookJPCoon<01ooonfX6ool=037ooo]Z1?oo3@04
oookJPKoon<000Cooo]Zof`0oom/0?ooK03o2_oonfX3of;o01cooo]Z00Coh_l0oookJ_oonf[ooo]Z
0_mJo`02o`3o_PCooo]Z0_oo0?H00ooonf[o00?ooookJP03o`0000;o0?m81OoonfX01?l0ogOooo]Z
oookJ_oonfX2ogT0o`03oiOo0?oonf[ooo]Z00Sooo]Z00Gookl0oookJ_l0S?oooo]Zo`3oXP02oook
JP03o`3o8Ooonf[ooo]Z00?ooo]Z00?oo`3boookJ_l0oeH01?oonfX00ooo0:3ooo]ZoookJP02oook
JP07oe@0ool09Ooooo]ZoookJ_lZ0?oooo]Zool:0005oookJP06og_o0?oonf[ooo]ZoookJ_ooW03o
od400ooonfX00ol0ocSo203ooookJP0;oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?oo`2eoookJ_oo
nfX04?oonfX00ol0okGooo]ZoookJP05oookJP03o`3oRooonf[ooo]Z017ooo]Z00?oo`1?oookJ_oo
nfX00ooonfX00ol0oiKooo]ZoookJP04oookJP05oolL0?oonf[ooo]ZoookJ_nho`003ooonfX01OoB
o`3ooo]ZoookJ_oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX00ooonfX01?ooV`3oo`00oookJ_o/
o`05oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?oE`3ooong0?oonfX00ooonfX00ooo0=cooo]Zoook
JP04oookJP03oigo0?oonf[ooo]Z01oooo]Z001@oookJP;oH_l03ooonfX3of`0o`Gooo]Z1?ooh`04
oookJPKoo`d09OoonfX8onGo00oooo]Z1?oo3@05oookJPCoon<000?ooo]Zof`0oom/0?l00_m/0?l8
oookJP?oH_l06ooonfX2on;o00;ooo]Z0_mJo`000ooonf[o0?nnoookJP03oookJP03ool0m_oonf[o
oo]Z00;o00?o0ol000000ooonf[o0?m8oookJP03oookJP03o`3oMooonf[ooo]Z00;ooo]Z00?oN@3o
oiOo0?nGo`002OoonfX01Ol0X_oookl0oookJ_l0S?oo0?nR00;ooo]Z00?o0?lQoookJ_oonfX01?oo
nfX00ooo0?;ooo]Zo`3oEP03oookJP03ool0X?oonf[ooo]Z00;ooo]Z00?oE03oo`0UoooonfX00_oo
nfX00olZ0?ooo`X0oookJP05oookJP05og_o0?oonf[ooo]ZoonL0?oo@@000ooonfX00ol0ocSooo]Z
onGo000;oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?oo`2eoookJ_oonfX03ooonfX00ol0okGooo]Z
oookJP05oookJP03onGo0?oonf[ooo]Z01?ooo]Z00?oo`1?oookJ_oonfX00_oonfX00ooUo`3ooo]Z
oookJP04oookJP05oolL0?oonf[ooo]ZoookJ_nho`003_oonfX00ooob@3ooo]ZoookJP02oookJP04
omgo0?oonf[ooo]Zob/0o`Gooo]Z00?oo`00ool0ZOo/o`001OoonfX00onC0?oooo]ZoookJP07oook
JP03oeL0oooo]`3ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX00ooonfX00ooob@3ooo]ZoookJP1/oook
JP;oH_l03ooonfX3of`0o`Gooo]Z1?ooh`05oookJPKoo`d0>ooonfX4ool=00Kooo]Z1?ooh`04of`0
o`Wooo]Z0omRo`0JoookJP;oh_l00ooonfX2oe[o0003o`3o__oonf[ooo]Z00?ooo]Z00Coo`3foook
J_l00ooo00?o0ol000000ooonf[o0?m8oookJP04oookJP07o`3oMooonf[ooo]ZoookJ_oo9`3oN@3o
oiOo000:oookJP05oono0?oonf[o08cooookJ_l0oj800_oonfX00ol0ob7ooo]ZoookJP03oookJP03
ool0l_oonf[o0?mF00Cooo]Z00?oo`2PoookJ_oonfX00_oonfX01omD0?oo02GooookJ_oonf[o:P3o
oookJ_oo2P001OoonfX01_mko`3ooo]ZoookJ_oonf[ooi`0oom100;ooo]Z00?o0?lhoookJ_l80?l0
3?oonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z013ooo]Z00?o0?neoookJ_oonfX0
1OoonfX00ol0oh_ooo]ZoookJP0BoookJP03ool0Cooonf[ooo]Z00;ooo]Z00?o0?nFoookJ_oonfX0
1?oonfX00ooo703ooo]ZoookJP02oookJP03okSo0?oonf[ooo]Z00cooo]Z00God_l0oookJ_oonf[o
oo]Zomgo0002oookJP03ob/0oooonf[ooo]Z00Cooo]Z00?oo`00ool0ZOo/o`001OoonfX00onC0?oo
oo]ZoookJP06oookJP03oeL0oooo]`3ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX01?oonfX00onMo`3o
oo]ZoookJP0OoookJP00CooonfX00omRo`3ooo]ZoookJP0=oookJP;oK03o0ooonfX5oooS00Cooo]Z
1?oo3@0[oookJP?oiOl06?oonfX5ool=00Cooo]Z0oooh`02oookJPCoK03o1ooonfX3of;o01[ooo]Z
00Koh_l0oookJ_oonf[ooo]Zoe[o0?oonfX2o`3o_P?ooo]Z0_oo0?H00ooonf[o0000o`03o`02o`00
00;ooo]Z0_oob@03oookJP;o0?mg0ooonfX00omi0?oooo]ZoiOo0009oookJP05o`2Roooo_`3ooo]Z
o`2<ool0oj800_oonfX00ol0ob7ooo]ZoookJP03oookJP04ool0l_oonf[ooo]Zo`3oEP?ooo]Z00Ko
o`2PoookJ_oonf[ooo]Zoe@0ool09Ol4oookJP03obX0oooo2P3ooo]Z00Gooo]Z00GoNol0oookJ_oo
nf[ooi`0oom10003oookJP03o`3o>?oUo`3ooo]Z00[ooo]Z00?oob00oookJ_oonfX01?oonfX00ooo
0;Gooo]ZoookJP0?oookJP03o`3o]Ooonf[ooo]Z00Gooo]Z00?oiOl0oookJ_oonfX04_oonfX00ooo
04oooo]ZoookJP02oookJP03onGo0?oonf[ooo]Z00Cooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000?
oookJP05ooo90?oonf[ooo]ZoookJ_oMo`000_oonfX00ol[0?oooo]ZoookJP03oookJP04oonK0?oo
003ooo]Zonco00Gooo]Z00?oT`3ooookJ_oonfX01ooonfX00omG0?oooo]ZoookJP02oookJP03ool0
g?oonf[ooo]Z00?ooo]Z00?oolT0oookJ_oonfX0JooonfX00omRo`3ooo]ZoookJP0=oookJP;oK03o
0ooonfX5oooS00Gooo]Z1?oo3@15oookJPGoo`d01OoonfX3oooS0003oookJ_m/0?ooK03o00;oK03o
2?oonfX3of;o01Wooo]Z0_oRo`03oookJP03oe[o0?l0okko0?nn00Cooo]Z0_oo0?H01?l0003o00?o
o`000?l00002oookJP;o0?m81?oonfX01ol0ogOooo]ZoookJ_oonf[oobL0ogT0oonGo`002_oonfX0
1Ooo_`3ooo]Zo`2<oooonf[o0?nR00;ooo]Z00?o0?lQoookJ_oonfX00_oonfX01?oo0?;ooo]Zoook
J_l0oeH4oookJP06ool0X?oonf[ooo]ZoookJ_mD0?oo02Go0ooonfX00olZ0?oo04coool:0005oook
JP06og_o0?oonf[ooo]ZoookJ_ooW03ood400_oonfX00ol0ocSooo]Zo`P0o`0;oookJP03oolP0?oo
nf[ooo]Z00?ooo]Z00?oo`2eoookJ_oonfX04?oonfX00ol0okGooo]ZoookJP05oookJP03o`3oRooo
nf[ooo]Z017ooo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP05oookJP05oolL0?oo
nf[ooo]ZoookJ_nho`003_oonfX01OoBo`3ooo]ZoookJ_oonf[ogOl000;ooo]Z00?o:`3ooookJ_oo
nfX01?oonfX01?ooV`3oo`00oookJ_o/o`05oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?oE`3ooook
J_oonfX00_oonfX00ooo0=cooo]ZoookJP04oookJP03oigo0?oonf[ooo]Z01oooo]Z001=oookJP;o
H_l03OoonfX3of`0o`;ooo]Z0oooh`06oookJP?oo`d0CooonfX4ool=00?ooo]Z0oooh`03oookJP?o
K03o1ooonfX2of;o01Wooo]Z0_oRo`02oookJP;oF_l000?ooo]Zo`3o__oonfX00ooonfX00ooo0?Ko
0000o`000002o`03o`Cooo]Z00?oolT0oookJ_oonfX00_oonfX01ol0ogOooo]ZoookJ_oonf[oN@3o
oolW0?nGo`002OoonfX01Ol0X_oookl0oookJ_l0S?oo0?nR00;ooo]Z00?o0?lQoookJ_oonfX00ooo
nfX01?oo0?;ooo]ZoookJ_l0oeH3oookJP06ool0X?oonf[ooo]ZoookJ_mD0?oo02Go1?oonfX00olZ
0?ooo`X0oookJP04oookJP06og_o0?oonf[ooo]ZoonL0?oonf[ood400ooonfX00ol0ocSoiOl0oook
JP0:oookJP03oolP0?oonf[ooo]Z00Cooo]Z00?oo`2eoookJ_oonfX03_oonfX00ol0okGooo]Zoook
JP05oookJP03onGo0?oonf[ooo]Z01?ooo]Z00?oo`1?oookJ_oonfX00_oonfX00ooUo`3ooo]Zoook
JP04oookJP05oolL0?oonf[ooo]ZoookJ_nho`003_oonfX00ooob@3ooo]ZoookJP02oookJP04omgo
0?oonf[ooo]Zob/0o`Gooo]Z00?oo`00ool0ZOo/o`001OoonfX00onC0?oooo]ZoookJP07oookJP03
oeL0oooo]`3ooo]Z00;ooo]Z00?oo`3LoookJ_oonfX01?oonfX00ooob@3ooo]ZoookJP1XoookJP;o
H_l03OoonfX3of`0o`;ooo]Z0oooh`07oookJP?oo`d0C_oonfX4ool=00Cooo]Z0oooh`02oookJP?o
K03o2?oonfX2of;o01Wooo]Z0_oRo`02oookJP;oF_l000?o0?nnoookJ_oonfX00ooonfX01?oo0?Ko
0000o`03ool00ol4oookJP03o`3oB?oonf[ooo]Z00;ooo]Z00Oo0?mgoookJ_oonf[ooo]ZoolW0?mi
0?ooUol000[ooo]Z00Gookl0oookJ_l0S?oooo]Zo`3oXP02oookJP03o`3o8Ooonf[ooo]Z00;ooo]Z
00Coo`3boookJ_oonf[o0?mF1?oonfX01_oo0:3ooo]ZoookJ_oonf[oE03oo`0Uo`?ooo]Z00?o:P3o
o`1<oooo2P001OoonfX01Omko`3ooo]ZoookJ_ooW03ood4000?ooo]Z00?o0?lhoookJ_l80?l02ooo
nfX00ooo803ooo]ZoookJP03oookJP03ool0]Ooonf[ooo]Z00oooo]Z00?o0?neoookJ_oonfX01Ooo
nfX00ol0oh_ooo]ZoookJP0BoookJP03ool0Cooonf[ooo]Z00;ooo]Z00?o0?nFoookJ_oonfX01?oo
nfX00ooo703ooo]ZoookJP02oookJP03okSo0?oonf[ooo]Z00cooo]Z00God_l0oookJ_oonf[ooo]Z
omgo0002oookJP03ob/0oooonf[ooo]Z00Cooo]Z00?oo`00oookJ_o/o`001OoonfX00onC0?oooo]Z
oookJP06oookJP03oeL0oooo]`3ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX01?oonfX00onMo`3ooo]Z
oookJP0NoookJP00BooonfX2of;o00cooo]Z0om/0?l3oookJP;oon<01ooonfX2ool=05Kooo]Z1?oo
3@02oookJP?oon<00ooonfX3of`0o`Kooo]Z0_mRo`0IoookJP;oh_l00_oonfX2oe[o00;o0?nn0ooo
nfX2ool0mP;o000000?o00?ooookJ_oonfX00_oonfX00ooob@3ooo]ZoookJP02oookJP07o`3oMooo
nf[ooo]ZoookJ_mi0?ooobL0oiOo0009oookJP05o`2Roooo_`3ooo]Zo`2<ool0oj800_oonfX00ol0
ob7ooo]ZoookJP03oookJP04ool0l_oonf[ooo]Zo`3oEP?ooo]Z00Koo`2PoookJ_oonf[ooo]Zoe@0
ool09Ol4oookJP03obX0oooo2P3ooo]Z00Cooo]Z00GoNol0oookJ_oonf[ooi`0oom10004oookJP03
o`3o>?oUo`3ooo]Z00;ooo]Z0_oUo`06oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?oo`2eoookJ_oo
nfX03ooonfX00ol0okGooo]ZoookJP05oookJP03onGo0?oonf[ooo]Z01;ooo]Z00?oo`1?oookJ_oo
nfX00_oonfX00ooUo`3ooo]ZoookJP04oookJP05oolL0?oonf[ooo]ZoookJ_nho`003ooonfX01Ooo
b@3ooo]ZoookJ_oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX00ooonfX01?ooV`3oo`00oookJ_o/
o`04oookJP03oi<0oooonf[ooo]Z00Oooo]Z00?oE`3ooong0?oonfX00ooonfX00ooo0=cooo]Zoook
JP03oookJP;oolT0IooonfX2of;o00cooo]Z0om/0?l3oookJP;oon<02?oonfX2ool=05Gooo]Z1?oo
3@03oookJP;oon<00ooonfX3of`0o`Oooo]Z0_mRo`0IoookJP;oh_l00_oonfX2oe[o0005o`3o__oo
nf[ooo]ZoookJ_l000000_oo0?H00ol0003o00?ooookJP03oookJP03o`3oB?oonf[ooo]Z00;ooo]Z
0_l0ogL2oookJP03ogT0oooo9`3oUol000[ooo]Z00Gookl0oookJ_l0S?oooo]Zo`3oXP02oookJP03
o`3o8Ooonf[ooo]Z00;ooo]Z00Coo`3boookJ_oonf[o0?mF1?oonfX01_oo0:3ooo]ZoookJ_oonf[o
E03oo`0Uo`?ooo]Z00?o:P3oo`1<oooo2P001?oonfX01_mko`3ooo]ZoookJ_oonf[ooi`0oom100?o
oo]Z00?o0?lho`P0oooonfX02ooonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z013o
oo]Z00?o0?neoookJ_oonfX01OoonfX00ol0oh_ooo]ZoookJP0AoookJP03ool0Cooonf[ooo]Z00;o
oo]Z00?o0?nFoookJ_oonfX01OoonfX01Ooo703ooo]ZoookJ_oonf[o^?l000kooo]Z00God_l0oook
J_oonf[ooo]Zomgo0002oookJP03ob/0oooonf[ooo]Z00Cooo]Z00Cooi/0ool00?oonf[ok?l01?oo
nfX00onC0?oooo]ZoookJP06oookJP03oeL0oooo]`3ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX01?oo
nfX00onMo`3ooo]ZoookJP0NoookJP00B_oonfX00omRo`3ooo]ZoookJP09oookJP?oK03o1?oonfX2
oooS00Kooo]Z0ooo3@1<oookJP;oogT03_oonfX4ool=0004oookJ_ooh`3oon<0oooS00?ooo]Z0_m/
0?l6oookJP;oH_l06OoonfX2on;o00;ooo]Z00GoF_l0oookJ_l0okko0?nnoookJP02o`000003ool0
m_l0003ooo]Z00;o00?o0ooonfX00ooob@3ooo]ZoookJP02oookJP07o`3oMooonf[ooo]ZoookJ_mi
0?ooobL0oiOo0009oookJP05o`2Roooo_`3ooo]Zo`2<ool0oj800_oonfX00ol0ob7ooo]ZoookJP03
oookJP04ool0l_oonf[ooo]Zo`3oEP?ooo]Z00Koo`2PoookJ_oonf[ooo]Zoe@0ool09Ol4oookJP03
obX0oooonf[ooo]Z00Cooo]Z00GoNol0oookJ_oonf[ooi`0oom10003oookJP04o`3o>?oonf[oiOl0
oookJP?oiOl01_oonfX00ooo803ooo]ZoookJP04oookJP03ool0]Ooonf[ooo]Z00kooo]Z00?o0?ne
oookJ_oonfX01OoonfX00ooUo`3ooo]ZoookJP0CoookJP03ool0Cooonf[ooo]Z00;ooo]Z00?oiOl0
oookJ_oonfX01?oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000kooo]Z00GoolT0oookJ_oonf[ooo]Z
omgo0002oookJP03ob/0oooonf[ooo]Z00Cooo]Z00?oo`00ool0ZOo/o`001OoonfX00onC0?oooo]Z
oookJP07oookJP03oeL0oooonf[ooo]Z00;ooo]Z00Coo`3LoookJ_oonf[ooo]Z1?oob@1VoookJP03
of;o0?oonf[ooo]Z00Wooo]Z0om/0?l4oookJP;oon<01ooonfX3ool=05_ooo]Z1?oo3@001?oonf[o
on<0oooS0?ooh`03oookJP;oK03o1ooonfX2of;o01Wooo]Z00Goh_l0oookJ_oonf[ooo]Zoe[o0002
o`3o_P06oookJ_l0003o0000o`000?oo0?Kooo]Z0_l00ol3oookJP03o`3oB?oonf[ooo]Z00?ooo]Z
00Ko0?mgoookJ_oonf[oN@3ooolW0?nGo`0:oookJP05oono0?oonf[o08cooookJ_l0oj800_oonfX0
0ol0ob7ooo]ZoookJP02oookJP04ool0l_oonf[ooo]Zo`3oEP?ooo]Z00?oo`2PoookJ_oonfX00_oo
nfX00omD0?oo02GooookJP02oookJP03obX0oooo2P3ooo]Z00Cooo]Z00KoNol0oookJ_oonf[ooo]Z
oonL0?oo@@02oookJP03o`3o>?oonf[o203o00_ooo]Z00?oob00oookJ_oonfX00ooonfX00ooo0;Go
oo]ZoookJP0?oookJP03o`3o]Ooonf[ooo]Z00Gooo]Z00?o0?n;oookJ_oonfX04_oonfX00ooo04oo
oo]ZoookJP02oookJP03o`3oU_oonf[ooo]Z00Cooo]Z00?ooa`0oookJ_oonfX00_oonfX00onho`3o
oo]ZoookJP0<oookJP04om;o0?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX01OoonfX00ooo
003ooo]Zonco0005oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?oE`3ooookJ_oonfX00_oonfX00ooo
0=cooo]ZoookJP04oookJP03oigo0?oonf[ooo]Z01kooo]Z0018oookJP;oH_l02OoonfX3of`0o`Go
oo]Z0_ooh`06oookJP;oo`d0<ooonfX>o`3oC@CoogT02_oonfX5oomi00oooo]Z0ooo3@000ooonf[o
on<0oooS0003oookJP;oK03o1_oonfX2of;o01Wooo]Z00Coh_l0oookJ_oonf[oF_l00_oonfX01?l0
okko0000o`000?l00002ool0mP;ooo]Z00Go00?ooookJ_oonf[ooo]Zooo90004oookJP;o0?mg0_oo
nfX00omi0?ooUol0oookJP09oookJP05o`2Roooo_`3ooo]Zo`2<ool0oj800_oonfX00ol0ob7ooo]Z
oookJP03oookJP04ool0l_oonf[ooo]Zo`3oEP?ooo]Z00Koo`2PoookJ_oonf[oE03ooookJ_l09Ol3
oookJP03o`1<oolZ0?oooo]Z00Cooo]Z00KoNol0oookJ_oonf[ooo]ZoonL0?oo@@03oookJP03o`3o
>?oUo`3oiOl000CoiOl01_oonfX00ooo803ooo]ZoookJP03oookJP03ool0]Ooonf[ooo]Z00oooo]Z
00?o0?neoookJ_oonfX01OoonfX00ooUo`3ooo]ZoookJP0BoookJP03ool0Cooonf[ooo]Z00;ooo]Z
00?oiOl0oookJ_oonfX01?oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000oooo]Z00GoolT0oookJ_oo
nf[ooo]Zomgo0002oookJP03ob/0oooonf[ooo]Z00?ooo]Z00Cooi/0ool00?oonf[ok?l01?oonfX0
0onC0?oooo]ZoookJP07oookJP03oeL0oooonf[ooo]Z00;ooo]Z00?oo`3LoookJ_oonfX01Ooob@1T
oookJP;oH_l02OoonfX3of`0o`Gooo]Z0_ooh`06oookJP?oo`d0<ooonfXBo`3oCAgooo]Z0ooo3@00
1?oonf[oon<0oooS0?ooh`02oookJP?oK03o1_oonfX00omRo`3ooo]ZoookJP0GoookJP;oh_l00_oo
nfX00omJo`3ooo]Zo`3o_P04o`0000;oo`3f00?ooo]Zo`03oooonfX00_oonfX00ol0odSooo]Zoook
JP03oookJP06o`3oMooonf[ooo]ZogT0oooo9`3oUol02_oonfX01Ooo_`3ooo]Zo`2<oooonf[o0?nR
00;ooo]Z00?o0?lQoookJ_oonfX00_oonfX01?oo0?;ooo]ZoookJ_l0oeH3oookJP06ool0X?oonf[o
oo]ZoookJ_mD0?oo02Go1?oonfX00olZ0?ooo`X0oookJP04oookJP05og_o0?oonf[ooo]ZoookJ_oo
@@000ooonfX00ol0ocSooo]Zo`P0o`0;oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oo
nfX04?oonfX00ol0okGooo]ZoookJP05oookJP03o`3oRooonf[ooo]Z017ooo]Z00?oo`1?oookJ_oo
nfX00_oonfX00ol0oiKooo]ZoookJP05oookJP05oolL0?oonf[ooo]ZoookJ_nho`003_oonfX01OoB
o`3ooo]ZoookJ_oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX01?oonfX00oooV`3oo`00onco0005
oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?oE`3ooong0?oonfX00ooonfX00ooo0=cooo]ZoookJP04
oookJP03oigo0?oonf[ooo]Z01gooo]Z0016oookJP;oH_l02OoonfX2onGo00Kooo]Z0_ooh`05oook
JP?oo`d09?oonfXAo`3oCA;ooo]Z1OooN@05oookJPOoogT04?oonfX3ool=00?oon<00_oonfX3of`0
o`Gooo]Z0_mRo`0HoookJP;oh_l000Cooo]Zoe[o0?mJo`3ooo]Z0_l0okh2o`000005oookJ_oo0?Ko
oo]ZoookJ_l00ol00ooonfX00ooob@3ooo]ZoookJP03oookJP05o`3oMooonf[ooo]ZogT0oonGo`00
2_oonfX01Ooo_`3ooo]ZoookJ_l0S?oo0?nR00;ooo]Z00?o0?lQoookJ_oonfX00ooonfX01?oo0?;o
oo]ZoookJ_oUo`02oookJP06ool0X?oonf[ooo]ZoookJ_mD0?oo02Go1?oonfX00ol0C?oo:P3ooook
JP04oookJP06og_o0?oonf[ooo]ZoonL0?oonf[ood400ooonfX00ol0ocSoiOl0onGo0003onGo00Oo
oo]Z00?oob00oookJ_oonfX00ooonfX00ooo0;Gooo]ZoookJP0>oookJP03o`3o]Ooonf[ooo]Z00Go
oo]Z00?oiOl0oookJ_oonfX04ooonfX01Ooo04oooo]ZoookJ_oonf[oiOl000Oooo]Z00Cooa`0oook
J_oonf[o^?l03ooonfX01Ooob@3ooo]ZoookJ_oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX00ooo
nfX01?ooV`3oo`00oookJ_o/o`04oookJP03oi<0oooonf[ooo]Z00Oooo]Z00?oE`3ooong0?oonfX0
0_oonfX00ooo0=cooo]ZoookJP05ooo906;ooo]Z0_mRo`09oookJP;oK03o1_oonfX2oooS00Kooo]Z
0_oo3@0UoookJQ7o0?m=4_oonfX5o`3oCA_ooo]Z0ooo3@001?oonf[oon<0oooS0?ooh`02oookJP;o
K03o1OoonfX2of;o01Wooo]Z0_oRo`000ooonf[oF_l0oookJP02o`3o_P;o00000_oonfX00ooo0?Ko
oo]Zo`03o`03oookJP03o`3oB?oonf[ooo]Z00?ooo]Z00Ko0?mgoookJ_oonf[oN@3ooolW0?nGo`0:
oookJP05oono0?oonf[o08cooookJ_l0oj800_oonfX00ol0ob7ooo]ZoookJP02oookJP04ool0l_oo
nf[ooo]Zo`3oEP?ooo]Z00Koo`2PoookJ_oonf[ooo]Zoe@0ool09Ol4oookJP03obX0oooo2P3ooo]Z
00?ooo]Z00KoNol0oookJ_oonf[ooo]ZoonL0?oo@@03oookJP03o`3o>?l80?oooo]Z00_ooo]Z00?o
ob00oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP0?oookJP03o`3o]Ooonf[ooo]Z00Gooo]Z00?o
0?n;oookJ_oonfX04_oonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Oooo]Z00Gooa`0oookJ_oonf[o
oo]ZokSo000>oookJP05om;o0?oonf[ooo]ZoookJ_oMo`000_oonfX00ol[0?oooo]ZoookJP04oook
JP04oonK0?oo003ooo]Zonco00Cooo]Z00?oT`3ooookJ_oonfX01_oonfX00omG0?oookL0oookJP03
oookJP03ool0g?oonf[ooo]Z02Cooo]Z0014oookJP;oH_l02?oonfX4onGo00Gooo]Z0_ooh`05oook
JP;oo`d08ooonfX4o`3oC@oooo]Z3Ooo0:X<oookJPkoogT04OoonfX2ool=0004oookJ_ooh`3oon<0
oooS00;ooo]Z0_m/0?l5oookJP;oH_l06?oonfX2on;o0005oookJ_mJo`3o0000o`000?l0okh00_l0
00001Ooonf[oo`3foookJ_oonf[o00?o00?ooo]Z00?oolT0oookJ_oonfX00ooonfX01Ol0ogOooo]Z
oookJ_mi0?ooUol000[ooo]Z00Gookl0oookJ_oonf[o08coo`3oXP02oookJP03o`3o8Ooonf[ooo]Z
00?ooo]Z00?oo`3boookJ_oUo`000ooonfX01_oo0:3ooo]ZoookJ_oonf[oE03oo`0Uo`Cooo]Z00?o
:P3oool:0?oonfX01?oonfX01Omko`3ooo]ZoookJ_ooW03ood4000;ooo]Z0_oUo`000ol0ocSoiOl0
onGo0002onGo00Sooo]Z00?oob00oookJ_oonfX00ooonfX00ooo0;Gooo]ZoookJP0>oookJP03o`3o
]Ooonf[ooo]Z00Cooo]Z00?oiOl0oookJ_oonfX04ooonfX00ooo04oooo]ZoookJP02oookJP03onGo
0?oonf[ooo]Z00Cooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000>oookJP05ooo90?oonf[ooo]Zoook
J_oMo`000_oonfX00ol[0?oooo]ZoookJP04oookJP03ool00?oo0:Wok?l000Gooo]Z00?oT`3ooook
J_oonfX01ooonfX00omG0?oooo]ZoookJP02oookJP03ool0g?oonf[ooo]Z00CoolT0H?oonfX2of;o
00[ooo]Z00?oK03ooookJ_oonfX01?oonfX2oooS00Gooo]Z0ooo3@0SoookJPCo0?m=3_oonfX=ool0
ZPgooo]Z1_l0oddHoookJP;oo`d00_oonfX2oooS00;ooo]Z0_m/0?l5oookJP;oH_l06OoonfX2on;o
00;oF_l000Co0000o`3o__l0003o00000_oonfX00ooo0?Kooo]Zo`03o`03oookJP03o`3oB?oonf[o
oo]Z00?ooo]Z00Ko0?mgoookJ_oonf[oN@3ooolW0?nGo`0:oookJP05oono0?oonf[o08cooookJ_l0
oj800_oonfX00ol0ob7ooo]ZoookJP02oookJP03ool0l_oonf[o0?mF00Cooo]Z00Koo`2PoookJ_oo
nf[ooo]Zoe@0ool09Ol3oookJP03obX0ool0C?ooo`X000Cooo]Z00KoNol0oookJ_oonf[ooo]ZoonL
0?oo@@03oookJP03o`3o>?l80?oooo]Z00_ooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]Z
oookJP0?oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX04_oonfX00ooo04oooo]Z
oookJP02oookJP03o`3oU_oonf[ooo]Z00Cooo]Z00?ooa`0oookJ_oonfX00_oonfX00onho`3ooo]Z
oookJP0<oookJP04om;o0?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX01OoonfX00ooo003o
oo]Zonco0005oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?oE`3ooookJ_oonfX00_oonfX00ooo0=co
oo]ZoookJP0ToookJP00@ooonfX00omRo`3ooo]ZoookJP05oookJPKoiOl01?oonfX2oooS00Cooo]Z
0ooo3@0QoookJPCo0?m=2OoonfX:ool0ZPgooo]Z3_oo0:X2oookJPgoogT04?oonfX2ool=00;ooo]Z
0oooh`000ooonf[oK03oof`0o`05oookJP03of;o0?oonf[ooo]Z01Oooo]Z00?oh_l0oookJ_mJo`00
0_l00002o`3o_P;ooo]Z00Coo`3foookJ_oonf[o00?o0ooonfX2ooo900Cooo]Z00Go0?mgoookJ_oo
nf[oN@3ooiOo000:oookJP04oono0?oonf[ooo]Zo`3oXP?ooo]Z00?o0?lQoookJ_oonfX00ooonfX0
0ooo0?;ooo]ZonGo0003oookJP06ool0X?oonf[ooo]ZoookJ_mD0?oo02Go1?oonfX00olZ0?ooo`X0
oookJP03oookJP06og_o0?oonf[ooo]ZoookJ_ooW03ood401?oUo`000ol0ocSoiOl0onGo0002onGo
00Oooo]Z00?oob00oookJ_oonfX00ooonfX00ooo0;Gooo]ZoookJP0>oookJP03o`3o]Ooonf[ooo]Z
00Gooo]Z00?oiOl0oookJ_oonfX04ooonfX01Ooo04oooo]ZoookJ_oonf[oiOl000Kooo]Z00Gooa`0
oookJ_oonf[ooo]ZokSo000?oookJP05ooo90?oonf[ooo]ZoookJ_oMo`000_oonfX00ol[0?oooo]Z
oookJP03oookJP04oonK0?oo003ooo]Zonco00Cooo]Z00?oT`3ooookJ_oonfX01ooonfX00omG0?oo
oo]ZoookJP02oookJP04ool0g?oonf[ooo]ZoookJP?oolT0GooonfX00omRo`3ooo]ZoookJP08oook
JP;oK03o1OoonfX2oooS00Gooo]Z0_oo3@0RoookJPCo0?m=2?oonfX:ool0ZPgooo]Z3_oo0:X5oook
JPGo0?m=5OoonfX2ool=00;ooo]Z0oooh`000ooonf[oK03oof`0o`05oookJP;oH_l06OoonfX01?oR
o`3o0000oe[o0?l00002o`3o_P?ooo]Z00?oo`3foookJ_l00ol00ooonfX2o`3oB0Cooo]Z0_l0ogL0
1?oonf[oN@3ooookJ_nGo`0:oookJP04oono0?oonf[o08coo`3oXP?ooo]Z00?o0?lQoookJ_oonfX0
0_oonfX00ooo0?;ooo]Zo`3oEP04oookJP06ool0X?oonf[ooo]ZoookJ_mD0?oo02Go0ooonfX00olZ
0?oo04coool:0004oookJP05og_o0?oonf[ooo]ZoookJ_oo@@001?oonfX00ol0ocSo203ooookJP0:
oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX03ooonfX00ol0okGooo]ZoookJP05
oookJP03o`3oRooonf[ooo]Z01;ooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP07oookJP05oolL0?oo
nf[ooo]ZoookJ_nho`003_oonfX01OoBo`3ooo]ZoookJ_oonf[ogOl000;ooo]Z00?o:`3ooookJ_oo
nfX01?oonfX01?ooV`3oo`00oookJ_o/o`04oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?oE`3ooook
J_oonfX00ooonfX00ooo0=cooo]ZoookJP0SoookJP00@OoonfX2of;o00Gooo]Z2?oUo`03oookJP;o
on<01?oonfX2ool=01oooo]Z1Ol0odd4oookJPWoo`2Z3OoonfX;oeT0o`gooo]Z0_oo0:X?oomi013o
oo]Z0ooo3@02oookJP?oon<00_m/0?l4oookJP;oH_l06?oonfX01ooRo`3o0000oe[o0?mJo`3o0000
oookJ_l0okh00_oonfX01?oo0?Kooo]ZoookJ_l00ol4oookJP03ooo90?oonf[ooo]Z00;ooo]Z00Go
0?mgoookJ_oonf[oN@3ooiOo000:oookJP04oono0?oonf[ooo]Zo`3oXP?ooo]Z00?o0?lQoookJ_oo
nfX00ooonfX00ooo0?;ooo]ZonGo0003oookJP06ool0X?oonf[ooo]ZoookJ_mD0?oo02Go0ooonfX0
0ol0C?oo:P3oool:0004oookJP07og_o0?oonf[ooo]ZoookJ_ooW03ood40oookJP02onGo0003o`3o
>?oUo`3oiOl000;oiOl02?oonfX00ooo803ooo]ZoookJP03oookJP03ool0]Ooonf[ooo]Z00kooo]Z
00?o0?neoookJ_oonfX01?oonfX00ooUo`3ooo]ZoookJP0CoookJP03ool0Cooonf[ooo]Z00;ooo]Z
00?oiOl0oookJ_oonfX01?oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000kooo]Z00GoolT0oookJ_oo
nf[ooo]Zomgo0002oookJP03ob/0oooonf[ooo]Z00?ooo]Z00Cooi/0ool00?oonf[ok?l01?oonfX0
0onC0?oooo]ZoookJP07oookJP03oeL0oooo]`3ooo]Z00;ooo]Z00?oo`3LoookJ_oonfX00_oonfX2
ooo905gooo]Z0_mRo`0:oookJP03of`0oooonf[ooo]Z00?ooo]Z0_ooh`04oookJP?oo`d07ooonfX5
o`3oC@?ooo]Z2Ooo0:X=oookJP_oF@3o3OoonfX9ool0ZP03oookJ_l0odgo0?m=00?o0?m=4_oonfX3
ool=00;ooo]Z0oooh`03of`0o`Cooo]Z0_mRo`0HoookJP06on;o0?l0003oF_l0o`000?oonf[o0?nn
0ooonfX00ooo0?Kooo]Zo`03o`04oookJP03o`3oB?oonf[ooo]Z00?ooo]Z00Go0?mgoookJ_mi0?oo
oo]ZoiOo000:oookJP04oono0?oonf[o08coo`3oXP?ooo]Z00?o0?lQoookJ_oonfX00_oonfX00ooo
0?;ooo]Zo`3oEP03oookJP06ool0X?oonf[ooo]ZoookJ_mD0?oo02Go1?oonfX00olZ0?oooo]Zool:
0004oookJP05og_o0?oonf[ooo]ZoookJ_oo@@000ooonfX00ol0ocSo203ooookJP0;oookJP03oolP
0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX03ooonfX00ol0okGooo]ZoookJP04oookJP03o`3o
Rooonf[ooo]Z01;ooo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP04oookJP03oolL
0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX03?oonfX01?oBo`3ooo]ZoookJ_oMo`02oookJP03
ob/0oooonf[ooo]Z00Cooo]Z00Cooi/0ool00?oonf[ok?l01?oonfX00onC0?oooo]ZoookJP06oook
JP03oeL0oooo]`3ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX08ooonfX003oooo]Z0_mRo`04oookJP[o
iOl00_oonfX2oooS00?ooo]Z0ooo3@0MoookJPCo0?m=0ooonfX6ool0ZPgooo]Z2OmI0?l;oookJPWo
F@3o1OoonfXAoomi0003o`3oCOoonf[ooo]Z00oooo]Z0_oo3@03oookJP;oon<00_m/0?l4oookJP;o
H_l05ooonfX01?oRo`3o0000o`000?mJo`02oookJP04o`3o__oonf[ooo]Zool0mP;ooo]Z00?o00?o
oookJ_oonfX00_oonfX00ooob@3ooo]ZoookJP02oookJP;o0?mg00?ooo]ZogT0oonGo`002_oonfX0
1?oo_`3ooo]ZoookJ_l0oj83oookJP03o`3o8Ooonf[ooo]Z00?ooo]Z00?oo`3boookJ_oUo`000ooo
nfX01Ooo0:3ooo]ZoookJ_mD0?oo02Go00Cooo]Z00?o:P3ooookJ_oo2P001?oonfX01Omko`3ooo]Z
oookJ_ooW03ood4000;ooo]Z0_oUo`000ol0ocSoiOl0onGo0002onGo00Sooo]Z00?oob00oookJ_oo
nfX00_oonfX00ooo0;Gooo]ZoookJP0>oookJP03o`3o]Ooonf[ooo]Z00Gooo]Z00?oiOl0oookJ_oo
nfX04ooonfX01Ooo04oooo]ZoookJ_oonf[oiOl000Kooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000?
oookJP07ooo90?oonf[ooo]Zomgo0?oob@3ooo]Zob/0o`06oookJP04ool00?oo0:Wooo]Zonco00Co
oo]Z00?oT`3ooookJ_oonfX01ooonfX00omG0?oooo]ZoookJP02oookJP04ool0g?oonf[ooo]Zoook
JP;oolT0FooonfX2of;o00[ooo]Z0_m/0?l4oookJP;oon<00ooonfX3ool=01kooo]Z1?l0odd2oook
JPKoo`2Z3OoonfX9oeT0o`_ooo]Z2OmI0?l=oookJPCoo`2Z0_oonfX4o`3oCA7ooo]Z0_oo3@03oook
JP;oon<000?ooo]Zof`0oom/0?l01?oonfX2of;o01Kooo]Z00Co0000on;o0?l0003oF_l00_oonfX0
1ol0okkooo]ZoookJ_oonf[oo`3foookJ_l00ol01?oonfX00ol0odSooo]ZoookJP03oookJP05o`3o
Mooonf[oN@3ooookJ_nGo`002_oonfX01?oo_`3ooo]Zo`2<ool0oj83oookJP03o`3o8Ooonf[ooo]Z
00;ooo]Z00?oo`3boookJ_l0oeH00ooonfX01_oo0:3ooo]ZoookJ_oonf[oE03oo`0Uo`?ooo]Z00Co
:P3oo`1<oooonf[oo`X00ooonfX01_mko`3ooo]ZoookJ_oonf[ooi`0oom100?ooo]Z00?o0?lho`P0
oooonfX02ooonfX01Ooo803ooo]ZoookJ_oonf[oo`2e017ooo]Z00?o0?neoookJ_oonfX01OoonfX0
0ol0oh_ooo]ZoookJP0BoookJP05ool0Cooonf[ooo]ZoookJ_l0oiH01ooonfX01Ooo703ooo]Zoook
J_oonf[o^?l000kooo]Z00Cod_l0oookJ_oonf[ogOl00_oonfX00ol[0?oooo]ZoookJP05oookJP04
ool00?oonf[ooo]Zonco00Cooo]Z00?oT`3ooookJ_oonfX01_oonfX00omG0?oooo]ZoookJP02oook
JP03ool0g?oonf[ooo]Z02?ooo]Z000moookJP;oH_l01?oonfX;onGo0003oookJ_ooh`3oon<000?o
oo]Z0_oo3@0LoookJPCo0?m=1?oonfX3ool0ZP[ooo]Z2OmI0?lMoookJPGoF@3o2?ooN@04oookJP?o
o`2Z0ooonfX3o`3oCA3ooo]Z0_oo3@03oookJP;oon<00_m/0?l4oookJP;oH_l05OoonfX01Ol0003o
h_l0o`000?l0003oF_l000;ooo]Z00Co0?nnoookJ_oonf[oo`3f0_oonfX00ol00ooooo]ZoookJP02
oookJP0:ooo90?oonf[ooo]ZoookJ_oob@3ooo]Zo`3oMooonf[oN@3ooiOo00[ooo]Z00Cookl0oook
J_oonf[o0?nR0ooonfX00ol0ob7ooo]ZoookJP03oookJP03ool0l_oUo`3ooo]Z00?ooo]Z00Goo`2P
oookJ_oonf[oE03oo`0Uo`04oookJP03obX0oooonf[oo`X000?ooo]Z00KoNol0oookJ_oonf[ooo]Z
oonL0?oo@@02oookJP;oiOl000Co0?lhonGo0?oUo`3oiOl02?oonfX00ooo803ooo]ZoookJP03oook
JP03ool0]Ooonf[ooo]Z00kooo]Z00?o0?neoookJ_oonfX01?oonfX00ooUo`3ooo]ZoookJP0Coook
JP05ool0Cooonf[ooo]ZoookJ_oUo`001ooonfX01Ooo703ooo]ZoookJ_oonf[o^?l000kooo]Z1?oo
b@001?oMo`3ooo]ZoookJ_l[0?l5oookJP04oonK0?oo003ooo]Zonco00Cooo]Z00?oT`3ooookJ_oo
nfX01ooonfX00omG0?oooo]ZoookJP02oookJP03ool0g?oonf[ooo]Z00;ooo]Z00?oolT0oookJ_oo
nfX0EooonfX2of;o00_ooo]Z00?oK03ooookJ_oonfX00_oonfX2oooS00?ooo]Z0_oo3@0MoookJPCo
0?m=0ooonfX3ool0ZP[ooo]Z2OmI0?lMoookJPWoF@3o2?oonfX3ool0ZP?ooo]Z0ol0odd@oookJP;o
o`d00ooonfX2oooS0003oookJ_m/0?ooK03o00Cooo]Z0_mRo`0DoookJP;o000000Koh_l0o`000?mJ
o`3oF_l0oookJ_l0okh3oookJP03ool0m_oonf[o00?o00Cooo]Z00?o0?m8oookJ_oonfX00ooonfX0
1Ol0ogOooo]ZogT0oooonf[oUol000Wooo]Z00Gookl0o`2Roooonf[o08coo`3oXP03oookJP03o`3o
8Ooonf[ooo]Z00;ooo]Z00?oo`3bo`3oE_oonfX00ooonfX01_oo0:3ooo]ZoookJ_oonf[oE03oo`0U
o`?ooo]Z00Co:P3oo`1<oooonf[oo`X00ooonfX01_mko`3ooo]ZoookJ_oonf[ooi`0oom100?ooo]Z
00?o0?lho`P0oooonfX02_oonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z00oooo]Z
00?o0?neoookJ_oonfX01?oonfX00ol0oh_ooo]ZoookJP0BoookJP05ool0Cooonf[ooo]ZoookJ_l0
oiH01ooonfX00ooo703ooo]ZoookJP02oookJP03okSo0?oonf[ooo]Z00cooo]Z00Cod_l0oookJ_oo
nf[ogOl00_oonfX00ol[0?oooo]ZoookJP04oookJP04oonK0?oo003ooo]Zonco00Cooo]Z00?oT`3o
oookJ_oonfX01_oonfX00omG0?oooo]ZoookJP03oookJP03ool0g?oonf[ooo]Z02;ooo]Z000loook
JP03of;o0?oonf[ooo]Z00Cooo]Z2_oUo`02oooS00;ooo]Z0ooo3@0JoookJPCo0?m=1OoonfX3ool0
ZPKooo]Z1omI0?l_oookJPKoF@3o1OoonfX4ool0ZP;ooo]Z0ol0odd?oookJP?oo`d00_oonfX00ooo
h`3ooo]Zof`0o`02of`0o`?ooo]Z0_mRo`0CoookJP;o00000_oRo`001Ooonf[oF_l0oe[o0?oonf[o
0?nn00;ooo]Z0_oo0?H00ooonf[o00?ooookJP03oookJP03ooo90?oonf[oolT000;oolT000Gooo]Z
o`3oMooonf[oN@3ooiOo0009oookJP05o`2Roooo_`3ooo]ZoookJ_l0oj800ooonfX00ol0ob7ooo]Z
oookJP03oookJP03ool0l_oUo`3ooo]Z00;ooo]Z00Koo`2PoookJ_oonf[ooo]Zoe@0ool09Ol4oook
JP03obX0oooo2P3ooo]Z00?ooo]Z00KoNol0oookJ_oonf[ooo]ZoonL0?oo@@02oookJP;oiOl000?o
0?lhonGo0?oUo`002OoonfX00ooo803ooo]ZoookJP03oookJP03ool0]Ooonf[ooo]Z00gooo]Z00?o
0?neoookJ_oonfX01OoonfX00ooUo`3ooo]ZoookJP0CoookJP05ool0Cooonf[ooo]ZoookJ_oUo`00
1_oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z1_oob@001?oMo`3ooo]ZoookJ_l[0?l5oook
JP04oonK0?oo003oo`2Yonco00Cooo]Z00?oT`3ooookJ_oonfX01ooonfX00omG0?oooo]ZoookJP02
oookJP03ool0g?oonf[ooo]Z05_ooo]Z00?oH_l0oookJ_oonfX02OoonfX2of`0o`?ooo]Z0_ooh`02
oookJP?oo`d06ooonfX4o`3oC@Cooo]Z0ooo0:X6oookJPOoF@3o;ooonfX7oeT0o`Cooo]Z1?oo0:X2
oookJP?o0?m=3ooonfX3ool=00;ooo]Z00?oon<0oookJ_oonfX00_m/0?l4oookJP03of;o0?oonf[o
oo]Z017ooo]Z0ol000001_oRo`3ooo]ZoookJ_mJo`3ooo]Zo`3o_P?ooo]Z0_oo0?H00ol00ooooo]Z
oookJP02oookJP03o`3oB?oonf[ooo]Z00?ooo]Z00Go0?mgoookJ_mi0?oooo]ZoiOo0009oookJP05
oono0?oonf[ooo]Zo`2<ool0oj800ooonfX00ol0ob7ooo]ZoookJP02oookJP03ool0l_l0oeKooo]Z
00?ooo]Z00Koo`2PoookJ_oonf[oE03ooookJ_l09Ol3oookJP03obX0ool0C?ooo`X000Cooo]Z00Go
Nol0oookJ_oonf[ooo]Zoom10004oookJP03o`3o>?oonf[ooo]Z00[ooo]Z00?oob00oookJ_oonfX0
0_oonfX00ooo0;Gooo]ZoookJP0>oookJP03o`3o]Ooonf[ooo]Z00Gooo]Z00?o0?n;oookJ_oonfX0
4_oonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Oooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000>oook
JP04om;o0?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX01?oonfX01?ooV`3oo`00oookJ_o/
o`04oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?oE`3ooong0?oonfX00ooonfX00ooo0=cooo]Zoook
JP0RoookJP00>_oonfX2of;o00Sooo]Z2?oUo`000oooh`3ooo]ZoookJP02ool=01[ooo]Z0ol0odd6
oookJP?oo`2Z1_oonfX3oeT0occooo]Z1?mI0?l5oookJPCoo`2Z00Cooo]Zo`3oCOl0odgo0?m=3ooo
nfX2ool=0003oookJ_ooh`3oon<000;ooo]Z0_m/0?l3oookJP;oH_l04OoonfX4o`000006on;o0?oo
nf[ooo]Zoe[o0?oonf[o0?nn0ooonfX00ooo0?Kooo]Zo`03o`04oookJPGoolT000Gooo]Zo`3oMooo
nf[oN@3ooiOo0009oookJP05o`2Roooo_`3ooo]Zo`3oX_l0S?l00ooonfX00ol0ob7ooo]ZoookJP03
oookJP03ool0l_oUo`3ooo]Z00;ooo]Z00Koo`2PoookJ_oonf[ooo]Zoe@0ool09Ol3oookJP03obX0
oooonf[oo`X000Cooo]Z00GoNol0oookJ_oonf[ooi`0oom10003oookJP03onGo0?l0ocSoiOl000;o
iOl02?oonfX00ooo803ooo]ZoookJP03oookJP03ool0]Ooonf[ooo]Z00kooo]Z00?o0?neoookJ_oo
nfX01?oonfX00ooUo`3ooo]ZoookJP0CoookJP05ool0Cooonf[ooo]ZoookJ_oUo`001ooonfX01Ooo
703ooo]ZoookJ_oonf[o^?l000[ooo]Z1ooob@001?oMo`3ooo]ZoookJ_l[0?l5oookJP05oonK0?oo
003oo`2YoookJ_o/o`001?oonfX00onC0?oooo]ZoookJP07oookJP03oeL0oooonf[ooo]Z00;ooo]Z
00?oo`3LoookJ_oonfX0F?oonfX2of;o00_ooo]Z00CoK03ooookJ_oonf[ooo]Z0_ooh`02oookJP;o
o`d06ooonfX3o`3oC@Gooo]Z0ooo0:X6oookJP?oF@3o?OoonfX3oeT0o`Gooo]Z1?oo0:X01?oonf[o
0?m=o`3oCOl0odd?oookJP;oo`d000?ooo]ZoooS0?ooh`000_oonfX3of`0o`;ooo]Z0_mRo`0Aoook
JPCo000000Koh_l0oookJ_oonf[oF_l0oookJ_l0okh4oookJP03ool0m_l00ooooo]Z00?ooo]Z00?o
0?m8oookJ_oonfX00ooonfX01Ol0ogOooo]ZogT0oooonf[oUol000Wooo]Z00Cookl0oookJ_oonf[o
0?nR1?oonfX00ol0ob7ooo]ZoookJP02oookJP03ool0l_l0oeKooo]Z00?ooo]Z00Goo`2PoookJ_oo
nf[oE03oo`0Uo`03oookJP04obX0ool0C?oooo]Zool:00?ooo]Z00KoNol0oookJ_oonf[ooo]ZoonL
0?oo@@03oookJP03o`3o>?l80?oooo]Z00[ooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]Z
oookJP0?oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX04_oonfX01Ooo04oooo]Z
oookJ_oonf[o0?nF00Oooo]Z00?ooa`0oookJ_oonfX00_oonfX00onho`3ooo]ZoookJP0;oookJP04
om;o0?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX01?oonfX01OooV`3oo`00oookJ_oonf[o
k?l000Cooo]Z00?oT`3ooookJ_oonfX01_oonfX00omG0?oooo]ZoookJP02oookJP03ool0g?oonf[o
oo]Z02;ooo]Z000hoookJP;oH_l02ooonfX6onGo00?ooo]Z00?oo`d0oookJ_oonfX06?oonfX2o`3o
C@Kooo]Z0ooo0:X6oookJP?oF@3o@ooonfX3oeT0o`Kooo]Z0ooo0:X01?oonf[o0?m=o`3oCOl0odd>
oookJP;oo`d000?ooo]ZoooS0?ooh`000_oonfX2of`0o`?ooo]Z0_mRo`0?oookJPCo000000Oooo]Z
on;o0?oonf[ooo]Zoe[o0?oonf[o0?nn00?ooo]Z00?oo`3foookJ_l00ol00_oonfX6ooo900;ooo]Z
00Co0?mgoookJ_mi0?ooUol02OoonfX01Ol0X_oookl0oookJ_l0oj;o08co00?ooo]Z00?o0?lQoook
J_oonfX00ooonfX00ooo0?;oiOl0oookJP02oookJP06ool0X?oonf[ooo]Zoe@0oooonf[o02Go0ooo
nfX00olZ0?oooo]Zool:0004oookJP05og_o0?oonf[ooo]ZoonL0?oo@@001?oonfX00ol0ocSoiOl0
onGo0009oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?oo`2eoookJ_oonfX03OoonfX00ol0okGooo]Z
oookJP05oookJP03onGo0?oonf[ooo]Z01?ooo]Z00Goo`1?oookJ_oonf[ooo]ZonGo0006oookJP05
oolL0?oonf[ooo]ZoookJ_nho`002_oonfX8ooo90004omgo0?oonf[ooo]Zob/0o`Gooo]Z00Coo`00
ool0ZOoonf[ok?l01?oonfX00onC0?oooo]ZoookJP07oookJP03oeL0oooonf[ooo]Z00;ooo]Z00?o
o`3LoookJ_oonfX0E_oonfX2of;o00_ooo]Z0_m/0?l2oookJP;oon<00ooonfX00ooo3@3ooo]Zoook
JP0IoookJP;o0?m=1OoonfX3ool0ZPKooo]Z0omI0?m3oookJPCoF@3o1OoonfX3ool0ZP04oookJ_l0
odgo0?m=o`3oC@kooo]Z0_oo3@000ooonf[oon<0oooS0003oookJP;oK03o0_oonfX2of;o00oooo]Z
1?l000001?oonf[oh_l0on;o0?oonfX2oe[o0003o`3o__oonf[ooo]Z00;ooo]Z00?oo`3fo`03oooo
nfX00ooonfX00ol0odSooo]ZoookJP03oookJP05o`3oMooonf[oN@3ooookJ_nGo`002OoonfX01?oo
_`3ooo]ZoookJ_l0oj84oookJP03o`3o8Ooonf[ooo]Z00;ooo]Z00?oo`3bo`3oE_oonfX00_oonfX0
1_oo0:3ooo]ZoookJ_oonf[oE03oo`0Uo`?ooo]Z00Co:P3oo`1<oooonf[oo`X00ooonfX01_mko`3o
oo]ZoookJ_oonf[ooi`0oom100?ooo]Z00?o0?lho`P0oooonfX02_oonfX00ooo803ooo]ZoookJP02
oookJP03ool0]Ooonf[ooo]Z00kooo]Z00?o0?neoookJ_oonfX01OoonfX00ol0oh_ooo]ZoookJP0B
oookJP05ool0Cooonf[ooo]ZoookJ_l0oiH01_oonfX00ooo703ooo]ZoookJP02oookJP03okSo0?oo
nf[ooo]Z00cooo]Z00Cod_l0oookJ_oonf[ogOl00_oonfX00ol[0?oooo]ZoookJP04oookJP04ool0
0?oo0:Wooo]Zonco00Cooo]Z00?oT`3ooookJ_oonfX01_oonfX00omG0?oooo]ZoookJP03oookJP03
ool0g?oonf[ooo]Z027ooo]Z000goookJP03of;o0?oonf[ooo]Z00Wooo]Z1ooUo`02oookJP;oo`d0
6OoonfX2o`3oC@Kooo]Z0_oo0:X6oookJP?oF@3o9?oonfXAobT0oaCooo]Z1?mI0?l5oookJPCoo`2Z
0ol0odd=oookJP?oo`d000Coon<0oookJ_oonf[ooo]Z0_m/0?l3oookJP;oH_l03OoonfX4o`0000;o
oo]Z00Koh_l0oookJ_oonf[oF_l0oookJ_l0okh3oookJP03ool0m_oonf[o00?o00SoolT000Kooo]Z
o`3oMooonf[ooo]ZogT0oonGo`09oookJP05oono0?oonf[ooo]Zo`3oX_l0S?l00ooonfX00ol0ob7o
oo]ZoookJP02oookJP03ool0l_oUo`3ooo]Z00?ooo]Z00Goo`2PoookJ_oonf[oE03oo`0Uo`04oook
JP03obX0oooo2P3ooo]Z00?ooo]Z00KoNol0oookJ_oonf[ooo]ZoonL0?oo@@03oookJP04o`3o>?oU
o`3oiOl0onGo00Sooo]Z00?oob00oookJ_oonfX01?oonfX00ooo0;Gooo]ZoookJP0=oookJP03o`3o
]Ooonf[ooo]Z00Cooo]Z00?oiOl0oookJ_oonfX04ooonfX01Ooo04oooo]ZoookJ_oonf[oiOl000Oo
oo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000:oookJPOoolT000CogOl0oookJ_oonf[o:`3o1OoonfX0
1?ooV`3oo`00ool0ZOo/o`05oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?oE`3ooookJ_oonfX00_oo
nfX00ooo0=cooo]ZoookJP1EoookJP03of;o0?oonf[ooo]Z00Wooo]Z0_m/0?l2oookJP;oon<01?oo
nfX00ooo3@3ooo]ZoookJP0HoookJP;o0?m=1OoonfX2ool0ZPKooo]Z0omI0?lToookJQ7o:@3o5Ooo
nfX4oeT0o`Cooo]Z1?oo0:X3o`3oC@gooo]Z0ooo3@02oooS00?ooo]Z0_m/0?l2oookJP;oH_l03Ooo
nfX4o`0000?ooo]Z00Goh_l0oookJ_oonf[oF_l0o`3o_P04oookJP03ool0m_l00ooo00?o00?ooo]Z
00?o0?m8oookJ_oonfX00_oonfX01_l0ogOooo]ZoookJ_mi0?oooo]ZoiOo00Wooo]Z00Cookl0oook
J_oonf[o0?nR1?oonfX01_l0ob7ooo]ZoookJ_oonf[oo`3bo`3oEPCooo]Z00Koo`2PoookJ_oonf[o
oo]Zoe@0ool09Ol3oookJP03obX0ool0C?ooo`X000Cooo]Z00GoNol0oookJ_oonf[ooo]Zoom10003
oookJP03o`3o>?oonf[o203o00[ooo]Z00?oob00oookJ_oonfX00ooonfX00ooo0;Gooo]ZoookJP0>
oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX04_oonfX01Ooo04oooo]ZoookJ_oo
nf[o0?nF00Oooo]Z00?ooa`0oookJ_oonfX00_oonfX00onho`3ooo]ZoookJP0;oookJP04om;o0?oo
nf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX01?oonfX01?ooV`3oo`00oookJ_o/o`05oookJP03
oi<0oooonf[ooo]Z00Gooo]Z00?oE`3ooong0?oonfX00ooonfX00ooo0=cooo]ZoookJP0QoookJP00
=OoonfX2of;o00[ooo]Z0_oUo`02oookJP04oooS0?oUo`3oiOl0onGo00;ooo]Z00?oo`d0oookJ_oo
nfX05ooonfX2o`3oC@Gooo]Z0ooo0:X5oookJP?oF@3o5ooonfX@obT0oa7ooo]Z1_lY0?lBoookJPCo
F@3o1OoonfX3ool0ZP?o0?m=3OoonfX00ooo3@3oon<0oooS0003oookJP03of`0oooonf[ooo]Z00;o
oo]Z00?oH_l0oookJ_oonfX02_oonfX4o`0000?ooo]Z00?oh_l0oookJ_oonfX00_mJo`001Ol0okko
oo]ZoookJ_oonf[oo`3f00[oolT000Kooo]Zo`3oMooonf[ooo]ZogT0oonGo`09oookJP05oono0?oo
nf[ooo]Zo`3oX_l0S?l00_oonfX00ol0ob7ooo]ZoookJP03oookJP03ool0l_oUo`3ooo]Z00?ooo]Z
00Goo`2PoookJ_oonf[oE03oo`0Uo`03oookJP03obX0ool0C?ooo`X000Cooo]Z00KoNol0oookJ_oo
nf[ooo]ZoonL0?oo@@03oookJP03o`3o>?oUo`3oiOl000Wooo]Z00?oob00oookJ_oonfX00ooonfX0
0ooo0;Gooo]ZoookJP0=oookJP03o`3o]Ooonf[ooo]Z00Gooo]Z00?oiOl0oookJ_oonfX04ooonfX0
1?oo04oooo]ZoookJ_oUo`07oookJP05oolL0?oonf[ooo]ZoookJ_nho`002ooonfX6ooo90004omgo
0?oonf[ooo]Zob/0o`Gooo]Z00Gooi/0ool00?oo0:Wooo]Zonco0004oookJP03oi<0oooonf[ooo]Z
00Kooo]Z00?ookL0oeL0oooonfX00ooonfX00ooo0=cooo]ZoookJP1BoookJP;oH_l02ooonfX00om/
0?oooo]ZoookJP02oooS00Cooo]Z0_oo3@0IoookJP;o0?m=1?oonfX3ool0ZPGooo]Z0omI0?lGoook
JQ3o:@3o4OoonfX7obT0oa;ooo]Z0omI0?l5oookJP?oo`2Z0ol0odd=oookJP;oo`d00_ooh`03oook
JP05of`0oooonf[ooo]ZoookJ_mRo`003?oonfX4o`0000Cooo]Z00Goh_l0oookJ_oonf[oF_l0o`3o
_P04oookJP03ool0m_oonf[o00?o00?ooo]Z0_l0odP3oookJP06o`3oMooonf[ooo]ZogT0oooonf[o
Uol02OoonfX01?oo_`3ooo]ZoookJ_l0oj83oookJP03o`3o8Ooonf[ooo]Z00;ooo]Z00?oo`3bo`3o
E_oonfX00ooonfX01Ooo0:3ooo]ZoookJ_mD0?oo02Go00Cooo]Z00?o:P3oo`1<oooo2P000ooonfX0
0omko`3ooo]ZoookJP02oookJP06oom10?oonf[ooo]ZoookJ_l0ocSo203o2ooonfX00ooo803ooo]Z
oookJP02oookJP03ool0]Ooonf[ooo]Z00kooo]Z00?o0?neoookJ_oonfX01OoonfX00ol0oh_ooo]Z
oookJP0BoookJP04ool0Cooonf[ooo]Zo`3oUPOooo]Z00?ooa`0oookJ_oonfX00_oonfX00onho`3o
oo]ZoookJP0<oookJP03om;o0?oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX01?oonfX01OooV`3o
o`00oookJ_oonf[ok?l000Cooo]Z00?oT`3ooookJ_oonfX01_oonfX00omG0?oooo]ZoookJP02oook
JP03ool0g?oonf[ooo]Z027ooo]Z000doookJP03of;o0?oonf[ooo]Z00Wooo]Z00?oiOl0oookJ_oo
nfX00_ooh`02oookJP04onGo0?oonf[ooo]Zool=01Sooo]Z0_l0odd4oookJP?oo`2Z1OoonfX3oeT0
oaKooo]Z1?lY0?lWoookJPOo:@3o3ooonfX3oeT0o`Gooo]Z0_oo0:X01?oonf[o0?m=o`3oCOl0odd<
oookJP03ool=0?ooh`3oon<000;ooo]Z0_m/0?l3oookJP;oH_l02_oonfX4o`0000Cooo]Z0_oRo`02
oookJP03oe[o0?l0okkooo]Z00;ooo]Z00?oo`3foookJ_oob@002?oob@001_oonf[o0?mgoookJ_oo
nf[oN@3ooiOo00Sooo]Z00Ko0:;ooono0?oonf[ooo]Zo`3oX_l0S?l2oookJP03o`3o8Ooonf[ooo]Z
00?ooo]Z00?oo`3bonGo0?oonfX00ooonfX01Ooo0:3ooo]ZoookJ_mD0?oo02Go00?ooo]Z00?o:P3o
ool:0?oonfX01?oonfX01Omko`3ooo]ZoookJ_ooW03ood4000Cooo]Z00?o0?lhonGo0?oonfX02Ooo
nfX00ooo803ooo]ZoookJP03oookJP03ool0]Ooonf[ooo]Z00gooo]Z00?o0?neoookJ_oonfX01?oo
nfX00ooUo`3ooo]ZoookJP0CoookJP05ool0Cooonf[ooo]ZoookJ_oUo`001_oonfX00ooo703ooo]Z
oookJP02oookJP03okSo0?oonf[ooo]Z00Wooo]Z1_oob@001?oMo`3ooo]ZoookJ_l[0?l5oookJP04
ool00?oo0:Wooo]Zonco00Cooo]Z00?oT`3ooookJ_oonfX01ooonfX00omG0?oooo]ZoookJP02oook
JP03ool0g?oonf[ooo]Z057ooo]Z00?oH_l0oookJ_oonfX02OoonfX2of`0o`03oookJ_ooh`3oon<0
00Gooo]Z00?oo`d0oookJ_oonfX05ooonfX2o`3oC@?ooo]Z0ooo0:X5oookJP?oF@3o5_oonfX4obT0
obSooo]Z1_lY0?l?oookJPCoF@3o1?oonfX2ool0ZP04oookJ_l0odgo0?m=o`3oC@cooo]Z00?oo`d0
oookJ_ooh`000ooonfX2of`0o`;ooo]Z0_mRo`0:oookJPCo00001OoonfX01OoRo`3ooo]ZoookJ_mJ
o`3o0?nn00Cooo]Z00?oo`3foookJ_l00ol01?oonfX01Ol0odSooo]ZoookJ_oonf[o0?mg00;ooo]Z
00?oN@3ooookJ_nGo`002?oonfX01Ol0X_oookl0oookJ_oonf[o0?nR00?ooo]Z00?o0?lQoookJ_oo
nfX00_oonfX00ooo0?;o0?mFoookJP03oookJP05ool0X?oonf[ooo]Zoe@0ool09Ol00ooonfX00olZ
0?oo04coool:0004oookJP06og_o0?oonf[ooo]ZoookJ_ooW03ood400ooonfX00ol0ocSo203ooook
JP09oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?oo`2eoookJ_oonfX03_oonfX00ol0okGooo]Zoook
JP04oookJP03o`3oRooonf[ooo]Z01;ooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP07oookJP03oolL
0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX02ooonfX01?oBo`3ooo]ZoookJ_oMo`02oookJP03
ob/0oooonf[ooo]Z00Cooo]Z00Coo`00ool0ZOoonf[ok?l01?oonfX00onC0?oooo]ZoookJP06oook
JP03oeL0oooonf[ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX08?oonfX003?ooo]Z00?oH_l0oookJ_oo
nfX02?oonfX2onGo00;ooo]Z00?oon<0oookJ_oonfX00ooonfX2ool=01Oooo]Z0_l0odd3oookJP?o
o`2Z1OoonfX3oeT0oaGooo]Z1?lY0?lDoookJPco0?o`4_oonfX6obT0o`cooo]Z1?mI0?l3oookJP;o
o`2Z0_oonfX3o`3oC@[ooo]Z0_oo3@02oooS00;ooo]Z00?oK03ooookJ_oonfX00_oonfX00omRo`3o
oo]ZoookJP07oookJPGo00001OoonfX01?oRo`3ooo]ZoookJ_mJo`02o`3o_P;ooo]Z00?oo`3foook
J_oonfX01ooob@02oookJP05o`3oMooonf[ooo]ZogT0oonGo`002?oonfX01_l0X_oookl0oookJ_oo
nf[o0?nRo`2<o`;ooo]Z00?o0?lQoookJ_oonfX00ooonfX00ooo0?;oiOl0oookJP02oookJP06ool0
X?oonf[ooo]Zoe@0oooonf[o02Go0ooonfX00olZ0?ooo`X0oookJP03oookJP06og_o0?oonf[ooo]Z
oookJ_ooW03ood400ooonfX00ol0ocSooo]ZonGo0009oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?o
o`2eoookJ_oonfX03_oonfX00ol0okGooo]ZoookJP04oookJP03onGo0?oonf[ooo]Z01?ooo]Z00Co
o`1?oookJ_oonf[oiOl01ooonfX01Ooo703ooo]ZoookJ_oonf[o^?l000_ooo]Z1_oob@001?oMo`3o
oo]ZoookJ_l[0?l5oookJP04oonK0?oo003oo`2Yonco00Gooo]Z00?oT`3ooookJ_oonfX01_oonfX0
0ooo]`3oE`3ooookJP02oookJP03ool0g?oonf[ooo]Z053ooo]Z00?oH_l0oookJ_oonfX02OoonfX0
1?m/0?oooo]ZoookJ_ooh`06oookJP03ool=0?oonf[ooo]Z01Kooo]Z0_l0odd2oookJP?oo`2Z1Ooo
nfX3oeT0oaKooo]Z0olY0?lEoookJP_o0?o`4_oonfX7obT0o`cooo]Z0omI0?l3oookJP;oo`2Z0_oo
nfX3o`3oC@[ooo]Z0_oo3@02oooS00?ooo]Z00GoK03ooookJ_oonf[ooo]Zof;o0009oookJPGo0000
1OoonfX00ooRo`3ooo]ZoookJP02oe[o0007o`3o__oonf[ooo]ZoookJ_oo0?Kooo]Zo`03o`04oook
JP05o`3oB?oonf[ooo]ZoookJ_l0ogL00_oonfX00omi0?oooo]ZoiOo0008oookJP05o`2Roooo_`3o
oo]ZoookJ_l0oj800ooonfX00ol0ob7ooo]ZoookJP02oookJP03ool0l_l0oeKooo]Z00?ooo]Z00Go
o`2PoookJ_oonf[oE03oo`0Uo`03oookJP03obX0ool0C?ooo`X000Cooo]Z00GoNol0oookJ_oonf[o
oo]Zoom10003oookJP03o`3o>?oonf[o203o00[ooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Go
oo]ZoookJP0>oookJP03o`3o]Ooonf[ooo]Z00Gooo]Z00?o0?n;oookJ_oonfX04_oonfX01?oo04oo
oo]ZoookJ_l0oiH7oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX02ooonfX01?oB
o`3ooo]ZoookJ_oMo`02oookJP03ob/0oooonf[ooo]Z00Cooo]Z00Cooi/0ool00?oonf[ok?l01Ooo
nfX00onC0?oooo]ZoookJP05oookJP03oong0?mG0?oooo]Z00?ooo]Z00?oo`3LoookJ_oonfX08?oo
nfX003;ooo]Z00?oH_l0oookJ_oonfX02?oonfX01OoUo`3ooo]ZoookJ_oonf[oon<000Gooo]Z00?o
o`d0oookJ_oonfX05OoonfX2o`3oC@;ooo]Z0ooo0:X5oookJP?oF@3o5?oonfX4obT0o`oooo]Z2Ol0
oo0<oookJPgo0?o`2ooonfX5obT0o`_ooo]Z0omI0?l2oookJP?oo`2Z0_oonfX2o`3oC@[ooo]Z0_oo
3@000oooh`3ooo]ZoookJP02of`0o`?ooo]Z00?oH_l0oookJ_oonfX01_oonfX4o`0000Oooo]Z00?o
h_l0oookJ_oonfX00_mJo`000ol0okkooo]ZoookJP02ool0mP03oookJ_l00oooolT000GoolT00_oo
nfX01Ol0ogOooo]ZoookJ_mi0?ooUol000Sooo]Z00Ko0:;ooono0?oonf[o0?nRoookJ_l0S?l2oook
JP03o`3o8Ooonf[ooo]Z00;ooo]Z00?oo`3bonGo0?oonfX00ooonfX01Ooo0:3ooo]ZoookJ_mD0?oo
02Go00?ooo]Z00?o:P3oo`1<oooo2P001?oonfX01_mko`3ooo]ZoookJ_oonf[ooi`0oom100?ooo]Z
00?o0?lho`P0oooonfX02OoonfX00ooo803ooo]ZoookJP03oookJP03ool0]Ooonf[ooo]Z00gooo]Z
00?o0?neoookJ_oonfX01?oonfX00ooUo`3ooo]ZoookJP0CoookJP05ool0Cooonf[ooo]ZoookJ_oU
o`001_oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z1Ooob@001?oMo`3ooo]ZoookJ_l[0?l5
oookJP04oonK0?oo003oo`2Yonco00Gooo]Z00?oT`3ooookJ_oonfX01_oonfX00ooo]`3oE`3ooook
JP03oookJP03ool0g?oonf[ooo]Z04kooo]Z00?oH_l0oookJ_oonfX02?oonfX2of`0o`;ooo]Z00?o
on<0oookJ_oonfX00ooonfX2ool=01Oooo]Z0_l0odd01?oonf[oo`2Zool0Z_oo0:X5oookJP?oF@3o
5OoonfX4obT0o`oooo]Z2Ol0oo0;oookJPgo0?o`3?oonfX5obT0o`[ooo]Z0omI0?l2oookJP?oo`2Z
0_oonfX2o`3oC@[ooo]Z0_oo3@02oooS00;ooo]Z00GoK03ooookJ_oonf[ooo]Zof;o0008oookJPCo
00001ooonfX01_oRo`3ooo]ZoookJ_oonf[oF_l0o`3o_P?ooo]Z0_oo0?H00ol00ooooo]ZoookJP02
oookJP05o`3oB?oonf[ooo]ZoookJ_l0ogL00_oonfX00omi0?oooo]ZoiOo0008oookJP05o`2Roooo
_`3ooo]Zo`3oX_l0S?l00ooonfX01_l0ob7ooo]ZoookJ_oonf[oo`3bo`3oEPCooo]Z00Koo`2Poook
J_oonf[ooo]Zoe@0ool09Ol3oookJP03obX0ool0C?ooo`X000Cooo]Z00GoNol0oookJ_oonf[ooo]Z
oom10003oookJP03o`3o>?l80?oooo]Z00Wooo]Z00?oob00oookJ_oonfX00ooonfX00ooo0;Gooo]Z
oookJP0=oookJP03o`3o]Ooonf[ooo]Z00Gooo]Z00?o0?n;oookJ_oonfX04_oonfX01Ooo04oooo]Z
oookJ_oonf[o0?nF00Oooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000>oookJP03om;o0?oonf[ogOl0
00;ooo]Z00?o:`3ooookJ_oonfX01?oonfX01?ooV`3oo`00oookJ_o/o`05oookJP03oi<0oooonf[o
oo]Z00Kooo]Z00?oE`3ooookJ_oonfX00_oonfX00ooo0=cooo]ZoookJP0PoookJP00<OoonfX00omR
o`3ooo]ZoookJP07oookJP;oiOl00ooonfX00oooh`3ooo]ZoookJP02oookJP;oo`d05ooonfX00ol0
odgooo]ZoookJP02onGo00Gooo]Z0omI0?lDoookJP?o:@3o2_oonfX9o`3ol2;ooo]Z2?l0oo08oook
JP?o:@3o2ooonfX2oeT0o`?ooo]Z0_oo0:X2oookJP;o0?m=2_oonfX00ooo3@3oon<0oooS0002oook
JP04of`0oooonf[ooo]ZoookJP;oH_l01_oonfX4o`0000Sooo]Z00Koh_l0oookJ_oonf[ooo]Zoe[o
0?l0okh3oookJP04ool0m_oonf[o00?ooookJPGoolT00_oonfX01Ol0ogOooo]ZoookJ_mi0?ooUol0
00Sooo]Z00So0:;ooono0?oonf[o0?nRoookJ_oUo`3ooo]Zo`3o8@Gooo]Z00?oo`3bonGo0?oonfX0
0ooonfX01Ooo0:3ooo]ZoookJ_mD0?oo02Go00?ooo]Z00?o:P3oool:0?oonfX01?oonfX01Omko`3o
oo]ZoookJ_oonf[ood4000?ooo]Z00?o0?lhoookJ_l80?l02OoonfX00ooo803ooo]ZoookJP04oook
JP03ool0]Ooonf[ooo]Z00gooo]Z00?o0?neoookJ_oonfX01?oonfX00ooUo`3ooo]ZoookJP0Coook
JP04ool0Cooonf[ooo]ZonGo00Oooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJPGoolT000?o
gOl0oookJ_l[0?l01_oonfX01?oo003oo`2YoookJ_o/o`04oookJP03oi<0oooonf[ooo]Z00Oooo]Z
00?oE`3ooookJ_oonfX00_oonfX00ooo0=cooo]ZoookJP1=oookJP03of;o0?oonf[ooo]Z00Sooo]Z
00GoK03ooookJ_oonf[ooo]ZoooS0005oookJP03ool=0?oonf[ooo]Z01Gooo]Z0_l0odd00ooonf[o
o`2Zool0ZP05oookJP?oF@3o5?oonfX4obT0o`[ooo]Z2Ol0oo0QoookJPSo0?o`2OoonfX3obT0o`[o
oo]Z0_mI0?l3oookJP;oo`2Z0_oonfX2o`3oC@[ooo]Z00Goo`d0oookJ_ooh`3oon<0oookJP02of`0
o`;ooo]Z0_mRo`06oookJPCo00002?oonfX2on;o00;ooo]Z00?oF_l0o`3o__oonfX00ooonfX00ooo
0?Ko00?ooookJP03oookJP05o`3oB?oonf[ooo]ZoookJ_l0ogL00_oonfX00omi0?oooo]ZoiOo0008
oookJP05o`2Roooo_`3ooo]Zo`3oX_l0S?l00_oonfX00ol0ob7ooo]ZoookJP02oookJP03ool0l_l0
oeKooo]Z00?ooo]Z00Goo`2PoookJ_oonf[oE03oo`0Uo`03oookJP03obX0oooonf[oo`X000Cooo]Z
00?oNol0oookJ_oonfX00_oonfX01_oo@@3ooo]ZoookJ_l0ocSooo]Zo`P0o`[ooo]Z00?oob00oook
J_oonfX00ooonfX00ooo0;Gooo]ZoookJP0=oookJP03o`3o]Ooonf[ooo]Z00Gooo]Z00?o0?n;oook
J_oonfX04_oonfX01?oo04oooo]ZoookJ_l0oiH7oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0
oookJ_oonfX02ooonfX01_oBo`3ooo]ZoookJ_oMo`3ooo]Zob/0o`Oooo]Z00Coo`00ool0ZOoonf[o
k?l01?oonfX00onC0?oooo]ZoookJP06oookJP03oeL0oooonf[ooo]Z00?ooo]Z00?oo`3LoookJ_oo
nfX07ooonfX0033ooo]Z00?oH_l0oookJ_oonfX01ooonfX00ooUo`3ooo]ZoookJP02oookJP03oooS
0?oonf[ooo]Z00;ooo]Z00?oo`d0oookJ_oonfX05OoonfX2o`3oC@CoiOl00ooonfX3oeT0oa?ooo]Z
1?lY0?l8oookJPGo0?o`<ooonfX4o`3ol0Oooo]Z0olY0?l:oookJP;oF@3o0ooonfX2ool0ZP;ooo]Z
00?o0?m=oookJ_oonfX02?oonfX2ool=00;oon<000?ooo]Zof`0oom/0?l00ooonfX00omRo`3ooo]Z
oookJP03oookJPCo00002OoonfX01_oRo`3ooo]ZoookJ_oonf[oF_l0o`3o_P?ooo]Z00?oo`3foook
J_l00ol00_oonfX3ooo900?ooo]Z00Go0?mgoookJ_oonf[oN@3ooiOo0008oookJP05o`2Roooo_`3o
oo]Zo`3oX_oUo`000_oonfX00ol0ob7ooo]ZoookJP03oookJP03ool0l_oUo`3ooo]Z00;ooo]Z00Ko
iOl0ool0X?oonf[ooo]Zoe@0ool09Ol3oookJP03obX0oooo2P3ooo]Z00?ooo]Z00KoNol0oookJ_oo
nf[ooo]ZonGo0?oo@@03oookJP03o`3o>?l80?oooo]Z00Wooo]Z00?oob00oookJ_oonfX00ooonfX0
0ooo0;Gooo]ZoookJP0=oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?oiOl0oookJ_oonfX04ooonfX0
1?oo04oooo]ZoookJ_oUo`07oookJP05oolL0?oonf[ooo]ZoookJ_nho`003OoonfX4ooo90004omgo
0?oonf[ooo]Zob/0o`Gooo]Z00Cooi/0ool00?oo0:Wok?l01OoonfX00onC0?oooo]ZoookJP06oook
JP03oong0?mG0?oooo]Z00;ooo]Z00?oo`3LoookJ_oonfX0C?oonfX00omRo`3ooo]ZoookJP07oook
JP;oK03o0ooonfX00oooh`3ooo]ZoookJP03oookJP03ool=0?oonf[ooo]Z01Cooo]Z0_l0odd2oook
JP03ool0Z_oonf[ooo]Z00;ooo]Z0omI0?lDoookJP?o:@3o2OoonfX5o`3ol3;ooo]Z1?l0oo08oook
JP?o:@3o2OoonfX2oeT0o`?ooo]Z0_oo0:X2oookJP03o`3oCOoonf[ooo]Z00Sooo]Z0_oo3@001Ooo
nf[oon<0oooS0?oonf[oK03o00?ooo]Z00?oH_l0oookJ_oonfX00ooonfX4o`0000[ooo]Z00Goh_l0
oookJ_oonf[oF_l0o`3o_P04oookJP03ool0m_l00ooooo]Z00?ooo]Z00Go0?m8oookJ_oonf[ooo]Z
o`3oM`02oookJP03ogT0oooonf[oUol000Oooo]Z00Go0:;ooookJ_oo_`3ooo]Zo`3oXP03oookJP03
o`3o8Ooonf[ooo]Z00;ooo]Z00?oo`3bo`3oE_oonfX00ooonfX01Ooo0:3ooo]ZoookJ_mD0?oo02Go
00?ooo]Z00?o:P3oo`1<oooo2P001?oonfX01Omko`3ooo]ZoookJ_oonf[ood4000?ooo]Z00?o0?lh
o`P0oooonfX02OoonfX00ooo803ooo]ZoookJP03oookJP03ool0]Ooonf[ooo]Z00gooo]Z00?o0?ne
oookJ_oonfX01OoonfX00ol0oh_ooo]ZoookJP0BoookJP04ool0Cooonf[ooo]Zo`3oUPOooo]Z00?o
oa`0oookJ_oonfX00_oonfX00onho`3ooo]ZoookJP0<oookJP03om;o0?oonf[ogOl000;ooo]Z00?o
:`3ooookJ_oonfX01?oonfX01?ooV`3oo`00oookJ_o/o`05oookJP03oi<0oooonf[ooo]Z00Gooo]Z
00?ookL0oeL0oooonfX00ooonfX00ooo0=cooo]ZoookJP0OoookJP00;ooonfX00omRo`3ooo]Zoook
JP06oookJP;oiOl01?oonfX00oooh`3ooo]ZoookJP02oookJP03ool=0?oonf[ooo]Z01Cooo]Z0_l0
odd5onGo00?ooo]Z00?oF@3ooookJ_oonfX04?oonfX4obT0o`Wooo]Z0ol0oo0PoookJP[oonP04_oo
nfX4o`3ol0Kooo]Z0olY0?l9oookJP;oF@3o0ooonfX2ool0ZP03oookJ_l0odgo0?m=00[ooo]Z0_oo
3@001?ooh`3ooo]ZoookJ_m/0?l3oookJP;oH_l00ooonfX4o`0000[ooo]Z0_oRo`02oookJP03oe[o
0?l0okkooo]Z00;ooo]Z00?oo`3foookJ_l00ol00ooonfX2ooo900?ooo]Z00Go0?mgoookJ_oonf[o
N@3ooiOo0008oookJP05o`2Roooo_`3ooo]Zo`3oX_oUo`000_oonfX00ol0ob7ooo]ZoookJP02oook
JP04ool0l_oonf[oiOl0oookJP?oiOl000Goo`2PoookJ_mD0?oooo]Zo`0Uo`02oookJP03obX0ool0
C?ooo`X000Cooo]Z00KoNol0oookJ_oonf[ooo]ZonGo0?oo@@02oookJP03o`3o>?oonf[o203o00Wo
oo]Z00?oob00oookJ_oonfX01?oonfX00ooo0;Gooo]ZoookJP0=oookJP03o`3o]Ooonf[ooo]Z00?o
oo]Z00?oiOl0oookJ_oonfX05?oonfX01?oo04oooo]ZoookJ_oUo`07oookJP05oolL0?oonf[ooo]Z
oookJ_nho`003OoonfX3ooo90004omgo0?oonf[ooo]Zob/0o`Gooo]Z00Cooi/0ool00?oo0:Wok?l0
1OoonfX00onC0?oooo]ZoookJP06oookJP03oong0?mG0?oooo]Z00?ooo]Z00?oo`3LoookJ_oonfX0
B_oonfX00omRo`3ooo]ZoookJP07oookJP03of`0oooonf[ooo]Z00;ooo]Z00?oon<0oookJ_oonfX0
0_oonfX2ool=01Gooo]Z0_l0odd2oookJP;oo`2Z1?oonfX00omI0?oooo]ZoookJP0AoookJPCo:@3o
2OoonfX3o`3ol1oooo]Z2_ooj00BoookJPCo0?o`1ooonfX3obT0o`Sooo]Z0omI0?l2oookJP;oo`2Z
00?ooo]Zo`3oCOl0odd02_oonfX2ool=0003oookJ_ooh`3ooo]Z00;oK03o0_oonfX2of;o00?ooo]Z
1?l0000;oookJP05on;o0?oonf[ooo]Zoe[o0?l0okh01?oonfX00ooo0?Ko00?ooookJP03oookJP05
o`3oB?oonf[ooo]ZoookJ_l0ogL00_oonfX00omi0?oooo]ZoiOo0007oookJP05o`2Roooonf[ookl0
oookJ_l0oj800ooonfX01ol0ob7ooo]ZoookJ_oonf[oo`3boookJ_l0oeH01?oonfX01Ooo0:3ooo]Z
oookJ_mD0?oo02Go00?ooo]Z00?o:P3oo`1<oooo2P001?oonfX01Omko`3ooo]ZoookJ_oonf[ood40
00?ooo]Z00?o0?lho`P0oooonfX02OoonfX00ooo803ooo]ZoookJP03oookJP03ool0]Ooonf[ooo]Z
00gooo]Z00?o0?neoookJ_oonfX01?oonfX00ol0oh_ooo]ZoookJP0CoookJP04ool0Cooonf[ooo]Z
o`3oUPOooo]Z00?ooa`0oookJ_oonfX00_oonfX00onho`3ooo]ZoookJP0;oookJP03om;o0?oonf[o
gOl000;ooo]Z00?o:`3ooookJ_oonfX01?oonfX01?ooV`3oo`00ool0ZOo/o`05oookJP03oi<0oooo
nf[ooo]Z00Kooo]Z00?oE`3ooookJ_oonfX00_oonfX00ooo0=cooo]ZoookJP0OoookJP00;_oonfX0
0omRo`3ooo]ZoookJP05oookJP;oiOl01OoonfX01?ooh`3ooo]ZoookJ_oonfX2ool=01Gooo]Z0_l0
odd6onGo00;ooo]Z0_mI0?l@oookJP?o:@3o2_oonfX3o`3ol1Kooo]Z3Oooj007ool02`?ooo]Z1_oo
j00@oookJPCo0?o`1OoonfX3obT0o`Sooo]Z0_mI0?l3oookJP;oo`2Z00?ooo]Zo`3oCOl0odd02_oo
nfX01?oo3@3oon<0oooS0?oonfX2of`0o`?ooo]Z00?oH_l0oookJ_oonfX01?l0000<oookJP05on;o
0?oonf[oF_l0oookJ_l0okh00ooonfX00ooo0?Kooo]Zo`03o`04oookJP04ooo90?oonf[ooo]Zo`3o
M`?ooo]Z00?oN@3ooiOo0?oonfX01_oonfX02?l0X_oooo]Zoono0?oonf[o0?nRonGo0?oonf[o0?lQ
1OoonfX00ooo0?;oiOl0onGo0004onGo0005ool0X?oonf[oE03ooookJ_l09Ol00_oonfX00olZ0?oo
o`X0oookJP04oookJP06og_o0?oonf[ooo]ZonGo0?oonf[ood400_oonfX00ol0ocSo203ooookJP09
oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?oo`2eoookJ_oonfX03OoonfX00ol0okGooo]ZoookJP04
oookJP03onGo0?oonf[ooo]Z01?ooo]Z00Coo`1?oookJ_oonf[oiOl01ooonfX01Ooo703ooo]Zoook
J_oonf[o^?l000gooo]Z0ooob@001?oonf[ogOl0oookJ_l[0?l5oookJP04oonK0?oo003ooo]Zonco
00Gooo]Z00?oT`3ooookJ_oonfX01_oonfX00ooo]`3oE`3ooookJP03oookJP03ool0g?oonf[ooo]Z
04Wooo]Z00?oH_l0oookJ_oonfX01_oonfX2of`0o`Cooo]Z00?oon<0oookJ_oonfX00_oonfX00ooo
3@3ooo]ZoookJP0CoookJP;o0?m=0ooonfX00ooo0:[ooo]ZoookJP02oookJP;oF@3o4OoonfX3obT0
o`[ooo]Z0ol0oo0EoookJPgoonP01ooo00/3oookJPKoonP04?oonfX5o`3ol0Gooo]Z0olY0?l8oook
JP;oF@3o0_oonfX2ool0ZP03oookJ_l0odgo0?m=00[ooo]Z00Koo`d0oookJ_ooh`3oon<0oookJ_m/
0?l3oookJP03of;o0?oonf[ooo]Z00Co00003?oonfX01OoRo`3ooo]ZoookJ_mJo`3o0?nn00Cooo]Z
00?oo`3fo`03oooonfX00ooonfX01Ol0odSooo]ZoookJ_oonf[o0?mg00;ooo]Z00?oN@3ooookJ_nG
o`001ooonfX01Ol0X_oooo]Zoono0?oonf[o0?nR00;ooo]Z00?o0?lQoookJ_oonfX00_oonfX00ooo
0?;ooo]Zo`3oEP04oookJP05ool0X?oonf[ooo]Zoe@0ool09Ol00_oonfX00olZ0?oooo]Zool:0004
oookJP06og_o0?oonf[ooo]ZoookJ_ooW03ood400_oonfX00ol0ocSo203ooookJP09oookJP03oolP
0?oonf[ooo]Z00?ooo]Z00?oo`2eoookJ_oonfX03OoonfX00ol0okGooo]ZoookJP05oookJP03o`3o
Rooonf[ooo]Z01;ooo]Z00Coo`1?oookJ_oonf[o0?nF1ooonfX00ooo703ooo]ZoookJP02oookJP03
okSo0?oonf[ooo]Z00cooo]Z00God_l0oookJ_oMo`3ooo]Zob/0o`06oookJP04oonK0?oo003oo`2Y
onco00Gooo]Z00?oT`3ooookJ_oonfX01_oonfX00omG0?oooo]ZoookJP03oookJP03ool0g?oonf[o
oo]Z01kooo]Z000]oookJP03of;o0?oonf[ooo]Z00Gooo]Z00?oiOl0oookJ_oonfX01?oonfX01Ooo
h`3ooo]ZoookJ_oonf[oo`d001Cooo]Z00?oiOl0o`3oCOl0odd01ooUo`02oookJP03oeT0oooonf[o
oo]Z00kooo]Z0_lY0?l:oookJP?o0?o`4OoonfX8oooX00Woo`0;2ooonfX8ool02`03oookJ_ooj03o
onP000CoonP03_oonfX4o`3ol0Cooo]Z0olY0?l7oookJP?oF@3o0_oonfX3ool0ZP03o`3oCOoonf[o
oo]Z00Sooo]Z0_oo3@02onGo0003oookJ_m/0?oooo]Z00;ooo]Z0_mRo`04o`0000gooo]Z00Goh_l0
oookJ_mJo`3ooo]Zo`3o_P03oookJP03ool0m_oonf[o00?o00?ooo]Z00Go0?m8oookJ_oonf[ooo]Z
o`3oM`03oookJP03ogT0oonGo`3ooo]Z00Kooo]Z00Go0:;ooono0?oonf[o0?nRonGo0002oookJP03
o`3o8Ooonf[ooo]Z00;ooo]Z00?oiOl0ool0l_oUo`001?oUo`001Ooo0:3ooo]ZoookJ_mD0?oo02Go
00;ooo]Z00?o:P3ooookJ_oo2P001?oonfX01_mko`3ooo]ZoookJ_oonf[oiOl0oom100;ooo]Z00?o
0?lhoookJ_l80?l02OoonfX00ooo803ooo]ZoookJP04oookJP03ool0]Ooonf[ooo]Z00gooo]Z00?o
0?neoookJ_oonfX00ooonfX00ooUo`3ooo]ZoookJP0CoookJP04ool0Cooonf[ooo]ZonGo00Sooo]Z
00Gooa`0oookJ_oonf[ooo]ZokSo000=oookJP?oolT000CogOl0oookJ_oonf[o:`3o1OoonfX01?oo
003ooo]Zool0ZOo/o`05oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?ookL0oeL0oooonfX00_oonfX0
0ooo0=cooo]ZoookJP18oookJP03of;o0?oonf[ooo]Z00Kooo]Z00?oK03ooookJ_oonfX00ooonfX0
1?ooh`3ooo]ZoookJ_oonfX2ool=01Cooo]Z0_l0odd3oookJP;oo`2Z1?oonfX00omI0?oooo]Zoook
JP0?oookJP;o:@3o2_oonfX3o`3ol13ooo]Z2?ooj009ool02`_ooo]Z2Ooo00/7oooX00kooo]Z1?l0
oo04oookJP?o:@3o1ooonfX2oeT0o`;ooo]Z0ooo0:X2o`3oC@Wooo]Z0_oo3@000ooonf[oon<0oooS
0002of`0o`;ooo]Z0_mRo`04o`0000gooo]Z00Goh_l0oookJ_oonf[oF_l0o`3o_P04oookJP03ool0
m_l00ooooo]Z00;ooo]Z00?o0?m8oookJ_oonfX00_oonfX01_l0ogOooo]ZoookJ_mi0?oooo]ZoiOo
00Oooo]Z00Go0:;ooono0?oonf[o0?nRo`2<o`02oookJP03o`3o8Ooonf[ooo]Z00;ooo]Z00?oo`3b
o`3oE_oonfX00ooonfX01Ooo0:3ooo]ZoookJ_mD0?oo02Go00?ooo]Z00?o:P3ooookJ_oo2P001?oo
nfX01Omko`3ooo]ZoookJ_oonf[ood4000?ooo]Z00?o0?lho`P0oooonfX02OoonfX00ooo803ooo]Z
oookJP03oookJP03ool0]Ooonf[ooo]Z00gooo]Z00?o0?neoookJ_oonfX01?oonfX00ol0oh_ooo]Z
oookJP0BoookJP04ool0Cooonf[ooo]Zo`3oUPSooo]Z00?ooa`0oookJ_oonfX00_oonfX00onho`3o
oo]ZoookJP0;oookJP03om;o0?oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX01?oonfX01?oo003o
o`2YoookJ_o/o`05oookJP03oi<0oooonf[ooo]Z00Gooo]Z00?ookL0oeL0oooonfX00ooonfX00ooo
0=cooo]ZoookJP0NoookJP00;?oonfX00omRo`3ooo]ZoookJP05oookJP03onGo0?oonf[ooo]Z00?o
oo]Z0_ooh`02oookJP;oo`d04ooonfX00ooUo`3o0?m=o`3oC@08onGo0003oookJ_mI0?ooF@3o00oo
oo]Z0_lY0?l9oookJP?o0?o`4OoonfX3oooX00Coo`0;8?oonfX7ool02`KoonP03?oonfX4o`3ol0?o
oo]Z0olY0?l6oookJP03o`00OomI0?ooF@3o00;o001o00Cooo]Zool0Z_l0odgo0?m=0ol007l3oook
JPCo001o0_oo3@001?oUo`3ooo]Zof`0oom/0?l3oookJP04of;o0?l0003o0000o`0000kooo]Z00Go
h_l0oookJ_mJo`3ooo]Zo`3o_P03oookJP03ool0m_oonf[o00?o00?ooo]Z00Go0?m8oookJ_oonf[o
oo]Zo`3oM`03oookJP03ogT0oonGo`3ooo]Z00Kooo]Z00Go0:;ooono0?oonf[o0?nRonGo0002oook
JP03o`3o8Ooonf[ooo]Z00?oiOl000?oo`3bonGo0?oUo`000ooUo`001Ooo0:3ooo]ZoookJ_mD0?oo
02Go00;ooo]Z00?o:P3oool:0?oonfX01?oonfX01_mko`3ooo]ZoookJ_oUo`3ooo]Zoom100;ooo]Z
00?o0?lho`P0oooonfX02OoonfX00ooo803ooo]ZoookJP04oookJP03ool0]Ooonf[ooo]Z00cooo]Z
00?o0?neoookJ_oonfX01?oonfX00ooUo`3ooo]ZoookJP0CoookJP04ool0Cooonf[ooo]ZonGo00Oo
oo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000>oookJP;oolT000CogOl0oookJ_oonf[o:`3o1OoonfX0
1?ooV`3oo`00ool0ZOo/o`05oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?ookL0oeL0oooonfX00ooo
nfX00ooo0=cooo]ZoookJP16oookJP03of;o0?oonf[ooo]Z00Kooo]Z00?oK03ooookJ_oonfX00ooo
nfX01Oooh`3ooo]ZoookJ_oonf[oo`d001Cooo]Z0_l0odd4oookJP03ool0Z_oonf[ooo]Z00;ooo]Z
0_mI0?l@oookJP;o:@3o2OoonfX3o`3ol13ooo]Z0oooj004ool02b7ooo]Z1ooo00/6oooX00cooo]Z
1?l0oo03oookJP?o:@3o1OoonfX00ol007ooF@3ooeT0o`02o`00O`03oookJ_oo0:[oo`2Z00;o0?m=
0_l007l3oookJPCo001o0_oo3@001?oonf[oon<0oookJ_m/0?l3oookJP04of;o0?l0003o0000o`00
00kooo]Z00Goh_l0oookJ_oonf[oF_l0o`3o_P04oookJP03ool0m_l00ooooo]Z00;ooo]Z00?o0?m8
oookJ_oonfX00_oonfX01_l0ogOooo]ZoookJ_mi0?oooo]ZoiOo00Oooo]Z00Co0:;ooono0?oonf[o
0?nR0ooonfX00ol0ob7ooo]ZoookJP02oookJP03ool0l_l0oeKooo]Z00?ooo]Z00Goo`2PoookJ_oo
nf[oE03oo`0Uo`03oookJP03obX0oooo2P3ooo]Z00Cooo]Z00GoNol0oookJ_oonf[ooi`0oom10002
oookJP03o`3o>?l80?oooo]Z00Wooo]Z00?oob00oookJ_oonfX01?oonfX00ooo0;Gooo]ZoookJP0<
oookJP03o`3o]Ooonf[ooo]Z00Gooo]Z00?o0?n;oookJ_oonfX04_oonfX01?oo04oooo]ZoookJ_l0
oiH7oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX02ooonfX00ooBo`3ooo]Zomgo
0002oookJP03ob/0oooonf[ooo]Z00Cooo]Z00Cooi/0ool00?oo0:Wok?l01OoonfX00onC0?oooo]Z
oookJP05oookJP03oong0?mG0?oooo]Z00?ooo]Z00?oo`3LoookJ_oonfX07_oonfX002_ooo]Z00?o
H_l0oookJ_oonfX01_oonfX00om/0?oooo]ZoookJP02oookJP05oooS0?oonf[ooo]ZoookJ_oo3@00
5?oonfX2o`3oC@WoiOl000?ooo]ZoeT0oooonfX03_oonfX2obT0o`Sooo]Z0ol0oo0@oookJPCoonP0
6?oonfX@oole00Oooo]Z1Ooo00/5oooX00_ooo]Z0ol0oo03oookJP?o:@3o0_oonfX4o`00O`;oF@3o
00Co001ooookJ_oonf[oo`2Z0_l0odd00ol007oooo]ZoookJP07o`00O`05ool=0?oUo`3ooo]Zoook
J_m/0?l00_oonfX01?l0003oH_l0of;o0?l0000?oookJP05on;o0?oonf[oF_l0oookJ_l0okh00ooo
nfX00ooo0?Kooo]Zo`03o`03oookJP05o`3oB?oonf[ooo]ZoookJ_l0ogL00ooonfX00omi0?ooUol0
oookJP06oookJP05o`2Roooo_`3ooo]Zo`3oX_oUo`000_oonfX01_l0ob7ooo]ZoookJ_oonf[oiOl0
ool0lPGoiOl000Kooo]Zool0X?oonf[ooo]Zoe@0ool09Ol2oookJP03obX0oooo2P3ooo]Z00Cooo]Z
00KoNol0oookJ_oonf[oiOl0oookJ_oo@@02oookJP03o`3o>?l80?oooo]Z00Sooo]Z00?oob00oook
J_oonfX01?oonfX00ooo0;Gooo]ZoookJP0=oookJP03o`3o]Ooonf[ooo]Z00?ooo]Z00?oiOl0oook
J_oonfX04ooonfX01?oo04oooo]ZoookJ_oUo`08oookJP04oolL0?oonf[ooo]ZokSo00oooo]Z00Go
olT0oookJ_oMo`3ooo]Zob/0o`05oookJP04oonK0?oo003ooo]Zonco00Gooo]Z00?oT`3ooookJ_oo
nfX01_oonfX00ooo]`3oE`3ooookJP03oookJP03ool0g?oonf[ooo]Z04Gooo]Z00?oH_l0oookJ_oo
nfX01ooonfX00om/0?oooo]ZoookJP02oookJP05oooS0?oonf[ooo]ZoookJ_oo3@004ooonfX2o`3o
C@Cooo]Z0_oo0:X4oookJP03oeT0oooonf[ooo]Z00kooo]Z0_lY0?l8oookJP?o0?o`3ooonfX4oooX
01Sooo]Z4?oo=@08oookJPGoo`0;1Oooj00;oookJP?o0?o`0ooonfX3obT0o`03oookJ_l007oo001o
00;o001o0_mI0?l00ol007oooo]ZoookJP02ool0ZP04o`3oCOl007oooo]ZoookJPOo001o00Coo`d0
oookJ_ooh`3ooo]Z0_m/0?l01Ooonf[o0000of;o0?mRo`3o000000oooo]Z00Goh_l0oookJ_oonf[o
F_l0o`3o_P04oookJP03ool0m_l00ooooo]Z00;ooo]Z00?o0?m8oookJ_oonfX00_oonfX01_l0ogOo
oo]ZoookJ_mi0?oooo]ZoiOo00Kooo]Z00Go0:;ooookJ_oo_`3ooo]Zo`3oXP03oookJP07o`3o8Ooo
nf[ooo]ZoookJ_oo0?;ooo]Zo`3oEP04oookJP05ool0X?oonf[ooo]Zoe@0ool09Ol00_oonfX00olZ
0?oooo]Zool:0005oookJP05og_o0?oonf[ooo]ZoonL0?oo@@000_oonfX00ol0ocSo203ooookJP09
oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?oo`2eoookJ_oonfX03OoonfX00ol0okGooo]ZoookJP04
oookJP03o`3oRooonf[ooo]Z01;ooo]Z00Coo`1?oookJ_oonf[o0?nF2?oonfX01Ooo703ooo]Zoook
J_oonf[o^?l000kooo]Z00God_l0oookJ_oMo`3ooo]Zob/0o`06oookJP04oonK0?oo003oo`2Yonco
00Gooo]Z00?oT`3ooookJ_oonfX01_oonfX00omG0?oooo]ZoookJP03oookJP03ool0g?oonf[ooo]Z
01gooo]Z000ZoookJP03of;o0?oonf[ooo]Z00Kooo]Z00?oK03ooookJ_oonfX00_oonfX01Oooh`3o
oo]ZoookJ_oonf[oo`d001?ooo]Z0_l0odd2oookJPSoiOl00_mI0?l>oookJP;o:@3o1ooonfX3o`3o
l0oooo]Z1?ooj0000ooo00_ooo]ZoookJP0;oookJPkoocD03ol0POl00onDo`3oocD0oole0004oole
00Oooo]Z1?oo00/3oooX00_ooo]Z0_l0oo04oookJP;oU?l00ol007l00ooonf[o001oo`00O`02oeT0
o`;ooo]Z00Co001oool0Z_l0odgooo]Z1?l007l01_oonf[o001oo`00Ool007oooo]Zool=00;oiOl0
00?ooo]Zof`0oom/0?l00ol000000omRo`3ooo]ZoookJP0>oookJP05on;o0?oonf[oF_l0oookJ_l0
okh00_oonfX00ooo0?Kooo]Zo`03o`04oookJP05o`3oB?oonf[ooo]ZoookJ_l0ogL00_oonfX00omi
0?ooobL0oiOo0007oookJP07o`2Roooo_`3ooo]Zo`3oX_oUo`3ooo]Zo`3o8@04oookJP03onGo0?oo
0?;oiOl000?oiOl000_ooo]Zool0X?oonf[ooo]Zoe@0oooonf[o02GooookJ_lZ0?oo04coool:0004
oookJP06og_o0?oonf[ooo]ZoookJ_oUo`3ood400_oonfX00ol0ocSooo]Zo`P0o`09oookJP03oolP
0?oonf[ooo]Z00Cooo]Z00?oo`2eoookJ_oonfX03?oonfX00ol0okGooo]ZoookJP04oookJP03onGo
0?oonf[ooo]Z00;oiOl04?oonfX01Ooo04oooo]ZoookJ_oonf[oiOl000Oooo]Z00Gooa`0oookJ_oo
nf[ooo]ZokSo000>oookJP03om;o0?oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX00ooonfX01?oo
003ooo]Zool0ZOo/o`05oookJP03oi<0oooonf[ooo]Z00Gooo]Z00?ookL0oookJ_mG0?l0B_oonfX0
0omRo`3ooo]ZoookJP07oookJP03of`0oooonf[ooo]Z00;ooo]Z00?oon<0oookJ_oonfX00_oo3@0B
oookJP;o0?m=1OoonfX00ooo0:[ooo]ZoookJP02oookJP;oF@3o3ooonfX2obT0o`Oooo]Z0ol0oo0>
oookJPCoonP000?oo`0;oookJ_oonfX02ooonfX>oole013o087o1_oo=@08oookJPCoo`0;0oooj00;
oookJP;o0?o`1?oonfX2obT0o`;o001o00?ooo]Zo`00Ool007l00omI0?l00ooonf[o001oool0ZP02
o`3oC@Co001o00Gooo]Zo`00Ool007oo001ooookJP02ool=00;oon<000?ooo]Zof`0ool000000_l0
00000omRo`3ooo]ZoookJP0>oookJP05on;o0?oonf[ooo]Zoe[o0?l0okh00ooonfX00ooo0?Ko00?o
oookJP03oookJP05o`3oB?oonf[ooo]ZoookJ_l0ogL00_oonfX01?mi0?ooobL0oookJ_nGo`06oook
JP05o`2Roooo_`3ooo]ZoookJ_l0oj800_oonfX00ol0ob7ooo]ZoookJP02oookJP03ool0l_oonf[o
0?mF00?ooo]Z00Koo`2PoookJ_oonf[oE03ooookJ_l09Ol2oookJP03obX0ool0C?ooo`X000Cooo]Z
00GoNol0oookJ_oonf[ooi`0oom10003oookJP03o`3o>?l80?oooo]Z00Sooo]Z00?oob00oookJ_oo
nfX01?oonfX00ooo0;Gooo]ZoookJP0<oookJP03o`3o]Ooonf[ooo]Z00Gooo]Z00?o0?n;oookJ_oo
nfX04OoonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Oooo]Z00?ooa`0oookJ_oonfX00_oonfX00onh
o`3ooo]ZoookJP0;oookJP03om;o0?oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX01?oonfX01?oo
003oo`2YoookJ_o/o`05oookJP03oi<0oooonf[ooo]Z00Gooo]Z00?ookL0oeL0oooonfX08ooonfX0
02Wooo]Z00?oH_l0oookJ_oonfX01_oonfX00om/0?oooo]ZoookJP02oookJP03oooS0?oonf[ooo]Z
00;oo`d04ooonfX00ol0odgooo]ZoookJP03oookJPKoiOl000?oF@3ooookJ_oonfX03?oonfX2obT0
o`Kooo]Z0ol0oo0?oookJP?oonP00_oo00/<oookJPCoocD03Ol0POl:oookJPGo=ol000?oU?l0o`21
ool0POl01?l0POl00onDo`3oocD0oole0003oole00Kooo]Z0ooo00/3oooX00?ooo]Z1ol007l3o`3o
l0;ooo]Z00?o001ooiCo0?nDo`000ooonfX3o`00O`;oU?l00ooonfX2o`3oC@;o001o0ooonfX3o`00
O`;ooo]Z00Goo`d0onGo0?oonf[ooo]Zof`0o`02o`000003onGo0?mRo`3ooo]Z00kooo]Z00Koh_l0
oookJ_oonf[oF_l0oookJ_l0okh2oookJP03ool0m_oonf[o00?o00Cooo]Z00Go0?m8oookJ_oonf[o
oo]Zo`3oM`02oookJP03ogT0oooo9`3oUol000Kooo]Z00Go0:;ooono0?oonf[ooo]Zo`3oXP02oook
JP03o`3o8Ooonf[ooo]Z00;ooo]Z00?oiOl0ool0l_oUo`000ooUo`001_oonf[oo`2PoookJ_oonf[o
E03oo`0Uo`;ooo]Z00?o:P3oool:0?oonfX01?oonfX01_mko`3ooo]ZoookJ_oUo`3ooo]Zoom100;o
oo]Z00?o0?lho`P0oooonfX02?oonfX00ooo803ooo]ZoookJP04oookJP03ool0]Ooonf[ooo]Z00go
oo]Z00?o0?neoookJ_oonfX00ooonfX5onGo017ooo]Z00Coo`1?oookJ_oonf[oiOl01ooonfX01Ooo
703ooo]ZoookJ_oonf[o^?l000kooo]Z00?od_l0oookJ_oMo`000_oonfX00ol[0?oooo]ZoookJP03
oookJP04oonK0?oo003oo`2Yonco00Gooo]Z00?oT`3ooookJ_oonfX01_oonfX00ooo]`3oE`3ooook
JP18oookJP03of;o0?oonf[ooo]Z00Oooo]Z00?oK03ooookJ_oonfX00_oonfX01?ooh`3ooo]Zoook
J_oo3@0CoookJP03o`3oCOoonf[ooo]Z00?ooo]Z0_oo0:X4oookJP03oeT0oooonf[ooo]Z00gooo]Z
0_lY0?l6oookJP?o0?o`3_oonfX3oooX00;oo`0;3?oonfX4oole00ko087o2_oonfX6ocOo00Ko087o
1_oo=@06oookJP?oo`0;0oooj002oookJPSo001o0_l0oo02oookJP;o001o0_lY0?l2oookJP?o001o
00?ooo]ZoeT0oomI0?l00_oonfX01?oo0:[o0?m=o`3oCOl007l3oookJP?o001o0_oonfX2ool=0003
oooS0?oonf[oK03o00?o000000?oH_l0oookJ_oonfX03_oonfX01OoRo`3ooo]ZoookJ_mJo`3o0?nn
00?ooo]Z00?oo`3fo`03oooonfX00ooonfX01Ol0odSooo]ZoookJ_oonf[o0?mg00;ooo]Z00CoN@3o
oolW0?oonf[oUol01_oonfX01Ol0X_oookl0oookJ_oonf[o0?nR00;ooo]Z00?o0?lQoookJ_oonfX0
0_oonfX00ooo0?;o0?mFoookJP03oookJP05ool0X?oonf[ooo]Zoe@0ool09Ol00ooonfX00olZ0?oo
o`X0oookJP04oookJP05og_o0?oonf[ooo]ZoonL0?oo@@000_oonfX00ol0ocSo203ooookJP09oook
JP03oolP0?oonf[ooo]Z00?ooo]Z00?oo`2eoookJ_oonfX03OoonfX00ol0okGooo]ZoookJP04oook
JP03o`3oRooonf[ooo]Z01;ooo]Z00Coo`1?oookJ_oonf[o0?nF1ooonfX00ooo703ooo]ZoookJP02
oookJP03okSo0?oonf[ooo]Z00_ooo]Z00?od_l0oookJ_oMo`000_oonfX00ol[0?oooo]ZoookJP04
oookJP04oonK0?oo003oo`2Yonco00Gooo]Z00?oT`3ooookJ_oonfX01OoonfX00ooo]`3oE`3ooook
JP0SoookJP00:?oonfX00omRo`3ooo]ZoookJP06oookJP03of`0oooonf[ooo]Z00;ooo]Z00Coon<0
oookJ_oonf[oo`d05?oonfX00ol0odgooo]ZoookJP02oookJPOoiOl000?oF@3ooookJ_oonfX02ooo
nfX2obT0o`Gooo]Z0ol0oo0>oookJPCoonP00_oo00/;oookJPCoocD00ol0POl5ocOo00Wooo]Z1_l0
oiL7oiCo00;ooo]Z1onDo`05o`21o`03ocOo0?oo=@3oocD000CoocD01?oonfX2ool02`CoonP000?o
001oonGo0?oUo`001_l007l2o`3ol0?o001o0_nDo`001?oonf[o001oo`00Ool007l3oiCo0004oeT0
oooonf[ooo]Zool0ZP;o0?m=0ooonfX3o`00O`Cooo]Z00?oiOl0oookJ_l000000_m/0?l01?oUo`3o
0000of;o0?mRo`0>oookJP06on;o0?oonf[ooo]Zoe[o0?oonf[o0?nn0_oonfX00ooo0?Kooo]Zo`03
o`04oookJP05o`3oB?oonf[ooo]ZoookJ_l0ogL00_oonfX00omi0?ooUol0oookJP06oookJP05o`2R
oooo_`3ooo]ZoookJ_l0oj800_oonfX00ol0ob7ooo]ZoookJP02oookJP03ool0l_oUo`3oiOl000;o
iOl000?ooo]Zool0X?oonfX00_oonfX01_mD0?oo02GooookJ_oonf[o:P3oool:00Gooo]Z00GoNol0
oookJ_oonf[oiOl0oom10002oookJP03o`3o>?oonf[o203o00Wooo]Z00?oob00oookJ_oonfX00ooo
nfX00ooo0;Gooo]ZoookJP0=oookJP03o`3o]Ooonf[ooo]Z00;ooo]Z1_oUo`0AoookJP04ool0Cooo
nf[ooo]ZonGo00?ooo]Z0_oUo`03oookJP04oolL0?oonf[ooo]ZokSo00oooo]Z00God_l0oookJ_oM
o`3ooo]Zob/0o`05oookJP04oonK0?oo003ooo]Zonco00Gooo]Z00?oT`3ooookJ_oonfX01_oonfX0
0ooo]`3oE`3ooookJP17oookJP03of;o0?oonf[ooo]Z00Oooo]Z00CoK03ooookJ_oonf[ooo]Z0_oo
h`02oookJP03ool=0?oonf[ooo]Z017ooo]Z00?o0?m=oookJ_oonfX00_oonfX2ool0ZPCooo]Z0_mI
0?l>oookJP;o:@3o1OoonfX3o`3ol0gooo]Z1?ooj003ool02`[ooo]Z1?oo=@04o`21o`Co=ol02Ooo
nfX=o`3oU`Wooo]Z00?o=ol0o`21ool0POl00ol0POl00olgo`3oocD0oole0004oole00Cooo]Z0_oo
00/3oooX00Wo001o0_l0oo03o`00O`03oookJ_lY0?oooo]Z00?o001o0ooonfX2oeT0o`03oookJ_oo
0:[oo`2Z00;o0?m=0_oonfX3o`00O`Cooo]Z00?oo`d0oooS0?l000000_m/0?l2o`0000;oH_l03ooo
nfX01OoRo`3ooo]ZoookJ_mJo`3o0?nn00?ooo]Z00?oo`3fo`03oooonfX00ooonfX01Ol0odSooo]Z
oookJ_oonf[o0?mg00;ooo]Z00?oN@3ooolW0?nGo`001ooonfX01Ol0X_oookl0oookJ_l0S?oo0?nR
00;ooo]Z00Oo0?lQoookJ_oonf[ooo]Zool0l_oonf[o0?mF00?ooo]Z00Koo`2PoookJ_oonf[ooo]Z
oe@0ool09Ol2oookJP03obX0ool0C?ooo`X000Gooo]Z00CoNol0oookJ_ooW03ood400ooonfX00ol0
ocSo203ooookJP09oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?oo`2eoookJ_oonfX03?oonfX00ol0
okGooo]ZoookJP05oookJP03o`3oRooonf[ooo]Z017ooo]Z00Coo`1?oookJ_oonf[o0?nF2?oonfX0
1Ooo703ooo]ZoookJ_oonf[o^?l000kooo]Z00God_l0oookJ_oMo`3ooo]Zob/0o`06oookJP04oonK
0?oo003oo`2Yonco00Gooo]Z00?oT`3ooookJ_oonfX01_oonfX00omG0?oooo]ZoookJP0RoookJP00
9ooonfX00omRo`3ooo]ZoookJP06oookJP03of`0oooonf[ooo]Z00;ooo]Z00Coon<0oookJ_oo3@3o
o`d05?oonfX00ol0odgooo]ZoookJP02oookJP04onGo0?oonf[ooo]ZoookJP?oiOl03_oonfX00olY
0?oooo]ZoookJP03oookJP;o0?o`3_oonfX3oooX0003oookJ_oo00_oo`0;00Wooo]Z1Ooo=@03o`21
o`03ocOo0?oonf[ooo]Z00?ooo]Z3?l0oiL4oookJPoo0?oX2?nDo`06o`21o`03ocOo0?oo=@3oocD0
00;oiOl00ooonfX3ool02`04oooX0?oUo`3oiOl0onGo00Oooo]Z0_l0oo001?l007oooo]ZoookJ_nD
o`02o`00O`OoU?l00_oonfX01?oo0:[o0?m=oookJ_oonfX3o`00O`Gooo]Z0_oUo`001?l0003oiOl0
of`0oooUo`02oookJP03of;o0?oonf[ooo]Z00cooo]Z00Goh_l0oookJ_oonf[oF_l0o`3o_P03oook
JP03ool0m_oonf[o00?o00?ooo]Z00?o0?m8oookJ_oonfX00_oonfX01Ol0ogOooo]ZoookJ_mi0?oo
Uol000Oooo]Z00Oo0:;ooono0?oonf[o0?nRonGo0?oonf[o0?lQ00Gooo]Z00?oo`3bonGo0?oUo`00
0_oUo`000ooonf[oo`2PoookJP02oookJP06oe@0oooonf[ooo]ZobX0ool0C?ooo`X01?oonfX01_mk
o`3ooo]ZoookJ_oUo`3ooo]Zoom100;ooo]Z00?o0?lho`P0oooonfX02OoonfX00ooo803ooo]Zoook
JP03oookJP03ool0]Ooonf[ooo]Z00gooo]Z00?o0?neoookJ_oonfX02?oUo`0@oookJP04ool0Cooo
nf[ooo]ZoookJPGoiOl00ooonfX01Ooo703ooo]ZoookJ_oonf[o^?l000kooo]Z00?od_l0oookJ_oM
o`000_oonfX00ol[0?oooo]ZoookJP02oookJP04oonK0?oo003ooo]Zonco00Kooo]Z00?oT`3ooook
J_oonfX01OoonfX00ooo]`3ooo]ZoeL0o`16oookJP03of;o0?oonf[ooo]Z00Oooo]Z00GoK03ooook
J_oonf[ooo]ZoooS0002oookJP;oo`d04ooonfX00ol0odgooo]ZoookJP02oookJP03ool0Z_oonf[o
oo]Z00?ooo]Z00?oF@3ooookJ_oonfX03?oonfX2obT0o`Gooo]Z0_l0oo0=oookJP?oonP000Cooo]Z
ool02ooo00_oo`0;2OoonfX4oole00Co087o1_oonfX;o`3oU`Cooo]Z3ol0onP6o`3oU`?ooo]Z1_l0
POl00ooonf[oocD0oole0002oole00?ooo]Z0_oo00/3oooX00Sooo]Z0_l0oo000ol007oooo]Zoook
JP02obT0o`;o001o1OoonfX2oeT0o`05oookJ_oo0:[ooo]Zo`3oCOoonfX00ol007l5oookJP05ool=
0?ooh`3oon<0o`000?m/0?l00ooonfX00omRo`3ooo]ZoookJP0=oookJP04on;o0?oonf[ooo]Zoe[o
00Cooo]Z00?oo`3fo`03oooonfX00_oonfX00ol0odSooo]ZoookJP02oookJP06o`3oMooonf[ooo]Z
ogT0oooo9`3oUol01_oonfX01Ol0X_oooo]Zoono0?oonf[o0?nR00;ooo]Z00?o0?lQoookJ_oonfX0
0_oonfX00ooo0?;ooo]Zo`3oEP03oookJP05ool0X?oonf[ooo]ZoookJ_mD0?l00ooonfX00olZ0?oo
04coool:0004oookJP05og_o0?oonf[ooo]ZoonL0?oo@@000_oonfX00ol0ocSo203ooookJP09oook
JP03oolP0?oonf[ooo]Z00?ooo]Z00?oo`2eoookJ_oonfX03OoonfX00ol0okGooo]ZoookJP04oook
JP03o`3oRooonf[ooo]Z017ooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP07oookJP05oolL0?oonf[o
oo]ZoookJ_nho`003_oonfX00ooBo`3ooo]Zomgo0002oookJP03ob/0oooonf[ooo]Z00?ooo]Z00Co
oi/0ool00?oo0:Wok?l01_oonfX00onC0?oooo]ZoookJP05oookJP03oong0?mG0?oooo]Z02;ooo]Z
000VoookJP03of;o0?oonf[ooo]Z00Kooo]Z00?oK03ooookJ_oonfX00_oonfX00oooh`3ooo]Zool=
000EoookJP04o`3oCOoonf[ooo]ZoookJP;oiOl01?oonfX00omI0?ooiOl0oookJP0<oookJP;o:@3o
1OoonfX00ol0oo3ooo]ZoookJP0:oookJP?oiOl000?oonP0oookJ_oo00/00_oo00/7oookJPCoocD0
1?l0POl3oookJPOo0?nG0_oonfX>o`3oj003oookJ_lfo`3o=_l000co=_l01_l0onP5oiCo00;o0?nG
00?ooo]Zo`21ool0POl00ol0POl3onGo00?ooo]Z1_oUo`05oookJP;o001o0_l0oo02oookJPSoU?l0
00Gooo]ZoiCo0?l007oo001oool0ZP02o`3oC@?o001o1_oonfX01?l0003oiOl0onGo0?oUo`02of`0
o`;ooo]Z0_mRo`0=oookJP05on;o0?oonf[ooo]Zoe[o0?l0okh00ooonfX00ooo0?Kooo]Zo`03o`03
oookJP05o`3oB?oonf[ooo]ZoookJ_l0ogL00_oonfX00omi0?oooo]ZoiOo0007oookJP04oono0?oo
nf[ooo]Zo`3oXP;ooo]Z00?o0?lQoookJ_oonfX00ooonfX01?oo0?;oiOl0onGo0?oUo`02oookJP05
ool0X?oonf[ooo]Zoe@0ool09Ol00_oonfX00olZ0?ooo`X0oookJP04oookJP05og_o0?oonf[ooo]Z
onGo0?oo@@000_oonfX00ol0ocSooo]Zo`P0o`09oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?oo`2e
oookJ_oonfX03OoonfX00ol0okGooo]ZoookJP08onGo017ooo]Z00?oo`1?onGo0?oUo`001OoUo`04
oookJP04oolL0?oonf[ooo]ZokSo00kooo]Z00?od_l0oookJ_oMo`000_oonfX00ol[0?oooo]Zoook
JP03oookJP04ool00?oonf[ooo]Zonco00Gooo]Z00?oT`3ooookJ_oonfX01_oonfX00ooo]`3oE`3o
oookJP14oookJP03of;o0?oonf[ooo]Z00Oooo]Z00GoK03ooookJ_oonf[ooo]ZoooS0002oookJP03
ool=0?oonf[ooo]Z01;ooo]Z00Co0?m=oookJ_oonf[ooo]Z0_oo0:X5oookJP03oeT0oooonf[ooo]Z
00_ooo]Z0_lY0?l6oookJP03o`3ol?oonf[ooo]Z00[ooo]Z0oooj002oookJP;oo`0;2?oonfX4oole
00Co087o0ooonfX7o`3oU`03oookJ_l0onSo0?oX00co0?oX0_oonfX=ocKo00Ko0?oX2?l0oiL00ooo
nf[o087oo`21o`03o`21o`?oocD01?oonfX01?oo00_oonP0oooX0?ooj005oookJP;o001o0ol0oo00
1?oonf[o001oobT0oolY0?l7oookJP04oeT0ool007ooo`2Zool0ZP;o0?m=0_l007l6oookJP04o`00
0?oo3@3oon<0o`0000;oK03o0_oonfX2of;o00kooo]Z00Coh_l0oookJ_oonf[oF_l01?oonfX00ooo
0?Ko00?ooookJP02oookJP03o`3oB?oonf[ooo]Z00;ooo]Z00Ko0?mgoookJ_mi0?oooo]ZoolW0?nG
o`06oookJP05o`2Roooo_`3ooo]ZoookJ_l0oj800_oonfX00ol0ob7ooo]ZoookJP02oookJP03ool0
l_oonf[o0?mF00?ooo]Z00Goo`2PoookJ_oonf[oE03oo`0Uo`03oookJP03obX0oooo2P3ooo]Z00Co
oo]Z00CoNol0oookJ_ooW03ood400ooonfX00ol0ocSo203ooookJP09oookJP03oolP0?oonf[ooo]Z
00;ooo]Z00?oo`2eoookJ_oonfX03OoonfX00ol0okGooo]ZoookJP05oookJP03o`3oRooonf[ooo]Z
017ooo]Z00Coo`1?oookJ_oonf[o0?nF2?oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000gooo]Z00?o
d_l0oookJ_oMo`000_oonfX00ol[0?oooo]ZoookJP04oookJP04ool00?oonf[oo`2Yonco00Gooo]Z
00?oT`3ooookJ_oonfX01OoonfX00ooo]`3oE`3ooookJP0RoookJP009OoonfX00omRo`3ooo]Zoook
JP06oookJP03of`0oooonf[ooo]Z00;ooo]Z00?oon<0oookJ_oo3@005OoonfX01Ol0odgooo]Zoook
J_oonf[oiOl000Cooo]Z0_mI0?l=oookJP;o:@3o1OoonfX2o`3ol0Wooo]Z1OoUo`001?oonf[oo`0;
ool02ooo00/6oookJPCoocD01?l0POl01?lgo`3ooo]ZoookJ_oonfX3o`3oU`Gooo]Z1?l0onP00ooo
nf[o=_l0ocKo000<ocKo00Wooo]Z1_nDo`05ocKo00Go0?oX0_oonfX4o`3oU`03oookJ_lgo`3o087o
00;o087o2_oUo`02oooX00;ooo]Z0ol007l01?oonf[o0?o`o`3ol?l007l8oiCo0003oookJ_nDo`3o
U?l000;o001o00Coo`2Zo`3oCOl0odgoU?l01_oonfX6onGo0005of`0oooonf[ooo]ZoookJ_mRo`00
3OoonfX01OoRo`3ooo]ZoookJ_mJo`3o0?nn00?ooo]Z00?oo`3foookJ_l00ol00ooonfX01Ol0odSo
oo]ZoookJ_oonf[o0?mg00;ooo]Z00?oN@3ooolW0?nGo`001ooonfX01?oo_`3ooo]ZoookJ_l0oj82
oookJP03o`3o8Ooonf[ooo]Z00?ooo]Z00Koo`3bonGo0?oUo`3oiOl0oookJ_oo0:03oookJP06oe@0
oooonf[ooo]ZoookJ_lZ0?ooo`X01?oonfX01_mko`3ooo]ZoookJ_oUo`3ooo]Zoom100;ooo]Z00?o
0?lho`P0oooonfX02OoonfX00ooo803ooo]ZoookJP03oookJP03ool0]Ooonf[ooo]Z00gooo]Z00?o
0?neoookJ_oonfX01ooUo`0AoookJP03ool0CooUo`3oiOl000GoiOl01?oonfX01?oo703ooo]Zoook
J_nho`0>oookJP06om;o0?oonf[ooo]Zomgo0?oonf[o:`3o1OoonfX01?ooV`3oo`00oookJ_o/o`05
oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?ookL0oeL0oooonfX0@ooonfX00omRo`3ooo]ZoookJP07
oookJP05of`0oooonf[ooo]ZoookJ_ooh`000_oonfX00ooo3@3ooo]ZoookJP0BoookJP05o`3oCOoo
nf[ooo]ZoookJ_oo0:X01OoonfX2oeT0o`cooo]Z0_lY0?l6oookJP;o0?o`2ooonfX2oooX00;ooo]Z
0ooo00/6oookJPCoocD01?l0POl4oookJP?o0?nG1?oonfX4o`3oj0;ooo]Z3_lfo`0?oookJPCo=_l0
1Ol0onP3oookJP?o0?nG00?ooo]ZocOo0?lgo`000ol0POl3oole00Gooo]Z0oooj002oookJP?o001o
0_oonfX2o`3ol0;o001o0_lY0?l5oookJP06o`00OomI0?ooF@3oo`00Oooo0:[o001o0_l0odd6oook
JP;o000000Goo`d0oooS0?oonf[ooo]Zof`0o`03oookJP03of;o0?oonf[ooo]Z00cooo]Z00Coh_l0
oookJ_oonf[oF_l01?oonfX00ooo0?Ko00?ooookJP02oookJP03o`3oB?oonf[ooo]Z00;ooo]Z00Ko
0?mgoookJ_mi0?ooobL0oookJ_nGo`06oookJP05o`2Roooo_`3ooo]ZoookJ_l0oj800_oonfX00ol0
ob7ooo]ZoookJP02oookJP03ool0l_l0oeKooo]Z00;ooo]Z00Goo`2PoookJ_oonf[ooo]Zoe@0o`04
oookJP03obX0oooo2P3ooo]Z00?ooo]Z00GoNol0oookJ_oonf[ooi`0oom10002oookJP03o`3o>?l8
0?oooo]Z00Wooo]Z00?oob00oookJ_oonfX00ooonfX00ooo0;Gooo]ZoookJP0=oookJP03o`3o]Ooo
nf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX04OoonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Oooo]Z
00Gooa`0oookJ_oonf[ooo]ZokSo000=oookJP06om;o0?oonf[ooo]Zomgo0?oonf[o:`3o1_oonfX0
1?ooV`3oo`00ool0ZOo/o`05oookJP03oi<0oooonf[ooo]Z00Gooo]Z00?ookL0oeL0oooonfX08_oo
nfX002gooo]Z00CoK03ooookJ_oonf[ooo]Z0_ooh`000ooonf[oo`d0oookJP0DoookJP03o`3oCOoo
nf[ooo]Z00;oiOl01?oonfX00omI0?oooo]ZoookJP0;oookJP;o:@3o1_oonfX00ol0oo3ooo]Zoook
JP06oookJPOoiOl00_oo00/6oookJP?oocD01?l0POl2ocOo00?ooo]Z0ol0oiL4oookJPCo0?oX00?o
oo]ZocKo0?lfo`000_lfo`0GoookJPCoU?l02?oonfX4ocKo00Ko0?oX0ol0oiL2oookJP;o087o2_oU
o`03oooX00;o001o0ooonfX3o`3ol0OoU?l00_l007l2oiCo0005o`00Oooo0:[oo`2Zo`3oCOnDo`00
1?oonfX8onGo0005of`0oooonf[ooo]ZoookJ_mRo`003OoonfX01OoRo`3ooo]ZoookJ_mJo`3o0?nn
00?ooo]Z00?oo`3foookJ_l00ol00ooonfX01Ol0odSooo]ZoookJ_oonf[o0?mg00;ooo]Z00?oN@3o
oiOo0?oonfX01ooonfX01?oo_`3ooo]ZoookJ_l0oj82oookJP03o`3o8OoUo`3oiOl000;ooo]Z00Co
o`3boookJ_oUo`3oiOl00_oonfX01Ooo0:3ooo]ZoookJ_mD0?oo02Go00;ooo]Z00?o:P3oool:0?oo
nfX01?oonfX01Omko`3ooo]ZoookJ_oUo`3ood4000;ooo]Z00?o0?lhoookJ_l80?l02OoonfX00ooo
803ooo]ZoookJP03oookJP03ool0]Ooonf[ooo]Z00gooo]Z00Co0?neoookJ_oonf[ooo]Z1_oUo`0A
oookJP03ool0CooUo`3oiOl000GoiOl01?oonfX01?oo703ooo]ZoookJ_nho`0?oookJP03om;o0?oo
nf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX00_oonfX01?ooV`3oo`00oookJ_o/o`06oookJP03oi<0
oooonf[ooo]Z00Gooo]Z00?ookL0oookJ_mG0?l0C?oonfX01Om/0?oooo]ZoookJ_oonf[oon<000;o
oo]Z00?oo`d0oookJ_oonfX04_oonfX00ol0odgooo]ZoookJP02ool0ZPGooo]Z00?oF@3ooookJ_oo
nfX02_oonfX2obT0o`Oooo]Z00?o0?o`oookJ_oonfX02_oonfX00oooj03ooo]Zool02`02ool02`Ko
oo]Z0ooo=@04o`21o`03ocOo0?oonf[ooo]Z00;ooo]Z0ol0oiL3oookJPCo0?oX0_oonfX4ocKo02;o
oo]Z1?lfo`06o`3oj0Co0?nG00?ooo]ZocOo0?l0POl00_l0POl2oole00Kooo]Z0oooj002o`00O`?o
oo]Z00?o001oo`3ol?l0oo000_oonfX00olY0?oooo]ZoookJP02oookJP?o001o00KoF@3oo`00Oooo
0:[oo`2ZoookJ_l0odd5oookJP?o000000Goo`d0oooS0?oonf[ooo]Zof`0o`03oookJP03of;o0?oo
nf[ooo]Z00cooo]Z00Coh_l0oookJ_oonf[oF_l01?oonfX00ooo0?Ko00?ooookJP02oookJP03o`3o
B?oonf[ooo]Z00;ooo]Z00Go0?mgoookJ_mi0?ooobL0oiOo0007oookJP05o`2Roooo_`3ooo]Zo`2<
ool0oj800_oonfX01ol0ob7ooo]ZoookJ_oonf[oo`3boookJ_l0oeH00ooonfX01Ooo0:3ooo]Zoook
J_mD0?oo02Go00?ooo]Z00?o:P3oool:0?oonfX01?oonfX01?mko`3ooo]ZoonL0?oo@@03oookJP03
o`3o>?l80?oooo]Z00Wooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP0=oookJP03
o`3o]Ooonf[ooo]Z00Gooo]Z00?o0?n;oookJ_oonfX04?oonfX01Ooo04oooo]ZoookJ_oonf[o0?nF
00Oooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000>oookJP03om;o0?oonf[ogOl000;ooo]Z00?o:`3o
oookJ_oonfX00ooonfX01?ooV`3oo`00ool0ZOo/o`06oookJP03oi<0oooonf[ooo]Z00Gooo]Z00?o
okL0oeL0oooonfX08OoonfX002cooo]Z00GoK03ooookJ_oonf[ooo]ZoooS0003oookJP03ool=0?oo
nf[ooo]Z017ooo]Z0_l0odd2oookJP03onGo0?oonf[ooo]Z00;ooo]Z0_mI0?l<oookJP;o:@3o1ooo
nfX00ol0oo3ooo]ZoookJP03oookJP[oiOl01ooonfX2oole00;oiOl000Co087oocOo0?lgo`3o=ol0
0ooonfX3o`3oU`?ooo]Z1?l0onP00ooonf[o=_l0ocKo0002ocKo02cooo]Z1Olfo`04o`3oj0?o0?nG
2ooUo`02ool02`;oonP00ooonfX00ol007ooU?l0oiCo0002o`3ol0KoU?l000Oo001ooookJ_oonf[o
U?l0oookJ_nDo`3oo`2Z00;o0?m=0_oonfX:onGo0005of`0oooonf[ooo]ZoookJ_mRo`003OoonfX0
1OoRo`3ooo]ZoookJ_mJo`3o0?nn00;ooo]Z00?oo`3foookJ_l00ol01?oonfX01Ol0odSooo]Zoook
J_oonf[o0?mg00;ooo]Z00?oN@3ooiOo0?oonfX01_oonfX01ol0X_oookl0oookJ_oonf[o0?nRonGo
0?l0ob400_oUo`03oookJP03ool0l_oonf[oiOl000?ooo]Z00Goo`2PoookJ_oonf[oE03oo`0Uo`02
oookJP03obX0oooo2P3ooo]Z00?ooo]Z00KoNol0oookJ_oonf[oiOl0oookJ_oo@@02oookJP03o`3o
>?l80?oooo]Z00Wooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP0>oookJP04o`3o
]Ooonf[ooo]ZoookJPGoiOl04_oonfX00ooo04ooiOl0onGo0005onGo00Cooo]Z00Cooa`0oookJ_oo
nf[o^?l03_oonfX00ooBo`3ooo]Zomgo0002oookJP03ob/0oooonf[ooo]Z00?ooo]Z00Coo`00oook
J_o/o`3oo`2Y1OoonfX00onC0?oooo]ZoookJP05oookJP03oong0?oonf[oE`3o04_ooo]Z00GoK03o
oookJ_oonf[ooo]ZoooS0003oookJP03ool=0?oonf[ooo]Z017ooo]Z00Co0?m=oookJ_oonf[oo`2Z
1OoonfX2oeT0o`_ooo]Z0_lY0?l7oookJP;o0?o`2ooonfX2oooX00;oo`0;1ooonfX2oole00?o087o
0_lgo`04oookJP?o0?nG0ooonfX3o`3oj0;ooo]Z1?lfo`0/oookJPCo=_l01Ol0onP2o`3oU`;ooo]Z
0_l0POl3oole00Gooo]Z00?oo`0;oooX0?ooj0000ooonfX3o`00O`;o0?o`00?ooo]ZobT0oolY0?l0
0_oonfX2o`00O`;ooo]Z0_mI0?l01?oonf[oo`2ZoookJ_l0odd4oookJPCo000000Goo`d0oooS0?oo
h`3ooo]Zof`0o`03oookJP03of;o0?oonf[ooo]Z00cooo]Z00Coh_l0oookJ_oonf[oF_l00ooonfX0
0ooo0?Ko00?ooookJP03oookJP03o`3oB?oonf[ooo]Z00;ooo]Z00Go0?mgoookJ_mi0?ooobL0oiOo
0007oookJP07oono0?oonf[ooo]Zo`2<ool0oj;ooo]Zo`3o8@04oookJP03ool0l_oonf[o0?mF00?o
oo]Z00Goo`2PoookJ_oonf[oE03oo`0Uo`03oookJP03obX0oooo2P3ooo]Z00?ooo]Z00GoNol0oook
J_oonf[ooi`0oom10003oookJP03o`3o>?oonf[ooo]Z00Sooo]Z00?oob00oookJ_oonfX00ooonfX0
0ooo0;Gooo]ZoookJP0=oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX04OoonfX0
1?oo04oooo]ZoookJ_l0oiH8oookJP05oolL0?oonf[ooo]ZoookJ_nho`003OoonfX00ooBo`3ooo]Z
omgo0002oookJP03ob/0oooonf[ooo]Z00Cooo]Z00?oo`00oookJ_o/o`001_oonfX00onC0?oooo]Z
oookJP05oookJP03oong0?mG0?oooo]Z027ooo]Z000/oookJP04of`0oooonf[ooo]ZoooS00?ooo]Z
00?oo`d0oookJ_oonfX04OoonfX00ol0odgooo]ZoookJP02onGo00Cooo]Z00?oF@3ooookJ_oonfX0
2_oonfX2obT0o`Oooo]Z0_l0oo04oookJP_oiOl01OoonfX00ooUo`3oocD0oole0003onGo00;o=ol0
0ooonfX3o`3oU`;ooo]Z1?l0onP2oookJP?o=_l0=_oonfX3ocKo00?o0?oX3?oUo`000ooonf[oo`0;
ool02`02oooX0003o`00OonDo`3oU?l000?oU?l00_l0oo05oiCo00?ooo]Z0onDo`02ool0ZP04o`3o
COoonf[ooo]ZoookJPWoiOl000GoK03ooookJ_oonf[ooo]Zof;o000=oookJP05on;o0?oonf[ooo]Z
oe[o0?l0okh00_oonfX00ooo0?Kooo]Zo`03o`04oookJP09o`3oB?oonf[ooo]ZoookJ_l0ogOooo]Z
ogT0oooo9`3oUol000Oooo]Z00Cookl0oookJ_oonf[o0?nR0_oUo`000ol0ob7oiOl0onGo0003oook
JP03ool0l_oonf[oiOl000;ooo]Z00Goo`2PoookJ_oonf[oE03oo`0Uo`03oookJP03obX0oooo2P3o
oo]Z00?ooo]Z00GoNol0oookJ_oonf[oiOl0oom10003oookJP03o`3o>?l80?oooo]Z00Sooo]Z00?o
ob00oookJ_oonfX00ooonfX00ooo0;Gooo]ZoookJP0=oookJP04o`3o]Ooonf[ooo]ZoookJPKoiOl0
4OoonfX00ooo04ooiOl0onGo0005onGo00Cooo]Z00Cooa`0oookJ_oonf[o^?l03_oonfX01_oBo`3o
oo]ZoookJ_oMo`3ooo]Zob/0o`Gooo]Z00Cooi/0ool00?oonf[ok?l01OoonfX00onC0?oooo]Zoook
JP06oookJP03oong0?mG0?oooo]Z04Wooo]Z00GoK03ooookJ_oonf[ooo]ZoooS0003oookJP03ool=
0?oonf[ooo]Z017ooo]Z00Co0?m=oookJ_oo0:[oo`2Z1OoonfX00omI0?oooo]ZoookJP09oookJP;o
:@3o2?oonfX00ol0oo3ooo]ZoookJP09oookJP;oonP000?ooo]Zool02ooonfX01_oonfX2oole00;o
087o0_lgo`04oookJP?o0?nG0_oonfX4o`3oj0;ooo]Z0olfo`0eoookJPCo=_l00ol0onP3o`3oU`03
oookJ_l0POoo087o00;oocD01?oonfX01?l007ooo`0;oooX0?ooj003o`00O`?ooo]Z0_l0oo000ooo
nf[o:@3oobT0o`02o`00O`Cooo]Z00CoF@3ooookJ_oo0:[oo`2Z0_l0odd2oookJPCo00000_oonfX0
1?oo3@3oon<0oookJ_m/0?l3oookJP03of;o0?oonf[ooo]Z00cooo]Z00Coh_l0oookJ_oonf[oF_l0
0ooonfX00ooo0?Ko00?ooookJP03oookJP03o`3oB?oonf[ooo]Z00;ooo]Z00Go0?mgogT0oooonf[o
obL0oiOo0006oookJP05o`2Roooo_`3ooo]ZoookJ_l0oj800_oonfX00ol0ob7ooo]ZoookJP02oook
JP03ool0l_oonf[o0?mF00;ooo]Z00Goo`2PoookJ_oonf[ooo]Zoe@0o`04oookJP03obX0oooo2P3o
oo]Z00?ooo]Z00CoNol0oookJ_ooW03ood400ooonfX00ol0ocSo203ooookJP09oookJP03oolP0?oo
nf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX03OoonfX00ol0okGooo]ZoookJP05oookJP03o`3oRooo
nf[ooo]Z013ooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP07oookJP05oolL0?oonf[ooo]ZoookJ_nh
o`003OoonfX01_oBo`3ooo]ZoookJ_oMo`3ooo]Zob/0o`Kooo]Z00Cooi/0ool00?oo0:Wok?l01Ooo
nfX00onC0?oooo]ZoookJP05oookJP03oong0?mG0?oooo]Z027ooo]Z000[oookJP04of`0oooonf[o
oo]ZoooS00?ooo]Z00?oo`d0oookJ_oonfX04OoonfX01?l0odgooo]ZoookJ_oUo`04oookJP;oF@3o
2ooonfX2obT0o`Sooo]Z00?o0?o`oookJ_oonfX01?oonfX:onGo00?ooo]Z0_oUo`02oole00CoiOl0
0ooonfX3o`3oU`03oookJ_l0onSo0?oX00;o0?oX0_oonfX4ocKo03gooo]Z00?o=_l0onGo0?l0onP0
0_l0onP;onGo0003o`00Oooo00_oo`0;00;oonP000?o001ooookJ_nDo`000onDo`02o`3ol0CoU?l0
0_l007l5oiCo0004ool0Z_l0odgooo]ZoookJP?o00001ooUo`001Om/0?oooo]ZoookJ_oonf[oH_l0
00gooo]Z00Goh_l0oookJ_oonf[oF_l0o`3o_P02oookJP03ool0m_oonf[o00?o00?ooo]Z00?o0?m8
oookJ_oonfX00_oonfX01?l0ogOooo]ZogT0oonGo`08oookJP04oono0?oUo`3oiOl0o`3oXP;oiOl0
00?o0?lQonGo0?oonfX00_oonfX00ooo0?;ooo]Zo`3oEP03oookJP05ool0X?oonf[ooo]Zoe@0ool0
9Ol00_oonfX00olZ0?ooo`X0oookJP03oookJP06og_o0?oonf[ooo]ZonGo0?oonf[ood400_oonfX0
0ol0ocSo203ooookJP09oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX03_oonfX0
1?l0okGooo]ZoookJ_oonfX5onGo017ooo]Z00?oo`1?onGo0?oUo`001OoUo`04oookJP04oolL0?oo
nf[ooo]ZokSo00kooo]Z00Kod_l0oookJ_oonf[ogOl0oookJ_l[0?l5oookJP04oonK0?oo003ooo]Z
onco00Kooo]Z00?oT`3ooookJ_oonfX01OoonfX00ooo]`3ooo]ZoeL0o`18oookJP05of`0oooonf[o
oo]ZoookJ_ooh`000ooonfX00ooo3@3ooo]ZoookJP0AoookJP03o`3oCOoonf[oo`2Z00Gooo]Z0_mI
0?l:oookJP;o:@3o2?oonfX2o`3ol0[ooo]Z0_ooj0000ooonf[oo`0;ool02`06oookJP;oocD000?o
=ol0o`21oolgo`001?oonfX3o`3oU`03oookJ_l0onSo0?oX00;o0?oX0_oonfX4ocKo03gooo]Z0_lf
o`03o`3oj0?o0?nG00?ooo]Zo`21oooo=@000_oo=@001Ooonf[o001oo`00Ool007ooo`0;00;oonP0
00?o001ooookJ_oonfX00ooonfX2o`3ol003oookJ_lY0?oo:@3o00Go001o0_mI0?l01Ooonf[oo`2Z
oookJ_l0odgooo]Z00Co00000ooonfX01?oo3@3oon<0oookJ_m/0?l3oookJP03of;o0?oonf[ooo]Z
00cooo]Z00Coh_l0oookJ_oonf[oF_l00ooonfX00ooo0?Ko00?ooookJP02oookJP03o`3oB?oonf[o
oo]Z00?ooo]Z00Co0?mgogT0oooo9`3oUol01ooonfX01Ol0X_oookl0oookJ_l0S?oo0?nR00;ooo]Z
00Oo0?lQoookJ_oonf[ooo]Zool0l_oonf[o0?mF00?ooo]Z00Goo`2PoookJ_oonf[oE03oo`0Uo`03
oookJP03obX0oooo2P3ooo]Z00?ooo]Z00GoNol0oookJ_oonf[ooi`0oom10003oookJP03o`3o>?oo
nf[ooo]Z00Sooo]Z00?oob00oookJ_oonfX00ooonfX00ooo0;Gooo]ZoookJP0=oookJP03o`3o]Ooo
nf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX04?oonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Oooo]Z
00Gooa`0oookJ_oonf[ooo]ZokSo000=oookJP06om;o0?oonf[ooo]Zomgo0?oonf[o:`3o1_oonfX0
1?ooV`3oo`00ool0ZOo/o`06oookJP03oi<0oooonf[ooo]Z00Gooo]Z00?ookL0oeL0oooonfX08?oo
nfX002[ooo]Z00CoK03ooookJ_oonf[oon<00ooonfX00ooo3@3ooo]ZoookJP0AoookJP04o`3oCOoo
nf[ooo]ZonGo00Cooo]Z00?oF@3ooookJ_oonfX02_oonfX00olY0?oooo]ZoookJP06oookJP;o0?o`
2?oonfX<onGo00;oocD01OoUo`001Ooonf[o0?nGo`3oUol0oiOooo]Z00?o0?oX0_oonfX4ocKo04Co
oo]Z0_lfo`03o`3oj0WoiOl00_l007l2ool02`;oonP01?oonfX2oiCo0003o`3ol?nDo`3oU?l000Wo
U?l000?oo`2Zo`3oCOl0odd01?l000000ooonf[oiOl0onGo0003onGo0003oookJ_m/0?oooo]Z00;o
oo]Z00?oH_l0oookJ_oonfX02ooonfX01OoRo`3ooo]ZoookJ_mJo`3o0?nn00;ooo]Z00?oo`3foook
J_l00ol00ooonfX00ol0odSooo]ZoookJP02oookJP04o`3oMooonf[oN@3ooiOo00Kooo]Z0_oUo`00
1ooo_`3oiOl0onGo0?l0oj;oiOl0o`3o8OoUo`001?oonfX00ooo0?;ooo]Zo`3oEP02oookJP05ool0
X?oonf[ooo]Zoe@0ool09Ol00ooonfX00olZ0?ooo`X0oookJP03oookJP05og_o0?oonf[ooo]ZonGo
0?oo@@000ooonfX00ol0ocSo203ooookJP08oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?oo`2eoook
J_oonfX03OoonfX00ol0okGooo]ZoookJP02oookJPCoiOl04OoonfX00ooo04oooo]ZonGo0005onGo
00Cooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000>oookJP03om;o0?oonf[ogOl000;ooo]Z00?o:`3o
oookJ_oonfX00_oonfX01OooV`3oo`00oookJ_o/o`3oo`2Y00Gooo]Z00?oT`3ooookJ_oonfX01Ooo
nfX00ooo]`3ooo]ZoeL0o`17oookJP05of`0oooonf[ooo]ZoookJ_ooh`000ooonfX00ooo3@3ooo]Z
oookJP0AoookJP03o`3oCOoonf[oo`2Z00Gooo]Z00?oF@3ooookJ_oonfX02OoonfX00olY0?oooo]Z
oookJP07oookJP03o`3ol?oonf[ooo]Z00Sooo]Z0_ooj0000ooonf[oo`0;ool02`06oookJP;oocD0
00?o=ol0o`21ool0POl00ooonfX3o`3oU`04oookJ_l0onSo0?oXo`3oj0;ooo]Z1?lfo`14oookJP;o
=_l00ol0onP3o`3oU`03oookJ_l0POooocD000;oocD00ol007l00ooo00_oonP0oooX0006oookJP04
o`3ol?oonf[o001oobT0o`Go001o00?ooo]ZoeT0oomI0?l00_oo0:X00ol0odgo0000o`000002o`00
00Cooo]Z00Coo`d0oooS0?ooh`3oK03o0ooonfX00omRo`3ooo]ZoookJP0<oookJP04on;o0?oonf[o
oo]Zoe[o00?ooo]Z00?oo`3fo`03oooonfX00_oonfX00ol0odSooo]ZoookJP03oookJP04o`3oMomi
0?ooobL0oiOo00Oooo]Z00Cookl0oookJ_oonf[o0?nR0_oonfX00ol0ob7ooo]ZoookJP02oookJP03
ool0l_oonf[o0?mF00;ooo]Z00Goo`2PoookJ_oonf[ooo]Zoe@0o`04oookJP03obX0oooo2P3ooo]Z
00?ooo]Z00CoNol0oookJ_oonf[ood400ooonfX00ol0ocSo203ooookJP09oookJP03oolP0?oonf[o
oo]Z00;ooo]Z00?oo`2eoookJ_oonfX03OoonfX00ol0okGooo]ZoookJP04oookJP03o`3oRooonf[o
oo]Z017ooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP06oookJP05oolL0?oonf[ooo]ZoookJ_nho`00
3_oonfX00ooBo`3ooo]Zomgo0002oookJP03ob/0oooonf[ooo]Z00?ooo]Z00Cooi/0ool00?oonf[o
k?l01_oonfX00onC0?oooo]ZoookJP05oookJP03oong0?mG0?oooo]Z023ooo]Z000YoookJP04of`0
oooonf[ooo]ZoooS00?ooo]Z00?oo`d0oookJ_oonfX04OoonfX01Ol0odgooo]ZoookJ_oonf[oo`2Z
00?ooo]Z00?oF@3ooookJ_oonfX02_oonfX00olY0?oooo]ZoookJP06oookJP03o`3ol?oonf[ooo]Z
00Sooo]Z2_oUo`02oole00KoiOl00_l0oiL2oookJP;o0?oX0_oonfX3ocKo03Gooo]Z0_oUo`0Doook
JP;o=_l00ol0onP00ooonf[o0?nGo`3oU`04onGo0005oole0?oonf[ooo]ZoookJ_oo00/00_ooj005
oookJP;o0?o`2onDo`000ooo0:[o0?m=o`000002o`0000?ooo]Z1?oUo`000ooonf[oK03ooookJP02
oookJP03of;o0?oonf[ooo]Z00_ooo]Z00Goh_l0oookJ_oonf[oF_l0o`3o_P02oookJP03ool0m_oo
nf[o00?o00?ooo]Z00?o0?m8oookJ_oonfX00_oonfX01?l0ogOooo]ZogT0oonGo`07oookJP04onGo
0?oo_`3oiOl0o`3oXP;oiOl000?o0?lQonGo0?oonfX00ooonfX00ooo0?;o0?mFoookJP02oookJP05
ool0X?oonf[ooo]Zoe@0ool09Ol00ooonfX00olZ0?ooo`X0oookJP02oookJP0:og_o0?oonf[ooo]Z
oookJ_oUo`3ood40oookJ_oUo`3o0?lho`P0o`[ooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Go
oo]ZoookJP0>oookJP03o`3o]Ooonf[ooo]Z00;ooo]Z0ooUo`0BoookJP03ool0Cooonf[oiOl000Co
iOl01OoonfX01?oo703ooo]ZoookJ_nho`0>oookJP06om;o0?oonf[ooo]Zomgo0?oonf[o:`3o1Ooo
nfX01?oo003ooo]ZoookJ_o/o`05oookJP03oi<0oooonf[ooo]Z00Gooo]Z00?ookL0oookJ_mG0?l0
A_oonfX01Om/0?oooo]ZoookJ_oonf[oon<000?ooo]Z00?oo`d0oookJ_oonfX04?oonfX2o`3oC@;o
oo]Z00?oo`2ZoookJ_oonfX00_oonfX00omI0?oooo]ZoookJP09oookJP03obT0oooonf[ooo]Z00Ko
oo]Z0_l0oo0:oookJP04oooX0?oonf[ooo]Zool02`Kooo]Z0_oo=@000olgo`3o087oo`21o`02oook
JP?o0?nG0_oonfX2o`3oj0;ooo]Z0olfo`1;oookJP;o=_l00ol0onP2o`3oU`03oookJ_lgo`3o087o
00;oocD00ooonfX01?oo00_oonP0oooX0?ooj004oookJP;o0?o`00?ooo]ZobT0oolY0?l01_oonfX0
0omI0?oooo]Zool0ZP02o`3oC@;o00001OoonfX2ool=0003oooS0?m/0?oooo]Z00;ooo]Z00?oH_l0
oookJ_oonfX03?oonfX01?oRo`3ooo]ZoookJ_mJo`03oookJP03ool0m_l00ooooo]Z00;ooo]Z00?o
0?m8oookJ_oonfX00ooonfX01?l0ogOoN@3ooolW0?nGo`07oookJP04oono0?oonf[ooo]Zo`3oXP;o
oo]Z00?o0?lQoookJ_oonfX00_oonfX00ooo0?;o0?mFoookJP02oookJP05ool0X?oonf[ooo]Zoe@0
ool09Ol00ooonfX00ol0C?oo:P3oool:0003oookJP05og_o0?oonf[ooo]ZoonL0?oo@@000ooonfX0
0ol0ocSooo]ZoookJP08oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX03_oonfX0
0ol0okGooo]ZoookJP04oookJP03o`3oRooonf[ooo]Z013ooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3o
UP07oookJP05oolL0?oonf[ooo]ZoookJ_nho`003OoonfX01_oBo`3ooo]ZoookJ_oMo`3ooo]Zob/0
o`Kooo]Z00Coo`00oookJ_oo0:Wok?l01OoonfX00onC0?oooo]ZoookJP05oookJP03oong0?mG0?oo
oo]Z023ooo]Z000XoookJP04of`0oooonf[ooo]ZoooS00Cooo]Z00?oo`d0oookJ_oonfX04?oonfX0
1Ol0odgooo]ZoookJ_oonf[oo`2Z00Cooo]Z00?oF@3ooookJ_oonfX02OoonfX00olY0?oooo]Zoook
JP05oookJP;o0?o`2OoonfX2onGo0003oookJ_oUo`3oiOl000KoiOl000?oocD0onGo0?oUo`001OoU
o`03oookJP;o0?oX0_oonfX2ocKo02?ooo]Z3ol0hol6oookJPGoiOl05?oonfX2ocKo00?o0?oX0ol0
oiL01?lgo`3o087ooole0?oo=@03oookJP03ool02oooj03oonP000Gooo]Z00Go0?o`oookJ_nDo`3o
U?l0obT0o`07oiCo0004ool0Z_l0odgo0?m=o`0000Kooo]Z0_oUo`000ooonf[oK03oof`0o`02oook
JP;oH_l03?oonfX01OoRo`3ooo]ZoookJ_mJo`3o0?nn00;ooo]Z00?oo`3foookJ_l00ol00ooonfX0
1Ol0odSooo]ZoookJ_oonf[o0?mg00;ooo]Z00?oN@3ooiOo0?oonfX01_oonfX01?oo_`3oiOl0onGo
0?l0oj82onGo0003o`3o8Ooonf[ooo]Z00?ooo]Z00?oo`3bo`3oE_oonfX00_oonfX01?oo0:3ooo]Z
oookJ_mD0?l3oookJP03obX0oooo2P3ooo]Z00?ooo]Z00GoNol0oookJ_oonf[oiOl0oom10003onGo
0003o`3o>?l80?oooo]Z00Sooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP0>oook
JP03o`3o]Ooonf[ooo]Z00;ooo]Z0ooUo`0BoookJP03ool0Cooonf[ooo]Z00CoiOl01OoonfX01?oo
703ooo]ZoookJ_nho`0>oookJP06om;o0?oonf[ooo]Zomgo0?oonf[o:`3o1OoonfX01?ooV`3oo`00
oookJ_o/o`06oookJP03oi<0oooonf[ooo]Z00Gooo]Z00?ookL0oeL0oooonfX0A?oonfX01Om/0?oo
oo]ZoookJ_oonf[oon<000?ooo]Z00?oo`d0oookJ_oonfX04?oonfX01Ol0odgooo]ZoookJ_oonf[o
o`2Z00Gooo]Z00?oF@3ooookJ_oonfX02?oonfX00olY0?oooo]ZoookJP06oookJP03o`3ol?oonf[o
oo]Z00Sooo]Z0_ooj0000ooonf[oo`0;ool02`06oookJP05oole0?lgo`3o087oo`21oooonfX00ol0
oiL3oookJP;o0?oX0_oonfX2ocKo02?ooo]Z3ol0holOoookJP;o=_l00ol0onP2o`3oU`04ocOo0?l0
POooocD0oole00?ooo]Z0_oo00/2oooX00Cooo]Z00?o0?o`oookJ_oonfX00_lY0?l5oookJP;oF@3o
0_oo0:X00ol0odgo0000oookJP06oookJP04ool=0?ooh`3oK03oof`0o`;ooo]Z0_mRo`0=oookJP04
on;o0?oonf[ooo]Zoe[o00?ooo]Z00?oo`3fo`03oooonfX00_oonfX00ol0odSooo]ZoookJP02oook
JP05o`3oMooonf[oN@3ooookJ_nGo`001_oonfX01Ol0X_oookl0oookJ_oonf[o0?nR00;ooo]Z00?o
0?lQoookJ_oonfX00_oonfX00ooo0?;o0?mFoookJP02oookJP04ool0X?oonf[ooo]Zoe@0o`Cooo]Z
00?o:P3oool:0?oonfX00ooonfX01?mko`3ooo]ZoookJ_oo@@04oookJP03o`3o>?oonf[ooo]Z00So
oo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP0=oookJP03o`3o]Ooonf[ooo]Z00Co
oo]Z00?o0?n;oookJ_oonfX04?oonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Oooo]Z00Gooa`0oook
J_oonf[ooo]ZokSo000=oookJP06om;o0?oonf[ooo]Zomgo0?oonf[o:`3o1_oonfX01?ooV`3oo`00
ool0ZOo/o`06oookJP03oi<0oooonf[ooo]Z00Gooo]Z00?ookL0oeL0oooonfX07ooonfX002Oooo]Z
00CoK03ooookJ_oonf[oon<01?oonfX00ooo3@3ooo]ZoookJP0@oookJP05o`3oCOoonf[ooo]Zoook
J_oo0:X01?oonfX00omI0?oooo]ZoookJP09oookJP03obT0oooonf[ooo]Z00Gooo]Z00?o0?o`oook
J_oonfX01ooonfX2onGo0004oookJ_oo00_oo`0;oookJP?oiOl00_oonfX2oole00OoiOl00ooonfX0
0ol0onSooo]ZoookJP02ocKo023ooo]Z1Ol0hol?oookJPKo0>?o2?oUo`0DoookJP;o=_l00ol0onP2
o`3oU`04ocOo0?l0POooocD0oole00?ooo]Z00?oo`0;oooX0?ooj0001?oonfX2o`3ol0;ooo]Z00?o
:@3ooookJ_nDo`001_nDo`000ooo0:[o0?m=o`000007oookJP04onGo0?ooh`3ooo]Zof`0o`?ooo]Z
00?oH_l0oookJ_oonfX02_oonfX01OoRo`3ooo]ZoookJ_mJo`3o0?nn00;ooo]Z00?oo`3foookJ_l0
0ol00ooonfX02?l0odSooo]ZoookJ_oonf[o0?mgoookJ_mi0?ooUol02?oonfX00ooo_`3oiOl0o`3o
XP03onGo0003o`3o8Ooonf[ooo]Z00;ooo]Z00?oo`3bo`3oE_oonfX00_oonfX01Ooo0:3ooo]Zoook
J_mD0?oo02Go00?ooo]Z00?o:P3oool:0?oonfX00_oonfX00omko`3ooo]ZonGo0002onGo0005oom1
0?oUo`3oiOl0o`3o>?l80?l02_oonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z00go
oo]Z00?o0?neoookJ_oonfX00ooonfX3onGo017ooo]Z00?oo`1?oookJ_oonfX01?oUo`05oookJP05
oolL0?oonf[ooo]ZoookJ_nho`003OoonfX01?oBo`3ooo]ZoookJ_oMo`02oookJP03ob/0oooonf[o
oo]Z00;ooo]Z00Gooi/0ool00?oonf[ok?l0ool0Z@05oookJP03oi<0oooonf[ooo]Z00Gooo]Z00?o
okL0oeL0oooonfX0@ooonfX01Om/0?oooo]ZoookJ_oonf[oon<000Cooo]Z00?oo`d0oookJ_oonfX0
3ooonfX01Ol0odgooo]ZoookJ_oonf[oo`2Z00Gooo]Z00?oF@3ooookJ_oonfX02?oonfX00olY0?oo
oo]ZoookJP05oookJP;o0?o`2OoonfX2oooX0003oookJ_oo00_oo`0;00Kooo]Z0_oo=@02o`21o`;o
oo]Z00?o0?nGoookJ_oonfX00_oonfX2o`3oj0;ooo]Z0_lfo`0PoookJPGo0>?o3ooonfX=o`3SoaGo
oo]Z0_lfo`03o`3oj003o`3oUooonf[o087o00;oocD00ooonfX2ool02`;oonP00ooonfX2o`3ol0;o
oo]Z00?o:@3ooookJ_oonfX01?oonfX00omI0?oo0000ool0ZP02o`3oC@Oooo]Z00Coo`d0oooS0?oo
nf[oK03o0ooonfX00omRo`3ooo]ZoookJP0;oookJP04on;o0?oonf[ooo]Zoe[o00?ooo]Z00?oo`3f
o`03oooonfX00_oonfX00ol0odSooo]ZoookJP02oookJP04o`3oMomi0?ooobL0oiOo00Oooo]Z00Co
okl0oookJ_oonf[o0?nR0ooonfX01_l0ob7ooo]ZoookJ_oonf[oo`3bo`3oEP?ooo]Z00Goo`2Poook
J_oonf[oE03oo`0Uo`04oookJP03obX0oooo2P3ooo]Z00;ooo]Z00GoNol0oookJ_oonf[ooi`0oom1
0003oookJP03o`3o>?oonf[ooo]Z00Sooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]Zoook
JP0>oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX04?oonfX01Ooo04oooo]Zoook
J_oonf[o0?nF00Kooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000=oookJP04om;o0?oonf[ooo]Zomgo
00;ooo]Z00?o:`3ooookJ_oonfX00ooonfX01?ooV`3oo`00oookJ_o/o`06oookJP03oi<0oooonf[o
oo]Z00Gooo]Z00?ookL0oeL0oooonfX07ooonfX002Kooo]Z00CoK03ooookJ_oob@3oolT01?oonfX0
0ooo3@3ooo]ZoookJP0@oookJP05o`3oCOoonf[ooo]ZoookJ_oo0:X01?oonfX00omI0?oooo]Zoook
JP09oookJP03obT0oooonf[ooo]Z00Cooo]Z0_l0oo09oookJP04onGo0?oonf[ooo]Zool02`Cooo]Z
00CoiOl0oookJ_oo=@3oocD02?oUo`02oookJP;o0?oX00?ooo]ZocKo0?lfo`007OoonfX5o`3So`[o
oo]Z2_oo0>`AonGo00;o0>?o4_oonfX2ocKo00;o0?oX0_l0oiL01?lgo`3o087ooole0?oo=@03oook
JP03ool02oooj03oonP000Cooo]Z00Co0?o`oookJ_oonf[o:@3o0ooonfX5oiCo0003ool0Z_l0odgo
0?m=00Oooo]Z00Coo`d0oooS0?oonf[oK03o0ooonfX00omRo`3ooo]ZoookJP0:oookJP04on;o0?oo
nf[ooo]Zoe[o00?ooo]Z00?oo`3foookJ_l00ol00_oonfX00ol0odSooo]ZoookJP02oookJP04o`3o
Mooonf[oN@3ooiOo00Oooo]Z00CoiOl0oono0?oUo`3o0?nR0_oUo`000ol0ob7ooo]ZoookJP03oook
JP03ool0l_l0oeKooo]Z00;ooo]Z00Coo`2PoookJ_oonf[oE03o0ooonfX00olZ0?ooo`X0oookJP03
oookJP05og_o0?oUo`3oiOl0onGo0?oo@@000ooUo`000ol0ocSo203ooookJP08oookJP03oolP0?oo
nf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX03_oonfX00ol0okGooo]ZoookJP03oookJP;oiOl04_oo
nfX00ooo04oooo]ZoookJP03onGo00Gooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000=oookJP07om;o
0?oonf[ooo]ZoookJ_oMo`3ooo]Zob/0o`05oookJP04ool00?oonf[ok?l0ool0Z@Gooo]Z00?oT`3o
oookJ_oonfX01OoonfX00ooo]`3oE`3ooookJP12oookJP05of`0oooonf[ooo]ZoookJ_ooh`001?oo
nfX00ooo3@3ooo]ZoookJP0?oookJP05o`3oCOoonf[ooo]ZoookJ_oo0:X01OoonfX00omI0?oooo]Z
oookJP08oookJP03obT0oooonf[ooo]Z00Gooo]Z00?o0?o`oookJ_oonfX01ooonfX2oooX00;ooo]Z
00?oo`0;oookJ_oonfX01?oonfX2oole0004ocOo0?l0POoooo]ZoookJP;o0?nG0ooonfX2o`3oj0;o
oo]Z0_lfo`0LoookJPKo0>?o2OoonfX@ool0k0Sooo]Z1Ol0holCoookJP;o=_l00_l0onP00ol0oiOo
oo]Zo`21o`02oole00?ooo]Z0_oo00/2oooX00?ooo]Z00Co0?o`oookJ_oonf[o:@3o1OoonfX00ol0
003oF@3ooeT0o`02ool0ZP03o`3oCOoonf[ooo]Z00Gooo]Z00Coo`d0oooS0?oonf[oK03o0ooonfX0
0omRo`3ooo]ZoookJP0;oookJP04on;o0?oonf[o0?nnoe[o00?ooo]Z00Goo`3fo`03oooonf[ooo]Z
o`3oB005oookJP04o`3oMomi0?ooobL0oiOo00Oooo]Z00Cookl0oookJ_oonf[o0?nR0_oonfX00ol0
ob7ooo]ZoookJP02oookJP03ool0l_l0oeKooo]Z00;ooo]Z00Coo`2PoookJ_oonf[oE03o1?oonfX0
0olZ0?ooo`X0oookJP03oookJP04og_o0?oonf[ooo]Zoom100Cooo]Z00?o0?lhoookJ_oonfX02?oo
nfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z00gooo]Z00?o0?neoookJ_oonfX01?oo
nfX00ol0oh_ooo]ZoookJP0@oookJP05ool0Cooonf[ooo]ZoookJ_l0oiH01_oonfX01Ooo703ooo]Z
oookJ_oonf[o^?l000gooo]Z00Ood_l0oookJ_oonf[ooo]Zomgo0?oonf[o:`3o00Kooo]Z00?oo`00
oookJ_o/o`001_oonfX00onC0?oooo]ZoookJP05oookJP03oong0?mG0?oooo]Z01oooo]Z000Uoook
JP03of`0oooonf[oolT000;oolT00ooonfX00ooo3@3ooo]ZoookJP0?oookJP;o0?m=0ooonfX00ooo
0:[ooo]ZoookJP02oookJP03oeT0oooonf[ooo]Z00Wooo]Z00?o:@3ooookJ_oonfX01?oonfX00ol0
oo3ooo]ZoookJP07oookJP;oiOl000?ooo]Zool02ooo00/01OoonfX2oole0003oookJ_oUo`3oiOl0
00KoiOl000Cooo]Zo`3oj?l0onSooo]Z0_lfo`0JoookJPGo0>?o0_oonfX=ool0k0oooo]Z3ooUo`04
o`3Soa3ooo]Z00?oiOl0o`3oj?l0onP00_l0oiL01?lgo`3o087ooole0?oo=@03oookJP03ool02ooo
j03oonP000?ooo]Z0_l0oo000ooonf[o:@3oobT0o`03oookJP07o`000?nDo`3oU?l0oiCo0?oonf[o
o`2Zo`3oC@07oookJP04ool=0?ooh`3ooo]Zof`0o`?ooo]Z00?oH_l0oookJ_oonfX02_oonfX01?oR
o`3ooo]ZoookJ_mJo`02oookJP03ool0m_oonf[o00?o00?ooo]Z00Go0?m8oookJ_oonf[ooo]Zo`3o
M`02oookJP03ogT0oonGo`3ooo]Z00Kooo]Z00CoiOl0oono0?oUo`3o0?nR0_oUo`000ol0ob7ooo]Z
oookJP03oookJP05ool0l_oonf[ooo]ZoookJ_oo0:000_oonfX00omD0?oo02GooookJP02oookJP03
obX0oooo2P3ooo]Z00;ooo]Z00?oNol0onGo0?oUo`000_oUo`001Ooo@@3oiOl0onGo0?l0ocSo203o
00[ooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP0=oookJP03o`3o]Ooonf[ooo]Z
00Cooo]Z00?oiOl0oookJ_oonfX04?oonfX01?oo04oooo]ZoookJ_oonfX3onGo00Gooo]Z00Cooa`0
oookJ_oonf[o^?l03_oonfX01_oBo`3ooo]ZoookJ_oMo`3ooo]Zob/0o`Gooo]Z00Cooi/0ool00?oo
nf[ok?l01_oonfX00onC0?oooo]ZoookJP05oookJP03oong0?mG0?oooo]Z043ooo]Z00?oK03ooook
J_oonfX00_oonfX01Oooh`3ooo]ZoookJ_oonf[oo`d0017ooo]Z00Go0?m=oookJ_oonf[ooo]Zool0
ZP05oookJP03oeT0oooonf[ooo]Z00Sooo]Z00?o:@3ooookJ_oonfX01?oonfX2o`3ol0Wooo]Z00?o
onP0oookJ_oonfX00_oo00/5oookJP;oocD000?o=ol0o`21ool0POl00_oonfX01?l0oiOooo]Zoook
J_oonfX2o`3oj0;ooo]Z0_lfo`0IoookJPGo0>?o0_oonfX=ool0k13ooo]Z2ooo0>`2oookJPGo0>?o
4OoonfX01_lfo`3o0?oXo`3oj?l0oiOooo]Zo`21o`;oocD00ooonfX2ool02`;oonP00_oonfX2o`3o
l003oookJ_lY0?oo:@3o00?ooo]Z0ol000001?mI0?oooo]Zool0Z_l0odd7oookJP04ool=0?ooh`3o
oo]Zof`0o`?ooo]Z00?oH_l0oookJ_oonfX02ooonfX01?oRo`3ooo]Zo`3o__mJo`02oookJP03ool0
m_l00ooooo]Z00;ooo]Z00?o0?m8oookJ_oonfX00_oonfX01Ol0ogOooo]ZogT0oooo9`3oUol000Ko
oo]Z00Go0:;ooono0?oonf[o0?nRo`2<o`02oookJP03o`3o8Ooonf[ooo]Z00;ooo]Z00Goo`3bo`3o
E_oonf[ooo]Zool0X003oookJP03oe@0oooonf[ooo]Z00;ooo]Z00?o:P3oool:0?oonfX00_oonfX0
1Omko`3ooo]ZoookJ_ooW03ood4000?ooo]Z00?o0?lhoookJ_oonfX02?oonfX00ooo803ooo]Zoook
JP02oookJP03ool0]Ooonf[ooo]Z00gooo]Z00?o0?neoookJ_oonfX01OoonfX00ol0oh_ooo]Zoook
JP0?oookJP03ool0Cooonf[ooo]Z00;ooo]Z00?o0?nFoookJ_oonfX01?oonfX01Ooo703ooo]Zoook
J_oonf[o^?l000gooo]Z00Kod_l0oookJ_oonf[ogOl0oookJ_l[0?l6oookJP04oonK0?oo003oo`2Y
onco00Kooo]Z00?oT`3ooookJ_oonfX01?oonfX00ooo]`3oE`3ooookJP0OoookJP009_oonfX3ooo9
00?ooo]Z00?oo`d0oookJ_oonfX03ooonfX00ol0odgooo]ZoookJP02oookJP03ool0Z_oonf[ooo]Z
00;ooo]Z00?oF@3ooookJ_oonfX02OoonfX00olY0?oooo]ZoookJP04oookJP03o`3ol?oonf[ooo]Z
00Kooo]Z0_oUo`000ooonf[oo`0;ool02`05oookJP;oocD000?ooo]ZonGo0?oUo`000ooonfX4onGo
00;o0?oX00?ooo]ZocKo0?lfo`006?oonfX4o`3So`Cooo]Z0ooo0>`LoookJQ3oiOl00_oo0>`00ooo
nf[o0>?oo`3So`03o`3So`Oooo]Z0_nDo`04oookJP03onGo0?l0onSo0?oX00;o0?nG00?oiOl0o`21
oooo=@001?oonfX00ooo00_oonP0oooX0003oookJP04o`3ol?oonf[ooo]ZobT0o`;ooo]Z1?l00000
1?nDo`3oF@3oool0Z_l0odd8oookJP03oooS0?oonf[oK03o00?ooo]Z00?oH_l0oookJ_oonfX02_oo
nfX01?oRo`3ooo]ZoookJ_oUo`02oookJP03ool0m_oonf[o00?o00?ooo]Z00Go0?m8oookJ_oonf[o
oo]Zo`3oM`02oookJP03ogT0oooonf[ooo]Z00Kooo]Z00?ookl0oookJ_l0oj800_oUo`000ooonf[o
0?lQoookJP03oookJP03ool0l_l0oeKooo]Z00;ooo]Z00Goo`2PoookJ_oonf[oE03oo`0Uo`02oook
JP03obX0ool0C?ooo`X000?ooo]Z00GoNol0onGo0?oUo`3oiOl0oom10002onGo0003oookJ_l0ocSo
203o00[ooo]Z00Goob00oookJ_oonf[ooo]Zool0]@0?oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o
0?n;oookJ_oonfX04?oonfX01?oo04oooo]ZoookJ_oonfX3onGo00Gooo]Z00Cooa`0oookJ_oonf[o
^?l03_oonfX01?oBo`3ooo]ZoookJ_oMo`02oookJP03ob/0oooonf[ooo]Z00;ooo]Z00Cooi/0ool0
0?oonf[ok?l01_oonfX00onC0?oooo]ZoookJP05oookJP03oong0?mG0?oooo]Z04Cooo]Z00Goon<0
oookJ_oonf[ooo]Zool=000AoookJP05o`3oCOoonf[ooo]ZoookJ_oo0:X01OoonfX00omI0?oooo]Z
oookJP08oookJP03obT0oooonf[ooo]Z00Cooo]Z00?o0?o`oookJ_oonfX01ooonfX2oooX0003oook
J_oo00_oo`0;00Gooo]Z0_oo=@000ooonf[o087oo`21o`02oookJP;o0?nG0ooonfX00ol0onSooo]Z
oookJP02ocKo01Oooo]Z1?l0hol4oookJP?oo`3/:?oonfX7ool0k0Go0>?o3_oonfX01_lfo`3o0?oX
o`3oj?l0oiOooo]Zo`21o`;oocD00ooonfX01?oo00_ooo]ZoooX0?ooj002oookJP;o0?o`00Cooo]Z
obT0oooonf[ooo]Z1?l00002oeT0o`03ool0Z_l0odgo0?m=00Oooo]Z00?oon<0oookJ_m/0?l00ooo
nfX00omRo`3ooo]ZoookJP0;oookJP04on;o0?oonf[o0?nnoe[o00;ooo]Z00?oo`3fo`03oooonfX0
0_oonfX00ol0odSooo]ZoookJP02oookJP04o`3oMooonf[oN@3ooiOo00Oooo]Z00Go0:;ooono0?oo
nf[o0?nRo`2<o`02oookJP06o`3o8Ooonf[ooo]ZoookJ_oo0?;o0?mF0ooonfX01Ooo0:3ooo]Zoook
J_mD0?oo02Go00?ooo]Z00?o:P3ooookJ_oo2P000ooonfX01Omko`3ooo]ZoookJ_ooW03ood4000?o
oo]Z00?o0?lhoookJ_oonfX02?oonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z00go
oo]Z00?o0?neoookJ_oonfX01?oonfX00ol0oh_ooo]ZoookJP0@oookJP05ool0Cooonf[ooo]Zoook
J_l0oiH01_oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000gooo]Z00Cod_l0oookJ_oonf[ogOl00_oo
nfX00ol[0?oooo]ZoookJP03oookJP04oonK0?oo003oo`2Yonco00Kooo]Z00?oT`3ooookJ_oonfX0
1OoonfX00omG0?oooo]ZoookJP0NoookJP009OoonfX4ooo900?ooo]Z00?oo`d0oookJ_oonfX03_oo
nfX00ol0odgooo]ZoookJP02oookJP03ool0Z_oonf[ooo]Z00;ooo]Z00?oF@3ooookJ_oonfX02Ooo
nfX00olY0?oooo]ZoookJP03oookJP;o0?o`2?oonfX01?oUo`3ooo]ZoookJ_oo00/5oookJP;oocD0
00?ooo]ZonGo0?oUo`000ooonfX2o`3oU`;oiOl00_l0onP00ooonf[o=_l0ocKo000GoookJP?o0>?o
1?oonfX4ool0k1oooo]Z2ooUo`07oookJP?oo`3/0ooonfX00ol0hoooU?l0oiCo0004oookJP?oU?l0
1OoonfX00ooUo`3o0?oXo`3oj002onGo0003o`21oooo=@3oocD000?ooo]Z0_oo00/01Oooj03ooo]Z
oookJ_oonf[o0?o`00;ooo]Z0_lY0?l4o`0000;ooo]Z00CoF@3oool0Z_l0odgo0?m=1ooonfX00ooo
h`3ooo]Zof`0o`03oookJP03of;o0?oonf[ooo]Z00[ooo]Z00Coh_l0oookJ_oUo`3o0?nn0_oonfX0
0ooo0?Kooo]Zo`03o`03oookJP08o`3oB?oonf[ooo]ZoookJ_l0ogOooo]ZogT0oonGo`07oookJP04
onGo0?oo_`3ooo]Zo`3oXP;oiOl000?o0?lQoookJ_oonfX00ooonfX00ooo0?;ooo]ZoookJP02oook
JP04ool0X?oonf[oE03oo`0Uo`?ooo]Z00?o:P3oool:0?oonfX00_oonfX01Omko`3oiOl0onGo0?oU
o`3ood4000;oiOl00_oonfX00ol0ocSo203ooookJP08oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?o
o`2eoookJ_oonfX03OoonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z017ooo]Z00Co
o`1?oookJ_oonf[ooo]Z0_oUo`05oookJP05oolL0?oonf[ooo]ZoookJ_nho`003OoonfX01ooBo`3o
oo]ZoookJ_oonf[ogOl0oookJ_l[0?l01?oonfX01OooV`3oo`00oookJ_o/o`3oo`2Y00Gooo]Z00?o
T`3ooookJ_oonfX01OoonfX00ooo]`3oE`3ooookJP13oookJP05oooS0?oonf[ooo]ZoookJ_oo3@00
4OoonfX01Ol0odgooo]ZoookJ_oonf[oo`2Z00Gooo]Z00?oF@3ooookJ_oonfX02?oonfX00olY0?oo
oo]ZoookJP03oookJP;o0?o`2OoonfX01?ooj03ooo]ZoookJ_oo00/5oookJP;oocD000?ooo]Zo`21
ool0POl00ooonfX01?l0oiOooo]ZoookJ_oonfX2o`3oj003oookJ_lfo`3o=_l001Kooo]Z0ol0hol4
oookJPCoo`3/<_oonfX3ool0k0;ooo]Z0ol0hol=oookJP03ocKo0?l0onSo0?oX00;o0?nG00?o087o
oole0?oo=@000_oonfX2ool02`03oookJ_ooj03ooo]Z00;ooo]Z00Co0?o`oookJ_lY0?oo:@3o1?l0
0002oookJP04oeT0oooo0:[ooo]Zo`3oC@Oooo]Z00?oon<0oookJ_m/0?l00ooonfX00omRo`3ooo]Z
oookJP0;oookJP03on;o0?oonf[oF_l000?ooo]Z00?oo`3fo`03oooonfX00_oonfX00ol0odSooo]Z
oookJP02oookJP04o`3oMomi0?ooobL0oiOo00Kooo]Z00Go0:;ooono0?oonf[ooo]Zo`3oXP02oook
JP03o`3o8Ooonf[ooo]Z00;ooo]Z00?oo`3bo`3oE_oonfX00_oonfX01?oo0:3ooo]ZoookJ_mD0?l4
oookJP03obX0oooo2P3ooo]Z00;ooo]Z00GoNol0oookJ_oonf[ooi`0oom10004oookJP03o`3o>?oo
nf[ooo]Z00Oooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP0=oookJP03o`3o]Ooo
nf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX04?oonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Kooo]Z
00Gooa`0oookJ_oonf[ooo]ZokSo000=oookJP07om;o0?oonf[ooo]ZoookJ_oMo`3ooo]Zob/0o`05
oookJP04oonK0?oo003ooo]Zonco00Kooo]Z00?oT`3ooookJ_oonfX01OoonfX00ooo]`3oE`3ooook
JP0NoookJP009OoonfX4ooo900;ooo]Z00?oo`d0oookJ_oonfX03_oonfX00ol0odgooo]ZoookJP02
oookJP03ool0Z_oonf[ooo]Z00;ooo]Z00?oF@3ooookJ_oonfX02OoonfX00olY0?oooo]ZoookJP03
oookJP03o`3ol?oonf[ooo]Z00Sooo]Z00?oonP0ool02ooo00/01?oonfX2oole00;ooo]Z00?oiOl0
ocOo0?oonfX00_oonfX00ol0oiOooo]ZoookJP02o`3oj003oookJ_lfo`3o=_l001Kooo]Z0ol0hol4
oookJP?oo`3/8ooonfX4onGo00Oooo]Z0_nDo`08oookJP?oo`3/0ooonfX2oiCo0003oookJ_nDo`3o
U?l000?oU?l01_oonfX00ooUo`3o0?oXo`3oj002onGo0003o`21oooo=@3oocD000?ooo]Z00?oiOl0
oooX0?oonfX00_oonfX2o`3ol0;ooo]Z00Co:@3oo`000?l0003o00000ooonfX01?mI0?ooo`2Zoook
J_l0odd7oookJP03oooS0?oonf[oK03o00?ooo]Z00?oH_l0oookJ_oonfX02_oonfX01?oRo`3ooo]Z
onGo0?l0okh2oookJP03ool0m_oonf[o00?o00?ooo]Z00Co0?m8oookJ_oonf[o0?mg0_oonfX00omi
0?ooUol0oookJP06oookJP07onGo0?oo_`3ooo]Zo`3oX_oUo`3ooo]Zo`3o8@04oookJP03ool0l_l0
oeKooo]Z00;ooo]Z00Goo`2PoookJ_oonf[oE03oo`0Uo`02oookJP03obX0ool0C?ooo`X000?ooo]Z
00GoNol0onGo0?oUo`3oiOl0oom10002onGo0003oookJ_l0ocSo203o00[ooo]Z00Goob00oookJ_oo
nf[ooo]Zool0]@0?oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX04?oonfX00ooo
04oooo]ZoookJP02oookJP03onGo0?oonf[ooo]Z00Cooo]Z00Cooa`0oookJ_oonf[o^?l03OoonfX0
1ooBo`3ooo]ZoookJ_oonf[ogOl0oookJ_l[0?l01OoonfX01?oo003ooo]Zonco0?oo0:T5oookJP03
oi<0oooonf[ooo]Z00Gooo]Z00?ookL0oeL0oooonfX0@_oonfX01Oooh`3ooo]ZoookJ_oonf[oo`d0
017ooo]Z00Go0?m=oookJ_oonf[ooo]Zool0ZP05oookJP03oeT0oooonf[ooo]Z00Sooo]Z00?o:@3o
oookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP08oookJP04oooX0?oonf[oo`0;ool02`Cooo]Z0_oo
=@02oookJP04o`21oooonf[ooo]ZoookJP;o0?nG0_oonfX2o`3oj003oookJ_lfo`3o=_l001Gooo]Z
0ol0hol4oookJP?oo`3/>OoonfX3ool0k0;ooo]Z0ol0hol<oookJP03ocKo0?l0onSo0?oX00;o0?nG
00?o087ooole0?oo=@000_oonfX00ooo00_ooo]ZoooX0003oookJP;o0?o`00?ooo]ZobT0ool00000
0_l00003oookJP04oeT0oooo0:[ooo]Zo`3oC@Oooo]Z00?oon<0oookJ_m/0?l00ooonfX00omRo`3o
oo]ZoookJP0;oookJP03on;o0?oonf[oF_l000?ooo]Z00?oo`3fo`03oooonfX00_oonfX02Ol0odSo
oo]ZoookJ_oonf[o0?mgoookJ_mi0?ooobL0oiOo0006oookJP05o`2Roooo_`3ooo]Zo`3oX_l0S?l0
0_oonfX01_l0ob7ooo]ZoookJ_oonf[oo`3bo`3oEP?ooo]Z00Goo`2PoookJ_oonf[oE03oo`0Uo`03
oookJP03obX0oooonf[oo`X000?ooo]Z00GoNol0oookJ_oonf[ooi`0oom10003oookJP03o`3o>?oo
nf[ooo]Z00Sooo]Z00Goob00oookJ_oonf[ooo]Zool0]@0?oookJP03o`3o]Ooonf[ooo]Z00Gooo]Z
00?o0?n;oookJ_oonfX03ooonfX00ooo04oooo]ZoookJP02oookJP03o`3oU_oonf[ooo]Z00Cooo]Z
00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP07om;o0?oonf[ooo]ZoookJ_oMo`3ooo]Zob/0o`06
oookJP03ool00?oonf[ok?l000Kooo]Z00?oT`3ooookJ_oonfX01OoonfX00ooo]`3oE`3ooookJP0N
oookJP009OoonfX3ooo900;ooo]Z00?oo`d0oookJ_oonfX03_oonfX00ol0odgooo]ZoookJP02oook
JP03ool0Z_oonf[ooo]Z00;ooo]Z00?oF@3ooookJ_oonfX02OoonfX00olY0?oooo]ZoookJP02oook
JP;oiOl02_oonfX00oooj03oo`0;oookJP04oookJP03oole0?oonf[ooo]Z00;oiOl00ooonfX2o`3o
U`;ooo]Z00Co0?oXoookJ_lfo`3o=_l05_oonfX2o`3So`?ooo]Z1?oo0>`aoookJPCoU?l02OoonfX3
ool0k0;ooo]Z2?nDo`03oookJPCoiOl000Go0?oXonGo0?oUo`3oiOl0o`21o`02oole00?oiOl00_oo
j003oookJP04o`3ol?oonf[o0000obT0o`;o00001?oonfX01?mI0?ooo`2ZoookJ_l0odd7oookJP03
oooS0?oonf[oK03o00?ooo]Z00?oH_l0oookJ_oonfX02_oonfX01?oRo`3ooo]ZonGo0?l0okh2oook
JP03ool0m_oonf[o00?o00?ooo]Z00Co0?m8oookJ_oonf[o0?mg0_oonfX00omi0?ooUol0oookJP05
oookJP07onGo0?oo_`3ooo]Zo`3oX_oUo`3ooo]Zo`3o8@05oookJP03ool0l_oonf[ooo]Z00;ooo]Z
00Coo`2PoookJ_mD0?oo02Go0ooonfX00olZ0?ooo`X0oookJP02oookJP05og_o0?oonf[oiOl0onGo
0?oo@@000_oUo`02oookJP03o`3o>?l80?oooo]Z00Sooo]Z00Goob00oookJ_oonf[ooo]Zool0]@0?
oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX04?oonfX00ooo04oooo]ZoookJP02
oookJP03o`3oU_oonf[ooo]Z00Cooo]Z00Cooa`0oookJ_oonf[o^?l03_oonfX01?oBo`3ooo]Zoook
J_oMo`02oookJP03ob/0oooonf[ooo]Z00;ooo]Z00Cooi/0ool00?oonf[ok?l01_oonfX00onC0?oo
oo]ZoookJP05oookJP03oeL0oooonf[ooo]Z043ooo]Z00Goon<0oookJ_oonf[ooo]Zool=000Aoook
JP03o`3oCOoonf[ooo]Z00;ooo]Z00?oo`2ZoookJ_oonfX00_oonfX00omI0?oooo]ZoookJP08oook
JP03obT0oooonf[ooo]Z00?ooo]Z00?o0?o`oookJ_oonfX02?oonfX00oooj03oo`0;ool02`05oook
JP03oole0?oonf[ooo]Z00;o087o0ooonfX00ol0oiOooo]ZoookJP02o`3oj003oookJ_lfo`3o=_l0
01Gooo]Z0_l0hol3oookJPCoo`3/?ooonfX3ool0k0;ooo]Z0_l0hol;oookJP;o=_l000Go0?oXoook
J_l0oiOo0?nGo`21o`02oole0003oookJ_oo00_oo`0;00;oonP00ooonfX00ol0oo3o0000obT0o`02
o`0000Cooo]Z00?oF@3oool0Z_oonfX00_l0odd6oookJP03oooS0?oonf[oK03o00?ooo]Z00?oH_l0
oookJ_oonfX02ooonfX00ooRo`3ooo]Zoe[o0003oookJP03ool0m_l00ooooo]Z00;ooo]Z00Wo0?m8
oookJ_oonf[ooo]Zo`3oMooonf[oN@3ooookJ_nGo`001_oonfX01ol0X_oookl0oookJ_l0oj;o08co
oookJ_l0ob401?oonfX00ooo0?;o0?mFoookJP02oookJP04ool0X?oonf[ooo]Zoe@0o`Cooo]Z00?o
:P3oool:0?oonfX00_oonfX01Omko`3ooo]ZoookJ_ooW03ood4000Cooo]Z00?o0?lhoookJ_oonfX0
1ooonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z00gooo]Z00?o0?neoookJ_oonfX0
1?oonfX00ol0oh_ooo]ZoookJP0@oookJP05ool0Cooonf[ooo]ZoookJ_l0oiH01_oonfX01Ooo703o
oo]ZoookJ_oonf[o^?l000gooo]Z00Cod_l0oookJ_oonf[ogOl00_oonfX00ol[0?oooo]ZoookJP03
oookJP04oonK0?oo003oo`2Yonco00Kooo]Z00?oT`3ooookJ_oonfX01OoonfX00omG0?oooo]Zoook
JP0MoookJP009OoonfX3ooo90003oookJ_oo3@3ooo]Z00oooo]Z00?o0?m=oookJ_oonfX00_oonfX0
0ooo0:[ooo]ZoookJP02oookJP03oeT0oooonf[ooo]Z00Wooo]Z00?o:@3ooookJ_oonfX00_oonfX3
onGo00Wooo]Z00?oonP0oookJ_oonfX01?oonfX01Ooo=@3ooo]Zo`21oooUo`3o=ol000?ooo]Z00?o
0?nGoookJ_oonfX00_l0onP2ocKo01Gooo]Z0ol0hol2oookJP?oo`3/=OoonfX6oiCo00[ooo]Z0ooo
0>`8oiCo00;ooo]Z1OoUo`02o`3oj0?oiOl000?o087ooole0?oo=@000ooUo`001?ooj03ooo]Zoook
J_oonfX2o`3ol003o`000?lY0?oo:@3o00Gooo]Z00CoF@3oool0Z_oonf[o0?m=1_oonfX01?oo3@3o
on<0oookJ_m/0?l3oookJP03of;o0?oonf[ooo]Z00[ooo]Z00Coh_l0oookJ_oUo`3o0?nn0_oonfX0
0ooo0?Kooo]Zo`03o`02oookJP05o`3oB?oonf[ooo]ZoookJ_l0ogL00_oonfX00omi0?oooo]Zoook
JP05oookJP07onGo0?oo_`3ooo]Zo`3oX_oUo`3ooo]Zo`3o8@04oookJP03ool0l_l0oeKooo]Z00?o
oo]Z00Coo`2PoookJ_mD0?oo02Go0_oonfX00olZ0?ooo`X0oookJP03oookJP06og_o0?oonf[oiOl0
onGo0?oo@@3oiOl00_oonfX00ol0ocSo203ooookJP09oookJP05oolP0?oonf[ooo]ZoookJ_oo0;D0
3ooonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z013ooo]Z00?oo`1?oookJ_oonfX0
0_oonfX00ol0oiKooo]ZoookJP04oookJP05oolL0?oonf[ooo]ZoookJ_nho`003OoonfX01ooBo`3o
oo]ZoookJ_oonf[ogOl0oookJ_l[0?l01?oonfX01?ooV`3oo`00oookJ_o/o`06oookJP03oi<0oooo
nf[ooo]Z00Gooo]Z00?ookL0oookJ_oonfX0?ooonfX00oooh`3ooo]ZoookJP02oookJP03ool=0?oo
nf[ooo]Z00kooo]Z00?o0?m=oookJ_oonfX00_oonfX00ooo0:[ooo]ZoookJP02oookJP03oeT0oooo
nf[ooo]Z00Sooo]Z00?o:@3ooookJ_oonfX01?oonfX00ol0oo3ooo]ZoookJP07oookJP03oooX0?oo
00_ooo]Z00Gooo]Z00GoocD0oookJ_l0POoo087oocOo0002oookJP;o0?nG00Cooo]Zo`3oj?l0onSo
oo]Z0_lfo`0DoookJP?o0>?o0_oonfX3ool0k4Kooo]Z0ooo0>`00ooonf[o0>?oo`3So`0;oookJP07
ocKo0?l0onSo0?oXoookJ_l0oiOooo]Zo`21o`02oole0004oookJ_oo00_ooo]ZoooX00?ooo]Z0_l0
oo02obT0o`Gooo]Z00GoF@3oool0Z_oonf[ooo]Zo`3oC@05oookJP04ool=0?ooh`3ooo]Zof`0o`?o
oo]Z00?oH_l0oookJ_oonfX02ooonfX00ooRo`3oF_l0o`3o_P03oookJP05ool0m_l00ooooo]Zoook
J_l0odP01?oonfX01?l0ogOooo]ZogT0oonGo`06oookJP08o`2Roooo_`3ooo]Zo`3oX_oonf[o08co
oookJ_l0ob43oookJP03ool0l_l0oeKooo]Z00?ooo]Z00Coo`2PoookJ_mD0?oo02Go0ooonfX00olZ
0?ooo`X0oookJP03oookJP05og_o0?oonf[ooo]ZoonL0?oo@@000ooonfX00ol0ocSooo]ZoookJP08
oookJP05oolP0?oonf[ooo]ZoookJ_oo0;D03ooonfX00ol0okGooo]ZoookJP04oookJP03o`3oRooo
nf[ooo]Z013ooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP06oookJP05oolL0?oonf[ooo]ZoookJ_nh
o`003OoonfX01ooBo`3ooo]ZoookJ_oonf[ogOl0oookJ_l[0?l01OoonfX01?ooV`3oo`00ool0ZOo/
o`06oookJP03oi<0oooonf[ooo]Z00Gooo]Z00?ookL0oookJ_oonfX07OoonfX002Gooo]Z0ooob@00
0ooonf[oo`d0oookJP0>oookJP03o`3oCOoonf[ooo]Z00;ooo]Z00?oo`2ZoookJ_oonfX00_oonfX0
0omI0?oooo]ZoookJP09oookJP04obT0oooonf[ooo]ZoookJPCoiOl02?oonfX00ooUo`3oonP0oook
JP05oookJP03oole0?oonf[o087o00;o=ol00_oonfX2o`3oU`03oookJ_l0onSo0?oX00;o=_l05Ooo
nfX2o`3So`;ooo]Z0ooo0>`MoookJQKo0?o]0onDo`000ooonf[oU?l0oiCo0007oiCo00[ooo]Z00Co
U?l0ool0k?oo0>coo`3/1_nDo`08onGo00;o0?oX0_oUo`001?l0oiOo087ooole0?oo=@02onGo00;o
onP00_oonfX01Ol0003o0?o`o`000?l0003o:@3o00Gooo]Z00CoF@3oool0Z_oo0:[o0?m=1_oonfX0
1?oo3@3oon<0oookJ_nDo`03oookJP03of;o0?oonf[ooo]Z00Wooo]Z00Goh_l0oookJ_oUo`3ooo]Z
o`3o_P02oookJP03oiCo0?oonf[oU?l000;ooo]Z00Co0?m8oookJ_oonf[o0?mg0_oonfX00omi0?oo
Uol0oookJP05oookJP05onGo0?oonf[ookl0oookJ_l0oj800_oonfX00ol0ob7ooo]ZoookJP02oook
JP03ool0l_oonf[ooo]Z00;ooo]Z00Coo`2PoookJ_mD0?oo02Go0ooonfX00olZ0?ooo`X0oookJP02
oookJP05og_o0?oonf[oiOl0onGo0?oo@@000_oUo`02oookJP03o`3o>?l80?oooo]Z00Sooo]Z00Go
ob00oookJ_oonf[ooo]Zool0]@0?oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX0
4?oonfX00ooo04oooo]ZoookJP02oookJP03o`3oU_oonf[ooo]Z00?ooo]Z00Gooa`0oookJ_oonf[o
oo]ZokSo000=oookJP07om;o0?oonf[ooo]ZoookJ_oMo`3ooo]Zob/0o`05oookJP03ool00?oonf[o
k?l000Kooo]Z00?oT`3ooookJ_oonfX0BooonfX00ooo3@3ooo]ZoookJP0>oookJP03o`3oCOoonf[o
oo]Z00;ooo]Z00?oo`2ZoookJ_oonfX00_oonfX00omI0?oooo]ZoookJP08oookJP03obT0oooonf[o
oo]Z00Cooo]Z00?o0?o`oookJ_oonfX01ooonfX00oooj03oo`0;oookJP05oookJP04oole0?oonf[o
087oocOo00?ooo]Z00Go0?nGoookJ_l0onSo0?oXoookJP02ocKo01Cooo]Z0_l0hol2oookJP?oo`3/
7_oonfXHo`3okAKooo]Z0ooo0>`3o`3So`[ooo]Z00?o=_l0o`3oj?l0onP00_l0oiL01?lgo`3o087o
oole0?oo=@02ool02`03oooX0?oonf[ooo]Z00;o000000?o0?o`o`000?lY0?l01OoonfX01OmI0?oo
o`2Zool0Z_oonf[o0?m=00Gooo]Z00Coo`d0oooS0?oonf[oK03o0ooonfX00omRo`3ooo]ZoookJP0:
oookJP04on;o0?oonf[oF_l0o`3o_P?ooo]Z00Goo`3fo`03oooonf[ooo]Zo`3oB003oookJP05o`3o
Mooonf[oN@3ooolW0?nGo`001_oonfX01ol0X_oookl0oookJ_l0oj;o08cooookJ_l0ob401?oonfX0
0ooo0?;o0?mFoookJP02oookJP04ool0X?oonf[ooo]Zoe@0o`?ooo]Z00?o:P3oo`1<oooo2P000ooo
nfX01Omko`3ooo]ZoookJ_ooW03ood4000Cooo]Z00?o0?lhoookJ_oonfX01ooonfX00ooo803ooo]Z
oookJP02oookJP03ool0]Ooonf[ooo]Z00cooo]Z00?o0?neoookJ_oonfX01OoonfX00ol0oh_ooo]Z
oookJP0?oookJP03ool0Cooonf[ooo]Z00;ooo]Z00?o0?nFoookJ_oonfX00ooonfX01Ooo703ooo]Z
oookJ_oonf[o^?l000gooo]Z00Ood_l0oookJ_oonf[ooo]Zomgo0?oonf[o:`3o00Kooo]Z00?oo`00
ool0ZOo/o`001_oonfX00onC0?oooo]ZoookJP0UoookJP009OoonfX2ooo90003oookJ_oo3@3ooo]Z
00kooo]Z00?o0?m=oookJ_oonfX00_oonfX00ooo0:[ooo]ZoookJP02oookJP03oeT0oooonf[ooo]Z
00Wooo]Z00Co:@3ooookJ_oonf[ooo]Z1OoUo`07oookJP03onGo0?ooj03oiOl000Gooo]Z00CoocD0
oookJ_l0POoo=ol00_oonfX2o`3oU`03oookJ_l0onSo0?oX00;o=_l05?oonfX3o`3So`;ooo]Z0_oo
0>`KoookJPGo0?o]6OoonfX<oiCo00Sooo]Z1?nDo`03ool0k0GoU?l000?ooo]ZonGo0?oUo`001OoU
o`02o`3oj005onGo0?l0oiOoiOl0o`21oooo=@000_oUo`000ooo00_oonP0oookJP02o`0000;oU?l0
00?ooo]ZobT0oolY0?l01?oonfX01?mI0?oooo]Zool0Z_l0odd6oookJP03ool=0?ooh`3oU?l000?o
oo]Z00?oH_l0oookJ_oonfX02_oonfX02OoRo`3ooo]ZonGo0?oonf[o0?nnoookJ_nDo`3ooo]ZoiCo
0003oookJP04o`3oB?oonf[ooo]Zo`3oM`;ooo]Z00?oN@3ooiOo0?oonfX01OoonfX01?oUo`3ooo]Z
oono0?l0oj82onGo0003o`3o8Ooonf[ooo]Z00;ooo]Z00?oo`3bo`3oE_oonfX00ooonfX01?oo0:3o
oo]Zoe@0ool09Ol2oookJP03obX0oooo2P3ooo]Z00?ooo]Z00KoNol0oookJ_oUo`3oiOl0oom10?oU
o`02oookJP03o`3o>?l80?oooo]Z00Sooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]Zoook
JP0<oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX04?oonfX00ooo04oooo]Zoook
JP02oookJP03o`3oU_oonf[ooo]Z00Cooo]Z00Cooa`0oookJ_oonf[o^?l03OoonfX01OoBo`3ooo]Z
oookJ_oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX00_oonfX01?ooV`3oo`00oookJ_o/o`05oook
JP03oi<0oooonf[ooo]Z04[ooo]Z00?oo`d0oookJ_oonfX03_oonfX00ol0odgooo]ZoookJP02oook
JP03ool0Z_oonf[ooo]Z00;ooo]Z00?oF@3ooookJ_oonfX02?oonfX00olY0?oooo]ZoookJP04oook
JP03o`3ol?oonf[ooo]Z00Oooo]Z00?oonP0oookJ_oo00/01OoonfX01?oo=@3ooo]Zo`21oolgo`02
oookJP;o0?nG0_l0onP00ooonf[o=_l0ocKo000CoookJP?o0>?o0_oonfX2ool0k1cooo]Z1Ol0ondH
oookJPGo0?o]5?oonfX3ool0k0;o0>?o2_oonfX02_lfo`3o0?oXo`3oj?l0oiOooo]ZocOo0?l0POoo
ocD0oookJ_oo00/2oooX00?o00000_l0oo02obT0o`Cooo]Z00GoF@3ooookJ_oo0:[ooo]Zo`3oC@05
oookJP03ool=0?ooh`3oK03o00?ooo]Z00?oH_l0oookJ_oonfX02ooonfX01?oRo`3ooo]Zoe[o0?l0
okh2oookJP03ool0m_l00ooooo]Z00;ooo]Z00Wo0?m8oookJ_oonf[ooo]Zo`3oMooonf[oN@3ooolW
0?nGo`001OoonfX02?l0X_oooo]Zoono0?oonf[o0?nRo`2<oooonf[o0?lQ0ooonfX00ooo0?;o0?mF
oookJP03oookJP04ool0X?oonf[oE03oo`0Uo`?ooo]Z00?o:P3oool:0?oonfX00ooonfX01Omko`3o
oo]ZoookJ_ooW03ood4000?ooo]Z00?o0?lhoookJ_oonfX01ooonfX00ooo803ooo]ZoookJP02oook
JP03ool0]Ooonf[ooo]Z00gooo]Z00?o0?neoookJ_oonfX01?oonfX00ol0oh_ooo]ZoookJP0@oook
JP05ool0Cooonf[ooo]ZoookJ_l0oiH01_oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00Go
d_l0oookJ_oonf[ooo]Zomgo0002oookJP03ob/0oooonf[ooo]Z00?ooo]Z00Cooi/0ool00?oo0:Wo
k?l01OoonfX00onC0?oooo]ZoookJP0UoookJP009OoonfX2ooo90003ool=0?oonf[ooo]Z00kooo]Z
00Go0?m=oookJ_oonf[ooo]Zool0ZP04oookJP03oeT0oooonf[ooo]Z00Wooo]Z00?o:@3ooookJ_oo
nfX01_oUo`06oookJP;oiOl000?oonP0onGo0?oonfX01?oonfX01?oo=@3ooo]Zo`21oolgo`02oook
JP06o`3oUooonf[ooo]Zo`3oj?oonf[o=_l04ooonfX3o`3So`Cooo]Z00?oo`3/oookJ_oonfX05_oo
nfX5o`3okAoooo]Z3OnDo`05oookJPSoU?l00_oo0>`4oiCo00Cooo]Z1OoUo`02o`3oj003o`3oUooU
o`3o087o00;oocD000?oiOl0ool02oooj0001?l000001_nDo`3ooo]ZoookJ_lY0?oooo]ZoiCo00;o
oo]Z0_mI0?l00ooo0:[o0?m=oookJP05oookJP03ool=0?ooh`3oU?l000?ooo]Z00?oH_l0oookJ_oo
nfX02_oonfX01_oRo`3ooo]ZonGo0?oonf[o0?nnoookJP;oiOl000CoU?l0oookJ_oonf[o0?m80ooo
nfX01?l0ogOooo]ZoookJ_mi0?l7oookJP07onGo0?oo_`3oiOl0o`3oX_oUo`3ooo]Zo`3o8@04oook
JP03ool0l_l0oeKooo]Z00;ooo]Z00Coo`2PoookJ_mD0?oo02Go0ooonfX00olZ0?ooo`X0oookJP02
oookJP06og_o0?oonf[ooo]ZonGo0?oo@@3oiOl00_oonfX00ol0ocSooo]Zo`P0o`09oookJP05oolP
0?oonf[ooo]ZoookJ_oo0;D03ooonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z013o
oo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP04oookJP04oolL0?oonf[ooo]ZokSo
00kooo]Z00Ood_l0oookJ_oonf[ooo]Zomgo0?oonf[o:`3o00Cooo]Z00Cooi/0ool00?oonf[ok?l0
1OoonfX00onC0?oooo]ZoookJP19oookJP03ool=0?oonf[ooo]Z00oooo]Z00Go0?m=oookJ_oonf[o
oo]Zool0ZP04oookJP03oeT0oooonf[ooo]Z00Sooo]Z00?o:@3ooookJ_oonfX01?oonfX00ol0oo3o
oo]ZoookJP07oookJP03oooX0?oonf[oo`0;00Gooo]Z00?oocD0oookJ_l0POl00ooonfX00ol0oiOo
oo]Zo`3oj002oookJP03ocKo0?oonf[ooo]Z013ooo]Z0ol0hol4oookJP03ool0k?oonf[ooo]Z01Oo
oo]Z1Ol0ondRoookJPGo0?o]4_oonfX2ool0k0;o0>?o2_oonfX00olfo`3o0?oXo`3oj002oookJP03
o`21oooo=@3ooo]Z00;oo`0;00?oonP0o`000?l000000_l000000ol0oo3ooo]ZobT0o`04oookJP;o
F@3o00?oo`2ZoookJ_l0odd01OoonfX00ooo3@3oon<0of`0o`03oookJP03of;o0?oonf[ooo]Z00_o
oo]Z00Coh_l0oe[o0?oonf[o0?nn0_oonfX01Ooo0?Ko00?ooookJ_oonf[o0?m800Cooo]Z00Co0?mg
oookJ_mi0?ooUol01_oonfX01ol0X_oookl0oookJ_l0oj;o08cooookJ_l0ob401?oonfX00ooo0?;o
0?mFoookJP02oookJP04ool0X?oonf[ooo]Zoe@0o`?ooo]Z00?o:P3oo`1<oooo2P000ooonfX01Omk
o`3ooo]ZoookJ_ooW03ood4000?ooo]Z00?o0?lho`P0oooonfX02?oonfX00ooo803ooo]ZoookJP02
oookJP03ool0]Ooonf[ooo]Z00cooo]Z00?o0?neoookJ_oonfX01?oonfX00ol0oh_ooo]ZoookJP0@
oookJP05ool0Cooonf[ooo]ZoookJ_l0oiH01_oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000gooo]Z
00Ood_l0oookJ_oonf[ooo]Zomgo0?oonf[o:`3o00Gooo]Z00Cooi/0ool00?oo0:Wok?l01OoonfX0
0onC0?oooo]ZoookJP0UoookJP009OoonfX2ooo9013ooo]Z00?o0?m=oookJ_oonfX00_oonfX00ooo
0:[ooo]ZoookJP02oookJP03oeT0oooonf[ooo]Z00Sooo]Z00?o:@3ooookJ_oonfX01ooUo`05oook
JP;oiOl000?oonP0onGo0?oUo`001?oonfX00ooo=@3ooo]Zo`21o`02oookJP;o0?nG0_oonfX00ol0
onSooo]ZocKo000BoookJP;o0>?o1OoonfX2ool0k1Cooo]Z1Ol0ondSoookJQ3oU?l02?oonfX5oiCo
00;oo`3/0onDo`05oookJPGoiOl00_nDo`001_l0oiOoiOl0o`21oooo=@3oU?l0oookJP;oonP00_l0
00001_oonf[oU?l0oookJ_oonf[o:@3ooiCo00Cooo]Z00?oF@3oool0Z_l0odd01_oonfX00ooo3@3o
on<0oiCo0003oookJP03of;o0?oonf[ooo]Z00[ooo]Z00Coh_l0onGo0?oonf[o0?nn0ooUo`001Ooo
nf[oU?l0oookJ_oonf[o0?m800;ooo]Z00Go0?mgoookJ_oonf[oobL0ogT0o`06oookJP;oiOl000Go
okl0o`3oX_oUo`3ooo]Zo`3o8@04oookJP03ool0l_l0oeKooo]Z00?ooo]Z00Coo`2PoookJ_mD0?oo
02Go0_oonfX00olZ0?ooo`X0oookJP03oookJP05og_o0?oonf[ooo]ZonGo0?oo@@000ooonfX00ol0
ocSo203ooookJP08oookJP05oolP0?oonf[ooo]ZoookJ_oo0;D03ooonfX00ol0okGooo]ZoookJP04
oookJP03o`3oRooonf[ooo]Z013ooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP06oookJP05oolL0?oo
nf[ooo]ZoookJ_nho`003OoonfX01ooBo`3ooo]ZoookJ_oonf[ogOl0oookJ_l[0?l01OoonfX00ooo
003ooo]Zonco0005oookJP03oi<0oooonf[ooo]Z04Sooo]Z00?oo`d0oookJ_oonfX03ooonfX01Ol0
odgooo]ZoookJ_oonf[oo`2Z00Cooo]Z00?oF@3ooookJ_oonfX02?oonfX00olY0?oooo]ZoookJP04
oookJP03o`3ol?oonf[ooo]Z00Oooo]Z00?oonP0oookJ_oo00/01OoonfX00ooo=@3o=ol0o`21o`02
oookJP;o0?nG00Gooo]Zo`3oj?oonf[ooo]ZocKo000AoookJP;o0>?o1OoonfX2ool0k1Gooo]Z1Ol0
ond/oookJPGo0?o]3ooonfX2ool0k0?o0>?o2?oonfX2ocKo00;o0?oX00Oooo]Zo`21oooo=@3oocD0
oookJ_oo00_oonP000;o00000_oonfX00ol0oo3ooo]ZobT0o`05oookJP04oeT0oooo0:[ooo]Zo`3o
C@Gooo]Z00?oo`d0oooS0?m/0?l00ooonfX00omRo`3ooo]ZoookJP0:oookJP04on;o0?oonf[oF_l0
o`3o_P?ooo]Z00Goo`3fo`03oooonf[ooo]Zo`3oB003oookJP05o`3oMooonf[ooo]ZogT0oonGo`00
1_oonfX01ol0X_oookl0oookJ_l0oj;o08cooookJ_l0ob400ooonfX00ooo0?;ooo]Zo`3oEP03oook
JP04ool0X?oonf[ooo]Zoe@0o`?ooo]Z00?o:P3oool:0?oonfX00ooonfX01Omko`3ooo]ZoookJ_oo
W03ood4000?ooo]Z00?o0?lhoookJ_oonfX01ooonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooo
nf[ooo]Z00cooo]Z00?o0?neoookJ_oonfX01?oonfX00ol0oh_ooo]ZoookJP0@oookJP05ool0Cooo
nf[ooo]ZoookJ_l0oiH01_oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000gooo]Z00Ood_l0oookJ_oo
nf[ooo]Zomgo0?oonf[o:`3o00Kooo]Z00?oo`00ool0ZOo/o`001OoonfX00onC0?oooo]ZoookJP0U
oookJP009OoonfX00ooob@3ooo]ZoookJP0>oookJP03o`3oCOoonf[ooo]Z00;ooo]Z00?oo`2Zoook
J_oonfX00_oonfX00omI0?oooo]ZoookJP08oookJP03obT0oooonf[ooo]Z00OoiOl01?oonfX3onGo
0003oooX0?oUo`3oiOl000Cooo]Z00?oocD0oookJ_l0POl00_oonfX01ol0oiOooo]ZoookJ_oonf[o
0?oXoookJ_lfo`004_oonfX00ol0hooooo]ZoookJP03oookJP;oo`3/4ooonfX3o`3okBSooo]Z4OnD
o`000ol0ongooo]ZoookJP0;oookJP;oo`3/0_nDo`000ol0hooooo]ZoookJP04oookJPCoiOl000[o
U?l0o`3oUooUo`3o087ooiCo0?oUo`3o0000ool02oooj03o00000_oonfX00onDo`3ooo]ZoiCo0002
oiCo00Cooo]Z00?oF@3oool0Z_l0odd01_oonfX00ooo3@3oon<0oiCo0003oookJP;oU?l02_oonfX0
0ooRo`3ooo]ZonGo0005onGo0004oiCo0?oonf[ooo]Zo`3oB0?ooo]Z00Go0?mgoookJ_oonf[oN@3o
oiOo0003oookJPCoiOl000Kookl0onGo0?l0oj;oiOl0oookJ_l0ob44oookJP03ool0l_l0oeKooo]Z
00?ooo]Z00?oo`2Poe@0ool09Ol00ooonfX00olZ0?ooo`X0oookJP02oookJP06og_o0?oonf[ooo]Z
oookJ_oo@@3oiOl00_oonfX00ol0ocSooo]Zo`P0o`08oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?o
o`2eoookJ_oonfX03?oonfX00ol0okGooo]ZoookJP04oookJP03o`3oRooonf[ooo]Z013ooo]Z00Go
o`1?oookJ_oonf[ooo]Zo`3oUP06oookJP05oolL0?oonf[ooo]ZoookJ_nho`003OoonfX01OoBo`3o
oo]ZoookJ_oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX00_oonfX00oooV`3oo`00onco0005oook
JP03oi<0oooonf[ooo]Z04Oooo]Z00?oo`d0oookJ_oonfX03ooonfX01Ol0odgooo]ZoookJ_oonf[o
o`2Z00Cooo]Z00?oF@3ooookJ_oonfX02?oonfX00olY0?oooo]ZoookJP04oookJP03o`3ol?oonf[o
oo]Z00Oooo]Z00?oonP0oookJ_oo00/01OoonfX00ooo=@3o=ol0o`21o`02oookJP04o`3oUooonf[o
oo]Zo`3oj0;ooo]Z00?o=_l0oookJ_oonfX03ooonfX00ol0hooooo]ZoookJP03oookJP;oo`3/4ooo
nfX4o`3okCKooo]Z0ol0ond>oookJP;oo`3/00?ooo]Zo`3Sool0hol02?oonfX2ocKo0009o`3oj?oo
nf[ooo]Zo`21oooo=@3o0000ool02oooj03o000000?ooo]Z00Co0?o`oookJ_lY0?oo:@3o1?oonfX0
1?mI0?ooo`2ZoookJ_l0odd5oookJP03ool=0?ooh`3oK03o00?ooo]Z00?oH_l0oookJ_oonfX02_oo
nfX01?oRo`3ooo]Zoe[o0?l0okh2oookJP03ool0m_l00ooooo]Z00;ooo]Z00Wo0?m8oookJ_oonf[o
oo]Zo`3oMooonf[oN@3ooolW0?nGo`001OoonfX01ol0X_oookl0oookJ_l0oj;o08cooookJ_l0ob40
1?oonfX00ooo0?;o0?mFoookJP03oookJP03ool0X?oonf[oE03o00?ooo]Z00?o:P3oo`1<oooo2P00
0ooonfX01Omko`3ooo]ZoookJ_ooW03ood4000?ooo]Z00?o0?lho`P0oooonfX01ooonfX00ooo803o
oo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z00gooo]Z00?o0?neoookJ_oonfX01?oonfX00ol0oh_o
oo]ZoookJP0@oookJP04ool0Cooonf[ooo]Zo`3oUPKooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000=
oookJP05om;o0?oonf[ooo]ZoookJ_oMo`000_oonfX00ol[0?oooo]ZoookJP03oookJP03oonK0?oo
003ok?l000Gooo]Z00?oT`3ooookJ_oonfX09OoonfX002Gooo]Z00?oolT0oookJ_oonfX03_oonfX0
1Ol0odgooo]ZoookJ_oonf[oo`2Z00Cooo]Z00?oF@3ooookJ_oonfX02?oonfX00olY0?oooo]ZonGo
0008onGo00?ooo]Z0ooUo`001?ooj03oiOl0onGo0?oUo`03oookJP03oole0?oonf[o087o00;ooo]Z
00Oo0?nGoookJ_oonf[ooo]Zo`3oj?oonf[o=_l001;ooo]Z00?o0>?ooookJ_oonfX00ooonfX00ooo
0>cooo]ZoookJP0AoookJP;o0?o]?OoonfX3o`3ok@cooo]Z0_oo0>`00ooonf[o0>?oo`3So`08oook
JP03onGo0?nDo`3o0?nG00?oU?l000?oocD0o`000?l000000_ooj002oookJPGoU?l01?oonfX00omI
0?ooo`2Zo`3oC@05oookJP05ool=0?oonf[oon<0oiCo0?oonfX00onDo`0;oookJP03on;o0?oUo`3o
iOl000CoiOl000Gooo]ZoiCo0?oonf[ooo]Zo`3oB003oookJP06o`3oMooonf[ooo]ZogT0oonGo`3o
oo]Z1_oUo`001Ooo_`3oiOl0o`3oX_oonf[o0?lQ00Cooo]Z00?oo`3bo`3oE_oonfX00ooonfX01?oo
0:3ooo]Zoe@0ool09Ol2oookJP03obX0oooo2P3o04co00?ooo]Z00GoNol0oookJ_oonf[ooo]Zoom1
0002oookJP03o`3o>?oonf[o203o00Wooo]Z00Goob00oookJ_oonf[ooo]Zool0]@0>oookJP03o`3o
]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX04?oonfX00ooo04oooo]ZoookJP02oookJP03o`3o
U_oonf[ooo]Z00Cooo]Z00Cooa`0oookJ_oonf[o^?l03OoonfX01OoBo`3ooo]ZoookJ_oonf[ogOl0
00;ooo]Z00?o:`3ooookJ_oonfX00_oonfX01?ooV`3oo`00ool0ZOo/o`05oookJP03oi<0oooonf[o
oo]Z05Sooo]Z00Co0?m=oookJ_oonf[oo`2Z1?oonfX00omI0?oooo]ZoookJP08oookJP03obT0oooo
nf[ooo]Z00Cooo]Z00?o0?o`oookJ_oonfX01ooonfX00oooj03ooo]Zool02`05oookJP03oole0?lg
o`3o087o00;ooo]Z00Co0?nGoookJ_oonf[o0?oX0_oonfX00olfo`3ooo]ZoookJP0?oookJP03o`3S
oooonf[ooo]Z00?ooo]Z00?oo`3/oookJ_oonfX04OoonfX2o`3okCgooo]Z0ol0ond=oookJP;oo`3/
00?ooo]Zo`3SoooonfX02?oonfX01_lfo`3o0?oXo`3oUooonf[o087ooole00;o00000_ooj003oook
JP04o`3ol?oonf[ooo]ZobT0o`Cooo]Z00CoF@3oool0Z_oonf[o0?m=1OoonfX00ooo3@3oon<0of`0
o`03oookJP03of;o0?oonf[ooo]Z00[ooo]Z00Coh_l0oe[o0?oonf[o0?nn0_oonfX01Ooo0?Ko00?o
oookJ_oonf[o0?m800Cooo]Z00Go0?mgoookJ_mi0?oooo]ZoiOo0005oookJP07o`2Roooo_`3ooo]Z
o`3oX_l0S?oooo]Zo`3o8@03oookJP03ool0l_oonf[o0?mF00?ooo]Z00Coo`2PoookJ_oonf[oE03o
0ooonfX00olZ0?ooo`X0oookJP03oookJP05og_o0?oonf[ooo]ZoonL0?oo@@000_oonfX00ol0ocSo
203ooookJP08oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX03?oonfX00ol0okGo
oo]ZoookJP04oookJP03o`3oRooonf[ooo]Z013ooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP06oook
JP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX01OoBo`3ooo]ZoookJ_oonf[ogOl000;ooo]Z00?o
:`3ooookJ_oonfX00ooonfX01?ooV`3oo`00oookJ_o/o`05oookJP03oi<0oooonf[ooo]Z02Cooo]Z
000UoookJP03ooo90?oonf[ooo]Z00gooo]Z00Go0?m=oookJ_oonf[ooo]Zool0ZP04oookJP03oeT0
oooonf[ooo]Z00Sooo]Z00?o:@3ooookJ_oUo`002?oUo`03oookJP?oiOl000CoonP0onGo0?oUo`3o
iOl00ooonfX01?oo=@3ooo]Zo`21oolgo`02oookJP06o`3oUooonf[ooo]Zo`3oj?oonf[o=_l04_oo
nfX00ol0hooooo]ZoookJP02oookJP;oo`3/4_oonfX2o`3okBcooo]Z0_oob@0DoookJP?o0?o]2ooo
nfX2ool0k003oookJ_l0hooooo]Z00Sooo]Z1OnDo`001Ooo=@3o0000o`000?nDo`3oonP000KoU?l0
1OoonfX00omI0?ooo`2Zo`3oC@05oookJP03ool=0?oonf[oon<000GoU?l02_oonfX7onGo0003oiCo
0?oonf[oU?l000;ooo]Z00Co0?m8oookJ_oonf[o0?mg0_oonfX01?mi0?ooUol0oookJ_oonfX5onGo
0003oono0?oUo`3o0?nR00;ooo]Z00?o0?lQoookJ_oonfX00_oonfX00ooo0?;o0?mFoookJP03oook
JP04ool0X?oonf[oE03oo`0Uo`;ooo]Z00?o:P3oo`1<oooonfX00_oonfX01Omko`3ooo]ZoookJ_oo
nf[ood4000?ooo]Z00?o0?lhoookJ_l80?l02?oonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooo
nf[ooo]Z00cooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0AoookJP05ool0Cooo
nf[ooo]ZoookJ_l0oiH01_oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000gooo]Z00Cod_l0oookJ_oo
nf[ogOl00_oonfX00ol[0?oooo]ZoookJP02oookJP04oonK0?oo003oo`2Yonco00Gooo]Z00?oT`3o
oookJ_oonfX0EooonfX01?l0odgooo]ZoookJ_oo0:X4oookJP03oeT0oooonf[ooo]Z00Sooo]Z00?o
:@3ooookJ_oonfX01?oonfX00ol0oo3ooo]ZoookJP07oookJP03oooX0?oonf[oo`0;00Cooo]Z0_oo
=@000ooonf[o087ooookJP02oookJP03o`3oUooonf[o0?oX00;ooo]Z00?o=_l0oookJ_oonfX03ooo
nfX00ol0hooooo]ZoookJP02oookJP;oo`3/4_oonfX2o`3okD;ooo]Z0ol0ond<oookJP04ool0k?oo
nf[o0>?oo`3So`Sooo]Z00Go=_l0o`3oj?l0onSooo]Zo`21o`02oole0003o`000?oo00_oonP000?o
oo]Z00Co0?o`oookJ_oonf[o:@3o1?oonfX01?mI0?ooo`2ZoookJ_l0odd5oookJP03ool=0?ooh`3o
K03o00;ooo]Z00?oH_l0oookJ_oonfX02_oonfX01?oRo`3ooo]Zoe[o0?l0okh3oookJP05ool0m_l0
0ooooo]ZoookJ_l0odP00ooonfX01Ol0ogOooo]ZogT0oooo9`3oUol000Kooo]Z00Kookl0oookJ_oo
nf[o0?nRoookJ_l0ob44oookJP03ool0l_l0oeKooo]Z00?ooo]Z00Coo`2PoookJ_mD0?oo02Go0_oo
nfX00olZ0?ooo`X0oookJP03oookJP05og_o0?oonf[ooo]ZoonL0?oo@@000ooonfX00ol0ocSo203o
oookJP07oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX03?oonfX00ol0okGooo]Z
oookJP04oookJP03o`3oRooonf[ooo]Z013ooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP06oookJP05
oolL0?oonf[ooo]ZoookJ_nho`003OoonfX01?oBo`3ooo]ZoookJ_oMo`02oookJP03ob/0oooonf[o
oo]Z00?ooo]Z00Cooi/0ool00?oonf[ok?l01OoonfX00onC0?oooo]ZoookJP0ToookJP00=?oonfX0
1Ol0odgooo]ZoookJ_oonf[oo`2Z00Cooo]Z00?oF@3ooookJ_oonfX02?oonfX00olY0?oooo]ZonGo
0009onGo0003oookJ_oUo`3oiOl000;oiOl000?oonP0onGo0?oUo`000_oUo`02oookJP04oole0?oo
nf[o087oocOo00;ooo]Z00Ko0?nGoookJ_oonf[o0?oXoookJ_lfo`0AoookJP;o0>?o0ooonfX2ool0
k1;ooo]Z0_l0ondHoookJPWooaX03OlM0?l5ooo901Cooo]Z0ol0ond:oookJP;oo`3/0_l0hol7oook
JPKoU?l00_oo=@000ooonf[oU?l0oiCo0006oiCo00Gooo]Z00?oF@3oool0Z_l0odd01OoonfX00ooo
3@3oU?l0oiCo0004oiCo00Wooo]Z2OoUo`001_oonf[oU?l0oookJ_oonf[o0?m8oiCo00;ooo]Z00Go
0?mgoookJ_oonf[oN@3ooiOo0002oookJPGoiOl000Gookl0onGo0?l0oj;ooo]Zo`3o8@04oookJP03
ool0l_l0oeKooo]Z00?ooo]Z00Coo`2PoookJ_mD0?oo02Go0_oonfX00olZ0?ooo`X0o`1<o`03oook
JP05og_o0?oonf[ooo]ZoookJ_oo@@000_oonfX00ol0ocSooo]Zo`P0o`08oookJP03oolP0?oonf[o
oo]Z00;ooo]Z00?oo`2eoookJ_oonfX03?oonfX00ol0okGooo]ZoookJP04oookJP03o`3oRooonf[o
oo]Z013ooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP06oookJP05oolL0?oonf[ooo]ZoookJ_nho`00
3OoonfX01ooBo`3ooo]ZoookJ_oonf[ogOl0oookJ_l[0?l01OoonfX00ooo003ooo]Zonco0005oook
JP03oi<0oooonf[ooo]Z05Kooo]Z00Go0?m=oookJ_oonf[ooo]Zool0ZP03oookJP03oeT0oooonf[o
oo]Z00Sooo]Z00?o:@3ooookJ_oonfX01OoonfX00ol0oo3ooo]ZoookJP06oookJP03oooX0?oonf[o
o`0;00Cooo]Z00CoocD0oookJ_oonf[o087o0ooonfX00ol0oiOooo]Zo`3oj002oookJP03ocKo0?oo
nf[ooo]Z00kooo]Z0_l0hol3oookJP;oo`3/4_oonfX2o`3okAWooo]Z2Ooo6P0=oad0o`?ooaX05Ooo
nfX3o`3ok@[ooo]Z0_oo0>`00ooonf[o0>?oo`3So`07oookJP;o=_l000Go0?oXo`000?l0003o087o
oole0002oookJP05oooX0?oonf[ooo]ZoookJ_l0oo000_oonfX00olY0?oooo]ZoookJP02oookJP04
oeT0oooo0:[ooo]Zo`3oC@Gooo]Z00?oo`d0oooS0?m/0?l00_oonfX00omRo`3ooo]ZoookJP0:oook
JP04on;o0?oonf[oF_l0o`3o_P;ooo]Z00?oo`3fo`03oooonfX00_oonfX02Ol0odSooo]ZoookJ_oo
nf[o0?mgoookJ_mi0?ooobL0oiOo0005oookJP07o`2Roooo_`3ooo]Zo`3oX_l0S?oooo]Zo`3o8@03
oookJP03ool0l_oonf[o0?mF00?ooo]Z00Coo`2PoookJ_oonf[oE03o0ooonfX00olZ0?ooo`X0oook
JP03oookJP05og_o0?oonf[ooo]ZoonL0?oo@@000_oonfX00ol0ocSo203ooookJP07oookJP03oolP
0?oonf[ooo]Z00?ooo]Z00?oo`2eoookJ_oonfX03?oonfX00ol0okGooo]ZoookJP03oookJP03o`3o
Rooonf[ooo]Z017ooo]Z00Coo`1?oookJ_oonf[o0?nF1_oonfX01Ooo703ooo]ZoookJ_oonf[o^?l0
00gooo]Z00Ood_l0oookJ_oonf[ooo]Zomgo0?oonf[o:`3o00Kooo]Z00?oo`00ool0ZOo/o`001Ooo
nfX00onC0?oooo]ZoookJP0ToookJP00=?oonfX01?l0odgooo]ZoookJ_oo0:X4oookJP03oeT0oooo
nf[ooo]Z00Sooo]Z00?o:@3ooookJ_oonfX00_oonfX7onGo0003oookJ_oUo`3oiOl000;oiOl000?o
onP0onGo0?oUo`000_oUo`02oookJP04oole0?oonf[o087oocOo00;ooo]Z00Ko0?nGoookJ_oonf[o
0?oXoookJ_lfo`0AoookJP03o`3Soooonf[ooo]Z00;ooo]Z00?oo`3/oookJ_oonfX03ooonfX3o`3o
kAOooo]Z0ooo6P02oookJP03o`3ol_lM0?oo7@3o00Co7@3o3?oonfX00ol0oo;oolT0ooo90005ooo9
00Co7@3o0_oo6P0?oookJP?o0?o]2OoonfX2ool0k0;o0>?o1?oonfX8oiCo0003o`21oonDo`3oU?l0
00SoU?l01OoonfX00omI0?ooU?l0o`3oC@04oookJPSoU?l02_oonfX7onGo0003oiCo0?oonf[oU?l0
00;oU?l000So0?m8oiCo0?oonf[ooo]Zo`3oMooonf[oN@3ooiOo00?ooo]Z1?oUo`001_oo_`3oiOl0
onGo0?l0oj;ooo]Zo`3o8@Cooo]Z00?oo`3bo`3oE_oonfX00_oonfX01Ooo0:3ooo]ZoookJ_mD0?oo
02Go00;ooo]Z00?o:P3oo`1<oooonfX00_oonfX01Omko`3ooo]ZoookJ_oonf[ood4000;ooo]Z00?o
0?lhoookJ_l80?l02OoonfX01Ooo803ooo]ZoookJ_oonf[oo`2e00kooo]Z00?o0?neoookJ_oonfX0
1?oonfX00ol0oh_ooo]ZoookJP0@oookJP05ool0Cooonf[ooo]ZoookJ_l0oiH01_oonfX01Ooo703o
oo]ZoookJ_oonf[o^?l000gooo]Z00Ood_l0oookJ_oonf[ooo]Zomgo0?oonf[o:`3o00Gooo]Z00?o
oi/0ool00?o/o`001OoonfX00onC0?oooo]ZoookJP1FoookJP04o`3oCOoonf[ooo]Zool0ZP?ooo]Z
00?oF@3ooookJ_oonfX02?oonfX00olY0?oooo]ZoookJP05oookJP03o`3ol?oonf[ooo]Z00Kooo]Z
00?oonP0oookJ_oo00/01?oonfX01?oo=@3ooo]ZoookJ_l0POl3oookJP03o`3oUooonf[o0?oX00;o
oo]Z00?o=_l0oookJ_oonfX03_oonfX00ol0hooooo]ZoookJP02oookJP03ool0k?oonf[ooo]Z00oo
oo]Z0ol0ondHoookJP?ooaX000?ooo]Zo`3ol_l0oo801_lM0?l;oookJP;o0?ob2_lM0?l2oolJ00oo
oo]Z0ol0ond9oookJP;oo`3/00?ooo]Zo`3SoooonfX01ooonfX01_lfo`3o0?oXo`3oUol0003o087o
oole00;ooo]Z0_ooj002oookJP;o0?o`00?ooo]ZobT0oooonfX00ooonfX01?mI0?ooo`2ZoookJ_l0
odd4oookJP04ool=0?oonf[oon<0of`0o`;ooo]Z00?oH_l0oookJ_oonfX02_oonfX01?oRo`3ooo]Z
oe[o0?l0okh2oookJP05ool0m_l00ooooo]ZoookJ_l0odP01?oonfX01?l0ogOoN@3ooookJ_nGo`06
oookJP06oono0?oonf[ooo]Zo`3oX_oonf[o0?lQ1?oonfX00ooo0?;o0?mFoookJP02oookJP05ool0
X?oonf[ooo]Zoe@0ool09Ol00_oonfX00olZ0?ooo`X0oookJP03oookJP05og_o0?oonf[ooo]ZoonL
0?oo@@000_oonfX00ol0ocSo203ooookJP08oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoook
J_oonfX03?oonfX00ol0okGooo]ZoookJP04oookJP03o`3oRooonf[ooo]Z013ooo]Z00Coo`1?oook
J_oonf[o0?nF1_oonfX00ooo703ooo]ZoookJP02oookJP03okSo0?oonf[ooo]Z00[ooo]Z00Ood_l0
oookJ_oonf[ooo]Zomgo0?oonf[o:`3o00Kooo]Z00?ooi/0ool00?o/o`001OoonfX00onC0?oooo]Z
oookJP0ToookJP00<ooonfX01?l0odgooo]ZoookJ_oo0:X4oookJP03oeT0oooonf[ooo]Z00Sooo]Z
00?o:@3ooookJ_oonfX01?oonfX:onGo0003oooX0?oUo`3oiOl000?oiOl000Gooo]Zoole0?oonf[o
087oocOo0002oookJP06o`3oUooonf[ooo]Zo`3oj?oonf[o=_l04OoonfX01?l0hooooo]ZoookJ_oo
nfX2ool0k13ooo]Z0_l0ondFoookJPCooaX01_lM0?lCoookJP[oolT000?o0?oboad0oolM0?l00_lM
0?l3oolJ00[ooo]Z0_oob@001?oonf[o0?o]o`3okOl0ond8oookJP;oo`3/00?o0>?ooookJ_oonfX0
2_nDo`000ol0POooocD0oiCo0008oiCo00Gooo]Z00?oU?l0oookJ_l0odd00_oonfX9oiCo0003of;o
0?oonf[ooo]Z00Sooo]Z1ooUo`04oiCo0005o`3oB?nDo`3ooo]ZoookJ_l0ogL00_oonfX00omi0?oo
Uol0oookJP02oookJPCoiOl000?ookl0onGo0?l0oj800_oonfX01_l0ob7ooo]ZoookJ_oonf[oo`3b
o`3oEPCooo]Z00Coo`2PoookJ_mD0?oo02Go0_oonfX00olZ0?ooo`X0o`1<o`03oookJP05og_o0?oo
nf[ooo]ZoonL0?oo@@000_oonfX00ol0ocSooo]Zo`P0o`08oookJP03oolP0?oonf[ooo]Z00;ooo]Z
00?oo`2eoookJ_oonfX03?oonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z017ooo]Z
00Goo`1?oookJ_oonf[ooo]Zo`3oUP06oookJP04oolL0?oonf[ooo]ZokSo00gooo]Z00God_l0oook
J_oonf[ooo]Zomgo0002oookJP03ob/0oooonf[ooo]Z00;ooo]Z00Cooi/0ool00?oo0:Wok?l01?oo
nfX00onC0?oooo]ZoookJP1EoookJP04o`3oCOoonf[ooo]Zool0ZP?ooo]Z00?oF@3ooookJ_oonfX0
2?oonfX00olY0?oooo]ZoookJP05oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0oookJ_oo00/0
1?oonfX01?oo=@3ooo]ZoookJ_l0POl3oookJP03o`3oUooonf[o0?oX00;ooo]Z00?o=_l0oookJ_oo
nfX03_oonfX01?l0hooooo]ZoookJ_oonfX2ool0k13ooo]Z0_l0ondGoookJPCooaX01_lM0?lLoook
JP03o`3ol_lM0?oo7@3o00;o7@3o0ooo6P0=oookJP?o0?o]2?oonfX2ool0k0;o0>?o1ooonfX01Olf
o`3o0?oXo`3oj?l0003o087o00;oocD000?ooo]Zool02oooj0000ooonfX00ol0oo3ooo]ZobT0o`04
oookJP04ool0Z_oonf[ooo]Zo`3oC@Cooo]Z00Coo`d0oookJ_ooh`3oK03o0_oonfX00omRo`3ooo]Z
oookJP09oookJP04on;o0?oonf[oF_l0o`3o_P;ooo]Z00?oo`3fo`03oooonfX00_oonfX02Ol0odSo
oo]ZoookJ_oonf[o0?mgoookJ_mi0?ooobL0oiOo0005oookJP07o`2Roooo_`3ooo]Zo`3oX_l0S?oo
oo]Zo`3o8@03oookJP03ool0l_oonf[o0?mF00?ooo]Z00Coo`2PoookJ_oonf[oE03o0ooonfX00olZ
0?ooo`X0oookJP03oookJP05og_o0?oonf[ooi`0oookJ_oo@@000_oonfX00ol0ocSo203ooookJP07
oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?oo`2eoookJ_oonfX02ooonfX00ol0okGooo]ZoookJP04
oookJP03o`3oRooonf[ooo]Z013ooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP06oookJP05oolL0?oo
nf[ooo]ZoookJ_nho`003?oonfX01OoBo`3ooo]ZoookJ_oonf[ogOl000;ooo]Z00?o:`3ooookJ_oo
nfX00ooonfX01?ooV`3oo`00oookJ_o/o`04oookJP03oi<0oooonf[ooo]Z02Cooo]Z000boookJP04
o`3oCOoonf[ooo]Zool0ZPCooo]Z00?oF@3ooookJ_oonfX02OoonfX00olY0?oooo]ZoookJP03oook
JP03onGo0?oonf[oiOl000?oiOl00ooonfX00ooUo`3oonP0onGo0004onGo0005oookJ_oo=@3ooo]Z
o`21oolgo`000_oonfX01_l0oiOooo]Zo`3oj?l0onSooo]ZocKo013ooo]Z0_l0hol2oookJP;oo`3/
4?oonfX2o`3okACooo]Z1?oo6P03oad0o`WoU?l01ooonfX8ool0]0koolT000?ooo]Zo`3ol_l0oo80
1OlM0?l00ooo6P3ooo]ZoookJP05oookJP?oolT00ooonfX2o`3ok@Sooo]Z0_oo0>`00ol0hooooo]Z
oookJP08oiCo0004o`3oUol0POooocD0oole00OoU?l000?o:@3ooookJ_oonfX00ooonfX00onDo`3o
oo]Zo`3oC@02oookJPWoU?l000?oH_l0oookJ_oonfX02?oonfX6onGo00GoU?l000Go0?m8oiCo0?oo
nf[ooo]Zo`3oM`02oookJP03ogT0oooonf[ooo]Z00;ooo]Z0ooUo`001_oo_`3oiOl0o`2<ool0oj;o
oo]Zo`3o8@Cooo]Z00?oo`3bo`3oE_oonfX00_oonfX01Ooo0:3ooo]ZoookJ_mD0?ooU?l000;ooo]Z
00?o:P3oo`1<oooonfX00_oonfX01Omko`3ooo]ZoookJ_oonf[ood4000;ooo]Z00?o0?lhoookJ_l8
0?l02?oonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z00cooo]Z00?o0?neoookJ_oo
nfX01?oonfX00ol0oh_ooo]ZoookJP0@oookJP05ool0Cooonf[ooo]ZoookJ_l0oiH01_oonfX01Ooo
703ooo]ZoookJ_oonf[o^?l000gooo]Z00Cod_l0oookJ_oonf[ogOl00_oonfX00ol[0?oooo]Zoook
JP03oookJP03ool00?oo0:Wok?l000Cooo]Z00?oT`3ooookJ_oonfX0E?oonfX01?l0odgooo]Zoook
J_oo0:X3oookJP03oeT0oooonf[ooo]Z00Wooo]Z00?o:@3ooookJ_oonfX01?oonfX00ol0oo3ooo]Z
oookJP06oookJP03oooX0?oonf[oo`0;00Cooo]Z00CoocD0oookJ_oonf[o087o0ooonfX01?l0oiOo
oo]Zo`3oj?oonfX2ocKo00oooo]Z0_l0hol2oookJP;oo`3/4?oonfX2o`3okAGooo]Z1?oo6P04oad0
o`kooo]Z3Ooo0;@;oookJP03o`3ol_lM0?oo7@3o00?o7@3o00?ooaX0oookJ_oonfX02ooonfX2o`3o
k@Sooo]Z0_oo0>`00ol0hooooo]ZoookJP04oookJP0;o`000?lfo`3o=_l0o`3oj?l0oiOooo]Zo`21
oooo=@3ooo]Zool02oooj0000ooonfX00ol0oo3ooo]ZobT0o`04oookJP04ool0Z_oonf[ooo]Zo`3o
C@Cooo]Z00Coo`d0oooS0?oonf[oK03o0_oonfX00omRo`3ooo]ZoookJP09oookJP04on;o0?oonf[o
F_l0o`3o_P;ooo]Z00?oo`3fo`03oooonfX00_oonfX02?l0odSooo]ZoookJ_oonf[o0?mgoookJ_mi
0?ooUol01_oonfX01?oo_`3ooo]ZoookJ_l0oj82oookJP06o`3o8Ooonf[ooo]ZoookJ_oo0?;o0?mF
0ooonfX01Ooo0:3ooo]ZoookJ_oonf[oE03o00;ooo]Z00?o:P3oool:0?oonfX00ooonfX01Omko`3o
oo]ZoookJ_ooW03ood4000;ooo]Z00?o0?lho`P0oooonfX01ooonfX00ooo803ooo]ZoookJP03oook
JP03ool0]Ooonf[ooo]Z00cooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0Aoook
JP04ool0Cooonf[ooo]Zo`3oUPKooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000=oookJP04om;o0?oo
nf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX01?oonfX00ooo003ooo]Zonco0004oookJP03oi<0
oooonf[ooo]Z02Cooo]Z000boookJP03o`3oCOoonf[oo`2Z00Cooo]Z00?oF@3ooookJ_oonfX02Ooo
nfX00olY0?oooo]ZoookJP04oookJP03onGo0?oonf[ooo]Z00?oiOl00ooonfX00oooj03oiOl0onGo
0004onGo0004oole0?oonf[o087oocOo00;ooo]Z00?o0?nGoookJ_l0onP00_oonfX00olfo`3ooo]Z
oookJP0>oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`04?oonfX2o`3okA?ooo]Z0ooo6P001?oonf[o
7@3ooad0oolM0?l3oookJQ3oU?l04oooY`06ooo900?ooo]Z0_l0oo84oad0o`?ooo]Z1Ooob@04oook
JP;o0?o]2?oonfX00ooo0>co0>?oo`3So`03oookJPKoU?l000Co0?nGoiCo0?l0POooocD01onDo`00
0olY0?oooo]ZoookJP02oookJP04oeT0oonDo`3ooo]Zo`3oC@_oU?l02ooonfX5onGo00KoU?l000So
0?m8oookJ_oonf[ooo]Zo`3oMooonf[oN@3ooiOo00Cooo]Z0ooUo`000ooo_`3oiOl0o`3oXP02oook
JP06o`3o8Ooonf[ooo]ZoookJ_oo0?;o0?mF1?oonfX01?oo0:3ooo]Zoe@0oonDo`02oookJP03obX0
oooo2P3ooo]Z00?ooo]Z00GoNol0oookJ_oonf[ooi`0oom10002oookJP03o`3o>?l80?oooo]Z00So
oo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP0;oookJP03o`3o]Ooonf[ooo]Z00Co
oo]Z00?o0?n;oookJ_oonfX04?oonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Kooo]Z00Gooa`0oook
J_oonf[ooo]ZokSo000=oookJP04om;o0?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX00ooo
nfX00oooV`3oo`00onco0005oookJP03oi<0oooonf[ooo]Z05;ooo]Z00Co0?m=oookJ_oonf[oo`2Z
0ooonfX00omI0?oooo]ZoookJP09oookJP03obT0oooonf[ooo]Z00Cooo]Z00?o0?o`oookJ_oonfX0
1_oonfX00oooj03ooo]Zool02`04oookJP04oole0?oonf[ooo]Zo`21o`?ooo]Z00Go0?nGoookJ_l0
onSooo]ZocKo000@oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`04?oonfX2o`3okACooo]Z0ooo6P00
1?l0oo;o7@3ooad0oolM0?l8oookJPSoo`2d5_ooY`02ool0]0Kooo]Z0_l0oo84oad0o`cooo]Z0_l0
ond8oookJP03ool0k?l0hooo0>?o00Cooo]Z0ol000002Olfo`3o0?oXo`3oUooonf[o087ooole0?oo
nf[oo`0;oooX0003oookJP03o`3ol?oonf[o:@3o00?ooo]Z00GoF@3oool0Z_oonf[ooo]Zo`3oC@04
oookJP06ool=0?ooh`3ooo]Zof`0oooonf[oH_l03?oonfX01?oRo`3ooo]Zoe[o0?l0okh2oookJP05
ool0m_l00ooooo]ZoookJ_l0odP01?oonfX01?l0ogOoN@3ooolW0?nGo`06oookJP06oono0?oonf[o
oo]Zo`3oX_oonf[o0?lQ0ooonfX00ooo0?;ooo]Zo`3oEP03oookJP04ool0X?oonf[ooo]Zoe@0o`?o
oo]Z00?o:P3oool:0?oonfX00ooonfX01Omko`3ooo]ZoonL0?oonf[ood4000;ooo]Z00?o0?lhoook
J_oonfX01ooonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z00cooo]Z00?o0?neoook
J_oonfX01?oonfX00ol0oh_ooo]ZoookJP0@oookJP04ool0Cooonf[ooo]Zo`3oUPKooo]Z00Gooa`0
oookJ_oonf[ooo]ZokSo000=oookJP04om;o0?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX0
1?oonfX00oooV`3oo`00onco0005oookJP03oi<0oooonf[ooo]Z02?ooo]Z000aoookJP03o`3oCOoo
nf[oo`2Z00Cooo]Z00?oF@3ooookJ_oonfX02OoonfX00olY0?oooo]ZoookJP04oookJP03onGo0?oo
nf[ooo]Z00;ooo]Z00KoiOl0oookJ_oonf[ooo]ZoooX0?oonfX5onGo0004oole0?oonf[o087oocOo
00;ooo]Z00?o0?nGoookJ_l0onP00_oonfX00olfo`3ooo]ZoookJP0>oookJP05o`3Soooonf[ooo]Z
oookJ_oo0>`03ooonfX2o`3okA;ooo]Z0ooo6P001?oonf[o0?oboad0oolM0?l6oookJPkoU?l01_oo
nfX3odCo00;ooo]Z2_oob@04oonW00?oolT00_oo0;@4oookJP;o0?ob00?o7@3oooo90?oob@001_oo
b@05oookJP03o`3okOoonf[ooo]Z00Kooo]Z0_oo0>`01Ol0hooooo]ZoookJ_oonf[o000000GoU?l0
00Co0?nGoiCo0?l0POooocD01onDo`000olY0?oooo]ZoookJP02oookJP04oeT0oonDo`3oU?l0o`3o
C@?oU?l000?ooo]ZoiCo0?nDo`001?nDo`000omRo`3ooo]ZoookJP09oookJPGoiOl01OnDo`001Ol0
odSooo]ZoookJ_oonf[o0?mg00;ooo]Z00?oN@3ooiOo0?oonfX00ooonfX2onGo0006oono0?oUo`3o
08coo`3oX_oonf[o0?lQ1?oonfX00ooo0?;o0?mFoookJP02oookJP03ool0X?oonf[ooo]Z00;oU?l0
0_oonfX00olZ0?oo04cooookJP02oookJP05og_o0?oonf[ooo]ZoonL0?oo@@000_oonfX00ol0ocSo
oo]Zo`P0o`08oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX03?oonfX00ol0okGo
oo]ZoookJP03oookJP03o`3oRooonf[ooo]Z013ooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP06oook
JP05oolL0?oonf[ooo]ZoookJ_nho`003OoonfX01?oBo`3ooo]ZoookJ_oMo`02oookJP03ob/0oooo
nf[ooo]Z00?ooo]Z00Cooi/0ool00?oonf[ok?l01?oonfX00onC0?oooo]ZoookJP1BoookJP03o`3o
COoonf[oo`2Z00?ooo]Z00?oF@3ooookJ_oonfX02OoonfX00olY0?oooo]ZoookJP04oookJP03o`3o
l?oonf[ooo]Z00Kooo]Z00CoonP0oookJ_oonf[oo`0;0ooonfX01?oo=@3ooo]ZoookJ_l0POl3oook
JP05o`3oUooonf[o0?oXoookJ_lfo`004?oonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00oooo]Z0_l0
ondCoookJP?ooaX000Cooo]Zo`3ol_lM0?oo7@3o2?oonfX3ool0]0?ooo]Z1OooY`0FoookJPCoojL0
1?oo0;@4oookJP;o0?ob0olM0?l;oookJP03o`3okOoonf[ooo]Z00Kooo]Z0_oo0>`2o`3So`;ooo]Z
1?l000001Olfo`3o0?oXo`3oj?oonf[o087o00;oocD000?oo`0;oooX0?oonfX00_oonfX00ol0oo3o
oo]ZobT0o`03oookJP05oeT0oooo0:[ooo]ZoookJ_l0odd01?oonfX01_oo3@3oon<0oookJ_m/0?oo
oo]Zof;o00_ooo]Z00Coh_l0oookJ_mJo`3o0?nn0_oonfX00ooo0?Ko00?ooookJP02oookJP08o`3o
B?oonf[ooo]ZoookJ_l0ogOooo]ZogT0oonGo`06oookJP04oono0?oonf[ooo]Zo`3oXP;ooo]Z00Oo
0?lQoookJ_oonf[ooo]Zool0l_oonf[o0?mF00;ooo]Z00Goo`2PoookJ_oonf[ooo]Zoe@0o`02oook
JP03obX0oooo2P3ooo]Z00?ooo]Z00GoNol0oookJ_ooW03ooo]Zoom10002oookJP03o`3o>?l80?oo
oo]Z00Oooo]Z00?oob00oookJ_oonfX00ooonfX00ooo0;Gooo]ZoookJP0;oookJP03o`3o]Ooonf[o
oo]Z00Cooo]Z00?o0?n;oookJ_oonfX04?oonfX01?oo04oooo]ZoookJ_l0oiH6oookJP03oolL0?oo
nf[ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX02_oonfX01?oBo`3ooo]ZoookJ_oMo`02oookJP03ob/0
oooonf[ooo]Z00Cooo]Z00Cooi/0ool00?oonf[ok?l01?oonfX00onC0?oooo]ZoookJP0SoookJP00
<?oonfX00ol0odgooo]Zool0ZP04oookJP03oeT0oooonf[ooo]Z00[ooo]Z00?o:@3ooookJ_oonfX0
0ooonfX00ooUo`3ooo]ZoookJP06oookJP03oooX0?oonf[oiOl000;ooo]Z0_oUo`001Ooo=@3ooo]Z
o`21oooonf[o=ol000;ooo]Z00Go0?nGo`3oj?oonf[ooo]ZocKo000@oookJP05o`3Soooonf[ooo]Z
oookJ_oo0>`03_oonfX2o`3okA;ooo]Z0_oo6P02oookJP?o7@3o2?oonfX<oiCo00Sooo]Z1Om4o`0<
ooo900;ooo]Z1?ooY`001?oonf[oo`2dool0]?oo0;@4oookJP03o`3ol_oob@3oolT000KoolT01Ooo
nfX2o`3ok@Sooo]Z00Coo`3/o`3Sool0hooooo]Z0ol00004oiCo0004o`3oUonDo`3o=ol0oole00;o
U?l000KoonP0oiCo0?nDo`3oU?l0oookJ_lY0?l4oookJP?oU?l000?o0?m=oiCo0?nDo`000_oonfX0
0ooo3@3oU?l0oiCo0003oiCo0003of;o0?oonf[ooo]Z00Wooo]Z00Coh_l0onGo0?oUo`3oiOl01_nD
o`002?l0odSooo]ZoookJ_oonf[o0?mgoookJ_mi0?ooUol01OoonfX2onGo0006oono0?oonf[o08co
o`3oX_oonf[o0?lQ0ooonfX00ooo0?;o0?mFoookJP03oookJP04ool0X?oonf[oU?l0oiCo00;ooo]Z
00?o:P3oo`1<oooonfX00ooonfX01?mko`3ooo]ZoookJ_oo@@02oookJP03o`3o>?oonf[o203o00So
oo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP0<oookJP03o`3o]Ooonf[ooo]Z00Co
oo]Z00?o0?n;oookJ_oonfX04?oonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Kooo]Z00Gooa`0oook
J_oonf[ooo]ZokSo000<oookJP04om;o0?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX00ooo
nfX01?ooV`3oo`00ool0ZOo/o`04oookJP03oi<0oooonf[ooo]Z057ooo]Z00?o0?m=oookJ_oo0:X0
0ooonfX00omI0?oooo]ZoookJP0:oookJP03obT0oooonf[ooo]Z00?ooo]Z00?o0?o`oookJ_oonfX0
1_oonfX01?ooj03ooo]ZoookJ_oo00/3oookJP05oole0?oonf[ooo]Zo`21oolgo`000_oonfX01Ol0
oiOooo]Zo`3oj?oonf[o=_l0013ooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00>oookJP;o0?o]4ooo
nfX2oolJ00;ooo]Z0olM0?l7oookJP?oo`2d0_oonfX4oonW01oooo]Z1?ooY`03ool0]0Cooo]Z00Co
0?oboolJ0?lM0?oo7@3o2_oonfX2o`3ok@Sooo]Z00Coo`3/oookJ_l0hooooo]Z1Ol00002ocKo0007
o`3oj?oonf[o=ol0o`21oooo=@3ooo]ZoooX0003oookJP03o`3ol?oonf[o:@3o00?ooo]Z00GoF@3o
ool0Z_oonf[ooo]Zo`3oC@04oookJP06ool=0?ooh`3ooo]Zof`0oooonf[oH_l02ooonfX01?oRo`3o
oo]Zoe[o0?l0okh2oookJP05ool0m_l00ooooo]ZoookJ_l0odP01?oonfX01?l0ogOoN@3ooolW0?nG
o`06oookJP06oono0?oonf[ooo]Zo`3oX_oonf[o0?lQ0ooonfX00ooo0?;ooo]Zo`3oEP03oookJP04
ool0X?oonf[ooo]Zoe@0o`?ooo]Z00?o:P3ooookJ_oonfX00ooonfX01?mko`3ooo]ZoonL0?oo@@02
oookJP03o`3o>?l80?oooo]Z00Oooo]Z00?oob00oookJ_oonfX00ooonfX00ooo0;Gooo]ZoookJP0<
oookJP03o`3o]Ooonf[ooo]Z00?ooo]Z00?o0?n;oookJ_oonfX04OoonfX01?oo04oooo]ZoookJ_l0
oiH6oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX01ooBo`3ooo]ZoookJ_oonf[ogOl0oook
J_l[0?l01_oonfX01?ooV`3oo`00oookJ_o/o`04oookJP03oi<0oooonf[ooo]Z02?ooo]Z000`oook
JP03o`3oCOoo0:[ooo]Z00?ooo]Z00?oiOl0oookJ_oonfX02_oonfX00olY0?oooo]ZoookJP03oook
JP03onGo0?oonf[ooo]Z00Kooo]Z00?oonP0oookJ_oUo`001?oonfX01Ooo=@3ooo]Zo`21oooonf[o
=ol000;ooo]Z00Go0?nGo`3oj?oonf[ooo]ZocKo000?oookJP;o0>?o0ooonfX00ooo0>cooo]Zoook
JP0<oookJP03o`3okOoonf[ooo]Z017ooo]Z00?ooaX0oookJ_oonfX00_lM0?l8oookJP?oo`2d2_nD
o`0:oookJPGoA?l01?oob@000om4o`3ooo]ZoookJP0;oookJPCoojL00ooo0;@2oookJP[oolT01Ooo
nfX2o`3ok@Oooo]Z00Coo`3/oookJ_l0hooo0>?o0ol00002oookJP;oU?l000Co0?nGoiCo0?nDo`3o
ocD00_nDo`001_ooj03oU?l0oiCo0?nDo`3ooo]ZobT0o`;ooo]Z1OnDo`000ol0odgoU?l0oiCo0002
oookJP03ool=0?nDo`3oU?l000;oU?l000?ooo]Zof;o0?oonfX02OoonfX00ooRo`3ooo]ZonGo0002
onGo00GoU?l000?o0?m8oookJ_oonfX00_oonfX01?nDo`3ooo]ZogT0oonGo`05oookJP07onGo0?oo
_`3ooo]ZoookJ_l0oj;ooo]Zo`3o8@04oookJP03ool0l_l0oeKooo]Z00;ooo]Z00Coo`2PoookJ_oo
nf[oU?l00ooonfX00olZ0?oooo]ZoookJP02oookJP05og_o0?oonf[ooo]ZoonL0?oo@@000_oonfX0
0ol0ocSo203ooookJP08oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oU?l0oookJ_oonfX02ooonfX0
0ol0okGooo]ZoookJP04oookJP03o`3oRooonf[ooo]Z013ooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3o
UP06oookJP05oolL0?oonf[ooo]ZoookJ_nho`003OoonfX01_oBo`3ooo]ZoookJ_oMo`3ooo]Zob/0
o`Gooo]Z00Cooi/0ool00?oo0:Wok?l01?oonfX00onC0?oooo]ZoookJP1@oookJP03o`3oCOoonf[o
o`2Z00?ooo]Z00?oF@3ooookJ_oonfX02_oonfX00olY0?oooo]ZoookJP04oookJP03o`3ol?oonf[o
oo]Z00Gooo]Z00CoonP0oookJ_oonf[oo`0;0ooonfX01Ooo=@3ooo]ZoookJ_l0POoo=ol000;ooo]Z
00Go0?nGoookJ_l0onSooo]ZocKo000?oookJP;o0>?o0ooonfX00ooo0>cooo]ZoookJP0<oookJP03
o`3okOoonf[ooo]Z01;ooo]Z00?ooaX0oookJ_lM0?l00_lM0?l7oookJP?oo`2d1OooY`0WoookJPCo
ojL00_oo0;@4oookJP04o`3ol_lM0?oo7@3ooolJ00Wooo]Z0_l0ond7oookJP;oo`3/0_l0hol3o`00
00?ooo]Z00Oo=_l0o`3oj?l0oiOooo]Zo`21oooo=@3ooo]Z00;oonP00_oonfX00ol0oo3ooo]ZobT0
o`03oookJP05oeT0oooo0:[ooo]ZoookJ_l0odd01?oonfX01_ooh`3ooo]ZoookJ_m/0?oooo]Zof;o
00_ooo]Z00Coh_l0oookJ_mJo`3o0?nn0_oonfX01Ooo0?Ko00?ooookJ_oonf[o0?m800Cooo]Z00?o
0?mgogT0oonGo`001_oonfX01?oo_`3ooo]ZoookJ_l0oj82oookJP07o`3o8Ooonf[ooo]ZoookJ_oo
0?;ooo]Zo`3oEP02oookJP05ool0X?oonf[ooo]Zo`0UoomD0?l00_oonfX00olZ0?ooo`X0oookJP03
oookJP05og_o0?oonf[ooi`0oookJ_oo@@000_oonfX00ol0ocSooo]ZoookJP07oookJP03oolP0?oo
nf[ooo]Z00?ooo]Z00?oo`2eoookJ_oonfX02ooonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooo
nf[ooo]Z017ooo]Z00Coo`1?oookJ_oonf[o0?nF1_oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000go
oo]Z00Kod_l0oookJ_oonf[ogOl0oookJ_l[0?l6oookJP04oonK0?oo003ooo]Zonco00Cooo]Z00?o
T`3ooookJ_oonfX08ooonfX002oooo]Z00?o0?m=oookJ_oo0:X01?oonfX00ooUo`3ooo]ZoookJP0:
oookJP03obT0oooonf[ooo]Z00;ooo]Z00?oiOl0oookJ_oonfX01_oonfX00oooj03ooo]ZonGo0004
oookJP05oole0?oonf[o087ooookJ_lgo`000_oonfX01Ol0oiOo0?oXoookJ_oonf[o=_l000oooo]Z
00?o0>?ooookJ_oonfX00_oonfX00ooo0>cooo]ZoookJP0<oookJP03o`3okOoonf[ooo]Z013ooo]Z
0_oo6P000ooonf[o7@3ooad0o`07oookJP?oo`2d00CoojL0oiCo0?nDo`3ooo]Z1onDo`0<oookJPko
A?l03OoonfX4oonW00;oo`2d2_oob@06oookJP03o`3okOoonf[ooo]Z00Gooo]Z0_oo0>`01?l0003o
0>?oo`000?l00004oookJP05oiCo0?l0onSooo]ZoiCo0?oo=@000_nDo`001_ooj03oU?l0oookJ_nD
o`3ooo]ZobT0o`KoU?l000?o0?m=oiCo0?nDo`000ooonfX00ooo3@3oon<0oiCo0002oiCo0003of;o
0?oonf[ooo]Z00Wooo]Z00Coh_l0oookJ_oUo`3oiOl01_nDo`002?l0odSooo]ZoookJ_oonf[oU?l0
oookJ_mi0?ooUol01_oonfX01ooUo`3ookl0oookJ_l0S?oo0?nRoookJ_l0ob400ooonfX00ooo0?;o
0?mFoookJP02oookJP03ool0X?oonf[ooo]Z00;oU?l00_oonfX00olZ0?oo04cooookJP03oookJP04
og_o0?oonf[ooi`0oom100;ooo]Z00?o0?lhoookJ_l80?l02?oonfX00ooo803ooo]ZoookJP02oook
JP03oiCo0?oonf[ooo]Z00cooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0@oook
JP05ool0Cooonf[ooo]ZoookJ_l0oiH01_oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000gooo]Z00Ko
d_l0oookJ_oonf[ogOl0oookJ_l[0?l5oookJP04oonK0?oo003oo`2Yonco00Cooo]Z00?oT`3ooook
J_oonfX0D?oonfX00ol0odgooo]Zool0ZP03oookJP03oeT0oooonf[ooo]Z00[ooo]Z00?o:@3ooook
J_oonfX00ooonfX00ol0oo3ooo]ZoookJP05oookJP04oooX0?oonf[ooo]Zool02`?ooo]Z00GoocD0
oookJ_oonf[o087oocOo0002oookJP05o`3oUooonf[o0?oXoookJ_lfo`003ooonfX00ol0hooooo]Z
oookJP02oookJP03ool0k?oonf[ooo]Z00cooo]Z00?o0?o]oookJ_oonfX04OoonfX2oolJ00;o7@3o
1ooonfX3ool0]0?oojL0<?oonfX4oonW0003ool0]?oonf[ooo]Z00;ooo]Z0olM0?l9oookJP03o`3o
kOoonf[ooo]Z00Kooo]Z00?oo`3/o`000?l0hol00_l00004oookJP09ocKo0?l0onSo0?oXoookJ_l0
POooocD0oookJ_oo00_oonP000;ooo]Z00?o0?o`oookJ_lY0?l00ooonfX01?mI0?ooo`2ZoookJ_l0
odd5oookJP05oooS0?oonf[ooo]Zof`0oomRo`002ooonfX01?oRo`3ooo]Zoe[o0?l0okh2oookJP03
ool0m_l00ooooo]Z00;ooo]Z00So0?m8oookJ_oonf[ooo]Zo`3oMomi0?ooobL0oiOo00Kooo]Z00Ko
okl0oookJ_l0S?oo0?nRoookJ_l0ob43oookJP03ool0l_oonf[o0?mF00;ooo]Z00Goo`2PoookJ_oo
nf[ooo]Zoe@0o`02oookJP03obX0oooo2P3ooo]Z00?ooo]Z00GoNol0oookJ_ooW03ooo]Zoom10002
oookJP03o`3o>?l80?oooo]Z00Oooo]Z00?oob00oookJ_oonfX00ooonfX00ooo0;Gooo]ZoookJP0;
oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX04?oonfX01?oo04oooo]ZoookJ_l0
oiH6oookJP05oolL0?oonf[ooo]ZoookJ_nho`003OoonfX01_oBo`3ooo]ZoookJ_oMo`3ooo]Zob/0
o`Kooo]Z00Cooi/0ool00?oonf[ok?l01?oonfX00onC0?oooo]ZoookJP0SoookJP00;_oonfX00ol0
odgooo]Zool0ZP04oookJP;oiOl02ooonfX00olY0?oooo]ZoookJP02oookJP03onGo0?oonf[ooo]Z
00Kooo]Z00?oonP0oookJ_oUo`001?oonfX01Ooo=@3ooo]Zo`21oooonf[o=ol000;ooo]Z00Go0?nG
o`3oj?oonf[ooo]ZocKo000?oookJP03o`3Soooonf[ooo]Z00;ooo]Z00?oo`3/oookJ_oonfX03?oo
nfX00ol0ongooo]ZoookJP0?oookJP;ooaX00olM0?l6oookJP?oo`2d00?ooo]ZoonW0?ooY`001?oo
nfX5oiCo00[ooo]Z0ol0o`TBodCo00;o0?l93?oonfX3oonW00;oo`2d2?oob@06oookJP;o0?o]1ooo
nfX01?oo0>co0000o`3Sool00005oookJP05ocKo0?l0onSo0?nGoookJ_oo=@000_nDo`000oooj03o
oo]Zo`3ol002oookJP03obT0oooonf[oU?l000CoU?l000?o0?m=oiCo0?nDo`000ooonfX01_oo3@3o
on<0oookJ_nDo`3ooo]Zof;o00_ooo]Z00Coh_l0oookJ_oUo`3o0?nn1_nDo`002?l0odSooo]Zoook
J_oonf[oU?l0oookJ_mi0?ooUol01_oonfX01_oo_`3ooo]ZoookJ_l0oj;ooo]Zo`3o8@Cooo]Z00?o
o`3bo`3oE_oonfX00_oonfX01?oo0:3ooo]ZoiCo0?nDo`03oookJP03obX0oooonf[ooo]Z00;ooo]Z
00CoNol0oookJ_oonf[ood400_oonfX00ol0ocSooo]Zo`P0o`08oookJP03oolP0?oonf[ooo]Z00;o
oo]Z00?oU?l0oookJ_oonfX03?oonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z017o
oo]Z00Coo`1?oookJ_oonf[o0?nF1_oonfX00ooo703ooo]ZoookJP02oookJP03okSo0?oonf[ooo]Z
00[ooo]Z00Cod_l0oookJ_oonf[ogOl00_oonfX00ol[0?oooo]ZoookJP03oookJP04ool00?oo0:Wo
oo]Zonco00?ooo]Z00?oT`3ooookJ_oonfX0CooonfX00ol0odgooo]Zool0ZP03oookJP03oeT0oooo
nf[ooo]Z00[ooo]Z00?o:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP05oookJP04oooX0?oo
nf[ooo]Zool02`?ooo]Z00GoocD0oookJ_oonf[o087oocOo0002oookJP05o`3oUooonf[o0?oXoook
J_lfo`003ooonfX00ol0hooooo]ZoookJP02oookJP03ool0k?oonf[ooo]Z00cooo]Z00?o0?o]oook
J_oonfX04?oonfX01?oo6P3o7@3ooad0oolM0?l6oookJP?oo`2d00?ooo]ZoonW0?ooY`004ooonfXG
o`3o2@gooo]Z0oooY`001Ooo0;Cooo]ZoookJ_oonf[o0?ob00;o7@3o2?oonfX2o`3ok@Oooo]Z0_oo
0>`00ol0hooo0000oookJP04oookJP;o=_l000Wo0?oXoookJ_l0POooocD0oookJ_oo00_oonP0oook
J_l0oo000_oonfX02?lY0?oooo]ZoookJ_mI0?oooo]Zool0Z_oonf[o0?m=1OoonfX01Oooh`3ooo]Z
oookJ_m/0?ooH_l000_ooo]Z00Coh_l0oookJ_mJo`3o0?nn0_oonfX01Ooo0?Ko00?ooookJ_oonf[o
0?m800Cooo]Z00?o0?mgogT0oonGo`001_oonfX01?oo_`3o0:;ooookJ_l0oj82oookJP07o`3o8Ooo
nf[ooo]ZoookJ_oo0?;ooo]Zo`3oEP02oookJP04ool0X?oonf[ooo]Zoe@0o`?ooo]Z00?o:P3oool:
0?oonfX00ooonfX01?mko`3ooo]ZoonL0?oo@@02oookJP03o`3o>?l80?oooo]Z00Oooo]Z00?oob00
oookJ_oonfX00ooonfX00ooo0;Gooo]ZoookJP0<oookJP03o`3o]Ooonf[ooo]Z00?ooo]Z00?o0?n;
oookJ_oonfX04OoonfX00ooo04oooo]Zo`3oUP06oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0
oookJ_oonfX02_oonfX01?oBo`3ooo]ZoookJ_oMo`02oookJP03ob/0oooonf[ooo]Z00?ooo]Z00Go
oi/0ool00?oonf[ooo]Zonco0003oookJP03oi<0oooonf[ooo]Z02?ooo]Z000^oookJP03o`3oCOoo
nf[oo`2Z00?ooo]Z0_oUo`0;oookJP03obT0oooonf[ooo]Z00;ooo]Z00?oiOl0oookJ_oonfX01_oo
nfX00oooj03ooo]ZonGo0005oookJP04oole0?l0POoooo]ZocOo00;ooo]Z00Go0?nGo`3oj?oonf[o
oo]ZocKo000?oookJP03o`3Soooonf[ooo]Z00;ooo]Z00?oo`3/oookJ_oonfX03?oonfX00ol0ongo
oo]ZoookJP0?oookJP03oolJ0?lM0?oo7@3o00Kooo]Z0ooo0;@01?oonf[oojL0oonW0?ooY`06oook
JP?oU?l01ooonfX5o`3o2@Cooo]Z3Om4o`02oookJPGoA?l01?l0o`T:oookJP?oojL00_oo0;@6ooo9
00Oooo]Z0_l0ond5oookJP04o`000?oo0>coo`3/o`3So`Oooo]Z00Co0?oXo`3oUooonf[oocD00_nD
o`000oooj03ooo]Zo`3ol002oookJP03obT0oooonf[oU?l000CoU?l000?o0?m=oiCo0?oonfX00_oo
nfX01ooo3@3ooo]ZoooS0?oonf[oU?l0oookJ_mRo`002ooonfX01?oRo`3ooo]ZonGo0?l0okh5oiCo
0008o`3oB?oonf[ooo]ZoookJ_nDo`3ooo]ZogT0oonGo`06oookJP04o`2Roooo_`3ooo]Zo`3oXP;o
oo]Z00Ko0?lQoookJ_oonf[ooo]Zool0l_l0oeH3oookJP04ool0X?oonf[ooo]ZoiCo00?ooo]Z00?o
:P3ooookJ_oonfX00_oonfX01Omko`3ooo]ZoookJ_ooW03ood4000;ooo]Z00?o0?lho`P0oooonfX0
2?oonfX00ooo803ooo]ZoookJP02oookJP03oiCo0?oonf[ooo]Z00_ooo]Z00?o0?neoookJ_oonfX0
1?oonfX00ol0oh_ooo]ZoookJP0@oookJP04ool0Cooonf[ooo]Zo`3oUPOooo]Z00Gooa`0oookJ_oo
nf[ooo]ZokSo000<oookJP04om;o0?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX00ooonfX0
1?oo003oo`2YoookJ_o/o`03oookJP03oi<0oooonf[ooo]Z04kooo]Z00Co0?m=oookJ_oonf[oo`2Z
0ooonfX00omI0?oooo]ZoookJP09oookJP03obT0oooonf[ooo]Z00?ooo]Z00?o0?o`oookJ_oonfX0
1OoonfX01?ooj03ooo]ZoookJ_oo00/4oookJP04oole0?oonf[o087oocOo00?ooo]Z00Co0?nGo`3o
j?oonf[o=_l03ooonfX00ol0hooooo]ZoookJP02oookJP03ool0k?oonf[ooo]Z00cooo]Z00?o0?o]
oookJ_oonfX04?oonfX2oad0o`03o`3ol_oonf[ooo]Z00Cooo]Z0_oo0;@01?oonf[oojL0oonW0?oo
Y`0@oookJPGo0?l95ooonfX5o`3o2@_ooo]Z0oooY`001?oo0;Cooo]ZoookJ_oonfX2oad0o`03o`3o
l_oonf[ooo]Z00Gooo]Z0_l0ond5oookJP;o000000?oo`3/o`3SoooonfX01_oonfX02_lfo`3o0?oX
oookJ_l0POooocD0oookJ_oo00_oonP0oookJ_l0oo02oookJP05obT0oooonf[ooo]ZoeT0oooo0:X0
0_oonfX00ol0odgooo]ZoookJP02oookJP06ool=0?ooh`3ooo]ZoookJ_m/0?ooH_l02ooonfX01?oR
o`3ooo]Zoe[o0?l0okh2oookJP05ool0m_l00ooooo]ZoookJ_l0odP00ooonfX01?l0ogOoN@3ooolW
0?nGo`06oookJP06oono0?oonf[o08coo`3oX_oonf[o0?lQ0ooonfX00ooo0?;ooo]Zo`3oEP02oook
JP05ool0X?oonf[ooo]ZoookJ_mD0?l00_oonfX00olZ0?ooo`X0oookJP03oookJP05og_o0?oonf[o
oi`0oookJ_oo@@000_oonfX00ol0ocSooo]ZoookJP07oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?o
o`2eoookJ_oonfX02ooonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z017ooo]Z00?o
o`1?oookJ_l0oiH01ooonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00Cod_l0oookJ_oonf[o
gOl00_oonfX00ol[0?oooo]ZoookJP04oookJP04ool00?oonf[ooo]Zonco00?ooo]Z00?oT`3ooook
J_oonfX08ooonfX002gooo]Z00?o0?m=oookJ_oo0:X00ooonfX3onGo00_ooo]Z00Go:@3ooookJ_oo
nf[ooo]ZonGo0009oookJP03oooX0?oUo`3ooo]Z00Cooo]Z00CoocD0o`21oooonf[o=ol00_oonfX0
1Ol0oiOo0?oXoookJ_oonf[o=_l000oooo]Z00?o0>?ooookJ_oonfX00_oonfX00ooo0>cooo]Zoook
JP0<oookJP03o`3okOoonf[ooo]Z00kooo]Z0_oo6P000olM0?oooo]ZoookJP04oookJP;oo`2d0_oo
nfX2oonW00Wooo]Z00?oU?l0oookJ_oonfX00_oonfX5o`3o2@Wooo]Z1oml0?l8ocCo00OoA?l00_nD
o`05o`3o2@03oookJ_nDo`3oU?l000Gooo]Z0oooY`000ooo0;CoolT0ooo90003ooo90003oolJ0?oo
nf[ooo]Z00Gooo]Z00?o0?o]oookJ_oonfX00_oonfX3o`000003ool0k?l0hooooo]Z00Kooo]Z00Wo
0?oXo`3oUooonf[oocD0oookJ_nDo`3oonP0oookJ_l0oo000_oonfX00olY0?oooo]ZoookJP04oiCo
0003o`3oCOnDo`3ooo]Z00;ooo]Z00Coo`d0oookJ_ooh`3oK03o0_oonfX00omRo`3ooo]ZoookJP08
oookJP05on;o0?oonf[oF_l0o`3o__oonfX01?nDo`000ooonf[o0?m8oookJP02oookJP04oiCo0?oo
nf[oN@3ooiOo00Kooo]Z00Cookl0oookJ_oonf[o0?nR0_oonfX01_l0ob7ooo]ZoookJ_oonf[oo`3b
o`3oEP?ooo]Z00Coo`2PoookJ_nDo`3oU?l00_oonfX00ooo2P3o:P3ooookJP03oookJP04og_o0?oo
nf[ooi`0oom100;ooo]Z00?o0?lhoookJ_l80?l02?oonfX00ooo803ooo]ZoookJP02oookJP03oiCo
0?oonf[ooo]Z00_ooo]Z00?o0?neoookJ_oonfX01?oonfX00ol0oh_ooo]ZoookJP0@oookJP05ool0
Cooonf[ooo]ZoookJ_l0oiH01_oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00Cod_l0oook
J_oonf[ogOl00_oonfX00ol[0?oooo]ZoookJP03oookJP04oonK0?oo003oo`2Yonco00Cooo]Z00?o
T`3ooookJ_oonfX0COoonfX00ol0odgooo]Zool0ZP03oookJP03oeT0oooonf[ooo]Z00[ooo]Z00?o
:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP06oookJP03oooX0?oonf[oo`0;00Cooo]Z00Co
ocD0oookJ_l0POoo=ol00ooonfX01?l0oiOo0?oXoookJ_lfo`0?oookJP03o`3Soooonf[ooo]Z00;o
oo]Z00?oo`3/oookJ_oonfX03?oonfX00ol0ongooo]ZoookJP0?oookJP03oolJ0?lM0?oo0?ob00Ko
oo]Z0_oo0;@00ooonf[oojL0oonW000>oookJPGo0?l92_oonfX6og`0o`_o=?l01_oonfX5o`3o2@Wo
oo]Z0oooY`03oookJP;o7@3o00?ooaX0oookJ_oonfX01OoonfX00ol0ongooo]ZoookJP02oookJP?o
00000_oo0>`00ol0hooooo]ZoookJP04oookJP0:ocKo0?l0onSo0?nGo`21oooo=@3ooo]Zool02ooo
j03ooo]Zo`3ol0;ooo]Z00Go:@3ooookJ_oonf[oF@3oool0ZP02oookJP03o`3oCOoonf[ooo]Z00;o
oo]Z00Koo`d0oooS0?oonf[oK03ooookJ_mRo`0:oookJP04on;o0?oonf[oF_l0o`3o_P;ooo]Z00?o
o`3fo`03oooonfX00_oonfX01ol0odSooo]ZoookJ_oonf[o0?mgogT0oonGo`001_oonfX01?oo_`3o
0:;ooookJ_l0oj82oookJP07o`3o8Ooonf[ooo]ZoookJ_oo0?;ooo]Zo`3oEP02oookJP04ool0X?oo
nf[ooo]Zoe@0o`?ooo]Z00?o:P3ooookJ_oonfX00_oonfX01Omko`3ooo]ZoonL0?oonf[ood4000;o
oo]Z00?o0?lho`P0oooonfX01ooonfX00ooo803ooo]ZoookJP03oookJP03ool0]Ooonf[ooo]Z00_o
oo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0AoookJP04ool0Cooonf[ooo]Zo`3o
UPKooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP04om;o0?oonf[ooo]Zomgo00;ooo]Z00?o
:`3ooookJ_oonfX01?oonfX01?ooV`3oo`00oookJ_o/o`04oookJP03oi<0oooonf[ooo]Z02;ooo]Z
000]oookJP03o`3oCOoonf[oo`2Z00;ooo]Z1?oUo`0:oookJP05obT0oooonf[ooo]ZoookJ_oUo`00
2OoonfX00oooj03oiOl0oookJP04oookJP04oole0?oonf[o087oocOo00;ooo]Z00Go0?nGonGo0?oo
nf[ooo]ZocKo000@oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`03_oonfX00ol0ongooo]ZoookJP0=
oookJP;ooaX00_lM0?l6oookJP03ool0]?oonf[ooo]Z00;oojL03?oonfX4o`3o2@Oooo]Z1?ml0?l:
ocCo00Koo`1?0_ml0?l9odCo00CoU?l000?ooo]Zo`3o2OnDo`000_nDo`07oookJP?oojL00_oonfX2
ooo90003oad0oooo6P3ooo]Z00Gooo]Z0_l0ond2oookJPCo000000?oo`3/o`3Sool0hol01_oonfX0
1?l0onSo0?nGoookJ_oo=@02oookJP03oooX0?oonf[o0?o`00;ooo]Z00?o:@3ooookJ_oonfX01?nD
o`000ol0odgooo]ZoookJP02oookJP04ool=0?ooh`3ooo]Zof`0o`;ooo]Z00?oH_l0oookJ_oonfX0
2?oonfX01OoRo`3ooo]Zoe[o0?l0okkooo]Z00CoU?l000So0?m8oookJ_oonf[ooo]ZoiCo0?oonf[o
N@3ooiOo00Kooo]Z00Co0:;ooono0?oonf[o0?nR0_oonfX01_l0ob7ooo]ZoookJ_oonf[oo`3bo`3o
EP?ooo]Z00Coo`2PoookJ_nDo`3oU?l00ooonfX00olZ0?oooo]ZoookJP02oookJP04og_o0?oonf[o
oo]Zoom100;ooo]Z00?o0?lhoookJ_l80?l02?oonfX00ooo803ooo]ZoookJP02oookJP03oiCo0?oo
nf[ooo]Z00cooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0AoookJP04ool0Cooo
nf[ooo]Zo`3oUPKooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000=oookJP03om;o0?oonf[ogOl000;o
oo]Z00?o:`3ooookJ_oonfX00ooonfX01?ooV`3oo`00ool0ZOo/o`04oookJP03oi<0oooonf[ooo]Z
04cooo]Z00Co0?m=oookJ_oonf[oo`2Z0ooonfX00omI0?oooo]ZoookJP09oookJP03obT0oooonf[o
oo]Z00;ooo]Z00?o0?o`oookJ_oonfX01_oonfX00oooj03ooo]Zool02`04oookJP04oole0?oonf[o
oo]Zo`21o`?ooo]Z00Co0?nGo`3oj?oonf[o=_l04?oonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00ko
oo]Z00?o0?o]oookJ_oonfX03_oonfX00ooo6P3o7@3ooad0o`07oookJP04ool0]?oonf[oojL0oonW
00cooo]Z1?l0o`T7oookJPCoO03o2_ldo`000ol0;Oooo`1?ool0C`04ool0C`CoO03o1Oldo`000oml
0?oooo]ZoookJP03oookJP?o0?l92OoonfX3oonW00;ooo]Z0_lM0?l00ooo6P3ooo]ZoookJP04oook
JP;o0?o]0_oonfX4o`000003oookJ_oo0>co0>?o00Kooo]Z00[o=_l0o`3oj?l0oiOo087ooole0?oo
nf[oo`0;oooX0?oonf[o0?o`0_oonfX01olY0?oooo]ZoookJ_mI0?ooo`2ZoookJ_l0odd01OoonfX0
1_ooh`3ooo]ZoookJ_m/0?oooo]Zof;o00[ooo]Z00Coh_l0oookJ_mJo`3o0?nn0_oonfX01Ooo0?Ko
00?ooookJ_oonf[o0?m800?ooo]Z00Co0?mgogT0oooo9`3oUol01_oonfX00ooo_`3ooo]Zo`3oXP02
oookJP07o`3o8Ooonf[ooo]ZoookJ_oo0?;ooo]Zo`3oEP02oookJP04ool0X?oonf[ooo]Zoe@0o`?o
oo]Z00?o:P3oool:0?oonfX00ooonfX01?mko`3ooo]ZoonL0?oo@@02oookJP03o`3o>?l80?oooo]Z
00Oooo]Z00?oob00oookJ_oonfX00ooonfX00ooo0;Gooo]ZoookJP0<oookJP03o`3o]Ooonf[ooo]Z
00?ooo]Z00?o0?n;oookJ_oonfX04OoonfX00ooo04oooo]Zo`3oUP06oookJP03oolL0?oonf[ooo]Z
00;ooo]Z00?o^?l0oookJ_oonfX02_oonfX01_oBo`3ooo]ZoookJ_oMo`3ooo]Zob/0o`Kooo]Z00Co
oi/0ool00?oonf[ok?l01?oonfX00onC0?oooo]ZoookJP0RoookJP00;?oonfX00ol0odgooo]Zool0
ZP02oookJPGoiOl02OoonfX01OlY0?oooo]ZoookJ_oonf[oiOl000Wooo]Z00?oonP0onGo0?oonfX0
1OoonfX00ooo=@3o087oocOo0003oookJP;oiOl00_oonfX00olfo`3ooo]ZoookJP0=oookJP05o`3S
oooonf[ooo]ZoookJ_oo0>`03OoonfX2o`3ok@oooo]Z00?ooaX0oookJ_lM0?l01_oonfX2ool0]0?o
ojL03?oonfX2o`3o2@Cooo]Z1?nDo`03og`0o`Co=?l04Ol02ol=odCo0003ocCo0?nDo`3oU?l000Go
U?l02?oonfX2oonW00?ooo]Z00?o7@3ooolJ0?oo6P001_oonfX00ol0ongooo]Zo`000003o`000004
oookJ_oo0>coo`3/o`3So`Kooo]Z00_o0?oXo`3oUooonf[oocD0oookJ_oo00_oonP0oookJ_l0oo3o
oo]ZobT0o`04oookJP;oU?l000?o0?m=oiCo0?oonfX00_oonfX01ooo3@3ooo]ZoooS0?oonf[oK03o
oookJ_mRo`002ooonfX01OoRo`3oF_l0oookJ_l0okkooo]Z00?oU?l000?ooo]Zo`3oB?oonfX00_oo
nfX01?nDo`3ooo]ZogT0oonGo`06oookJP04oono0?oonf[ooo]Zo`3oXP;ooo]Z00Go0?lQoookJ_oo
nf[ooo]Zool0lP03oookJP04ool0X?oonf[ooo]ZoiCo00?ooo]Z00?oo`X0obX0oooonfX00_oonfX0
1Omko`3ooo]ZoookJ_ooW03ood4000;ooo]Z00?o0?lho`P0oooonfX02?oonfX01Ooo803ooo]Zoook
J_oonf[oU?l000kooo]Z00?o0?neoookJ_oonfX01?oonfX00ol0oh_ooo]ZoookJP0@oookJP04ool0
Cooonf[ooo]Zo`3oUPOooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP03om;o0?oonf[ogOl0
00;ooo]Z00?o:`3ooookJ_oonfX00ooonfX01?ooV`3oo`00ool0ZOo/o`04oookJP03oi<0oooonf[o
oo]Z04_ooo]Z00Co0?m=oookJ_oonf[oo`2Z0ooonfX00omI0?oooo]ZoookJP09oookJP03obT0oooo
nf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01ooonfX00oooj03oo`0;oookJP04oookJP03oole0?oo
nf[o087o00?ooo]Z00Go0?nGoookJ_l0onSooo]ZocKo000?oookJP05o`3Soooonf[ooo]ZoookJ_oo
0>`03_oonfX00ol0ongooo]ZoookJP0>oookJP03oolJ0?lM0?oo0?ob00Kooo]Z00Coo`2doonW0?oo
Y`3oojL03?oonfX2o`3o2@Kooo]Z1Oml0?l4ocCo0003o`0]ool02ooo00_o01Co00_o0ooo04l5ocCo
0004og`0oooonf[ooo]ZoookJP?o0?l92?oonfX00ooo0;CoojL0oonW0002oookJP;o7@3o00?ooaX0
oookJ_oonfX01?oonfX00ol0ongooo]Zo`000003o`0000;ooo]Z00?oo`3/o`3SoooonfX01OoonfX0
3?lfo`3o0?oXo`3oUol0POooocD0ool02ooonf[oonP0oookJ_l0oo3ooo]ZobT0o`?ooo]Z00CoF@3o
ool0Z_oonf[o0?m=1?oonfX01_oo3@3oon<0oookJ_oonf[oK03oof;o00_ooo]Z00Ooh_l0oe[o0?oo
nf[o0?nnoookJ_oo0?Ko00?o00?ooo]Z00Oo0?m8oookJ_oonf[o0?mgoookJ_mi0?ooUol000Kooo]Z
00Cookl0oookJ_oonf[o0?nR0_oonfX01_l0ob7ooo]ZoookJ_oonf[oo`3bo`3oEP;ooo]Z00Goo`2P
oookJ_oonf[ooo]Zoe@0o`03oookJP03obX0oooonf[ooo]Z00;ooo]Z00CoNol0oookJ_ooW03ood40
0ooonfX00ol0ocSooo]ZoookJP07oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX0
3?oonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z017ooo]Z00?oo`1?oookJ_l0oiH0
1ooonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00Kod_l0oookJ_oonf[ogOl0oookJ_l[0?l6
oookJP04oonK0?oo003ooo]Zonco00Cooo]Z00?oT`3ooookJ_oonfX08_oonfX002_ooo]Z00Co0?m=
oookJ_oonf[oo`2Z0_oonfX4onGo00[ooo]Z00Co:@3ooookJ_oonf[oiOl02_oonfX00oooj03ooo]Z
oookJP04oookJP04oole0?l0POoooo]ZocOo00;ooo]Z0_oUo`02oookJP03ocKo0?oonf[ooo]Z00go
oo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00=oookJP03o`3okOoonf[ooo]Z00gooo]Z0_oo6P02oad0
o`Gooo]Z0_oo0;@2oonW00cooo]Z0ol0o`T00ooonf[oU?l0oiCo0005oiCo0003oookJ_ldo`3o=?l0
00;o=?l01?l02ol5ool06003oookJ_m4o`3oA?l001SoA?l00_ldo`02og`0o`?oU?l00_l0o`T7oook
JP;oojL00_oonfX2oad0o`;ooaX01OoonfX2o`3ok@?o00000ooonfX00ooo0>co0>?ooookJP05oook
JP0;o`3oj?l0oiOo=ol0oole0?oonf[oo`0;oiCo0?oonf[o0?o`oookJ_lY0?l01?oonfX2oiCo0003
o`3oCOoonf[ooo]Z00;ooo]Z00Coo`d0oookJ_ooh`3oK03o0_oonfX00omRo`3ooo]ZoookJP08oook
JP04on;o0?oonf[oF_l0o`3o_P;ooo]Z0_nDo`02oookJP07o`3oB?oonf[ooo]ZoiCo0?oonf[oN@3o
oiOo0006oookJP04o`2Roooo_`3ooo]Zo`3oXP;ooo]Z00Ko0?lQoookJ_oonf[ooo]Zool0l_l0oeH3
oookJP04ool0X?oonf[oU?l0oiCo00?ooo]Z00?o:P3ooookJ_oonfX00_oonfX01?mko`3ooo]Zoook
J_oo@@02oookJP03o`3o>?oonf[o203o00Sooo]Z00?oob00oookJ_oonfX00_oonfX00onDo`3ooo]Z
oookJP0;oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX04?oonfX01?oo04oooo]Z
oookJ_l0oiH7oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX01_oBo`3ooo]ZoookJ_oMo`3o
oo]Zob/0o`Gooo]Z00Cooi/0ool00?oo0:Wok?l01?oonfX00onC0?oooo]ZoookJP1;oookJP04o`3o
COoonf[ooo]Zool0ZP?ooo]Z00?oF@3ooookJ_oonfX02OoonfX01OlY0?oooo]ZoookJ_oonf[o0?o`
00Wooo]Z00?oonP0ool02ooonfX01?oonfX01?oo=@3ooo]Zo`21oolgo`02oookJP05o`3oUooonf[o
0?oXoookJ_lfo`003ooonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00kooo]Z00?o0?o]oookJ_oonfX0
3OoonfX01?oo6P3o7@3ooad0ool0oo85oookJP03ool0]?ooY`3oojL000cooo]Z0ol0o`T6oookJP;o
O03o00?ooo]ZocCo0?ldo`000_ldo`000ol0;Ooo00_oo`0;o`02o`0;o`Goo`0H3OoonfX4ool060Oo
00_o00Coo`1?ocCo0?ldo`3o=?l00oml0?l01?oonf[o0?l9o`3o2Ol0o`T7oookJP03ool0]?ooY`3o
oo]Z00;ooo]Z00?o7@3ooolJ0?oo6P001OoonfX2o`3ok@?o00000ooonfX00ooo0>co0>?oo`3So`05
oookJP0<ocKo0?l0onSo0?nGo`21oooo=@3oo`0;oookJ_ooj03ooo]Zo`3ol?oonf[o:@3o0ooonfX0
1?mI0?ooo`2ZoookJ_l0odd4oookJP06ool=0?ooh`3ooo]Zof`0oooonf[oH_l02_oonfX01?oRo`3o
oo]Zoe[o0?l0okh2oookJP03ool0m_l00ooooo]Z00;ooo]Z00Oo0?m8oookJ_oonf[o0?mgogT0oooo
9`3oUol000Kooo]Z00?ookl0oookJ_l0oj800_oonfX01ol0ob7ooo]ZoookJ_oonf[oo`3boookJ_l0
oeH00_oonfX01?oo0:3ooo]ZoookJ_mD0?l3oookJP03obX0oooo2P3ooo]Z00;ooo]Z00GoNol0oook
J_oonf[ooi`0oom10002oookJP03o`3o>?l80?oooo]Z00Oooo]Z00?oob00oookJ_oonfX00ooonfX0
0ooo0;Gooo]ZoookJP0;oookJP03o`3o]Ooonf[ooo]Z00?ooo]Z00?o0?n;oookJ_oonfX04OoonfX0
0ooo04oooo]Zo`3oUP07oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX01_oBo`3ooo]Zoook
J_oMo`3ooo]Zob/0o`Kooo]Z00Cooi/0ool00?oonf[ok?l01?oonfX00onC0?oooo]ZoookJP0Roook
JP00:ooonfX00ol0odgooo]Zool0ZP02oookJPGoiOl02OoonfX01OlY0?oooo]ZoookJ_oonf[o0?o`
00Wooo]Z00?oonP0oookJ_oonfX01?oonfX01?oo=@3ooo]Zo`21oolgo`02oookJP?oiOl000?ooo]Z
ocKo0?oonfX03_oonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00gooo]Z00?o0?o]oookJ_oonfX03?oo
nfX2onGo0003oookJ_lM0?oooo]Z00Cooo]Z0_oo0;@2oonW00cooo]Z00?o0?l9oiCo0?nDo`001onD
o`04ocCo0004o`0]ool02ooo00_oo`0;o`;oo`0H1_oonfX2ok3o01_oA?l000Co00_oocCo0?ldo`3o
=?l00_ml0?l2oiCo00?o0?l91_oonfX01?ooY`3oo`2doookJ_oonfX2oad0o`;ooaX01?oonfX01?l0
003o0?o]o`000?l00004oookJP03ool0k?l0hooooo]Z00Gooo]Z00Ko0?oXo`3oUolgo`3oocD0oook
J_nDo`02oookJP03o`3ol?nDo`3o:@3o00?ooo]Z00CoF@3ooiCo0?nDo`3o0?m=1?oonfX01?oo3@3o
oo]ZoooS0?m/0?l2oookJP03of;o0?oonf[ooo]Z00Sooo]Z00Coh_l0oe[o0?oonf[o0?nn0_oonfX2
oiCo0003oookJ_l0odSooo]Z00;ooo]Z00?oU?l0oookJ_mi0?l00_nDo`04oookJP05o`2Roooo_`3o
oo]Zo`3oX_l0S?l00_oonfX01Ol0ob7ooo]ZoookJ_oonf[oU?l000?ooo]Z00Coo`2PoookJ_nDo`3o
U?l00ooonfX00olZ0?oooo]ZoookJP02oookJP04og_o0?oonf[ooo]Zoom100?ooo]Z00?o0?lho`P0
oooonfX01ooonfX00ooo803ooo]ZoookJP02oookJP03oiCo0?oonf[ooo]Z00cooo]Z00?o0?neoook
J_oonfX00ooonfX00ol0oh_ooo]ZoookJP0@oookJP05ool0Cooonf[ooo]ZoookJ_l0oiH01_oonfX0
1Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00Kod_l0oookJ_oonf[ogOl0oookJ_l[0?l5oookJP04
oonK0?oo003oo`2Yonco00Cooo]Z00?oT`3ooookJ_oonfX0B_oonfX01?l0odgooo]ZoookJ_oo0:X3
oookJP03oeT0oooonf[ooo]Z00Wooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP06
oookJP03oooX0?oo00_ooo]Z00Gooo]Z00?oocD0oookJ_l0POl00_oonfX01Ol0oiOooo]Zo`3oj?oo
nf[o=_l000oooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00>oookJP03o`3okOoonf[ooo]Z00cooo]Z
0_oo6P000olM0?oo0?oboookJP04oookJP03ool0]?ooY`3oojL000cooo]Z0_l0o`T7oookJP03og`0
ooldo`3o=?l000;o=?l000?o02goool0Col02ol00_l02ol2ool060Kooo]Z4on`o`04oookJP;oo`0H
1?l02ol3ocCo00?oO03o00Cooo]Zo`3o2Ol0o`Wo0?l91_oonfX2oonW00;ooo]Z0_lM0?l2oolJ00Co
oo]Z00Co0000o`3okOl0003o00001?oonfX00ooo0>cooo]Zo`3So`05oookJP07ocKo0?l0onSo0?nG
o`21oooo=@3oo`0;oooX0002oookJP03o`3ol?oonf[o:@3o00;ooo]Z00GoF@3ooookJ_oo0:[ooo]Z
o`3oC@04oookJP06ool=0?ooh`3ooo]Zof`0oooonf[oH_l02_oonfX01?oRo`3oF_l0oookJ_l0okh2
oookJP05ool0m_l00ooooo]ZoookJ_l0odP00_oonfX01?l0ogOooo]ZogT0oonGo`06oookJP04oono
0?oonf[ooo]Zo`3oXP;ooo]Z00Ko0?lQoookJ_oonf[ooo]Zool0l_l0oeH2oookJP05ool0X?oonf[o
oo]Zoe@0ool09Ol00_oonfX00olZ0?ooo`X0oookJP03oookJP04og_o0?oonf[ooi`0oom100?ooo]Z
00?o0?lhoookJ_oonfX01_oonfX00ooo803ooo]ZoookJP03oookJP03ool0]Ooonf[ooo]Z00cooo]Z
00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0@oookJP04ool0Cooonf[ooo]Zo`3oUPKo
oo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP06om;o0?oonf[ooo]Zomgo0?oonf[o:`3o1_oo
nfX01?ooV`3oo`00oookJ_o/o`04oookJP03oi<0oooonf[ooo]Z02;ooo]Z000ZoookJP05o`3oCOoo
nf[ooo]Zool0Z_oonfX01_oUo`09oookJP04obT0oooonf[ooo]Zo`3ol0[ooo]Z00?oonP0oookJ_oo
nfX01?oonfX00ooo=@3o087oocOo0002oookJPCoiOl000?ooo]ZocKo0?oonfX03_oonfX01?l0hooo
oo]ZoookJ_oo0>`=oookJP03o`3okOoonf[ooo]Z00_ooo]Z1?oUo`000olM0?oooo]ZoookJP02oook
JP;oo`2d00?ooo]ZoonW0?oonfX02ooonfX9oiCo00?o=?l000?oU?l0o`0;ool02ol00_l02ol6oook
JPGo/?l00_oonfX00om4o`3o0?_oo`3ko`03o`3ko`?oA?l00_l0nol8odCo00;o/?l01?m4o`03oiCo
00?o00_o0oldo`001?ml0?ooU?l0oookJ_oonfX3o`3o2@Cooo]Z0_ooY`001_oo0;Cooo]ZoookJ_lM
0?oo0?oboolJ00?ooo]Z00Co0000ooo90?l0ongo0?o]1OoonfX00ooo0>co0>?ooookJP05oookJP0;
o`3oj?oonf[o=ol0oole0?oonf[oU?l0oookJ_nDo`3o0?o`oiCo0?lY0?l00ooonfX01?mI0?oooo]Z
oiCo0?l0odd4oookJP06ool=0?ooh`3ooo]Zof`0oooonf[oH_l02_oonfX02?oRo`3ooo]Zoe[o0?oo
nf[oiOl0oookJ_oo0?Ko00?o0_oonfX00ol0odSooo]ZoookJP03oiCo0003ogT0oonDo`3ooo]Z00Co
oo]Z00Co0:;ooono0?oonf[o0?nR0_oonfX01_l0ob7ooo]ZoookJ_oonf[oU?l0o`3oEP?ooo]Z00?o
o`2PoookJ_nDo`000_oonfX00onDo`3o04coobX0o`03oookJP05og_o0?oonf[ooo]ZoonL0?oo@@00
0_oonfX00ol0ocSo203ooookJP08oookJP05oolP0?oonf[ooo]ZoookJ_nDo`003_oonfX00ol0okGo
oo]ZoookJP04oookJP03o`3oRooonf[ooo]Z00oooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP06oook
JP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX02_oonfX00ooBo`3ooo]Zomgo0002oook
JP03ob/0oooonf[ooo]Z00;ooo]Z00Cooi/0ool00?oo0:Wok?l01?oonfX00onC0?oooo]ZoookJP19
oookJP05o`3oCOoonf[ooo]ZoookJ_oo0:X00ooonfX00omI0?oooo]ZoookJP09oookJP05obT0oooo
nf[ooo]ZoookJ_l0oo002OoonfX00oooj03oo`0;oookJP04oookJP03oole0?oonf[o087o00;ooo]Z
00Ko0?nGoookJ_oonf[o0?oXoookJ_lfo`0?oookJP04o`3Soooonf[ooo]Zool0k0kooo]Z00?o0?o]
oookJ_oonfX03?oonfX01?oo6P3ooo]Zoad0ool0oo84oookJP;oo`2d00?oojL0oookJ_oonfX02_oo
nfX2o`3o2@Kooo]Z00KoO03oocCo0?ldo`3o=?l0o`0]oooo04l4o`0;o`Kooo]Z1On`o`02oookJPoo
0?_o0_oonfX5ok3o00Cooo]Z00Coo`0Ho`0;ool02ooo00_o0oldo`02og`0o`;ooo]Z0ol0o`T5oook
JP;oojL00_oonfX2oad0o`04oolJ0?oonf[ooo]ZoookJP;o00000_l0ond5oookJP03ool0k?oonf[o
0>?o00Gooo]Z00Wo=_l0o`3oj?lgo`3o087ooole0?oo00_oonP0oookJ_l0oo000_oonfX01olY0?oo
oo]ZoookJ_mI0?oooo]Zool0Z_l0odd01OoonfX01Oooh`3ooo]Zof`0oooonf[oH_l000[ooo]Z00So
h_l0oookJ_mJo`3ooo]Zo`3o__oonf[oo`3fo`03o`?ooo]Z00Oo0?m8oookJ_oonf[o0?mgoookJ_mi
0?ooUol000Kooo]Z00?ookl0oookJ_l0oj800_oonfX01_l0ob7ooo]ZoookJ_oonf[oo`3bo`3oEP?o
oo]Z00Coo`2PoookJ_oonf[oE03o0ooonfX00olZ0?ooo`X0oookJP02oookJP04og_o0?oonf[ooi`0
oom100?ooo]Z00?o0?lhoookJ_oonfX01ooonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[o
oo]Z00cooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0@oookJP04ool0Cooonf[o
oo]Zo`3oUPKooo]Z00?ooa`0oookJ_oonfX00_oonfX00onho`3ooo]ZoookJP0:oookJP03om;o0?oo
nf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX00ooonfX01?ooV`3oo`00oookJ_o/o`04oookJP03oi<0
oooonf[ooo]Z02;ooo]Z000YoookJP05o`3oCOoonf[ooo]Zool0Z_oonfX01_oUo`09oookJP05obT0
oooonf[ooo]ZoookJ_l0oo002OoonfX00oooj03ooo]ZoookJP04oookJP03oole0?oonf[o087o00;o
oo]Z1?oUo`000ooonf[o=_l0oookJP0>oookJP04o`3Soooonf[ooo]Zool0k0gooo]Z00?o0?o]oook
J_oonfX02_oonfX4onGo00;o7@3o1?oonfX01?oo0;Cooo]ZoookJ_ooY`0:oookJP?o0?l91onDo`02
ocCo0005oiCo0?l02ooo00_oo`0;oooo01P01?oonfX4ok3o00Wo0?_o2om4o`04oookJPGo0?_o1?m4
o`06oiCo00?o00_o0oldo`04oookJP;o0?l91?oonfX2oonW0005ool0]?oonf[o7@3ooad0oooo6P00
0_oonfX01Ol0003oolT0o`000?l0003o0?o]00Gooo]Z00?oo`3/o`3SoooonfX01OoonfX01Ol0onSo
oo]ZocOo0?oo=@3ooo]Z00?oU?l000?o0?o`oiCo0?lY0?l00ooonfX01?mI0?oooo]ZoiCo0?l0odd3
oookJP04ool=0?oonf[oon<0of`0o`;ooo]Z00?oH_l0oookJ_oonfX02?oonfX01?oRo`3ooo]Zoe[o
0?oUo`02oookJP04ool0m_l00ooooo]Zo`3oB0GoU?l000?oN@3ooiCo0?oonfX01?oonfX01ol0X_oo
okl0oookJ_l0oj;o08cooookJ_l0ob400ooonfX00onDo`3o0?mFoookJP02oookJP03ool0X?oonf[o
U?l000CoU?l000?o:P3ooookJ_oonfX00_oonfX01?mko`3ooo]ZoookJ_oo@@02oookJP03o`3o>?oo
nf[o203o00Sooo]Z00?oob00oookJ_oonfX00_oonfX00onDo`3ooo]ZoookJP0;oookJP03o`3o]Ooo
nf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX04?oonfX01?oo04oooo]ZoookJ_l0oiH7oookJP05oolL
0?oonf[ooo]ZoookJ_nho`003?oonfX00ooBo`3ooo]Zomgo0002oookJP03ob/0oooonf[ooo]Z00?o
oo]Z00Coo`00oookJ_oo0:Wok?l01?oonfX00onC0?oooo]ZoookJP17oookJP05o`3oCOoonf[ooo]Z
oookJ_oo0:X00ooonfX00omI0?oooo]ZoookJP09oookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`
oookJ_oonfX01_oonfX00oooj03oo`0;oookJP04oookJP06oole0?oonf[o=ol0o`21oooonf[o0?nG
0_oonfX00ol0onSooo]ZocKo000?oookJP04o`3Soooonf[ooo]Zool0k0kooo]Z00?o0?o]oookJ_oo
nfX03?oonfX01?oo6P3o7@3ooad0ool0oo84oookJP03ool0]?oonf[oojL000[ooo]Z0ol0o`T6oook
JP05og`0ooldo`3o=?l0o`0]oooo04l00ol02ol00ooo01Sooo]ZoookJP02oookJP?o/?l02Ol0nol?
oookJPWo0?_o0on`o`03oookJP?o00_o0oldo`001?ml0?oooo]ZoookJ_oonfX2o`3o2@Gooo]Z00Co
ojL0ool0]?oonf[ooo]Z0_lM0?l2oookJPCo000000?o0?o]oookJ_oonfX00ooonfX00ooo0>cooo]Z
o`3So`05oookJP0;ocKo0?l0onSo=ol0o`21oooo=@3oo`0;oooX0?oonf[o0?o`oookJ_lY0?l00ooo
nfX01?mI0?oooo]Zool0Z_l0odd4oookJP06ool=0?ooh`3ooo]Zof`0oooonf[oH_l02_oonfX01?oR
o`3ooo]Zoe[o0?l0okh2oookJP05ool0m_l00ooooo]ZoookJ_l0odP00_oonfX01?l0ogOooo]ZogT0
oonGo`06oookJP04oono0?oonf[ooo]Zo`3oXP;ooo]Z00Ko0?lQoookJ_oonf[ooo]Zool0l_l0oeH2
oookJP04ool0X?oonf[ooo]Zoe@0o`?ooo]Z00?o:P3oool:0?oonfX00_oonfX01Omko`3ooo]Zoook
J_ooW03ood4000;ooo]Z00?o0?lho`P0oooonfX01ooonfX00ooo803ooo]ZoookJP02oookJP03ool0
]Ooonf[ooo]Z00cooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0@oookJP04ool0
Cooonf[ooo]Zo`3oUPOooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP03om;o0?oonf[ogOl0
00;ooo]Z00?o:`3ooookJ_oonfX00ooonfX01OooV`3oo`00ool0ZOoonf[ok?l000Cooo]Z00?oT`3o
oookJ_oonfX08OoonfX002Wooo]Z00Co0?m=oookJ_oonf[oo`2Z1ooUo`08oookJP05obT0oooonf[o
oo]ZoookJ_l0oo002OoonfX00oooj03oo`0;oookJP04oookJP03oole0?oonf[o087o00;ooo]Z1OoU
o`000olfo`3ooo]ZoookJP0=oookJP04o`3Soooonf[ooo]Zool0k0gooo]Z00?o0?o]oookJ_oonfX0
2OoonfX5onGo0003oad0oooonf[ooo]Z00;ooo]Z0_oo0;@2oookJP03oonW0?oonf[ooo]Z00Oooo]Z
0_l0o`T4oookJPCoU?l00_ldo`000onDo`3o00_oo`0;o`02ool060?ooo]Z0on`o`001?oonf[o0?_o
o`3kool0nol8oookJQ3oA?l00_m>0?l6odCo00[oU?l00ol02ol3ocCo00?ooo]Z0_l0o`T4oookJP;o
ojL00_oonfX2oad0o`07oolJ0?oob@3oolT0ooo90?l0003ooo]Zo`3ok@05oookJP03ool0k?l0hooo
oo]Z00Gooo]Z00Co0?oXoookJ_lgo`3oocD01?nDo`000ol0oo3o:@3ooookJP03oookJP04oeT0oooo
0:[ooo]Zo`3oC@?ooo]Z00Koo`d0oookJ_ooh`3oK03ooookJ_mRo`0:oookJP09on;o0?oonf[oF_l0
oookJ_oUo`3ooo]Zool0m_l00ooooo]Z00OoU?l000?oN@3ooiCo0?oonfX01?oonfX01?l0X_oookl0
oookJ_l0oj82oookJP05o`3o8Ooonf[ooo]ZoookJ_nDo`000ooonfX00ooo0:3oU?l0oiCo0004oiCo
0003obX0oooonf[ooo]Z00;ooo]Z00CoNol0oookJ_oonf[ood400ooonfX00ol0ocSo203ooookJP07
oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oU?l0oookJ_oonfX03?oonfX00ol0okGooo]ZoookJP03
oookJP03o`3oRooonf[ooo]Z013ooo]Z00Coo`1?oookJ_oonf[o0?nF1ooonfX01Ooo703ooo]Zoook
J_oonf[o^?l000cooo]Z00?od_l0oookJ_oMo`000_oonfX00ol[0?oooo]ZoookJP03oookJP04ool0
0?oonf[oo`2Yonco00Cooo]Z00?oT`3ooookJ_oonfX0AooonfX01Ol0odgooo]ZoookJ_oonf[oo`2Z
00?ooo]Z00?oF@3ooookJ_oonfX02?oonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z
00Oooo]Z00?oonP0ool02ooonfX01?oonfX01Ooo=@3o=ol0o`21oooonf[o0?nG00;ooo]Z00?o0?oX
oookJ_lfo`003ooonfX01?l0hooooo]ZoookJ_oo0>`>oookJP03o`3okOoonf[ooo]Z00cooo]Z00?o
oaX0oad0ool0oo801?oonfX2ool0]003oookJ_ooY`3ooo]Z00Sooo]Z0_l0o`T7oookJP05og`0oold
o`3o=?l0o`0]oooo04l00_l02ol2ool060;ooo]Z1?n`o`03o`3ko`_ooo]Z5?m>0?l2oookJP?o0?_o
0on`o`03oookJP?o00_o0oldo`000oml0?oooo]ZoookJP02o`3o2@Cooo]Z0_ooY`03oookJP03oad0
oooo6P3o000000?o000000?ooo]Zo`3okOoonfX01?oonfX00ooo0>cooo]Zo`3So`05oookJP0;ocKo
0?l0onSo=ol0o`21oooo=@3oo`0;oooX0?oonf[o0?o`oookJ_lY0?l00ooonfX01?mI0?ooo`2Zoook
J_l0odd4oookJP05ool=0?ooh`3ooo]Zof`0oomRo`002_oonfX02?oRo`3ooo]Zoe[o0?oonf[o0?nn
oookJ_oo0?Ko00?o0_oonfX02?l0odSooo]ZoookJ_oonf[o0?mgoookJ_mi0?ooUol01OoonfX01?l0
X_oookl0oookJ_l0oj82oookJP06o`3o8Ooonf[ooo]ZoookJ_oo0?;o0?mF0_oonfX01Ooo0:3ooo]Z
oookJ_mD0?oo02Go00;ooo]Z00?o:P3oool:0?oonfX00_oonfX01Omko`3ooo]ZoookJ_ooW03ood40
00?ooo]Z00?o0?lhoookJ_oonfX01_oonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z
00gooo]Z00?o0?neoookJ_oonfX00_oonfX00ol0oh_ooo]ZoookJP0AoookJP03ool0Cooonf[o0?nF
00Oooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP06om;o0?oonf[ooo]Zomgo0?oonf[o:`3o
1OoonfX01OooV`3oo`00ool0ZOoonf[ok?l000Cooo]Z00?oT`3ooookJ_oonfX08OoonfX002Sooo]Z
00Co0?m=oookJ_oonf[oo`2Z2?oUo`08oookJP05obT0oooonf[ooo]ZoookJ_l0oo002OoonfX00ooo
j03ooo]ZoookJP04oookJP04oole0?l0POoooo]ZoookJPKoiOl000?o=_l0oookJ_oonfX03?oonfX0
1?l0hooooo]ZoookJ_oo0>`=oookJP03o`3okOoonf[ooo]Z00Wooo]Z1?oUo`02oad0o`05onGo0?oo
nf[ooo]ZoookJ_oo0;@00_oonfX2oonW00Sooo]Z0_l0o`T6oookJP04oiCo0?ldo`3o=?l0ocCo00;o
U?l000?o00_ooiCo0?oonfX00ooonfX2ok3o0004oookJ_l0nooo0?_oo`3ko`Kooo]Z1Om>0?l2odCo
00Cooo]Z5om4o`08oiCo00?o00_o0_ldo`000ol0;Ooooo]ZoookJP02o`3o2@Cooo]Z00KoojL0ool0
]?oonf[ooo]Zoad0oooo6P03ooo900;ooo]Z0_l0ond4oookJP03ool0k?l0hooooo]Z00Gooo]Z00?o
0?oXoiCo0?oo=@001OnDo`000ol0oo3o:@3ooookJP03oookJP03oeT0oooo0:[o0?m=00Cooo]Z00Ko
o`d0oookJ_ooh`3oK03ooookJ_mRo`0:oookJP04on;o0?oonf[oF_l0onGo00;ooo]Z00?o00?ooook
J_nDo`001_nDo`000omi0?ooU?l0oookJP04oookJP07o`2Roooo_`3ooo]Zo`3oX_l0S?oooo]Zo`3o
8@03oookJP06oiCo0?l0oeKooo]ZoookJ_nDo`3oo`2P1OnDo`000ol0C?oo:P3ooookJP02oookJP05
og_o0?oonf[ooo]ZoonL0?oo@@000_oonfX00ol0ocSo203ooookJP08oookJP05oolP0?oonf[ooo]Z
oookJ_nDo`003_oonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z013ooo]Z00Coo`1?
oookJ_oonf[o0?nF1ooonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00?od_l0oookJ_oMo`00
0_oonfX00ol[0?oooo]ZoookJP03oookJP04ool00?oonf[oo`2Yonco00Cooo]Z00?oT`3ooookJ_oo
nfX0A_oonfX01Ol0odgooo]ZoookJ_oonf[oo`2Z00?ooo]Z00?oF@3ooookJ_oonfX02OoonfX00olY
0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0ool02ooonfX01?oonfX01Ooo
=@3o=ol0o`21oooonf[o0?nG00?ooo]Z00?o0?oXoookJ_lfo`003_oonfX01?l0hooooo]ZoookJ_oo
0>`>oookJP03o`3okOoonf[ooo]Z00cooo]Z0_lM0?l00ol0oo;ooo]ZoookJP02oookJP04ool0]?oo
nf[oojL0oonW00Sooo]Z0_l0o`T7oookJP05og`0ooldo`3o=?l0oookJ_oo04l00_l02ol01?oo01So
oo]ZoookJ_oonfX2ok3o0004oookJ_l0nooo0?_oo`3ko`Oooo]Z1om>0?lDoookJPGoCP3o1?l0nol2
ok3o00?ooo]Z0ol02ol2ocCo0003og`0oooonf[ooo]Z00;o0?l91?oonfX2oonW00;ooo]Z0_lM0?l3
o`0000;ooo]Z0_l0ond4oookJP03ool0k?l0hooooo]Z00Gooo]Z00Ko=_l0o`3oj?l0POooocD0oook
J_ooj002oookJP03o`3ol?oonf[o:@3o00?ooo]Z00CoF@3oool0Z_oonf[o0?m=1?oonfX01Ooo3@3o
on<0of`0oooonf[oH_l000[ooo]Z00Coh_l0oookJ_mJo`3o0?nn0_oonfX01Ooo0?Ko00?ooookJ_oo
nf[o0?m800;ooo]Z00Co0?mgoookJ_mi0?ooUol01_oonfX01_oo_`3ooo]ZoookJ_l0oj;ooo]Zo`3o
8@?ooo]Z00?oo`3bo`3oE_oonfX00_oonfX01?oo0:3ooo]ZoookJ_mD0?l3oookJP03obX0oooo2P3o
oo]Z00;ooo]Z00CoNol0oookJ_ooW03ood400ooonfX00ol0ocSooo]ZoookJP07oookJP03oolP0?oo
nf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX03?oonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooo
nf[ooo]Z013ooo]Z00?oo`1?oookJ_l0oiH01ooonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z
00Kod_l0oookJ_oonf[ogOl0oookJ_l[0?l5oookJP05oonK0?oo003oo`2YoookJ_o/o`001?oonfX0
0onC0?oooo]ZoookJP0QoookJP009ooonfX01Ol0odgooo]ZoookJ_oonf[oo`2Z00;ooo]Z1_oUo`07
oookJP05obT0oooonf[ooo]ZoookJ_l0oo002OoonfX00oooj03oo`0;oookJP04oookJP04oole0?oo
b@3o087ooookJPKoiOl000?o=_l0oookJ_oonfX03OoonfX00ol0hooooo]Zool0k00=oookJP03o`3o
kOoonf[ooo]Z00Sooo]Z1OoUo`000olM0?ooiOl0onGo0004oookJP03ool0]?oonf[oojL000Wooo]Z
00?o0?l9oookJ_oonfX01?oonfX00oml0?oo=?l0ocCo0003oiCo00;o00_o00CoU?l0oookJ_oonf[o
oo]Z0_n`o`03o`3ko`Cooo]Z1Om>0?l9oookJP03ool05?m4o`3oA?l000koA?l00_oo01@<odCo00;o
/?l00onDo`02o`0;o`;o=?l000?o02gooookJ_oonfX00_l0o`T3oookJP;oojL000Cooo]Zooo90?lM
0?oo7@3o0ooob@03oookJP03o`3okOoonf[ooo]Z00;ooo]Z00?oo`3/o`3SoooonfX01OoonfX00ol0
onSoU?l0oole0005oiCo0003o`3ol?lY0?oooo]Z00;ooo]Z00CoF@3ooookJ_oo0:[o0?m=0ooonfX0
1?oo3@3ooo]ZoooS0?m/0?l2oookJP03of;o0?oonf[ooo]Z00Oooo]Z00Woh_l0oookJ_mJo`3ooo]Z
onGo0?oonf[oo`3fo`03oooonfX01onDo`000omi0?ooUol0oookJP04oookJP06o`2Roooo_`3o0?nR
o`2<oooonf[o0?lQ0ooonfX00onDo`3o0?mFoookJP02oookJP03ool0X?nDo`3oU?l000CoU?l000?o
:P3ooookJ_oonfX00_oonfX01?mko`3ooo]ZoookJ_oo@@02oookJP03o`3o>?oonf[o203o00Sooo]Z
00Goob00oookJ_oonf[ooo]ZoiCo000>oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oo
nfX03ooonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Kooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000=
oookJP05om;o0?oMo`3ooo]ZoookJ_l[0?l01OoonfX01?oo003ooo]Zool0ZOo/o`04oookJP03oi<0
oooonf[ooo]Z04Gooo]Z00Go0?m=oookJ_oonf[ooo]Zool0ZP04oookJP03oeT0oooonf[ooo]Z00So
oo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP06oookJP03oooX0?oonf[oo`0;00Go
oo]Z00GoocD0oookJ_l0POoooo]Zo`3oU`02oookJP03o`3oj?oonf[o=_l000oooo]Z00?o0>?ooook
J_oo0>`03_oonfX00ol0ongooo]ZoookJP0<oookJP03oad0ool0oo;o0?ob00Gooo]Z00?oo`2doonW
0?oonfX02?oonfX00ol0o`Wooo]ZoookJP05oookJP05og`0ooldo`3o=?l0oookJ_oo04l00_l02ol0
1?oo01Sooo]ZoookJ_oonfX2ok3o00?o0?_o1OoonfX5odh0o`Sooo]Z5?oo01@4oookJPCoCP3o0ol0
nol2ok3o00;ooo]Z00?oo`0Ho`0;ool02ol00_ldo`000oml0?oooo]ZoookJP02o`3o2@Cooo]Z00Co
ojL0oookJ_oonf[o00000_lM0?l00ol0003ooo]ZoookJP02oookJP03o`3okOoonf[ooo]Z00;ooo]Z
00?oo`3/o`3SoooonfX01OoonfX01_lfo`3o0?oXo`21oooo=@3oo`0;oooX00;ooo]Z00?o0?o`oook
J_lY0?l00_oonfX01?mI0?oooo]Zool0Z_l0odd4oookJP06ool=0?ooh`3ooo]Zof`0oooonf[oH_l0
2_oonfX01ooRo`3oF_l0oookJ_l0okkooo]Zool0m_l00ol00_oonfX01?l0odSooo]ZoookJ_l0ogL2
oookJP03ogT0oonGo`3ooo]Z00Cooo]Z00Co0:;ooono0?oonf[o0?nR0_oonfX01_l0ob7ooo]Zoook
J_oonf[oo`3bo`3oEP;ooo]Z00Coo`2PoookJ_oonf[oE03o0ooonfX00olZ0?ooo`X0oookJP02oook
JP05og_o0?oonf[ooo]ZoonL0?oo@@000_oonfX00ol0ocSo203ooookJP07oookJP03oolP0?oonf[o
oo]Z00;ooo]Z00?oo`2eoookJ_oonfX03?oonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[o
oo]Z013ooo]Z00Coo`1?oookJ_oonf[o0?nF1_oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000gooo]Z
00God_l0oookJ_oMo`3ooo]Zob/0o`06oookJP04ool00?oo0:Wooo]Zonco00Cooo]Z00?oT`3ooook
J_oonfX08OoonfX002Oooo]Z00Go0?m=oookJ_oonf[ooo]Zool0ZP03oookJPCoiOl02?oonfX01OlY
0?oooo]ZoookJ_oonf[o0?o`00Sooo]Z00?oonP0ool02ooonfX01?oonfX01?oo=@3ooo]Zo`21oooo
nfX7onGo0003ocKo0?oonf[ooo]Z00cooo]Z00?o0>?ooookJ_oo0>`03OoonfX00ol0ongooo]Zoook
JP07oookJPKoiOl000Co7@3oonGo0?oUo`3oiOl00ooonfX00ooo0;Cooo]ZoonW0009oookJP03o`3o
2Ooonf[ooo]Z00Cooo]Z0_ldo`02oookJP04oiCo0?l02ooo00_ooiCo00?ooo]Z00Co/?l0o`3kool0
nooo0?_o1OoonfX2odh0o`Oooo]Z1ooo01@00ooonf[oA?l0odCo000@odCo00Goo`0D00?oU?l0odCo
0?m4o`001Om4o`000ol0nooo/?l0ok3o0002oookJP03ool06?l02ooo00_o00;o=?l00ooonfX01Ol0
o`Wooo]ZoookJ_oonf[oU?l000;oojL00_oob@000olM0?oooaX0ooo90003oookJP03oiCo0?l0ongo
oo]Z00?ooo]Z00?oo`3/o`3SoooonfX01?oonfX01?l0onSoU?l0oiCo0?oo=@05oiCo0003o`3ol?lY
0?oooo]Z00;ooo]Z00CoF@3oool0Z_oonf[o0?m=0ooonfX01_oo3@3ooo]ZoooS0?m/0?oooo]Zof;o
00[ooo]Z00Ooh_l0oookJ_mJo`3oiOl0oookJ_oo0?Ko00?o00;ooo]Z1_nDo`000omi0?ooUol0oook
JP04oookJP07o`2Roooo_`3ooo]Zo`3oX_l0S?oooo]Zo`3o8@03oookJP03oiCo0?oonf[ooo]Z00;o
U?l000?oo`2PoiCo0?nDo`000onDo`000olZ0?oooo]ZoookJP02oookJP04og_o0?oonf[ooo]Zoom1
00?ooo]Z00?o0?lho`P0oooonfX01ooonfX00ooo803ooo]ZoookJP02oookJP03oiCo0?oonf[ooo]Z
00cooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0?oookJP05ool0Cooonf[ooo]Z
oookJ_l0oiH01ooonfX01?oo703ooo]ZoookJ_nho`0=oookJP05om;o0?oonf[ogOl0oookJ_l[0?l0
1OoonfX01?ooV`3oo`00ool0ZOo/o`04oookJP03oi<0oooonf[ooo]Z04Gooo]Z00Go0?m=oookJ_oo
nf[ooo]Zool0ZP03oookJP03oeT0oooonf[ooo]Z00Wooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0
oo3ooo]ZoookJP06oookJP03oooX0?oo00_ooo]Z00Cooo]Z00GoocD0ocOo0?l0POoooo]Zo`3oU`03
oookJP03o`3oj?oonf[o=_l000kooo]Z00?o0>?ooookJ_oo0>`03_oonfX00ol0ongooo]ZoookJP0<
oookJP03oad0ool0oo;ooo]Z00Gooo]Z00?oo`2doonW0?oonfX02?oonfX00ol0o`Wooo]ZoookJP04
oookJP04o`0]ooldo`3o=?l0oookJP;oo`1?00?o00_ooookJ_oonfX00_oonfX01?n`o`3o0?_oo`3k
ool0nol5oookJP?oCP3o1_oonfX7ool050?ooo]Z2oooa`06oookJPGoo`0D0ooonfX3odh0o`?o0?_o
00Co/?l0oookJ_oonf[ooo]Z0_l02ol2ocCo0004og`0oooonf[ooo]Zo`3o2@Cooo]Z0_ooY`02o`00
0003oolJ0?lM0?oooo]Z00Cooo]Z00?o0?o]oookJ_oonfX00_oonfX00ooo0>co0>?ooookJP05oook
JP06o`3oj?l0oiOo087ooole0?oo00_oonP00_oonfX00ol0oo3o:@3ooookJP02oookJP04oeT0oooo
0:[ooo]Zo`3oC@Cooo]Z00Goo`d0oooS0?m/0?oooo]Zof;o000:oookJP04on;o0?oonf[oF_l0o`3o
_P;ooo]Z00Goo`3fo`03oooonf[ooo]Zo`3oB002oookJP04o`3oMooonf[oN@3ooiOo00Kooo]Z00Ko
okl0oookJ_l0oj;o08cooookJ_l0ob43oookJP03ool0l_l0oeKooo]Z00;ooo]Z00Coo`2PoookJ_mD
0?oo02Go0_oonfX00olZ0?ooo`X0oookJP02oookJP05og_o0?oonf[ooo]ZoonL0?oo@@000ooonfX0
0ol0ocSooo]ZoookJP06oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX03OoonfX0
0ol0okGooo]ZoookJP02oookJP03o`3oRooonf[ooo]Z013ooo]Z00Coo`1?oookJ_oonf[o0?nF1ooo
nfX01?oo703ooo]ZoookJ_nho`0=oookJP05om;o0?oonf[ogOl0oookJ_l[0?l01_oonfX01?ooV`3o
o`00oookJ_o/o`04oookJP03oi<0oooonf[ooo]Z027ooo]Z000VoookJP05o`3oCOoonf[ooo]Zoook
J_oo0:X01?oonfX01?oUo`3ooo]ZoookJ_oUo`07oookJP05obT0oooonf[ooo]ZoookJ_l0oo002Ooo
nfX00oooj03oo`0;oookJP04oookJP03oole0?oob@3o087o00SoiOl03_oonfX00ol0hooooo]Zool0
k00>oookJP03o`3okOoonf[ooo]Z00Kooo]Z1ooUo`000olM0?ooiOl0onGo0003oookJP03ool0]?oo
nf[oojL000Wooo]Z00?o0?l9oookJ_oonfX00ooonfX2ocCo00;oiOl000?oo`1?o`0;ool02ol00_nD
o`02oookJP03ok3o0?l0nooo0?_o00Kooo]Z0_m>0?l4oookJPGoo`0D00?ooo]ZodCo0?m4o`000om4
o`02ooo700SoA?l01?oonfX7ooo700CoU?l01?oo01@00onDo`3ooo]ZoookJP02odh0o`?o0?_o0_n`
o`001?oonf[oo`0Ho`0;ool02ol2ocCo00;ooo]Z0_l0o`T01Ooonf[oU?l0ooo90?oob@3oojL000;o
olT000Co7@3ooolJ0?oob@3ooo]Z0_nDo`000ooonf[o0?o]oookJP03oookJP03ool0k?l0hooooo]Z
00;ooo]Z0_nDo`001?l0onSoU?l0oiCo0?oo=@04oiCo0003oookJ_l0oo3o:@3o00?ooo]Z00CoF@3o
ool0Z_oonf[o0?m=0ooonfX01_oo3@3oon<0oookJ_m/0?oooo]Zof;o00Wooo]Z00Coh_l0oookJ_mJ
o`3oiOl00_oonfX2onGo0003oookJ_l0odSoU?l000GoU?l000?oN@3ooiCo0?oonfX01?oonfX01_l0
X_oookl0o`3oX_l0S?oooo]Zo`3o8@?ooo]Z00?oU?l0o`3oE_oonfX00_nDo`000ooo0:3oU?l0oiCo
0003oiCo0003obX0oooo2P3ooo]Z00;ooo]Z00GoNol0oookJ_oonf[ooi`0oom10002oookJP03o`3o
>?l80?oooo]Z00Sooo]Z00Goob00oookJ_oonf[ooo]ZoiCo000>oookJP03o`3o]Ooonf[ooo]Z00?o
oo]Z00?o0?n;oookJ_oonfX03ooonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Oooo]Z00Cooa`0oook
J_oonf[o^?l03OoonfX01OoBo`3ooo]Zomgo0?oonf[o:`3o00Gooo]Z00Cooi/0ool00?oo0:Wok?l0
1?oonfX00onC0?oooo]ZoookJP14oookJP05o`3oCOoonf[ooo]ZoookJ_oo0:X01?oonfX00omI0?oo
oo]ZoookJP08oookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01_oonfX00oooj03o
oo]Zool02`04oookJP06oole0?lgo`3ooo]Zo`21oooonf[o0?nG0_oonfX00ol0onSooo]ZocKo000>
oookJP03o`3Soooonf[oo`3/00oooo]Z00?o0?o]oookJ_oonfX02ooonfX00ooo6P3o7@3ooookJP05
oookJP03ool0]?ooY`3ooo]Z00Sooo]Z00?o0?l9oookJ_oonfX01?oonfX2ocCo0003oookJ_oo04oo
o`1?00;o00_o0ooonfX00on`o`3o0?_oo`3ko`06oookJP;oCP3o1?oonfX5ool050;ooo]Z2?ooa`0;
oookJPOoolL01?oonfX4ool050;ooo]Z0om>0?l3o`3ko`03ok3o0?oonf[ooo]Z00;o00_o0_ldo`00
1?ml0?oooo]Zo`3o2Ol0o`T4oookJP05oonW0?l0003o0000o`3ol_lM0?l01OoonfX00ol0ongooo]Z
oookJP02oookJP03ool0k?l0hooooo]Z00Cooo]Z00Oo=_l0o`3oj?l0oiOo087ooole0?oo00_oonP0
00;ooo]Z00?o0?o`obT0oooonfX00_oonfX01?mI0?ooo`2ZoookJ_l0odd4oookJP05oooS0?oonf[o
K03ooookJ_mRo`002_oonfX00ooRo`3oF_l0o`3o_P02oookJP05ool0m_l00ooooo]ZoookJ_l0odP0
0_oonfX01Ol0ogOooo]ZoookJ_mi0?ooUol000Gooo]Z00Ko0:;ooono0?oonf[o0?nRoookJ_l0ob43
oookJP03ool0l_l0oeKooo]Z00;ooo]Z00Coo`2PoookJ_oonf[oE03o0_oonfX00olZ0?oo04coool:
0003oookJP04og_o0?oonf[ooi`0oom100?ooo]Z00?o0?lhoookJ_oonfX01ooonfX01Ooo803ooo]Z
oookJ_oonf[oo`2e00oooo]Z00?o0?neoookJ_oonfX00_oonfX00ol0oh_ooo]ZoookJP0@oookJP04
ool0Cooonf[ooo]Zo`3oUPOooo]Z00Cooa`0oookJ_oonf[o^?l03OoonfX01OoBo`3ooo]Zomgo0?oo
nf[o:`3o00Kooo]Z00Cooi/0ool00?oonf[ok?l01?oonfX00onC0?oooo]ZoookJP0QoookJP009Ooo
nfX00ol0odgooo]ZoookJP02oookJP05ool0Z_oonf[ooo]ZoookJ_oUo`002_oonfX00olY0?oooo]Z
oookJP02oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0ool02ooonfX01?oonfX00ooo=@3oolT0
o`21o`08onGo00kooo]Z00Co0>?ooookJ_oonf[oo`3/3OoonfX00ol0ongooo]ZoookJP07oookJPKo
iOl000?o7@3oonGo0?oUo`000ooonfX00ooo0;CoojL0oonW0009oookJP03o`3o2Ooonf[ooo]Z00;o
oo]Z0_ldo`001Oml0?ooiOl0ool0Cooo04oo00_o00;ooo]Z00GoU?l0oookJ_n`o`3o/?l0o`3ko`05
oookJP?oCP3o1?oonfX2ool050Cooo]Z0_ooa`0<odCo00?oiOl02ooonfX8oiCo00?oo`0D0ooonfX2
odh0o`;o0?_o0_n`o`001?oonf[oo`0Ho`0;ool02ol2ocCo00;ooo]Z0onDo`02ooo90003oonW0?oo
0;CoolT000;o7@3o1?nDo`000ooonf[o0?o]oookJP03oookJP03ool0k?l0hooooo]Z00?ooo]Z00Go
U?l0o`3oj?nDo`3oU?l0oole0004oiCo0003o`3ol?lY0?oooo]Z00;ooo]Z00GoF@3oool0Z_oonf[o
oo]Zo`3oC@03oookJP05ool=0?ooh`3oK03ooookJ_mRo`002_oonfX00ooRo`3ooo]Zoe[o0004onGo
00;ooo]Z00?o0?m8oiCo0?nDo`000onDo`000omi0?ooU?l0oookJP04oookJP06o`2Roooo_`3ooo]Z
o`3oX_oonf[o0?lQ0ooonfX01?nDo`3o0?mFoookJ_oonfX2oiCo0003ool0X?nDo`3oU?l000;oU?l0
00?ooo]ZobX0oooonfX00ooonfX01?mko`3ooo]ZoookJ_oo@@02oookJP03o`3o>?oonf[o203o00So
oo]Z00Goob00oookJ_oonf[ooo]ZoiCo000>oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oook
J_oonfX03_oonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Oooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo
000<oookJP03om;o0?oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX00_oonfX01?ooV`3oo`00oook
J_o/o`04oookJP03oi<0oooonf[ooo]Z04?ooo]Z00?o0?m=oookJ_oonfX00_oonfX01Ooo0:[ooo]Z
oookJ_oonf[oF@3o00[ooo]Z00?o:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP06oookJP03
oooX0?oo00_ooo]Z00Cooo]Z00GoocD0ocOo0?l0POoooo]Zo`3oU`02oookJP03o`3oj?oonf[o=_l0
00kooo]Z00Co0>?ooookJ_oonf[oo`3/3_oonfX00ol0ongooo]ZoookJP0;oookJP03oolJ0?lM0?oo
oo]Z00Gooo]Z0_ooY`09oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z0_ldo`000ooonf[oo`1?ool0C`02
o`0;o`?ooo]Z0_n`o`000ol0nooooo]ZoookJP04oookJP;oCP3o1?oonfX2ool050Cooo]Z0oooa`0J
oookJPGoolL00ooonfX3ool050;ooo]Z0_m>0?l01?oonf[o0?_oo`3koon`o`02oookJP;o00_o0_ld
o`02oookJP;o0?l90_oonfX01_l0003oojL0ool0]?l0003o0?oboad0o`Gooo]Z00?o0?o]oookJ_oo
nfX00_oonfX00ooo0>co0>?ooookJP04oookJP06ocKo0?l0onSo=ol0o`21oooo=@3oonP00_oonfX0
0ol0oo3ooo]ZobT0o`02oookJP05oeT0oooonf[oo`2ZoookJ_l0odd01?oonfX01?ooh`3ooo]Zof`0
oomRo`0:oookJP04on;o0?oonf[oF_l0o`3o_P;ooo]Z00Co00?ooookJ_oonf[o0?m80ooonfX01?l0
ogOooo]ZogT0oonGo`05oookJP04o`2Roooo_`3ooo]Zo`3oXP;ooo]Z00Ko0?lQoookJ_oonf[ooo]Z
ool0l_l0oeH3oookJP04ool0X?oonf[oE03oo`0Uo`;ooo]Z00?o:P3oool:0?oonfX00_oonfX01?mk
o`3ooo]ZoookJ_oo@@03oookJP03o`3o>?l80?oooo]Z00Oooo]Z00?oob00oookJ_oonfX00_oonfX0
0ooo0;Gooo]ZoookJP0<oookJP03o`3o]Ooonf[ooo]Z00?ooo]Z00?o0?n;oookJ_oonfX03ooonfX0
1?oo04oooo]ZoookJ_l0oiH7oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX00ooBo`3ooo]Z
omgo0002oookJP03ob/0oooonf[ooo]Z00?ooo]Z00Cooi/0ool00?oo0:Wok?l01?oonfX00onC0?oo
oo]ZoookJP0QoookJP00:OoonfX01Ooo0:[ooo]ZoookJ_oonf[oiOl000_ooo]Z00Go:@3ooookJ_oo
nf[ooo]Zo`3ol008oookJP03oooX0?oonf[oo`0;00Gooo]Z00?oocD0o`21oooob@000_oonfX6onGo
00gooo]Z00Co0>?ooookJ_oonf[oo`3/3OoonfX00ol0ongooo]ZoookJP09oookJPCoiOl000Co7@3o
onGo0?oUo`3oiOl00_oonfX00ooo0;CoojL0oookJP09oookJP08o`3o2Ooonf[ooo]ZoookJ_oUo`3o
=?l0og`0oooUo`02ool0C`;o00_o0ooonfX2ok3o00;o0?_o1?oonfX2odh0o`Gooo]Z0_oo01@3oook
JP?oolL00_oonfX@odCo00OoojP00_l007l00ooonf[oU?l0oiCo0009oiCo00?oo`0D0_l007l2odh0
o`;o0?_o0_n`o`001Ol007ooo`0Ho`0;ool02ooo=?l000GoU?l000Oo0000ooo90?ooY`3oo`2dooo9
0?nDo`3o7@3o00CoU?l000?ooo]Zo`3okOoonfX00ooonfX00ooo0>co0>?ooookJP03oookJP04oiCo
0?l0onSoU?l0oole00CoU?l000?ooo]Zo`3ol?lY0?l00ooonfX01?mI0?ooo`2ZoookJ_l0odd3oook
JP06ool=0?oonf[oon<0of`0oooonf[oH_l02OoonfX2onGo0003oe[o0?oUo`3oiOl000;oiOl00_oo
nfX00ol0odSooo]ZoiCo0003oiCo0003ogT0oonDo`3ooo]Z00Cooo]Z00Oo0:;ooono0?oonf[o0?nR
o`2<oooonf[o0?lQ00?ooo]Z00KoU?l0o`3oE_oonf[ooo]ZoiCo0?oo0:05oiCo0003obX0oooonf[o
oo]Z00;ooo]Z00CoNol0oookJ_oonf[ood400ooonfX00ol0ocSo203ooookJP07oookJP05oolP0?oo
nf[ooo]ZoookJ_nDo`003_oonfX00ol0okGooo]ZoookJP04oookJP03o`3oRooonf[ooo]Z00oooo]Z
00Goo`1?oookJ_oonf[ooo]Zo`3oUP06oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX00ooB
o`3ooo]Zomgo0002oookJP03ob/0oooonf[ooo]Z00;ooo]Z00Cooi/0ool00?oonf[ok?l01OoonfX0
0onC0?oooo]ZoookJP16oookJP05ool0Z_oonf[ooo]ZoookJ_mI0?l02ooonfX00olY0?oooo]Zoook
JP02oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0oookJ_oo00/01?oonfX00ooo=@3o=ol0o`21
o`02oookJP06o`3oUooonf[ooo]Zo`3oj?oonf[o=_l03OoonfX01?l0hooooo]ZoookJ_oo0>`>oook
JP03o`3okOoonf[ooo]Z00_ooo]Z00?ooaX0oad0ool0oo801OoonfX00oooY`3ooo]ZoookJP08oook
JP03o`3o2Ooonf[ooo]Z00?ooo]Z00Co=?l0og`0oooo04ooo`1?0_l02ol3oookJP;o/?l00_l0nol4
oookJP?oCP3o1?oonfX2ool050?ooo]Z0oooa`0>oookJP_oojP00_l007l4oookJP?o001o1?ooa`02
o`00O`?oo`0D00Co001oodh0oom>0?oooo]Z0_l0nol00on`o`3o001oo`00O`02o`0;o`;o=?l00_oo
nfX2o`3o2@;o000000CoojL0ool0]?oonf[o0?ob0_lM0?l4oookJP03o`3okOoonf[ooo]Z00;ooo]Z
00?oo`3/o`3SoooonfX01?oonfX01_lfo`3o0?oXo`21oooo=@3ooo]ZoooX00;ooo]Z00?o0?o`obT0
oooonfX00_oonfX01?mI0?ooo`2ZoookJ_l0odd4oookJP05ool=0?ooh`3oK03ooookJ_mRo`002_oo
nfX00ooRo`3oF_l0o`3o_P02oookJP05ool0m_l00ooooo]ZoookJ_l0odP00_oonfX01Ol0ogOooo]Z
ogT0oooo9`3oUol000Gooo]Z00Kookl0oookJ_oonf[o0?nRoookJ_l0ob43oookJP03ool0l_l0oeKo
oo]Z00;ooo]Z00Coo`2PoookJ_mD0?oo02Go0_oonfX00olZ0?ooo`X0oookJP02oookJP05og_o0?oo
nf[ooo]ZoonL0?oo@@000ooonfX00ol0ocSooo]ZoookJP06oookJP03oolP0?oonf[ooo]Z00;ooo]Z
00?oo`2eoookJ_oonfX03?oonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z00oooo]Z
00Goo`1?oookJ_oonf[ooo]Zo`3oUP06oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX01_oB
o`3ooo]ZoookJ_oMo`3ooo]Zob/0o`Gooo]Z00Cooi/0ool00?oo0:Wok?l01OoonfX00onC0?oooo]Z
oookJP0PoookJP00:OoonfX01Ooo0:[ooo]ZoookJ_oonf[oiOl000[ooo]Z00?o:@3ooookJ_oonfX0
0_oonfX00ol0oo3ooo]ZoookJP06oookJP03oooX0?oo00_ooo]Z00Cooo]Z00OoocD0ooo90?l0POoo
olT0oookJ_l0oiOooo]Z00GoiOl03OoonfX01?l0hooooo]ZoookJ_oo0>`=oookJP03o`3okOoonf[o
oo]Z00[ooo]Z0_oUo`001?lM0?ooiOl0onGo0?oUo`02oookJP03ool0]?ooY`3ooo]Z00Sooo]Z0_l0
o`T2oookJP;oiOl000Co=?l0og`0oooUo`3oo`1?0_l02ol3oookJP;o/?l000?ooo]Zo`3koooonfX0
0ooonfX2odh0o`Cooo]Z0ooo01@3oookJP;oolL01OoonfX?odCo00SoiOl02?ooZ009oiCo00;oo`0D
0_oonfX2odh0o`?o0?_o00?o/?l0o`00Oooo01P00_l02ol5oiCo00;o00000_ooY`000ooo0;CoU?l0
oad0o`03oiCo00;ooo]Z00?o0?o]oookJ_oonfX00_oonfX00ooo0>co0>?ooookJP03oookJP04oiCo
0?l0onSoU?l0oole00CoU?l000?ooo]Zo`3ol?lY0?l00_oonfX01OmI0?oooo]Zool0Z_oonf[o0?m=
00?ooo]Z00Koo`d0oooS0?oonf[oK03ooookJ_mRo`07oookJPCoiOl000?oF_l0onGo0?oUo`000_oU
o`02oookJP03o`3oB?nDo`3oU?l000?oU?l000?oN@3ooiCo0?oonfX01?oonfX01_l0X_oookl0o`3o
X_l0S?oooo]Zo`3o8@?ooo]Z00KoU?l0o`3oE_oonf[ooo]ZoiCo0?oo0:05oiCo0003obX0oooo2P3o
oo]Z00;ooo]Z00GoNol0oookJ_oonf[ooi`0oom10002oookJP03o`3o>?l80?oooo]Z00Sooo]Z00Go
ob00oookJ_oonf[ooo]ZoiCo000=oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX0
3ooonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Kooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oook
JP03om;o0?oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX00ooonfX00ooo003ooo]Zonco0005oook
JP03oi<0oooonf[ooo]Z04Kooo]Z00Goo`2ZoookJ_oonf[ooo]ZoeT0o`0:oookJP03obT0oooonf[o
oo]Z00?ooo]Z00?o0?o`oookJ_oonfX01OoonfX00oooj03ooo]Zool02`04oookJP06oole0?oonf[o
=ol0o`21oooonf[o0?nG0_oonfX00ol0onSooo]ZocKo000>oookJP04o`3Soooonf[ooo]Zool0k0ko
oo]Z00?o0?o]oookJ_oonfX02_oonfX00ooo6P3o7@3oo`3olP05oookJP03oonW0?oonf[ooo]Z00Oo
oo]Z0_l0o`T5oookJP03ocCo0?ml0?ooo`1?00;o00_o00?oo`0HoookJ_oonfX00_n`o`000ooonf[o
0?_ooookJP03oookJP;oCP3o1?oonfX3ool050?ooo]Z0_ooa`0;oookJPKoojP02ooo0:L8oonX0003
o`00Oooonf[o001o00;o001o1?ooa`001?l007ooo`0Dool05?oonfX3odh0o`?o0?_o00Co001oool0
6?l02ooo00_o0_ldo`02oookJP03o`3o2Ol0003o000000;oojL000Coo`2doookJ_l0oo;o7@3o1?oo
nfX00ol0ongooo]ZoookJP02oookJP03ool0k?l0hooooo]Z00Cooo]Z00Ko0?oXo`3oUol0POooocD0
oookJ_ooj002oookJP09o`3ol?lY0?oooo]ZoookJ_mI0?oooo]Zool0Z_oonf[o0?m=00Cooo]Z00Go
on<0oookJ_m/0?oooo]Zof;o0009oookJP04on;o0?oonf[oF_l0o`3o_P;ooo]Z00Co00?ooookJ_oo
nf[o0?m80ooonfX01?l0ogOooo]ZogT0oonGo`05oookJP06o`2Roooo_`3ooo]Zo`3oX_oonf[o0?lQ
0ooonfX00ooo0?;o0?mFoookJP02oookJP04ool0X?oonf[ooo]Zoe@0o`;ooo]Z00?o:P3oool:0?oo
nfX00ooonfX01?mko`3ooo]ZoonL0?oo@@03oookJP03o`3o>?oonf[ooo]Z00Oooo]Z00Goob00oook
J_oonf[ooo]Zool0]@0>oookJP03o`3o]Ooonf[ooo]Z00?ooo]Z00?o0?n;oookJ_oonfX03ooonfX0
1Ooo04oooo]ZoookJ_oonf[o0?nF00Kooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP06om;o
0?oonf[ooo]Zomgo0?oonf[o:`3o1OoonfX01?ooV`3oo`00ool0ZOo/o`05oookJP03oi<0oooonf[o
oo]Z023ooo]Z000XoookJP05ool0Z_oonf[ooo]ZoookJ_oUo`002_oonfX00olY0?oooo]ZoookJP02
oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0oookJ_oo00/01?oonfX00ooo=@3oolT0o`21o`02
ooo90005oookJ_l0oiOooo]ZonGo0?oonfX00_oUo`0=oookJP04o`3Soooonf[ooo]Zool0k0gooo]Z
00?o0?o]oookJ_oonfX02_oonfX00ooUo`3oogT0oad0o`04onGo0003oookJ_oo0;CoojL000Wooo]Z
00?o0?l9oookJ_oonfX00ooUo`001_ldo`3oO03oonGo0?oo04oo00_oonGo00?ooo]Z00Co/?l0oook
J_l0nooo0?_o0ooonfX2odh0o`Cooo]Z0_oo01@3oookJP?oolL01ooonfXCodCo00Koob401_nDo`04
oonX00KoU?l000?oolL0ool05?oo01@00ol007l2odh0o`;o0?_o0onDo`02o`0;o`?oU?l000Oo0?l9
o`000?nDo`3oU?l0oonW0?oo0;CoU?l000;o7@3o0_nDo`02oookJP07o`3okOoonf[ooo]ZoookJ_oo
0>cooo]Zo`3So`04oookJP04o`3oj?nDo`3oU?l0oole00?oU?l000Cooo]Zo`3ol?oonf[o:@3o0_oo
nfX01?mI0?ooo`2ZoookJ_l0odd4oookJP05ool=0?ooh`3oK03ooookJ_mRo`001ooonfX5onGo0004
oe[o0?oUo`3oiOl0onGo00;ooo]Z00?o0?m8oookJ_nDo`000onDo`000omi0?ooU?l0oookJP04oook
JP06o`2Roooo_`3ooo]Zo`3oX_oonf[o0?lQ0ooonfX00onDo`3o0?mFoiCo0008oiCo0003obX0oooo
2P3ooo]Z00?ooo]Z00CoNol0oookJ_oonf[ood400_oonfX00ol0ocSooo]Zo`P0o`08oookJP04ooo9
0?oonf[ooo]ZoookJPGoU?l02OoonfX00ol0okGooo]ZoookJP05oookJP03o`3oRooonf[ooo]Z00ko
oo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP06oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX0
0ooBo`3ooo]Zomgo0002oookJP03ob/0oooonf[ooo]Z00?ooo]Z00?oo`00oookJ_o/o`001OoonfX0
0onC0?oooo]ZoookJP15oookJP05ool0Z_oonf[ooo]ZoookJ_mI0?l02_oonfX00olY0?oooo]Zoook
JP03oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0oookJ_oo00/01?oonfX00ooo=@3o=ol0o`21
o`02oookJP05o`3oUooonf[o0?oXoookJ_lfo`003_oonfX01?l0hooooo]ZoookJ_oo0>`>oookJP03
o`3okOoonf[ooo]Z00[ooo]Z00?ooaX0oookJ_lM0?l01OoonfX00oooY`3ooo]ZoookJP07oookJP03
o`3o2Ooonf[ooo]Z00Cooo]Z00Co=?l0o`0]oooo04oo00_o0_oo01P2oookJP04ok3o0?oonf[o0?_o
o`3ko`?ooo]Z0_m>0?l4oookJP;oo`0D0ooonfX3ooo700Sooo]Z1OooZ0000ooo0:Oooo]ZoookJP06
oookJP[oob400_oo0;@4ool0Y`CoojP00_l007l3oookJP?oolL00_oo01@2o`00O`;oCP3o00Go001o
o`3kool0nooooo]Zool06002o`0;o`04ocCo0?oonf[o0000o`3o2@;o000000Kooo]ZoonW0?oo0;Co
oo]Zo`3ol_lM0?l4oookJP07o`3okOoonf[ooo]ZoookJ_oo0>cooo]Zo`3So`04oookJP0;ocKo0?l0
onSo0?nGo`21oooo=@3oonP0ool02ooonf[o0?o`oookJ_lY0?l00_oonfX01?mI0?oooo]Zool0Z_l0
odd5oookJP04oooS0?m/0?oooo]Zof;o00[ooo]Z00?oh_l0oookJ_mJo`000_oonfX01Ooo0?Ko00?o
oookJ_oonf[o0?m800;ooo]Z00Co0?mgoookJ_mi0?ooUol01_oonfX01_oo_`3ooo]Zo`2<ool0oj;o
oo]Zo`3o8@?ooo]Z00?oo`3bo`3oE_oonfX00_oonfX02?oo0:3ooo]Zoe@0ool09Ooooo]ZobX0ool0
C?ooo`X00ooonfX01?mko`3ooo]ZoookJ_oo@@03oookJP03o`3o>?l80?oooo]Z00Oooo]Z00Goob00
oookJ_oonf[ooo]Zool0]@0>oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX03ooo
nfX01?oo04oooo]ZoookJ_l0oiH6oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX01_oBo`3o
oo]ZoookJ_oMo`3ooo]Zob/0o`Gooo]Z00Cooi/0ool00?oo0:Wok?l01OoonfX00onC0?oooo]Zoook
JP0PoookJP00:?oonfX01Ooo0:[ooo]ZoookJ_oonf[oiOl000[ooo]Z00?o:@3ooookJ_oonfX00_oo
nfX00ol0oo3ooo]ZoookJP06oookJP03oooX0?oo00_ooo]Z00Cooo]Z00SoocD0o`21oooob@3oolT0
oookJ_l0oiOooo]ZonGo00;ooo]Z00?o=_l0onGo0?oonfX02ooonfX01?l0hooooo]ZoookJ_oo0>`=
oookJP03o`3okOoonf[ooo]Z00[ooo]Z00CoiOl0oomi0?lM0?ooogT00ooUo`000ooonf[oo`2doonW
0009oookJP03o`3o2Ooonf[oiOl000?oiOl000Ko=?l0og`0oooUo`3oo`1?o`0;oooUo`03oookJP03
ok3o0?oonf[o0?_o00Cooo]Z00?oCP3ooookJ_oonfX00_oonfX2ool050?ooo]Z0_ooa`05oookJP?o
A?l00oooZ00@odCo0004oookJ_l007oo001oo`00O`?ooo]Z00?o001ooolQ0?oo8@001_oo8@02ool0
Y`?oojP01?oonfX2ooo700?oo`0D0_oonfX00om>0?ooU?l0oiCo0004oiCo000:o`0;oonDo`3oU?l0
oiCo0?l0o`Wo0000oookJ_nDo`3oojL0ool0]0;oU?l000?o7@3ooiCo0?oonfX00_oonfX01ol0ongo
oo]ZoookJ_oonf[oo`3/oookJ_l0hol01?oonfX01?l0onSoU?l0oiCo0?oo=@03oiCo0004oookJ_l0
oo3ooo]ZobT0o`;ooo]Z00CoF@3oool0Z_oonf[o0?m=0ooonfX01_oo3@3oon<0oookJ_m/0?oooo]Z
of;o00Oooo]Z1?oUo`001OmJo`3oiOl0onGo0?oUo`3o00?o00;ooo]Z00?o0?m8oookJ_nDo`000_nD
o`000omi0?ooU?l0oookJP05oookJP07oono0?oonf[o0?nRo`2<oooonf[o0?lQoookJP0<oiCo0003
oookJ_lZ0?oooo]Z00?ooo]Z00CoNol0oookJ_oonf[ood400ooonfX00ol0ocSo203ooookJP07oook
JPWoU?l02_oonfX00ol0okGooo]ZoookJP04oookJP03o`3oRooonf[ooo]Z00kooo]Z00Goo`1?oook
J_oonf[ooo]Zo`3oUP06oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX00ooBo`3ooo]Zomgo
0002oookJP03ob/0oooonf[ooo]Z00?ooo]Z00?oo`00oookJ_o/o`001OoonfX00onC0?oooo]Zoook
JP15oookJP05ool0Z_oonf[ooo]ZoookJ_mI0?l02_oonfX00olY0?oooo]ZoookJP03oookJP03o`3o
l?oonf[ooo]Z00Gooo]Z00?oonP0oookJ_oo00/01?oonfX00ooo=@3ooo]Zo`21o`02oookJP06o`3o
Uooonf[ooo]Zo`3oj?oonf[o=_l03OoonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00gooo]Z00?o0?o]
oookJ_oonfX02_oonfX00ooo6P3ooo]Zoad0o`05oookJP03oonW0?oonf[ooo]Z00Oooo]Z00?o0?l9
oookJ_oonfX00ooonfX01_ml0?oo=?l0oookJ_oo04oo00_oool060?ooo]Z00?o/?l0oookJ_l0nol0
1?oonfX00om>0?oooo]ZoookJP02oookJP;oo`0D0ooonfX2ooo700Sooo]Z0oooZ002ool0Y`?ooo]Z
0ol007l6oolQ00;oo`2d00Cooo]Zo`00Ool007oo001o0ooonfX00ol007ooob40oolQ0006oolQ00;o
o`2W1?ooZ004oookJP;oolL00ooo01@03_oonf[oCP3oo`00Ool007oo0?_ook3o0?oonf[oo`0Ho`0;
ooldo`3oO03oo`000?l0o`Wo00000_oonfX01OooY`3oo`2doookJ_l0oo;o7@3o00Cooo]Z00Oo0?o]
oookJ_oonf[ooo]Zool0k?oonf[o0>?o00Cooo]Z00Ko=_l0o`3oj?l0oiOo087ooole0?ooj002oook
JP03o`3ol?oonf[o:@3o00;ooo]Z00CoF@3ooookJ_oo0:[o0?m=1?oonfX01Oooh`3ooo]Zof`0oooo
nf[oH_l000Wooo]Z00Ooh_l0oookJ_mJo`3o0?nnoookJ_oo0?Ko00?o00;ooo]Z00So0?m8oookJ_oo
nf[o0?mgoookJ_mi0?ooobL0oiOo00Gooo]Z00Kookl0oookJ_oonf[o0?nRoookJ_l0ob43oookJP03
ool0l_l0oeKooo]Z00;ooo]Z00Coo`2PoookJ_mD0?oo02Go0_oonfX00olZ0?ooo`X0oookJP02oook
JP05og_o0?oonf[ooo]ZoonL0?oo@@000ooonfX00ol0ocSooo]ZoookJP06oookJP03oolP0?oonf[o
oo]Z00;ooo]Z00?oo`2eoookJ_oonfX03?oonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[o
oo]Z00oooo]Z00Coo`1?oookJ_oonf[o0?nF1_oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z
00Kod_l0oookJ_oonf[ogOl0oookJ_l[0?l5oookJP04oonK0?oo003oo`2Yonco00Gooo]Z00?oT`3o
oookJ_oonfX08?oonfX002Oooo]Z00Goo`2ZoookJ_oonf[ooo]ZonGo000:oookJP03obT0oooonf[o
oo]Z00;ooo]Z00?o0?o`oookJ_oonfX01_oonfX00oooj03ooo]Zool02`04oookJP03oole0?oob@3o
087o00;oolT000Ko0?nGoookJ_oonf[oiOl0oookJ_lfo`0=oookJP05o`3Soooonf[ooo]ZoookJ_oo
0>`03?oonfX00ol0ongooo]ZoookJP09oookJP0<oomi0?oUo`3oogT0oomi0?lM0?ooogT0oookJ_oU
o`3ooo]Zool0]?oonf[oojL02?oonfX00ol0o`Wooo]ZonGo0003onGo0006ocCo0?oUo`3oiOl0ool0
Col02oooiOl00ooonfX00on`o`3ooo]Zo`3ko`04oookJP04odh0oooonf[ooo]ZoookJP;oo`0D1?oo
nfX00oooa`3ooo]ZoookJP05oookJP?oojP04?m4o`02o`00O`;ooo]Z0ol007l3oookJP?o001o1Ooo
nfX00ooo0;Coob40oolQ0002oolQ0004ool0YoooZ03oojP0oonX00?ooo]Z0oooa`02ool05003o`00
Oom>0?ooCP3o00GoU?l000Go00_ooiCo0?nDo`3oU?l0o`3o2@02o`000003oiCo0?ooY`3oo`2d00;o
U?l000?o7@3ooiCo0?oonfX00_oonfX01ol0ongooo]ZoookJ_oonf[oo`3/oookJ_l0hol01?oonfX0
1_l0onSoU?l0oole0?nDo`3ooo]ZoiCo00;ooo]Z00Wo0?o`obT0oooonf[ooo]ZoeT0oooonf[oo`2Z
oookJ_l0odd00ooonfX01Ooo3@3oon<0oookJ_m/0?ooH_l000Sooo]Z1?oUo`001?mJo`3oiOl0onGo
0?l00ol2oookJP03o`3oB?oonf[ooo]Z00?oU?l000?oN@3ooiCo0?oonfX01?oonfX01_l0X_oookl0
oookJ_l0oj;ooo]Zo`3o8@OoU?l000?ooo]ZoiCo0?nDo`000onDo`000ooonf[o:P3ooookJP03oook
JP05og_o0?oonf[ooo]ZoonL0?oo@@000_oonfX00ol0ocSo203ooookJP07oookJPWoU?l02_oonfX0
0ol0okGooo]ZoookJP04oookJP03o`3oRooonf[ooo]Z00kooo]Z00?oo`1?oookJ_oonfX00_oonfX0
0ol0oiKooo]ZoookJP03oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX01_oBo`3ooo]Zoook
J_oMo`3ooo]Zob/0o`Gooo]Z00Coo`00oookJ_o/o`3oo`2Y1?oonfX00onC0?oooo]ZoookJP14oook
JP05ool0Z_oonf[ooo]ZoookJ_mI0?l02_oonfX00olY0?oooo]ZoookJP03oookJP03o`3ol?oonf[o
oo]Z00Kooo]Z00?oonP0oookJ_oo00/01?oonfX00ooo=@3o=ol0o`21o`02oookJP05o`3oUooonf[o
0?oXoookJ_lfo`003OoonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00gooo]Z00?o0?o]oookJ_oonfX0
2_oonfX00ooo6P3ooo]Zoad0o`05oookJP03ool0]?ooY`3ooo]Z00Oooo]Z00?o0?l9oookJ_oonfX0
0ooonfX01_ml0?oo=?l0oookJ_oo04oo00_oool060?ooo]Z00?o/?l0oookJ_l0nol01?oonfX01?m>
0?oooo]ZoookJ_oonfX2ool050Cooo]Z00?oolL0oookJ_oonfX01OoonfX3oonX0003ool0Yooonf[o
oo]Z00Cooo]Z1?oo8@07o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX4oolQ00;oo`2W0oooZ003
oookJP?oolL00_oo01@2odh0o`06oookJ_l0nooo0?_ook3o0?oo01So00_o0_ldo`002_ml0?oo0?l9
o`3o2Ol0003ooo]ZoonW0?oo0;Cooo]Zo`3ol_lM0?l4oookJP07o`3okOoonf[ooo]ZoookJ_oo0>co
oo]Zo`3So`04oookJP06o`3oj?oonf[o087ooole0?oonf[oonP00_oonfX02Ol0oo3o:@3ooookJ_oo
nf[oF@3ooookJ_oo0:[ooo]Zo`3oC@04oookJP04oooS0?oonf[oK03oof;o00[ooo]Z00?oh_l0oook
J_mJo`000_oonfX01Ooo0?Ko00?ooookJ_oonf[o0?m800;ooo]Z00Co0?mgoookJ_mi0?ooUol01Ooo
nfX01?l0X_oookl0oookJ_l0oj82oookJP05o`3o8Ooonf[ooo]Zool0l_l0oeH00ooonfX02?oo0:3o
oo]ZoookJ_mD0?oo02GooookJ_lZ0?ooo`X00ooonfX01Omko`3ooo]ZoookJ_ooW03ood4000?ooo]Z
00?o0?lhoookJ_oonfX01_oonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z00cooo]Z
00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0?oookJP05ool0Cooonf[ooo]ZoookJ_l0
oiH01OoonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00Kod_l0oookJ_oonf[ogOl0oookJ_l[
0?l5oookJP04oonK0?oo003ooo]Zonco00Gooo]Z00?oT`3ooookJ_oonfX08?oonfX002Oooo]Z00Go
o`2ZoookJ_oonf[ooo]ZonGo000:oookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX0
1OoonfX00oooj03ooo]Zool02`04oookJP03oole0?oob@3o087o00?oolT000Go0?nGoookJ_oUo`3o
oo]ZocKo000>oookJP04o`3Soooonf[ooo]Zool0k0gooo]Z00?o0?o]oookJ_oonfX02?oonfX01Ooo
N@3oiOl0oomi0?ooN@3o7@3o00;oogT00_oonfX00ooo0;Cooo]ZoonW0008oookJP03o`3o2Ooonf[o
oo]Z00?oiOl000Go=?l0onGo0?oUo`3oo`1?o`0;o`02onGo00;ooo]Z00?o/?l0o`3kool0nol00ooo
nfX2odh0o`?ooo]Z00?oo`0DoookJ_oonfX00_oonfX2ooo700Gooo]Z0oooZ00AodCo00;oU?l01?oo
nfX3o`00O`?ooo]Z0ol007l9oookJP05ool0]?oo8@3oob40oolQ0?oo0:L00_ooZ004oookJP;oolL0
0_oo01@01?l007ooCP3oodh0ool0nol3oiCo0005o`0;oonDo`3oU?l0oiCo0?l0o`T00ooonfX01_oo
Y`3oo`2doiCo0?nDo`3o7@3ooiCo00?ooo]Z00Oo0?o]oookJ_oonf[ooo]Zool0k?oonf[o0>?o00?o
oo]Z00_o=_l0o`3oj?nDo`3oocD0oiCo0?oonf[oU?l0oookJ_l0oo3ooo]ZobT0o`02oookJP04oeT0
oooo0:[ooo]Zo`3oC@?ooo]Z00Koo`d0oooS0?oonf[oK03ooookJ_mRo`08oookJP?oiOl000GoF_l0
onGo0?oUo`3oo`3fo`03o`02oookJP03o`3oB?oonf[ooo]Z00;oU?l000CoN@3ooiCo0?oonf[ooo]Z
0_nDo`02oookJP05oono0?oonf[o0?nRoookJ_l0ob401onDo`02oookJPCoU?l000?ooo]ZobX0oooo
2P001?oonfX01?mko`3ooo]ZoookJ_oo@@02oookJP03o`3o>?oonf[o203o00Oooo]Z00?oolT0oiCo
0?nDo`001_nDo`0:oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX03_oonfX00ooo
04oooo]ZoookJP02oookJP03o`3oU_oonf[ooo]Z00?ooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000=
oookJP05om;o0?oonf[ogOl0oookJ_l[0?l01OoonfX01?oo003ooo]ZoookJ_o/o`04oookJP03oi<0
oooonf[ooo]Z04Cooo]Z00Goo`2ZoookJ_oonf[ooo]ZoeT0o`0:oookJP03obT0oooonf[ooo]Z00?o
oo]Z00?o0?o`oookJ_oonfX01OoonfX00oooj03ooo]Zool02`04oookJP03oole0?oonf[o087o00;o
oo]Z00Go0?nGoookJ_l0onSooo]ZocKo000>oookJP04o`3Soooonf[ooo]Zool0k0kooo]Z00?o0?o]
oookJ_oonfX02OoonfX00ooo6P3ooo]Zoad0o`05oookJP03ool0]?ooY`3ooo]Z00Oooo]Z00?o0?l9
oookJ_oonfX00ooonfX01Oml0?oo=?l0oookJ_oo04oo00_o00Cooo]Z00?o/?l0o`3kool0nol01?oo
nfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Cooo]Z0_ooa`05oookJP?oojP000?oo`2WoookJ_oonfX0
0ooonfX01?oo0;Coob40oolQ0?oo8@0=oookJP?o001o0ooonfX3o`00O`[ooo]Z0ooo8@02ool0Y`;o
ojP01?oonfX2ooo700;oo`0D0_m>0?l01?oonf[o0?_ook3o0?n`o`02o`0;o`04ocCo0?ml0?oooo]Z
o`3o2@;ooo]Z00GoojL0ool0]?oo0;Co0?oboad0o`04oookJP07o`3okOoonf[ooo]ZoookJ_oo0>co
oo]Zo`3So`03oookJP0;ocKo0?l0onSo0?nGo`21oooo=@3ooo]ZoooX0?oonf[o0?o`oookJ_lY0?l0
0_oonfX01?mI0?oooo]Zool0Z_l0odd4oookJP05oooS0?oonf[oK03ooookJ_mRo`002_oonfX01_oR
o`3oF_l0oookJ_oonf[oo`3fo`03o`;ooo]Z00Oo0?m8oookJ_oonf[o0?mgoookJ_mi0?ooUol000Ko
oo]Z00Kookl0oookJ_l0S?oo0?nRoookJ_l0ob43oookJP03ool0l_l0oeKooo]Z00;ooo]Z00Ooo`2P
oookJ_mD0?oo02GooookJ_lZ0?ooo`X000Cooo]Z00CoNol0oookJ_oonf[ood400ooonfX00ol0ocSo
203ooookJP06oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX03?oonfX00ol0okGo
oo]ZoookJP03oookJP03o`3oRooonf[ooo]Z00oooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP05oook
JP05oolL0?oonf[ooo]ZoookJ_nho`003OoonfX01OoBo`3ooo]Zomgo0?oonf[o:`3o00Kooo]Z00Co
o`00oookJ_oo0:Wok?l01?oonfX00onC0?oooo]ZoookJP0PoookJP009_oonfX01Ooo0:[ooo]Zoook
J_oonf[oiOl000[ooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP06oookJP03oooX
0?oo00_ooo]Z00?ooo]Z00CoolT0oole0?oob@3o087o0_oob@000ol0oiOooo]ZonGo0002oookJP03
ocKo0?oonf[ooo]Z00_ooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00<oookJP03o`3okOoonf[ooo]Z
00Sooo]Z0_ooN@000ooo6P3oogT0oad0o`02oomi00;ooo]Z00?oo`2doookJ_ooY`002?oonfX00ol0
o`Wooo]ZoookJP02oookJP04onGo0?ldo`3oiOl0onGo00;o00_o0_oUo`001?oonf[o/?l0ok3o0?l0
nol4oookJP03odh0oooonf[ooo]Z00;ooo]Z00Coo`0DoookJ_oonf[ooo]Z0_ooa`04oookJP?oojP0
00Cooo]Zool0Yooonf[ooo]Z0om4o`02oolQ00SoA?l03?nDo`0:o`3oU`;oA?l01OoonfX00ol007oo
o`2doolQ0002oolQ00?oojP00_oonfX00ol007ooolL0ooo70002ool05004oookJ_m>0?oooo]Zo`3k
o`;oU?l00_l02ol00onDo`3ooo]Zo`3o2@03oookJP05oonW0?oo0;CoU?l0oad0oonDo`001?oonfX0
1ol0ongooo]ZoookJ_oonf[oo`3/oookJ_l0hol00ooonfX01_l0onSooo]ZoiCo0?oo=@3ooo]ZoooX
00;ooo]Z00?o0?o`oookJ_lY0?l00_oonfX01?mI0?ooo`2ZoookJ_l0odd3oookJP06ool=0?ooh`3o
oo]Zof`0oooonf[oH_l02?oonfX3onGo0004oe[o0?oUo`3oiOl0o`03o`;ooo]Z00Ko0?m8oookJ_oo
nf[ooo]ZoiCo0?mi0?l5oiCo00;ooo]Z00Kookl0oookJ_l0oj;o08cooookJ_l0ob46oiCo00;ooo]Z
1?nDo`02oookJP03obX0oooonf[ooo]Z00;ooo]Z00CoNol0oookJ_oonf[ood400_oonfX00ol0ocSo
oo]Zo`P0o`08oookJPSoU?l02_oonfX00ol0okGooo]ZoookJP04oookJP03o`3oRooonf[ooo]Z00ko
oo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP04oookJP04oolL0?oonf[ooo]ZokSo
00gooo]Z00?od_l0oookJ_oMo`000_oonfX00ol[0?oooo]ZoookJP02oookJP04oonK0?oo003ooo]Z
onco00Gooo]Z00?oT`3ooookJ_oonfX0@_oonfX01Ooo0:[ooo]ZoookJ_oonf[oF@3o00[ooo]Z00?o
:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP05oookJP03oooX0?oonf[oo`0;00Cooo]Z00Co
ocD0oookJ_lgo`3o087o0_oonfX01Ol0oiOooo]Zo`3oj?oonf[o=_l000gooo]Z00Go0>?ooookJ_oo
nf[ooo]Zool0k00=oookJP03o`3okOoonf[ooo]Z00[ooo]Z00?ooaX0oad0ool0oo801?oonfX00ooo
0;CoojL0oookJP07oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z00?oO03oocCo0?oonfX00_l02ol3oook
JP;o/?l000?o0?_ooookJ_oonfX00ooonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Cooo]Z00?oolL0
oookJ_oonfX00_oonfX3oonX0003oookJ_oo0:Oooo]Z00?ooo]Z00Coo`2doolQ0?oo8@3oob402ooo
nfXDo`3oU`Gooo]Z0_l007l3oolQ0003ool0YoooZ03oojP000;ooo]Z0_l007l2ooo70009ool05?oo
nf[oCP3ooookJ_l0nooooo]Zok3o0?oo01So00_o00;o=?l000Wooo]Zo`3o2Ooonf[ooo]ZoonW0?oo
nf[oo`2doad0oooo6P001?oonfX01ol0ongooo]ZoookJ_oonf[oo`3/oookJ_l0hol00ooonfX01_lf
o`3o0?oXo`3oUol0POooocD0oooX00;ooo]Z00?o0?o`oookJ_lY0?l00_oonfX01?mI0?oooo]Zool0
Z_l0odd4oookJP05oooS0?oonf[oK03ooookJ_mRo`002OoonfX00ooRo`3ooo]Zoe[o0002oookJP04
ool0m_l00ooooo]Zo`3oB0?ooo]Z00Co0?mgogT0oooo9`3oUol01OoonfX01_oo_`3ooo]ZoookJ_l0
oj;ooo]Zo`3o8@?ooo]Z00?oo`3bo`3oE_oonfX00_oonfX01?oo0:3ooo]Zoe@0ool09Ol2oookJP03
obX0oooo2P3ooo]Z00;ooo]Z00CoNol0oookJ_oonf[ood400ooonfX00ol0ocSo203ooookJP07oook
JP05oolP0?oonf[ooo]ZoookJ_oo0;D03_oonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[o
oo]Z00oooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP06oookJP04oolL0?oonf[ooo]ZokSo00gooo]Z
00Kod_l0oookJ_oonf[ogOl0oookJ_l[0?l5oookJP04oonK0?oo003oo`2Yonco00Gooo]Z00?oT`3o
oookJ_oonfX07ooonfX002Kooo]Z00Goo`2ZoookJ_oonf[ooo]ZonGo0009oookJP03onGo0?oonf[o
oo]Z00?ooo]Z00?o0?o`oookJ_oonfX01OoonfX00oooj03ooo]Zool02`03oookJP04ooo90?oo=@3o
olT0o`21o`?oolT000Go0?nGoookJ_oUo`3ooo]ZocKo000=oookJP05o`3Soooonf[ooo]ZoookJ_oo
0>`03?oonfX00ol0ongooo]ZoookJP08oookJP;oogT000?ooaX0oomi0?lM0?l00oooN@001Ooonf[o
o`2doookJ_oonf[oojL000Oooo]Z00?o0?l9oookJ_oonfX00ooonfX01?ldo`3oO03oonGo0?l02ol3
onGo0004oookJ_n`o`3ooo]Zo`3ko`Cooo]Z00CoCP3ooookJ_oonf[ooo]Z0_oo01@3oookJP03ooo7
0?oonf[ooo]Z00?ooo]Z00?oojP0oookJ_oonfX00_oo0:L2oookJP04ool0]?oo8@3oob40oolQ00So
A?l00_l0oiL@oiCo00?oS_l00ooonfX3odCo00?o0?nG0_oonfX3o`00O`04ool0]?oo8@3oob40ool0
Y`;oojP00ol007l2ooo70004ool05?oonf[oCP3oodh0o`;o0?_o0_nDo`001Ol02oooU?l0oookJ_l0
o`Wooo]Z00;oU?l000GoojL0ool0]?nDo`3o7@3ooiCo0004oookJP06o`3okOoonf[ooo]ZoookJ_oo
0>co0>?o1?oonfX01_l0onSo0?nGoiCo0?oo=@3ooo]ZoooX00;ooo]Z00So0?o`obT0oooonf[ooo]Z
oeT0oooo0:[ooo]Zo`3oC@?ooo]Z00Koo`d0oooS0?oonf[oK03ooookJ_mRo`09oookJP;oiOl000Co
F_l0onGo0?oUo`3o00?o0ooonfX01_l0odSooo]ZoookJ_l0ogOoU?l0ogT0o`CoU?l00_oonfX01_l0
X_oookl0oookJ_l0oj;ooo]Zo`3o8@KoU?l00_oonfX4oiCo00;ooo]Z00?o:P3ooookJ_oonfX00_oo
nfX02Omko`3ooo]ZoookJ_ooW03ood40oookJ_l0ocSooo]Zo`P0o`08oookJP03ooo90?nDo`3oU?l0
00GoU?l02_oonfX00ol0okGooo]ZoookJP04oookJP03o`3oRooonf[ooo]Z00oooo]Z00Goo`1?oook
J_oonf[ooo]Zo`3oUP06oookJP04oolL0?oonf[ooo]ZokSo00gooo]Z00?od_l0oookJ_oMo`000_oo
nfX00ol[0?oooo]ZoookJP02oookJP04oonK0?oo003ooo]Zonco00Gooo]Z00?oT`3ooookJ_oonfX0
@_oonfX01Ooo0:[ooo]ZoookJ_oonf[oF@3o00Wooo]Z00?o:@3ooookJ_oonfX00ooonfX00ol0oo3o
oo]ZoookJP06oookJP03oooX0?oonf[oo`0;00Cooo]Z00?oocD0oookJ_l0POl00_oonfX01Ol0oiOo
oo]Zo`3oj?oonf[o=_l000gooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00=oookJP03o`3okOoonf[o
oo]Z00[ooo]Z00?ooaX0oookJ_lM0?l01?oonfX00ooo0;Cooo]ZoonW0007oookJP03o`3o2Ooonf[o
oo]Z00Cooo]Z00Co=?l0oookJ_l02oooo`0H0ooonfX00on`o`3ooo]Zo`3ko`04oookJP;oCP3o0_oo
nfX2ool050?ooo]Z0_ooa`04oookJP03oonX0?oonf[ooo]Z00;oo`2W0ooonfX3oolQ00Oooo]Z1ol0
oiL5oookJP03o`00Oon>o`3oS_l000OoS_l01OoonfX4o`3oU`;ooo]Z0ol007l01?oo0;Coob40oolQ
0?oo0:L2oonX00?o001o00Cooo]Zooo70?oo01Coo`0D0_m>0?l2o`3ko`07ok3o0?l0003o00_oo`0;
ooldo`3ooo]Zo`3o2@02oookJP05oonW0?oonf[oo`2doad0oooo6P001?oonfX01_l0ongooo]Zoook
J_oonf[oo`3/o`3So`Cooo]Z00Ko=_l0o`3oj?l0oiOo087ooole0?ooj002oookJP08o`3ol?lY0?oo
oo]ZoookJ_mI0?oooo]Zool0Z_l0odd4oookJP05oooS0?oonf[oK03ooookJ_mRo`002_oonfX01_oR
o`3oF_l0oookJ_oonf[oo`3fo`03o`;ooo]Z00Oo0?m8oookJ_oonf[o0?mgoookJ_mi0?ooUol000Ko
oo]Z00Kookl0oookJ_l0S?oo0?nRoookJ_l0ob42oookJP03ool0l_l0oeKooo]Z00;ooo]Z00Soo`2P
oookJ_oonf[oE03oo`0Uoooonf[o:P3oool:00?ooo]Z00GoNol0oookJ_oonf[ooi`0oom10002oook
JP03o`3o>?l80?oooo]Z00Oooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP0;oook
JP03o`3o]Ooonf[ooo]Z00?ooo]Z00?o0?n;oookJ_oonfX03ooonfX01Ooo04oooo]ZoookJ_oonf[o
0?nF00Kooo]Z00Cooa`0oookJ_oonf[o^?l03OoonfX01_oBo`3ooo]ZoookJ_oMo`3ooo]Zob/0o`Go
oo]Z00Cooi/0ool00?oo0:Wok?l01OoonfX00onC0?oooo]ZoookJP0OoookJP009OoonfX01Ooo0:[o
oo]ZoookJ_oonf[oiOl000[ooo]Z00?oiOl0oookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP04oook
JP03oooX0?oonf[oo`0;00?ooo]Z00CoolT0oole0?oob@3o087o0ooob@000ol0oiOooo]ZonGo0002
oookJP03ocKo0?oonf[ooo]Z00[ooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00=oookJP03o`3okOoo
nf[ooo]Z00Oooo]Z0_ooN@000ooo6P3oogT0oad0o`03oomi0005oookJ_oo0;Cooo]ZoookJ_ooY`00
2?oonfX00ol0o`Wooo]ZoookJP02oookJP04ocCo0?ml0?oooo]Zo`0;o`CoiOl000Co/?l0oookJ_oo
nf[o0?_o0ooonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00?ooo]Z0_ooa`04oookJP;oojP000?ooo]Z
ool0Yooo0:L00_oonfX3oolQ00KoA?l000Cooo]ZodCo0?l0oiOo0?nG0ooonfX>oiCo00Goo`0i0on>
o`05odCo0004oookJ_l0oiOo0?nGo`3oU`;o001o0_oonfX01?l007ooob40oolQ0?oo0:L2oonX00?o
oo]Z00OoolL0ool05?oo01Cooo]Zodh0ool0003o0?_o00;o000000?o00_ooiCo0?ml0?l01?nDo`00
1?ooY`3oo`2doiCo0?lM0?l5oookJP06o`3okOoonf[ooo]ZoookJ_oo0>co0>?o1?oonfX02_l0onSo
0?nGoiCo0?oo=@3oonP0ool02ooonf[o0?o`oookJ_lY0?l2oookJP04oeT0oooo0:[ooo]Zo`3oC@?o
oo]Z00?oo`d0oooS0?m/0?l00_oonfX00omRo`3ooo]ZoookJP06oookJP;oiOl000GoF_l0onGo0?oU
o`3oo`3fo`03o`02oookJP06o`3oB?oonf[oU?l0o`3oMonDo`3oN@3o1?nDo`03oookJP05oono0?oo
nf[o0?nRoookJ_l0ob401_nDo`02oookJPCoU?l00_oonfX00olZ0?ooo`X0oookJP03oookJP04og_o
0?oonf[ooi`0oom100;ooo]Z00?o0?lho`P0oooonfX01ooonfX00ooob@3ooo]ZoiCo0005oiCo00[o
oo]Z00?o0?neoookJ_oonfX01?oonfX00ol0oh_ooo]ZoookJP0?oookJP05ool0Cooonf[ooo]Zoook
J_l0oiH01_oonfX01?oo703ooo]ZoookJ_nho`0=oookJP03om;o0?oonf[ogOl000;ooo]Z00?o:`3o
oookJ_oonfX00_oonfX01?ooV`3oo`00oookJ_o/o`05oookJP03oi<0oooonf[ooo]Z047ooo]Z00Go
o`2ZoookJ_oonf[ooo]ZoeT0o`0:oookJP03obT0oooonf[ooo]Z00?ooo]Z00?o0?o`oookJ_oonfX0
1OoonfX00oooj03ooo]Zool02`04oookJP03oole0?oonf[o087o00?ooo]Z00Go0?nGoookJ_l0onSo
oo]ZocKo000<oookJP03o`3Soooonf[ooo]Z00;ooo]Z00?oo`3/oookJ_oonfX02ooonfX00ol0ongo
oo]ZoookJP09oookJP03oolJ0?oonf[o7@3o00Cooo]Z00?oo`2doookJ_ooY`002?oonfX00ol0o`Wo
oo]ZoookJP03oookJP05ocCo0?oonf[o00_ooookJ_oo01P00_oonfX01?n`o`3ooo]ZoookJ_l0nol3
oookJP05odh0oooonf[ooo]ZoookJ_oo01@01?oonfX00oooa`3ooo]ZoookJP03oookJP04oonX0?oo
nf[oo`2Wool0Y`;ooo]Z0ooo8@08oookJP;o0?nG1_oonfX7ohko00Woo`0i1On>o`03o`00O`04oook
J_l0oiOo0?nGo`3oU`;o001o0_oonfX01?l007ooob40oolQ0?oo8@02oonX00Cooo]Z00goolL0ool0
5?oo01CoCP3oo`000?l0nooo/?l0o`000?oo01So00_oocCo0?oonf[o0?l900;ooo]Z00GoojL0oook
J_oo0;Co7@3ooolJ0004oookJP06o`3okOoonf[ooo]ZoookJ_oo0>co0>?o1?oonfX02_l0onSo0?nG
ocOo0?l0POooocD0oooX0?oonf[o0?o`oookJ_lY0?l2oookJP04oeT0oooonf[oo`2Zo`3oC@Cooo]Z
00Goon<0oookJ_m/0?oooo]Zof;o0009oookJP03on;o0?oonf[oF_l000;ooo]Z00Coo`3fo`03oooo
nf[o0?m80_oonfX01?l0ogOooo]ZogT0oonGo`06oookJP06oono0?oonf[o08coo`3oX_oonf[o0?lQ
0ooonfX01Ooo0?;o0?mFoookJ_oonf[oo`2P00;ooo]Z00GoE03oo`0Uoooonf[o:P3oool:0004oook
JP04og_o0?oonf[ooi`0oom100?ooo]Z00?o0?lhoookJ_oonfX01_oonfX00ooo803ooo]ZoookJP02
oookJP03ool0]Ooonf[ooo]Z00_ooo]Z00?o0?neoookJ_oonfX01?oonfX00ol0oh_ooo]ZoookJP0>
oookJP05ool0Cooonf[ooo]ZoookJ_l0oiH01_oonfX01?oo703ooo]ZoookJ_nho`0=oookJP06om;o
0?oonf[ooo]Zomgo0?oonf[o:`3o1OoonfX01?ooV`3oo`00ool0ZOo/o`05oookJP03oi<0oooonf[o
oo]Z01oooo]Z000YoookJP03onGo0?oonf[ooo]Z00Oooo]Z0_oUo`04oookJP03o`3ol?oonf[ooo]Z
00Gooo]Z00?oonP0oookJ_oo00/01?oonfX00ooo=@3oolT0o`21o`03ooo90005o`3oUooonf[oiOl0
oookJ_lfo`003OoonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00cooo]Z00?o0?o]oookJ_oonfX01ooo
nfX3oomi0003oolJ0?ooN@3o7@3o00?oogT000Coo`2doookJ_oonf[oojL02?oonfX00ol0o`Wooo]Z
oookJP02oookJP05ocCo0?ml0?oooo]Zo`0;oooonfX00ooUo`001?n`o`3ooo]ZoookJ_l0nol2oook
JP;oCP3o0ooonfX00ooo01Cooo]ZoookJP02ooo700Gooo]Z00CoojP0oookJ_oonf[oo`2W0ooonfX0
0ooo8@3ooo]ZoookJP02oookJP?oA?l000Cooo]Zo`3oUol0oiOo0?nG1OoonfX;oiCo0003o`00Oooo
nf[o0?o000Oo0?o02?m4o`000ooonf[o001oo`3oU`02o`3oU`04oookJ_l007oo001ooookJP;oob40
00?oo`2WoonX0?ooZ0000_oonfX2ooo700;oo`0D0_m>0?l2o`3ko`04oookJ_l02oooU?l0og`0o`?o
U?l000Gooo]ZoonW0?oo0;Cooo]Zoad0o`04oookJP03o`3okOoonf[ooo]Z00;ooo]Z00?oo`3/o`3S
oooonfX00_oonfX01_lfo`3o0?oXo`21oooo=@3ooo]ZoooX00;ooo]Z00So0?o`obT0oooonf[ooo]Z
oeT0oooonf[oo`2Zo`3oC@?ooo]Z00Koo`d0oookJ_ooh`3oK03ooookJ_mRo`09oookJP;oiOl000Co
F_l0onGo0?oonf[o00?o0_oonfX01ol0odSooo]ZoiCo0?nDo`3o0?mgoiCo0?mi0?l00onDo`03oook
JP06oono0?oonf[o0?nRo`2<oooonf[o0?lQ1OnDo`03oookJP?oU?l00_oonfX00olZ0?ooo`X0oook
JP03oookJP04og_o0?oonf[ooo]Zoom100;ooo]Z00?o0?lho`P0oooonfX01ooonfX00ooob@3ooo]Z
oiCo0005oiCo00[ooo]Z00?o0?neoookJ_oonfX01?oonfX00ol0oh_ooo]ZoookJP0?oookJP03ool0
Cooonf[ooo]Z00;ooo]Z00?o0?nFoookJ_oonfX00ooonfX01?oo703ooo]ZoookJ_nho`0=oookJP03
om;o0?oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX00_oonfX01?ooV`3oo`00oookJ_o/o`05oook
JP03oi<0oooonf[ooo]Z04Gooo]Z00?oF@3ooookJ_oonfX02?oonfX00olY0?oooo]ZoookJP02oook
JP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0oookJ_oo00/01?oonfX00ooo=@3ooo]Zo`21o`02oook
JP05o`3oUooonf[o0?oXoookJ_lfo`003OoonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00gooo]Z00?o
0?o]oookJ_oonfX02_oonfX00ooo6P3o7@3ooookJP03oookJP03ool0]?oonf[oojL000Sooo]Z00?o
0?l9oookJ_oonfX00ooonfX01Oldo`3o02goo`0;oooonf[oo`0H00;ooo]Z00Co/?l0oookJ_oonf[o
0?_o0ooonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00?ooo]Z0_ooa`04oookJP;oojP000?ooo]Zool0
YooonfX00_oonfX00ooo8@3oo`2doookJP06oookJP?o0?nG1OoonfX3ohko00Ooo`0i0_l007l00ooo
nf[o0?o0o`3o`007o`3o`0;oo`0i1On>o`000ooonf[o001oo`3oU`02o`3oU`05oookJ_l007oo001o
oookJ_oo0;@00_oo8@02oonX00?ooo]Z00?oolL0oookJ_oo01@00_m>0?l2o`3ko`06ok3o0?oo01So
00_oocCo0?oonf[o0?l90_oonfX01OooY`3ooo]Zool0]?lM0?oooaX000?ooo]Z00?o0?o]oookJ_oo
nfX00_oonfX00ooo0>co0>?ooookJP02oookJP06ocKo0?l0onSo0?nGo`21oooo=@3oonP00_oonfX0
1Ol0oo3o:@3ooookJ_oonf[oF@3o00;ooo]Z00?o0?m=oookJ_oonfX00_oonfX01Ooo3@3oon<0of`0
oooonf[oH_l000[ooo]Z00Koh_l0oe[o0?oonf[ooo]Zool0m_l00ol2oookJP07o`3oB?oonf[ooo]Z
o`3oMooonf[oN@3ooiOo0005oookJP06oono0?oonf[ooo]Zo`3oX_oonf[o0?lQ0ooonfX00ooo0?;o
0?mFoookJP02oookJP07ool0X?oonf[oE03oo`0Uoooonf[o:P3oool:0004oookJP04og_o0?oonf[o
oo]Zoom100?ooo]Z00?o0?lho`P0oooonfX01_oonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooo
nf[ooo]Z00_ooo]Z00?o0?neoookJ_oonfX01?oonfX00ol0oh_ooo]ZoookJP0>oookJP03ool0Cooo
nf[ooo]Z00;ooo]Z00?o0?nFoookJ_oonfX00ooonfX01?oo703ooo]ZoookJ_nho`0=oookJP06om;o
0?oonf[ooo]Zomgo0?oonf[o:`3o1OoonfX01?ooV`3oo`00ool0ZOo/o`05oookJP03oi<0oooonf[o
oo]Z01oooo]Z000XoookJP03onGo0?oonf[ooo]Z00Oooo]Z0ooUo`04oookJP03o`3ol?oonf[ooo]Z
00Cooo]Z00?oonP0oookJ_oo00/01?oonfX00ooo=@3ooo]Zo`21o`03ooo90005o`3oUooonf[oiOl0
oookJ_lfo`003OoonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00cooo]Z00?o0?o]oookJ_oonfX02_oo
nfX00ooo6P3oogT0oad0o`03oomi0005ool0]?oonf[ooo]ZoookJ_ooY`001ooonfX00ol0o`Wooo]Z
oookJP02oookJP09ocCo0?ml0?oooo]Zo`0;oooonf[oo`0HoookJ_oUo`3o/?l000;ooo]Z00Co0?_o
oookJ_oonf[oCP3o0ooonfX2ool050;ooo]Z00?oolL0oookJ_oonfX00ooonfX2oonX0003oookJ_oo
0:Ooo`2W00;ooo]Z0_oo8@05oookJP04odCo0?oonf[o0?nGo`3oU`GoA?l00on>o`08oiCo00;o0?o0
2ooo00L9odCo00;oS_l000Go001ooookJ_l0oiOo0?nGo`00O`03oookJP;oob4000?oo`2WoonX0?oo
nfX00_oonfX02?ooa`3ooo]Zool05?oo01CoCP3oo`000?l0noooU?l00_l02ol02Oml0?ooU?l0oiCo
0?nDo`3ooo]ZoonW0?oo0;Cooo]Zoad0o`04oookJP03o`3okOoonf[ooo]Z00;ooo]Z00?oo`3/oook
J_oonfX00_oonfX01_lfo`3o0?oXo`21oooo=@3ooo]ZoooX00;ooo]Z00So0?o`obT0oooonf[ooo]Z
oeT0oooo0:[ooo]Zo`3oC@?ooo]Z00Goo`d0oooS0?m/0?oooo]Zof;o0009oookJP07on;o0?oUo`3o
F_l0onGo0?oonf[oo`3fo`03o`02oookJP06o`3oB?oonf[oU?l0o`3oMonDo`3oN@3o0onDo`04oook
JP05oono0?oonf[o0?nRoookJ_l0ob401_nDo`02oookJP03oiCo0?oonf[oU?l000?ooo]Z00?o:P3o
oookJ_oonfX00_oonfX02Omko`3ooo]ZoookJ_ooW03ood40oookJ_l0ocSooo]Zo`P0o`07oookJP03
ooo90?oonf[ooo]Z00GoU?l02ooonfX00ol0okGooo]ZoookJP04oookJP03o`3oRooonf[ooo]Z00ko
oo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP03oookJP05oolL0?oonf[ooo]Zoook
J_nho`003?oonfX00ooBo`3ooo]Zomgo0002oookJP03ob/0oooonf[ooo]Z00?ooo]Z00Coo`00oook
J_o/o`3oo`2Y1?oonfX00onC0?oooo]ZoookJP14oookJP03oeT0oooonf[ooo]Z00Sooo]Z00?o:@3o
oookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP05oookJP03oooX0?oonf[oo`0;00Cooo]Z00?oocD0
oookJ_l0POl00ooonfX01?l0oiOo0?oXoookJ_lfo`0=oookJP03o`3Soooonf[ooo]Z00;ooo]Z00?o
o`3/oookJ_oonfX02_oonfX00ol0ongooo]ZoookJP0:oookJP03oolJ0?lM0?oooo]Z00?ooo]Z00Co
o`2doookJ_oonf[oojL01ooonfX00ol0o`Wooo]ZoookJP03oookJP05ocCo0?l0;Ooo00_ooookJ_oo
01P00_oonfX01?n`o`3ooo]ZoookJ_l0nol3oookJP03odh0oooonf[ooo]Z00;oo`0D0ooonfX00ooo
a`3ooo]ZoookJP03oookJP04oonX0?oonf[oo`2Wool0Y`;ooo]Z0_oo8@07oookJP;o0?nG1OoonfX3
ohko00;oo`0i0ooonfX6o`3o`0_oo`071Ol0ol000ol007ooo`0iohko0002ohko0003o`00Oooonf[o
0?nG00;o0?nG0ooonfX00ooo0;Coob40oolQ0002oonX00;ooo]Z0_ooa`02ool05009odh0ool0003o
0?_ook3o0?oo01So00_oog`0oooonf[o0?l900;ooo]Z00GoojL0oookJ_oo0;Co7@3ooolJ0003oook
JP03o`3okOoonf[ooo]Z00;ooo]Z00?oo`3/o`3SoooonfX00_oonfX01_lfo`3o0?oXo`3oUol0POoo
ocD0oooX00;ooo]Z00So0?o`obT0oooonf[ooo]ZoeT0oooonf[oo`2Zo`3oC@Cooo]Z00Goon<0oook
J_m/0?oooo]Zof;o0009oookJP03on;o0?mJo`3o0?nn00;ooo]Z00Co00?ooookJ_oonf[o0?m80_oo
nfX01?l0ogOooo]ZogT0oonGo`06oookJP06oono0?oonf[o08coo`3oX_oonf[o0?lQ0_oonfX00ooo
0?;o0?mFoookJP02oookJP04ool0X?oonf[ooo]Zoe@0o`;ooo]Z00?o:P3oool:0?oonfX00_oonfX0
1Omko`3ooo]ZoookJ_ooW03ood4000;ooo]Z00?o0?lho`P0oooonfX01_oonfX00ooo803ooo]Zoook
JP02oookJP03ool0]Ooonf[ooo]Z00_ooo]Z00?o0?neoookJ_oonfX01?oonfX00ol0oh_ooo]Zoook
JP0?oookJP05ool0Cooonf[ooo]ZoookJ_l0oiH01OoonfX01Ooo703ooo]ZoookJ_oonf[o^?l000co
oo]Z00Kod_l0oookJ_oonf[ogOl0oookJ_l[0?l5oookJP04oonK0?oo003ooo]Zonco00Gooo]Z00?o
T`3ooookJ_oonfX07ooonfX002Sooo]Z00?oiOl0oookJ_oonfX01ooonfX3onGo00?ooo]Z00?o0?o`
oookJ_oonfX01OoonfX00oooj03ooo]Zool02`03oookJP05oole0?oonf[ooo]Zo`21oooob@000_oo
nfX01Ol0oiOoiOl0oookJ_oonf[o=_l000gooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00<oookJP03
o`3okOoonf[ooo]Z00[ooo]Z00?ooaX0oad0ooooN@000oooN@001?oo0;Cooo]ZoookJ_ooY`08oook
JP0:o`3o2Ooonf[ooo]ZoookJ_oUo`3oO03ooookJ_l02ooooo]Zool060;ooo]Z00Co/?l0oookJ_oo
nf[o0?_o0_oonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00?ooo]Z00?oolL0oookJ_oonfX00ooonfX0
1?ooZ03ooo]Zool0Yooo0:L2oookJP;oob401ooonfX2o`3oU`;ooo]Z0_m4o`03ohko00?oA?l00onD
o`07ool01`Oo001o1?oonfX;odCo00?oS_l000Cooo]Zo`3oUol0oiOo0?nG0ol007l2oolQ00;oojP0
0_oonfX01oooa`3o0000o`000?oo01CoCP3ooiCo0?l0nol00_nDo`000ol02oooO03ooiCo0002oiCo
0005oookJ_ooY`3ooo]ZoolJ0?lM0?l01?oonfX00ol0ongooo]ZoookJP02oookJP03ool0k?oonf[o
oo]Z00;ooo]Z00Go0?oXo`3oUooo=@3ooo]ZoooX0002oookJP03o`3ol?oonf[o:@3o00;ooo]Z00?o
F@3oool0Z_l0odd00ooonfX01_oo3@3ooo]ZoooS0?m/0?oooo]Zof;o00Sooo]Z00?oh_l0oookJ_mJ
o`000_oUo`001Ooo0?Ko00?ooookJ_oonf[o0?m800;ooo]Z00?o0?mgoiCo0?mi0?l00onDo`04oook
JP06oono0?oonf[o0?nRoookJ_l0ob7ooo]Z1OnDo`02oookJP04oiCo0?oonf[oE03oo`0Uo`;ooo]Z
00?o:P3ooookJ_oonfX00ooonfX02?mko`3ooo]ZoonL0?oo@@3ooo]Zo`3o>?oonf[o203o1ooonfX0
0ooob@3ooo]ZoookJP05oiCo00_ooo]Z00?o0?neoookJ_oonfX01?oonfX00ol0oh_ooo]ZoookJP0>
oookJP03ool0Cooonf[ooo]Z00;ooo]Z00?o0?nFoookJ_oonfX00ooonfX01Ooo703ooo]ZoookJ_oo
nf[o^?l000cooo]Z00Kod_l0oookJ_oonf[ogOl0oookJ_l[0?l5oookJP04ool00?oonf[ok?l0ool0
Z@Cooo]Z00?oT`3ooookJ_oonfX0A?oonfX00omI0?oooo]ZoookJP08oookJP03obT0oooonf[ooo]Z
00;ooo]Z00?o0?o`oookJ_oonfX01OoonfX01?ooj03ooo]ZoookJ_oo00/3oookJP04oole0?oonf[o
oo]Zo`21o`;ooo]Z00Go0?nGoookJ_l0onSooo]ZocKo000=oookJP05o`3Soooonf[ooo]ZoookJ_oo
0>`03OoonfX00ol0ongooo]ZoookJP0:oookJP03oolJ0?lM0?oooo]Z00?ooo]Z00?oo`2doookJ_oo
Y`002?oonfX00ol0o`Wooo]ZoookJP02oookJP05ocCo0?l0;Ooo00_ooookJ_oo01P00_oonfX01?n`
o`3ooo]ZoookJ_l0nol3oookJP04odh0oooonf[ooo]Zool050Cooo]Z00?oolL0oookJ_oonfX00_oo
nfX2oonX00;oo`2W0_oonfX2oolQ00Oooo]Z0_l0oiL4oookJP?oS_l000?oo`0ioookJ_oonfX00ol0
ol08ool01`Ko001o1OoonfX7ool01`?o0?o00on>o`001?oonf[o001oo`3oUol0oiL3o`00O`04ool0
]?oo8@3oob40oonX00?ooo]Z00coolL0o`000?oo01CoCP3ooookJ_l0nooo/?l0ool06?l02oooO03o
oookJ_l0o`T2oookJP04oonW0?oo0;Cooo]Zoad0o`Cooo]Z00?o0?o]oookJ_oonfX00_oonfX00ooo
0>cooo]ZoookJP02oookJP0:o`3oj?l0oiOo087ooole0?oo00_oonP0oookJ_l0oo3ooo]ZobT0o`;o
oo]Z00?oF@3ooookJ_l0odd01?oonfX01Ooo3@3oon<0of`0oooonf[oH_l000Wooo]Z00?oh_l0oook
J_mJo`000_oonfX01?oo0?Ko00?ooookJ_l0odP2oookJP04o`3oMooonf[oN@3ooiOo00Kooo]Z00Ko
okl0oookJ_l0S?oo0?nRoookJ_l0ob43oookJP05ool0l_l0oeKooo]ZoookJ_oo0:000_oonfX01OmD
0?oo02GooookJ_lZ0?ooo`X000Cooo]Z00CoNol0oookJ_ooW03ood400_oonfX00ol0ocSo203ooook
JP06oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX02ooonfX00ol0okGooo]Zoook
JP04oookJP03o`3oRooonf[ooo]Z00oooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP05oookJP05oolL
0?oonf[ooo]ZoookJ_nho`003?oonfX01_oBo`3ooo]ZoookJ_oMo`3ooo]Zob/0o`Gooo]Z00Cooi/0
ool00?oonf[ok?l01OoonfX00onC0?oooo]ZoookJP0OoookJP009ooonfX00ooUo`3ooo]ZoookJP07
oookJP?oiOl01?oonfX00ol0oo3ooo]ZoookJP04oookJP03oooX0?oonf[oo`0;00Cooo]Z00_oocD0
oookJ_l0POoooo]Zooo90?oonf[o0?nGoookJ_oUo`3ooo]ZocKo000=oookJP05o`3Soooonf[ooo]Z
oookJ_oo0>`03?oonfX00ol0ongooo]ZoookJP0:oookJP04oolJ0?lM0?oooo]ZoookJP;oogT000Co
o`2doookJ_oonf[oojL02?oonfX01?l0o`Wooo]ZoookJ_oonfX2onGo0004og`0ool02ooooo]Zool0
60;ooo]Z00Co/?l0oookJ_oonf[o0?_o0_oonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Cooo]Z00Co
olL0oookJ_oonf[ooo]Z0_ooZ0001_oonf[oo`2WoookJ_oonf[oo`2doolQ00Oooo]Z0_oUo`04oook
JP;oS_l01Om4o`04ool01`03odCo0?oonf[ooo]Z00Gooo]Z1Ol007l4oookJPkoA?l000Goo`0iohko
0?n>o`3oS_l0o`00O`02o`3oU`;o001o00Kooo]ZoolQ0?oo0;CoojP0ool0YooonfX2ooo70005o`00
0?oo01CoCP3oodh0ool0nol00_nDo`001?l02oooO03ooiCo0?nDo`02oookJP04oonW0?oonf[ooaX0
oad0o`Cooo]Z00?o0?o]oookJ_oonfX00_oonfX02_oo0>cooo]ZoookJ_oonf[o=_l0o`3oj?l0POoo
ocD0oookJ_ooj002oookJP08o`3ol?lY0?oooo]ZoookJ_mI0?ooo`2ZoookJ_l0odd2oookJP06ool=
0?oonf[oon<0of`0oooonf[oH_l02OoonfX01_oRo`3ooo]Zoe[o0?oUo`3ooo]Zo`03o`?ooo]Z00Ko
0?m8oookJ_nDo`3o0?mgoiCo0?mi0?l2oiCo00Cooo]Z00Oookl0oookJ_l0oj;o08cooookJ_l0ob7o
oo]Z00CoU?l00_oonfX00onDo`3ooo]ZoiCo0002oiCo0003oookJ_lZ0?ooo`X000Cooo]Z00SoU?l0
oookJ_ooW03ood40oookJ_l0ocSooo]Zo`P0o`Sooo]Z00?oolT0oookJ_oonfX01?nDo`0;oookJP03
o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX03_oonfX00ooo04oooo]ZoookJP02oookJP03
o`3oU_oonf[ooo]Z00?ooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP06om;o0?oonf[ooo]Z
omgo0?oonf[o:`3o1OoonfX01?oo003ooo]Zonco0?oo0:T4oookJP03oi<0oooonf[ooo]Z04?ooo]Z
00?oF@3ooookJ_oonfX02OoonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Gooo]Z
00?oonP0oookJ_oo00/01?oonfX01?oo=@3ooo]Zo`21oolgo`02oookJP04o`3oUol0onSooo]ZocKo
00kooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00<oookJP03o`3okOoonf[ooo]Z00[ooo]Z00?ooaX0
oad0oooonfX00ooonfX00ooo0;Cooo]ZoonW0008oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z00Co=?l0
o`0;oooonf[oo`0H0_oonfX01?n`o`3ooo]ZoookJ_l0nol3oookJP04odh0oooonf[ooo]Zool050Co
oo]Z00?oolL0oookJ_oonfX00_oonfX00oooZ03ooo]Zool0Y`03oookJP03oolQ0?oonf[ooo]Z00Go
oo]Z0_l0oiL4oookJP;oS_l000?oo`0ioookJ_l0ol000ol0ol03ool01`Sooo]Z1Ol007l:oookJP?o
001o0ooo00L3o`3o`0?oS_l000So001oo`3oUol0oiOo0?nGo`00Oooonf[oo`2doolQ00;oojP000Go
oo]Zo`000?ooa`3o0000ool05002odh0o`07o`3koon`o`3oo`0Ho`0;ooml0?oooo]Zo`3o2@02oook
JP04oonW0?oo0;Cooo]Zoad0o`Cooo]Z00?o0?o]oookJ_oonfX00_oonfX02_oo0>cooo]ZoookJ_oo
nf[o=_l0o`3oj?l0oiOo087ooole0?ooj002oookJP08o`3ol?lY0?oooo]ZoookJ_mI0?oooo]Zool0
Z_l0odd3oookJP05ool=0?ooh`3ooo]Zof`0oomRo`002_oonfX00ooRo`3oF_l0oookJP02oookJP04
o`03oooonf[ooo]Zo`3oB0;ooo]Z00Co0?mgoookJ_mi0?ooUol01OoonfX01_oo_`3ooo]ZoookJ_l0
oj;ooo]Zo`3o8@?ooo]Z00Goo`3bo`3oE_oonf[ooo]Zool0X002oookJP05oe@0ool09Ooooo]ZobX0
oooo2P001?oonfX01?mko`3ooo]ZoonL0?oo@@02oookJP03o`3o>?l80?oooo]Z00Oooo]Z00?oob00
oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP0;oookJP03o`3o]Ooonf[ooo]Z00?ooo]Z00?o0?n;
oookJ_oonfX03ooonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Gooo]Z00Gooa`0oookJ_oonf[ooo]Z
okSo000<oookJP06om;o0?oonf[ooo]ZoookJ_oMo`3o:`3o1OoonfX01?ooV`3oo`00oookJ_o/o`05
oookJP03oi<0oooonf[ooo]Z01oooo]Z000WoookJP03onGo0?oonf[ooo]Z00Kooo]Z1?oUo`03oook
JP03o`3ol?oonf[ooo]Z00Cooo]Z00CoonP0oookJ_oonf[oo`0;0ooonfX01Ooo=@3ooo]Zo`21oooo
nf[oolT000;ooo]Z00Co0?nGonGo0?oonf[oolT03_oonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00_o
oo]Z00?o0?o]oookJ_oonfX02_oonfX00ooo6P3o7@3ooomi0003oookJP05oomi0?oo0;Cooo]Zoook
J_ooY`001ooonfX01?l0o`Wooo]ZoookJ_oonfX2onGo0005og`0oooonf[o00_ooookJ_oo01P00_oo
nfX00on`o`3ooo]Zo`3ko`03oookJP04odh0oooonf[ooo]Zool050Cooo]Z00GoolL0oookJ_oonf[o
oo]ZoonX0002oookJP03ool0Yooonf[ooo]Z00;oob401OoonfX5onGo0005oookJ_oUo`3oS_l0ohko
0?oUo`000om4o`03ool01`?oA?l04_oonfX?odCo00;o0?o000Coo`0iohko0?n>o`3ooo]Z0_l0oiL2
oookJP;oob400_ooZ002o`000006ooo70?l0003oo`0DoookJ_m>0?oo0?_o0_nDo`001?l02oooU?l0
oiCo0?nDo`02oookJP04oonW0?oonf[ooaX0oad0o`?ooo]Z00?o0?o]oookJ_oonfX00_oonfX00ooo
0>cooo]ZoookJP02oookJP06o`3oj?l0oiOo087ooole0?ooj03oo`0;0_oonfX02?l0oo3o:@3ooook
J_oonf[oF@3oool0Z_oonf[o0?m=0_oonfX01_oo3@3ooo]ZoooS0?m/0?oooo]Zof;o00Sooo]Z00Oo
h_l0oookJ_mJo`3oiOl0oookJ_oo0?Ko00?o00;ooo]Z00Ko0?m8oookJ_oonf[o0?mgoiCo0?mi0?l2
oiCo00Gooo]Z00Kookl0o`3oX_l0S?oooo]Zo`3o8OoonfX4oiCo0003oookJ_nDo`3oU?l000CoU?l0
00?ooo]ZobX0oooo2P001?oonfX01?nDo`3ooo]ZoonL0?oo@@02oookJP03o`3o>?l80?oooo]Z00Oo
oo]Z00?oolT0oookJ_oonfX01?nDo`0;oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oo
nfX03ooonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Gooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<
oookJP04om;o0?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX00_oonfX01?oo003ooo]Zonco
0?oo0:T5oookJP03oi<0oooonf[ooo]Z04;ooo]Z00?oF@3ooookJ_oonfX02?oonfX00olY0?oooo]Z
oookJP02oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00CoonP0oookJ_oonf[oo`0;0ooonfX01?oo=@3o
oo]Zo`21oolgo`02oookJP04o`3oUol0onSooo]ZocKo00kooo]Z00Go0>?ooookJ_oonf[ooo]Zool0
k00<oookJP03o`3okOoonf[ooo]Z00[ooo]Z00?ooaX0oad0oooonfX01?oonfX00ooo0;Cooo]ZoonW
0007oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z00Go=?l0o`0]ool02ooooo]Zool06002oookJP03ok3o
0?oonf[o0?_o00Cooo]Z00?oCP3ooookJ_oo01@01?oonfX00oooa`3ooo]ZoookJP02oookJP03oonX
0?oonf[oo`2W00;ooo]Z0_oo8@07oookJP03o`3oUooonf[ooo]Z00;ooo]Z0_n>o`02oookJP;o0?o0
00Cooo]Zool01ooo00Ooo`078?oonfX3ool01`?o0?o00_n>o`02oookJP;o0?nG0_oonfX01ooo8@3o
o`2doonX0?ooZ03o0000ooo70?l000000_oo01@01Om>0?oo0?_ook3o0?oo01So00_o00;ooo]Z00Oo
0?l9oookJ_oonf[oojL0ool0]?oonf[o7@3o00?ooo]Z00?o0?o]oookJ_oonfX00_oonfX00ooo0>co
0>?ooookJP02oookJP06ocKo0?l0onSo087ooole0?oonf[oonP00_oonfX02?l0oo3o:@3ooookJ_oo
nf[oF@3ooookJ_oo0:[o0?m=0ooonfX01Ooo3@3oon<0of`0oooonf[oH_l000Wooo]Z00?oh_l0oe[o
0?l0okh00_oonfX01?oo0?Ko00?ooookJ_l0odP2oookJP04o`3oMooonf[oN@3ooiOo00Kooo]Z00?o
okl0oookJ_l0oj800_oonfX01Ol0ob7ooo]ZoookJ_oo0?;o0?mF00;ooo]Z00Soo`2PoookJ_oonf[o
E03oo`0Uoooonf[o:P3oool:00Cooo]Z00CoNol0oookJ_ooW03ood400ooonfX00ol0ocSooo]Zoook
JP06oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX02ooonfX00ol0okGooo]Zoook
JP03oookJP03o`3oRooonf[ooo]Z00oooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP05oookJP05oolL
0?oonf[ooo]ZoookJ_nho`003?oonfX01ooBo`3ooo]ZoookJ_oonf[ogOl0oookJ_l[0?l01?oonfX0
1?ooV`3oo`00oookJ_o/o`06oookJP03oi<0oooonf[ooo]Z01kooo]Z000VoookJP03onGo0?oonf[o
oo]Z00Kooo]Z1OoUo`03oookJP03o`3ol?oonf[ooo]Z00Cooo]Z00?oonP0oookJ_oo00/01?oonfX0
2ooo=@3ooo]Zo`21oooonf[oolT0oookJ_l0oiOooo]Zo`3oj?oonf[oolT000kooo]Z00Co0>?ooook
J_oonf[oo`3/2ooonfX00ol0ongooo]ZoookJP0;oookJP03oad0ooooN@3ooo]Z00?ooo]Z00Coo`2d
oookJ_oonf[oojL02?oonfX00ol0o`Wooo]ZoookJP03onGo0004oookJ_l02ooooo]Zool060;ooo]Z
00?o/?l0oookJ_l0nol00ooonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00?ooo]Z00GoolL0oookJ_oo
nf[ooo]ZoonX0002oookJP04ool0Yooonf[ooo]ZoolQ00Cooo]Z2OoUo`001?n>o`3oiOl0onGo0?l0
ol03ool01`CoA?l07OoonfX7odCo0004ool01ol0ol3o0?o0o`3o`0?oS_l00_l0oiL2oookJP03oolQ
0?oo0;CoojP000;o00000_ooa`001?oo01Cooo]Zodh0ool0nol2oiCo0004o`0;oonDo`3oU?l0o`3o
2@;ooo]Z00CoojL0oookJ_oo6P3o7@3o0ooonfX00ol0ongooo]ZoookJP02oookJP0:ool0k?oonf[o
oo]ZoookJ_lfo`3o0?oXo`21oooo=@3ooo]ZoooX00;ooo]Z00So0?o`obT0oooonf[ooo]ZoeT0oooo
0:[ooo]Zo`3oC@;ooo]Z00Koo`d0oookJ_ooh`3oK03ooookJ_mRo`08oookJP07on;o0?oonf[oF_l0
o`3o__oonf[oo`3fo`03o`02oookJP06o`3oB?oonf[ooo]Zo`3oMonDo`3oN@3o0onDo`04oookJP05
oono0?oonf[o0?nRoookJ_l0ob400_oonfX:oiCo0003oookJ_l0C?oo:P3o00Cooo]Z00CoU?l0oook
J_oonf[ood400_oonfX00ol0ocSo203ooookJP07oookJP04ooo90?oonf[ooo]ZoookJP?oU?l02ooo
nfX00ol0okGooo]ZoookJP04oookJP03o`3oRooonf[ooo]Z00oooo]Z00Goo`1?oookJ_oonf[ooo]Z
o`3oUP05oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX01?oBo`3ooo]ZoookJ_oMo`02oook
JP03ob/0oooonf[ooo]Z00;ooo]Z00Coo`00oookJ_o/o`3oo`2Y1OoonfX00onC0?oooo]ZoookJP11
oookJP03oeT0oooonf[ooo]Z00Wooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP05
oookJP03oooX0?oonf[oo`0;00Cooo]Z00CoocD0oookJ_l0POoo=ol00_oonfX01?l0oiOo0?oXoook
J_lfo`0>oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`02ooonfX00ol0ongooo]ZoookJP0;oookJP03
oad0oooonf[ooo]Z00?ooo]Z00?oo`2doookJ_ooY`002?oonfX00ol0o`Wooo]ZoookJP02oookJP05
ocCo0?l0;Ooo00_ooookJ_oo01P00_oonfX00on`o`3ooo]Zo`3ko`04oookJP04odh0oooonf[ooo]Z
ool050?ooo]Z00?oolL0oookJ_oonfX00_oonfX00oooZ03ooo]Zool0Y`02oookJP03oolQ0?oo0;Co
oo]Z00Gooo]Z0_l0oiL4oookJP05ohko0?oo03Wooo]ZoookJ_l0ol000ooo00LVoookJP?oo`070_l0
ol03ohko0004oookJ_l0oiOooo]ZoookJP;oob4000?oo`2WoonX0?l000000_ooa`001ooonf[oo`0D
odh0ool0nooo/?l0ool06?l02ol00_oonfX01ol0o`Wooo]ZoookJ_ooY`3oo`2doookJ_lM0?l00ooo
nfX00ol0ongooo]ZoookJP02oookJP03ool0k?l0hooooo]Z00;ooo]Z00Go0?oXo`3oUol0POooocD0
oooX0002oookJP08o`3ol?lY0?oooo]ZoookJ_mI0?oooo]Zool0Z_l0odd3oookJP05ool=0?ooh`3o
K03ooookJ_mRo`002OoonfX00ooRo`3ooo]Zoe[o0002oookJP04ool0m_l00ooooo]Zo`3oB0;ooo]Z
00Co0?mgoookJ_mi0?ooUol01_oonfX00ooo_`3ooo]Zo`3oXP02oookJP06o`3o8Ooonf[ooo]Zoook
J_oo0?;o0?mF0_oonfX01?oo0:3ooo]ZoookJ_mD0?l2oookJP03obX0oooo2P3ooo]Z00;ooo]Z00Co
Nol0oookJ_oonf[ood400ooonfX00ol0ocSooo]ZoookJP06oookJP03oolP0?oonf[ooo]Z00;ooo]Z
00?oo`2eoookJ_oonfX02ooonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z00oooo]Z
00Goo`1?oookJ_oonf[ooo]Zo`3oUP05oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX01ooB
o`3ooo]ZoookJ_oonf[ogOl0oookJ_l[0?l01?oonfX01?ooV`3oo`00oookJ_o/o`06oookJP03oi<0
oooonf[ooo]Z01kooo]Z000VoookJP03onGo0?oonf[ooo]Z00Kooo]Z1OoUo`02oookJP03o`3ol?oo
nf[ooo]Z00Gooo]Z00?oonP0oookJ_oo00/01?oonfX01?oo=@3ooo]Zo`21oooob@02oookJP03o`3o
Uol0onSooo]Z00;oolT03OoonfX01?l0hooooo]ZoookJ_oo0>`<oookJP03o`3okOoonf[ooo]Z00[o
oo]Z00?ooaX0oad0oooonfX01?oonfX00ooo0;Cooo]ZoonW0008oookJP03o`3o2Ooonf[ooo]Z00Co
iOl000?oo`1?o`0;oooo01P00_oonfX00on`o`3ooo]Zo`3ko`03oookJP05odh0oooonf[ooo]Zoook
J_oo01@00ooonfX00oooa`3ooo]ZoookJP02oookJP03oonX0?oo0:Ooo`2W00;ooo]Z00?oob40oook
J_oonfX02_oUo`02ohko00;oiOl000?o0?o0ool01om4o`001Om4o`0@oookJP;oiOl05?oonfX2ool0
1`04oookJ_l0ol3o0?o0ool0>@;oS_l00_l0oiL00ooonf[oob40oolQ0002oonX00;o000000GoolL0
ool05?oonf[oCP3oo`3ko`02oiCo0004o`0;oonDo`3oU?l0o`3o2@;ooo]Z00CoojL0odCo0?oo6P3o
7@3o0ooonfX01_l0ongooo]ZoookJ_oonf[oo`3/o`3So`?ooo]Z00Ko0?oXo`3oUol0POooocD0oooX
0?oo00/2oookJP08o`3ol?lY0?oooo]ZoookJ_mI0?ooo`2ZoookJ_l0odd2oookJP05ool=0?oonf[o
K03ooookJ_mRo`002OoonfX00ooRo`3ooo]Zoe[o0002oookJP07o`03oooonf[ooo]ZoookJ_l0odSo
oo]Zo`3oM`02oiCo0003ogT0oonDo`3oU?l000Cooo]Z00Oookl0oookJ_l0oj;o08cooookJ_l0ob7o
oo]Z00[oU?l00_oonfX00olZ0?ooo`X0oookJP02oookJP08oiCo0?oonf[ooo]ZoonL0?oo@@3ooo]Z
o`3o>?l80?l8oookJP03ooo90?oonf[ooo]Z00;ooo]Z0_nDo`0;oookJP03o`3o]Ooonf[ooo]Z00Co
oo]Z00?o0?n;oookJ_oonfX03ooonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Gooo]Z00Gooa`0oook
J_oonf[ooo]ZokSo000<oookJP04om;o0?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX00_oo
nfX01?oo003ooo]Zonco0?oo0:T5oookJP03oi<0oooonf[ooo]Z047ooo]Z00?oF@3ooookJ_oonfX0
2OoonfX01OlY0?oooo]ZoookJ_oonf[o0?o`00Sooo]Z00?oonP0oookJ_oo00/01?oonfX00ooo=@3o
087oocOo0002oookJP05o`3oUol0onSooo]ZoookJ_lfo`003OoonfX01Ol0hooooo]ZoookJ_oonf[o
o`3/00cooo]Z00?o0?o]oookJ_oonfX02_oonfX00ooo6P3o7@3ooookJP04oookJP03ool0]?ooY`3o
oo]Z00Oooo]Z00?o0?l9oookJ_oonfX00_oonfX01Oml0?oo=?l0ool0Col02oooo`0H00;ooo]Z00Co
/?l0oookJ_oonf[o0?_o0ooonfX01?m>0?oooo]ZoookJ_oo01@3oookJP03ooo70?oonf[ooo]Z00?o
oo]Z00KoojP0ool0Yooonf[ooo]ZoolQ0?oo0;@6oookJP03o`3oUooonf[ooo]Z00;ooo]Z0_n>o`02
oookJP;o0?o000?oo`07oookJ_oonfX0:_oonfX2ool01`;o0?o000?oo`0iohko0?n>o`000_l0oiL2
oookJP0=oolQ0?oo0;CoojP0oonX0?l0003oolL0oookJ_oo01CoCP3oo`3koon`o`3oo`0Ho`0;o`02
oookJP07o`3o2Ooonf[ooo]ZoonW0?oo0;Co0?oboad0o`03oookJP06o`3okOoonf[ooo]ZoookJ_oo
0>co0>?o0ooonfX01_lfo`3o0?oXo`3oUooo=@3ooo]ZoooX00;ooo]Z00So0?o`obT0oooonf[ooo]Z
oeT0oooonf[oo`2Zo`3oC@?ooo]Z00Goo`d0oooS0?m/0?oooo]Zof;o0009oookJP03on;o0?mJo`3o
oo]Z00;ooo]Z00Co00?ooookJ_oonf[o0?m80_oonfX01?l0ogOooo]ZogT0oonGo`05oookJP06oono
0?oonf[ooo]Zo`3oX_oonf[o0?lQ0ooonfX01Ooo0?;o0?mFoookJ_oonf[oo`2P00;ooo]Z00GoE03o
oookJ_oonf[o:P3oool:0003oookJP05og_o0?oonf[ooo]ZoonL0?oo@@000_oonfX00ol0ocSo203o
oookJP06oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX02ooonfX00ol0okGooo]Z
oookJP03oookJP03o`3oRooonf[ooo]Z00oooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP05oookJP05
oolL0?oonf[ooo]ZoookJ_nho`003?oonfX01ooBo`3ooo]ZoookJ_oonf[ogOl0oookJ_l[0?l01Ooo
nfX00ooo003ooo]Zonco0006oookJP03oi<0oooonf[ooo]Z01kooo]Z000UoookJP03onGo0?oonf[o
oo]Z00Kooo]Z1_oUo`02oookJP03o`3ol?oonf[ooo]Z00Cooo]Z00?oonP0oookJ_oo00/01?oonfX0
2Ooo=@3ooo]Zo`21oooonf[oolT0oookJ_l0oiOooo]Zo`3oj003ooo900gooo]Z00Co0>?ooookJ_oo
nf[oo`3/2ooonfX00ol0ongooo]ZoookJP0;oookJP03oad0oooonf[ooo]Z00?ooo]Z00Coo`2doook
J_oonf[oojL01ooonfX00ol0o`Wooo]ZoookJP04onGo0003oookJ_l02oooo`0H00?ooo]Z00?o/?l0
o`3koooonfX00_oonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00?ooo]Z00?oolL0oookJ_oonfX00_oo
nfX00oooZ03oo`2WoookJP02oookJP03ool0]?oo8@3oiOl000WoiOl00_n>o`02onGo00;o0?o000?o
o`07oookJ_oonfX00om4o`0BoookJPCoiOl00_m4o`0BoookJP?oo`070_l0ol002Ooo03WoS_l0ohko
0?l0oiOooo]Zo`000?oo8@3oo`2doonX0002oookJP0:ooo70?oo01Cooo]Zodh0ool0nooooo]ZoiCo
0?l02oooU?l0oookJP;oA?l000CoojL0odCo0?oonf[o7@3o0ooonfX00ol0ongooo]ZoookJP02oook
JP03ool0k?oonf[ooo]Z00;ooo]Z00oo0?oXo`3oUooo=@3ooo]ZoooX0?oo00_ooo]Zo`3ol?oonf[o
:@3ooookJ_mI0?ooo`2ZoookJ_l0odd00_oonfX01_oo3@3ooo]ZoooS0?m/0?oooo]Zof;o00Sooo]Z
00Ooh_l0oookJ_mJo`3o0?nnoookJ_oo0?Ko00?o00;ooo]Z00Ko0?m8oookJ_oonf[o0?mgoiCo0?mi
0?l2oiCo00Cooo]Z00Ko0:;ooono0?l0oj;o08cooookJ_l0ob42oookJPWoU?l00_oonfX00olZ0?oo
o`X0oookJP03oookJP07oiCo0?oonf[ooi`0oom10?oonf[o0?lho`P0o`08oookJP03ooo90?oonf[o
oo]Z00;ooo]Z0_nDo`0;oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX03ooonfX0
1Ooo04oooo]ZoookJ_oonf[o0?nF00Gooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP04om;o
0?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX00_oonfX01?ooV`3oo`00onco0?oo0:T5oook
JP03oi<0oooonf[ooo]Z043ooo]Z00?oF@3ooookJ_oonfX02OoonfX00olY0?oooo]ZoookJP02oook
JP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0oookJ_oo00/01?oonfX01?oo=@3ooo]Zo`21oolgo`02
oookJP04o`3oUol0onSooo]ZocKo00kooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00;oookJP03o`3o
kOoonf[ooo]Z00[ooo]Z00?o0?oboad0oooonfX01?oonfX00ooo0;Cooo]ZoonW0007oookJP03o`3o
2Ooonf[ooo]Z00;ooo]Z00GoO03oocCo0?l0;Ooo00_oool06003oookJP03ok3o0?oonf[o0?_o00?o
oo]Z00CoCP3ooookJ_oonf[oo`0D0ooonfX00oooa`3ooo]ZoookJP03oookJP03oonX0?oo0:Oooo]Z
00;ooo]Z00?oob40oookJ_oonfX01?oonfX01?l0oiOooo]ZoookJ_oonfX2ohko0004ool0>Ooonf[o
0?o0o`3o`0;oo`07;ooonfX2ool01`?o0?o00_n>o`02o`3oU`0>o`000?oo8@3oo`2dool0YoooZ03o
oo]Zooo70?oonf[oo`0Dodh0ool0nooo/?l0ool06?l02ol2oookJP06o`3o2Ooonf[oojL0ool0]?oo
nf[o7@3o0ooonfX00ol0ongooo]ZoookJP02oookJP03ool0k?l0hooooo]Z00;ooo]Z00oo0?oXo`3o
Uol0POooocD0oookJ_ooj03ooo]Zo`3ol?oonf[o:@3ooookJ_mI0?oooo]Zool0Z_l0odd00ooonfX0
1Ooo3@3oon<0of`0oooonf[oH_l000Wooo]Z00?oh_l0oe[o0?l0okh00_oonfX01?oo0?Ko00?ooook
J_l0odP2oookJP04o`3oMooonf[oN@3ooiOo00Gooo]Z00Co0:;ooono0?oonf[o0?nR0_oonfX01Ol0
ob7ooo]ZoookJ_oo0?;o0?mF00;ooo]Z00Soo`2PoookJ_oonf[oE03oo`0Uoooonf[o:P3oool:00Co
oo]Z00CoNol0oookJ_ooW03ood400_oonfX00ol0ocSo203ooookJP06oookJP03oolP0?oonf[ooo]Z
00?ooo]Z00?oo`2eoookJ_oonfX02_oonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z
00oooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP05oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oo
nfX01ooBo`3ooo]ZoookJ_oonf[ogOl0oookJ_l[0?l01OoonfX00oooV`3oo`00onco0006oookJP03
oi<0oooonf[ooo]Z01kooo]Z000UoookJP03oeT0oooonf[ooo]Z00Gooo]Z1ooUo`000ooonf[o0?o`
oookJP06oookJP03oooX0?oonf[oo`0;00Cooo]Z00KoocD0oookJ_l0POooolT0oookJ_l0oiL2oook
JP04o`3oj?oob@3oolT0ooo900cooo]Z00Co0>?ooookJ_oonf[oo`3/2ooonfX00ol0ongooo]Zoook
JP0;oookJP03oolJ0?lM0?oooo]Z00Cooo]Z00?oo`2doookJ_ooY`001ooonfX00ol0o`Wooo]Zoook
JP05onGo0003o`0;oooonf[oo`0H00;ooo]Z00?o/?l0o`3koooonfX00ooonfX01?m>0?oooo]Zoook
J_oo01@3oookJP03ooo70?oonf[ooo]Z00;ooo]Z00?oojP0ool0YooonfX00_oonfX00ooo0;Coob40
onGo0009onGo0003ohko0?oUo`3oiOl000;o0?o00_oo00L3oookJP03odCo0?oonf[ooo]Z01;ooo]Z
1?oUo`05odCo01;ooo]Z0_oo00L2o`3o`005ool0>On>o`3o0?nGo`3oUol000000_oo8@002oooZ03o
oo]ZoiCo0?ooa`3oo`0Dodh0oooonf[o0?_ooookJ_nDo`3o00_o00CoA?l000CoojL0odCo0?oonf[o
7@3o0ooonfX00ol0ongooo]ZoookJP02oookJP0:ool0k?oonf[ooo]ZoookJ_lfo`3o0?oXo`21oooo
=@3ooo]ZoooX00;ooo]Z00Oo0?o`obT0oooonf[ooo]ZoeT0oooo0:[o0?m=00?ooo]Z00Goo`d0oooS
0?m/0?oooo]Zof;o0008oookJP07on;o0?oonf[oF_l0o`3o__oonf[oo`3fo`03o`02oookJP06o`3o
B?oonf[ooo]Zo`3oMonDo`3oN@3o0_nDo`04oookJP06o`2Roooo_`3o0?nRo`2<oooonf[o0?lQ0ooo
nfX8oiCo00;ooo]Z00?o04coobX0oooonfX00ooonfX02?nDo`3ooo]ZoonL0?oo@@3ooo]Zo`3o>?oo
nf[o203o1ooonfX00ooob@3ooo]ZoookJP03oookJP03oiCo0?oonf[ooo]Z00[ooo]Z00?o0?neoook
J_oonfX00ooonfX00ol0oh_ooo]ZoookJP0?oookJP05ool0Cooonf[ooo]ZoookJ_l0oiH01OoonfX0
1Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00Cod_l0oookJ_oonf[ogOl00_oonfX00ol[0?oooo]Z
oookJP02oookJP04oonK0?oo003ok?l0ool0Z@Gooo]Z00?oT`3ooookJ_oonfX0@?oonfX00omI0?oo
oo]ZoookJP09oookJP05obT0oooonf[ooo]ZoookJ_l0oo002?oonfX00oooj03ooo]Zool02`04oook
JP03oole0?oonf[o087o00;ooo]Z00Go0?nGoookJ_l0onSooo]ZocKo000>oookJP04o`3Soooonf[o
oo]Zool0k0_ooo]Z00?o0?o]oookJ_oonfX02ooonfX00ooo6P3o7@3ooookJP03oookJP03ool0]?oo
nf[oojL000Oooo]Z00?o0?l9oookJ_oonfX00ooonfX01Oldo`3o02goo`0;oooonf[oo`0H00;ooo]Z
00?o/?l0oookJ_l0nol00ooonfX01?m>0?oooo]ZoookJ_oo01@3oookJP03ooo70?oonf[ooo]Z00?o
oo]Z00?oojP0ool0YooonfX00_oonfX00ooo8@3ooo]ZoookJP03oookJP;o0?nG0ooonfX01on>o`3o
o`0iool0>Ooonf[o0?o0oookJ_oo00L0<ooonfX2ool01`07oookJ_l0ol3o0?o0ohko0?oonf[o0?nG
o`000002oolQ000;ool0]?ooZ03ooo]Zooo70?oonf[oo`0DoookJ_l0nooo/?l0ool06?l02ol00_oo
nfX01_l0o`Wooo]ZoonW0?oo0;Cooo]Zoad0o`?ooo]Z00?o0?o]oookJ_oonfX00_oonfX00ooo0>co
0>?ooookJP02oookJP05o`3oj?l0oiOoocD0oookJ_ooj0000_oonfX02?l0oo3o:@3ooookJ_oonf[o
F@3ooookJ_oo0:[o0?m=0ooonfX01Oooh`3ooo]Zof`0oooonf[oH_l000Sooo]Z00?oh_l0oookJ_mJ
o`000_oonfX01?oo0?Ko00?ooookJ_l0odP2oookJP04o`3oMooonf[oN@3ooiOo00Gooo]Z00Co0:;o
oono0?oonf[o0?nR0_oonfX01Ol0ob7ooo]ZoookJ_oonf[oo`3b00;ooo]Z00Goo`2PoookJ_oonf[o
E03oo`0Uo`02oookJP03obX0oooonf[ooo]Z00;ooo]Z00CoNol0oookJ_ooW03ood400_oonfX00ol0
ocSo203ooookJP06oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?oo`2eoookJ_oonfX02_oonfX00ol0
okGooo]ZoookJP04oookJP03o`3oRooonf[ooo]Z00kooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP05
oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX01ooBo`3ooo]ZoookJ_oonf[ogOl0oookJ_l[
0?l01OoonfX00oooV`3oo`00onco0006oookJP03oi<0oooonf[ooo]Z01kooo]Z000]oookJPOoiOl0
00?ooo]Zo`3ol?oonfX01_oonfX00oooj03oo`0;oookJP04oookJP08oole0?oonf[o087oooo90?oo
nf[o0?nGoookJ_l0onP3ooo900gooo]Z00Co0>?ooookJ_oonf[oo`3/2ooonfX00ol0ongooo]Zoook
JP0:oookJP03oolJ0?lM0?oooo]Z00Cooo]Z00?oo`2doookJ_ooY`002?oonfX00ol0o`Wooo]ZonGo
0005onGo0006o`0;oooo01Sooo]ZoookJ_n`o`3o0?_o1?oonfX01Om>0?oooo]ZoookJ_oonf[oo`0D
00;ooo]Z00?oolL0oookJ_oonfX00_oonfX00oooZ03oo`2WoookJP02oookJP03ool0]?oo8@3oiOl0
00WoiOl000KoS_l0onGo0?l0ol3o0?o0onGo0?oo00LJoookJPCoiOl01om4o`0BoookJP;oo`070_l0
ol001_n>o`3o0000o`3oUol0oiOo0000oolQ00;oojP000KoU?l0ooo70?oo01CoCP3oo`3koon`o`02
odCo0003o`0;oom4o`3oA?l000;oA?l000CoojL0ool0]?l0oo;o7@3o0ooonfX01_l0ongooo]Zoook
J_oonf[oo`3/o`3So`?ooo]Z00oo0?oXo`3oUooo=@3ooo]ZoooX0?oo00_ooo]Zo`3ol?oonf[o:@3o
oookJ_mI0?oooo]Zool0Z_l0odd00_oonfX01Ooo3@3ooo]ZoooS0?m/0?ooH_l000Wooo]Z00?oh_l0
oe[o0?l0okh00_oonfX01?l00ooooo]ZoookJ_l0odP2oookJP03o`3oMooonf[oU?l000;oU?l01Ooo
nfX01Ooo_`3ooo]Zo`3oX_l0S?oo0?lQ00?ooo]Z00?oo`3bo`3oE_nDo`001OnDo`02oookJP03o`1<
oolZ0?oooo]Z00?ooo]Z00CoU?l0oookJ_ooW03ood400_oonfX00ol0ocSo203ooookJP07oookJPCo
olT000?ooo]Zool0]OoonfX02ooonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z00oo
oo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP05oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX0
1ooBo`3ooo]ZoookJ_oonf[ogOl0oookJ_l[0?l01OoonfX00ooo003ooo]Zonco0005oookJP03oi<0
oooonf[ooo]Z04cooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol008oookJP03oooX0?oo00_ooo]Z00Co
oo]Z00?oocD0o`21oolgo`000_oonfX01Ol0oiOo0?oXoookJ_oonf[o=_l000gooo]Z00Co0>?ooook
J_oonf[oo`3/3?oonfX00ol0ongooo]ZoookJP0:oookJP03oolJ0?lM0?oooo]Z00Cooo]Z00?oo`2d
oonW0?oonfX01ooonfX00ol0o`Wooo]ZoookJP02oookJP05og`0ooldo`3ooo]Zo`0;oooo01P00_oo
nfX00on`o`3ooo]Zo`3ko`03oookJP05odh0oooonf[ooo]ZoookJ_oo01@00_oonfX00oooa`3ooo]Z
oookJP03oookJP03oonX0?oo0:Oooo]Z00;ooo]Z00?oob40oookJ_oonfX00ooonfX00ol0oiOooo]Z
oookJP02oookJP03ohko0?oo03Wooo]Z00;o0?o000?ooo]Zool01ooonfX0=OoonfX2ool01`04oook
J_l0ol3oS_l0o`0000;o0?nG00?o0000oolQ0?oo0;@00_ooZ0002_ooa`3oo`0Dodh0ool0nooooo]Z
ok3o0?oo01So00_ooookJ_l0o`T2oookJP04oonW0?oo0;Co0?oboad0o`?ooo]Z00Oo0?o]oookJ_oo
nf[ooo]Zool0k?oonf[o0>?o00;ooo]Z00oo=_l0o`3oj?l0POooocD0oookJ_ooj03ooo]Zo`3ol?oo
nf[o:@3ooookJ_mI0?oooo]Zool0Z_l0odd00ooonfX01Ooo3@3oon<0of`0oooonf[oH_l000Wooo]Z
00Koh_l0oe[o0?oonf[ooo]Zool0m_l00ol2oookJP07o`3oB?oonf[ooo]Zo`3oMooonf[oN@3ooiOo
0005oookJP06oono0?oonf[o0?nRo`2<oooonf[o0?lQ0ooonfX02?oo0?;ooo]ZoookJ_oonf[oo`2P
oookJ_mD0?oo02Go0_oonfX00olZ0?ooo`X0oookJP02oookJP04og_o0?oonf[ooi`0oom100?ooo]Z
00?o0?lhoookJ_oonfX01_oonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z00[ooo]Z
00?o0?neoookJ_oonfX01?oonfX00ol0oh_ooo]ZoookJP0?oookJP04ool0Cooonf[ooo]Zo`3oUPGo
oo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP03om;o0?oonf[ooo]Z00;ooo]Z00?ogOl0ob/0
oooonfX01?oonfX01?ooV`3oo`00ool0ZOo/o`05oookJP03oi<0oooonf[ooo]Z01kooo]Z000/oook
JPOoiOl000?ooo]Zo`3ol?oonfX01_oonfX00oooj03ooo]Zool02`04oookJP06oole0?oonf[o087o
ooo90?oonf[o0?nG0_oonfX01?l0onSoolT0ooo90?oob@0<oookJP04o`3Soooonf[ooo]Zool0k0_o
oo]Z00?o0?o]oookJ_oonfX02ooonfX00ooo6P3o7@3ooookJP04oookJP03ool0]?oonf[oojL000Oo
oo]Z00?o0?l9oookJ_oUo`001OoUo`000ol02oooo`0HoookJP02oookJP03o`3koooonf[ooo]Z00;o
oo]Z00GoCP3ooookJ_oonf[ooo]Zool05002oookJP03ooo70?oonf[ooo]Z00?ooo]Z00OoojP0oook
J_oonf[ooo]Zool0]?oo8@3ooo]Z00WoiOl000?oS_l0onGo0?l0ol000_oUo`000ooo00Oooo]Zoook
JP0HoookJPGoiOl02Om4o`000ooUo`3ooo]ZoookJP0?oookJP03ool01ooonf[o0?o000;oS_l000[o
0000o`3oUonDo`3oob40ool0YoooZ03oU?l0ooo70?oo01CoCP3o0om4o`000ol02oooA?l0odCo0002
odCo0005oonW0?oonf[oo`2doad0oooo6P000_m4o`000ooonf[o0?o]oookJP02oookJP0>ool0k?oo
nf[ooo]ZoookJ_lfo`3o0?oXo`21oooo=@3ooo]ZoooX0?oonf[o0?o`oookJ_lY0?l2oookJP03oeT0
oooo0:[o0?m=00?ooo]Z00GoU?l0oooS0?m/0?ooU?l0of;o0008oookJP03on;o0?oonf[oF_l000;o
oo]Z00Soo`3fo`03oooonf[ooo]Zo`3oB?oonf[o0?mgoookJP?oU?l01OoonfX01Ol0X_oookl0o`3o
X_l0S?oo0?lQ00?ooo]Z00?oo`3bo`3oE_nDo`001OnDo`02oookJP03o`1<oolZ0?ooo`X000?ooo]Z
00CoU?l0oookJ_ooW03ood400_oonfX00ol0ocSo203ooookJP03oookJPSoolT000?ooo]Zool0]Ooo
nfX02ooonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z00oooo]Z00Goo`1?oookJ_oo
nf[ooo]Zo`3oUP05oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX01ooBo`3ooo]ZoookJ_oo
nf[ogOl0oookJ_l[0?l01OoonfX00ooo003ooo]Zonco0005oookJP03oi<0oooonf[ooo]Z04_ooo]Z
00Go:@3ooookJ_oonf[ooo]Zo`3ol008oookJP03oooX0?oonf[oo`0;00Cooo]Z00?oocD0oookJ_l0
POl00_oonfX01Ol0oiOooo]Zo`3oj?oonf[o=_l000kooo]Z00Co0>?ooookJ_oonf[oo`3/2ooonfX0
0ol0ongooo]ZoookJP0;oookJP03oolJ0?lM0?oooo]Z00?ooo]Z00?oo`2doookJ_ooY`001ooonfX0
0ol0o`Wooo]ZoookJP02oookJP05og`0ooldo`3o02goo`0;oooo01P00ooonfX00on`o`3o0?_ooook
JP02oookJP05odh0oooonf[ooo]ZoookJ_oo01@00_oonfX00oooa`3ooo]ZoookJP03oookJP03oonX
0?oo0:Oooo]Z00;ooo]Z00?oob40oookJ_oonfX00ooonfX00ol0oiOooo]ZoookJP02oookJP05ohko
0?oo03Wooo]Zo`3o`?oonfX00_oo00LLoookJP[oo`0h4ooonfX00ooo00Oooo]Zool0>@02ohko000A
o`000?l0oiOooo]ZoolQ0?oo0;Coo`2WoonX0?ooa`3oo`0Dodh0ool0nooooo]Zok3o0?l02oooO03o
oookJ_l0o`T00_oonfX01?ooY`3oo`2doad0oooo6P03oookJP06o`3okOoonf[ooo]ZoookJ_oo0>co
0>?o0ooonfX02Ol0onSo0?nGoole0?oonf[oo`0;oooX0?oonf[o0?o`obT0o`02oookJP03oeT0oooo
0:[o0?m=00Cooo]Z00Goon<0oookJ_m/0?oooo]Zof;o0008oookJP03on;o0?mJo`3o0?nn00;ooo]Z
00Co00?ooookJ_oonf[o0?m80_oonfX01?l0ogOooo]ZogT0oonGo`05oookJP06o`2Roooo_`3o0?nR
o`2<oooonf[o0?lQ0ooonfX02?oo0?;o0?mFoookJ_oonf[oo`2PoookJ_mD0?oo02Go0_oonfX00olZ
0?ooo`X0oookJP02oookJP04og_o0?oonf[ooi`0oom100?ooo]Z00?o0?lhoookJ_oonfX01_oonfX0
0ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z00[ooo]Z00?o0?neoookJ_oonfX01?oonfX0
0ol0oh_ooo]ZoookJP0?oookJP04ool0Cooonf[ooo]Zo`3oUPGooo]Z00Gooa`0oookJ_oonf[ooo]Z
okSo000<oookJP03om;o0?oonf[ooo]Z00;ooo]Z00?ogOl0ob/0oooonfX01?oonfX01?ooV`3oo`00
ool0ZOo/o`05oookJP03oi<0oooonf[ooo]Z01kooo]Z000[oookJPSoiOl000?ooo]Zo`3ol?oonfX0
1_oonfX00oooj03oo`0;oookJP04oookJP09oole0?oonf[o087oooo90?oonf[o0?nGoookJ_oob@3o
0?oX00?oolT03?oonfX00ol0hooooo]Zool0k00<oookJP03o`3okOoonf[ooo]Z00[ooo]Z00?ooaX0
oad0ool0oo801?oonfX00ooo0;Cooo]ZoonW0007oookJP03o`3o2Ooonf[oiOl000KoiOl000Go00_o
oookJ_oonf[ooo]Zo`3ko`04oookJP05odh0oooonf[ooo]ZoookJ_oo01@00_oonfX00oooa`3ooo]Z
oookJP03oookJP06oonX0?oonf[ooo]ZoookJ_oo0;Coob400ooonfX7onGo0003ohko0?oUo`3o0?o0
00;oiOl000?oo`07oookJ_oonfX05_oonfX3ool0>0ooN@3o0_m4o`000ooo03Sooo]ZoookJP0=oook
JP;oo`0700?o0?o0ool0>On>o`000onDo`02oolQ0006oonX0?oonf[oolL0ool05?m>0?oo0?_o0_m4
o`000ol02oooA?l0odCo0002odCo0003oonW0?oonf[oo`2d00?oA?l000?ooo]Zo`3okOoonfX00_oo
nfX00ooo0>co0>?ooookJP02oookJP0>o`3oj?l0oiOo087ooole0?ooj03oo`0;oookJ_l0oo3ooo]Z
obT0oooonf[oF@3ooookJ_l0odd2oookJP;oU?l000Coon<0of`0oonDo`3oH_l02?oonfX01ooRo`3o
oo]Zoe[o0?l0okkooo]Zool0m_l00ol00_oonfX01Ol0odSooo]ZoookJ_l0ogOooo]Z00;oU?l01Ooo
nfX01_l0X_ooU?l0o`3oX_l0S?oooo]Zo`3o8@;ooo]Z00?oo`3bo`3oE_oonfX01OnDo`03oookJP03
obX0oooo2P3ooo]Z00;ooo]Z00CoU?l0oookJ_oonf[ood400_oonfX00ol0ocSo203ooookJP03oook
JPSoolT000?ooo]Zool0]OoonfX02ooonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z
013ooo]Z00Coo`1?oookJ_oonf[o0?nF1_oonfX01?oo703ooo]ZoookJ_nho`0=oookJP04om;o0?oo
nf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX00_oonfX00ooo003ooo]Zonco0005oookJP03oi<0
oooonf[ooo]Z04_ooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol008oookJP03oooX0?oo00_ooo]Z00Co
oo]Z00?oocD0oookJ_l0POl00_oonfX01Ol0oiOooo]Zo`3oj?oonf[o=_l000gooo]Z00Co0>?ooook
J_oonf[oo`3/3?oonfX00ol0ongooo]ZoookJP0:oookJP03oolJ0?lM0?oooo]Z00Cooo]Z00?oo`2d
oonW0?oonfX01_oonfX00ol0o`Wooo]ZoookJP02oookJP05og`0ooldo`3o02goool0Col02ol00ooo
nfX00on`o`3o0?_ooookJP03oookJP04odh0oooonf[ooo]Zool050;ooo]Z00?oolL0oookJ_oonfX0
0ooonfX00oooZ03oo`2WoookJP02oookJP03oolQ0?oonf[ooo]Z00Cooo]Z00[o0?nGoookJ_oonf[o
oo]Zohko0?oo03Wooo]Zo`3o`?oonf[oo`076OoonfX3ool0>0koN@3o1?oo03P>oookJP;oo`0700Ko
0000o`3o`?n>o`3o0000o`3oUooonfX2oolQ000<ool0YoooZ03oolL0ool05?m>0?oo0?_ooookJ_n`
o`3o00_oog`0oooonf[o0?l90_oonfX01?ooY`3oo`2doad0oooo6P02oookJP07o`3okOoonf[ooo]Z
oookJ_oo0>cooo]Zo`3So`03oookJP0>o`3oj?l0POooocD0oookJ_ooj03ooo]Zo`3ol?oonf[o:@3o
oookJ_mI0?oooo]Zool0Z_l0odd3oookJP05oooS0?oonf[oK03ooookJ_mRo`002?oonfX00ooRo`3o
oo]Zoe[o0002oookJP04ool0m_l00ooooo]Zo`3oB0;ooo]Z00Co0?mgoookJ_mi0?ooUol01OoonfX0
1_l0X_oookl0oookJ_l0oj;ooo]Zo`3o8@?ooo]Z00Goo`3bo`3oE_oonf[ooo]Zool0X002oookJP05
oe@0oooonf[ooo]ZobX0oooo2P000ooonfX01?mko`3ooo]ZoookJ_oo@@03oookJP03o`3o>?l80?oo
oo]Z00Kooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP0:oookJP03o`3o]Ooonf[o
oo]Z00Cooo]Z00?o0?n;oookJ_oonfX03ooonfX01?oo04oooo]ZoookJ_l0oiH6oookJP04oolL0?oo
nf[ooo]ZokSo00gooo]Z00Ood_l0oookJ_oonf[ooo]Zomgo0?oonf[o:`3o00Cooo]Z00Cooi/0ool0
0?oo0:Wok?l01OoonfX00onC0?oooo]ZoookJP0NoookJP00;_oonfX5onGo0003o`3ol?oonf[ooo]Z
00Kooo]Z00?oonP0ool02ooonfX01?oonfX01Ooo=@3ooo]Zo`21oooonf[o0?nG00;ooo]Z00?o0?oX
ooo90?oob@000_oob@0;oookJP04o`3Soooonf[ooo]Zool0k0cooo]Z00?o0?o]oookJ_oonfX02_oo
nfX00ooo6P3o7@3ooookJP04oookJP03ool0]?ooY`3ooo]Z00Oooo]Z00?o0?l9onGo0?oUo`001OoU
o`001_l02ooooo]ZoookJ_oonf[o/?l0o`3ko`?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05002oook
JP03ooo70?oonf[ooo]Z00?ooo]Z00KoojP0ool0Yooonf[ooo]Zool0]?oo8@05oookJPGoiOl000?o
S_l0onGo0?l0ol000_oUo`000ooo00Oooo]ZoookJP0DoookJP03ool0>?m4o`3oA?l000?oN@3o00Co
iOl0okSo0?nho`3o^?l02om4o`000omi0?ooA?l0odCo0003ogT0o`03ool0>?oonf[ooo]Z00_ooo]Z
0_oo00L00ol0ol3oS_l0oiCo0002oiCo0008ool0]?oo8@3oojP0oookJ_ooa`3oo`0Dodh0ool0nol2
odCo0003o`0;oom4o`3oA?l000OoA?l00_oonfX01Ol0ongooo]ZoookJ_oonf[oo`3/00Cooo]Z00ko
0?oXocOo0?oo=@3ooo]ZoooX0?oonf[o0?o`oookJ_lY0?oooo]ZoeT0oooonf[oo`2Zo`3oC@CoU?l0
00Coon<0of`0oonDo`3oH_l02?oonfX00ooRo`3oF_l0o`3o_P02oookJP04o`03oooonf[ooo]Zo`3o
B0;ooo]Z00Co0?mgoookJ_nDo`3oU?l01OoonfX01_l0X_ooU?l0o`3oX_l0S?oooo]Zo`3o8@?ooo]Z
00?oo`3bo`3oE_nDo`001?nDo`001Ol09Ooooo]ZoookJ_lZ0?ooo`X000?ooo]Z00CoU?l0oookJ_oo
nf[ood400_oonfX00ol0ocSo203ooookJP04oookJPOoolT000?ooo]Zool0]OoonfX02ooonfX00ol0
okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z013ooo]Z00Coo`1?oookJ_oonf[o0?nF1_oonfX0
1Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00Cod_l0oookJ_oonf[ogOl00_oonfX00ol[0?oooo]Z
oookJP02oookJP03ool00?oonf[ok?l000Gooo]Z00?oT`3ooookJ_oonfX0BooonfX01?lY0?oooo]Z
oookJ_l0oo09oookJP03oooX0?oo00_ooo]Z00Cooo]Z00OoocD0o`21oooonf[ooo]Zo`3oUooonf[o
0?oX00;ooo]Z00?o=_l0oookJ_oonfX02ooonfX01?l0hooooo]ZoookJ_oo0>`<oookJP03o`3okOoo
nf[ooo]Z00[ooo]Z00?ooaX0oad0oooonfX00ooonfX00ooo0;CoojL0oookJP07oookJP09o`3o2Ooo
nf[ooo]ZoookJ_ml0?oooo]ZocCo0?oonf[o00_o00?ooo]Z00?o/?l0oookJ_l0nol00ooonfX01?m>
0?oooo]ZoookJ_oo01@2oookJP03ooo70?oonf[ooo]Z00Cooo]Z00GoojP0ool0Yooonf[ooo]ZoolQ
0006oookJP0:o`3oUooonf[ooo]ZoookJ_n>o`3oo`0ioookJ_l0ol3ooo]Zool01aOooo]Z0ooo03P3
ogT0o`03oookJ_nho`3o^?l000_o^?l01_mi0?l2ool0>0cooo]Z0_oo00L00ol0ol3oS_l0oookJP02
o`3oU`0Cool0]?oo8@3oo`2WoonX0?ooa`3oo`0Dodh0ool0nooooo]Zok3o0?l02oooO03ooookJ_l0
o`Wooo]ZoonW0?oo0;Co0?oboad0o`03oookJP06o`3okOoonf[ooo]ZoookJ_oo0>co0>?o0ooonfX0
3_l0onSo0?nGoole0?oonf[oo`0;oooX0?oonf[o0?o`obT0oooonf[oF@3ooookJ_oo0:[o0?m=0ooo
nfX01Ooo3@3oon<0oookJ_m/0?ooH_l000Wooo]Z00Koh_l0oe[o0?oonf[ooo]Zool0m_l00ol2oook
JP07o`3oB?oonf[ooo]Zo`3oMomi0?ooobL0oiOo0004oookJP04o`2Roooo_`3ooo]Zo`3oXP;ooo]Z
00Go0?lQoookJ_oonf[oo`3bo`3oEP02oookJP08ool0X?oonf[ooo]Zoe@0ool09Ooooo]ZobX0oooo
2P03oookJP04og_o0?oonf[ooo]Zoom100?ooo]Z00?o0?lho`P0oooonfX01_oonfX00ooo803ooo]Z
oookJP02oookJP03ool0]Ooonf[ooo]Z00_ooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]Z
oookJP0?oookJP04ool0Cooonf[ooo]Zo`3oUPKooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oook
JP07om;o0?oonf[ooo]ZoookJ_oMo`3ooo]Zob/0o`04oookJP04oonK0?oo003oo`2Yonco00Gooo]Z
00?oT`3ooookJ_oonfX07_oonfX002oooo]Z00GoiOl0oookJ_oUo`3oiOl0o`3ol008oookJP03oooX
0?oo00_ooo]Z00?ooo]Z00WoocD0oookJ_l0POooolT0oookJ_l0oiOooo]Zooo90?l0onP01?oob@0;
oookJP03o`3Soooonf[oo`3/00cooo]Z00?o0?o]oookJ_oonfX02_oonfX00ooo6P3ooo]Zoad0o`04
oookJP03ool0]?oonf[oojL000Oooo]Z00?o0?l9onGo0?oUo`001OoUo`000ol02oooo`0HoookJP02
oookJP03o`3koooonf[ooo]Z00;ooo]Z00CoCP3ooookJ_oonf[oo`0D0_oonfX00oooa`3ooo]Zoook
JP03oookJP06oonX0?oo0:Oooo]ZoookJ_oo0;Coob401_oonfX4onGo0003ohko0?oo03Wo0?o000;o
iOl000?oo`07oookJ_oonfX04_oonfX3ool0>0?oN@3o1?nho`000om4o`3oo`2lool0_00<ool0_0Co
A?l000?o^?l0ogT0oomi0?l00_mi0?l:oookJP05odCo0?nDo`3oo`07o`3o`?n>o`000onDo`002ooo
0;Coob40oonX0?ooa`3ooo]Zool05?m>0?oo0?_oodCo0?l02ooo=?l000WoA?l000?ooo]Zo`3okOoo
nfX00ooonfX02Ooo0>cooo]ZoookJ_oonf[o0?oXo`3oUol0POooocD0oooX0002oookJP07o`3ol?lY
0?oooo]ZoookJ_mI0?oooo]Zo`3oC@04oiCo0004oooS0?m/0?ooU?l0of;o00Sooo]Z00?oh_l0oook
J_mJo`000_oonfX01?oo0?Ko00?ooookJ_l0odP2oookJP04o`3oMooonf[ooo]ZoiCo00Kooo]Z00Go
U?l0oookJ_l0oj;ooo]Zo`3o8@03oookJP03ool0l_l0oeKooo]Z00CoU?l000Ko02GooookJ_oonf[o
:P3ooookJ_oo2P02oookJP08oiCo0?oonf[ooo]ZoonL0?oo@@3ooo]Zo`3o>?l80?l5oookJPOoolT0
00?ooo]Zool0]OoonfX02ooonfX00ol0okGooo]ZoookJP04oookJP03o`3oRooonf[ooo]Z00oooo]Z
00Coo`1?oookJ_oonf[o0?nF1_oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00Cod_l0oook
J_oonf[ogOl00_oonfX00ol[0?oooo]ZoookJP02oookJP03ool00?oonf[ok?l000Gooo]Z00?oT`3o
oookJ_oonfX0B_oonfX01OlY0?oooo]ZoookJ_oonf[o0?o`00Sooo]Z00?oonP0oookJ_oo00/01?oo
nfX00ooo=@3ooo]Zo`21o`02oookJP05o`3oUooonf[o0?oXoookJ_lfo`003OoonfX01?l0hooooo]Z
oookJ_oo0>`<oookJP03o`3okOoonf[ooo]Z00[ooo]Z00?ooaX0oad0oooonfX01?oonfX00ooo0;Co
ojL0oookJP06oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z00GoO03oocCo0?l0;Ooo00_oool06003oook
JP03ok3o0?l0nooooo]Z00;ooo]Z00CoCP3ooookJ_oonf[oo`0D0_oonfX00oooa`3ooo]ZoookJP04
oookJP05oonX0?oo0:Oooo]ZoookJ_oo8@001_oonfX02?l0oiOooo]ZoookJ_oonf[oS_l0ool0>Ooo
nf[o0?o00_oonfX00ooo00Oooo]ZoookJP0BoookJP?oo`0h0omi0?l4okSo017oo`2l0_nho`04ogT0
o`03ool0>?oonf[ooo]Z00Oooo]Z0_l000000ooo00Oo0?o0ohko0002oookJP0<o`3oUooo0;Coob40
oonX0?oonf[oolL0ool05?m>0?oo0?_ook3o0?oonf[o00_o0_oonfX01_l0o`Wooo]ZoonW0?oo0;Co
7@3ooolJ00;ooo]Z00?o0?o]oookJ_oonfX00_oonfX00ooo0>co0>?ooookJP02oookJP08o`3oj?l0
POooocD0ool02oooj03ooo]Zo`3ol?lY0?l2oookJP03oeT0oooonf[o0?m=00Cooo]Z00Goon<0oook
J_m/0?oooo]Zof;o0008oookJP06on;o0?mJo`3o0?nnoookJ_oo0?Ko00?o0_oonfX01ol0odSooo]Z
oookJ_l0ogOooo]ZogT0oonGo`001OoonfX00ooo_`3ooo]Zo`3oXP02oookJP05o`3o8Ooonf[ooo]Z
oookJ_oo0?800ooonfX02?oo0:3ooo]Zoe@0ool09Ooooo]ZobX0ool0C?ooo`X00_oonfX01Omko`3o
oo]ZoookJ_ooW03ood4000;ooo]Z00?o0?lho`P0oooonfX01_oonfX00ooo803ooo]ZoookJP02oook
JP03ool0]Ooonf[ooo]Z00_ooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0?oook
JP04ool0Cooonf[ooo]Zo`3oUPKooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP07om;o0?oo
nf[ooo]ZoookJ_oMo`3ooo]Zob/0o`04oookJP04oonK0?oo003oo`2Yonco00Gooo]Z00?oT`3ooook
J_oonfX07_oonfX002oooo]Z00GoiOl0oookJ_oonf[ooo]Zo`3ol007oookJP03oooX0?oo00_ooo]Z
00Cooo]Z00KoocD0oookJ_l0POoooo]Zo`3oUooonfX2ooo90003o`3oj?oob@3oolT000;oolT02ooo
nfX00ol0hooooo]Zool0k00<oookJP03o`3okOoonf[ooo]Z00Wooo]Z00?ooaX0oookJ_lM0?l01Ooo
nfX00ooo0;CoojL0oookJP06oookJP04o`3o2Ooonf[ooo]ZoookJPGoiOl000Ko00_ooookJ_oonf[o
oo]Zok3o0?l0nol3oookJP05odh0oooonf[ooo]ZoookJ_oo01@00_oonfX00oooa`3ooo]ZoookJP03
oookJP05oonX0?oo0:Oooo]ZoookJ_oo8@001_oonfX01ol0oiOooo]ZonGo0?oUo`3oS_l0ool0>Ol0
ol000_oUo`000ooo00Oooo]ZoookJP0AoookJP;oo`0h00?ooo]ZogT0oomi0?l00_nho`03oiCo00?o
o`2l2_m4o`03of`0o`KoA?l00_oo0;`2okSo00?oN@3o1ooonfX00om4o`3o0000o`000002ool01`0?
ohko0?nDo`3oU?l0oiCo0?oo0;Coob40oonX0?ooa`3ooo]Zool05?m>0?oo0?_oodCo0?l02ooo=?l0
00SoA?l00_oonfX01Ol0ongooo]ZoookJ_oonf[oo`3/00Cooo]Z00go0?oXoookJ_oo=@3ooo]ZoooX
0?oonf[o0?o`oookJ_lY0?oooo]ZoeT0oooonf[o0?m=00GoU?l000?oK03ooiCo0?mRo`002?oonfX0
1ooRo`3ooo]Zoe[o0?l0okkooo]Zool0m_l00ol00_oonfX01ol0odSooo]ZoookJ_l0ogOooo]ZoiCo
0?oo9`001OoonfX01OnDo`3ooo]Zo`3oX_oonf[o0?lQ00?ooo]Z00?oo`3bo`3oE_oonfX01?nDo`00
1_mD0?oooo]ZoookJ_l0C?oo:P3oool:00?ooo]Z00CoU?l0oookJ_ooW03ood400_oonfX00ol0ocSo
oo]ZoookJP04oookJPKoolT000?ooo]Zool0]OoonfX02ooonfX00ol0okGooo]ZoookJP04oookJP03
o`3oRooonf[ooo]Z00oooo]Z00Coo`1?oookJ_oonf[o0?nF1_oonfX01Ooo703ooo]ZoookJ_oonf[o
^?l000cooo]Z00Cod_l0oookJ_oonf[ogOl00_oonfX00ooUo`3ooo]ZoookJP02oookJP03ool00?oo
nf[ok?l000Gooo]Z00?oT`3ooookJ_oonfX0B_oonfX01OlY0?oooo]ZoookJ_oonf[o0?o`00Sooo]Z
00?oonP0ool02ooonfX01?oonfX01Ooo=@3o=ol0o`21oooonf[o0?nG00;ooo]Z00?o0?oXoookJ_lf
o`003OoonfX01?l0hooooo]ZoookJ_oo0>`<oookJP03o`3okOoonf[ooo]Z00Wooo]Z00?ooaX0o`3o
l_lM0?l01?oonfX00ooo0;CoojL0oookJP06oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z00GoO03ooook
J_ldo`3oo`1?o`0;o`03oookJP03ok3o0?oonf[o0?_o00;ooo]Z00GoCP3ooookJ_oonf[ooo]Zool0
5002oookJP03ooo70?oonf[ooo]Z00?ooo]Z00KoojP0ool0Yooonf[ooo]ZoolQ0?oo0;@5oookJP08
o`3oUooonf[ooo]ZoookJ_n>o`3oo`0ioookJ_l0ol02oookJP03ool01ooonf[ooo]Z013ooo]Z0ooo
03P00ooonf[oN@3oogT0o`02okSo00Goo`2l1OoonfX8of`0o`Cooo]Z1Ooo0;`01Onho`3oN@3oogT0
oomi0?ooo`0h00Kooo]Z0ol00002ool01`0Aohko0?oonf[ooo]Zo`3oUooo0;Coob40oonX0?oonf[o
olL0ool05?m>0?oo0?_ook3o0?oo01So00_ooookJ_l0o`T00_oonfX01?ooY`3oo`2doad0oooo6P02
oookJP06o`3okOoonf[ooo]ZoookJ_oo0>co0>?o1?oonfX01?l0onSoocD0oookJ_ooj002oookJP07
o`3ol?lY0?oooo]ZoeT0oooonf[oo`2Zo`3oC@03oookJP05ool=0?ooh`3oK03ooookJ_mRo`002?oo
nfX00ooRo`3ooo]Zoe[o0002oookJP04ool0m_l00ooooo]Zo`3oB0;ooo]Z00Co0?mgoookJ_mi0?oo
Uol01OoonfX00ooo_`3ooo]Zo`3oXP02oookJP05o`3o8Ooonf[ooo]ZoookJ_oo0?800ooonfX01?oo
0:3ooo]Zoe@0ool09Ol2oookJP03obX0oooo2P3ooo]Z00;ooo]Z00CoNol0oookJ_ooW03ood400ooo
nfX00ol0ocSooo]ZoookJP05oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX02ooo
nfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z00oooo]Z00Coo`1?oookJ_oonf[o0?nF
1_oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00Ood_l0oookJ_oonf[ooo]Zomgo0?oonf[o
:`3o00Cooo]Z00Cooi/0ool00?oo0:Wok?l01OoonfX00onC0?oooo]ZoookJP0NoookJP00;ooonfX0
1?oUo`3ooo]ZoookJ_l0oo08oookJP03oooX0?oo00_ooo]Z00Cooo]Z00SoocD0oookJ_l0POoooo]Z
o`3oUooonf[oolT0o`3oj0GoolT02_oonfX01?l0hooooo]ZoookJ_oo0>`<oookJP03o`3okOoonf[o
oo]Z00Wooo]Z00?ooaX0oookJ_lM0?l01?oonfX00ooo0;Cooo]ZoonW0007oookJP03o`3o2Ooonf[o
oo]Z00;ooo]Z0ooUo`001_l02oooiOl0oookJ_oonf[o/?l0o`3ko`?ooo]Z00GoCP3ooookJ_oonf[o
oo]Zool05002oookJP03ooo70?oonf[ooo]Z00?ooo]Z00GoojP0ool0Yooonf[ooo]ZoolQ0006oook
JP07o`3oUooonf[ooo]ZoookJ_n>o`3oo`0io`3o`002oookJP03ool01ooonf[ooo]Z017ooo]Z00Co
o`0hoookJ_mi0?ooN@3o1OnDo`0<odCo00Gooo]Z00?o0?l<odCo0?m4o`001Om4o`001?oonf[oo`2l
ool0_?oo0;`2okSo00;oN@3o1?oonfX3odCo0005o`000?nDo`3oU?l0ool01on>o`000onDo`002_oo
8@3oo`2WoonX0?ooa`3ooo]Zool05?m>0?oo0?_oodCo0?l02ol8odCo00;ooo]Z00?o0?o]oookJ_oo
nfX00_oonfX02Ooo0>cooo]ZoookJ_oonf[o0?oXo`3oUol0POooocD0oooX0002oookJP07o`3ol?lY
0?oooo]ZoookJ_mI0?oooo]Zo`3oC@04oiCo0005oooS0?m/0?oooo]ZoiCo0?oonfX00onDo`04oook
JP06on;o0?mJo`3o0?nnoookJ_oo0?Ko00?o0_oonfX01Ol0odSooo]ZoookJ_l0ogOooo]Z00GoU?l0
0_oonfX01OnDo`3ooo]Zo`3oX_l0S?oo0?lQ00?ooo]Z00Coo`3bo`3oE_oonf[ooo]Z0onDo`001_mD
0?oooo]ZoookJ_l0C?oo:P3oool:00?ooo]Z1?nDo`02oookJP03o`3o>?l80?oooo]Z00Cooo]Z1_oo
b@000ooonf[oo`2eoookJP0<oookJP03o`3o]Ooonf[ooo]Z00?ooo]Z00?o0?n;oookJ_oonfX03ooo
nfX01?oo04oooo]ZoookJ_l0oiH6oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX01?oBo`3o
oo]ZoookJ_oMo`02oookJP03onGo0?oonf[ooo]Z00;ooo]Z00?oo`00oookJ_o/o`001OoonfX00onC
0?oooo]ZoookJP1:oookJP04obT0oooonf[ooo]Zo`3ol0Wooo]Z00?oonP0ool02ooonfX01?oonfX0
1ooo=@3o087ooookJ_oonf[o0?nGoookJ_l0onP00_oonfX00olfo`3ooo]ZoookJP0;oookJP04o`3S
oooonf[ooo]Zool0k0_ooo]Z00?o0?o]oookJ_oonfX02_oonfX00ooo6P3o7@3ooookJP04oookJP03
ool0]?ooY`3ooo]Z00Kooo]Z00?o0?l9oookJ_oonfX00_oonfX01Oml0?oo=?l0oookJ_l02oooo`0H
00;ooo]Z00?o/?l0oookJ_l0nol00_oonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00;ooo]Z00?oolL0
oookJ_oonfX00ooonfX01_ooZ03ooo]Zool0Yooonf[oob40ool0]0Gooo]Z00So0?nGoookJ_oonf[o
oo]Zohko0?oo03Wooo]Zo`3o`0;ooo]Z00?oo`07oookJ_oonfX04?oonfX00ooo03Sooo]ZoookJP02
ogT0o`04oookJ_nho`3oo`2lool0_0Gooo]Z1Om/0?l8oookJPSoK03o00Gooo]Zool0_?oo0;coo`2l
okSo0003ogT0o`Cooo]Z1?l000004ooonf[oo`07ohko0?oo03Wooo]Zo`3oUooo8@3ooo]ZoonX0?oo
nf[oolL0ool05?m>0?oo0?_ook3o0?l02ooo=?l0oookJ_l0o`T00_oonfX00oooY`3o7@3ooolJ0002
oookJP03o`3okOoonf[ooo]Z00;ooo]Z00?oo`3/o`3SoooonfX00_oonfX02?l0onSo087ooole0?oo
00_oonP0oookJ_l0oo3o:@3o0_oonfX00omI0?oooo]Zo`3oC@03oookJP06ool=0?ooh`3ooo]Zof`0
oooonf[oH_l02?oonfX02?oRo`3oF_l0oookJ_oonf[oo`3fo`03oooonf[o0?m80ooonfX00ol0ogOo
N@3ooiOo0005oookJP06oono0?oonf[o0?nRo`2<oooonf[o0?lQ0ooonfX02?oo0?;o0?mFoookJ_oo
nf[oo`2PoookJ_mD0?oo02Go0_oonfX00olZ0?ooo`X0oookJP02oookJP04og_o0?oonf[ooi`0oom1
00?ooo]Z00?o0?lhoookJ_oonfX01OoonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z
00_ooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0?oookJP04ool0Cooonf[ooo]Z
o`3oUPKooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP07om;o0?oonf[ooo]ZoookJ_oMo`3o
oo]Zob/0o`04oookJP04oonK0?oo003oo`2Yonco00Gooo]Z00?oT`3ooookJ_oonfX07_oonfX002ko
oo]Z00GoiOl0oookJ_oonf[ooo]Zo`3ol008oookJP03oooX0?oo00_ooo]Z00?ooo]Z00KoocD0oook
J_oob@3o087ooookJ_l0oiL2ooo90003o`3oj?oob@3oolT000;oolT02ooonfX00ol0hooooo]Zool0
k00<oookJP03o`3okOoonf[ooo]Z00Wooo]Z00CooaX0oookJ_lM0?oo0?ob1?oonfX00ooo0;Cooo]Z
oonW0006oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z00GoO03oonGo0?oo04ooiOl0o`0;o`03oookJP05
ok3o0?l0nooooo]ZoookJ_m>0?l00ooonfX01Ooo01Cooo]ZoookJ_oonf[oolL000Cooo]Z00GoojP0
ool0Yooonf[ooo]ZoolQ0006oookJP07o`3oUooonf[ooo]ZoookJ_n>o`3oo`0io`3o`002oookJP03
ool01ooonf[ooo]Z017ooo]Z00?oo`0hogT0oonDo`001_nDo`0:odCo00Sooo]Z1_m4o`02o`3o30;o
A?l00_m/0?l2ool0_005oookJ_nho`3oN@3oogT0oooonfX01Om4o`03oiCo0003ool01on>o`3oU?l0
00;oU?l000Woob40ool0YoooZ03oolL0oookJ_oo01Co0?l<o`3kool02ol02?m4o`03oookJP05o`3o
kOoonf[ooo]ZoookJ_oo0>`01?oonfX02?l0onSo087ooole0?oonf[oonP0oookJ_l0oo3o:@3o0_oo
nfX00omI0?oooo]Zo`3oC@04oiCo0003oooS0?m/0?ooU?l000GoU?l01?oonfX00ooRo`3ooo]Zoe[o
0002oookJP04ool0m_l00ooooo]Zo`3oB0WoU?l00_oonfX01Ol0X_ooU?l0o`3oX_l0S?oo0?lQ00?o
oo]Z00Coo`3bo`3oE_oonf[ooo]Z0onDo`001OmD0?oooo]ZoookJ_l0C?oo:P3o00SoU?l00_oonfX0
0ol0ocSo203ooookJP04oookJPKoolT000?ooo]Zool0]OoonfX03?oonfX00ol0okGooo]ZoookJP03
oookJP03o`3oRooonf[ooo]Z00oooo]Z00Coo`1?oookJ_oonf[o0?nF1_oonfX01Ooo703ooo]Zoook
J_oonf[o^?l000cooo]Z00Cod_l0oookJ_oonf[ogOl00_oonfX00ooUo`3ooo]ZoookJP02oookJP03
ool00?oonf[ok?l000Gooo]Z00?oT`3ooookJ_oonfX0BOoonfX01OlY0?oooo]ZoookJ_oonf[o0?o`
00Sooo]Z00?oonP0oookJ_oo00/01?oonfX00ooo=@3o=ol0o`21o`02oookJP05o`3oUooonf[o0?oX
oookJ_lfo`003OoonfX01?l0hooooo]ZoookJ_oo0>`<oookJP03o`3okOoonf[ooo]Z00Wooo]Z00?o
oaX0oookJ_lM0?l01?oonfX00ooo0;Cooo]ZoonW0006oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z00Go
=?l0o`0]oooo04oo00_oool06002oookJP05ok3o0?oonf[o0?_ooookJ_m>0?l00ooonfX01Ooo01Co
oo]ZoookJ_oonf[oolL000Cooo]Z00KoojP0oookJ_oo0:Oooo]ZoolQ0?oo0;@5oookJP08o`3oUooo
nf[ooo]ZoookJ_n>o`3oo`0ioookJ_l0ol02oookJP03ool01ooonf[ooo]Z013ooo]Z00Koo`0hoook
J_mi0?ooN@3ooookJ_nho`02ool0_0Cooo]Z0om/0?lEoookJPCoK03o0_oo0;`2okSo00;oN@3o0_oo
nfX5o`00000CoookJ_oo00OoS_l0ool0>Ol0oiOooo]ZoolQ0?oonf[oojP0oookJ_ooa`3oo`0Doook
J_l0nooo/?l0o`0;ooldo`3ooo]Zo`3o2@02oookJP03oonW0?lM0?oooaX000;ooo]Z00Ko0?o]oook
J_oonf[ooo]Zool0k?l0hol3oookJP05ocKo0?l0onSoocD0oookJ_ooj0000_oonfX01ol0oo3ooo]Z
oookJ_mI0?oooo]Zool0Z_l0odd00ooonfX01Oooh`3ooo]Zof`0oooonf[oH_l000Sooo]Z00Koh_l0
oe[o0?l0okkooo]Zool0m_l00ol2oookJP07o`3oB?oonf[ooo]Zo`3oMomi0?ooobL0oiOo0004oook
JP06o`2Roooo_`3ooo]Zo`3oX_oonf[o0?lQ0ooonfX02?oo0?;o0?mFoookJ_oonf[oo`2PoookJ_mD
0?oo02Go0_oonfX00olZ0?ooo`X0oookJP02oookJP04og_o0?oonf[ooi`0oom100?ooo]Z00?o0?lh
oookJ_oonfX01_oonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z00[ooo]Z00?o0?ne
oookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0?oookJP04ool0Cooonf[ooo]Zo`3oUPKooo]Z00Go
oa`0oookJ_oonf[ooo]ZokSo000<oookJP07om;o0?oonf[ooo]ZoookJ_oMo`3ooo]Zob/0o`05oook
JP03ool00?oo0:Wok?l000Gooo]Z00?oT`3ooookJ_oonfX07_oonfX002kooo]Z00GoiOl0oookJ_oo
nf[ooo]Zo`3ol007oookJP03oooX0?oonf[oo`0;00Cooo]Z00GoocD0oookJ_l0POoooo]Zo`3oU`03
ooo90003o`3oj?oob@3oolT000;oolT02_oonfX01?l0hooooo]ZoookJ_oo0>`<oookJP03o`3okOoo
nf[ooo]Z00Wooo]Z00?ooaX0oookJ_lM0?l01?oonfX00ooo0;Cooo]ZoonW0007oookJP03o`3o2Ooo
nf[ooo]Z00;ooo]Z00GoiOl0oookJ_oo04oo00_oonGo0002oookJP03ok3o0?oonf[o0?_o00;ooo]Z
00CoCP3ooookJ_oonf[oo`0D0ooonfX00oooa`3ooo]ZoookJP02oookJP06oonX0?oonf[oo`2Woook
J_oo8@3oo`2d1_oonfX01_l0oiOooo]ZoookJ_n>o`3oo`0io`3o`0;ooo]Z00?oo`07oookJ_oonfX0
4?oonfX:oiCo0003oookJ_m4o`3oA?l000KoA?l00ooonfX7ond0o`KoA?l00ol0o``2odCo00;ooo]Z
00?oK03oool0_?oo0;`00_nho`06odCo0006o`000?nDo`3oU?l0oiCo0?oo00OoS_l00onDo`002Ooo
8@3ooo]ZoonX0?ooa`3oo`0Do`3o3?l0nooo/?l0o`0;o`08odCo00?ooo]Z00Go0?o]oookJ_oonf[o
oo]Zool0k003oookJP09o`3oj?l0oiOoocD0oookJ_ooj03ooo]Zo`3ol?oonf[o:@3o00;ooo]Z00?o
F@3oo`3oCOoonfX01?nDo`000om/0?ooU?l0oiCo0004oiCo00Cooo]Z00?oh_l0oookJ_mJo`000_oo
nfX01?oo0?Ko00?ooookJ_l0odP9oiCo00?ooo]Z00GoU?l0oookJ_l0oj;oU?l0o`3o8@02oookJP03
ool0l_l0oeKooo]Z00;ooo]Z0_nDo`001OmD0?oo02GooookJ_oonf[o:P3o00SoU?l00_oonfX00ol0
ocSo203ooookJP05oookJPCoolT00_oonfX00ooo0;Gooo]ZoookJP0;oookJP03o`3o]Ooonf[ooo]Z
00?ooo]Z00?o0?n;oookJ_oonfX03ooonfX01?oo04oooo]ZoookJ_l0oiH6oookJP05oolL0?oonf[o
oo]ZoookJ_nho`003?oonfX01?oBo`3ooo]ZoookJ_oMo`02oookJP03onGo0?oonf[ooo]Z00?ooo]Z
00?oo`00onco0?oonfX01?oonfX00onC0?oooo]ZoookJP19oookJP05obT0oooonf[ooo]ZoookJ_l0
oo002?oonfX00oooj03ooo]Zool02`04oookJP05oole0?lgo`3o087ooookJ_l0oiL00_oonfX00ol0
onSooo]ZocKo000=oookJP04o`3Soooonf[ooo]Zool0k0cooo]Z00?o0?o]oookJ_oonfX02OoonfX0
0ooo6P3o7@3ooookJP03oookJP03ool0]?oonf[oojL000Oooo]Z00?o0?l9oookJ_oonfX00_oonfX0
1Oml0?oo=?l0oookJ_l02oooo`0H00;ooo]Z00?o/?l0oookJ_l0nol00_oonfX01?m>0?oooo]Zoook
J_oo01@3oookJP03ooo70?oonf[ooo]Z00;ooo]Z00OoojP0oookJ_oo0:Oooo]ZoolQ0?oonf[oo`2d
00Gooo]Z00Oo0?nGoookJ_oonf[oS_l0ool0>Ooonf[o0?o000;ooo]Z00?oo`07oookJ_oonfX04?oo
nfX01Ooo03SoN@3oogT0oooonf[o^?l000;oo`2l0ooonfX3of`0o`Sooo]Z3_o]0?l6oookJP;oK03o
0_oo0;`01?nho`3ooo]ZogT0oomi0?l4o`0000?ooo]Z01Koo`07ohko0?oo03Wo0?nGoookJ_oo8@3o
o`2WoonX0?oonf[oo`0Dodh0ool0nooo/?l0ool06?l02ooo=?l0oookJ_l0o`Wooo]ZoonW0?l0oo;o
7@3o0ooonfX01_l0ongooo]ZoookJ_oonf[oo`3/o`3So`?ooo]Z00So0?oXoole0?oonf[oo`0;oooX
0?oonf[o0?o`obT0o`;ooo]Z00?oF@3oool0Z_l0odd00ooonfX01Ooo3@3oon<0of`0oooonf[oH_l0
00Sooo]Z00Koh_l0oookJ_mJo`3ooo]Zool0m_l00ol2oookJP07o`3oB?oonf[ooo]Zo`3oMomi0?oo
obL0oiOo0005oookJP05oono0?oonf[o0?nRoookJ_l0ob400ooonfX03?oo0?;o0?mFoookJ_oonf[o
o`2PoookJ_mD0?oooo]Zo`0Uoooonf[o:P3oool:00?ooo]Z00CoNol0oookJ_oonf[ood400ooonfX0
0ol0ocSo203ooookJP06oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX02_oonfX0
0ol0okGooo]ZoookJP04oookJP03o`3oRooonf[ooo]Z00oooo]Z00?oo`1?oookJ_l0oiH01_oonfX0
1Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00Ood_l0oookJ_oonf[ooo]Zomgo0?oonf[o:`3o00Go
oo]Z00?ooi/0ool00?o/o`001OoonfX00onC0?oooo]ZoookJP0NoookJP00;_oonfX01OoUo`3ooo]Z
oookJ_oonf[o0?o`00Oooo]Z00?oonP0ool02ooonfX01?oonfX01Ooo=@3ooo]Zo`21oooonf[o0?nG
00;ooo]Z00?o0?oXooo90?oob@000ooob@0:oookJP04o`3Soooonf[ooo]Zool0k0cooo]Z00?o0?o]
oookJ_oonfX02OoonfX00ooo6P3o7@3oo`3olP04oookJP03ool0]?oonf[oojL000Oooo]Z00Wo0?l9
oookJ_oonf[ooo]Zog`0oooUo`3oo`1?o`0;oooo01P00_oonfX00on`o`3ooo]Zo`3ko`02oookJP05
odh0oooonf[ooo]ZoookJ_oo01@00ooonfX00oooa`3ooo]ZoookJP02oookJP05oonX0?oo0:Oooo]Z
oookJ_oo8@001_oonfX02Ol0oiOooo]ZoookJ_n>o`3oo`0ioookJ_l0ol3ooo]Zool01`0AoookJP_o
U?l00_m/0?l8odCo00?ok@3o0om4o`02oigo00;o0?l<1Om4o`05o`3o30;oU?l00ooonfX00om/0?oo
o`2lool0_007odCo0006oookJ_nDo`3oU?l0oiCo0?oo00OoS_l00_nDo`002ol0o`coob40o`3o3?oo
Z03oolL0ool05?m>0?oo0?_oo`3o3?l02ooo=?l000KoA?l00ooonfX01Ol0ongooo]ZoookJ_oonf[o
o`3/00?ooo]Z00Go0?oXo`3oUol0POooocD0oooX0002odCo0007o`3ol?lY0?oooo]ZoookJ_mI0?oo
oo]Zo`3oC@04oiCo0003oooS0?m/0?ooU?l000CoU?l01OoonfX01_oRo`3oF_l0o`3o__oonf[oo`3f
o`03o`;ooo]Z00?o0?m8oiCo0?nDo`001_nDo`000ooonf[oU?l0oiCo0002oiCo0003o`3oX_nDo`3o
0?lQ00?ooo]Z00Coo`3boookJ_oonf[ooo]Z0_nDo`001_mD0?oo02GooookJ_oonf[o:P3oool:00Oo
U?l00_oonfX00ol0ocSo203ooookJP05oookJPCoolT00_oonfX00ooo0;Gooo]ZoookJP0;oookJP03
o`3o]Ooonf[ooo]Z00?ooo]Z00?o0?n;oookJ_oonfX04?oonfX00ooo04oooo]Zo`3oUP06oookJP05
oolL0?oonf[ooo]ZoookJ_nho`003?oonfX01?oBo`3ooo]ZoookJ_oMo`02oookJP03onGo0?oonf[o
oo]Z00?ooo]Z00?oo`00onco0?oonfX01?oonfX00onC0?oooo]ZoookJP19oookJP05obT0oooonf[o
oo]ZoookJ_l0oo002?oonfX00oooj03oo`0;oookJP04oookJP07oole0?l0POoooo]ZoookJ_l0oiOo
oo]Zo`3oj002oookJP03ocKo0?oonf[ooo]Z00[ooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00;oook
JP03o`3okOoonf[ooo]Z00[ooo]Z00?ooaX0oad0oooonfX00ooonfX00ooo0;Cooo]ZoonW0007oook
JP03o`3o2Ooonf[ooo]Z00;ooo]Z00Oo=?l0o`0]ool02ooooo]Zool06?oonf[o/?l000;ooo]Z00?o
0?_ooookJ_m>0?l00ooonfX01Ooo01Cooo]ZoookJ_oonf[oolL000Cooo]Z00KoojP0oookJ_oo0:Oo
oo]ZoolQ0?oo0;@5oookJP05o`3oUooonf[ooo]Zohko0?oo03T00_oonfX00ol0ol3ooo]Zool01`0B
oookJP06ool0>?mi0?oooo]ZoookJ_nho`3oo`2l0ooonfX2of`0o`Sooo]Z0oo]0?l>oigo00Cok@3o
1?oonfX2of`0o`;oo`2l00?o^?l0ool0>?mi0?l00ol00004oookJP0Aool01on>o`3oo`0io`3oUooo
0;Coob40ool0YoooZ03ooo]Zool05?m>0?oo0?_ook3o0?oo01So00_ooookJ_l0o`T00_oonfX00ooo
Y`3o7@3ooolJ0002oookJP06o`3okOoonf[ooo]ZoookJ_oo0>co0>?o0ooonfX01Ol0onSo0?nGoole
0?oonf[oonP000;ooo]Z00Ko0?o`oookJ_oonf[oF@3ooookJ_l0odd3oookJP05ool=0?ooh`3oK03o
oookJ_mRo`002OoonfX02?oRo`3oF_l0oookJ_oonf[oo`3fo`03oooonf[o0?m80ooonfX00ol0ogOo
N@3ooiOo0005oookJP05oono0?oonf[o0?nRoookJ_l0ob400ooonfX00ooo0?;o0?mFoookJP02oook
JP07ool0X?oonf[oE03oo`0Uoooonf[o:P3oool:0003oookJP04og_o0?oonf[ooo]Zoom100?ooo]Z
00?o0?lho`P0oooonfX01_oonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z00[ooo]Z
00?o0?neoookJ_oonfX01?oonfX00ol0oh_ooo]ZoookJP0?oookJP03ool0Cooonf[o0?nF00Kooo]Z
00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP07om;o0?oonf[ooo]ZoookJ_oMo`3ooo]Zob/0o`05
oookJP03oonK0?oo003ok?l000Cooo]Z00?oT`3ooookJ_oonfX07ooonfX002gooo]Z00GoiOl0oook
J_oonf[ooo]Zo`3ol008oookJP03oooX0?oo00_ooo]Z00?ooo]Z00KoocD0oookJ_lgo`3o087ooook
J_l0oiL2oookJP04o`3oj?oonf[oolT0oookJP;oolT02OoonfX01Ol0hooooo]ZoookJ_oonf[oo`3/
00_ooo]Z00?o0?o]oookJ_oonfX02OoonfX00ooo6P3ooo]Zoad0o`04oookJP03ool0]?oonf[oojL0
00Oooo]Z00?o0?l9oookJ_oonfX00_oonfX01OoUo`3oo`1?oookJ_l02oooo`0H00;ooo]Z00?o/?l0
oookJ_l0nol00_oonfX01?m>0?oooo]ZoookJ_oo01@3oookJP03ooo70?oonf[ooo]Z00;ooo]Z00Ko
ojP0oookJ_oo0:Oooo]ZoolQ0?oo0;@5oookJP09o`3oUooonf[ooo]ZoookJ_n>o`3ooo]Zo`3o`?oo
nf[oo`0701;ooo]Z2_nDo`000om/0?ooA?l0odCo0005odCo00?ok@3o1?m4o`001Ooonf[oo`3LoeL0
oomG0?oo0?l<00KoA?l01ol0o``01?nDo`3oA?l0oookJ_oonfX2odCo00;oo`2l1Om4o`02oookJP;o
A?l000?oU?l0ool01on>o`000ol0o``01Ooo8@3o0?l<oonX0?l0o`coo`0D00;o0?l<00?o00_oool0
Coldo`001Om4o`001OlM0?oo0?l<oookJ_oonf[o0?o]00;ooo]Z00?oo`3/o`3SoooonfX00_oonfX0
2?l0onSoA?l0oole0?m4o`3oonP0odCo0?l0oo3o:@3o0_oonfX01?mI0?oooo]Zo`3oCOoonfX3oiCo
0003oooS0?m/0?ooU?l000CoU?l01OoonfX00ooRo`3oF_l0o`3o_P02oookJP04ool0m_l00ooooo]Z
o`3oB0goU?l000?o0?nRoiCo0?l0ob400ooonfX00ooo0?;o0?mFoookJP02oookJP03oiCo0?oonf[o
E03o00;ooo]Z00?o:P3oool:0?nDo`001_nDo`03oookJP03o`3o>?oonf[ooo]Z00Gooo]Z0ooob@02
oookJP03ool0]Ooonf[ooo]Z00_ooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0@
oookJP03ool0Cooonf[o0?nF00Kooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP04om;o0?oo
nf[ooo]Zomgo00;ooo]Z00?oiOl0oookJ_oonfX00ooonfX00ooo003ok?l0oookJP04oookJP03oi<0
oooonf[ooo]Z04Sooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol008oookJP03oooX0?oonf[oo`0;00Co
oo]Z00?oocD0ocOo0?l0POl00_oonfX01Ol0oiOooo]Zo`3oj?oonf[o=_l000gooo]Z00Co0>?ooook
J_oonf[oo`3/3?oonfX00ol0ongooo]ZoookJP09oookJP03oolJ0?lM0?oooo]Z00?ooo]Z00?oo`2d
oookJ_ooY`001ooonfX00ol0o`Wooo]ZoookJP02oookJP05ocCo0?oonf[oo`1?o`0;oooo01P00_oo
nfX00on`o`3ooo]Zo`3ko`02oookJP04odh0oooonf[ooo]Zool050?ooo]Z00?oolL0oookJ_oonfX0
0_oonfX01oooZ03ooo]Zool0Yooonf[oob40oookJ_oo0;@01?oonfX01Ol0oiOooo]ZoookJ_oonf[o
S_l000;ooo]Z00?o0?o0oookJ_oo00L04_oonfX00ooo03SoN@3ooookJP02okSo0005ool0_?oonf[o
oo]ZoookJ_m/0?l01ooonfX3ond0o`?oWOl00_oonfX2ool0g0_oE`3o00?oo`3Loigo0?nMo`000_o]
0?l4oookJP;oK03o0_oo0;`01?nho`3oN@3oo`000?l00005oookJP0Fool01on>o`3ooo]Zo`3oUooo
0;Coob40ool0YoooZ03ooo]Zool05?m>0?oo0?_ook3o0?l02ooo=?l0oookJ_l0o`Wooo]ZoonW0?oo
0;Co7@3ooolJ00;ooo]Z00Ko0?o]oookJ_oonf[ooo]Zool0k?l0hol2oookJP05ocKo0?l0onSoocD0
oookJ_ooj0000_oonfX01ol0oo3ooo]ZoookJ_mI0?oooo]Zool0Z_l0odd00ooonfX01Oooh`3ooo]Z
of`0oooonf[oH_l000Sooo]Z00Koh_l0oe[o0?l0okkooo]Zool0m_l00ol2oookJP06o`3oB?oonf[o
oo]Zo`3oMomi0?ooUol01OoonfX00ooo_`3ooo]Zo`3oXP02oookJP05o`3o8Ooonf[ooo]Zool0l_l0
oeH00ooonfX01ooo0:3ooo]Zoe@0ool09Ooooo]ZobX0oooo2P000ooonfX01?mko`3ooo]ZoookJ_oo
@@04oookJP03o`3o>?oonf[ooo]Z00Gooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]Zoook
JP0:oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX03ooonfX00ooo04oooo]Zo`3o
UP06oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX01ooBo`3ooo]ZoookJ_oonf[ogOl0oook
J_l[0?l01OoonfX00oooV`3oo`00onco0004oookJP03oi<0oooonf[ooo]Z01oooo]Z000]oookJP05
onGo0?oonf[ooo]ZoookJ_l0oo002?oonfX00oooj03oo`0;oookJP03oookJP03oole0?oonf[o087o
00;ooo]Z00Go0?nGoookJ_oonf[o0?oXooo9000=oookJP04o`3Soooonf[ooo]Zool0k0cooo]Z00?o
0?o]oookJ_oonfX02OoonfX00ooo6P3o7@3oo`3olP04oookJP03ool0]?oonf[oojL000Oooo]Z00Wo
0?l9oookJ_oonf[ooo]Zog`0ooldo`3oo`1?o`0;oooo01P00_oonfX00on`o`3ooo]Zo`3ko`03oook
JP04odh0oooonf[ooo]Zool050?ooo]Z00?oolL0oookJ_oonfX00_oonfX01OooZ03oo`2WoookJ_oo
nf[oob4000Gooo]Z00Wo0?nGoookJ_oonf[ooo]Zohko0?oo03Wooo]Zo`3o`?oo00L04OoonfX:oiCo
00;oK03o1_m4o`02ond0o`?oA?l00ooo0=`3oeL0o`03oong0?oonf[o0?l<00ko0?l<00?oU?l0odCo
0?oonfX00_oonfX2odCo00;oo`2l1om4o`000onDo`3oo`07ohko0008o`3o3005ool05?l0o`co0?l<
o`0;ooldo`001_m4o`001?l0o`cooo]ZoookJ_l0ond3oookJP0=ool0k?oonf[oA?l0odCo0?l0onSo
A?l0o`21oooo=@3oonP0odCo0?l0oo3ooo]ZobT0o`02oookJP03oeT0ool0odgoolT000CoolT000?o
K03ooiCo0?nDo`000onDo`05oookJP03on;o0?mJo`3o0?nn00;ooo]Z00Goo`3fo`03oooonf[o0?m8
oookJP0<oiCo0003o`3oX_nDo`3o0?lQ00?ooo]Z00?oo`3bo`3oE_oonfX00_oonfX00ooo0:3ooo]Z
oe@0o`02oookJP03obX0oooo2P3ooo]Z00KoU?l000Cood40oookJ_oonf[o0?lh1ooonfX3ooo900;o
oo]Z00?oo`2eoookJ_oonfX02ooonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z013o
oo]Z00?oo`1?oookJ_l0oiH01_oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00Cod_l0oook
J_oonf[ogOl00_oonfX00ooUo`3ooo]ZoookJP03oookJP03ool00?o/o`3ooo]Z00Cooo]Z00?oT`3o
oookJ_oonfX0B?oonfX01OlY0?oooo]ZoookJ_oonf[o0?o`00Sooo]Z00?oonP0oookJ_oo00/01?oo
nfX00ooo=@3o=ol0o`21o`02oookJP05o`3oUooonf[o0?oXoookJ_lfo`003OoonfX01?l0hooooo]Z
oookJ_oo0>`<oookJP03o`3okOoonf[ooo]Z00Wooo]Z00?ooaX0oad0oooonfX00ooonfX00ooo0;Co
oo]ZoonW0007oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z00Oo=?l0o`0]ool02ooooo]Zool06?oonf[o
/?l000;ooo]Z00Co0?_ooookJ_oonf[oCP3o0_oonfX01Ooo01Cooo]ZoookJ_oonf[oolL000Cooo]Z
00KoojP0oookJ_oo0:Oooo]ZoolQ0?oo0;@4oookJP06o`3oUooonf[ooo]ZoookJ_n>o`3oo`0i0_oo
nfX00ol0ol3oo`07oookJP0AoookJP06ool0>?mi0?oooo]ZokSo0?oonf[oo`2l0_oonfX2of`0o`Oo
oo]Z00Gok@3ooigo0?nMo`3oWOl0oookJP03ool0g0?oE`3o00?ooo]Zoi<0oonC0?l02?nC0?l3oeL0
o`;oo`3L0_o]0?l4oookJP06of`0oooonf[oo`2lool0_?mi0?ooo`0h1OoonfX04Ooo00Oo0?o0ohko
0?l0oiOooo]Zool0]?oo8@3oojP0oookJ_ooa`3oo`0DoookJ_l0nooo/?l0o`0;ooml0?oo0?l900;o
oo]Z00?oojL0oad0oooo6P000_oonfX01_l0ongooo]ZoookJ_oonf[oo`3/o`3So`?ooo]Z00So0?oX
o`21oooo=@3oo`0;oooX0?oonf[o0?o`obT0o`;ooo]Z00?oF@3oool0Z_l0odd00ooonfX01Ooo3@3o
on<0of`0oooonf[oH_l000Sooo]Z00Koh_l0oe[o0?l0okkooo]Zool0m_l00ol2oookJP06o`3oB?oo
nf[ooo]Zo`3oMomi0?ooUol01OoonfX00ooo_`3ooo]Zo`3oXP02oookJP06o`3o8Ooonf[ooo]Zool0
l_oonf[o0?mF0_oonfX01ooo0:3ooo]Zoe@0ool09Ooooo]ZobX0oooo2P000ooonfX01Omko`3ooo]Z
oookJ_ooW03ood4000?ooo]Z00?o0?lhoookJ_oonfX01OoonfX00ooo803ooo]ZoookJP02oookJP03
ool0]Ooonf[ooo]Z00[ooo]Z00?o0?neoookJ_oonfX01?oonfX00ol0oh_ooo]ZoookJP0?oookJP03
ool0Cooonf[o0?nF00Kooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP07om;o0?oonf[ooo]Z
oookJ_oMo`3ooo]Zob/0o`05oookJP03oonK0?oo003ok?l000Cooo]Z00?oT`3ooookJ_oonfX07ooo
nfX002gooo]Z00GoiOl0oookJ_oonf[ooo]Zo`3ol007oookJP03oooX0?oonf[oo`0;00Cooo]Z00?o
ocD0oookJ_l0POl00_oonfX01Ol0oiOooo]Zo`3oj?oonf[oolT000cooo]Z00Go0>?ooookJ_oonf[o
oo]Zool0k00<oookJP03o`3okOoonf[ooo]Z00Wooo]Z00?ooaX0oad0ool0oo800ooonfX01?oo0;Co
oo]ZoookJ_ooY`07oookJP09o`3o2Ooonf[ooo]ZoookJ_ldo`3o02goool0Col02oooo`0H00;ooo]Z
00?o/?l0oookJ_l0nol00_oonfX01?m>0?oooo]ZoookJ_oo01@3oookJP03ooo70?oonf[ooo]Z00;o
oo]Z00GoojP0oookJ_oo0:Oooo]ZoolQ0005oookJP03o`3oUooonf[ooo]Z00;ooo]Z00CoS_l0oook
J_l0ol3oo`074OoonfX:oiCo0003of`0oooonf[ooo]Z00GoA?l000Cok@3oodCo0?m4o`3oA?l00_oo
0=`3oeL0o`;ooo]Z0_nC0?l00ol0o`coo`00ool00004ool000[o0?l<00KoU?l0odCo0?o]0?oo0?l<
oookJ_l0o``2odCo0003ool0_?m4o`3oA?l000GoA?l000?o0?l<ool01on>o`001ol0o``01ooo01Co
0?l<o`3o3?l0o`co00_oocCo0?l0o``01?m4o`001OlM0?oooo]ZoookJ_oonf[o0?o]00;ooo]Z00?o
o`3/o`3Soom4o`000_nDo`002?l0onSo087ooole0?m4o`3oonP0oookJ_l0oo3o:@3o2Ooob@000ooo
h`3oK03ooiCo0003oiCo00Gooo]Z00?oh_l0oookJ_mJo`000_oonfX01Ooo0?Ko00?ooookJ_l0odSo
oo]Z00goU?l000?o0?nRo`3o8OoonfX00_oonfX00ooo0?;o0?mFoookJP02oookJP03ool0X?oonf[o
E03o00;ooo]Z00?o:P3oool:0?oonfX01_nDo`001?oo@@3ooo]ZoookJ_l0ocP8oookJP;oolT00_oo
nfX00ooo0;Gooo]ZoookJP0;oookJP03o`3o]Ooonf[ooo]Z00?ooo]Z00?o0?n;oookJ_oonfX04?oo
nfX01?oo04oooo]ZoookJ_l0oiH5oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX01?oBo`3o
oo]ZoookJ_oMo`02oookJP03onGo0?oonf[ooo]Z00?ooo]Z00?oo`00ool0ZOo/o`001?oonfX00onC
0?oooo]ZoookJP18oookJP05obT0oooonf[ooo]ZoookJ_l0oo002?oonfX00oooj03ooo]Zool02`04
oookJP03oole0?l0POoooo]Z00;ooo]Z00Go0?nGo`3oj?oonf[ooo]ZocKo000<oookJP05o`3Soooo
nf[ooo]ZoookJ_oo0>`02ooonfX00ol0ongooo]ZoookJP0:oookJP03oad0ool0oo;ooo]Z00;ooo]Z
00Coo`2doookJ_oonf[oojL01ooonfX02Ol0o`Wooo]ZoookJ_oonf[o=?l0oookJ_oo04oo00_oool0
6002oookJP03ok3o0?oonf[o0?_o00;ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05002oookJP03ooo7
0?oonf[ooo]Z00;ooo]Z00KoojP0oookJ_oo0:Oooo]ZoolQ0?oo0;@4oookJP03o`3oUooonf[ooo]Z
00;ooo]Z00GoS_l0oookJ_oonf[o0?o0ool01`0BoookJP06ool0>?mi0?oooo]ZokSo0?oonf[oo`2l
0_oonfX00om/0?oooo]ZoookJP05oookJP;ok@3o00?oWOl0oookJ_oo0=`00_oo0=`3oeL0o`05oook
J_nC0?ooT`3ooi<0oooo0:T01ooo0002ool0Z@?oT`3o0_mG0?l00ooo]`3oo`3Lond0o`02ond0o`;o
oo]Z0_m/0?l01?l0003oo`2logT0oooo03P5oookJP0Aool01ol0ol3oS_l0o`3oUooonf[oo`2doolQ
0?ooZ03ooo]Zool05?m>0?oo0?_ook3o0?oo01So00_ooookJ_l0o`T00_oonfX00oooY`3o7@3ooolJ
0002oookJP06o`3okOoonf[ooo]ZoookJ_oo0>co0>?o0_oonfX01Olfo`3o0?oXoole0?oonf[oonP0
00;ooo]Z00Ko0?o`oookJ_oonf[oF@3oool0Z_l0odd3oookJP05ool=0?ooh`3oK03ooookJ_mRo`00
2?oonfX01_oRo`3ooo]Zoe[o0?oonf[oo`3fo`03o`;ooo]Z00Ko0?m8oookJ_oonf[o0?mgogT0oonG
o`05oookJP06oono0?oonf[o08coo`3oX_oonf[o0?lQ0ooonfX03?oo0?;o0?mFoookJ_oonf[oo`2P
oookJ_mD0?oo02GooookJ_lZ0?oo04coool:00?ooo]Z00CoNol0oookJ_ooW03ood400ooonfX00ol0
ocSooo]ZoookJP05oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX02ooonfX00ol0
okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z00oooo]Z00Coo`1?oookJ_oonf[o0?nF1OoonfX0
1Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00Ood_l0oookJ_oonf[ooo]Zomgo0?oonf[o:`3o00Go
oo]Z00Cooi/0ool00?oonf[ok?l00ooonfX00onC0?oooo]ZoookJP0OoookJP00;?oonfX00ooUo`3o
oo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0ool02ooonfX00ooonfX01_oo=@3o
oo]ZoookJ_l0POoooo]Zo`3oU`;ooo]Z00?o0?oXoookJ_oob@003?oonfX01Ol0hooooo]ZoookJ_oo
nf[oo`3/00_ooo]Z00?o0?o]oookJ_oonfX02OoonfX00ooo6P3o7@3oo`3olP04oookJP03ool0]?oo
nf[oojL000Oooo]Z00Wo0?l9oookJ_oonf[ooo]Zog`0ooldo`3oo`1?o`0;oooo01P00ooonfX00on`
o`3o0?_ooookJP02oookJP04odh0oooonf[ooo]Zool050?ooo]Z00?oolL0oookJ_oonfX00_oonfX0
1OooZ03oo`2WoookJ_oonf[oob4000Gooo]Z00Wo0?nGoookJ_oonf[ooo]Zohko0?oo03Wo0?o0oook
J_oo00L03ooonfX6oiCo0003okSo0?nDo`3oU?l000;oU?l000?oK03ooookJ_oonfX00_oonfX2odCo
00;ok@3o0_m4o`02ool0g0;oE`3o0_oonfX2oi<0o`Coo`004_l0o``01?m4o`3ok@3oond0ooo]0?l2
o`3o30SoA?l00_l0o``00ooo00OoS_l0o`3o3006o`3o3005ool05?l0o`co0?l<o`0;oooo04l00_l0
o``3odCo0005oolJ0?lM0?oooo]ZoookJ_l0ond00_oonfX5oiCo0008o`3oj?m4o`3o087ooole0?oo
j03ooo]Zo`3ol?lY0?l9ooo90003oooS0?m/0?ooU?l000?oU?l01OoonfX01?oRo`3ooo]Zoe[o0?l0
okh2oookJP05ool0m_l00ooooo]Zo`3oB?oonfX03?nDo`000ol0oj;ooo]Zo`3o8@02oookJP03ool0
l_l0oeKooo]Z00;ooo]Z00Coo`2PoookJ_mD0?oo02Go0_oonfX00olZ0?oooo]ZoiCo0005oiCo0005
oom10?oonf[ooo]Zo`3o>?l80?l01ooonfX2ooo900;ooo]Z00?oo`2eoookJ_oonfX03?oonfX00ol0
okGooo]ZoookJP02oookJP03o`3oRooonf[ooo]Z013ooo]Z00Coo`1?oookJ_oonf[o0?nF1OoonfX0
1Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00Kod_l0oookJ_oonf[ogOl0oookJ_oUo`06oookJP03
ool00?oo0:Wok?l000Cooo]Z00?oT`3ooookJ_oonfX0AooonfX00olY0?oooo]ZoookJP02oookJP03
o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0oookJ_oo00/01?oonfX00ooo=@3ooo]Zo`21o`02oookJP05
o`3oUooonf[o0?oXoookJ_lfo`003OoonfX01?l0hooooo]ZoookJ_oo0>`<oookJP03o`3okOoonf[o
oo]Z00Wooo]Z00?ooaX0oad0oooonfX00ooonfX00ooo0;Cooo]ZoonW0007oookJP03o`3o2Ooonf[o
oo]Z00;ooo]Z00Go=?l0o`0]ool02ooooo]Zool06002oookJP03ok3o0?oonf[o0?_o00;ooo]Z00Co
CP3ooookJ_oonf[oo`0D0ooonfX00oooa`3ooo]ZoookJP02oookJP06oonX0?oo0:Oooo]ZoookJ_oo
8@3oo`2d1?oonfX02_l0oiOooo]ZoookJ_oonf[oS_l0ool0>Ooonf[o0?o0oookJ_oo00LAoookJP06
ool0>?mi0?oooo]ZokSo0?oonf[oo`2l0_oonfX00om/0?oooo]ZoookJP05oookJP03ond0oonMo`3o
oo]Z00;oo`3L0omG0?l01?oonf[oT`3ooi<0oonC0?l4ool000Oo:`3o1_oo00001_nC0?ooE`3ooeL0
oomG0?oookL0ool0g0?ok@3o00Co0000of`0ool0003oo`2l0_mi0?l5oookJP0Eool01ooonf[oS_l0
o`3oUooonf[oob40ool0YoooZ03oolL0ool05?m>0?oo0?_ook3o0?l02ooo=?l0oookJ_l0o`Wooo]Z
oonW0?l0oo;o7@3o00;ooo]Z00Ko0?o]oookJ_oonf[ooo]Zool0k?l0hol2oookJP05ocKo0?l0onSo
087ooole0?ooj0000_oonfX01ol0oo3ooo]ZoookJ_mI0?oooo]Zool0Z_l0odd00ooonfX01?ooh`3o
K03ooookJ_mRo`08oookJP07on;o0?oonf[oF_l0o`3o__oonf[oo`3fo`03o`02oookJP05o`3oB?oo
nf[o0?mgogT0oonGo`001OoonfX01_oo_`3o0:;ooookJ_l0oj;ooo]Zo`3o8@?ooo]Z00coo`3bo`3o
E_oonf[ooo]Zool0X?oonf[oE03ooookJ_l09Ooooo]ZobX0oooo2P03oookJP04og_o0?oonf[ooo]Z
oom100?ooo]Z00?o0?lhoookJ_oonfX01_oonfX01Ooo803ooo]ZoookJ_oonf[oo`2e00gooo]Z00?o
0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0?oookJP04ool0Cooonf[ooo]Zo`3oUPGooo]Z
00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP07om;o0?oonf[ooo]ZoookJ_oMo`3ooo]Zob/0o`05
oookJP04oonK0?oo003ooo]Zonco00?ooo]Z00?oT`3ooookJ_oonfX07ooonfX002cooo]Z00?oiOl0
oookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP05oookJP03oooX0?oo00_ooo]Z00?ooo]Z00KoocD0
oookJ_l0POoo=ol0oookJ_l0oiL2oookJP03o`3oj?oob@3ooo]Z00cooo]Z00Co0>?ooookJ_oonf[o
o`3/3?oonfX00ol0ongooo]ZoookJP09oookJP03oolJ0?lM0?oo0?ob00Cooo]Z00?oo`2doookJ_oo
Y`001ooonfX02Ol0o`Wooo]ZoookJ_oonf[oO03oocCo0?oo04oo00_oool06002oookJP03ok3o0?oo
nf[o0?_o00;ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05002oookJP03ooo70?oonf[ooo]Z00;ooo]Z
00GoojP0ool0Yooonf[ooo]ZoolQ0005oookJP09o`3oUooonf[ooo]ZoookJ_n>o`3oo`0ioookJ_l0
ol3oo`0700oooo]Z1onDo`001Ooo0;coU?l0oiCo0?nDo`3oK03o00Gooo]Z00CoA?l0ond0oom4o`3o
A?l00_oo0=`2oeL0o`;ooo]Z00CoT`3oool00?oo003oo`000ol[0?l00ol0o`cogOl0omgo0003omgo
00ko0?l<00?oU?l0ool0g?oo0=`00_o]0?l9odCo00;o0?l<00?oo`07o`3o3?l0o``01_l0o``00ooo
01Co0?l<o`3o3004o`3o30;oA?l000?oo`2doad0oooonfX00ooUo`07oiCo0008o`3oj?l0POooocD0
odCo0?ooj03o0?o`oookJ_lY0?l8ooo90003oooS0?m/0?ooU?l000?oU?l01_oonfX00ooRo`3oF_l0
o`3o_P02oookJP05ool0m_l00ooooo]Zo`3oB?oonfX01OnDo`02oookJPGoU?l000?o0?nRoookJ_l0
ob400_oonfX00ooo0?;o0?mFoookJP02oookJP04ool0X?oonf[oE03oo`0Uo`;ooo]Z00?o:P3ooook
J_oonfX01?nDo`001_oonf[ood40oookJ_oonf[o0?lho`P0o`Oooo]Z0_oob@02oookJP03ool0]Ooo
nf[ooo]Z00cooo]Z00?o0?neoookJ_oonfX00_oonfX00ol0oh_ooo]ZoookJP0@oookJP04ool0Cooo
nf[ooo]Zo`3oUPGooo]Z00?ooa`0oookJ_oonfX00_oonfX00onho`3ooo]ZoookJP09oookJP03om;o
0?oonf[ogOl000;ooo]Z00?oiOl0oookJ_oonfX01?oonfX00ooo003oo`2Yonco0004oookJP03oi<0
oooonf[ooo]Z04Oooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP05oookJP03oooX
0?oonf[oo`0;00Cooo]Z00?oocD0oookJ_l0POl00_oonfX01Ol0oiOooo]Zo`3oj?oonf[o=_l000co
oo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00;oookJP03o`3okOoonf[ooo]Z00[ooo]Z00?o7@3oo`3o
l_oonfX00ooonfX00ooo0;Cooo]ZoonW0007oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z00Wo=?l0o`0]
ool02ooooo]Zool06?oonf[o/?l0oookJ_l0nol00_oonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00;o
oo]Z00?oolL0oookJ_oonfX00_oonfX01_ooZ03ooo]Zool0Yooonf[oob40ool0]0Cooo]Z00Ko0?nG
oookJ_oonf[ooo]Zohko0?oo03T2oookJP03o`3o`?oo00Oooo]Z013ooo]Z00Koo`0hogT0oooonf[o
^?l0oookJ_oo0;`2oookJP03of`0oooonf[ooo]Z00Cooo]Z0_o]0?l00ooonf[oo`3Lool0g002oeL0
o`;ooo]Z0_nC0?l3ool000?o:`3o3OoMo`001Ol[0?ooo`00ool00?oo003oT`3o00;oE`3o00Gooo]Z
ool0g?oo0=cok@3oo`000002of`0o`03ool0_?nho`3oN@3o00Gooo]Z00?oo`07ool0>On>o`000_oo
nfX02ooo8@3oo`2WoonX0?ooa`3oo`0Dodh0ool0noooo`0Ho`0;oooonf[o0?l900;ooo]Z00?oojL0
oad0oooo6P000_oonfX01Ol0ongooo]ZoookJ_oo0>co0>?o00?ooo]Z00So=_l0o`3oj?oo=@3oo`0;
oooX0?oonf[o0?o`obT0o`;ooo]Z00?oF@3oool0Z_l0odd00ooonfX01?oo3@3oon<0of`0oomRo`08
oookJP07on;o0?oonf[oF_l0o`3o__oonf[oo`3fo`03o`02oookJP06o`3oB?oonf[o0?mgoookJ_mi
0?ooUol01OoonfX01Ooo_`3ooo]Zo`3oX_oonf[o0?lQ00?ooo]Z00coo`3bo`3oE_oonf[ooo]Zool0
X?oonf[oE03ooookJ_l09Ooooo]ZobX0oooo2P03oookJP04og_o0?oonf[ooo]Zoom100?ooo]Z00?o
0?lho`P0oooonfX01_oonfX01Ooo803ooo]ZoookJ_oonf[oo`2e00gooo]Z00?o0?neoookJ_oonfX0
0ooonfX00ol0oh_ooo]ZoookJP0?oookJP04ool0Cooonf[ooo]Zo`3oUPGooo]Z00?ooa`0oookJ_oo
nfX00_oonfX00onho`3ooo]ZoookJP09oookJP04om;o0?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooook
J_oonfX00ooonfX01?ooV`3oo`00oookJ_o/o`03oookJP03oi<0oooonf[ooo]Z01oooo]Z000/oook
JP05onGo0?oonf[ooo]ZoookJ_l0oo001ooonfX00oooj03ooo]Zool02`04oookJP03oole0?oonf[o
087o00;ooo]Z00Go0?nGoookJ_l0onSooo]Zooo9000<oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`0
3?oonfX00ol0ongooo]ZoookJP09oookJP03oolJ0?lM0?oo0?ob00?ooo]Z00?oo`2doookJ_ooY`00
1ooonfX00ol0o`Wooo]ZoookJP02oookJP05ocCo0?l0;Oooo`1?o`0;oooo01P00_oonfX00on`o`3o
0?_ooookJP02oookJP04odh0oooonf[ooo]Zool050?ooo]Z00?oolL0oookJ_oonfX00_oonfX01Ooo
Z03oo`2WoookJ_oonf[oob4000Gooo]Z00Wo0?nGoookJ_oonf[ooo]Zohko0?oo03Wo0?o0oookJ_oo
00L03_oonfX7oiCo0006ool0_?oonf[ooo]ZoiCo0?oonf[oK03o1OoonfX01?o]0?ooA?l0odCo0?oo
0=`2oeL0o`;oA?l00ooo00000om4o`3o:`3oob/0o`04omgo00Wo0?l<00?oU?l0o`3o3?l0o``02?l0
o``01_nDo`3oE`3oool0g?oo0=cok@3oo`3o30OoA?l00ol0o``00ooo00Oo0?l<o`3o300=o`3o30;o
A?l01OoUo`07oiCo0008o`3oj?l0POooocD0odCo0?ooj03ooo]Zo`3ol?lY0?l8ooo90003oooS0?nD
o`3oK03o00?oU?l01_oonfX00ooRo`3oF_l0o`3o_P02oookJP06ool0m_l00ooooo]Zo`3oB?oonf[o
0?mg1?nDo`02oookJPGoU?l000?o0?nRoookJ_l0ob400ooonfX01Ooo0?;ooo]ZoookJ_oonf[oo`2P
00;ooo]Z00CoE03ooookJ_oonf[o:P3o0_oonfX4oiCo0006oookJ_oo@@3ooo]ZoookJ_l0ocSo203o
2?oonfX01Ooob@3ooo]ZoookJ_oonf[oo`2e00gooo]Z00?o0?neoookJ_oonfX00_oonfX00ol0oh_o
oo]ZoookJP0@oookJP04ool0Cooonf[ooo]Zo`3oUPGooo]Z00?ooa`0oookJ_oonfX00_oonfX00onh
o`3ooo]ZoookJP09oookJP03om;o0?oonf[ogOl000;ooo]Z00?oiOl0oookJ_oonfX01?oonfX00ooo
003oo`2Yonco0004oookJP03oi<0oooonf[ooo]Z04Oooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol008
oookJP03oooX0?oonf[oo`0;00Cooo]Z00?oocD0o`21oooonfX00_oonfX01Ol0oiOo0?oXoookJ_oo
nf[o=_l000cooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00;oookJP03o`3okOoonf[ooo]Z00[ooo]Z
00?o7@3oo`3ol_oonfX00_oonfX00ooo0;Cooo]ZoonW0007oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z
00Go=?l0oookJ_oo04oo00_oool06002oookJP03ok3o0?oonf[o0?_o00;ooo]Z00CoCP3ooookJ_oo
nf[oo`0D0ooonfX00oooa`3ooo]ZoookJP02oookJP06oonX0?oo0:Oooo]ZoookJ_oo8@3oo`2d1?oo
nfX02_l0oiOooo]ZoookJ_oonf[oS_l0ool0>Ooonf[o0?o0oookJ_oo00L@oookJP06ool0>?mi0?oo
oo]ZokSo0?oonf[oo`2l0ooonfX00om/0?oooo]ZoookJP03oookJP04ond0oonMo`3ooo]Zool0g0;o
E`3o0_oonfX01?nC0?ooo`00ool00?oo0002ob/0o`CogOl03OoonfX3omgo0004ob/0oooo003oo`00
ool000;oE`3o00?oWOl0ool0g?o]0?l00_l000001?m/0?ooo`2lokSo0?mi0?l5oookJP0Dool01ooo
03WoS_l0oookJ_oo8@3oo`2doonX0?ooa`3oo`0Dodh0oooonf[o0?_oo`0;ooldo`3ooo]Zo`3o2Ooo
nf[oojL0o`3ol_lM0?l2oookJP06o`3okOoonf[ooo]ZoookJ_oo0>co0>?o0_oonfX02?lfo`3o0?oX
oole0?oonf[oonP0oookJ_l0oo3o:@3o0_oonfX00omI0?ooo`2Zo`3oC@03oookJP05ool=0?ooh`3o
K03ooookJ_mRo`002?oonfX01_oRo`3oF_l0o`3o__oonf[oo`3fo`03o`;ooo]Z00Ko0?m8oookJ_l0
ogOooo]ZogT0oonGo`05oookJP05oono0?oonf[o0?nRoookJ_l0ob400ooonfX01Ooo0?;o0?mFoook
J_oonf[oo`2P00;ooo]Z00GoE03oo`0Uoooonf[o:P3oool:0003oookJP04og_o0?oonf[ooo]Zoom1
00?ooo]Z00?o0?lho`P0oooonfX01_oonfX01Ooo803ooo]ZoookJ_oonf[oo`2e00gooo]Z00?o0?ne
oookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0?oookJP04ool0Cooonf[ooo]Zo`3oUPGooo]Z00?o
oa`0oookJ_oonfX00_oonfX00onho`3ooo]ZoookJP09oookJP04om;o0?oonf[ooo]Zomgo00;ooo]Z
00?o:`3ooookJ_oonfX00ooonfX01?ooV`3oo`00oookJ_o/o`03oookJP03oi<0oooonf[ooo]Z01oo
oo]Z000[oookJP03onGo0?oonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01OoonfX00oooj03ooo]Z
ool02`03oookJP04oole0?oonf[ooo]Zo`21o`;ooo]Z00Go0?nGoookJ_l0onSooo]Zooo9000<oook
JP05o`3Soooonf[ooo]ZoookJ_oo0>`02ooonfX00ol0ongooo]ZoookJP0:oookJP03oad0ool0oo;o
oo]Z00?ooo]Z00?oo`2doookJ_ooY`001ooonfX02Ol0o`Wooo]ZoookJ_oonf[oO03oocCo0?oo04oo
00_oool06003oookJP03ok3o0?l0nooooo]Z00;ooo]Z00CoCP3ooookJ_oonf[oo`0D0_oonfX00ooo
a`3ooo]ZoookJP02oookJP05oonX0?oo0:Oooo]ZoookJ_oo8@001OoonfX02Ol0oiOooo]ZoookJ_oo
nf[oS_l0ool0>Ooonf[o0?o0ool01`0=oookJPWoU?l000Goo`2loookJ_oonf[ooo]Zof`0o`05oook
JP05ond0oom4o`3oo`3Lool0g?mG0?l00_m4o`001OnC0?ooo`00odCo0?m4o`3o:`3o00?ogOl00_m4
o`02oookJPGo^?l000?ooa`0o`3o3?l0o``01?l0o``5oiCo00Co0?l<00Koo`00oeL0ool0o`coo`3L
ond0ool0o``6odCo00?o0?l<00?oA?l0ool01ol0o``02ol0o``3onGo0003odCo0?oUo`3oiOl000?o
iOl01onDo`002Ol0onSoA?l0o`21oooo=@3oonP0oookJ_l0oo3o:@3ooookJP07ooo90003oiCo0?oo
h`3oK03o00?oU?l01_oonfX00ooRo`3oF_l0o`3o_P02oookJP04ool0m_l00ooooo]Zo`3oB0;ooo]Z
1?nDo`02oookJPGoU?l000?o0?nRoookJ_l0ob400ooonfX01Ooo0?;o0?mFoookJ_oonf[oo`2P00;o
oo]Z00CoE03ooookJ_oonf[o:P3o0ooonfX3oiCo0006oookJ_oo@@3ooo]ZoookJ_l0ocSo203o2?oo
nfX01Ooo803ooo]ZoookJ_oonf[oo`2e00gooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]Z
oookJP0?oookJP04ool0Cooonf[ooo]Zo`3oUPKooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000;oook
JP03om;o0?oonf[ogOl000;ooo]Z00?oiOl0oookJ_oonfX01?oonfX00ooo003oo`2Yonco0004oook
JP03oi<0oooonf[ooo]Z04Kooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP06oook
JP03oooX0?oonf[oo`0;00?ooo]Z00?oocD0oookJ_l0POl00ooonfX01?l0oiOo0?oXoookJ_lfo`0=
oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`02ooonfX00ol0ongooo]ZoookJP09oookJP03oad0ool0
oo;ooo]Z00?ooo]Z00?oo`2doookJ_ooY`001ooonfX00ol0o`Wooo]ZoookJP02oookJP05ocCo0?l0
;Ooo00_ooookJ_oo01P00_oonfX00on`o`3o0?_ooookJP02oookJP04odh0oooonf[ooo]Zool050;o
oo]Z00?oolL0oookJ_oonfX00_oonfX01_ooZ03oo`2WoookJ_oonf[oob40ool0]0Cooo]Z00Ko0?nG
oookJ_oonf[ooo]Zohko0?oo03T2oookJP03o`3o`?oo00Oooo]Z00oooo]Z00Coo`0hogT0oooonf[o
^?l00_oonfX01?oo0;cooo]ZoookJ_m/0?l5oookJP07ond0oonMo`3oo`3Lool0g?mG0?oookL0oook
JP02oi<0o`03ool00?ooV`3ooi/000?ogOl000Cod_l0oookJ_oonf[ooo]Z1Onho`06oolL00Go^?l0
0ooMo`003Ol[0?ooo`00ool00?mG0?ooT`3oool0g?o]0?oo0000oookJ_m/0?ooo`2lokSo0?mi0?l0
1OoonfX03ooo00Ooo`0iohko0?oonf[oob40ool0YoooZ03oolL0ool05?m>0?oo0?_oool06?l02ooo
O03oo`3o2@02oookJP05oonW0?lM0?oooo]ZoookJ_l0ond00ooonfX02Ooo0>co0>?ooookJ_oonf[o
=_l0o`3oj?l0oiOoocD0oooX0002oookJP06o`3ol?oonf[ooo]ZoeT0oooonf[o0?m=1?oonfX01?oo
h`3oK03ooookJ_mRo`08oookJP06on;o0?mJo`3o0?nnoookJ_oo0?Ko00?o0_oonfX01_l0odSooo]Z
oookJ_l0ogOoN@3ooiOo00Gooo]Z00Gookl0oookJ_l0oj;ooo]Zo`3o8@03oookJP05ool0l_oonf[o
0?mFoookJ_oo0:000_oonfX01OmD0?oo02GooookJ_lZ0?ooo`X000?ooo]Z00CoNol0oookJ_oonf[o
od400ooonfX00ol0ocSo203ooookJP06oookJP05oolP0?oonf[ooo]ZoookJ_oo0;D03OoonfX00ol0
okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z00oooo]Z00Coo`1?oookJ_oonf[o0?nF1_oonfX0
1Ooo703ooo]ZoookJ_oonf[o^?l000_ooo]Z00Kod_l0oookJ_oonf[ogOl0oookJ_l[0?l6oookJP04
oonK0?oo003ooo]Zonco00?ooo]Z00?oT`3ooookJ_oonfX07ooonfX002_ooo]Z00?oiOl0oookJ_oo
nfX00_oonfX00ol0oo3ooo]ZoookJP05oookJP03oooX0?oo00_ooo]Z00?ooo]Z00KoocD0oookJ_l0
POoo=ol0oookJ_l0oiL2oookJP03o`3oj?oob@3ooo]Z00_ooo]Z00?oiOl0oookJ_oonfX00_oonfX0
0ooo0>cooo]ZoookJP09oookJP03o`3okOoonf[ooo]Z00Wooo]Z00?ooaX0oad0ool0oo801?oonfX0
0ooo0;CoojL0oookJP07oookJP09o`3o2Ooonf[ooo]ZoookJ_ml0?oo=?l0ool0Col02oooo`0H00;o
oo]Z00?o/?l0oookJ_l0nol00_oonfX01?m>0?oooo]ZoookJ_oo01@3oookJP0:ooo70?oonf[ooo]Z
oookJ_ooZ03ooo]Zool0Yooonf[oo`2doolQ00Gooo]Z00Wo0?nGoookJ_oonf[ooo]Zohko0?oonf[o
0?o0oookJ_oo00L03?oonfX9oiCo0005ool0_?oonf[ooo]ZoookJ_m/0?l00ooonfX2odCo0003ond0
oom4o`3oo`3L00;oE`3o0_m4o`001?nC0?ooo`00odCo0?l[0?l2omgo00?oA?l01?l0o``5oolL0003
ool0Col0o`co0?l<00So0?l<1_nDo`02ool00004oeL0ool0oegok@3oo`3oG@KoA?l00_l0o``00om4
o`3oo`07odCo000;o`3o3003ocCo0?l0o`co0?l<00;o0?l<1?oUo`07oiCo0009ocKo0?l0onSo087o
oole0?oo00_oonP0o`3ol?oonf[o:@3o00OoolT000?oU?l0oooS0?m/0?l00onDo`06oookJP03on;o
0?oonf[oF_l000;ooo]Z00Coo`3fo`03oooonf[o0?m80_oonfX01?l0ogOoU?l0oiCo0?nDo`03oook
JPCoU?l000?o0?nRoookJ_l0ob400ooonfX01Ooo0?;o0?mFoookJ_oonf[oo`2P00;ooo]Z00CoE03o
oookJ_oonf[o:P3o0ooonfX3oiCo0006oookJ_oo@@3ooo]ZoookJ_l0ocSo203o2?oonfX01Ooo803o
oo]ZoookJ_oonf[oo`2e00gooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0?oook
JP04ool0Cooonf[ooo]Zo`3oUPKooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP05om;o0?oM
o`3ooo]ZoookJ_oUo`001OoonfX01?ooV`3oo`00ool0ZOoUo`04oookJP03oi<0oooonf[ooo]Z04Ko
oo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP05oookJP03oooX0?oonf[oo`0;00Co
oo]Z00?oocD0oookJ_l0POl00_oonfX01Ol0oiOooo]Zo`3oj?oonf[o=_l000cooo]Z00Go0>?ooook
J_oonf[ooo]Zool0k00;oookJP03o`3okOoonf[ooo]Z00[ooo]Z00?o7@3oo`3ol_oonfX00ooonfX0
0ooo0;CoojL0oookJP07oookJP09o`3o2Ooonf[ooo]ZoookJ_ml0?oo=?l0o`0]ool02oooo`0H00;o
oo]Z00?o/?l0oookJ_l0nol00_oonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00;ooo]Z00?oolL0oook
J_oonfX00_oonfX01OooZ03oo`2WoookJ_oonf[oob4000Gooo]Z00Go0?nGoookJ_oonf[ooo]Zohko
0002oookJP03o`3o`?oo00Oooo]Z00oooo]Z00Ooo`0hoookJ_mi0?oooo]ZokSo0?oonf[oo`2l00;o
oo]Z00?oK03ooookJ_oonfX00ooonfX02?o]0?ooWOl0ool0g?oonf[oE`3ooong0?oonf[oT`3o0_oo
00001?ooV`3ogOl0omgo0?oBo`03oookJP?o^?l01Ooo7006ool0C`Gooa`00onho`02omgo0006ob/0
oooo003oo`00oeL0oooo0=cok@3o0_oonfX01?m/0?ooo`2lokSo0?mi0?l4oookJP0Dool01ol0ol3o
S_l0o`3oUooonf[oob40oookJ_ooZ03oo`0Dodh0oooonf[o0?_oool06?l02ooooo]Zo`3o2Ooonf[o
ojL0o`3ol_lM0?l2oookJP05o`3okOoonf[ooo]ZoookJ_oo0>`00ooonfX03Olfo`3o0?oXoole0?oo
00_oonP0oookJ_l0oo3o:@3ooookJ_mI0?oooo]Zool0Z_l0odd00ooonfX01?ooh`3oK03ooookJ_mR
o`08oookJP06on;o0?oonf[oF_l0oookJ_oo0?Ko00?o0_oonfX01_l0odSooo]ZoookJ_l0ogOoN@3o
oiOo00Gooo]Z00Gookl0oookJ_l0oj;ooo]Zo`3o8@03oookJP05ool0l_oonf[o0?mFoookJ_oo0:00
0_oonfX01OmD0?oo02GooookJ_lZ0?ooo`X000?ooo]Z00CoNol0oookJ_oonf[ood400ooonfX00ol0
ocSo203ooookJP06oookJP05oolP0?oonf[ooo]ZoookJ_oo0;D03OoonfX00ol0okGooo]ZoookJP04
oookJP03o`3oRooonf[ooo]Z00kooo]Z00Coo`1?oookJ_oonf[o0?nF1_oonfX01Ooo703ooo]Zoook
J_oonf[o^?l000cooo]Z00God_l0oookJ_oMo`3ooo]Zob/0o`06oookJP04oonK0?oo003ooo]Zonco
00?ooo]Z00?oT`3ooookJ_oonfX07ooonfX002_ooo]Z00?oiOl0oookJ_oonfX00_oonfX00ol0oo3o
oo]ZoookJP05oookJP03oooX0?oo00_ooo]Z00?ooo]Z00[oocD0oookJ_l0POoo=ol0oookJ_l0oiOo
oo]Zo`3oj?oonf[oolT03?oonfX01OoUo`3ooo]ZoookJ_oonf[oo`3/00cooo]Z00?o0?o]oookJ_oo
nfX02OoonfX00oooN@3o0?oboookJP03oookJP03ool0]?oonf[oojL000Oooo]Z00Wo0?l9oookJ_oo
nf[ooo]Zog`0ooldo`3ooo]Zool0Col02ol00ooonfX00on`o`3o0?_ooookJP02oookJP04odh0oooo
nf[ooo]Zool050;ooo]Z00?oolL0oookJ_oonfX00_oonfX01_ooZ03oo`2WoookJ_oonf[oo`2doolQ
00Cooo]Z00Wo0?nGoookJ_oonf[ooo]Zohko0?oo03Wo0?o0oookJ_oo00L03?oonfX9oiCo0005ool0
_?oonf[ooo]ZoookJ_m/0?l00_oonfX3odCo0004ond0oom4o`3oo`3LoeL0o`;oA?l00_nC0?l01?oo
003o0?l<ob/0oooMo`05o`3o30Cooa`000?o0?l<ool0Cooo04l00_oo04l>o`3o30GoU?l000Goo`00
o`3oGOl0oegok@3oo`3oG@05odCo00?o0?l<00?oA?l0ool01onDo`003ol0o``4onGo0003odCo0?nD
o`3oU?l000CoU?l000[oA?l0o`3oj?l0POooocD0ool02oooj03ooo]Zo`3ol?lY0?oooo]Z1_oob@00
1?oo3@3oon<0oookJ_m/0?l2oiCo00Kooo]Z00?oh_l0oookJ_mJo`000_oonfX01?oo0?Ko00?ooook
J_l0odP2oookJP04o`3oMonDo`3oU?l0oiCo00?ooo]Z1?nDo`000ol0oj;ooo]Zo`3o8@03oookJP05
ool0l_l0oeKooo]ZoookJ_oo0:000_oonfX01OmD0?oooo]ZoookJ_lZ0?ooo`X000?ooo]Z0_nDo`00
1_oonf[ooi`0oom10?oonf[o0?lho`P0o`Sooo]Z00Goob00oookJ_oonf[ooo]Zool0]@0=oookJP03
o`3o]Ooonf[ooo]Z00?ooo]Z00?o0?n;oookJ_oonfX03_oonfX01Ooo04oooo]ZoookJ_oonf[o0?nF
00Kooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP05om;o0?oMo`3ooo]ZoookJ_oUo`001Ooo
nfX01?ooV`3oo`00oookJ_oUo`04oookJP03oi<0oooonf[ooo]Z04Kooo]Z00?o:@3ooookJ_oonfX0
0_oonfX00ol0oo3ooo]ZoookJP05oookJP03oooX0?oonf[oo`0;00Cooo]Z00?oocD0o`21oolgo`00
0_oonfX01Ol0oiOo0?oXoookJ_oonf[o=_l000cooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00;oook
JP03o`3okOoonf[ooo]Z00Wooo]Z00?o7@3ooolJ0?oonfX00ooonfX00ooo0;Cooo]ZoonW0007oook
JP03o`3o2Ooonf[ooo]Z00;ooo]Z00Go=?l0o`0]oooo04oo00_oool06002oookJP03ok3o0?l0nooo
oo]Z00;ooo]Z00CoCP3ooookJ_oonf[oo`0D0_oonfX00oooa`3ooo]ZoookJP03oookJP05oonX0?oo
nf[ooo]ZoookJ_oo8@001OoonfX02Ol0oiOooo]ZoookJ_n>o`3oo`0ioookJ_l0ol3ooo]Zool01`0?
oookJP07ool0>?oonf[oN@3ooookJ_nho`3ooo]Zool0_002oookJP03of`0oooonf[ooo]Z00?ooo]Z
00Kok@3ooigo0?oo0=cooo]ZoeL0oooo]`02oi<0o`05ool00?o/o`3ooi/0omgo0?oBo`000ooonfX0
0onho`3ooa`0oolL0002oolL0003o`3oU_oo04ooo`1?00;oo`1?1_oonfX4ool0C`04o`3oU_oo703o
oa`0oolL00;o^?l00ooMo`001?oo003oE`3ooeL0ooo]0?l2oookJP04of`0oooo0;coN@3oool0>0Co
oo]Z01?oo`07o`3o`?n>o`3o0?nGoolQ0?oo0;CoojP0ooo70?oo01CoCP3oo`3koooo01So00_oog`0
ool0o`Wooo]Zool0]?ooY`3o7@3o00;ooo]Z00Ko0?o]oookJ_oonf[ooo]Zool0k?l0hol2oookJP08
ocKo0?l0onSoocD0ool02oooj03ooo]Zo`3ol?lY0?l2oookJP03oeT0oooo0:[o0?m=00?ooo]Z00Co
on<0oookJ_m/0?ooH_l02?oonfX01_oRo`3ooo]Zoe[o0?oonf[oo`3fo`03o`;ooo]Z00Ko0?m8oook
J_oonf[o0?mgogT0oonGo`05oookJP03oono0?oonf[o0?nR00;ooo]Z00So0?lQoookJ_oonf[oo`3b
oookJ_l0oeKooo]Zool0X0;ooo]Z00GoE03oo`0Uoooonf[o:P3oool:0003oookJP05og_o0?oonf[o
oo]ZoonL0?oo@@000_oonfX00ol0ocSo203ooookJP06oookJP05oolP0?oonf[ooo]ZoookJ_oo0;D0
3OoonfX00ol0okGooo]ZoookJP04oookJP03o`3oRooonf[ooo]Z00kooo]Z00Coo`1?oookJ_oonf[o
0?nF1_oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00God_l0oookJ_oMo`3ooo]Zob/0o`06
oookJP04ool00?oonf[ooo]Zonco00?ooo]Z00?oT`3ooookJ_oonfX07ooonfX002[ooo]Z00?oiOl0
oookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP05oookJP03oooX0?oonf[oo`0;00?ooo]Z00CoocD0
oookJ_oonf[o087o0_oonfX01Ol0oiOooo]Zo`3oj?oonf[oolT000_ooo]Z0_oUo`03oookJP03ool0
k?oonf[ooo]Z00Wooo]Z00?o0?o]oookJ_oonfX02_oonfX00oooN@3o0?oboookJP03oookJP03ool0
]?oonf[oojL000Oooo]Z00Wo0?l9oookJ_oonf[ooo]Zog`0ooldo`3ooo]Zo`0;oooo01P00_oonfX0
0on`o`3ooo]Zo`3ko`03oookJP03odh0oooonf[oo`0D00?ooo]Z00OoolL0oookJ_oonf[ooo]ZoonX
0?oonf[oo`2W00;ooo]Z00?oob40oookJ_oonfX00ooonfX02Ol0oiOooo]ZoookJ_n>o`3oo`0ioook
J_l0ol3ooo]Zool01`0>oookJPOoU?l000Coo`2loookJ_oonf[oK03o0_oonfX3odCo0004ond0oom4
o`3oA?l0oeL0o`;oA?l000CoT`3oodCo0?oo003oA?l00_oMo`05o`3o3003oolL0?l0o`co0?l<00?o
o`1?00?oA?l0oookJ_oonfX00ooonfX3o`3oG@go0?l<0_nDo`001Ooo003o0?mMo`3oGOo]0?oo0?l<
00GoA?l00_l0o``2oiCo0003ool01onDo`3o0?l<00go0?l<1?oUo`000om4o`3oU?l0oiCo0004oiCo
000:odCo0?l0onSoA?l0oole0?oonf[oonP0oookJ_l0oo3o:@3ooookJPGoolT000Gooo]Zool=0?oo
h`3ooo]Zof`0o`02oiCo00Oooo]Z00Soh_l0oe[o0?l0okkooo]Zool0m_l00ooooo]Zo`3oB0;ooo]Z
00Co0?mgoookJ_nDo`3oU?l01?oonfX3oiCo0004o`3oX_oonf[ooo]Zo`3o8@;ooo]Z00Goo`3bo`3o
E_oonf[ooo]Zool0X002oookJP05oe@0oooonf[ooo]ZobX0oooo2P000ooonfX2oiCo0006oookJ_oo
W03ood40oookJ_l0ocSo203o2?oonfX01Ooo803ooo]ZoookJ_oonf[oo`2e00gooo]Z00?o0?neoook
J_oonfX00ooonfX00ol0oh_ooo]ZoookJP0>oookJP05ool0Cooonf[ooo]ZoookJ_l0oiH01_oonfX0
1Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00God_l0omgo0?oonf[ooo]ZonGo0005oookJP04oonK
0?oo003ooo]ZonGo00Cooo]Z00?oT`3ooookJ_oonfX0AOoonfX00olY0?oooo]ZoookJP02oookJP03
o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0oookJ_oo00/00ooonfX00ooo=@3ooo]Zo`21o`03oookJP04
o`3oUol0onSooo]ZocKo00gooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00:oookJP03o`3okOoonf[o
oo]Z00[ooo]Z00?o7@3oo`3ol_oonfX00ooonfX00ooo0;Cooo]ZoonW0007oookJP09o`3o2Ooonf[o
oo]ZoookJ_ml0?oo=?l0o`0]ool02oooo`0H00;ooo]Z00?o/?l0oookJ_l0nol00ooonfX01?m>0?oo
oo]ZoookJ_oo01@2oookJP03ooo70?oonf[ooo]Z00;ooo]Z00GoojP0ool0Yooonf[ooo]ZoolQ0005
oookJP05o`3oUooonf[ooo]Zohko0?oo03T00_oonfX00ol0ol3oo`07oookJP0?oookJP06ool0>?oo
nf[oN@3ooookJ_nho`3oo`2l0ooonfX00om/0?oooo]ZoookJP02oookJP0=ond0oonMo`3ooo]Zool0
g?mG0?oookL0oi<0oooonf[oo`00onco0?oonf[ogOl0om;o0003oookJP04okSo0?oo703ooo]Zoook
JP?oo`1?3_oonfX5ool0C`;ooa`000?o^?l0o`000?oMo`000_oo00002?mG0?ook@3ooookJ_oonf[o
K03oool0_?mi0?ooo`0h1?oonfX04ooo00OoS_l0oookJ_l0oiOoob40ool0YoooZ03oo`0DoookJ_l0
nooo/?l0ool06?l02ooooo]Zo`3o2Ooonf[oojL0o`3ol_lM0?l00_oonfX01Ol0ongooo]ZoookJ_oo
0>co0>?o00;ooo]Z00So=_l0o`3oj?l0POooocD0oooX0?oonf[o0?o`obT0o`;ooo]Z00?oF@3oool0
Z_l0odd00ooonfX01?oo3@3oon<0of`0oomRo`08oookJP03on;o0?oonf[oF_l000;ooo]Z00Co00?o
oookJ_oonf[o0?m80_oonfX00ol0ogOooo]ZogT0o`05oookJP03oono0?oonf[o0?nR00;ooo]Z00So
0?lQoookJ_oonf[oo`3boookJ_l0oeKooo]Zool0X0;ooo]Z00GoE03oo`0Uoooonf[o:P3oool:0004
oookJP04og_o0?oonf[ooi`0oom100;ooo]Z00?o0?lho`P0oooonfX01_oonfX01Ooo803ooo]Zoook
J_oonf[oo`2e00gooo]Z00?o0?neoookJ_oonfX01?oonfX00ol0oh_ooo]ZoookJP0>oookJP04ool0
Cooonf[ooo]Zo`3oUPKooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP05om;o0?oonf[ogOl0
oookJ_l[0?l01OoonfX01OooV`3oo`00oookJ_oonf[ok?l000?ooo]Z00?oT`3ooookJ_oonfX07ooo
nfX002[ooo]Z00?oiOl0o`00Ool007l00_oonfX00ol0oo3ooo]ZoookJP05oookJP03oooX0?oonf[o
o`0;00?ooo]Z00CoocD0oookJ_oonf[o087o0_oonfX01?l0oiOooo]Zo`3oj?oob@0;oookJP03o`00
OooUo`3oiOl000;o001o00Cooo]Zool0k?oonf[ooo]Z0ol007l3oookJP?o001o00?o0?o]oookJ_oo
nfX01?oonfX5o`00O`;oogT000?o0?oboookJ_oonfX00_oonfX00ooo0;CoojL0oookJP06oookJP09
o`3o2Ooonf[ooo]ZoookJ_ml0?oooo]ZocCo0?oo04oo00_o00?ooo]Z00?o/?l0o`3kool007l00_l0
07l02?m>0?oooo]ZoookJ_oo01Cooo]Zo`00Ooooa`3o001o0ooonfX01_ooZ03o001oool0Yol007oo
o`2doolQ00Cooo]Z00Wo0?nGoookJ_oonf[ooo]Zohko0?oo03Wo0?o0oookJ_oo00L03ooonfX00ol0
07ooU?l0oiCo0003oiCo0004ool0_?oonf[ooo]Zof`0o`;o001o00kooo]ZodCo0?m4o`3oA?l0ond0
oom4o`3oo`3LoeL0oom4o`3oT`3oodCo0?o/o`3oo`00omgo00Ko0?l<00Cooa`0o`3o3?l0o`coo`1?
0_l0o``00ol0oego0?l<o`3o3003o`3o30?o0?n;1Ol0oed3o`3oR`Co0?l<00Woo`1?o`3o3?l0o`co
0?mMomgo0?oo003o0?mMoeL0ooo]0?l00_l0o``3odCo00;o0?l<0_nDo`000ooo00Oo0?l<o`3o300=
o`3o30CoiOl00_m4o`05oiCo000;o`00Ool0onSoA?l0o`21oooo=@3oonP0oookJ_l0oo3o:@3oo`00
OooonfX01?oob@001Ol007ooo`d0oooS0?l007ooK03o00;oU?l000?ooo]Zo`00Ool007l00ol007l0
1ooonf[oh_l0oe[o0?l0okkooo]Zool0m_l00ol00_oonfX01?l0odSooo]Zo`3oMooonfX2oiCo00Co
oo]Z0onDo`001?l0oj;o08cooookJ_l0ob42oookJP08ool0l_l0oeKo001oo`00Oooo0:3o001ooook
J_mD0?l2oookJP03obX0oooo2P3o001o00;ooo]Z0_nDo`001_l007oooi`0oom10?l007oo0?lho`P0
o`Sooo]Z00Goob00oookJ_oonf[ooo]Zool0]@0=oookJP03o`3o]Ol007oo001o00?o001o00Co0?n;
oookJ_oonf[ooo]Z0ol007l3oookJP?o001o1?oonfX01Ooo04oooo]ZoookJ_l007oo0?nF00?o001o
0ooonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00God_l0omgo0?oonf[ooo]ZonGo0005oook
JP04ool00?oo0:Wooo]ZonGo00Cooo]Z00?oT`3oo`00Ool007l0AOoonfX01_lY0?oo001oo`00Ool0
07oooo]Zo`3ol0Oooo]Z00CoonP0oookJ_oonf[oo`0;0ooonfX00ooo=@3ooo]Zo`21o`03oookJP04
o`3oUol0onSooo]ZocKo00[ooo]Z0ol007l01?l0hooo001ooookJ_oo0>`2oookJP?o001o0ooonfX3
o`00O`03o`3okOoonf[ooo]Z00Cooo]Z1Ol007l00ooonf[o7@3oo`3olP04oookJP03ool0]?ooY`3o
oo]Z00Kooo]Z00?o0?l9oookJ_oonfX00_oonfX01Oml0?oo=?l0o`0]ool02oooo`0H00;ooo]Z00?o
/?l0o`3kool007l00_l007l02?m>0?oooo]ZoookJ_oonf[oo`0Do`00Ooooa`3o001o0ooonfX00ol0
07ooojP0ool0Y`02o`00O`03oolQ0?oonf[ooo]Z00?ooo]Z00Wo0?nGoookJ_oonf[oS_l0ool0>Ooo
nf[o0?o0oookJ_oo00L03_oonfX03Ol007ooo`0ho`00Oomi0?oo001ookSo0?oonf[oo`2loookJ_l0
07ooK03oo`00OooonfX00ol007l03?o]0?oo001oool0g?l007ooE`3ooi<0oooonf[oo`2Yool00?l0
07oogOl0om;o00;o001o00Kooo]ZokSo0?oo703ooo]Zo`3oU_oo04l6oookJPgo0?n;0ooonfX2ool0
C`;ooa`000Ko0000om;o0?oMo`3oo`00oeL0ooo]0?l2oookJP04of`0oooo0;coN@3oool0>0?ooo]Z
01?oo`07o`3o`?n>o`3o0?nGoolQ0?oo0;CoojP0ooo70?oo01CoCP3oo`3koooo01So00_oog`0ool0
o`Wooo]ZoonW0?l0oo;o7@3o00;ooo]Z00Go0?o]oookJ_oonf[oo`3/o`3So`02o`00O`0=ocKo0?l0
onSo0?nGoole0?ooj03ooo]Zo`3ol?lY0?oo001ooookJ_mI0?oo001oo`3oC@03o`00O`06ool=0?oo
h`3oK03ooookJ_mRo`3ooo]Z1Ol007l01?oonf[oh_l0oookJ_mJo`02oookJP04o`03oooonf[ooo]Z
o`3oB0;ooo]Z00?o0?mgoookJ_mi0?l01OoonfX01_oo_`3ooo]Zo`3oX_l0S?oooo]Zo`3o8@?ooo]Z
00coo`3bo`3oE_l007ooo`2Po`00Oooonf[oE03oo`0Uoooonf[o:P3oool:0?l007l3oookJP08og_o
0?l007oooi`0oom10?l007oooo]Zo`3o>?l80?l7oookJP05oolP0?oonf[ooo]ZoookJ_oo0;D03Ooo
nfX00ol0okGo001oo`00O`03o`00O`04oookJ_l0oh_ooo]ZoookJP?o001o0ooonfX3o`00O`Gooo]Z
00Coo`1?oookJ_l007oo0?nF0ol007l3oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX01OoB
o`3ooo]Zomgo0?oonf[o:`3o00Gooo]Z00Gooi/0ool00?oonf[ooo]Zonco0003oookJP04oi<0ool0
07oo001oo`00Oakooo]Z000ZoookJP03onGo0?l007oo001o00;ooo]Z00?o0?o`oookJ_oonfX01Ooo
nfX00oooj03oo`0;oookJP03oookJP0:oole0?oonf[o087oocOo0?oonf[o0?nGoookJ_l0onSooo]Z
ooo900[ooo]Z00Co001oonGo0?oUo`3oiOl00ol007l00ooo0>cooo]ZoookJP03o`00O`?ooo]Z0ol0
07l00ol0ongooo]ZoookJP03oookJPKo001o0_ooN@05oookJP03ool0]?ooY`3ooo]Z00Kooo]Z00Wo
0?l9oookJ_oonf[ooo]Zog`0ooldo`3ooo]Zool0Col02ol00ooonfX00on`o`3o0?_oo`00O`02o`00
O`03odh0ool007ooo`0D00;ooo]Z00?o001oooo70?l007l00_oonfX00oooZ03o001oool0Y`02o`00
O`03oolQ0?l007oooo]Z00?ooo]Z00Wo0?nGoookJ_oonf[oS_l0ool0>Ooonf[o0?o0oookJ_oo00L0
3_oonfX2o`00O`03ool0>?nDo`3oU?l000;oU?l000?oo`2loookJ_m/0?l00ol007l01ooonf[o001o
odCo0?o]0?ooA?l0ool0g?mG0?l00_m4o`001?nC0?ook?l0ool00?oMo`02odCo00Co0?l<00Cooa`0
o`3o3?l0o`coo`1?1?l0o``?o`3oG@04o`3o3?l0oh_o0?n;o`3oR`;o0?mM00Woo`1?o`3o3?l0o`co
0?mMomgo0?oo003o0?n]oeL0ooo]0?l00_l0o``3odCo00Co0?l<00?oo`07o`3o3?l0o``03?l0o``0
1?ooY`3oiOl0onGo0?oUo`02odCo00GoU?l000_o001oocKo0?l0onSo087ooole0?oo00_oonP0o`00
Ool0oo3o:@3ooookJP04ooo900;o001o00?oon<0o`00Oom/0?l00_nDo`07o`00O`06on;o0?mJo`3o
0?nnoookJ_oo0?Ko00?o0_oonfX00ol0odSooo]Zo`3oM`02oookJP03oiCo0?nGo`3ooo]Z00?ooo]Z
0_nDo`001?l0oj;o08cooookJ_nDo`02oookJP05o`00Oooo0?;o001oo`00Oooo0:000_l007l01_mD
0?oooo]ZoookJ_lZ0?ooo`X0o`00O`;ooo]Z00So001ooiCo0?l007oooi`0oom10?l007oo0?lho`P0
o`Sooo]Z00Goob00oookJ_oonf[ooo]Zool0]@0=oookJP03o`3o]Ol007oo001o00?o001o00Co0?n;
oookJ_oonf[ooo]Z0ol007l3oookJP?o001o1?oonfX01Ooo04oooo]Zo`00Ool007oo0?nF00Co001o
0_oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00God_l0omgo0?oonf[ooo]ZonGo0005oook
JP04ool00?oo0:Wooo]ZonGo00?ooo]Z00CoT`3oo`00Ool007oo001oAOoonfX01_lY0?oo001oo`00
Ool007oooo]Zo`3ol0Oooo]Z00?oonP0oookJ_oo00/01?oonfX00ooo=@3o087oocOo0002oookJP05
o`3oUol0onSooo]ZoookJ_lfo`002OoonfX3o`00O`05o`3Sool007oo001oo`00Oooo0>`00_oonfX3
o`00O`?ooo]Z0ol007l00ol0ongooo]ZoookJP03oookJPOo001o00?o7@3ooookJ_oonfX00ooonfX0
0ooo0;CoojL0oookJP06oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z00Go=?l0o`0]oooo04oo00_oool0
6002oookJP03ok3o0?l0nooo001o00;o001o00SoCP3oo`00Oooonf[oo`0DoookJ_l007ooolL0o`00
O`;ooo]Z00?o001ooonX0?oo0:L00_l007l00ooo8@3oo`2doookJP03oookJP05o`3oUooonf[ooo]Z
ohko0?oo03T00_oonfX00ol0ol3oo`07oookJP0=oookJP;o001o00Koo`0ho`00Oomi0?oo^?l0o`00
Oooo0;`2oookJP04of`0ool007oo001ooookJP;o001o00cok@3ooigo0?oo0=co001ooeL0ool007oo
T`3oool0ZOoo003ooi/0omgo0?oBo`03o`00O`05okSo0?oo703ooo]Zo`3oU_oo04l01OoonfX2o`3o
R`go0?ne0ol0oh/2oookJP09ool0Col0oiKooa`0oolL0?oBo`3ogOl0ool00?mG0?ook@3o00;ooo]Z
00?oo`2logT0oooo03P01?oonfX03_oo00OoS_l0oookJ_l0oiOoob40ool0]?ooZ03oo`0DoookJ_l0
nooo/?l0o`0;ooml0?oo0?l90_oonfX01OooY`3o7@3ooookJ_oonf[o0?o]00;ooo]Z017o001oool0
k?l007oo001oocKo0?l007oo0?oXoole0?oo00_oonP0o`00Ool0oo3o:@3ooookJ_l007ooF@3oo`3o
C@03o`00O`05ool=0?ooh`3oK03ooookJ_mRo`001ol007l00ooRo`3ooo]Zoe[o0002oookJP04o`03
oooonf[ooo]Zo`3oB0;ooo]Z00Co0?mgoookJ_mi0?ooUol01?oonfX01_l0X_oookl0o`3oX_l0S?oo
oo]Zo`3o8@;ooo]Z00Go001oool0l_l0oeKo001oool0X002o`00O`06oe@0ool09Ooooo]ZobX0oooo
2P3o001o0_oonfX01Ol007ooNol0o`00OoooW03ood4000;o001o00?o0?lho`P0oooonfX01_oonfX0
1Ooo803ooo]ZoookJ_oonf[oo`2e00gooo]Z00?o0?neo`00Ool007l01?l007l00ol0oh_ooo]Zoook
JP03o`00O`?ooo]Z0ol007l4oookJP05ool0Cooonf[o001oo`00Ool0oiH01?l007l2oookJP05oolL
0?oonf[ooo]ZoookJ_nho`003?oonfX01OoBo`3ooo]Zomgo0?oonf[o:`3o00Gooo]Z00Gooi/0ool0
0?oonf[ooo]Zonco0003oookJP04oi<0ool007oo001oo`00Oakooo]Z000YoookJP04onGo0?l007oo
001oo`00O`;ooo]Z00?o0?o`oookJ_oonfX01?oonfX00oooj03ooo]Zool02`03oookJP0;oole0?oo
nf[ooo]Zo`21oolgo`3ooo]Zo`3oUooonf[o0?oXoookJ_oob@002_oonfX01?l007ooiOl0onGo0?oU
o`02o`00O`04ool0k?oonf[ooo]ZoookJP?o001o0ooonfX2o`00O`03o`3okOoonf[ooo]Z00?ooo]Z
1?l007l00ooonf[o001ooomi0002oomi00Cooo]Z00?oo`2doonW0?oonfX01ooonfX02?l0o`Wooo]Z
oookJ_ml0?oooo]ZocCo0?oonf[o00_o0ooonfX01_n`o`3o001oo`3kool007oooo]Zodh0o`;o001o
00ooo`0DoookJ_oonf[o001oooo70?l007oooo]Zo`00OoooZ03o001oool0Yooonf[o001ooolQ0?l0
07l00ooonfX02Ol0oiOooo]ZoookJ_oonf[oS_l0ool0>Ooonf[o0?o0ool01`0?oookJP04o`00Oooo
03So001oogT0o`;oU?l000Coo`2loookJ_oonf[oK03o0ol007l03Ooonf[o001oond0oom4o`3oo`3L
odCo0?mG0?ooA?l0oi<0ooo/o`3oo`00odCo0?oMo`000_m4o`03o`3o3004oolL0?l0o`co0?l<ool0
C`Go0?l<4?l0oed01?l0ojgo0?mMo`3oGOl0oed2o`3o[@06ool0Col0ojgo0?l<o`3o[OoMo`3oo`00
0_l0ojd00oo]0?oo0?l<o`3o3002odCo00?o0?mM0_l0o``00ooo00OoA?l0o`3o300;o`3o3004oonW
0?oUo`3oiOl0onGo00?oA?l01?nDo`003?oonf[o001oo`3oj?l0POooocD0ool02oooj03o001oo`3o
l?lY0?oooo]Zo`00O`?oolT00_oonfX01Oooh`3ooo]Zof`0oooonf[oU?l000?o001o00[ooo]Zo`00
Ool007oo001oon;o0?mJo`3o0?nnoookJ_oo0?Ko00?o0_oonfX00ol0odSooo]Zo`3oM`02oookJP03
ogT0oonGo`3ooo]Z00?ooo]Z0_nDo`001?l0oj;o08cooookJ_nDo`02oookJP08o`00Oooo0?;o001o
oookJ_l007ooo`2Po`00OomD0?l2oookJP04o`1<oolZ0?oo001ooookJP;o001o00OoNol0o`00Oooo
W03ood40o`00Ool0ocSo203o00Sooo]Z00Goob00oookJ_oonf[ooo]Zool0]@0=oookJP04o`3o]Ol0
07oo001ooookJP;o001o00Co0?n;oookJ_oonf[ooo]Z0ol007l3oookJP?o001o1?oonfX01_oo04oo
001oo`00Ool007oo0?nFoookJP?o001o0_oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00Go
d_l0omgo0?oonf[ooo]ZonGo0005oookJP03ool00?oo0:WoiOl000Cooo]Z00CoT`3oo`00Ool007oo
001oA?oonfX00olY0?oooo]Zo`00O`02o`00O`03oookJ_l0oo3ooo]Z00Kooo]Z00?oonP0oookJ_oo
00/00ooonfX01?oo=@3ooo]Zo`21oolgo`02oookJP04o`3oUol0onSooo]ZocKo00[ooo]Z0ol007l0
1Ol0hooo001oo`00Ool007ooo`3/00;ooo]Z0ol007l3oookJP;o001o00?o0?o]oookJ_oonfX00ooo
nfX4o`00O`05oookJ_l007oo001ooad0ool0oo801?oonfX00ooo0;CoojL0oookJP07oookJP09o`3o
2Ooonf[ooo]ZoookJ_ml0?oo=?l0o`0]ool02oooo`0H00;ooo]Z00Ko/?l0o`00Ool0nooo001ooook
J_m>0?l2o`00O`07oookJ_oo01Cooo]Zo`00Ooooa`3o001ooookJP02o`00O`06oonX0?oo0:Oooo]Z
o`00Oooo8@3o001o1?oonfX02?l0oiOooo]ZoookJ_n>o`3oo`0ioookJ_l0ol3oo`073ooonfX01ol0
07ooo`0ho`00Oomi0?oo001ookSo0?oo0;`00ooonfX06Om/0?oo001oo`00Oooonf[o001oond0oonM
o`3oo`3LoookJ_mG0?oooo]Zoi<0oooonf[oo`00oonK0?l007oogOl0o`00Oooonf[o001ookSo0?oo
703ooo]Zo`3oU_oo04l01?oonfX2o`3oR`;o0?ne1ooonfX5ool0]@04oookJ_l0okGo0?neo`3o]@;o
0?n;00[ooo]Zool0Col0oiKo^?l0oolL0?oBo`3ogOl0ool00?mG0?ook@3o0_oonfX00ooo0;coN@3o
ool0>004oookJP0Bool01on>o`3o0?nGoolQ0?oo0;CoojP0ooo70?oo01Co0?_ook3o0?oo01So00_o
oookJ_l0o`Wooo]ZoonW0?l0oo;o7@3o0_oonfX05?l0ongooo]Zo`00Oooo0>co0>?ooookJ_l007oo
=_l0o`3oj?oo=@3oo`0;oooX0?l007oo0?o`obT0oooonf[o001ooeT0ool0odgo001o0_oonfX01Ooo
3@3oon<0of`0oooonf[oH_l000?o001o00Oooo]Zo`00Ool007oo001oon;o0?oonf[oF_l000;ooo]Z
00Co00?ooookJ_oonf[o0?m80_oonfX01?l0ogOooo]ZogT0oonGo`04oookJP06o`2Roooo_`3o0?nR
o`2<oooonf[o0?lQ0_oonfX03_l007ooo`3bo`3oE_oonf[o001oool0X?l007ooE03oo`0Uoooonf[o
001oobX0ool007oooo]Z0_l007l01?mko`3o001ooonL0?oo@@02o`00O`03o`3o>?l80?oooo]Z00Ko
oo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP0:oookJP04o`3o]Ol007oo001ooook
JP?o001o00?o0?n;oookJ_oonfX00ol007l3oookJP?o001o1?oonfX01_oo04oo001oo`00Ool007oo
0?nFoookJP?o001o0_oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00God_l0oookJ_oMo`3o
oo]Zob/0o`05oookJP04oonK0?oo003ooo]Zonco00Cooo]Z00CoT`3oo`00Ool007oo001o7_oonfX0
01[ooo]Z2_l007l5oookJP06onGo0?l007oo001oo`00Oooonf[o0?o`1ooonfX00oooj03ooo]Zool0
2`03oookJP04oole0?oonf[ooo]Zo`21o`;ooo]Z00Co0?nGoookJ_l0onSoolT02?l007l2oookJP;o
001o0ooUo`001?oonf[o001oool0k?l007l9oookJP03o`00Ool0ongooo]Z00Cooo]Z0ol007l3oook
JP?oogT01?oonfX00ooo0;CoojL0oookJP06oookJP0:o`3o2Ol007oo001oo`00Ooml0?oo02goocCo
0?oo04oo00_oo`00O`;ooo]Z00?o/?l0o`3kool007l00_oonfX01?m>0?oo001oo`00Oooo01@2oook
JP05ooo70?oonf[ooo]ZoookJ_ooZ0000_l007l00ooo0:Oooo]ZoolQ0003o`00O`;ooo]Z00Wo0?nG
oookJ_oonf[ooo]Zohko0?oonf[o0?o0oookJ_oo00L00_oonfX:o`00O`;ooo]Z0_l007l01Ooo03So
N@3ooookJ_nho`3oo`2l00;o001o00?oK03ooookJ_oonfX00ooonfX03_o]0?ooWOl0odCo0?oo0=co
E`3oodCo0?nC0?ook?l0ool00?m4o`3ogOl0om;o0?m4o`3ooo]Z0_l0o``01?oo703o0?l<o`3o3?oo
04l6o`3o313o0?mM00?o0?n]o`3oGOl0oed01?l0ojd2ool0C`03oolL0?l0ojgoo`0000?o0?n]0ol0
oed01?m4o`3o0?mMo`3oGOl0oed@o`3o3004oonW0?oUo`3oiOl0onGo00?oA?l01?nDo`000ooonf[o
U?l0o`3oj005oiCo0004o`3ol?lY0?oooo]ZoookJP?oolT000Oo001ooookJ_oo3@3oon<0of`0oooo
nf[oH_l000;o001o0ooonfX2o`00O`03on;o0?oonf[oF_l000;ooo]Z00Ko00?ooookJ_oonf[o0?m8
oookJ_l0ogL2oookJP03ogT0oonGo`3ooo]Z00?ooo]Z0_nDo`001Ol0oj;o08cooookJ_nDo`3ooo]Z
00;o001o00Ooo`3boookJ_oonf[ooo]Zool0X?l007ooE03o00;ooo]Z00Co04coobX0oooonf[ooo]Z
0_l007l01omko`3ooo]ZoonL0?oo@@3o001oo`3o>?l80?l02?oonfX01Ooo803ooo]ZoookJ_oonf[o
o`2e00cooo]Z00?o001oo`3o]Ol007l00ooonfX00ol007oo0?n;o`00O`09oookJP;o001o1?oonfX0
1Ooo04oo001oo`00Ool007oo0?nF00;ooo]Z0ol007l00ooonf[ooa`0oookJP02oookJP03okSo0?oo
nf[ooo]Z00[ooo]Z00God_l0omgo0?oonf[ooo]ZonGo0005oookJP03ool00?oo0:WoiOl000Cooo]Z
00CoT`3oo`00Ool007oo001o=_oonfX:o`00O`Cooo]Z00?o:@3ooookJ_l007l00_l007l00ol0oo3o
oo]ZoookJP05oookJP04oooX0?oonf[ooo]Zool02`?ooo]Z00?oocD0oookJ_l0POl00ooonfX01?l0
oiOo0?oXo`00Oolfo`07o`00O`;ooo]Z0ol007l01_oonf[o0>?ooookJ_l007ooo`3/o`00O`Wooo]Z
00?o001oo`3okOoonfX01?oonfX3o`00O`?ooo]Z00?o001ooad0ool0oo801?oonfX00ooo0;CoojL0
oookJP06oookJP03o`3o2Ol007oo001o00;o001o00GoO03oocCo0?l007oo00_oool06002oookJP03
ok3o0?l0nooo001o00;ooo]Z00CoCP3oo`00Ool007ooo`0D0_oonfX02oooa`3ooo]ZoookJ_oonf[o
001ooonX0?l007ooo`2WoookJ_oo8@3oo`2d00;o001o0_oonfX01Ol0oiOooo]ZoookJ_oonf[oS_l0
00;ooo]Z00Co0?o0ool01ooonf[ooo]Z2_l007l2oookJP;o001o00Goo`0hoookJ_mi0?oo^?l0ool0
_002o`00O`03oookJ_m/0?oooo]Z00?ooo]Z00gok@3oo`00OonMo`3oo`3LoeL0oooonf[oT`3ooook
J_o/o`3oo`00o`00OooMo`3o001o00;ooo]Z00Go^?l0oolL0?l007oo0?nFool0C`04oookJP03o`3o
Rol0okGo0?ne00Gooo]Z1?oo0;D5oolP00?oo`2e0_oonfX00ol0okGo0?n;o`3oR`02ool0C`0<okSo
0?oo703od_l0ool00?nC0?ook@3oool0g?oonf[oK03oool0_?nho`3oo`0h0ooonfX04_oo00OoS_l0
oookJ_l0oiOoob40oonX0?oonf[oo`0Dodh0ool0noooo`0Ho`0;ooml0?oo0?l9oookJ_ooY`3o0?ob
oad0o`;ooo]Z00Go0?o]o`00Ool007ooo`3/o`3So`02oookJP08ocKo0?l0onSo087ooole0?ooj03o
oo]Zo`3ol?lY0?l2oookJP0:oeT0ool0odgo001oo`00Oooonf[oo`d0oooS0?m/0?oooo]Zof;o00;o
001o0ooonfX2o`00O`06on;o0?oonf[ooo]Zoe[o0?oonf[o00?o0_oonfX01ol0odSooo]ZoookJ_l0
ogOooo]ZogT0oonGo`001?oonfX01ol0X_oookl0o`3oX_l0S?oooo]Zo`3o8OoonfX00_l007l02?oo
0?;o0?mFoookJ_oonf[oo`2Po`00OomD0?oo02Go0_oonfX00olZ0?oooo]ZoookJP02o`00O`04og_o
0?oonf[ooi`0oom100;o001o00?o0?lho`P0oooonfX01_oonfX00ooo803ooo]ZoookJP02oookJP03
ool0]Ooonf[ooo]Z00Wooo]Z00?o001oo`3o]Ol007l00ooonfX2o`00O`03o`3oRooonf[ooo]Z00Oo
oo]Z0_l007l4oookJP05ool0Col007oo001oo`00Ool0oiH00_oonfX3o`00O`03oookJ_oo703ooo]Z
00;ooo]Z00?o^?l0oookJ_oonfX02_oonfX01OoBo`3ooo]Zomgo0?oonf[o:`3o00Gooo]Z00Cooi/0
ool00?oonf[ok?l01?oonfX01?nC0?oo001oo`00Ool007lNoookJP006_oonfX:o`00O`Gooo]Z00Ko
iOl0o`00Ool007oo001ooookJ_l0oo07oookJP03oooX0?oonf[oo`0;00?ooo]Z00CoocD0oookJ_l0
POoo=ol00_oonfX01?l0oiOo0?oXo`00Oooob@08o`00O`;ooo]Z00?o001oonGo0?oUo`000_oUo`00
1?oonf[o001oool0k?l007l9oookJP03o`00Ool0ongo001o00[ooo]Z0oooN@04oookJP03ool0]?oo
Y`3ooo]Z00Kooo]Z00[o0?l9o`00Ool007oo001oog`0ooldo`3o001oool0Col02ooo001o0_oonfX0
0on`o`3o0?_oo`00O`02oookJP04odh0ool007ooo`0Do`00O`;ooo]Z00OoolL0oookJ_oonf[ooo]Z
oonX0?oonf[oo`2W00;ooo]Z00Koob40o`00Ool007oo001ooookJ_l0oiL3oookJP05ohko0?oo03Wo
oo]Zo`3o`?oo00L00ooonfX:o`00O`;ooo]Z00Oo001oool0>?mi0?oooo]ZokSo0?oonf[oo`2l00;o
001o00?oK03ooookJ_oonfX00ooonfX01?o]0?ooA?l0ool0g?mG0?l2odCo0006oi<0oooo003oA?l0
omgo0?oBo`3ooo]Z0om4o`001?oo703o0?l<o`3o3?oo04l6o`3o317o0?mM0_l0ojd01?l0ooko0;3o
o`2`ool0ojd5o`2`o`06o`3o[Ooo003o0?n]o`3o[Oo]0?oo0?mM5Ol0o``00om4o`3oojL0odCo0005
odCo00?oU?l000?ooo]ZoiCo0?l0onP01OnDo`001Ol0oo3o:@3ooookJ_oonf[oo`2Z00;oolT00_l0
07l01Ooo3@3oon<0of`0oooonf[oH_l000Gooo]Z0_l007l00ooRo`3ooo]Zoe[o0002oookJP06ool0
m_l00ooooo]Zo`3oB?oonf[o0?mg0_oonfX00omi0?ooUol0oookJP03oookJP07o`2RoonDo`3ooo]Z
o`3oX_oonf[oU?l0oookJP02o`00O`07ool0l_oonf[ooo]ZoookJ_oo0:3o001ooe@0o`02oookJP03
o`1<oolZ0?oooo]Z00?ooo]Z00OoNol0oookJ_ooW03ood40o`00Ool0ocSo203o00Sooo]Z00Goob00
oookJ_oonf[ooo]Zool0]@0<oookJP03o`3o]Ol007oo001o00?ooo]Z00?o001oo`3oRol007l02Ooo
nfX3o`00O`?ooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP02oookJP?o001o00Gooo]ZoolL0?oonf[o
oo]ZokSo000=oookJP05om;o0?oMo`3ooo]ZoookJ_oUo`001OoonfX00ooo003oo`2YonGo0004oook
JP04oi<0ool007oo001oo`00OcKooo]Z2_l007l4oookJP03obT0oooonf[o001o00;o001o00?o0?o`
oookJ_oonfX01OoonfX01?ooj03ooo]ZoookJ_oo00/3oookJP03oole0?l0POoo=ol000?ooo]Z00Co
0?oXo`00Ool007oo=_l01ol007l2oookJP?o001o00Kooo]Zo`3Soooonf[o001oool0k?l007l9oook
JP03o`00Ool0ongo001o00[ooo]Z00?o001ooad0ool0oo801?oonfX00ooo0;CoojL0oookJP06oook
JP03o`3o2Ol007oo001o00;o001o00Go=?l0o`0]oooo04oo00_oool06002oookJP03ok3o0?l0nooo
001o00;ooo]Z00CoCP3oo`00Ool007ooo`0D0_oonfX00oooa`3ooo]ZoookJP02oookJP06oonX0?oo
0:Oooo]ZoookJ_oo8@3oo`2d0_l007l2oookJP05o`3oUooonf[ooo]Zohko0?oo03T00_oonfX01?oo
00Oooo]ZoookJ_oonfX:o`00O`;ooo]Z00Oo001oool0>?l007ooN@3ooookJ_nho`3oo`2l00;o001o
00?ooo]Zof`0oooonfX00ooonfX02oo]0?ooWOl0ool0g?l007ooE`3oo`00OonC0?ook?l0ool00?oo
nf[ogOl000?ooo]Z00Go^?l0oolL0?l007oo0?nFool0C`04oookJP03o`3oRol0okGooo]Z00?ooo]Z
0ooo0;D2oolP0003oookJ_l0ocSo0?lh00Ko0?lh00?oob00ool0]Ooo0;D00_oo0;D00ol0okGo0?n;
o`000002ool0C`05oolL0?oBo`3oo`00oeL0ooo]0?l00_oonfX00om/0?ooo`2lool0>004oookJP0=
ool01on>o`3o0?nGoolQ0?oo0;CoojP0ooo70?oo01Co0?_ook3o0?l02oooO03oo`3o2@02oookJP05
oonW0?lM0?oooo]ZoookJ_l0ond00_l007l03?oo0>co0>?ooookJ_oonf[o=_l0o`3oj?l0POooocD0
oooX0?oonf[o0?o`obT0o`;ooo]Z00?oF@3oool0Z_l0odd00_l007l01Ooo3@3ooo]Zof`0oooonf[o
H_l000Gooo]Z0ol007l01_oRo`3ooo]Zoe[o0?oonf[oo`3fo`03o`;ooo]Z00Ko0?m8oookJ_l0ogOo
oo]ZogT0oonGo`04oookJP07o`2Roooo_`3ooo]Zo`3oX_oonf[o0?lQoookJP02o`00O`08ool0l_l0
oeKooo]ZoookJ_oo0:3o001ooe@0ool09Ol2oookJP03obX0oooonf[ooo]Z00;ooo]Z00CoNol0oook
J_ooW03ood400_l007l00ol0ocSo203ooookJP06oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2e
oookJ_oonfX02OoonfX00ol007oo0?neo`00O`03oookJP;o001o00?o0?n;oookJ_oonfX01ooonfX3
o`00O`?ooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP02oookJP?o001o00Gooo]ZoolL0?oonf[ooo]Z
okSo000=oookJP05om;o0?oonf[ogOl0oookJ_l[0?l01OoonfX01?ooV`3oo`00oookJ_o/o`04oook
JP04oi<0ool007oo001oo`00Oakooo]Z000XoookJP03onGo0?oonf[o001o00;o001o00?ooo]Zo`3o
l?oonfX01_oonfX00oooj03oo`0;oookJP02oookJP05oole0?oonf[ooo]Zo`21oolgo`000_oonfX0
1?l0oiOo0?oXoookJ_oob@0:oookJP03o`00OooUo`3oiOl000?oiOl000?o001oool0k?l007l02Ooo
nfX00ol0ongo001oo`00O`09oookJPCoogT00ooonfX00ooo0;CoojL0oookJP07oookJP09o`3o2Ooo
nf[ooo]ZoookJ_ml0?oo=?l0oookJ_l02oooo`0H00;ooo]Z00[o/?l0o`00Ool0nooo001ooookJ_m>
0?oooo]Zo`00Oooo01Co001o0_oonfX01oooa`3ooo]ZoookJ_oonf[oojP0oookJ_oo0:L00_oonfX0
1_oo8@3o001oo`00Ool007oooo]Zo`3oU`?ooo]Z00GoS_l0ool0>Ooonf[o0?o0ool01`0?oookJP06
o`00Oooo03SoN@3ookSo0?oonf[oo`2l0_l007l00om/0?oooo]ZoookJP03oookJP08ond0oonMo`3o
o`3Loong0?mG0?ooA?l0oi<0oooo0002odCo0003omgo0?oBo`3oA?l000;oA?l000Gooa`0o`3o3?l0
o`co0?l<ool0C`04o`3o30ko0?mM0_l0ojd4o`3oG@03o`3oo_l0/?oo0;3o00Oo0;3o0_l0Gol00ooo
003o0?n]o`3oG@07o`3oG@oo0?l<00?oA?l0oonW0?m4o`001Om4o`03oiCo0003oookJ_nDo`3o0?oX
00GoU?l000Go0?o`obT0oooonf[ooo]ZoeT0o`02ooo900;o001o00Goo`d0oooS0?m/0?oooo]Zof;o
0005oookJP?o001o00Soh_l0oe[o0?oonf[ooo]Zool0m_l00ooooo]Zo`3oB0;ooo]Z00Co0?mgoook
J_mi0?ooUol01?oonfX01ol0X_oookl0oookJ_l0oj;ooo]ZoiCo0?oonfX00_l007l01ooo0?;ooo]Z
oookJ_oonf[oo`2Po`00OomD0?l00_oonfX00ol0C?oo:P3ooookJP03oookJP07og_o0?oonf[ooi`0
oom10?l007oo0?lho`P0o`08oookJP05oolP0?oonf[ooo]ZoookJ_oo0;D03?oonfX00ol0okGo001o
o`00O`03oookJP03o`00Ool0oh_o001o00Wooo]Z0ol007l3oookJP05ool0Cooonf[ooo]ZoookJ_l0
oiH00_oonfX3o`00O`05oookJ_oo703ooo]ZoookJ_nho`003OoonfX01OoBo`3ogOl0oookJ_oonf[o
iOl000Gooo]Z00?oo`00ool0ZOoUo`001?oonfX01?nC0?oo001oo`00Ool007m3oookJP03obT0oooo
nf[ooo]Z00?o001o00?o0?o`oookJ_oonfX01OoonfX00oooj03ooo]Zool02`03oookJP04oole0?oo
nf[o087oocOo00?ooo]Z00?o0?oXoookJ_lfo`002_oonfX3o`00O`06oookJ_l0hooooo]Zo`00Oooo
0>co001o2OoonfX00ol0ongo001oo`00O`0:oookJP03oolJ0?lM0?oo001o00?ooo]Z00?oo`2doonW
0?oonfX01ooonfX02Ol0o`Wooo]ZoookJ_oonf[oO03oocCo0?l0;Ooo00_oool06002oookJP07ok3o
0?l007oo0?_oo`00Oooonf[oCP3ooookJP02o`00O`04ool05?oonf[ooo]Zooo700Cooo]Z00GoojP0
ool0Yooonf[ooo]ZoolQ0003o`00O`;ooo]Z00So0?nGoookJ_oonf[oS_l0ool0>Ooonf[o0?o0ool0
1`oooo]Z00Ko001oool0>?l007ooN@3ookSo0?oo0;`3o`00O`03of`0oooonf[ooo]Z00;ooo]Z00co
k@3ooigo0?oo0=cooo]ZoeL0ool007ooT`3oo`00Oooo003ooo]Zob/0oooMo`02oookJP06okSo0?oo
703ooo]Zo`3oU_l007ooo`1?0ooonfX00ol0oh_o0?neoookJP02oookJP;oo`2e0_oo80001?oonf[o
0?lho`3o>?l0ocP2oom100OoNol00_l0ocP2oolP00;oo`2e0_l0oh/03?oonf[oo`1?oolL0?oBo`3o
o`00oeL0ooo]0?oooo]Zof`0oooo0;coN@3oool0>0?ooo]Z01;oo`07ohko0?oonf[o0?nGoolQ0?oo
Z03ooo]Zool05?l0nooo/?l0ool06?l02ooooo]Zo`3o2Ooonf[oojL0o`3ol_lM0?l2oookJP04o`3o
kOl007ooo`3/o`3So`;ooo]Z00So=_l0o`3oj?l0POooocD0ool02oooj03o0?o`obT0o`;ooo]Z00?o
F@3oool0Z_l0odd00ol007l01?oo3@3oK03ooookJ_mRo`05oookJP?o001o00Koh_l0oookJ_mJo`3o
oo]Zool0m_l00ol2oookJP06o`3oB?oonf[ooo]Zo`3oMomi0?ooUol01OoonfX01_oo_`3ooo]Zo`3o
X_oonf[o0?lQoookJP;o001o00Soo`3bo`3oE_oonf[ooo]Zool0X?l007ooE03oo`0Uo`;ooo]Z00?o
:P3oool:0?oonfX00_oonfX01?mko`3ooo]ZoonL0?oo@@02o`00O`03o`3o>?l80?oooo]Z00Kooo]Z
00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP09oookJP03o`00Ool0okGo001o00?ooo]Z
0_l007l00ol0oh_ooo]ZoookJP07oookJP?o001o0ooonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00;o
oo]Z0ol007l01Ooonf[ooa`0oookJ_oonf[o^?l000gooo]Z00God_l0oookJ_oMo`3ooo]Zob/0o`05
oookJP04oonK0?oo003ooo]Zonco00Cooo]Z00CoT`3oo`00Ool007oo001o7_oonfX002Sooo]Z00?o
iOl0oookJ_l007l00_l007l00ooonf[o0?o`oookJP05oookJP03oooX0?oonf[oo`0;00?ooo]Z00[o
olT0oookJ_oonf[o087oocOo0?oonf[o0?nGoookJ_l0onSoolT02ooonfX6onGo0003ool0k?l007oo
001o00Wooo]Z00?o0?o]o`00Ool007l01OoonfX2o`00O`;ooo]Z1?ooN@03oookJP03ool0]?ooY`3o
oo]Z00Kooo]Z00Wo0?l9oookJ_oonf[ooo]Zog`0ool0;Ooo=?l0oookJ_l02ol00ooonfX02?n`o`3o
001oo`3kool007oooo]Zodh0oooonf[oo`0D0_l007l2oookJP09ooo70?oonf[ooo]ZoonX0?oonf[o
001oool0Yooonf[oob4000Co001o00?o0?nGoookJ_oonfX00_oonfX01On>o`3ooo]Zo`3o`?oonf[o
o`0700oooo]Z00Ko001oogT0ool007oo^?l0oookJ_oo0;`2o`00O`03of`0oooonf[ooo]Z00;ooo]Z
00cok@3ooigo0?oonf[oo`3LoeL0oom4o`3oT`3oonco0?oo003oA?l0omgo0?oBo`05odCo0003o`3o
U_l0o`coo`1?00Co0?l<3ol0oed3o`3o[@?o0?mM2_l0/?l2o`1Oo`04o`3oo_oo003o0?ono`3ooPOo
0?mM3_l0o``01?m4o`3oojL0odCo0?m4o`02onGo00?oA?l00_nDo`02odCo0003oiCo0?l0onSoU?l0
00?oU?l000ko0?o`oookJ_lY0?oooo]ZoeT0oooo0:[oolT0oookJ_l007ooo`d0oooS0?m/0?oooo]Z
of;o00;o001o0_oonfX4o`00O`08on;o0?mJo`3ooo]ZoookJ_oo0?Ko00?ooookJ_l0odP2oookJP04
o`3oMooonf[oN@3ooiOo00Cooo]Z00?o0:;ooiCo0?nDo`001_nDo`001ooo0?;ooo]ZoookJ_oonf[o
o`2Po`00OomD0?l00_oonfX00ol0C?oo:P3ooookJP02oookJP08o`00Oomko`3ooo]ZoonL0?oo@@3o
001oo`3o>?l80?l8oookJP05oolP0?oonf[ooo]ZoookJ_oo0;D03?oonfX00ol0okGo001oo`00O`03
oookJP03o`00Ool0oh_o001o00[ooo]Z0_l007l3oookJP06ool0Cooonf[o001oo`00Ool0oiKooo]Z
1?l007l01Ooonf[ooa`0oookJ_oonf[o^?l000gooo]Z00God_l0omgo0?oonf[ooo]ZonGo0005oook
JP03ool00?oo0:WoiOl000Cooo]Z00CoT`3oo`00Ool007oo001o@ooonfX00olY0?oooo]ZoookJP03
o`00O`03o`3ol?oonf[ooo]Z00Cooo]Z00CoonP0oookJ_oonf[oo`0;0ooonfX01?oo=@3ooo]Zo`21
oolgo`02oookJP04o`3oUol0onSooo]ZocKo00[ooo]Z0ol007l01_l0hooooo]ZoookJ_l007ooo`3/
o`00O`Wooo]Z00?o0?o]o`00Ool007l01OoonfX2o`00O`;ooo]Z00Co001ooolJ0?lM0?oo001o0ooo
nfX00ooo0;CoojL0oookJP06oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z00GoO03oocCo0?oonf[o00_o
ool06002oookJP0:ok3o0?l007oo0?_oo`00Oooonf[oCP3ooookJ_l007ooo`0Do`00O`;ooo]Z00[o
olL0oookJ_oonf[ooo]ZoonX0?l007ooo`2WoookJ_oo8@3oo`2d0ol007l00ooonf[o0?nGoookJP02
oookJP05ohko0?oonf[ooo]Zo`3o`?oo00L03ooonfX01_l007ooo`0hogT0oooonf[o^?l0ool0_0;o
001o00?oK03ooookJ_oonfX00_oonfX05Oo]0?oooo]Zoigo0?oo0=coE`3ooong0?nC0?oo001oonco
0?oo003o:`3oomgo0?oonf[o001ookSo0?oo703ooo]Zo`3oU_l007ooo`1?o`00O`03oookJP0:o`3o
Rooonf[ooo]ZoookJ_oo0;Gooo]ZoolP0?oonf[o203oo`3o>0;ood400omko`03obX0o`Coo`2P0omk
o`02o`3o>00?o`000?oo0;Go0?neo`3oRooo04oooa`0oookJ_oMo`3oo`00oeL0ooo]0?oooo]Zof`0
oooo0;coN@3o00Cooo]Z017oo`07ohko0?l0oiOoob40oonX0?oonf[oolL0ool05?l0noooo`0Ho`0;
oooonf[o0?l9oookJ_ooY`3o0?oboad0o`02oookJP04o`3okOl007oo001oool0k0;ooo]Z00ko=_l0
o`00Ool0onSoocD0ool02oooj03o0?o`oookJ_lY0?oooo]ZoeT0oooo0:[o0?m=oookJP;o001o00Co
o`d0of`0oooonf[oH_l00_l007l2oookJPCo001o00Koh_l0oookJ_mJo`3ooo]Zool0m_l00ol2oook
JP06o`3oB?oonf[ooo]Zo`3oMomi0?ooUol01OoonfX01_oo_`3ooo]Zo`3oX_oonf[o0?lQoookJP;o
001o00Soo`3bo`3oE_oonf[ooo]Zool0X?l007ooE03oo`0Uo`;ooo]Z00Wo:P3oool:0?oonf[ooo]Z
o`00Oomko`3ooo]ZoonL0?oo@@000_l007l00ol0ocSo203ooookJP06oookJP03oolP0?oonf[ooo]Z
00;ooo]Z00?oo`2eoookJ_oonfX02OoonfX00ol007oo0?neo`00O`03oookJP03o`00Ool0oh_o001o
00[ooo]Z0_l007l3oookJP06ool0Cooonf[o001oo`00Ool0oiKooo]Z1?l007l01Ooonf[ooa`0oook
J_oonf[o^?l000gooo]Z00God_l0oookJ_oMo`3ooo]Zob/0o`05oookJP04oonK0?oo003ooo]Zonco
00Cooo]Z00CoT`3oo`00Ool007oo001o7_oonfX002Sooo]Z00?o:@3ooookJ_l007l00_l007l00ooo
nf[o0?o`oookJP05oookJP03oooX0?oonf[oo`0;00?ooo]Z00[oolT0oookJ_l0POoooo]ZocOo0?oo
nf[o0?nGo`3oj?oonf[o=_l02ooonfX6onGo0003ool0k?l007oo001o00Wooo]Z00Co0?o]o`00Ool0
07oo001o1?oonfX3o`00O`KoogT00_oonfX00ooo0;CoojL0oookJP06oookJP09o`3o2Ooonf[ooo]Z
oookJ_ml0?oo=?l0oookJ_oo04oo00_o00?ooo]Z00So/?l0o`3kool007oo001ooookJ_m>0?oooo]Z
ool050;o001o00?ooo]Zooo70?oonfX00_oonfX00oooZ03ooo]Zool0Y`02o`00O`06oolQ0?l007oo
001oo`00Oooonf[o0?nG0ooonfX01On>o`3oo`0ioookJ_l0ol3oo`07013ooo]Z00Koo`0hogT0ool0
07oo^?l0oookJ_oo0;`2o`00O`03of`0oooonf[ooo]Z00;ooo]Z00cok@3ooookJ_oo0=cooo]ZoeL0
oom4o`3oT`3oool00?m4o`3oiOl0odCo0?oBo`05odCo0003o`3oU_oo04oo0?l<00?o0?l<00?oA?l0
o`3oGOl0oed03?l0oed5o`3o[@?o0?mM2Ol0/?l2o`1Oo`;o0?on00?oo`00o`3oo_l0oed01_l0oed6
o`3o3003odCo0?l0o`co0?l<00Go0?l<00?oA?l0oonW0?m4o`001ooUo`001OnDo`3oA?l0odCo0?nD
o`3o0?oX00CoU?l000Oo0?o`oookJ_lY0?oooo]ZoeT0oooo0:[o0?m=00;ooo]Z00Goo`d0oooS0?l0
07ooK03oof;o0004o`00O`GoU?l000OoF_l0oookJ_oonf[oo`3fo`03oooonf[o0?m800;oU?l000Co
0?mgoiCo0?mi0?ooUol01?oonfX00ol0X_ooU?l0oiCo0006oiCo0007ool0l_oonf[ooo]ZoookJ_oo
0:3o001ooe@0o`02oookJP03o`1<oolZ0?oooo]Z00;ooo]Z00So001oog_o0?l007oooi`0oom10?l0
07oo0?lho`P0o`Sooo]Z00Goob00oookJ_oonf[ooo]Zool0]@0<oookJP03o`3o]Ol007oo001o00?o
oo]Z00?o0?n;o`00Ool007l02_oonfX3o`00O`;ooo]Z00Goo`1?oookJ_l007oo001oo`3oUP04o`00
O`03oookJ_oo703ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX02ooonfX01?oBo`3ogOl0oookJ_oUo`06
oookJP03ool00?oo0:WoiOl000Cooo]Z00CoT`3oo`00Ool007oo001o@ooonfX00olY0?oooo]Zoook
JP03o`00O`03o`3ol?oonf[ooo]Z00Cooo]Z00CoonP0oookJ_oonf[oo`0;0ooonfX01?oo=@3o087o
oookJ_lgo`02oookJP04o`3oj?oonf[ooo]ZocKo00[ooo]Z0ol007l01?l0hooooo]ZoookJ_oo0>`2
o`00O`Wooo]Z00Co0?o]o`00Ool007oo001o1?oonfX5o`00O`03oad0ool0oo;ooo]Z00?ooo]Z00?o
o`2doonW0?oonfX01_oonfX00ol0o`Wooo]ZoookJP02oookJP05ocCo0?l0;Oooo`1?o`0;oooo01P0
0_oonfX03?n`o`3o0?_oo`00Ool007oooo]Zodh0oooonf[o001oool05?l007oooo]Zooo700Cooo]Z
00GoojP0ool0Yol007oo001ooolQ0003o`00O`;ooo]Z00Go0?nGoookJ_oonf[ooo]Zohko0002oook
JP03o`3o`?oo00Oooo]Z00kooo]Z00Koo`0ho`00Oomi0?oo^?l0oookJ_oo0;`2o`00O`03of`0oooo
nf[ooo]Z00;ooo]Z01Cok@3ooigo0?oo0=cooo]ZoeL0oooonf[oT`3oool0ZOoo003o:`3oomgo0?oB
o`3ooo]Zo`00Oonho`3ooa`0o`00Ool0oiKoo`1?o`00O`?ooo]Z00[o0?n;o`3o]Ooonf[ooo]Zool0
]Ooonf[oob00oookJ_l80?oo0?lh0omko`05ool0X0Ko0?lQ00?oo`2PobX0oomko`000_mko`003ooo
803oo`2eo`3o]Ol0oh_oo`1?oolL0?oonf[oo`00oi<0ooo]0?oooo]Zof`0oooo0;coN@3oool0>003
oookJP0Aool01on>o`3ooo]ZoolQ0?oo0;CoojP0ooo70?oo01Co0?_ook3o0?l02oooO03oo`3o2Ooo
nf[oojL0o`3ol_lM0?l00_oonfX01?l0ongo001oo`00Oooo0>`2oookJP0=o`00Oolfo`3o0?oXo`21
oooo=@3oonP0o`3ol?oonf[o:@3ooookJ_mI0?ooo`2Zo`3oC@02oookJP05o`00Oooo3@3oon<0of`0
oomRo`001ol007l01ooonf[oh_l0oookJ_mJo`3ooo]Zool0m_l00ol00_oonfX01_l0odSooo]Zoook
J_l0ogOoN@3ooiOo00Gooo]Z00Kookl0oookJ_l0oj;ooo]Zo`3o8OoonfX2o`00O`08ool0l_l0oeKo
oo]ZoookJ_oo0:3o001ooe@0ool09Ol2oookJP09obX0oooo2P3ooo]ZoookJ_l007ooNol0o`00Oooo
W03ood4000;o001o00?o0?lho`P0oooonfX01_oonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooo
nf[ooo]Z00Wooo]Z00?o001oo`3o]Ol007l00ooonfX00ol007oo0?n;o`00O`0:oookJP?o001o0_oo
nfX01Ooo04oooo]Zo`00Ool007oo0?nF00Co001o00?ooo]ZoolL0?oonfX00_oonfX00onho`3ooo]Z
oookJP0;oookJP05om;o0?oonf[ogOl0oookJ_l[0?l01OoonfX01?ooV`3oo`00oookJ_o/o`04oook
JP04oi<0ool007oo001oo`00Oakooo]Z000XoookJP03obT0oooonf[o001o00;o001o00?o0?o`oook
J_oonfX01OoonfX00oooj03ooo]Zool02`02oookJP;oolT000?ooo]Zo`21oolgo`000_oonfX01?l0
oiOo0?oXoookJ_lfo`0:oookJPOoiOl000?oo`3/o`00Ool007l02OoonfX01?l0ongooo]Zo`00Ool0
07l4oookJP?o001o1_ooN@001?oonf[oo`2doookJ_ooY`07oookJP09o`3o2Ooonf[ooo]ZoookJ_ml
0?oo=?l0oookJ_l02oooo`0H00;ooo]Z00?o/?l0oookJ_l0nol00_l007l01?oonf[oCP3ooookJ_oo
01@2o`00O`03oookJ_ooa`3ooo]Z00;ooo]Z00?oojP0oookJ_oo0:L00_l007l00ooo8@3o001oo`00
O`02oookJP09o`3oUooonf[ooo]ZoookJ_n>o`3oo`0ioookJ_l0ol3oo`07013ooo]Z00Woo`0hogT0
oonho`3ooo]Zool0_?oonf[o001oof`0ool007l01?oonfX02oo]0?oooo]Zool0g?mG0?oo001ooi<0
ooo/o`3oo`00odCo0?oUo`3od_l000GoA?l000?o0?nFool0Col007l00_l0o``00ol0oh_oA?l0odCo
0002o`3o30co0?mM1_l0ojd3o`3oG@So0;3o00?o05ooo`3oo_l0ooh00_l0ooh00ooo003o0?mMo`3o
G@05o`3oG@03odCo0?l0o`co0?l<00?o0?l<00GoA?l0oonX0?l0o`co0?l<odCo0003o`3o30;oA?l0
00?oojL0onGo0?oUo`001OoUo`001OnDo`3oA?l0odCo0?nDo`3o0?oX00CoU?l000Oo0?o`oookJ_lY
0?oo001ooeT0oooo0:[o0?m=00;ooo]Z00Go001ooooS0?l007ooK03oof;o0004o`00O`GoU?l000Oo
F_l0o`3o__nDo`3oo`3fo`03oooonf[o0?m800;oU?l000Co0?mgoiCo0?mi0?ooUol00onDo`000ooo
nf[o0:;ooiCo0007oiCo0007ool0l_oonf[ooo]ZoookJ_oo0:3o001ooe@0o`02oookJP03o`1<oolZ
0?oooo]Z00;ooo]Z00CoNol0o`00OoooW03ood400_l007l00ol0ocSo203ooookJP07oookJP05oolP
0?oonf[ooo]ZoookJ_oo0;D03?oonfX00ol0okGo001oo`00O`03oookJP03o`3oRol007oo001o00_o
oo]Z0_l007l2oookJP05ool0Cooonf[o001oo`00Ool0oiH00ol007l2oookJP05oolL0?oonf[ooo]Z
oookJ_nho`003?oonfX01OoBo`3ooo]Zomgo0?oonf[oiOl000Gooo]Z00Cooi/0ool00?oo0:WoiOl0
1?oonfX01?nC0?oo001oo`00Ool007m3oookJP03obT0oooonf[ooo]Z00;o001o00?o0?o`oookJ_oo
nfX01OoonfX01?ooj03ooo]ZoookJ_oo00/3oookJP03oole0?l0POoo=ol000?ooo]Z00Co0?oXoook
J_oonf[o=_l02_oonfX3o`00O`04o`3Soooonf[ooo]Zool0k0;o001o2OoonfX01?l0ongooo]Zo`00
Ool007l4oookJPCo001o00?ooaX0oad0ool0oo800ooonfX00ooo0;Cooo]ZoonW0007oookJP03o`3o
2Ooonf[ooo]Z00;ooo]Z00Wo=?l0o`0]ool02ooooo]Zool06?oonf[o/?l0oookJ_l0nol00_l007l0
2?oonf[oCP3ooookJ_l007ooo`0Do`00Oooonf[oolL01?oonfX01OooZ03oo`2Wo`00Ool007ooob40
00;o001o0ooonfX02?l0oiOooo]ZoookJ_n>o`3oo`0ioookJ_l0ol3oo`074?oonfX02Ooo03SoN@3o
o`00Oonho`3oo`2loookJ_l007ooK03oo`00O`04oookJP0;ond0oonMo`3oo`3LoeL0oooo]`3oT`3o
oookJ_o/o`3oo`00ob/0oooMo`000_oonfX01_nho`3ooa`0o`00Ool0oiKoo`1?o`00O`?ooo]Z013o
0?n;o`3o]Ooonf[ooo]Zool0]Ooonf[oob00oookJ_l80?oo0?lhog_o0?lZ0?ooo`X0ool0X?oonf[o
o`3b0ol0ob46o`3oXP?o0?lQ017oo`2PobX0oomko`3oob00ool0]Ol0oh_ooo]Zool0Cooo703ogOl0
ool00?mG0?ook@3ooookJ_m/0?ooo`2logT0o`04oookJP0@ool01on>o`3o0?nGoolQ0?ooZ03oolL0
ool05?l0nooo/?l0o`0;ooldo`3o0?l9oookJ_ooY`3oo`2doad0o`;ooo]Z00Co0?o]o`00Ool007oo
o`3/0_oonfX03Ol007oo=_l0o`3oj?l0POooocD0oooX0?l0oo3ooo]ZobT0ool007ooF@3oo`00Ool0
odd00_oonfX01Ol007ooo`d0oooS0?m/0?ooH_l000Ko001o0_oonfX00ooRo`3ooo]Zoe[o0002oook
JP04o`03oooonf[ooo]Zo`3oB0;ooo]Z00?o0?mgogT0oonGo`001OoonfX01_oo_`3ooo]Zo`3oX_oo
nf[o0?lQoookJP;o001o00Soo`3bo`3oE_oonf[ooo]Zool0X?l007ooE03oo`0Uo`;ooo]Z00So:P3o
ool:0?oonf[ooo]Zo`00Oomko`3o001ooom100;o001o00?ooo]Zo`3o>?l80?l01ooonfX00ooo803o
oo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z00Wooo]Z00?o001oo`3o]Ol007l00ooonfX00ol007oo
0?n;o`00O`0;oookJP;o001o0_oonfX01Ooo04oooo]Zo`00Ool007oo0?nF00?o001o0_oonfX01Ooo
703ooo]ZoookJ_oonf[o^?l000cooo]Z00Kod_l0oookJ_oonf[ogOl0oookJ_l[0?l5oookJP04oonK
0?oo003ooo]Zonco00Cooo]Z00CoT`3oo`00Ool007oo001o7_oonfX002Oooo]Z00?o001oobT0ool0
07l00ol007l00ol0oo3ooo]ZoookJP04oookJP03oooX0?oonf[oo`0;00?ooo]Z0ooob@002?l0POoo
=ol0oookJ_oonf[o0?nGo`3oj?oonf[o=_l02_oonfX6onGo0004ool0k?l007oo001oo`00O`Wooo]Z
00?o0?o]oookJ_oonfX00_l007l3oookJP;o001o1oooN@000ooonf[oo`2doonW0008oookJP09o`3o
2Ooonf[ooo]ZoookJ_ml0?oo=?l0oookJ_l02oooo`0H00;ooo]Z00?o/?l0oookJ_l0nol00_l007l0
1?m>0?oooo]ZoookJ_oo01@2o`00O`03oookJ_ooa`3ooo]Z00;ooo]Z00KoojP0oookJ_oo0:Oo001o
ool0]?oo8@04oookJP09o`3oUooonf[ooo]ZoookJ_n>o`3oo`0ioookJ_l0ol3oo`0700oooo]Z00[o
o`0hogT0ool007oo^?l0oookJ_oo0;cooo]Zo`00Oom/0?oo001o0ooonfX02Oo]0?ooWOl0oookJ_oo
0=coE`3oo`00OonC0?ooo`00oonK0002onGo00GoA?l000Ko0?nFool0Cooonf[ooo]Zo`3o3?l0oh/3
odCo0003o`3o3?oo0;Go0?mM00[o0?mM2?l0ojd:o`2`o`03o`1Oool0ooko0?on00?o0?on1ol0oed0
0om4o`3o0?l<o`3o3003o`3o3005oolQ0?ooZ03oA?l0o`3o3?m4o`000ol0o``2odCo0003oonW0?oU
o`3oiOl000CoiOl000KoA?l0ool0k?m4o`3oA?l0oiCo0?l0onP5oiCo0006o`3ol?lY0?oo001oo`00
Oooo0:[o0?m=0_oonfX01Ol007ooon<0o`00Oom/0?ooH_l000;o001o0_oonfX5oiCo0005oe[o0?l0
okkoU?l0ool0m_l00ol00_oonfX01_l0odSoU?l0o`3oMonDo`3oN@3ooiOo00?oU?l000?ooo]Zo`2R
oooo_`001_nDo`000ooo0?;o0?mFoookJP02oookJP03ool0X?mD0?oo02Go00;ooo]Z00?o04coobX0
oooonfX00_oonfX01?mko`3o001ooonL0?oo@@02oookJP03o`3o>?l80?oooo]Z00Oooo]Z00Goob00
oookJ_oonf[ooo]Zool0]@0<oookJP03o`3o]Ol007oo001o00?ooo]Z00?o0?n;o`00Ool007l03?oo
nfX2o`00O`03oookJ_oo04oooo]Z00;o001o00?o0?nFoookJ_oonfX00ooonfX01Ooo703ooo]Zoook
J_oonf[o^?l000cooo]Z00God_l0oookJ_oMo`3ooo]ZonGo0005oookJP04oonK0?oo003oo`2YonGo
00;ooo]Z0_l007l01?nC0?oo001oo`00Ool007m3oookJP03obT0ool007oo001o00;o001o00?o0?o`
oookJ_oonfX01?oonfX01?ooj03ooo]ZoookJ_oo00/4oookJP03oole0?l0POoo=ol000?ooo]Z00Co
0?oXoookJ_oonf[o=_l02_oonfX3o`00O`04o`3Soooonf[ooo]Zool0k0;o001o2OoonfX00ol0ongo
oo]ZoookJP02o`00O`?ooo]Z0_l007l2oookJP03oolJ0?lM0?oo0?ob00?ooo]Z00?oo`2doonW0?oo
nfX01ooonfX00ol0o`Wooo]ZoookJP02oookJP09ocCo0?l0;Ooo00_ooookJ_oo01Sooo]Zok3o0?oo
nf[o0?_o00;o001o00SoCP3ooookJ_oonf[o001oool05?l007oooo]Zooo700Cooo]Z00GoojP0ool0
Yol007oooo]ZoolQ0004oookJP09o`3oUooonf[ooo]ZoookJ_n>o`3oo`0ioookJ_l0ol3oo`0700oo
oo]Z00[oo`0ho`00Oomi0?oo001ookSo0?oo0;cooo]Zo`00Oom/0?oo001o0ooonfX03?o]0?oooo]Z
oigo0?oo0=coE`3oo`00OonC0?ook?l0ool00?l[0?oogOl0om;o00;ooo]Z00Co^?l0oolL0?l0oiKo
o`1?1?oonfX01Ol0oh_o0?neoookJ_oonf[oo`2e00;ooo]Z00Soob00o`P0ool0ocSoNol0obX0oooo
2P3oo`2Po`3oEP;o0?lQ0_l0oj800onGo`3o0?mgogT0o`07ogT0o`;o0?lQ013oo`2Pog_o0?oo803o
o`2eo`3oRooo04oooa`0okSo0?oMo`3oo`00ond0oonMo`3oK03oool0_?mi0?ooo`0h0ooonfX04ooo
00OoS_l0o`3oUooo8@3oojP0oookJ_ooa`3oo`0Do`3koooo01So00_oo`3o2Ooonf[oojL0ool0]?lM
0?oooaX0oookJ_l0ond00_l007l03?oo0>co0>?ooookJ_l007oo=_l0o`3oj?l0POooocD0oooX0?oo
nf[o0?o`obT0o`;o001o00WoF@3oo`3oCOoonf[ooo]Zo`00Oooo3@3oon<0of`0oomRo`000_l007l6
oookJP03on;o0?oonf[oF_l000;ooo]Z00Co00?ooookJ_oonf[o0?m80_oonfX00ol0ogOoN@3ooiOo
0005oookJP06oono0?oonf[o0?nRoookJ_l0ob7ooo]Z0_l007l02?oo0?;o0?mFoookJ_oonf[oo`2P
o`00OomD0?oo02Go0_oonfX02?lZ0?ooo`X0oookJ_oonf[o001oog_o0?oonf[ood400ooonfX00ol0
ocSo203ooookJP06oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX02OoonfX00ol0
07oo0?neo`00O`03oookJP03o`00Ool0oh_o001o00cooo]Z0_l007l00ooonf[oo`1?oookJP02o`00
O`03o`3oU_oonf[ooo]Z00?ooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP06om;o0?oonf[o
oo]Zomgo0?oonf[o:`3o1OoonfX01?oo003oo`2YoookJ_o/o`02oookJP;o001o00CoT`3oo`00Ool0
07oo001o7_oonfX002Oooo]Z00?o001oobT0ool007l00ol007l00ol0oo3ooo]ZoookJP04oookJP03
oooX0?oonf[oo`0;00?ooo]Z0ooob@002?l0POoo=ol0oookJ_l0oiOooo]Zo`3oj?oonf[o=_l02_oo
nfX6onGo0003ool0k?l007oo001o00Wooo]Z00Co0?o]oookJ_oonf[ooo]Z0_l007l3oookJP;o001o
1oooN@000ooonf[oo`2doonW0007oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z00Go=?l0o`0]oooo04oo
00_oool06002oookJP03ok3o0?oonf[o0?_o00;o001o00?oCP3ooookJ_oo01@00_l007l00ooonf[o
olL0oookJP03oookJP06oonX0?oo0:Oo001oo`00Oooo0;Coob400ooonfX02_l0oiOooo]ZoookJ_oo
nf[oS_l0ool0>Ooonf[o0?o0oookJ_oo00L?oookJP09ool0>?mi0?oo001ookSo0?l007ooo`2lo`00
Oom/0?oo001o00Cooo]Z00Sok@3ooookJ_oo0=co001ooeL0ool007ooT`3oool000?oiOl01Om4o`00
1_l0oiKoo`1?oookJ_oonf[oA?l0o`3oR`;oA?l00_l0o``00ooo0;Goob00o`3oG@07o`3oG@03o`3o
8Ol0oego0?n]00Wo0?n]2?l0/?l00ol0Gooo0?ono`3ooP03o`3ooP03ool00?l0oego0?mM00Co0?mM
00?oA?l0o`3o3?l0o``00ol0o``01?oo8@3oA?l0oonX0?oo01@2odCo00;o0?l<0_m4o`000oooY`3o
o`2donGo0004onGo0003odCo0?oo0>coA?l000;oA?l000?o0?oXoiCo0?nDo`000_nDo`000ooonf[o
0?o`obT0o`02o`00O`0;ool0Z_l0odgooo]ZoookJ_l007ooon<0o`00Oom/0?oooo]Zof;o0?l007l0
0ooonfX4oiCo0005oe[o0?l0okkoU?l0ool0m_l00ol00_oonfX01_l0odSoU?l0o`3oMonDo`3oN@3o
oiOo00;oU?l00_oonfX00ol0X_oookl0oiCo0005oiCo0008ool0l_l0oeKo001ooookJ_l007ooo`2P
oe@0ool09Ol2oookJP03o`1<oolZ0?oooo]Z00;ooo]Z00CoNol0o`00OoooW03ood400_oonfX00ol0
ocSo203ooookJP06oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX02_oonfX02?l0
okGo001oo`00Ool007oooo]Zo`00Ool0oh_o001o3OoonfX2o`00O`03ool0Cooonf[ooo]Z00;o001o
00?o0?nFoookJ_oonfX00ooonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00God_l0oookJ_oM
o`3ooo]ZonGo0005oookJP04oonK0?oo003oo`2YonGo00;ooo]Z0_l007l01?nC0?oo001oo`00Ool0
07m3oookJP03obT0ool007oo001o00;o001o00?o0?o`oookJ_oonfX01?oonfX01?ooj03ooo]Zoook
J_oo00/4oookJP03oole0?l0POoo=ol000;ooo]Z00Go0?nGo`3oj?oonf[ooo]ZocKo000;oookJP;o
001o00?o0>?ooookJ_oo0>`00_l007l9oookJP04o`3okOoonf[ooo]ZoookJP;o001o0ooonfX2o`00
O`;ooo]Z00?ooaX0oad0oooonfX00ooonfX00ooo0;CoojL0oookJP07oookJP09o`3o2Ooonf[ooo]Z
oookJ_ldo`3o02goool0Col02oooo`0H00;ooo]Z00?o/?l0oookJ_l0nol00_l007l01om>0?oooo]Z
o`00Oooo01Co001ooookJ_ooa`001OoonfX01OooZ03o001oo`00Oooo0;Coob4000Cooo]Z00Go0?nG
oookJ_oonf[ooo]Zohko0002oookJP03o`3o`?oo00Oooo]Z00kooo]Z00Woo`0hoookJ_mi0?oo^?l0
o`00Oooo0;co001oof`0ool007l01?oonfX04_o]0?ooWOl0ool0g?l007ooE`3oo`00OonC0?ooo`00
oonK0?l[0?oogOl0om;o0?oonf[o^?l0oolL0?l007oo0?nFool0C`Cooo]Z01;o0?n;oookJ_oonf[o
oo]Zool0]Ooonf[oob00oookJ_l0ocSoNol0o`1<oolZ0?ooE03oool0X?l0ob7o0?nRoono0?nGo`03
ogT0o`03o`3o__mJo`3oF_l000?oF_l00_l0ogL04_mi0?oo0?nRo`3o8Ooo0:3oNol0oolP0?oo0;Go
0?n;ool0Cooo703ogOl0ool00?mG0?ook@3ooookJ_m/0?ooo`2lool0>0?ooo]Z017oo`07ohko0?oo
nf[oob40ool0YoooZ03oolL0ool05?l0noooo`0Ho`0;oooonf[o0?l9oookJ_ooY`3o7@3ooolJ0002
oookJP04o`3okOl007ooo`3/o`3So`;o001o00So=_l0o`3oj?l0POooocD0oooX0?oonf[o0?o`obT0
o`;o001o00_oF@3oo`3oCOoonf[ooo]Zo`00Oooo3@3oon<0of`0oooonf[oH_l0o`00O`06oookJP03
on;o0?oonf[oF_l000;ooo]Z00Co00?ooookJ_oonf[o0?m80_oonfX00ol0ogOoN@3ooiOo0005oook
JP05oono0?oonf[o0?nRoookJ_l0ob400_oonfX02Ol007ooo`3bo`3oE_oonf[o001oool0X?l007oo
E03oo`0Uo`02oookJP08obX0oooo2P3ooo]ZoookJ_l007ooNol0oookJ_oo@@03oookJP03o`3o>?oo
nf[ooo]Z00Gooo]Z00?oob00oookJ_oonfX00ooonfX00ooo0;Gooo]ZoookJP0:oookJP04o`3o]Ol0
07oo001ooookJP;o001o00?o0?n;oookJ_oonfX02ooonfX2o`00O`03oookJ_oo04oooo]Z00;o001o
00?o0?nFoookJ_oonfX00ooonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00Kod_l0oookJ_oo
nf[ogOl0oookJ_l[0?l5oookJP04ool00?oo0:Wooo]Zonco00;ooo]Z0_l007l01?nC0?oo001oo`00
Ool007lNoookJP00:?oonfX00olY0?oo001oo`00O`02o`00O`03o`3ol?oonf[ooo]Z00Cooo]Z00?o
onP0oookJ_oo00/00_oonfX4ooo90008o`21oolgo`3ooo]Zo`3oUooonf[o0?oXoookJ_lfo`09oook
JPOoiOl000?oo`3/o`00Ool007l01ooonfX2o`00O`03o`3okOl007oo001o00Co001o0ooonfX00ol0
07ooogT0oomi0005oomi0003oookJ_oo0;CoojL000Oooo]Z00?o0?l9oookJ_oonfX00_oonfX01Old
o`3ooo]Zo`0;oooonf[oo`0H00;ooo]Z00?o/?l0o`3koooonfX00_l007l00om>0?oo001oool05002
o`00O`03oookJ_ooa`3ooo]Z00;ooo]Z00KoojP0oookJ_oo0:Oooo]Zo`00Oooo8@04o`00O`09o`3o
Uooonf[ooo]ZoookJ_n>o`3oo`0ioookJ_l0ol3oo`07013ooo]Z00Goo`0hogT0oonho`3o001oool0
_002o`00O`03of`0ool007oooo]Z00?ooo]Z00Sok@3ooookJ_oo0=coE`3oo`00OonC0?ook?l0ool0
00?oiOl01Om4o`001Ooo04oo001oodCo0?m4o`3o0?n;00?oA?l000Co0?l<ool0]Ol0o`coob000_l0
oed00omko`3o0?mMo`3oG@02o`3oG@03o`3o8Ol0oego0?mM00_o0?n]1ol0/?l00ol0Gooo0?ono`3o
oP04o`3ooPGo0?mM0om4o`04o`3o3006ool0]?m4o`3oojP0ool05?l0o`coA?l00_l0o``2odCo0003
oonW0?oo0;CoiOl000CoiOl000?oA?l0ool0k?m4o`000_m4o`000ol0onSoU?l0oiCo0002oiCo0007
oookJ_l0oo3o:@3ooookJ_l007ooF@3oo`3oC@03o`00O`05oooS0?oonf[oK03ooookJ_mRo`001?l0
07l4oiCo0005oe[o0?l0okkooo]Zool0m_l00ol00_oonfX01_l0odSoU?l0o`3oMonDo`3oN@3ooiOo
00;oU?l00_oonfX00ol0X_oookl0oiCo0005oiCo0003ool0l_l0oeKo001o00;o001o00?oo`2Poe@0
ool09Ol00_oonfX00olZ0?ooo`X0oookJP02oookJP04og_o0?l007oooi`0oom100;o001o00?o0?lh
o`P0oooonfX01_oonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z00[ooo]Z00?o0?ne
o`00Ool007l00ol007l00ol0oh_o001ooookJP06oookJPSo001o00Koo`1?oookJ_oonf[ooo]Zo`00
Ool0oiH5o`00O`05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX01OoBo`3ooo]Zomgo0?oonf[oiOl0
00Gooo]Z00?ooi/0ool00?oUo`001OoonfX01?nC0?oo001oo`00Ool007m3oookJP03obT0oooonf[o
001o00;o001o00?o0?o`oookJ_oonfX01?oonfX01?ooj03ooo]ZoookJ_oo00/4oookJP03oole0?l0
POoo=ol000;ooo]Z00Go0?nGo`3oj?oonf[ooo]ZocKo000;oookJP;o001o00?o0>?oo`00Oooo0>`0
0_l007l7oookJP;o001o00?o0?o]o`00Ool007l01?l007l3oookJP;o001o00?ooaX0o`00OolM0?l0
0_l007l2oookJP03ool0]?ooY`3ooo]Z00Kooo]Z00?o0?l9oookJ_oonfX00_oonfX01Oldo`3o02go
o`0;oooonf[oo`0H00;ooo]Z00?o/?l0o`3koooonfX00_l007l01om>0?oo001oo`00Oooo01Co001o
oookJ_ooa`001?oonfX01OooZ03oo`2WoookJ_l007ooob4000Go001o00Wo0?nGoookJ_oonf[ooo]Z
ohko0?oonf[o0?o0oookJ_oo00L03ooonfX01Ooo03SoN@3oo`00Oonho`3oo`2l00;o001o00?oK03o
o`00OooonfX00ooonfX02oo]0?ooWOl0ool0g?mG0?oo001ooi<0ooo/o`3oo`00ob/0ool007oogOl0
00;ooo]Z00Co^?l0oolL0?l0oiKoo`1?1?l007l05Ol0oh_o0?neoookJ_oonf[oo`2eoookJ_oo803o
oo]Zo`3o>?mko`3ooo]ZobX0oomD0?ooo`2Po`3o8Ol0oj;o0:;ooiOo0?mi0?oo0?m8o`03o`02oe[o
00Goh_l00_mJo`004_l0ogOoN@3oogT0ool0ob7oo`2Pog_o0?oo803oo`2eo`3oRooo04oooa`0omgo
0?oo003ok@3ooigo0?m/0?ooo`2logT0o`Cooo]Z013oo`07ohko0?oo0;Coob40oonX0?ooa`3oo`0D
o`3koon`o`3o00_oocCo0?l0o`Wooo]ZoonW0?l0oo;o7@3o0_oonfX01?l0ongo001oool0k?l0hol2
o`00O`0<ocKo0?l0onSo087ooole0?ooj03ooo]Zo`3ol?lY0?oooo]Zo`00OomI0?oo0?m=0ol007l0
1Ooo3@3oon<0of`0oooonf[oH_l000Oo001o00?oh_l0oookJ_mJo`000_oonfX01?l00ooooo]Zoook
J_l0odP2oookJP03o`3oMomi0?ooUol000Gooo]Z00Gookl0oookJ_l0oj;ooo]Zo`3o8@02oookJP03
o`00Oooo0?;o0?mF00;o001o00Soo`2Po`00OomD0?oo02GooookJ_lZ0?oo04coool:00?ooo]Z00?o
Nol0o`00Oooo@@000ol007l00ol0ocSooo]ZoookJP05oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?o
o`2eoookJ_oonfX02_oonfX00ol0okGo001oo`00O`03o`00O`03o`3oRooonf[ooo]Z00Gooo]Z2Ol0
07l01Ooo04oooo]ZoookJ_l007oo0?nF00Go001o00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP06
om;o0?oonf[ooo]Zomgo0?oonf[o:`3o1OoonfX00ooo003oo`2Yonco0005oookJP04oi<0ool007oo
001oo`00Oakooo]Z000WoookJP03obT0oooonf[ooo]Z00;o001o00?o0?o`oookJ_oonfX01OoonfX0
0oooj03ooo]Zool02`02oookJPCoolT000Oo087ooookJ_oonf[o0?nGoookJ_l0onSo=_l000kooo]Z
0ooUo`000ooo0>co001ooookJP07oookJP;o001o00?o0?o]o`00Ool007l01?l007l3oookJPSoogT0
00?oo`2doookJ_ooY`001ooonfX02Ol0o`Wooo]ZoookJ_oonf[oO03oocCo0?oonf[o00_oool06003
oookJP09ok3o0?l0nooooo]ZoookJ_l007ooCP3oo`00Oooo01Co001o00;ooo]Z00[oolL0oookJ_oo
nf[ooo]ZoonX0?oonf[oo`2WoookJ_oo0;Coob401?l007l02Ol0oiOooo]ZoookJ_oonf[oS_l0ool0
>Ooonf[o0?o0ool01`0?oookJP06ool0>?oonf[oN@3ookSo0?l007ooo`2l0_l007l00om/0?oooo]Z
oookJP02oookJP08ond0oonMo`3ooo]Zool0g?mG0?oooo]Zoi<0oom4o`03onGo00KoA?l000Goo`1?
odCo0?m4o`3oA?l0o`3oR`03odCo0003o`3o3?oo0;Goob0000;o0?mM00?oNol0obX0ool0oed00ol0
oed00ol0ob7o0?ono`3ooP02o`3ooP[o0?n]1Ol0/?l2o`1Oo`Go0?on1_l0oed2odCo0003o`3oGOl0
o`co0?l<00;o0?l<00Gooo]ZodCo0?ooZ03oo`0Do`3o3002odCo0005o`3o3?ml0?ooA?l0onGo0?oo
Y`001?oUo`000ooonf[oA?l0ool0k003odCo0004o`3oj?nDo`3oU?l0oiCo00;oA?l000Ko0?o`odCo
0?m4o`3ooo]ZoeT0ool0odd3o`00O`05oooS0?oonf[oK03ooookJ_mRo`001?l007l4oiCo0005oe[o
0?l0okkooo]Zool0m_l00ol00_oonfX01_l0odSoU?l0o`3oMonDo`3oN@3ooiOo00;oU?l00_oonfX0
0ol0X_oookl0oiCo0005oiCo0003ool0l_l0oeKo001o00;o001o00?oo`2Poe@0ool09Ol00_oonfX0
0olZ0?ooo`X0oookJP02oookJP04og_o0?l007oooi`0oom100;o001o00?o0?lho`P0oooonfX01_oo
nfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z00[ooo]Z00?o0?neoookJ_l007l00ol0
07l00ol0oh_ooo]ZoookJP06oookJPSo001o00Koo`1?oookJ_oonf[ooo]Zo`00Ool0oiH5o`00O`05
oolL0?oonf[ooo]ZoookJ_nho`003?oonfX00ooBo`3oiOl0omgo0006onGo0004oookJ_ooV`3oo`00
onGo00Gooo]Z00CoT`3oo`00Ool007oo001o@_oonfX01olY0?oooo]ZoookJ_oonf[o001oo`3ol?l0
07l01_oonfX01?ooj03ooo]ZoookJ_oo00/3oookJP03oole0?oonf[o087o00?ooo]Z00Co0?nGo`3o
j?oonf[o=_l03OoonfX01Ol0hooo001oo`00Oooo0>co001o00Sooo]Z0_l007l00ol0ongo001oo`00
O`04o`00O`?ooo]Z0_l007l00ooo6P3o7@3oo`3olP02o`00O`04oookJ_oo0;Cooo]ZoonW00Oooo]Z
00?o0?l9oookJ_oonfX00_oonfX01Oldo`3o02goo`0;oooonf[oo`0H00;ooo]Z00Ko/?l0o`3koooo
nf[ooo]Zo`00Oom>0?l2o`00O`04ool05?oonf[ooo]Zooo700Cooo]Z00GoojP0ool0Yooonf[o001o
oolQ0005o`00O`09o`3oUooonf[ooo]Zohko0?oo03Wooo]Zo`3o`?oonf[oo`0700oooo]Z00Goo`0h
ogT0oooonf[o^?l0ool0_002o`00O`03of`0oooonf[ooo]Z00;ooo]Z00cok@3ooookJ_nMo`3oo`3L
oeL0oooonf[oT`3oool00?ooV`3o:`3oomgo0?oBo`02oookJP04oolL0?oonf[o0?nFool0C`?o001o
00?o0?n;o`3o]OoonfX00_oonfX03ooo0;Goob00oookJ_l0ocSoNol0oonL0?lZ0?oooo]Zool0X?oo
0?;o0?lQoono0?nGo`3oN@3oo`3oB002oe[o0003on;o0?mRo`3oon<000OoK03o01;o0?nno`3oMomi
0?oo0?lQool0X?mko`3oo`2eo`3o]Ol0oh_oo`1?okSo0?oMo`3oo`00ond0oooonf[oo`2logT0oooo
03P3oookJP0@ool01on>o`3o0?nGoolQ0?ooZ03oolL0ool05?l0nooo/?l0o`0;ooldo`3o0?l9oook
J_ooY`3o0?oboad0o`;ooo]Z00Co0?o]o`00Oooo0>co0>?o0_l007l02?lfo`3o0?oXo`21oooo=@3o
onP0oookJ_l0oo3o:@3o0_oonfX00omI0?oo0?m=o`00O`02o`00O`05ool=0?ooh`3oK03ooookJ_mR
o`001ol007l00ooRo`3ooo]Zoe[o0002oookJP04o`03oooonf[ooo]Zo`3oB0;ooo]Z00?o0?mgogT0
oonGo`001OoonfX01Ooo_`3ooo]Zo`3oX_oonf[o0?lQ00?ooo]Z00coo`3bo`3oE_l007oo001oool0
X?oonf[oE03oo`0Uoooonf[o:P3oo`1<oooo2P03oookJP03og_o0?l007oood4000?o001o00?o0?lh
oookJ_oonfX01OoonfX00ooo803ooo]ZoookJP03oookJP03ool0]Ooonf[ooo]Z00Wooo]Z00?o0?ne
oookJ_l007l01?l007l00ol0oh_ooo]ZoookJP05oookJPWo001o00Goo`1?oookJ_oonf[o001oo`3o
UP05o`00O`05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX01_oBo`3ooo]ZoookJ_oMo`3ooo]Zob/0
o`Gooo]Z00?oo`00ool0ZOo/o`001?oonfX00onC0?oooo]Zo`00O`02o`00Oakooo]Z000WoookJP03
obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01OoonfX00oooj03oo`0;oookJP02oookJPCo
olT000Oo087ooookJ_oonf[o0?nGoookJ_l0onSo=_l000kooo]Z00?oiOl0oookJ_oo0>`03?oonfX0
0ol0ongooo]ZoookJP09oookJP03oolJ0?ooN@3oogT000?oogT000?oo`2doookJ_ooY`001ooonfX0
2Ol0o`Wooo]ZoookJ_oonf[oO03oocCo0?oUo`3o00_oool06002oookJP03ok3o0?oonf[o0?_o00?o
oo]Z00?oCP3ooookJ_oo01@00ooonfX01_ooa`3ooo]ZoookJ_oonf[oojP0ool0Y`;ooo]Z00?oo`2d
oolQ0?oonfX00ooonfX02Ol0oiOooo]ZoookJ_n>o`3ooo]Zool0>Ol0ol3ooo]Zool01`0?oookJP08
ool0>?mi0?oooo]ZokSo0?oonf[oo`2loookJ_m/0?l5oookJP08ond0oonMo`3oo`3LoookJ_mG0?oo
oo]Zoi<0oom4o`03onGo00GoA?l000?oo`1?odCo0?m4o`000_m4o`000ol0oh_oA?l0odCo0002o`3o
3006ool0]Ooo803o0?mMo`3oGOmko`3o:P3o0ol0oed00ol0ob7o0?ono`3ooP06o`3ooPSo0?n]1?l0
/?l00ol0Gooo0?ono`3ooP03o`3ooPOo0?mM00?oA?l0o`3o[Ol0oed01?l0o``01Ooonf[oob40oonX
0?m4o`3oo`0D00;oA?l000Go00_oog`0oom4o`3oiOl0oonW0004onGo0003oookJ_m4o`3oo`3/00?o
A?l000Co0?oXoiCo0?nDo`3oU?l00_m4o`000ol0oo3oA?l0odCo0004odCo00;ooo]Z00Goon<0oook
J_m/0?oooo]Zof;o0004oookJPCoU?l000GoF_l0o`3o__oonf[oo`3fo`03o`02oookJP05o`3oB?nD
o`3o0?mgoiCo0?mi0?l00_nDo`03oookJP03o`2Roooo_`3oU?l000CoU?l000?ooo]Zool0l_l0oeH0
0ooonfX00ooo0:3oE03oo`0Uo`02oookJP03obX0oooo2P3ooo]Z00;ooo]Z00CoNol0oookJ_ooW03o
od400_oonfX00ol0ocSo203ooookJP06oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oo
nfX02_oonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z00kooo]Z00?oo`1?oookJ_oo
nfX00_oonfX00ol0oiKooo]ZoookJP03oookJP04oolL0?oonf[ooo]ZokSo00gooo]Z00?od_l0onGo
0?oMo`001_oUo`001?oonf[ooi/0ool00?oUo`05oookJP03oi<0oooonf[ooo]Z04?ooo]Z00?o:@3o
oookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP05oookJP03oooX0?oonf[oo`0;00Cooo]Z00?oocD0
oookJ_l0POl00ooonfX01?l0oiOo0?oXoookJ_lfo`0=oookJP03o`3Soooonf[oo`3/00cooo]Z00?o
0?o]oookJ_oonfX02OoonfX00ooo6P3o7@3oo`3olP03oookJP03ool0]?oonf[oojL000Oooo]Z00?o
0?l9oookJ_oonfX00_oonfX02Oldo`3o02goo`0;oooonf[oo`0HoookJ_n`o`3ooo]Zo`3ko`03oook
JP04odh0oooonf[ooo]Zool050;ooo]Z00?oolL0oookJ_oonfX00_oonfX01OooZ03ooo]ZoookJ_oo
0;Coob4000Gooo]Z00So0?nGoookJ_oonf[oS_l0ool0>Ooonf[o0?o0ool01`oooo]Z00Koo`0hoook
J_mi0?oo^?l0oookJ_oo0;`2oookJP03of`0oooonf[ooo]Z00;ooo]Z01;ok@3ooigo0?oo0=cooo]Z
oeL0oooonf[oT`3oool00?oonf[o:`3oomgo0?oBo`3ooo]ZokSo0?oo703ooo]Zo`3oU_oo04l3oook
JP03o`3oRol0okGooo]Z00;ooo]Z01;oo`2eoolP0?l0ocSo203oog_o0?oonf[o:P3ooe@0oooo0:3o
0?lQo`3oX_oonf[oN@3oo`3oB?mJo`3o0?nnoookJ_mRo`02of`0o`03o`3oCOl0oo3o0?o`00?o0?o`
01?oon<0of`0ool0okkoN@3oo`3oX_l0ob7oNol0o`3o>?oo0;Go0?n;o`3oU_oo04oogOl0ool00?mG
0?ook@3oof`0oooo0;coo`0h00?ooo]Z013oo`07ohko0?l0oiOoob40oonX0?ooa`3ooo]Zool05?n`
o`3o00_oocCo0?l0o`Wooo]ZoonW0?oonf[o7@3o0_oonfX01?l0ongooo]ZoookJ_oo0>`2oookJP08
ocKo0?l0onSo087ooole0?ooj03ooo]Zo`3ol?lY0?l2oookJP03oeT0ool0odgooo]Z00;ooo]Z00Go
o`d0oooS0?m/0?oooo]Zof;o0007oookJP03on;o0?oonf[oF_l000;ooo]Z00Co00?ooookJ_oonf[o
0?m80_oonfX00ol0ogOoN@3ooolW0005oookJP05oono0?oonf[o0?nRoookJ_l0ob400ooonfX03?oo
0?;o0?mFoookJ_oonf[oo`2PoookJ_mD0?oo02GooookJ_lZ0?oo04coool:00;ooo]Z00CoNol0oook
J_oonf[ood400ooonfX00ol0ocSooo]ZoookJP05oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2e
oookJ_oonfX02_oonfX00ol0okGooo]ZoookJP04oookJP03o`3oRooonf[ooo]Z00kooo]Z00Goo`1?
oookJ_oonf[ooo]Zo`3oUP05oookJP04oolL0?oonf[ooo]ZokSo00gooo]Z00Kod_l0oookJ_oonf[o
gOl0oookJ_l[0?l4oookJP04oonK0?oo003oo`2Yonco00Cooo]Z00?oT`3ooookJ_oonfX08?oonfX0
02Oooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP05oookJP04oooX0?oo00_ooo]Z
oookJPKoolT000Kooo]Zo`3oUooonf[o0?oXoookJ_lfo`0=oookJP04onGo0?oonf[ooo]Zool0k0co
oo]Z00?o0?o]oookJ_oonfX02OoonfX01?oo6P3oogT0o`3ol_oonfX2oomi0003ool0]?oonf[oojL0
00Oooo]Z00Wo0?l9oookJ_oonf[ooo]Zog`0ooldo`3oiOl0o`0;oooo01P00_oonfX00on`o`3ooo]Z
o`3ko`02oookJP04odh0oooonf[ooo]Zool050;ooo]Z00?oolL0oookJ_oonfX00_oonfX01_ooZ03o
o`2WoookJ_oonf[oo`2doolQ00Cooo]Z00Wo0?nGoookJ_oonf[oS_l0ool0>Ooonf[o0?o0oookJ_oo
00L03ooonfX01Ooo03SoN@3ooookJ_nho`3oo`2l00;ooo]Z00?oK03ooookJ_oonfX00ooonfX01_o]
0?ooWOl0oiCo0?mG0?oooo]Zoi<0o`;oA?l00ooUo`05odCo0005ool0Com4o`3oA?l0odCo0?l0oh/0
0om4o`003?l0o`coo`2eoolP0?l0o`co0?lhog_o0?l0oego:P3oool0X?l0oego0?lQo`3oG@_o0?on
1Ol0ojd4o`2`o`03o`1Oool0ooko0?on00;o0?on00?o0;3oo`3oGOl0oed01?l0oed2odCo0003ogT0
ool0oego0?l<00Go0?l<00[oojP0odCo0?oo01Co0?l<odCo0?l02oooA?l0o`3o2OoUo`3oojL01?oU
o`02oookJP06ool0k?m4o`3oA?l0odCo0?nDo`3o0?oX0_nDo`02odCo0003o`3ol?m4o`3oA?l000Co
A?l00_oonfX01Oooh`3ooo]Zof`0oooonf[oH_l000Cooo]Z1?nDo`001OmJo`3o0?nnoookJ_oo0?Ko
00?o00;ooo]Z00Go0?m8oiCo0?l0ogOoU?l0ogT0o`02oiCo00?ooo]Z00?ookl0oookJ_l0S?l01?nD
o`000ooonf[oo`3bo`3oEP03oookJP03ool0X?mD0?oo02Go00;ooo]Z00?o:P3oool:0?oonfX00_oo
nfX01?mko`3ooo]ZoonL0?oo@@02oookJP03o`3o>?l80?oooo]Z00Kooo]Z00Goob00oookJ_oonf[o
oo]Zool0]@0=oookJP03o`3o]Ooonf[ooo]Z00?ooo]Z00?o0?n;oookJ_oonfX03_oonfX01Ooo04oo
oo]ZoookJ_oonf[o0?nF00Kooo]Z00Cooa`0oookJ_oonf[o^?l03?oonfX01?oBo`3ooo]ZonGo0?oM
o`05onGo00;ooo]Z00?oo`00oookJ_oUo`001OoonfX00onC0?oooo]ZoookJP13oookJP03obT0oooo
nf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01OoonfX00oooj03ooo]Zool02`04oookJP03oole0?oo
nf[o087o00;ooo]Z00Go0?nGo`3oj?oonf[ooo]ZocKo000=oookJP03o`3Soooonf[oo`3/00cooo]Z
00?o0?o]oookJ_oonfX02OoonfX00ooo6P3o7@3oo`3olP03oookJP03ool0]?oonf[oojL000Oooo]Z
00?o0?l9oookJ_oonfX00_oonfX01?ldo`3o02goo`0;oooo01P2oookJP03ok3o0?oonf[o0?_o00;o
oo]Z00OoCP3ooookJ_oonf[ooo]Zool05?oonf[oolL000Gooo]Z00GoojP0oookJ_oonf[oo`2doolQ
0004oookJP09o`3oUooonf[ooo]ZoookJ_n>o`3ooo]Zo`3o`?oonf[oo`0700oooo]Z00Goo`0hogT0
oooonf[o^?l0ool0_002oookJP03of`0oooonf[ooo]Z00?ooo]Z00_ok@3ooigo0?oo0=coE`3ooook
J_nC0?ook?l0ool00?l[0?oooo]Zomgo0002oookJP04okSo0?oo703o0?nFool0C`?ooo]Z00?o0?n;
oookJ_l0okD00_oonfX04?oo0;Goob00oookJ_l0ocSood40og_o0?lZ0?ooE03oool0X?l0ob7o0?nR
o`2Roomi0?oo0?m8o`3o__mJo`02oookJP05of`0ooooh`3o:@3oo`3ol?lY0?l01_l0onP04Om/0?oo
on<0ogT0ool0ob7o0?nRog_o0?oo0;Go0?neo`3oRooo04ood_l0omgo0?oo003ok@3ooookJ_oo0;co
N@3o00?ooo]Z013oo`07ohko0?l0oiOoob40ool0YoooZ03ooo]Zool05?l0nooo00_oocCo0?l0o`Wo
oo]ZoonW0?oonf[o7@3o0_oonfX01?l0ongooo]ZoookJ_oo0>`3oookJP07o`3oj?l0POooocD0oooX
0?oonf[o0?o`obT0o`02oookJP03oeT0ool0odgooo]Z00;ooo]Z00Goo`d0oooS0?m/0?oooo]Zof;o
0007oookJP03on;o0?mJo`3o0?nn00;ooo]Z00Wo00?ooookJ_oonf[o0?m8oookJ_l0ogOooo]ZogT0
oooo9`001?oonfX01_oo_`3o0:;oo`2<ool0oj;ooo]Zo`3o8@;ooo]Z00?oo`3boookJ_l0oeH00_oo
nfX01ooo0:3ooo]Zoe@0ool09Ooooo]ZobX0oooo2P000ooonfX01?mko`3ooo]ZoookJ_oo@@03oook
JP03o`3o>?oonf[ooo]Z00Gooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP0:oook
JP03o`3o]Ooonf[ooo]Z00?ooo]Z00?o0?n;oookJ_oonfX03ooonfX01?oo04oooo]ZoookJ_l0oiH6
oookJP04oolL0?oonf[ooo]ZokSo00cooo]Z00Ood_l0oookJ_oonf[ooo]Zomgo0?oonf[o:`3o00Co
oo]Z00Cooi/0ool00?oo0:Wok?l01?oonfX00onC0?oooo]ZoookJP0PoookJP009ooonfX00olY0?oo
oo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00CoonP0ool02ooonf[ooo]Z1_oob@001_oo
nf[o0?nGoookJ_l0onSooo]ZocKo00gooo]Z00CoiOl0oookJ_oonf[oo`3/3?oonfX00ol0ongooo]Z
oookJP09oookJP03oolJ0?ooN@3o0?ob00;ooo]Z00Coo`2doookJ_oonf[oojL01ooonfX02Ol0o`Wo
oo]ZoookJ_oonf[oO03oocCo0?oUo`3o00_oool06002oookJP03ok3o0?oonf[o0?_o00;ooo]Z00Co
CP3ooookJ_oonf[oo`0D0_oonfX00oooa`3ooo]ZoookJP02oookJP05oonX0?oo0:Oooo]ZoookJ_oo
8@001OoonfX02?l0oiOooo]ZoookJ_n>o`3oo`0ioookJ_l0ol3oo`074?oonfX01Ooo03SoN@3ookSo
0?oonf[oo`2l00;ooo]Z00?oK03ooookJ_oonfX00_oonfX00oo]0?ooWOl0oookJP02oiCo0004oook
J_m4o`3oA?l0odCo00?oiOl02Om4o`000ol0oh_oA?l0odCo0002o`3o3007ool0]Ooo803o0?l<o`3o
>?mko`3o:P3oool0X002o`3oG@03o`3o8Ol0oego0?on00go0?on0_l0/?l01Ol0ojgo0;3oo`2`ool0
/?oo05oo00;o0?on00?o0?n]o`3oo_l0/?l01_l0oed01?m4o`3o05ooo`3oo_l0oed6o`3o3006oonX
0?m4o`3oo`0Do`3o3?m4o`3o00_o0om4o`001OooY`3oiOl0onGo0?oUo`3o0?o]00;ooo]Z00Koo`3/
odCo0?m4o`3oA?l0oiCo0?l0onP2oiCo00;oA?l000?o0?o`odCo0?m4o`000om4o`03oookJP05oooS
0?oonf[oK03ooookJ_mRo`001OoonfX3oiCo0005oe[o0?l0okkooo]Zool0m_l00ol00_oonfX01Ol0
odSoU?l0o`3oMonDo`3oN@3o00;oU?l00ooonfX00ooo_`3ooo]Zo`2<o`04oiCo0003oookJ_oo0?;o
0?mF00?ooo]Z00?oo`2Poe@0ool09Ol00_oonfX00olZ0?ooo`X0oookJP02oookJP04og_o0?oonf[o
oi`0oom100;ooo]Z00?o0?lho`P0oooonfX01_oonfX01Ooo803ooo]ZoookJ_oonf[oo`2e00gooo]Z
00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0>oookJP05ool0Cooonf[ooo]ZoookJ_l0
oiH01_oonfX01?oo703ooo]ZoookJ_nho`0<oookJP03om;o0?oonf[ogOl000KoiOl00_oonfX00ooo
003ooo]ZonGo0005oookJP03oi<0oooonf[ooo]Z04?ooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0
oo3ooo]ZoookJP05oookJP03oooX0?oonf[oo`0;00Cooo]Z00?oocD0oookJ_l0POl00_oonfX01Ol0
oiOo0?oXoookJ_oonf[o=_l000gooo]Z00?o0>?ooookJ_oo0>`03?oonfX00ol0ongooo]ZoookJP09
oookJP03oolJ0?lM0?oo0?ob00;ooo]Z00Coo`2doookJ_oonf[oojL01ooonfX02Ol0o`Wooo]Zoook
J_oonf[oO03oocCo0?l0;Ooo00_oool06002oookJP03ok3o0?oonf[o0?_o00;ooo]Z00CoCP3ooook
J_oonf[oo`0D0_oonfX00oooa`3ooo]ZoookJP03oookJP04oonX0?oonf[ooo]ZoolQ00Gooo]Z00Wo
0?nGoookJ_oonf[ooo]Zohko0?oonf[o0?o0oookJ_oo00L03ooonfX01Ooo03SoN@3ooookJ_nho`3o
o`2l00;ooo]Z00?oK03ooookJ_oonfX00_oonfX03?o]0?oooo]Zoigo0?oo0=coE`3ooookJ_nC0?oo
k?l0ool00?l[0?oogOl0om;o00;ooo]Z00Cooa`0oookJ_l0oiKoo`1?0ooonfX00ol0oh_o0?neoook
JP02oookJP0?ool0]Ooo803ooo]Zo`3o>?mko`3oo`X0obX0oooo0:3oo`3bo`3o8Ooo_`3oN@3oo`3o
Mol0odSoF_l000;ooo]Z00CoK03ooooS0?oo0:[o0?o`0_l0onP2ool0k00Eoad0oooo0;Co7@3oool0
k?l0onSoK03ooooS0?l0ogOo0?lQool0X?mko`3oo`2eo`3oRooo04oo^?l0omgo0?oo003oo`3Lond0
oom/0?ooo`2l00?ooo]Z013oo`07ohko0?l0oiOoo`2doolQ0?ooZ03oolL0ool05?l0nooo00_oocCo
0?l0o`Wooo]ZoonW0?oonf[o7@3o0_oonfX01?l0ongooo]ZoookJ_oo0>`3oookJP07o`3oj?l0POoo
ocD0oooX0?oonf[o0?o`obT0o`02oookJP03oeT0ool0odgooo]Z00;ooo]Z00Goo`d0oooS0?m/0?oo
oo]Zof;o0006oookJP04on;o0?oonf[oF_l0o`3o_P;ooo]Z00So00?ooookJ_oonf[o0?m8oookJ_l0
ogOooo]ZogT0o`Gooo]Z00Kookl0o`2Rool0S?oo0?nRoookJ_l0ob42oookJP03ool0l_oonf[o0?mF
00;ooo]Z00Ooo`2PoookJ_mD0?oo02GooookJ_lZ0?ooo`X000?ooo]Z00CoNol0oookJ_oonf[ood40
0ooonfX00ol0ocSooo]ZoookJP05oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX0
2_oonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z00oooo]Z00Coo`1?oookJ_oonf[o
0?nF1_oonfX01?oo703ooo]ZoookJ_nho`0<oookJP04om;o0?oonf[ooo]Zomgo00;ooo]Z00?o:`3o
oookJ_oonfX00_oonfX01?ooV`3oo`00ool0ZOo/o`04oookJP03oi<0oooonf[ooo]Z023ooo]Z000W
oookJP05obT0oooonf[ooo]ZoookJ_l0oo002?oonfX01?ooj03oo`0;oookJ_oonfX6ooo90006oook
J_l0oiOooo]Zo`3oj?oonf[o=_l03OoonfX01?oUo`3ooo]ZoookJ_oo0>`<oookJP03o`3okOoonf[o
oo]Z00Wooo]Z00?ooaX0oomi0?oonfX00_oonfX00ooo0;Cooo]ZoonW0008oookJP07o`3o2Ooonf[o
oo]ZoookJ_ldo`3oiOl0o`0;o`02onGo00;ooo]Z00?o/?l0o`3koooonfX00_oonfX01?m>0?oooo]Z
oookJ_oo01@2oookJP07ooo70?oonf[ooo]ZoookJ_ooZ03ooo]Zool0Y`02oookJP03oolQ0?oonf[o
oo]Z00;ooo]Z00Wo0?nGoookJ_oonf[oS_l0oookJ_oo03Wooo]Zo`3o`?oo00L03ooonfX01_oo03So
oo]ZogT0oonho`3ooo]Zool0_0;ooo]Z00?oK03ooookJ_oonfX00_oonfX00onDo`3oWOl0oiCo0002
oiCo0004oookJ_m4o`3oA?l0odCo00?oiOl02Om4o`004?l0oh_oA?l0odCo0?l0o`coo`2eo`3o3?oo
803o0?lho`3o3?mko`3o0?l<ool0X?l0oego0?lQo`3o3?m4o`0Ao`3ooP?o0;3o00Ko05ooo`3oo_l0
ooko0?n]o`2`ool0Gol5o`3oG@?o00oo00?o0?ono`3o3?l0o``01Ol0o``01_ooZ03o0?l<ool05?m>
0?ooA?l0o`0;o`?oA?l000GoojL0odCo0?m4o`3oiOl0o`3ok@02oookJP06ool0k?m4o`3oA?l0odCo
0?nDo`3o0?oX0_nDo`02odCo0003o`3ol?m4o`3oA?l000?oA?l00ooonfX01Oooh`3ooo]Zof`0oooo
nf[oH_l000Gooo]Z0onDo`001omJo`3ooo]ZoookJ_oo0?Ko00?ooookJ_l0odP00_oonfX01?l0ogOo
U?l0ogT0oonDo`04oookJP03oono0?oonf[o08co00?oU?l00_oonfX00ooo0?;o0?mFoookJP02oook
JP03ool0X?mD0?oo02Go00;ooo]Z00?o:P3ooookJ_oonfX00_oonfX01?mko`3ooo]ZoonL0?oo@@02
oookJP03o`3o>?l80?oooo]Z00Kooo]Z00Goob00oookJ_oonf[ooo]Zool0]@0=oookJP03o`3o]Ooo
nf[ooo]Z00?ooo]Z00?o0?n;oookJ_oonfX03_oonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Gooo]Z
00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP03om;o0?oonf[ogOl000KoiOl00_oonfX00ooo003o
oo]ZonGo0005oookJP03oi<0oooonf[ooo]Z04?ooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol008oook
JP03oooX0?oonf[oo`0;00Cooo]Z00?oocD0o`21oooonfX00_oonfX01Ol0oiOo0?oXoookJ_oonf[o
=_l000gooo]Z00?o0>?ooookJ_oo0>`03?oonfX00ol0ongooo]ZoookJP09oookJP03oolJ0?lM0?oo
oo]Z00;ooo]Z00?oo`2doookJ_ooY`002?oonfX02Ol0o`Wooo]ZoookJ_oonf[oO03oocCo0?oonf[o
00_oool06002oookJP03ok3o0?l0nooooo]Z00;ooo]Z00CoCP3ooookJ_oonf[oo`0D0_oonfX00ooo
a`3ooo]ZoookJP02oookJP05oonX0?oo0:Oooo]ZoookJ_oo8@001OoonfX02Ol0oiOooo]ZoookJ_n>
o`3oo`0ioookJ_l0ol3ooo]Zool01`0?oookJP05ool0>?mi0?oo^?l0oookJ_oo0;`00_oonfX00om/
0?oooo]ZoookJP02oookJP0Bond0oonMo`3ooo]Zool0g?mG0?oooo]Zoi<0ooo/o`3oo`00ob/0oooM
o`3od_l0oookJ_nho`3ooa`0oookJ_l0oiKoo`1?0ooonfX07_l0oh_o0?neoookJ_oonf[oo`2eoook
J_oo803o0?lhoom10?mko`3o:P3ooe@0oooo0:3oo`3bo`3o8Ol0X_ooN@3oo`3oB?l0okkoF_l0oook
J_ooh`3oK03oo`3oCOl0oo3o0?oXocKo0?oo0>coo`2doonW00;o00_o01?oo`0Do`0;ooooY`3o0?oX
o`3ol?ooh`3oN@3oo`3o8Omko`3o0?lho`3o]Ooo04oooa`0omgo0?oo003oE`3oond0oom/0?ooo`2l
00Cooo]Z00ooo`07ohko0?oo0;Coob40oonX0?ooa`3oo`0Do`3kool02ooo=?l0o`3o2Ooonf[oojL0
oookJ_lM0?l00_oonfX01?l0ongooo]ZoookJ_oo0>`3oookJP07o`3oj?l0POooocD0oooX0?oonf[o
0?o`obT0o`02oookJP03oeT0ool0odgooo]Z00;ooo]Z00Goo`d0oooS0?m/0?oooo]Zof;o0006oook
JP07on;o0?oonf[oF_l0o`3o__oonf[oo`3fo`03o`02oookJP05o`3oB?oonf[o0?mgoookJ_mi0?l0
1OoonfX01_oo_`3o0:;oo`2<ool0oj;ooo]Zo`3o8@;ooo]Z00?oo`3boookJ_l0oeH00_oonfX01ooo
0:3ooo]Zoe@0ool09Ooooo]ZobX0oooo2P000ooonfX01?mko`3ooo]ZoookJ_oo@@03oookJP03o`3o
>?oonf[ooo]Z00Gooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP0:oookJP03o`3o
]Ooonf[ooo]Z00?ooo]Z00?o0?n;oookJ_oonfX03ooonfX01?oo04oooo]ZoookJ_l0oiH5oookJP05
oolL0?oonf[ooo]ZoookJ_nho`003?oonfX01?oBo`3ooo]ZoookJ_oMo`02oookJP03ob/0oooonf[o
oo]Z00;ooo]Z00Cooi/0ool00?oo0:Wok?l01?oonfX00onC0?oooo]ZoookJP0PoookJP009ooonfX0
1OlY0?oooo]ZoookJ_oonf[o0?o`00Sooo]Z00?oonP0oookJ_oonfX01ooob@001_oonf[o0?nGoook
J_l0onSooo]ZocKo00gooo]Z00CoiOl0oookJ_oonf[oo`3/3?oonfX00ol0ongooo]ZoookJP09oook
JP03oolJ0?ooN@3ooo]Z00;ooo]Z00?oo`2doookJ_ooY`001ooonfX00ol0o`Wooo]ZoookJP02oook
JP03ocCo0?oUo`3o00_o00;oiOl00_oonfX00on`o`3o0?_ooookJP02oookJP03odh0oooonf[oo`0D
00?ooo]Z00OoolL0oookJ_oonf[ooo]ZoonX0?oonf[oo`2W00;ooo]Z00?oob40oookJ_oonfX00_oo
nfX02Ol0oiOooo]ZoookJ_n>o`3ooo]Zool0>Ooonf[o0?o0ool01`0?oookJP08ool0>?mi0?oooo]Z
okSo0?oonf[oo`2loookJ_m/0?l5oookJP03oiCo0?nMo`3oU?l000;oU?l000CoiOl0odCo0?m4o`3o
A?l00ooUo`08odCo000:o`3oRom4o`3oA?l0oookJ_l0o`coo`2eoolP0?l0o`co0?lhog_o00;o0?l<
00Goo`2Po`3oGOl0ob7o0?l<ogT0o`0Bo`3ooP;o0;3o00Co05ooo`3oo_l0ojgo0?n]0_l0Gol00ol0
oego00ooo`0?o`02o`0?o`Co05oo00?o0?ono`3o3?l0o``01?l0o``01_ooZ03oA?l0ool05?m>0?oo
A?l0o`0;o`;oA?l000?oojL0odCo0?m4o`000_m4o`001?l0ongooo]ZoookJ_oo0>`2odCo00;oU?l0
00?o0?oXoiCo0?nDo`000_m4o`000ol0oo3oA?l0odCo0002odCo0006o`3oCOoonf[ooo]ZoookJ_oo
h`3oK03o0_oonfX00omRo`3ooo]ZoookJP03oookJP?oU?l000CoF_l0oookJ_oonf[o00?o0_oonfX0
1ol0odSooo]ZoookJ_l0ogOoU?l0ogT0oonDo`001?oonfX00ooo_`3ooo]Zo`2<o`03oiCo00;ooo]Z
00Soo`3bo`3oE_oonf[ooo]Zool0X?oonf[oE03oo`0Uo`;ooo]Z00?o:P3ooookJ_oonfX00_oonfX0
1?mko`3ooo]ZoonL0?oo@@02oookJP03oiCo0?l80?oooo]Z00Kooo]Z00Goob00oookJ_oonf[ooo]Z
ool0]@0=oookJP03o`3o]Ooonf[ooo]Z00;ooo]Z00?o0?n;oookJ_oonfX03ooonfX01Ooo04oooo]Z
oookJ_oonf[o0?nF00Gooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP03om;o0?oonf[ogOl0
00GoiOl00ooonfX00ooo003ooo]ZonGo0005oookJP03oi<0oooonf[ooo]Z04?ooo]Z00Go:@3ooook
J_oonf[ooo]Zo`3ol008oookJP03oooX0?oo00_ooo]Z00Cooo]Z00?oocD0o`21oooonfX00_oonfX0
1Ol0oiOo0?oXoookJ_oonf[o=_l000cooo]Z00Co0>?ooookJ_oonf[oo`3/3?oonfX00ol0ongooo]Z
oookJP09oookJP03oolJ0?lM0?oooo]Z00;ooo]Z00?oo`2doookJ_ooY`002?oonfX02Ol0o`Wooo]Z
oookJ_oonf[oO03oocCo0?oonf[o00_oool06002oookJP03ok3o0?l0nooooo]Z00;ooo]Z00CoCP3o
oookJ_oonf[oo`0D0_oonfX00oooa`3ooo]ZoookJP02oookJP05oonX0?oo0:Oooo]ZoookJ_oo8@00
1OoonfX02Ol0oiOooo]ZoookJ_n>o`3oo`0ioookJ_l0ol3ooo]Zool01`0?oookJP05ogT0oooonf[o
^?l0oookJ_oo0;`00_oonfX00om/0?oooo]ZoookJP02oookJP0Bond0oonMo`3ooo]Zool0g?mG0?oo
oo]Zoi<0ooo/o`3oo`00ob/0oooMo`3od_l0oookJ_nho`3ooa`0o`3oU_oonf[oo`1?0ooonfX04ol0
oh_o0?neoookJ_oonf[oo`2eoolP0?oonf[o0?lhoom10?mko`3o:P3ooe@0oooo0:3o0?lQo`3oX_mi
0?oo0?mgo`3oB?mJo`000_oonfX02?m/0?oo0?m=obT0ool0oo3o0?oXool0k?lM0?ooojL00_oo01@3
ool01`0Bool05?l02ooo0?oXof`0oomi0?oo0?lQog_o0?l0ocSoo`2eool0Cooo703ogOl0ool00?mG
0?ook@3oof`0oooo0;coo`0h0ooonfX03ooo00OoS_l0oookJ_oo8@3oojP0ooo70?oo01Co0?_oo`0;
ooldo`3o0?l9oookJ_ooY`3ooo]Zoad0o`02oookJP04o`3okOoonf[ooo]Zool0k0?ooo]Z00Oo0?oX
o`21oooo=@3oonP0oookJ_l0oo3o:@3o00;ooo]Z00?oF@3oo`3oCOoonfX00_oonfX01Ooo3@3oon<0
of`0oooonf[oH_l000Kooo]Z00Ooh_l0oookJ_mJo`3o0?nnoookJ_oo0?Ko00?o00;ooo]Z00Go0?m8
oookJ_l0ogOooo]ZogT0o`05oookJP06oono0?l0X_oo08coo`3oX_oonf[o0?lQ0_oonfX01Ooo0?;o
oo]Zo`3oE_oonf[oo`2P00;ooo]Z00GoE03oo`0Uoooonf[o:P3oool:0003oookJP04og_o0?oonf[o
oo]Zoom100?ooo]Z00?o0?lhoookJ_oonfX01OoonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooo
nf[ooo]Z00[ooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0?oookJP04ool0Cooo
nf[ooo]Zo`3oUPGooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP06om;o0?oonf[ooo]Zomgo
0?oonf[o:`3o1OoonfX01?ooV`3oo`00ool0ZOo/o`04oookJP03oi<0oooonf[ooo]Z023ooo]Z000W
oookJP05obT0oooonf[ooo]ZoookJ_l0oo001ooonfX01?ooj03oo`0;oookJ_oonfX7ooo90006oook
J_l0oiOooo]Zo`3oj?oonf[o=_l03OoonfX01?oUo`3ooo]ZoookJ_oo0>`;oookJP03o`3okOoonf[o
oo]Z00Wooo]Z00?ooaX0oomi0?l0oo800ooonfX00ooo0;Cooo]ZoonW0007oookJP08o`3o2Ooonf[o
oo]ZoookJ_ml0?oo=?l0onGo0?l02ol2onGo00;ooo]Z00?o/?l0o`3koooonfX00_oonfX00om>0?oo
oo]Zool05002oookJP03ooo70?oonf[ooo]Z00;ooo]Z00?oojP0oookJ_oo0:L00_oonfX00ooo8@3o
oo]ZoookJP02oookJP05o`3oUooonf[ooo]Zohko0?oo03T00_oonfX00ol0ol3oo`07oookJP0>oook
JP05ool0>?mi0?oooo]ZokSo0?oo0;`00_oonfX00om/0?oooo]ZoookJP02oookJPKoU?l01?m4o`03
onGo00GoA?l000Cooo]ZodCo0?m4o`3o0?n;0_m4o`02oookJP09ool0]Ooo803o0?l<o`3o3?mko`3o
0?l<ool0X?l0oego0?lQ00;o0?l<00?oN@3oo`3oo_l0ooh02ol0ooh00ol0/?ooo`07o`2`o`04o`2`
o`;o0?on0_l0ojd2o`0?o`Wo05oo0_l0ooh4o`3o3007oolQ0?ooZ03oolL0ool05?m>0?ooA?l0o`0;
o`02odCo0003oonW0?m4o`3oA?l000;oA?l000CoiOl0oookJ_oonf[oo`3/1?m4o`000ol0onSoU?l0
oiCo0002odCo0003o`3ol?m4o`3oA?l000;oA?l000Ko0?m=oookJ_oonf[oo`d0oooS0?m/0?l2oook
JP03of;o0?oonf[ooo]Z00?ooo]Z0onDo`001?mJo`3ooo]ZoookJ_l00ol2oookJP03o`3oB?oonf[o
0?mg00;oU?l000?oN@3ooiCo0?oonfX00ooonfX00ooo_`3ooo]Zo`3oXP03oiCo00;ooo]Z00Soo`3b
o`3oE_oonf[ooo]Zool0X?oonf[oE03oo`0Uo`;ooo]Z00?o:P3ooookJ_oonfX00_oonfX01?mko`3o
oo]ZoonL0?oo@@02oookJP03oiCo0?l80?oooo]Z00Kooo]Z00Goob00oookJ_oonf[ooo]Zool0]@0=
oookJP03o`3o]Ooonf[ooo]Z00;ooo]Z00?o0?n;oookJ_oonfX03ooonfX01Ooo04oooo]ZoookJ_oo
nf[o0?nF00Gooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP03om;o0?oonf[ogOl000GoiOl0
0_oonfX01?ooV`3oo`00oookJ_oUo`05oookJP03oi<0oooonf[ooo]Z04?ooo]Z00Go:@3ooookJ_oo
nf[ooo]Zo`3ol007oookJP03oooX0?oonf[oo`0;00Gooo]Z00?oocD0o`21oooonfX00_oonfX01Ol0
oiOo0?oXoookJ_oonf[o=_l000cooo]Z00Co0>?ooookJ_oonf[oo`3/2ooonfX00ol0ongooo]Zoook
JP0:oookJP03oad0ool0oo;ooo]Z00;ooo]Z00?oo`2doookJ_ooY`002?oonfX02Ol0o`Wooo]Zoook
J_oonf[o=?l0o`0]ool02ooooo]Zool06002oookJP03ok3o0?l0nooooo]Z00;ooo]Z00KoCP3ooook
J_oonf[oo`0DoookJ_ooa`05oookJP05oonX0?oo0:Oooo]ZoookJ_oo8@001?oonfX01Ol0oiOooo]Z
oookJ_oonf[oS_l000;ooo]Z00?o0?o0ool01ooonfX03ooonfX01Omi0?oooo]ZokSo0?oonf[oo`2l
00;ooo]Z00?oK03ooookJ_oonfX00_oonfX02oo]0?ooWOl0oookJ_oo0=coE`3ooookJ_nC0?ooo`00
oookJ_oMo`3od_l000;ooo]Z00Go^?l0oolL0?l0oiKooo]Zool0C`02oookJP03o`3oRooonf[o0?ne
00;ooo]Z00ooo`2eoolP0?oonf[o0?lhoom10?mko`3o:P3oool0X?oo0?;o0?lQoono0?mi0?oo0?mg
o`3oB?mJo`000_oonfX02Om/0?oo0?m=o`3ol?oo=@3o0?oXo`3SooooY`3o00_oool05002ool01`0D
ond0oooo003oo`07ool01ol0onSo0?o`oooS0?l0ob7oNol0o`3o>?oo0;Go0?n;ool0CooMo`3oo`00
oeL0ooo]0?ooK03oool0_?oo03P3oookJP0?ool01on>o`3ooo]ZoolQ0?ooZ03oolL0ool05?l0nooo
00_oocCo0?l0o`Wooo]ZoonW0?l0oo;o7@3o00;ooo]Z00Co0?o]oookJ_oonf[oo`3/0ooonfX01ol0
onSo087ooole0?ooj03ooo]Zo`3ol?lY0?l00_oonfX00omI0?oo0?m=oookJP02oookJP05ool=0?oo
h`3oK03ooookJ_mRo`001_oonfX02OoRo`3ooo]Zoe[o0?l0okkooo]Zool0m_l00ooooo]Zo`3oB002
oookJP03o`3oMooonf[oN@3o00Gooo]Z00?ookl0o`2Rool0oj800_oonfX02?l0ob7ooo]ZoookJ_oo
0?;ooo]Zo`3oE_oonf[oo`2P0_oonfX01OmD0?oo02GooookJ_lZ0?ooo`X000?ooo]Z00CoNol0oook
J_oonf[ood400ooonfX00ol0ocSooo]ZoookJP05oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2e
oookJ_oonfX02_oonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z00oooo]Z00Coo`1?
oookJ_oonf[o0?nF1OoonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00Kod_l0oookJ_oonf[o
gOl0oookJ_l[0?l5oookJP04oonK0?oo003oo`2Yonco00Cooo]Z00?oT`3ooookJ_oonfX08?oonfX0
02?ooo]Z1?l000001OlY0?oo0000o`000?l0003o0?o`00Oo000000CoonP0ool02ol0003o00002?oo
b@02o`000003o`3oj?l0003o=_l000go000000CoiOl0o`000?l0003oo`3/2ol000000ol0ongo0000
o`000009o`000003oolJ0?ooN@3o0?ob00?o000000?oo`2do`000?ooY`001ol000002?l0o`Wo0000
o`000?l0003oO03oocCo0?oUo`3o00_o0_oUo`02o`000003ok3o0?l0nooo000000;o000000?oCP3o
o`000?oo01@00_l000000ooUo`3o0000o`000002o`000006oonX0?oo0:Oo0000o`000?oo0;Coob40
1?l000002?l0oiOo0000o`000?n>o`3oo`0io`000?l0ol3oo`074?l000001Ooo03SoN@3oo`000?nh
o`3oo`2l00;o000000?oK03oo`000?l000000_l00005oiCo0003onGo0?m4o`3oA?l000;oA?l00ooU
o`05odCo00?o000000Oo0?n;odCo0?m4o`3o0000ool0]Ol0003oob0000;o0?l<00GoNol0o`3o3?oo
0:3o0?mMo`3o8@02o`3o3003ogT0ool0ooko0?on00?o0?on1Ol0/?l4o`0?o`07ool01ooo003oo`00
o`1Ooooo00Oo0;3oo`0?o`0>o`1Oo`04o`3oo_l0o`co0?l<ool01`;o0?l<00Coob40oonX0?ooa`3o
o`0D0_m4o`001?l02oooA?l0odCo0?ooY`03odCo00CoiOl000?oo`3/odCo0?m4o`001om4o`001_l0
oo3oA?l0odCo0?m4o`3oo`2Zo`3oC@;o000000?oo`d0oooS0?m/0?l00_l000000omRo`3o0000o`00
0003o`0000?oU?l000CoF_l0o`000?oo0?Ko00?o0_l000000ol0odSo0000o`3oM`02oiCo0003ogT0
ool0003o000000?o000000Cookl0o`000?l0oj;o00000_nDo`001?l0003oo`3bo`000?l0oeH2o`00
0004ool0X?l0003oE03oo`0Uo`;o000000Go:P3oo`000?l0003o0000og_o0002o`000006oonL0?oo
@@3o0000o`000?nDo`3o203o1ol000001Ooo803o0000o`000?l0003oo`2e00co000000?o0?neo`00
0?l000000ol000000ol0oh_o0000o`00000?o`000004ool0Col0003o0000o`3oUPKo000000Gooa`0
o`000?l0003o0000okSo000<o`000003om;o0?l0003ogOl000GoiOl00_l000001?ooV`3oo`00onGo
0?oo0:T5o`000004oi<0ool0003o0000o`0003kooo]Z1?l000001OlY0?oo0000o`000?l0003o0?o`
00Oo000000?oonP0o`000?oo00/01Ol000001ooo=@3o087oo`000?l0003o0?nGo`000?l0onP00_l0
00000olfo`3o0000o`00000:o`000004o`3Sool0003o0000ool0k0_o000000?o0?o]o`000?l00000
2_l000000olM0?oo0?obo`000002o`000003ool0]?l0003oojL000So000000So0?l9o`000?l0003o
0000ocCo0?l0;Ooo00_oool060?o000000?o/?l0o`3kool000000_l000001_m>0?oo0000o`000?oo
01Co0000ooo700Go000000GoojP0ool0Yol0003oo`2doolQ0004o`000009o`3oUol0003o0000o`00
0?n>o`3o0000o`3o`?l0003oo`0700oo000000Koo`0hogT0ool0003o^?l0o`000?oo0;`2o`000003
of`0ool0003o000000;o000000_ok@3ooigo0?l0003oo`3LoeL0ool0003oT`3oool00?l[0?oogOl0
om;o0002o`000004oolL0?l0003o0?nFool0C`?o0000027o0?n;o`3o]Ol0003o0000ool0]Ol0003o
ob00o`000?l0ocSood40og_o0?mD0?ooo`2Pool0l_l0ob7ookl0ogT0ool0ogOo0?nnoe[o0?l0003o
K03ooooS0?l0odgo0?o`o`3oj?oo0>co0?o]oonW0?oo01CoojP0ool01oo]0?l00_oo0002ool01`0@
ool05?l0onSoK03oogT0ool0ob7oNol0ool0]Ol0oh_oo`1?omgo0?oo003oE`3oond0oom/0?ooo`2l
ool0>0?o000000ooo`07ohko0?l0003oojP0o`000?oo01CoCP3oo`3kool02ooo=?l0o`3o2Ol0003o
ojL0oad0oooo6P000_l000001?l0ongo0000o`000?oo0>`3o`000007o`3oj?l0POooocD0oooX0?l0
003o0?o`obT0o`02o`000003ool0Z_l0odgo000000;o000000Goo`d0oooS0?m/0?oo0000of;o0006
o`000003on;o0?l0003oF_l000;o000000Coo`3fo`03ool0003o0?m80_l000000ol0ogOo0000ogT0
o`05o`000003oono0?l0003o0?nR00;o000000So0?lQo`000?l0003oo`3bo`000?l0oeKo0000ool0
X0;o000000GoE03oo`0Uool0003o:P3oool:0003o`000004og_o0?l0003o0000oom100?o000000?o
0?lho`000?l000001Ol000000ooo803o0000o`000002o`000003ool0]Ol0003o000000[o000000?o
0?neo`000?l000000ol000000ol0oh_o0000o`00000>o`000005ool0Col0003o0000o`000?l0oiH0
1Ol000001Ooo703o0000o`000?l0003o^?l000co000000Kod_l0o`000?l0003ogOl0o`000?l[0?l5
o`000003ool00?l0003ok?l000Go000000?oT`3oo`000?l000000_l0000NoookJP008ooonfX4o`00
0005obT0ool0003o0000o`000?l0oo001ol000000oooj03oo`0;o`000009ooo900;o000000?o0?oX
o`000?lfo`003Ol000001?oUo`3o0000o`000?oo0>`;o`000003o`3okOl0003o000000Wo000000?o
oaX0oomi0?l0oo800ol000000ooo0;Co0000oonW0007o`000008o`3o2Ol0003o0000o`000?ml0?oo
=?l0onGo0?l02ol2onGo00;o000000Go0?_oo`000?l0003o0000odh0o`02o`000004ool05?l0003o
0000onGo00Co000000GoojP0ool0Yol0003o0000oolQ0005o`000008o`3oUol0003o0000ohko0?oo
03Wo0000o`3o`?nDo`0?o`000006ool0>?l0003oN@3oo`000?nho`3oo`2l0_l000001?m/0?oo0000
o`000?l00005oiCo0003onGo0?m4o`3oA?l000?oA?l00_oUo`000ol0003oA?l0odCo0004odCo0004
o`000?l0oh_o0000odCo00;o000000?oo`2eo`000?oo80000_l0o``01_mko`3o0?l<ool0X?l0o`co
0?lQo`3o30;o0?n]0ol0ooh:o`0?o`03ool01ol03ooo0?on00?o00oo4?l0Gol01?l0ooko0?l<o`3o
3?oo00L3o`3o3006oonX0?ooa`3oo`0Do`3koom4o`3o00_o0_m4o`000oooY`3oA?l0odCo0005onGo
0003ool0k?m4o`3o000000_oA?l000Woo`2Zo`3oCOm4o`3oA?l0ool=0?ooh`3oK03oo`000?mRo`00
1ol00002oiCo0004oe[o0?l0003oo`3fo`03o`;o000000?o0?m8o`000?l0ogL00_nDo`000omi0?oo
0000o`000002o`000006o`2Roooo_`3o0000o`3oX_l0003oU?l00_l000000ooo0?;o0000o`3oEP02
o`000004ool0X?l0003oE03oo`0Uo`;o000000Go:P3oo`000?l0003o0000og_o0002o`000006oom1
0?l0003o0000o`000?nDo`3o203o1ol000001Ooo803o0000o`000?l0003oo`2e00co000000?o0?ne
o`000?l000000ol000000ol0oh_o0000o`00000?o`000004ool0Col0003o0000o`3oUPKo000000Go
oa`0o`000?l0003o0000okSo000<o`000003om;o0?l0003ogOl000CoiOl00ol000001?ooV`3oo`00
onGo0?oo0:T5o`000004oi<0ool0003o0000o`0003kooo]Z1?l000001OlY0?oo0000o`000?l0003o
0?o`00Oo000000?oonP0o`000?oo00/01Ol000001ooo=@3o087oo`000?l0003o0?nGo`000?l0onP0
0_l000000olfo`3o0000o`00000:o`000004o`3Sool0003o0000ool0k0_o000000?o0?o]o`000?l0
00002Ol000000ooo6P3o7@3oo`3olP03o`000003ool0]?l0003oojL000Oo000000Wo0?l9o`000?l0
003o0000og`0ooldo`3o02goo`0;oooo01P00ol000001Ol0nooo0000o`000?l0003oCP3o00;o0000
00Coo`0Do`000?l0003oolL01Ol000001?ooZ03oo`2Wo`000?oo8@05o`000009o`3oUol0003o0000
o`000?n>o`3o0000o`3o`?l0003oo`0700oo000000Soo`0hogT0ool0003o^?l0o`000?oo0;co0000
of`0o`Go0000017ok@3ooigo0?oo0=cookL0oeL0ool0003oT`3oool00?l[0?oogOl0om;o0?l0003o
^?l0oolL0?l0003o0?nFool0C`03o`00000So`3oRol0okGo0000o`000?oo0;Go0000oolP0?l80?oo
0?lhog_o0?lZ0?ooE03oool0X?l0oeKo0?lQo`2Roomi0?oo0?m8oe[o0?oRo`3o0000of`0ooooh`3o
0?m=o`3ol?l0onSoo`3/oad0ooooY`3oo`0DoonX0?oo00Ook@3oool00?l0ob400ooo00L03_l0onSo
K03oogT0ool0ob7oNol0ool0]Ol0oh_oo`1?omgo0?oo003oE`3oond0oom/0?ooo`2l1?l000003ooo
00OoS_l0oolQ0?ooZ03oolL0ool05?m>0?oo0?_oo`0;ooldo`3o0?l9o`000?ooY`3o7@3ooolJ0002
o`000004o`3okOl0003oo`3/o`3So`?o000000_o0?oXo`21oooo=@3oonP0o`3ol?l0003o:@3oo`00
0?mI0?ooo`2Zo`3oC@03o`000004ool=0?m/0?oo0000of;o00Oo000000?oh_l0o`000?mJo`000_l0
00001?l00ooo0000o`000?l0odP2o`000003o`3oMol0003oN@3o00Go000000?ookl0o`000?l0oj80
0_l000002?l0ob7o0000o`000?oo0?;o0000o`3oE_l0003oo`2P0_l000001OmD0?oo02Goo`000?lZ
0?ooo`X000?o000000CoNol0o`000?oo@@3ooi`00_l000000ol0ocSo203oo`000006o`000005oolP
0?l0003o0000o`000?oo0;D03Ol000000ol0okGo0000o`000003o`000003o`3oRol0003o000000ko
000000Goo`1?o`000?l0003o0000o`3oUP05o`000005oolL0?l0003o0000o`000?nho`003?l00000
1_oBo`3o0000o`000?oMo`3o0000ob/0o`Go000000?oo`00o`000?o/o`001Ol000000onC0?oo0000
o`000002o`0001kooo]Z000SoookJPCo000000Co:@3oo`000?l0003o0?o`2?l000000oooj03oo`0;
o`000009ooo900;o000000?o0?oXocKo0?l000003?l000001OoUo`3o0000o`000?l0003oo`3/00_o
000000?o0?o]o`000?l000002Ol000000ooo6P3oogT0o`3olP03o`000003ool0]?l0003oojL000Oo
000000So0?l9o`000?l0003o0000og`0ooldo`3oiOl0o`0;o`;oiOl000?o0000ok3o0?nDo`000ol0
00001?m>0?oo0000o`000?oo01@2o`000007onGo0?l0003o0000o`000?ooZ03o0000ool0Y`02o`00
0003oolQ0?l0003o000000?o000000So0?nGo`000?l0003oS_l0ool0>Ol0003o0?o0oiCo00oo0000
00Soo`0ho`000?mi0?oo0000okSo0?oo0;co0000of`0o`Co00001_nDo`06odCo0004onGo0?l0003o
^?l0oolL00CoA?l000Co0000o`3oRol0003o0?ne0_l000000ooo0;Goob00o`000002o`3o3006og_o
0?l0o`coo`2Po`3o3?l0ob7o0?l<0ol0ojd2o`3ooP[o00oo00Ko0?n]o`0?ool0ookogOl0o`1Oool0
3ol2o`2`o`go05oo0_l0ooh2o`3o300:ool01ol0o`co0?l<o`3o3?ooZ03oolL0ool05?l0noooA?l0
o`0;o`;oA?l000?oojL0odCo0?oUo`000_m4o`03onGo0003ool0k?m4o`3oA?l000_oA?l000Woo`2Z
o`3oCOm4o`3oA?l0ool=0?ooh`3oK03oo`000?mRo`001ol000002?nDo`3o0000oe[o0?l0003oo`3f
o`03ool0003o0?m80_l000001?l0ogOo0000oiCo0?mi0?l4o`000006o`2Roooo_`3o0000o`3oX_l0
003oU?l00_l000000ooo0?;o0000o`3oEP02o`000003ool0X?l0003oE03o00;o000000?o04coobX0
ool000000_l000001?mko`3o0000o`000?oo@@02o`000003oiCo0?l0003o203o00Oo000000Goob00
o`000?l0003o0000ool0]@0<o`000003o`3o]Ol0003o000000?o000000?o0?n;o`000?l000003ol0
00001?oo04oo0000o`000?l0oiH6o`000005oolL0?l0003o0000o`000?nho`002ol000001?oBo`3o
0000o`000?oMo`04onGo00?o000000Cooi/0ool00?oUo`3oo`2Y1Ol000001?nC0?oo0000o`000?l0
000noookJPCo000000Co:@3oo`000?l0003o0?o`2?l000000oooj03o0000ool02`05o`000009oole
0?l0POoo0000o`000?l0oiOo0000o`3oj?l0003o=_l000go000000Co0>?oo`000?l0003oo`3/2ol0
00000ol0ongo0000o`000009o`000003oolJ0?lM0?oo0?ob00?o000000?oo`2do`000?ooY`001ol0
00002Ol0o`Wo0000o`000?l0003oO03oocCo0?l0;Ooo00_oool06002o`000003ok3o0?l0nooo0000
00;o000000CoCP3oo`000?l0003oo`0D0_l000000oooa`3o0000o`000002o`000005oonX0?l0003o
o`2Wo`000?oo8@001Ol000002Ol0oiOo0000o`000?l0003oS_l0o`000?l0ol3o0000ool01`0?o`00
0005ool0>?mi0?oo0000okSo0?oo0;`00_l000000om/0?oo0000o`000003o`00000Aond0oonMo`3o
o`3LoeL0ool0003oT`3oonco0?oo003o:`3oomgo0?oBo`3o0000okSo0?oo703o0000o`3oU_oo04l0
0ol000008ol0oh_o0?neo`000?l0003oo`2eoolP0?l0003o203oo`3o>?mko`3o:P3ooe@0oooo0:3o
0?lQo`3oX_l0X_ooN@3oo`3oB?mJo`3oh_l0o`000?m/0?oo0?m=obT0ool0oo3o0?oXool0k?lM0?oo
ojL0ool05?ooZ03oo`07ond0oooo003o0?lQ00Co0?oX00goN@3oo`3o8Omko`3o0?lhool0]Ol0oh_o
o`1?omgo0?oo003ok@3oo`000?nho`3oo`2l00?o0000013oo`07ohko0?l0oiOoob40oonX0?ooa`3o
o`0Dodh0ool0nooo00_oocCo0?l0o`Wo0000oonW0?lM0?oooaX00_l000001?l0ongo0000ool0k?l0
hol2o`000007o`3oj?l0oiOoocD0ool02oooj03o0?o`obT0o`02o`000003oeT0oooo0:[o0?m=00?o
000000Coo`d0of`0ool0003oH_l01ol000000ooRo`3o0000oe[o0002o`000004o`03ool0003o0000
o`3oB0;o000000?o0?mgo`000?mi0?l01Ol000000ooo_`3o0000o`3oXP02o`000008o`3o8Ol0003o
0000ool0l_l0003o0?mFo`000?oo0:02o`000004oe@0ool0003o0000obX0o`Co000000CoNol0o`00
0?oo@@3ooi`00_l000000ol0ocSo203oo`000006o`000005oolP0?l0003o0000o`000?oo0;D03Ol0
00000ol0okGo0000o`000002o`000003o`3oRol0003o000000oo000000Coo`1?o`000?l0003o0?nF
1_l000001Ooo703o0000o`000?l0003o^?l000_o000000Ood_l0o`000?l0003o0000omgo0?l0003o
:`3o00Go000000?oo`00o`000?o/o`001Ol000000onC0?oo0000o`000002o`0001kooo]Z000Soook
JPCo000000Co:@3oo`000?l0003o0?o`2?l000000oooj03oo`0;o`000004o`000005ooo90?lgo`3o
087oo`000?l0oiL00_l000000ol0onSo=_l0o`00000<o`000005onGo0?l0003o0000o`000?oo0>`0
2ol000000ol0ongo0000o`000009o`000003oolJ0?ooN@3o000000?o000000?oo`2do`000?ooY`00
1ol000002?l0o`Wo0000o`000?l0003oO03oocCo0?oUo`3o00_o0_oUo`000ol0003o/?l0oiCo0003
o`000005odh0ool0003o0000ool05?l000000ooUo`02o`000003oonX0?l0003oo`2W00;o000000?o
ob40o`000?l000000_l000002Ol0oiOo0000o`000?l0003oS_l0ool0>Ol0003o0?o0oiCo000?o`00
0008ool0>?l0003oN@3oo`000?nho`3oo`2lo`000?m/0?l4o`0000GoU?l01om4o`000ooUo`3o0000
okSo0005odCo0004o`000?l0oh_o0000o`3o]@;o000000?oo`2eoolP0?l0o``00_l0o``00omko`3o
0?l<o`3o3003o`3o3005ogT0ool0ojgo0?n]o`3oo_l0ojd02?l03ol01?l0ojgoo`0Do`3o[Ol0ojd2
o`3ooP03o`1Oool03ooo05oo00Go0;3o2Ol0Gol2o`3ooP;o0?l<00Woo`07o`3o3?l0o`co0?l<oonX
0?l0o`coo`0DodCo0?l02ol00om4o`000oooY`3oA?l0odCo0003odCo0004onGo0?oo0>co0000o`3S
o`_oA?l000?oo`2Zo`3oCOm4o`000_m4o`001Ooo3@3oon<0of`0ool0003oH_l000Oo000000SoU?l0
o`000?mJo`3o0000ool0m_l00ooo0000o`3oB0;o000000Co0?mgo`000?mi0?ooUol01?l000001_l0
X_oookl0o`000?l0oj;o0000o`3o8@;o000000?oo`3bo`3oE_l000000_l000000ooo0:3o0000oe@0
o`02o`000003obX0oooo2P3o000000;o000000CoNol0o`000?l0003ood400_l000000onDo`3o0000
o`P0o`07o`000005oolP0?l0003o0000o`000?oo0;D03?l000000ol0okGo0000o`000003o`000003
o`3oRol0003o000000ko000000Goo`1?o`000?l0003o0000o`3oUP06o`000004oolL0?l0003o0000
okSo00co000000Cod_l0o`000?l0003ogOl01?oUo`03o`000004oonK0?oo003oiOl0ool0Z@Go0000
00CoT`3oo`000?l0003o0000?_oonfX4o`000004obT0ool0003o0000o`3ol0So000000?oonP0o`00
0?oo00/01?l000000ooo=@3o=ol0o`21o`02o`000005o`3oUol0003o0?oXo`000?lfo`003Ol00000
1?l0hooo0000o`000?oo0>`;o`000003o`3okOl0003o000000Wo000000?ooaX0oad0ool000000ol0
00000ooo0;Co0000oonW0007o`000009o`3o2Ol0003o0000o`000?ml0?oo=?l0o`000?l02oooo`0H
00;o000000?o/?l0o`3kool000000_l000001?m>0?oo0000o`000?oo01@2o`000003ooo70?l0003o
000000;o000000GoojP0o`000?oo0:Oo0000oolQ0005o`000009o`3oUol0003o0000o`000?n>o`3o
0000o`3o`?l0003oo`0700oo000000Goo`0hogT0ool0003o^?l0ool0_002o`000003of`0ool0003o
000000;o000001;ok@3oo`000?nMo`3oo`3LoeL0ool0003oT`3oonco0?oo003o:`3oomgo0?oBo`3o
0000okSo0?oo703o0000o`3oU_oo04l3o`00000So`3oRol0okGo0000o`000?oo0;Goob00o`000?l0
ocSood40og_o0?lZ0?ooo`2Pool0l_l0ob7o0?nRo`000?mi0?oo0?m8oe[o0?oRo`3o0000of`0ool0
odgo:@3oo`3ol?l0onSoo`3/oad0ooooY`3oo`0DoonX0?oo00Ooo`2lool00?oo04l00_l0ob42ogT0
o`;o0?lQ00_oNol0ool0]Ol0oh_oo`1?oolL0?oo003oE`3oond0ool0003oo`2logT0o`03o`00000?
ool01on>o`3o0?nGoolQ0?ooZ03oolL0ool05?m>0?oo00_oocCo0?ml0?oo0?l9oonW0?oo0;Co7@3o
00;o000000Go0?o]o`000?l0003oo`3/o`3So`02o`000007o`3oj?l0oiOoocD0oooX0?l0003o0?o`
obT0o`02o`000003oeT0ool0odgo000000?o000000Coon<0of`0ool0003oH_l01ol000000ooRo`3o
0000oe[o0002o`000009o`03ool0003o0000o`3oB?l0003o0?mgo`000?mi0?ooUol000Go000000?o
okl0o`000?l0oj800_l000001Ol0ob7o0000o`000?oo0?;o0?mF00;o000000Ooo`2Po`000?l0003o
E03oo`000?lZ0?ooo`X000Co000000CoNol0o`000?oo@@3ooi`00_l000000ol0ocSo203oo`000006
o`000005oolP0?l0003o0000o`000?oo0;D03Ol000000ol0okGo0000o`000002o`000003o`3oRol0
003o000000oo000000Coo`1?o`000?l0003o0?nF1_l000001?oo703o0000o`000?nho`0<o`000007
om;o0?l0003o0000o`000?oMo`3o0000ob/0o`05o`000003ool00?l0003ok?l000Go000000?oT`3o
o`000?l000000_l0000NoookJP009OoonfX00ol0003o:@3ooookJP02oookJP03o`3ol?oonf[ooo]Z
00Kooo]Z00?oonP0ool02ooonfX01?oonfX01Ooob@3o=ol0o`21oooonf[o0?nG00;ooo]Z00?o0?oX
ocKo0?oonfX03?oonfX01OoUo`3ooo]ZoookJ_oonf[oo`3/00Kooo]Z00?o0000oookJ_oonfX00_oo
nfX00ol0ongooo]ZoookJP09oookJP03oomi0?l0oo;ooo]Z00?ooo]Z00?oo`2doonW0?oonfX01_oo
nfX02Ol0o`Wooo]ZoookJ_oonf[oiOl0og`0ooldo`3oiOl0o`0;o`03onGo0003ok3o0?nDo`3ooo]Z
00;ooo]Z00GoCP3ooookJ_oonf[oo`0DoookJP03onGo00;ooo]Z00?oojP0oookJ_oo0:L00_oonfX0
0ooo8@3ooo]ZoookJP02oookJP07o`3oUooonf[ooo]ZoookJ_n>o`3oo`0ioookJP03oiCo00kooo]Z
00Soo`0hoookJ_mi0?oooo]ZokSo0?oo0;cooo]Zof`0o`?ooo]Z1_nDo`07odCo0003onGo0?oonf[o
^?l000GoA?l000Cooo]Zo`3oRooonf[o0?ne0_oonfX00ooo0;Goob00o`3o3002o`3o3003og_o0?l0
o`co0?l<00?o0?l<00?oN@3oo`3o[Ol0ojd00_l0ojd3o`0?o`Co0?mM00?oojL0o`3o[Ol0ojd00_l0
ojd2o`3ooP?o00oo00?o0?ono`2`ool0/?l01Ol0/?l6o`1Oo`?o0?on00?o0?l<ool01ol0o``00_l0
o``01OooZ03oolL0ool05?m4o`3o00_o00?oA?l000?oojL0odCo0?m4o`001?m4o`000ooo0>cooo]Z
o`3So`0;odCo0003ool0Z_l0odgoA?l000;oA?l000Goon<0of`0oooonf[ooo]Zof;o0007oookJP08
on;o0?l0okkoF_l0oookJ_oo0?Ko00?ooookJ_l0odP2oookJP04o`3oMooonf[oN@3ooiOo00Cooo]Z
00Ko0:;ooono0?l0oj;o08cooookJ_l0ob42oookJP03ool0l_l0oeKooo]Z00;ooo]Z00?oo`2Poe@0
ool09Ol00_oonfX00olZ0?ooo`X0o`000002oookJP04og_o0?oonf[ooi`0oom100;ooo]Z00?oU?l0
oookJ_l80?l01ooonfX01?oo803ooo]ZoookJ_oo0;D=oookJP03o`3o]Ooonf[ooo]Z00?ooo]Z00?o
0?n;oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP02oookJP05ool0Cooonf[ooo]ZoookJ_l0oiH0
1_oonfX01?oo703ooo]ZoookJ_nho`0<oookJP04om;o0?oonf[ooo]Zomgo00?oiOl00_oonfX3onGo
0003ool00?oUo`3ooo]Z00Gooo]Z00?oiOl0oookJ_l00000@OoonfX00ol0003o:@3ooookJP02oook
JP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0oookJ_oo00/01?oonfX00ooo=@3o=ol0o`21o`02oook
JP05o`3oUooonf[o0?oXoookJ_lfo`003?oonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00Kooo]Z00?o
0000oookJ_oonfX00_oonfX00ol0ongooo]ZoookJP09oookJP03oad0ool0oo;ooo]Z00?ooo]Z00?o
o`2doonW0?oonfX01ooonfX02Ol0o`Wooo]ZoookJ_oonf[oO03oocCo0?oonf[o00_oool06002oook
JP03ok3o0?l0nooooo]Z00;ooo]Z00OoCP3ooookJ_oonf[oo`0DoookJ_l0003oolL000Cooo]Z00Go
ojP0oookJ_oo0:Oooo]ZoolQ0004oookJP03o`3oUooonf[ooo]Z00;ooo]Z00GoS_l0oookJ_l0ol3o
oo]Zool01`0?oookJP05ool0>?mi0?oooo]ZokSo0?oo0;`00_oonfX00om/0?oooo]ZoookJP02oook
JP0Bond0oonMo`3o0000ool0g?mG0?oooo]Zoi<0ooo/o`3oo`00omgo0?oonf[od_l0oookJ_nho`3o
oa`0oookJ_l0oiKoo`1?0ooonfX09?l0oh_o0?neoookJ_oonf[oo`2eoolP0?oonf[o0?lhoom10?mk
o`3o:P3oool0X?oo0?;o0?lQo`3oX_oonf[oN@3oo`3oB?mJo`3oh_l0oookJ_m/0?oo0?m=obT0ool0
oo3o0?oXool0k?lM0?ooojL0o`0;oooo01Coo`07ogT0ooo]0?ooo`00ool0C`?o0?lQ0_mko`002ol0
ocSo0?neo`3oRooo04oooa`0ool00?mG0?ook@3oof`0oooo0;coN@3o00?ooo]Z00ooo`07ohko0?l0
oiOoob40oonX0?ooa`3oo`0Dok3o0?l02ooo=?l0o`3o2Ooonf[oojL0ool0]?lM0?l00_oonfX01Ol0
ongooo]ZoookJ_oo0>co0>?o00;ooo]Z00Oo0?oXo`21oooo=@3oonP0oookJ_l0oo3o:@3o00;ooo]Z
00?oF@3oo`3oCOoonfX00ooonfX01?ooh`3oK03ooookJ_mRo`07oookJP06on;o0?oonf[oF_l0oook
J_oo0?Ko00?o0_oonfX01_l0odSooo]Zo`3oMooonf[oN@3ooiOo00Gooo]Z00?ookl0o`3oX_l0S?l0
0_oonfX01Ol0ob7ooo]ZoookJ_oo0?;o0?mF00;ooo]Z00Woo`2PoookJ_mD0?oo02GooookJ_lZ0?oo
o`X0oookJ_l000000_oonfX00omko`3ooo]Zoom10003oookJP03o`3o>?l80?oooo]Z00Kooo]Z00Go
ob00oookJ_oonf[ooo]Zool0]@0=oookJP03o`3o]Ooonf[ooo]Z00;ooo]Z00?o0?n;oookJ_oonfX0
2_oonfX00ol0003ooo]ZoookJP02oookJP04ool0Cooonf[ooo]Zo`3oUPKooo]Z00Cooa`0oookJ_oo
nf[o^?l03?oonfX01ooBo`3ooo]ZoookJ_oonf[ogOl0oookJ_l[0?l01OoonfX00ooo003oo`2Yonco
0005oookJP04oi<0oooonf[ooo]Zo`0001oooo]Z000VoookJP05obT0oooonf[ooo]ZoookJ_l0oo00
2?oonfX00oooj03oo`0;oookJP04oookJP05ooo90?l0POoooo]ZoookJ_l0oiL00_oonfX00ol0onSo
=_l0oookJP0<oookJP04onGo0?oonf[ooo]Zool0k0cooo]Z00?o0?o]oookJ_oonfX02OoonfX00ooo
N@3o0?oboookJP03oookJP03ool0]?ooY`3ooo]Z00Kooo]Z00So0?l9oookJ_oonf[ooo]Zog`0oold
o`3oiOl0o`0;o`CoiOl00onDo`02oookJP03odh0oooonf[oo`0D00;ooo]Z0ooUo`02oookJP03oonX
0?oonf[oo`2W00;ooo]Z00?oob40oookJ_oonfX00_oonfX01ol0oiOooo]ZoookJ_oonf[oS_l0ool0
>OoonfX00onDo`0>oookJP08ool0>?oonf[oN@3ookSo0?oonf[oo`2loookJ_m/0?l3oookJPGoU?l0
2?m4o`02oookJPKoA?l000Cooo]Zo`3oRooonf[o0?ne0_oonfX00ooo0;Goob00o`3o3002o`3o3003
og_o0?l0o`co0?l<00?o0?l<00?oN@3oo`3o[Ol0ojd00ol0ojd7o`3oG@Co0?n]0_l0ooh3o`0?o`;o
05oo1_l0/?l01?oo003o0;3oo`2`ool0/?l2o`1Oo`?o0?on00[oo`07o`3o3?l0oego0?mMoonX0?oo
a`3oo`0Do`3oGOm4o`3o00_o0_m4o`000oooY`3oo`2dodCo0005odCo0003ool0k?l0hooooo]Z00Oo
A?l000Oo0?o`odCo0?m4o`3oA?l0ool0Z_l0odgoA?l000;oU?l000Goon<0of`0oooonf[ooo]Zof;o
0007oookJP05on;o0?mJo`3ooo]ZoookJ_l00ol00_oonfX01_l0odSooo]ZoookJ_l0ogOooo]ZogT0
o`Gooo]Z00Go0:;ooono0?l0oj;o08coo`3o8@03oookJP08ool0l_l0oeKooo]ZoookJ_oo0:3ooo]Z
oe@0ool09Ol2oookJP03obX0oooo2P3ooo]Z00;ooo]Z00?oNol0oookJ_nDo`001?nDo`000ooonf[o
203ooookJP06oookJP04oolP0?oonf[ooo]Zool0]@gooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0
oh_ooo]ZoookJP0>oookJP05ool0Cooonf[ooo]ZoookJ_l0oiH01_oonfX01?oo703ooo]ZoookJ_nh
o`0<oookJP05om;o0?oonf[ooo]Zomgo0?oonfX00_oUo`02oookJP?oiOl000?oo`00onGo0?oUo`00
0ooUo`02oookJP03onGo0?oonf[ooo]Z04;ooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol008oookJP03
oooX0?oonf[oo`0;00Cooo]Z00?oocD0ocOo0?l0POl00_oonfX01Ol0oiOooo]Zo`3oj?oonf[o=_l0
00cooo]Z00Co0>?ooookJ_oonf[oo`3/3?oonfX00ol0ongooo]ZoookJP09oookJP03oad0ool0oo;o
oo]Z00?ooo]Z00?oo`2doonW0?oonfX01ooonfX02?l0o`Wooo]ZoookJ_oonf[oO03oocCo0?oonf[o
00_o0ooonfX00on`o`3o0?_ooookJP02oookJP04odh0oooonf[ooo]Zool050;ooo]Z00?oolL0oook
J_oonfX00_oonfX01OooZ03oo`2WoookJ_oonf[oob4000Cooo]Z00?o0?nGoookJ_oonfX00_oonfX0
1On>o`3ooo]Zo`3o`?oonf[oo`0700oooo]Z00Goo`0hogT0oonho`3ooo]Zool0_002oookJP03of`0
oooonf[ooo]Z00;ooo]Z01;ok@3ooigo0?oonf[oo`3LoeL0oooonf[oT`3oonco0?oo003ogOl0oook
J_oBo`3ooo]ZokSo0?oo703ooo]Zo`3oU_oo04l3oookJP0Ro`3oRol0okGooo]ZoookJ_oo0;Goob00
oookJ_l0ocSood40og_o0?lZ0?ooo`2Pool0l_l0ob7o0?nRoookJ_mi0?oo0?m8o`3o__mJo`3ooo]Z
of`0ooooh`3o0?m=o`3ol?l0onSoo`3/o`3okOooY`3o00_oool05?oo00Oo0?o0ool0_0;oo`0000?o
o`1?o`3oRol0oh/00_oo0;D02_l0oh_oo`1?ool0Cooo703oo`00oeL0ooo]0?oooo]Zool0_?mi0?l3
oookJP0@ool01ol0ol3oS_l0oookJ_ooZ03ooo]Zool05?m>0?oo0?_oo`0;ooldo`3o0?l9oookJ_oo
Y`3oo`2doolJ00;ooo]Z00Co0?o]oookJ_oo0>co0>?o0ooonfX01ol0onSo087ooole0?ooj03ooo]Z
o`3ol?lY0?l00_oonfX00omI0?oo0?m=oookJP03oookJP04oooS0?m/0?oooo]Zof;o00Oooo]Z00Ko
h_l0oe[o0?l0okkooo]Zool0m_l00ol2oookJP06o`3oB?oonf[o0?mgoookJ_mi0?ooobL01?oonfX0
1_l0X_oookl0o`3oX_l0S?oooo]Zo`3o8@?ooo]Z00Coo`3bo`3oE_oonf[oo`2P0_oonfX01OmD0?oo
02GooookJ_lZ0?ooo`X000Cooo]Z00?oNol0oookJ_oo@@000ooonfX00ol0ocSo203ooookJP06oook
JP05oolP0?oonf[ooo]ZoookJ_oo0;D03OoonfX00ol0okGooo]ZoookJP02oookJP03o`3oRooonf[o
oo]Z00oooo]Z00Coo`1?oookJ_oonf[o0?nF1_oonfX01?oo703ooo]ZoookJ_nho`0<oookJP07om;o
0?oonf[ooo]ZoookJ_oMo`3ooo]Zob/0o`05oookJP03ool00?oo0:Wok?l000Gooo]Z00?oT`3ooook
J_oonfX08?oonfX002Kooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol008oookJP03oooX0?oo00_ooo]Z
00Cooo]Z00GoolT0o`21oooonf[ooo]Zo`3oU`02oookJP03o`3oj?lfo`3ooo]Z00cooo]Z00CoiOl0
oookJ_oonf[oo`3/2ooonfX00ol0ongooo]ZoookJP0:oookJP03oomi0?l0oo;ooo]Z00?ooo]Z00?o
o`2doonW0?oonfX01_oonfX02?l0o`Wooo]ZoookJ_oonf[oO03oocCo0?oUo`3o00_o1?oUo`03oiCo
0005oookJ_m>0?oooo]ZoookJ_oo01@00_oonfX3onGo00;ooo]Z00?oojP0oookJ_oo0:L00_oonfX0
0ooo8@3ooo]ZoookJP02oookJP07o`3oUooonf[ooo]ZoookJ_n>o`3oo`0ioookJP03oiCo00kooo]Z
00Goo`0hoookJ_mi0?oo^?l0ool0_002oookJP03of`0oooonf[ooo]Z00KoU?l02?m4o`02oookJPKo
A?l000Cooo]Zo`3oRooonf[o0?ne0_oonfX00ooo0;Go0?l<o`3o3002o`3o3003og_o0?l0o`co0?l<
00?o0?l<00?o0?mMogT0ool0ojd00ol0ojd7o`3oG@Go0?n]00Go0?ono`0?ool03ooo00ooo`3o3002
o`1Oo`?o0;3o0_oo0006o`2`o`;o0?on00?oo`07o`3oGOl0oed00_l0oed01_ooZ03oolL0ool05?l0
noooA?l0o`0;o`;oA?l000?oojL0odCo0?m4o`001Om4o`000ooo0>co0>?ooookJP0;odCo0003ool0
Z_l0odgoA?l000?oU?l000CoK03ooiCo0?oonf[oH_l01_oonfX00ooRo`3ooo]Zoe[o0002oookJP04
o`03oooonf[ooo]Zo`3oB0;ooo]Z00?o0?mgoookJ_mi0?l01OoonfX01Ol0X_oookl0o`3oX_l0S?oo
0?lQ00?ooo]Z00Soo`3bo`3oE_oonf[ooo]Zool0X?oonf[oE03oo`0Uo`;ooo]Z00?o:P3oool:0?oo
nfX00_oonfX00omko`3ooo]ZoiCo0007oiCo00Kooo]Z00Coob00oookJ_oonf[oo`2e3OoonfX00ol0
okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z00kooo]Z00Coo`1?oookJ_oonf[o0?nF1_oonfX0
1Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00God_l0oookJ_oonf[ogOl0oookJP02onGo00;ooo]Z
0ooUo`000ooo003oiOl0onGo0003onGo00;ooo]Z00?oiOl0oookJ_oonfX0@_oonfX01OlY0?oooo]Z
oookJ_oonf[o0?o`00Sooo]Z00?oonP0oookJ_oo00/01?oonfX00ooo=@3o=ol0o`21o`02oookJP05
o`3oUooonf[o0?oXoookJ_lfo`003?oonfX01?l0hooooo]ZoookJ_oo0>`;oookJP03o`3okOoonf[o
oo]Z00[ooo]Z00?o7@3oo`3ol_oonfX00ooonfX00ooo0;CoojL0oookJP07oookJP08o`3o2Ooonf[o
oo]Zog`0oooonf[o=?l0oookJ_l02ol3oookJP05ok3o0?l0nooooo]ZoookJ_m>0?l00_oonfX01Ooo
01Cooo]ZoookJ_oonf[oolL000Cooo]Z00GoojP0ool0Yooonf[ooo]ZoolQ0004oookJP03o`3oUooo
nf[ooo]Z00;ooo]Z00GoS_l0oookJ_l0ol3ooo]Zool01`0?oookJP05ool0>?mi0?oo^?l0oookJ_oo
0;`00_oonfX00om/0?oooo]ZoookJP02oookJP0;ond0oonMo`3ooo]Zool0g?mG0?oooo]Zoi<0ooo/
o`3oo`00omgo0?oBo`000_oonfX01Onho`3ooa`0oookJ_l0oiKoo`1?00?ooo]Z02;o0?n;o`3o]Ooo
nf[ooo]Zool0]Ooo803ooo]Zo`3o>?oo@@3oNol0obX0oooo0:3o0?mFool0l_l0ob7ooo]ZogT0ool0
odSo0?nnoe[o0?oonf[oK03ooooS0?l0odgo0?o`o`3oj?oo0>co0?o]oonW0?l02oooo`0DoonX0?oo
00OoN@3o0_o]0?l00ooo003oo`1?ool0C`03ool0C`;ogOl000Coo`00ond0ooo]0?oooo]Z0_oo0;`0
5_oo03Sooo]ZoookJ_oonf[oo`07ohko0?l0oiOoob40oonX0?ooa`3oo`0Dodh0ool0nooo00_oocCo
0?l0o`WoojL0ool0]?lM0?oooaX0oookJ_l0ond2oookJP03ool0k?l0hooooo]Z00;ooo]Z00Oo0?oX
o`21oooo=@3oonP0oookJ_l0oo3o:@3o00;ooo]Z00?oF@3oo`3oCOoonfX00_oonfX01Oooh`3ooo]Z
of`0oooonf[oH_l000Kooo]Z00Woh_l0oookJ_mJo`3o0?nnoookJ_oo0?Ko00?ooookJ_l0odP00_oo
nfX01?l0ogOooo]ZogT0oooo9`04oookJP06o`2Roooo_`3o0?nRo`2<oooonf[o0?lQ0ooonfX01?oo
0?;ooo]ZoookJ_oo0:02oookJP05oe@0oooonf[ooo]ZobX0oooo2P001?oonfX00omko`3ooo]Zoom1
0002oookJP03o`3o>?l80?oooo]Z00Oooo]Z00Goob00oookJ_oonf[ooo]Zool0]@0=oookJP03o`3o
]Ooonf[ooo]Z00;ooo]Z00?o0?n;oookJ_oonfX03ooonfX01?oo04oooo]ZoookJ_l0oiH5oookJP05
oolL0?oonf[ooo]ZoookJ_nho`003?oonfX01ooBo`3ooo]ZoookJ_oonf[ogOl0oookJ_l[0?l01Ooo
nfX00ooo003oo`2Yonco0005oookJP03oi<0oooonf[ooo]Z023ooo]Z000VoookJP05obT0oooonf[o
oo]ZoookJ_l0oo002?oonfX00oooj03oo`0;oookJP04oookJP05ooo90?l0POoooo]ZoookJ_l0oiL0
0_oonfX00ol0onSo=_l0oookJP0<oookJP04onGo0?oonf[ooo]Zool0k0_ooo]Z00?o0?o]oookJ_oo
nfX02_oonfX00olM0?oo0?oboookJP03oookJP03ool0]?ooY`3ooo]Z00Kooo]Z00So0?l9oookJ_oo
nf[oiOl0og`0ooldo`3oiOl0o`0;o`CoiOl00onDo`001_oonf[oCP3ooookJ_oonf[oo`0DoookJPCo
iOl00_oonfX00oooZ03ooo]Zool0Y`02oookJP03oolQ0?oonf[ooo]Z00;ooo]Z00Ko0?nGoookJ_oo
nf[ooo]Zohko0?oo03T4oiCo00kooo]Z00Goo`0hogT0oooonf[o^?l0ool0_002oookJP03of`0oooo
nf[ooo]Z00GoU?l02Om4o`000ooonf[oA?l0odCo0005odCo0004oookJ_l0oh_ooo]Zo`3o]@;ooo]Z
00?oo`2eo`3o3?l0o``02Ol0o``01?mi0?oo0?mMo`3o[Ol0ojd6o`3oG@04o`3oj?l0oego0?n]o`1O
o`?o0?n]00Coo`07o`0?ool03ooo00oo2Ol0ojd4o`2`o`;o0?on00?o0?n]ool01ol0oed00ol0oed0
1OooZ03o0?mMool05?l0oego00_o00;oA?l000?o0?l<oonW0?m4o`001_m4o`000ooo0>co0>?oodCo
000:odCo0004ool0Z_m4o`3o0?m=odCo00?oU?l000CoK03ooiCo0?nDo`3oU?l01_oonfX00ooRo`3o
oo]Zoe[o0002oookJP03o`03oooonf[o0?m800?ooo]Z00?o0?mgogT0oonGo`001OoonfX01Ooo_`3o
oo]Zo`3oX_oonf[o0?lQ00;ooo]Z00?oo`3boookJ_l0oeH00_oonfX00ooo0:3ooo]Zoe@0o`02oook
JP03o`1<oolZ0?ooo`X000?ooo]Z00?oNol0oookJ_nDo`001onDo`05oookJP05oolP0?oonf[ooo]Z
oookJ_oo0;D03OoonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z00kooo]Z00Coo`1?
oookJ_oonf[o0?nF1_oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00Kod_l0oookJ_oonf[o
gOl0oookJ_oUo`03oookJP?oiOl000?oo`00onGo0?oUo`000_oUo`02oookJP03onGo0?oonf[ooo]Z
04?ooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol008oookJP03oooX0?oonf[oo`0;00Cooo]Z00?oocD0
ocOo0?l0POl00_oonfX01Ol0oiOooo]Zo`3oj?oonf[o=_l000cooo]Z00Co0>?ooookJ_oonf[oo`3/
2ooonfX00ol0ongooo]ZoookJP0:oookJP03oad0ool0oo;ooo]Z00?ooo]Z00?oo`2doonW0?oonfX0
1ooonfX02?l0o`Wooo]ZoookJ_ml0?oooo]ZocCo0?oonf[o00_o0ooonfX01On`o`3o0?_ooookJ_oo
nf[oCP3o00;ooo]Z00Goo`0DoookJ_oonf[ooo]Zooo70004oookJP05oonX0?oo0:Oooo]ZoookJ_oo
8@001?oonfX00ol0oiOooo]ZoookJP02oookJP05ohko0?oonf[o0?o0oookJ_oo00L03ooonfX01Ooo
03SoN@3ookSo0?oonf[oo`2l00;ooo]Z00?oK03ooookJ_oonfX00_oonfX02oo]0?ooWOl0oookJ_oo
0=coE`3ooookJ_nC0?ook?l0ool00?oMo`3od_l000;ooo]Z00Go^?l0oolL0?oonf[o0?nFool0C`03
oookJP0So`3oRol0okGooo]ZoookJ_oo0;Goob00oookJ_l0ocSo203oog_o0?lZ0?ooo`2PoookJ_oo
0?;o0?lQoookJ_mi0?oo0?m8o`3o__mJo`3ooo]Zof;o0?m/0?oo0?m=o`3ol?l0oiOo0?oXool0k?oo
6P3oojL0o`0;oooo01CoojP0ool01ol000000_oo0;`7ool00006ond0oooo]`3ooo]Zool0_?mi0?oo
o`0h1?oonfX04_oo00OoS_l0o`3oUooo8@3oojP0ooo70?oo01CoCP3oo`0;ooldo`3ooo]Zo`3o2Ooo
Y`3oo`2doad0oooo6P3ooo]Zo`3ok@;ooo]Z00_oo`3/o`3Soooonf[ooo]Zo`3oj?l0oiOoocD0ool0
2oooj03o0?o`obT0o`03oookJP03ool0Z_l0odgooo]Z00;ooo]Z00Coon<0oookJ_m/0?ooH_l01ooo
nfX02OoRo`3ooo]Zoe[o0?l0okkooo]Zool0m_l00ooooo]Zo`3oB002oookJP03o`3oMooonf[oN@3o
00Gooo]Z00?ookl0oookJ_l0oj800_oonfX01Ol0ob7ooo]ZoookJ_oo0?;o0?mF00;ooo]Z00Coo`2P
oookJ_oonf[oE03o0_oonfX00olZ0?ooo`X0oookJP03oookJP03og_o0?oonf[ood4000;ooo]Z00?o
0?lho`P0oooonfX01_oonfX01Ooo803ooo]ZoookJ_oonf[oo`2e00kooo]Z00?o0?neoookJ_oonfX0
0_oonfX00ol0oh_ooo]ZoookJP0?oookJP04ool0Cooonf[ooo]Zo`3oUPGooo]Z00Gooa`0oookJ_oo
nf[ooo]ZokSo000<oookJP07om;o0?oonf[ooo]ZoookJ_oMo`3ooo]Zob/0o`05oookJP03ool00?oo
0:Wok?l000Cooo]Z00?oT`3ooookJ_oonfX08OoonfX002Kooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3o
l008oookJP03oooX0?oo00_ooo]Z00?ooo]Z00?oolT0oookJ_l0POl00_oonfX01Ol0oiOooo]Zo`3o
j?oonf[o=_l000gooo]Z00CoiOl0oookJ_oonf[oo`3/2ooonfX00ol0ongooo]ZoookJP0:oookJP03
oad0oooonf[ooo]Z00?ooo]Z00?oo`2doonW0?oonfX01_oonfX02Ol0o`Wooo]ZoookJ_oonf[oO03o
ocCo0?oonf[o00_oonGo0003oookJP?oU?l000Kooo]ZoiCo0?oonf[ooo]Zool05?oonfX5onGo0004
oookJ_ooZ03ooo]Zool0Y`;ooo]Z00?oob40oookJ_oonfX00_oonfX01_l0oiOooo]ZoookJ_n>o`3o
oo]Zool0>@GoU?l03OoonfX01Ooo03SoN@3ooookJ_nho`3oo`2l00;ooo]Z00?oK03ooookJ_nDo`00
2?nDo`06odCo0003oookJ_m4o`3oA?l000KoA?l000Go0?n;oookJ_l0okGooo]ZodCo000=o`3o30;o
0?mM00?o0?n]o`3oGOl0oed01?l0oed01?l0onSo0?mMo`3o[Ol0Gol3o`3o[@Go00oo3_l0ojd00ooo
00Oo0?mMo`3oG@04o`3oG@05ool05?l0oegoA?l0o`0;oom4o`000_l0o``00oooY`3o7@3oodCo0004
odCo0003ool0k?l0hooooo]Z00coA?l000?o0?m=odCo0?nDo`000onDo`000om/0?ooU?l0oiCo0002
oiCo00Gooo]Z00?oh_l0oe[o0?l0okh00_oonfX00ol00ooooo]Zo`3oB002oookJP04o`3oMooonf[o
N@3ooiOo00Gooo]Z00Gookl0oookJ_l0oj;ooo]Zo`3o8@02oookJP03ool0l_l0oeKooo]Z00;ooo]Z
00?oo`2PoookJ_mD0?l00_oonfX00ol0C?ooU?l0oookJP02oookJP03og_o0?oonf[ooi`000OoU?l0
1_oonfX01Ooo803ooo]ZoookJ_oonf[oo`2e00gooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_o
oo]ZoookJP0>oookJP04onGo0?oonf[ooo]Zo`3oUPKooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000;
oookJP07om;o0?oonf[ooo]ZoookJ_oMo`3ooo]ZonGo0003oookJP?oiOl000?oo`00onGo0?oUo`00
0_oUo`02oookJP03onGo0?oonf[ooo]Z04?ooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol008oookJP03
oooX0?oonf[oo`0;00Cooo]Z00?oocD0ocOo0?l0POl00_oonfX01Ol0oiOo0?oXoookJ_oonf[o=_l0
00cooo]Z00Co0>?ooookJ_oonf[oo`3/2ooonfX00ol0ongooo]ZoookJP0:oookJP03oad0oooonf[o
oo]Z00?ooo]Z00?oo`2doonW0?oonfX01ooonfX02?l0o`Wooo]ZoookJ_ml0?oooo]ZocCo0?oonf[o
00_o0ooonfX01On`o`3o0?_ooookJ_oonf[oCP3o00;ooo]Z00Goo`0DoookJ_oonf[ooo]Zooo70004
oookJP05oonX0?oo0:Oooo]ZoookJ_oo8@001?oonfX02_l0oiOooo]ZoookJ_oonf[oS_l0ool0>Ooo
nf[o0?o0oookJ_oo00L?oookJP05ool0>?mi0?oo^?l0oookJ_oo0;`00_oonfX00om/0?oooo]Zoook
JP02oookJP0;ond0oonMo`3ooo]Zool0g?mG0?oooo]Zoi<0ooo/o`3oo`00omgo0?oBo`000_oonfX0
1Onho`3ooa`0oookJ_l0oiKoo`1?00?ooo]Z02Ko0?n;o`3o]Ooonf[ooo]Zool0]Ooonf[oob00o`3o
>?l80?ooNol0obX0oooo0:3ooo]Zool0l_l0ob7o0?nRogT0oooonf[o0?m8oe[o0?oonf[oH_l0of`0
oooo0:[o0?o`obT0ool0onSoo`3/o`3okOooY`3oO03oo`0;oooo01Coob40ool01ol0003oN@3oool0
_0Kok@3o00GoK03ookSo0?nho`3oo`2logT0o`04oookJP0@ool01on>o`3o0?nGool0]?oo8@3oojP0
ool05?m>0?oo0?_oo`0;ooldo`3o0?l9oookJ_ooY`3o7@3ooolJ00;ooo]Z00Co0?o]oookJ_oo0>co
0>?o0ooonfX01ol0onSo0?nGoole0?oo00_oonP0o`3ol?lY0?l00_oonfX00omI0?oo0?m=oookJP03
oookJP04oooS0?m/0?oooo]Zof;o00Oooo]Z00Woh_l0oookJ_mJo`3o0?nnoookJ_oo0?Ko00?ooook
J_l0odP00_oonfX00ol0ogOoN@3ooiOo0005oookJP05oono0?oonf[o0?nRoookJ_l0ob400ooonfX0
2?oo0?;o0?mFoookJ_oonf[oo`2PoookJ_mD0?oo02Go0_oonfX00olZ0?ooo`X0oookJP02oookJP04
og_o0?oonf[ooi`0oom100;ooo]Z00?o0?lho`P0oooonfX01_oonfX01Ooo803ooo]ZoookJ_oonf[o
o`2e00kooo]Z00?o0?neoookJ_oonfX00_oonfX00ol0oh_ooo]ZoookJP0?oookJP03ool0Cooonf[o
0?nF00Kooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000;oookJP03om;o0?oonf[ooo]Z00;ooo]Z00?o
gOl0oookJ_l[0?l01?oonfX00oooV`3oo`00onco0005oookJP03oi<0oooonf[ooo]Z027ooo]Z000V
oookJP05obT0oooonf[ooo]ZoookJ_l0oo002?oonfX00oooj03oo`0;oookJP03oookJP03ooo90?oo
nf[o087o00;ooo]Z00Go0?nGoookJ_l0onSooo]ZocKo000<oookJP05onGo0?oonf[ooo]ZoookJ_oo
0>`02ooonfX00ol0ongooo]ZoookJP09oookJP03oolJ0?lM0?oooo]Z00Cooo]Z00?oo`2doonW0?oo
nfX01_oonfX02?l0o`Wooo]ZoookJ_oonf[oO03oocCo0?oonf[o00_o0_oUo`000ooonf[oU?l0oiCo
0004oiCo00;ooo]Z00?oo`0DoookJ_oUo`001?oUo`001?oonf[oojP0oookJ_oo0:L2oookJP03oolQ
0?oonf[ooo]Z00;ooo]Z00Ko0?nGoookJ_oonf[oS_l0oookJ_oo03T5oiCo00gooo]Z00Goo`0hogT0
oooonf[o^?l0ool0_002oookJP03of`0oooonf[oU?l000[oU?l000Goo`00odCo0?m4o`3oA?l0oook
JP08odCo0003o`3oRooonf[o0?ne00;ooo]Z3Ol0o``9o`3oG@04o`3oj?l0oego05ooo`1Oo`?o0?n]
1_l03ol<o`3o[@;oo`071_l0oed01?oo01Co0?mModCo0?l02ol2o`3o3003oonW0?l0o`co0?l<00Co
A?l000Cooo]Zool0k?l0hooooo]Z3Om4o`001Ooonf[oU?l0oiCo0?nDo`3oK03o00GoU?l01?oonfX0
0ooRo`3ooo]Zoe[o0002oookJP04ool0m_l00ooooo]Zo`3oB0;ooo]Z00?o0?mgoookJ_mi0?l01_oo
nfX01?oo_`3ooo]Zo`3oX_l0ob43oookJP03ool0l_l0oeKooo]Z00;ooo]Z00?oo`2Poe@0ool09Ol0
0_oonfX00ol0C?ooU?l0oookJP02oookJP03og_o0?oonf[ooi`000OoU?l01_oonfX01Ooo803ooo]Z
oookJ_oonf[oo`2e00gooo]Z00?o0?neoookJ_oonfX00_oonfX00ol0oh_ooo]ZoookJP0?oookJP04
onGo0?oonf[ooo]Zo`3oUPKooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000;oookJP04om;o0?oonf[o
oo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX00_oonfX00ooUo`3oo`00onGo0004onGo00;ooo]Z00?o
iOl0oookJ_oonfX0@ooonfX01OlY0?oooo]ZoookJ_oonf[o0?o`00Sooo]Z00?oonP0oookJ_oo00/0
1?oonfX00ooo=@3o=ol0o`21o`02oookJP05o`3oUol0onSooo]ZoookJ_lfo`002ooonfX01Ol0hooo
oo]ZoookJ_oonf[oo`3/00_ooo]Z00?o0?o]oookJ_oonfX02_oonfX00olM0?oooo]ZoookJP03oook
JP03ool0]?ooY`3ooo]Z00Oooo]Z00So0?l9oookJ_oonf[oO03oo`0]ooldo`3ooo]Zo`0;o`?ooo]Z
00Go/?l0o`3koooonf[ooo]Zodh0o`02oookJP05ool05?oonf[ooo]ZoookJ_ooa`001?oonfX01Ooo
Z03oo`2WoookJ_oonf[oob4000Cooo]Z00Oo0?nGoookJ_oonf[ooo]Zohko0?oo03Wo0?o000;ooo]Z
00?oo`07oookJ_oonfX03OoonfX01Ooo03SoN@3ookSo0?oonf[oo`2l00;ooo]Z00?oK03ooookJ_oo
nfX00_oonfX02oo]0?ooWOl0oookJ_oo0=coE`3ooookJ_nC0?ook?l0ool00?oMo`3od_l000;ooo]Z
00Go^?l0oolL0?oonf[o0?nFool0C`03oookJP0Qo`3oRol0okGooo]ZoookJ_oo0;Gooo]ZoolP0?oo
nf[o0?lhog_o0?lZ0?oo04coool0X?oo0?;o0?lQo`3oX_mi0?oo0?mgo`3oB?l0okkoF_l0oookJ_m/
0?ooon<0o`3oCOl0oo3o0?oXoookJ_oo0>cooaX0oonW0?ml0?ooo`0D00;oojP000?oo`07o`000?mi
0?l02Ooo0;`01?mi0?oooo]ZoookJ_oonfX2ool01`0Bohko0?l0oiOooo]ZoolQ0?ooZ03oolL0ool0
5?m>0?oo0?_oo`0;ooldo`3ooo]ZoonW0?oo0;Co7@3oo`3ol_oonf[o0?o]0_oonfX00ooo0>co0>?o
oookJP02oookJP07o`3oj?l0POooocD0oooX0?oonf[o0?o`obT0o`02oookJP03oeT0ool0odgooo]Z
00;ooo]Z00Goo`d0oooS0?m/0?oooo]Zof;o0007oookJP03on;o0?mJo`3o0?nn00;ooo]Z00Woo`3f
o`03oooonf[o0?m8oookJ_l0ogOooo]ZogT0oonGo`001OoonfX01Ooo_`3ooo]Zo`3oX_oonf[o0?lQ
00?ooo]Z00Ooo`3bo`3oE_oonf[ooo]Zool0X?oonf[oE03o00?ooo]Z00?o:P3ooookJ_oonfX00_oo
nfX00omko`3ooo]Zoom10003oookJP03o`3o>?oonf[ooo]Z00Kooo]Z00Goob00oookJ_oonf[ooo]Z
ool0]@0>oookJP03o`3o]Ooonf[ooo]Z00;ooo]Z00?o0?n;oookJ_oonfX03ooonfX00ooo04oooo]Z
o`3oUP06oookJP05oolL0?oonf[ooo]ZoookJ_nho`002ooonfX01OoBo`3ooo]ZoookJ_oonf[ogOl0
00;ooo]Z00?o:`3ooookJ_oonfX00_oonfX00oooV`3oo`00onco0005oookJP03oi<0oooonf[ooo]Z
027ooo]Z000VoookJP05obT0oooonf[ooo]ZoookJ_l0oo002?oonfX00oooj03oo`0;oookJP03oook
JP03ooo90?oonf[o087o00;ooo]Z00Go0?nGoookJ_l0onSooo]ZocKo000<oookJP05onGo0?oonf[o
oo]ZoookJ_oo0>`02ooonfX00ol0ongooo]ZoookJP09oookJP03oolJ0?lM0?oooo]Z00Cooo]Z00?o
o`2doonW0?oonfX01_oonfX02?l0o`Wooo]ZoookJ_oonf[oO03oocCo0?oonf[o00_o0_oUo`000ooo
nf[oU?l0oiCo0004oiCo00;ooo]Z00?oo`0DonGo0?oUo`001?oUo`001?oonf[oojP0oookJ_oo0:L2
oookJP03oolQ0?oonf[ooo]Z00;ooo]Z00Ko0?nGoookJ_oonf[oS_l0ool0>OoonfX5oiCo00gooo]Z
00Goo`0hogT0oooonf[o^?l0ool0_003oookJP03of`0oonDo`3oU?l000WoU?l000?oo`00odCo0?oM
o`002_m4o`001?l0oh_ooo]Zo`3o]OoonfX?o`3o30Wo0?mM0ol0Gol3o`3o[@Go00oo00Co0;3oo`0?
ool0Gooo05oo1ol0ojd2ool01`;o0?n]1Ol0oed01?oo01Co0?mMo`3o3?l02ol3o`3o3003oonW0?l0
o`co0?l<00;oA?l000Ko0?o]oookJ_oonf[oo`3/o`3SoooonfX<odCo0003o`3oCOoonf[oU?l000;o
U?l000?oK03ooiCo0?nDo`000_nDo`05oookJP03on;o0?oonf[oF_l000;ooo]Z00Co00?ooookJ_oo
nf[o0?m80_oonfX00ol0ogOoN@3ooiOo0005oookJP05o`2Roooo_`3o0?nRoookJ_l0ob400ooonfX0
0ooo0?;o0?mFoookJP02oookJP03ool0X?mD0?oo02Go00;ooo]Z00SoU?l0ool:0?oonf[ooo]ZoiCo
0?mko`3ooo]ZoonL00KoU?l01_oonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z00[o
oo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0?oookJP04onGo0?oonf[ooo]Zo`3o
UPKooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000;oookJP04om;o0?oonf[ooo]Zomgo00;ooo]Z00?o
:`3ooookJ_oonfX00_oonfX00ooUo`3oo`00onGo0003onGo00?ooo]Z00?oiOl0oookJ_oonfX0@ooo
nfX01OlY0?oooo]ZoookJ_oonf[o0?o`00Sooo]Z00?oonP0oookJ_oo00/01?oonfX00ooo=@3o087o
oookJP02oookJP05o`3oUol0onSooo]ZoookJ_lfo`002ooonfX01Ol0hooooo]ZoookJ_oonf[oo`3/
00_ooo]Z00?o0?o]oookJ_oonfX02_oonfX00olM0?oooo]ZoookJP03oookJP03ool0]?ooY`3ooo]Z
00Kooo]Z00Wo0?l9oookJ_oonf[ooo]Zog`0ool0;Ooo=?l0oookJ_l02ol00_oonfX00on`o`3ooo]Z
o`3ko`02oookJP04odh0oooonf[ooo]Zool050?ooo]Z00?oolL0oookJ_oonfX00_oonfX01OooZ03o
o`2WoookJ_oonf[oob4000Cooo]Z00Oo0?nGoookJ_oonf[ooo]Zohko0?oo03Wo0?o000;ooo]Z00?o
o`07oookJ_oonfX03OoonfX01Ooo03SoN@3ookSo0?oonf[oo`2l00;ooo]Z00?oK03ooookJ_oonfX0
0_oonfX02oo]0?ooWOl0oookJ_oo0=coE`3ooookJ_nC0?ook?l0ool00?oMo`3od_l000;ooo]Z00Go
^?l0oolL0?oonf[o0?nFool0C`03oookJP0Qo`3oRol0okGooo]ZoookJ_oo0;Gooo]ZoolP0?oonf[o
0?lhog_o0?oonf[o:P3oool0X?oo0?;o0?lQo`3oX_oonf[oN@3oo`3oB?l0okkoF_l0oookJ_m/0?oo
on<0o`3oCOl0oo3o0?nGo`3oj?l0hoooo`3/oad0ooooY`3o00_o00;oo`0D00?oojP0ool01ooo00L0
0_oonfX01Ooo03SoN@3oogT0oomi0?ooo`0h00Gooo]Z00Goo`07ohko0?oonf[o0?nGoolQ0002oonX
000;ooo70?oo01CoCP3oo`3kool02ooo=?l0o`3o2Ooonf[oojL0oookJ_lM0?l00_oonfX01Ol0ongo
oo]ZoookJ_oo0>co0>?o00;ooo]Z00Oo0?oXo`3oUooo=@3oo`0;oooX0?l0oo3o:@3o00?ooo]Z00?o
o`2Zo`3oCOoonfX00_oonfX01Oooh`3ooo]Zof`0oooonf[oH_l000Kooo]Z00Ooh_l0oookJ_mJo`3o
0?nnoookJ_oo0?Ko00?o00;ooo]Z00Go0?m8oookJ_l0ogOooo]ZogT0o`06oookJP05oono0?l0oj;o
08cooookJ_l0ob400_oonfX00ooo0?;o0?mFoookJP02oookJP03ool0X?oonf[oE03o00;ooo]Z00?o
:P3oool:0?oonfX00ooonfX00omko`3ooo]Zoom10002oookJP03o`3o>?l80?oooo]Z00Kooo]Z00?o
ob00oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP0;oookJP03o`3o]Ooonf[ooo]Z00;ooo]Z00?o
0?n;oookJ_oonfX04?oonfX00ooo04oooo]Zo`3oUP06oookJP05oolL0?oonf[ooo]ZoookJ_nho`00
2ooonfX01OoBo`3ooo]ZoookJ_oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX00_oonfX00oooV`3o
o`00onco0005oookJP03oi<0oooonf[ooo]Z027ooo]Z000VoookJP05obT0oooonf[ooo]ZoookJ_l0
oo002?oonfX00oooj03oo`0;oookJP03oookJP03ooo90?oonf[o087o00;ooo]Z00Go0?nGoookJ_l0
onSooo]ZocKo000<oookJP05onGo0?oonf[ooo]ZoookJ_oo0>`02ooonfX00ol0ongooo]ZoookJP09
oookJP03oolJ0?lM0?oooo]Z00Cooo]Z00?oojL0oookJ_oonfX01OoonfX00ol0o`Wooo]ZoookJP02
oookJP04og`0ooldo`3ooo]Zo`0;o`;oiOl000?ooo]ZoiCo0?nDo`001OnDo`000ooonf[oo`0DonGo
0005onGo0003oookJ_ooZ03oo`2W00;ooo]Z00?oo`2doolQ0?oonfX00ooonfX01Ol0oiOooo]Zoook
J_n>o`3oo`0i00OoU?l03?oonfX01Ooo03SoN@3ooookJ_nDo`3oo`2l00?ooo]Z3?nDo`002Ooo003o
A?l0odCo0?oMo`3oA?l0oookJ_nho`3ooa`0oookJP04odCo0004o`3oRooonf[o0?neoookJPoo0?l<
2?l0oed4o`1Oo`;o0?n]1ol03ol00ooo00Oo00ooo`1Oo`02o`1Oo`Co0?n]2Ol0oed01Ooo01Co0?mM
o`3oGOl0oego=?l000Oo0?l<00Go0?o]oookJ_oonf[oo`3/o`3So`02oookJP?oA?l000?oocD0odCo
0?m4o`001_m4o`000ol0odgooo]ZoiCo0002oiCo0004of`0oonDo`3oU?l0oiCo00Kooo]Z00?oh_l0
oe[o0?l0okh00_oonfX02Ol00ooooo]ZoookJ_l0odSooo]Zo`3oMooonf[oN@3ooiOo0003oookJP;o
U?l000Gookl0oookJ_l0oj;ooo]Zo`3o8@02oookJP03ool0l_oonf[o0?mF00?ooo]Z00Ooo`2PoiCo
0?nDo`3oU?l0oookJ_nDo`3oo`X000;ooo]Z00?oU?l0og_o0?nDo`001onDo`06oookJP03oolP0?oo
nf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX02_oonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooo
nf[ooo]Z00kooo]Z00CoiOl0oookJ_oonf[o0?nF1ooonfX01Ooo703ooo]ZoookJ_oonf[o^?l000_o
oo]Z00Kod_l0oookJ_oonf[ogOl0oookJ_l[0?l5oookJP03onGo0?oo003oiOl000?oiOl00_oonfX0
0ooUo`3ooo]ZoookJP14oookJP05obT0oooonf[ooo]ZoookJ_l0oo002?oonfX00oooj03oo`0;oook
JP04oookJP03oole0?l0POoooo]Z00;ooo]Z00Go0?nGo`3oj?oonf[ooo]ZocKo000;oookJP05o`3S
oooonf[ooo]ZoookJ_oo0>`02ooonfX00ol0ongooo]ZoookJP0:oookJP03oad0oooonf[ooo]Z00?o
oo]Z00?oojL0oookJ_oonfX01_oonfX02Ol0o`Wooo]ZoookJ_oonf[oO03oo`0]ooldo`3ooo]Zo`0;
o`02oookJP03ok3o0?oonf[o0?_o00;ooo]Z00CoCP3ooookJ_oonf[oo`0D0ooonfX00oooa`3ooo]Z
oookJP02oookJP05oonX0?oo0:Oooo]Zool0]?oo8@001?oonfX02Ol0oiOooo]ZoookJ_oonf[oS_l0
ool0>Ol0ol3ooo]Zool01`0@oookJP05ool0>?mi0?oo^?l0oookJ_oo0;`00_oonfX00om/0?oooo]Z
oookJP02oookJP0;ond0oonMo`3ooo]Zool0g?mG0?oooo]Zoi<0ooo/o`3oo`00ob/0oooMo`000_oo
nfX01Onho`3ooa`0oookJ_l0oiKoo`1?00?ooo]Z01Go0?n;o`3o]Ooonf[ooo]Zool0]Ooonf[oob00
oookJ_l0ocSood40og_o0?lZ0?ooo`2Pool0l_l0ob7o0?nRoookJ_mi0?oooo]Zo`3oB?mJo`000_oo
nfX02_m/0?oo0?m=o`3ol?lY0?oo0?oXoookJ_oo0>co0?o]oad0ooooY`02o`0;o`03ool05?ooZ03o
ob4000;oo`072OoonfX03_oo00OoS_l0o`3oUol0oiOoob40oonX0?oonf[oolL0ool05?m>0?oo0?_o
ool06?l02ooo0?l90_oonfX01OooY`3o7@3ooookJ_oonf[o0?o]00;ooo]Z00?oo`3/o`3SoooonfX0
0_oonfX01ol0onSo087ooole0?oo00_oonP0o`3ol?lY0?l00_oonfX00omI0?ooo`2Zo`3oC@02oook
JP05ool=0?ooh`3oK03ooookJ_mRo`001ooonfX02OoRo`3ooo]Zoe[o0?l0okkooo]Zool0m_l00ooo
oo]Zo`3oB002oookJP03o`3oMooonf[oN@3o00Gooo]Z00Gookl0oookJ_l0oj;ooo]Zo`3o8@03oook
JP03ool0l_l0oeKooo]Z00;ooo]Z00?oo`2Poe@0ool09Ol00_oonfX00olZ0?ooo`X0oookJP02oook
JP04og_o0?oonf[ooo]Zoom100;ooo]Z00?o0?lho`P0oooonfX01_oonfX00ooo803ooo]ZoookJP02
oookJP03ool0]Ooonf[ooo]Z00_ooo]Z00?o0?neoookJ_oonfX00_oonfX00ol0oh_ooo]ZoookJP0?
oookJP04ool0Cooonf[ooo]Zo`3oUPKooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000;oookJP07om;o
0?oonf[ooo]ZoookJ_oMo`3ooo]Zob/0o`05oookJP03ool00?oo0:Wok?l000Cooo]Z00?oT`3ooook
J_oonfX08_oonfX002Kooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol008oookJP03oooX0?oo00_ooo]Z
00?ooo]Z00?oolT0oookJ_l0POl00_oonfX01?l0oiOooo]Zo`3oj?lfo`0=oookJP05o`3Soooonf[o
oo]ZoookJ_oo0>`02ooonfX00ol0ongooo]ZoookJP09oookJP03oolJ0?lM0?oooo]Z00Cooo]Z00?o
ojL0oookJ_oonfX01OoonfX00ol0o`Wooo]ZoookJP02oookJP04og`0ooldo`3ooo]Zo`0;o`;oiOl0
2?nDo`000ooonf[oo`0DonGo0005onGo0003oookJ_ooZ03oo`2W00;ooo]Z00?oo`2doolQ0?oonfX0
0ooonfX01Ol0oiOooo]ZoookJ_n>o`3oo`0i00OoU?l03?oonfX01Ooo03SoN@3ooookJ_nDo`3oo`2l
00?ooo]Z00?oK03ooookJ_oonfX00_oonfX4oiCo0004oong0?m4o`3oT`3oool000;oA?l000SogOl0
odCo0?oonf[o^?l0oolL0?oonf[o0?nFool0C`;ooo]Z00Co0?n;oookJ_l0okGooo]Z3_l0o``8o`3o
G@Go05oo0_l0ojd7o`0?o`03o`2`ool0oego0?mM01?o0?mM0_l0o``00oooY`3o0?l<o`3o3004o`3o
30;ooo]Z00?oo`3/oookJ_oonfX00om4o`000ooo=@3oonP0odCo0005odCo0004ool0Z_l0odgooo]Z
oookJP;oU?l000CoK03ooiCo0?nDo`3oU?l01_oonfX00ooRo`3ooo]Zoe[o0002oookJP04ool0m_l0
0ooooo]Zo`3oB0;ooo]Z00?o0?mgoookJ_mi0?l01?oonfX5oiCo0006oookJ_l0ob7ooo]ZoookJ_oo
0?;o0?mF0ooonfX00ooo0:3ooo]ZoiCo0005oiCo00;ooo]Z00?oNol0oiCo0?nDo`001onDo`06oook
JP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX02_oonfX00ol0okGooo]ZoookJP03oook
JP03o`3oRooonf[ooo]Z00kooo]Z00CoiOl0oookJ_oonf[o0?nF1ooonfX01?oo703ooo]ZoookJ_nh
o`0<oookJP06om;o0?oonf[ooo]Zomgo0?oonf[o:`3o1OoonfX00ooUo`3oo`00onGo0002onGo00?o
oo]Z00?oiOl0oookJ_oonfX0A?oonfX01OlY0?oooo]ZoookJ_oonf[o0?o`00Sooo]Z00?oonP0ool0
2ooonfX01?oonfX00ooo=@3o087ooookJP02oookJP04o`3oUol0onSooo]ZocKo00cooo]Z00Go0>?o
oookJ_oonf[ooo]Zool0k00;oookJP03o`3okOoonf[ooo]Z00[ooo]Z00?o7@3ooookJ_oonfX00ooo
nfX00oooY`3ooo]ZoookJP06oookJP09o`3o2Ooonf[ooo]ZoookJ_ml0?oo=?l0oookJ_l02oooo`0H
00;ooo]Z00?o/?l0oookJ_l0nol00_oonfX01?m>0?oooo]ZoookJ_oo01@3oookJP03ooo70?oonf[o
oo]Z00;ooo]Z00GoojP0ool0Yooonf[oo`2doolQ0004oookJP09o`3oUooonf[ooo]ZoookJ_n>o`3o
o`0io`3o`?oonf[oo`07013ooo]Z00Goo`0hogT0oonho`3ooo]Zool0_002oookJP03of`0oooonf[o
oo]Z00;ooo]Z00_ok@3ooigo0?oonf[oo`3LoeL0oooonf[oT`3oonco0?oo003o:`3oomgo0002oook
JP05okSo0?oo703ooo]Zo`3oU_oo04l00ooonfX00ol0oh_o0?neoookJP02oookJP0Pool0]Ooo803o
oo]Zo`3o>?oo@@3oNol0obX0oooo0:3o0?mFool0l_l0ob7o0?nRogT0oooonf[o0?m8oe[o0?oRo`3o
oo]Zof`0ooooh`3o0?m=o`3ol?oo=@3o0?oXo`3Soooo0>cooo]Zoad0ooooY`3oO03oo`0;oooo01@2
oonX0003oolQ0?oo00Ooo`0700Ooo`0700go0?nGool0]?oo8@3oob40oonX0?oonf[oolL0ool05?m>
0?oo0?_oool06?l02ooo0?l900;ooo]Z00?oojL0oookJ_lM0?l00_oonfX01Ol0ongooo]ZoookJ_oo
0>co0>?o00;ooo]Z00So0?oXo`3oUooo=@3ooo]ZoooX0?oonf[o0?o`obT0o`;ooo]Z00?oF@3oo`3o
COoonfX00_oonfX01Ooo3@3oon<0of`0oooonf[oH_l000Oooo]Z00?oh_l0oookJ_mJo`000_oonfX0
1_oo0?Ko00?ooookJ_l0odSooo]Zo`3oM`;ooo]Z00?oN@3ooookJ_oonfX00ooonfX01Ooo_`3ooo]Z
o`3oX_oonf[o0?lQ00?ooo]Z00Soo`3bo`3oE_oonf[ooo]Zool0X?oonf[oE03oo`0Uo`;ooo]Z00?o
:P3oool:0?oonfX00_oonfX00omko`3ooo]Zoom10003oookJP03o`3o>?l80?oooo]Z00Kooo]Z00?o
ob00oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP0;oookJP03o`3o]Ooonf[ooo]Z00;ooo]Z00?o
0?n;oookJ_oonfX03ooonfX01?oo04oooo]ZoookJ_l0oiH6oookJP04oolL0?oonf[ooo]ZokSo00co
oo]Z00Cod_l0oookJ_oonf[ogOl00_oonfX00ol[0?oooo]ZoookJP03oookJP03ool00?oonf[ok?l0
00Cooo]Z00?oT`3ooookJ_oonfX08_oonfX002Kooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol007oook
JP03oooX0?oonf[oo`0;00Cooo]Z00?oolT0oookJ_l0POl00_oonfX01?l0oiOooo]Zo`3oj?lfo`0=
oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`02ooonfX00ol0ongooo]ZoookJP09oookJP03oolJ0?lM
0?oooo]Z00?ooo]Z00?oo`2doonW0?oonfX01_oonfX00ol0o`Wooo]ZoookJP02oookJP04og`0oold
o`3oiOl0o`0;o`;oiOl02?nDo`000ooonf[oo`0DonGo0006onGo0006oonX0?oo0:Oooo]ZoookJ_oo
0;Coob401?oonfX01Ol0oiOooo]ZoookJ_n>o`3oo`0i00OoU?l03?oonfX00ooo03SoN@3ooookJP02
oiCo0004ool0_?oonf[ooo]Zof`0o`Cooo]Z00Sok@3ooigo0?oonf[oo`3LoeL0oom4o`3oT`3oool0
00;oA?l000SogOl0odCo0?oonf[o^?l0oolL0?oonf[o0?nFool0C`?ooo]Z00?o0?n;o`3o]Ol0o``0
4Ol0o``4o`3oG@Ko05oo0_l0ojd7o`0?o`03o`2`ool03ooo00oo01?o0?mM1_l0o``00ooonf[o0?o]
oookJP02oookJP03ool0k?oonf[ooo]Z00;oA?l000?oocD0odCo0?m4o`001Om4o`001?oo0:[oA?l0
o`3oCOoonfX3oiCo0004of`0oonDo`3oU?l0of;o00Kooo]Z00?oh_l0oookJ_mJo`000_oonfX01?l0
0ooooo]ZoookJ_l0odP2oookJP03o`3oMooonf[oN@3o00Cooo]Z1_nDo`001Ol0ob7ooo]ZoookJ_oo
0?;o0?mF00?ooo]Z00?oo`2PoookJ_nDo`001onDo`000omko`3oU?l0oiCo0006oiCo00Oooo]Z00Go
ob00oookJ_oonf[ooo]Zool0]@0<oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX0
3_oonfX01?oUo`3ooo]ZoookJ_l0oiH7oookJP04oolL0?oonf[ooo]ZokSo00cooo]Z00?od_l0oook
J_oMo`000_oonfX00ol[0?oooo]ZoookJP03oookJP03onGo0?oo003oiOl000;oiOl00ooonfX00ooU
o`3ooo]ZoookJP14oookJP05obT0oooonf[ooo]ZoookJ_l0oo001ooonfX00oooj03ooo]Zool02`04
oookJP03oole0?oonf[o087o00?ooo]Z00Co0?nGo`3oj?oonf[o=_l03?oonfX01Ol0hooooo]Zoook
J_oonf[oo`3/00_ooo]Z00?o0?o]oookJ_oonfX02_oonfX00olM0?oooo]ZoookJP02oookJP03ool0
]?ooY`3ooo]Z00Oooo]Z00Wo0?l9oookJ_oonf[ooo]Zog`0ooldo`3ooo]Zo`0;oooo01P00_oonfX0
0on`o`3ooo]Zo`3ko`02oookJP04odh0oooonf[ooo]Zool050?ooo]Z00?oolL0oookJ_oonfX00_oo
nfX01OooZ03oo`2WoookJ_oo0;Coob4000Cooo]Z00Wo0?nGoookJ_oonf[ooo]Zohko0?oo03Wo0?o0
oookJ_oo00L04?oonfX01Ooo03SoN@3ookSo0?oonf[oo`2l00;ooo]Z00?oK03ooookJ_oonfX00_oo
nfX02oo]0?oooo]Zoigo0?oo0=cookL0oeL0oonC0?ook?l0ool00?l[0?oogOl000;ooo]Z00Go^?l0
oolL0?oonf[o0?nFool0C`04oookJP0To`3oRooonf[ooo]ZoookJ_oo0;Gooo]ZoolP0?l0ocSo203o
og_o0?oo2P3oo`2PoookJ_oo0?;o0?lQo`3oX_nGo`3oN@3oo`3oB?l0okkoF_l0oookJ_m/0?ooon<0
o`3oCOlY0?oo0?o`oole0?l0onSo0>?oool0k?oonf[o7@3ooonW0?ml0?oo00_o0ooo01@2oonX00;o
ob400on>o`001ol0oiOoo`2doolQ0?oo8@3oo`2WoonX0?ooa`000_oo01@01On`o`3o0?_oo`0;ool0
2ooo0?l900;ooo]Z00?oojL0ool0]?lM0?l00_oonfX01Ol0ongooo]ZoookJ_oonf[oo`3/00?ooo]Z
00Oo0?oXo`3oUooo=@3oo`0;oooX0?l0oo3o:@3o00?ooo]Z00?oo`2Zo`3oCOoonfX00_oonfX01Ooo
h`3oK03ooookJ_oonf[oH_l000Oooo]Z00Koh_l0oookJ_mJo`3ooo]Zool0m_l00ol2oookJP06o`3o
B?oonf[o0?mgoookJ_mi0?ooUol01OoonfX01Ooo_`3ooo]Zo`3oX_oonf[o0?lQ00;ooo]Z00?oo`3b
oookJ_l0oeH00_oonfX00ooo0:3ooo]Zoe@0o`02oookJP03obX0ool0C?ooo`X000?ooo]Z00?oNol0
oookJ_oo@@000ooonfX00ol0ocSooo]ZoookJP06oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2e
oookJ_oonfX02_oonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z00oooo]Z00Coo`1?
oookJ_oonf[o0?nF1_oonfX01?oo703ooo]ZoookJ_nho`0<oookJP04om;o0?oonf[ooo]Zomgo00;o
oo]Z00?o:`3ooookJ_oonfX00ooonfX00ooo003ooo]Zonco0004oookJP03oi<0oooonf[ooo]Z02;o
oo]Z000VoookJP05obT0oooonf[ooo]ZoookJ_l0oo001ooonfX00oooj03ooo]Zool02`04oookJP03
ooo90?oonf[o087o00;ooo]Z00Co0?nGoookJ_l0onSo=_l03OoonfX01Ol0hooooo]ZoookJ_oonf[o
o`3/00[ooo]Z00?o0?o]oookJ_oonfX02_oonfX00ooo6P3o7@3ooookJP03oookJP03ool0]?ooY`3o
oo]Z00Kooo]Z00?o0?l9oookJ_oonfX00_oonfX00oldo`3o02goo`0;o`03onGo00SoU?l000?ooo]Z
ool05?oUo`001_oUo`001_ooZ03oo`2WoookJ_oonf[oo`2doolQ00Cooo]Z00Co0?nGoookJ_oonf[o
S_l02?nDo`0<oookJP03ool0>?mi0?oooo]Z00;oU?l000Coo`2loookJ_oonf[oK03o1?oonfX02?o]
0?ooWOl0oookJ_oo0=coE`3oodCo0?nC0?ooo`000_m4o`002?oMo`3oA?l0odCo0?nho`3ooo]ZoolL
0?l0oiKoo`1?0ooonfX00ol0oh_ooo]Zo`3o]@02oookJP03ool0]OnDo`3o0?l<00co0?l<1Ol0oed0
0ol0ooko05ooo`1Oo`02o`1Oo`;o0?n]1ol03ol01_l0/?ooo`0Dool05?l03ooo05ooo`3o[A3o0?mM
1ol0o``3oookJP04ool0k?oonf[ooo]ZocKo00;oA?l000?oocD0odCo0?m4o`001Om4o`001?oo0:[o
0?m=oookJ_oonfX3oiCo0003of`0oonDo`3oH_l000Oooo]Z00Koh_l0oe[o0?l0okkooo]Zool0m_l0
0ol2oookJP06o`3oB?oonf[o0?mgoookJ_mi0?ooUol01?oonfX5oiCo0006o`3o8OnDo`3oU?l0oook
J_oo0?;o0?mF0ooonfX00ooo0:3oE03ooiCo0007oiCo0003og_o0?nDo`3oU?l000KoU?l01_oonfX0
0ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z00[ooo]Z00?o0?neoookJ_oonfX01?oonfX0
0ol0oh_ooo]ZoookJP0=oookJP05onGo0?oonf[ooo]ZoookJ_l0oiH01ooonfX01?oo703ooo]Zoook
J_nho`0;oookJP06om;o0?oonf[ooo]Zomgo0?oonf[o:`3o1_oonfX00ooUo`3oo`00onGo0002onGo
00?ooo]Z00?oiOl0oookJ_oonfX0A?oonfX01OlY0?oooo]ZoookJ_oonf[o0?o`00Oooo]Z00?oonP0
oookJ_oo00/01?oonfX00ooo=@3ooo]Zo`21o`03oookJP04o`3oUol0onSooo]ZocKo00cooo]Z00Go
0>?ooookJ_oonf[ooo]Zool0k00:oookJP03o`3okOoonf[ooo]Z00_ooo]Z00?o7@3ooookJ_oonfX0
0_oonfX00ooo0;CoojL0oookJP07oookJP09o`3o2Ooonf[ooo]ZoookJ_ml0?oo=?l0oookJ_l02ooo
o`0H00;ooo]Z00?o/?l0oookJ_l0nol00_oonfX01?m>0?oooo]ZoookJ_oo01@3oookJP03ooo70?oo
nf[ooo]Z00;ooo]Z00GoojP0ool0Yooonf[oo`2doolQ0004oookJP09o`3oUooonf[ooo]ZoookJ_n>
o`3oo`0io`3o`?oonf[oo`07013ooo]Z00Goo`0hogT0oonho`3ooo]Zool0_002oookJP03of`0oooo
nf[ooo]Z00;ooo]Z00cok@3ooookJ_nMo`3oo`3Loong0?mG0?ooT`3oonco0?oo003o:`3oomgo0?oB
o`02oookJP04okSo0?oo703ooo]Zool0C`Cooo]Z01Go0?n;o`3o]Ooonf[ooo]Zool0]Ooonf[oob00
oookJ_l0ocSood40og_o0?lZ0?ooo`2Pool0l_l0ob7o0?nRoookJ_mi0?oooo]Zo`3oB?mJo`000_oo
nfX02?m/0?ooon<0oookJ_l0oo3oonP0oole0?l0onSoo`3/0_l0ond01_lM0?ooojL0oonW0?l02ooo
O03ook3o00?oo`0D2?ooZ003ool050;o0?_o0_l02ol01oldo`3o0?l9oookJ_oonf[oojL0ool0]?lM
0?l00ooonfX01Ol0ongooo]ZoookJ_oo0>co0>?o00;ooo]Z00So0?oXo`3oUol0POooocD0ool02ooo
j03o0?o`obT0o`;ooo]Z00?oF@3oo`3oCOoonfX00_oonfX01Ooo3@3oon<0of`0oooonf[oH_l000So
oo]Z00Soh_l0oe[o0?l0okkooo]Zool0m_l00ooooo]Zo`3oB0;ooo]Z00Co0?mgoookJ_mi0?ooUol0
1OoonfX01Ooo_`3o0?nRo`2<oooonf[o0?lQ00;ooo]Z00?oo`3bo`3oE_oonfX00_oonfX00ooo0:3o
oo]Zoe@0o`02oookJP03obX0oooo2P3ooo]Z00;ooo]Z00CoNol0oookJ_oonf[ood400_oonfX00ol0
ocSo203ooookJP06oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX02ooonfX00ol0
okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z00kooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP06
oookJP04oolL0?oonf[ooo]ZokSo00_ooo]Z00Ood_l0oookJ_oonf[ooo]Zomgo0?oonf[o:`3o00Ko
oo]Z00?oo`00oookJ_o/o`001?oonfX00onC0?oooo]ZoookJP0RoookJP009OoonfX00olY0?oooo]Z
oookJP02oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0oookJ_oo00/01?oonfX00ooob@3o087o
ocOo0002oookJP04o`3oUooonf[o0?oXocKo00gooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00:oook
JP03o`3okOoonf[ooo]Z00[ooo]Z00?ooaX0oad0oooonfX00ooonfX00ooo0;CoojL0oookJP06oook
JP03o`3o2Ooonf[ooo]Z00;ooo]Z00?o=?l0o`0]ool02ol00ooUo`09oiCo0003ool05?oUo`3oiOl0
00GoiOl000Kooo]ZoonX0?oonf[ooo]Zool0]?oo8@04oookJP04o`3oUooonf[ooo]Zohko00WoU?l0
2ooonfX00ooo03SoN@3ooookJP02oiCo0004ool0_?oonf[ooo]Zof`0o`Cooo]Z00Sok@3ooigo0?oo
nf[oo`3LoeL0oom4o`3oT`3oool000;oA?l000SogOl0odCo0?m4o`3ooo]ZokSo0?oo703o0?nFool0
C`?ooo]Z00?o0?n;oookJ_l0okD00_oonfX01?l0o`coU?l0oiCo0?nDo`0<o`3o30?o0?mM00?oK03o
o`3oGOl0oed00_l0oed00ol0Gooo0?n]o`0?o`08o`0?o`03o`2`ool0o`coo`0D00;oo`0D0_l0ojd?
o`3oG@Ko0?l<0_oonfX01ooo0>cooo]ZoookJ_oonf[o=_l0o`3oj?oo=@001_m4o`001?oonf[oA?l0
odCo0?l0odd2oookJP;oU?l000CoK03ooiCo0?nDo`3oH_l01_oonfX00ooRo`3ooo]Zoe[o0002oook
JP04ool0m_l00ooooo]Zo`3oB0;ooo]Z00Co0?mgoookJ_mi0?ooUol01?oonfX5oiCo0006o`3o8OnD
o`3oU?l0oookJ_oo0?;o0?mF0ooonfX00ooo0:3oE03ooiCo0006oiCo0003oookJ_mko`3oU?l000Ko
U?l01ooonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z00[ooo]Z00?o0?neoookJ_oo
nfX00ooonfX00ol0oh_ooo]ZoookJP0>oookJP05onGo0?oonf[ooo]ZoookJ_l0oiH01_oonfX01Ooo
703ooo]ZoookJ_oonf[o^?l000_ooo]Z00Kod_l0oookJ_oonf[ogOl0oookJ_l[0?l6oookJPCoiOl0
0ooonfX00ooUo`3ooo]ZoookJP14oookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX0
1OoonfX00oooj03ooo]Zool02`04oookJP03oole0?oonf[o087o00?ooo]Z00Co0?nGo`3oj?oonf[o
=_l03?oonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00[ooo]Z00?o0?o]oookJ_oonfX02ooonfX00olM
0?oooo]ZoookJP02oookJP03ool0]?ooY`3ooo]Z00Oooo]Z00Wo0?l9oookJ_oonf[ooo]Zog`0oold
o`3ooo]Zo`0;oooo01P00_oonfX00on`o`3ooo]Zo`3ko`02oookJP04odh0oooonf[ooo]Zool050?o
oo]Z00?oolL0oookJ_oonfX00_oonfX01OooZ03oo`2WoookJ_oo0;Coob4000Cooo]Z00Wo0?nGoook
J_oonf[ooo]Zohko0?oo03Wo0?o0oookJ_oo00L04?oonfX01Ooo03SoN@3ookSo0?oonf[oo`2l00;o
oo]Z00?oK03ooookJ_oonfX00_oonfX03?o]0?oooo]Zoigo0?oo0=cookL0oeL0oonC0?ook?l0ool0
0?l[0?oogOl0om;o00;ooo]Z00Co^?l0oolL0?oonf[oo`1?1?oonfX05_l0oh_o0?neoookJ_oonf[o
o`2eoookJ_oo803ooo]Zo`3o>?oo@@3oNol0obX0oooo0:3oo`3bo`3o8Ol0S?oo0?nRo`3oMomi0?oo
0?m8oe[o0?oRo`02oookJP0=of`0ool0odgoo`2Zo`3ol?ooj03o0?oXo`3oUooo0>co0>?oo`3okOoo
6P3oo`2doonW0003o`0;o`03o`3koon`o`3oo`0D00;oo`0D0_ooa`03ool050?o0?_o0_l02ol01?ml
0?oo=?l0oookJ_oonfX2oonW0003oolJ0?lM0?oooo]Z00;ooo]Z00Go0?o]oookJ_oonf[oo`3/o`3S
o`03oookJP08o`3oj?lgo`3oocD0ool02oooj03o0?o`oookJ_lY0?l2oookJP03oeT0ool0odgooo]Z
00;ooo]Z00Goon<0oookJ_m/0?oooo]Zof;o0007oookJP03on;o0?oonf[oF_l000;ooo]Z00Co00?o
oookJ_oonf[o0?m80_oonfX00ol0ogOooo]ZogT0o`05oookJP05oono0?oonf[o0?nRoookJ_l0ob40
0ooonfX00ooo0?;o0?mFoookJP02oookJP03ool0X?mD0?oo02Go00;ooo]Z00?o:P3oool:0?oonfX0
0_oonfX01?mko`3ooo]Zoom10?ooW002oookJP03o`3o>?l80?oooo]Z00Kooo]Z00?oob00oookJ_oo
nfX00_oonfX00ooo0;Gooo]ZoookJP0;oookJP03o`3o]Ooonf[ooo]Z00?ooo]Z00?o0?n;oookJ_oo
nfX03_oonfX01?oo04oooo]ZoookJ_l0oiH6oookJP05oolL0?oonf[ooo]ZoookJ_nho`002ooonfX0
1ooBo`3ooo]ZoookJ_oonf[ogOl0oookJ_l[0?l01_oonfX00ooo003ooo]Zonco0003oookJP03oi<0
oooonf[ooo]Z02?ooo]Z000UoookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01Ooo
nfX00oooj03ooo]Zool02`04oookJP03ooo90?l0POoo=ol000;ooo]Z00Co0?nGoookJ_l0onSo=_l0
3OoonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00[ooo]Z00?o0?o]oookJ_oonfX02_oonfX00ooo6P3o
7@3ooookJP03oookJP03ool0]?ooY`3ooo]Z00Kooo]Z00?o0?l9oookJ_oonfX00_oonfX00oldo`3o
02goo`0;o`02onGo00[oU?l000Coo`0DoookJ_oonf[oiOl01OoonfX01OooZ03ooo]ZoookJ_oo0;Co
ob4000Gooo]Z00Oo0?nGoookJ_n>o`3oo`0ioookJ_l0ol3ooo]Z00GoU?l02ooonfX00ooo03SoN@3o
oiCo0002oiCo0004ool0_?oonf[ooo]Zof`0o`Gooo]Z00[ok@3ooigo0?oo0=coE`3oodCo0?nC0?oo
A?l0ool00?m4o`3ogOl00_m4o`001_oonf[o^?l0oolL0?oonf[o0?nFool0C`;ooo]Z00?o0?n;oook
J_l0okD00_oonfX01?l0o`coU?l0oiCo0?nDo`0@o`3o3004of`0ool0oego0?mMo`3oG@;o0?n]2Ol0
3ol01_l0o`co00_oo`0;ool02ooo0?l<ool050;o0?mM00?o0?l<o`3oGOl0oed02ol0oed6o`3o3003
oookJ_oo0>cooo]Z00;ooo]Z00Co=_l0o`3oj?m4o`3oocD01Om4o`001Ooonf[oA?l0odCo0?l0odgo
A?l000;ooo]Z0_nDo`000om/0?ooU?l0of;o0007oookJP03on;o0?oonf[oF_l000;ooo]Z00Co00?o
oookJ_oonf[o0?m80_oonfX00ol0ogOooo]ZogT0o`04oookJPKoU?l000Ko0?lQoiCo0?oonf[oo`3b
oookJ_l0oeH2oookJP03ool0X?oonf[oE03o00KoU?l000?oolT0og_o0?nDo`001onDo`07oookJP03
oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX02_oonfX00ol0okGooo]ZoookJP03oookJP03
o`3oRooonf[ooo]Z00kooo]Z00GoiOl0oookJ_oonf[ooo]Zo`3oUP06oookJP05oolL0?oonf[ooo]Z
oookJ_nho`002ooonfX01_oBo`3ooo]ZoookJ_oMo`3ooo]Zob/0o`Kooo]Z1?oUo`03oookJP03onGo
0?oonf[ooo]Z04Cooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP05oookJP03oooX
0?oonf[oo`0;00Cooo]Z00?oocD0oookJ_l0POl00ooonfX01?l0oiOo0?oXoookJ_lfo`0<oookJP05
o`3Soooonf[ooo]ZoookJ_oo0>`02_oonfX00ol0ongooo]ZoookJP0:oookJP03oolJ0?lM0?oooo]Z
00?ooo]Z00?oo`2doonW0?oonfX01ooonfX02Ol0o`Wooo]ZoookJ_oonf[oO03oocCo0?oonf[o00_o
ool06002oookJP03ok3o0?oonf[o0?_o00;ooo]Z00CoCP3ooookJ_oonf[oo`0D0ooonfX00oooa`3o
oo]ZoookJP02oookJP05oonX0?oo0:Oooo]Zool0]?oo8@001OoonfX02?l0oiOooo]ZoookJ_n>o`3o
o`0io`3o`?oonf[oo`074?oonfX02?oo03SoN@3ooookJ_nho`3ooo]Zool0_?oonf[oK03o1OoonfX0
2oo]0?ooWOl0ool0g?oo]`3oE`3ooi<0oooonf[oo`00ob/0oooMo`3od_l000;ooo]Z00Go^?l0oolL
0?oonf[o0?nFool0C`03oookJP0Fo`3oRol0okGooo]ZoookJ_oo0;Gooo]ZoolP0?oonf[o0?lhoom1
0?mko`3o:P3oool0X?l0oeKoo`3bo`3o8Ol0oj;ooo]ZogT0oooonf[o0?m8oe[o00;ooo]Z00SoH_l0
of`0ool0odgoo`2Zo`3ol?oo00_o0?oXo`3oU`;oo`3/00?o0?o]oolJ0?lM0?l00_ooY`001?ml0?oo
00_oo`0;ool02ol2o`3ko`;oo`0D0ol0nol2ok3o0004o`0;ooldo`3o=?l0ocCo00;ooo]Z00CoojL0
ool0]?oo6P3o7@3o0ooonfX01Ol0ongooo]ZoookJ_oo0>co0>?o00?ooo]Z00So0?oXo`3oUooo=@3o
o`0;oooX0?oonf[o0?o`obT0o`?ooo]Z00Wo0?m=oookJ_oonf[ooo]Zool=0?ooh`3oK03ooookJ_mR
o`002?oonfX02?oRo`3ooo]Zoe[o0?oonf[oo`3fo`03oooonf[o0?m80_oonfX01?l0ogOooo]Zoook
J_mi0?l5oookJP05oono0?oonf[o0?nRoookJ_l0ob400ooonfX03?oo0?;o0?mFoookJ_oonf[oo`2P
oookJ_mD0?oo02GooookJ_lZ0?oo04coool:00?ooo]Z00CoNol0oookJ_oo@@3ooi`00_oonfX00ol0
ocSooo]ZoookJP06oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX02_oonfX00ol0
okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z00oooo]Z00Coo`1?oookJ_oonf[o0?nF1_oonfX0
1Ooo703ooo]ZoookJ_oonf[o^?l000_ooo]Z00Cod_l0oookJ_oonf[ogOl00_oonfX00ol[0?oooo]Z
oookJP03oookJP04oonK0?oo003ooo]Zonco00?ooo]Z00?oT`3ooookJ_oonfX08ooonfX002Gooo]Z
00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP05oookJP03oooX0?oonf[oo`0;00Cooo]Z
00?oolT0o`21oolgo`000_oonfX01?l0oiOooo]Zo`3oj?lfo`0=oookJP05o`3Soooonf[ooo]Zoook
J_oo0>`02_oonfX00ooUo`3ooo]ZoookJP0:oookJP03oolJ0?lM0?oooo]Z00?ooo]Z00?oo`2doonW
0?oonfX01_oonfX00ol0o`Wooo]ZoookJP02oookJP03ocCo0?l0;OooU?l000;oiOl02_nDo`001?oo
01Cooo]ZoookJ_oUo`05oookJP05oonX0?oonf[ooo]Zool0]?oo8@001OoonfX02?l0oiOooo]Zohko
0?oo03Wooo]Zo`3o`?oonf[oU?l03ooonfX00ooo03Sooo]ZogT0o`02oiCo0004ool0_?oonf[ooo]Z
of`0o`Gooo]Z00Gok@3ooigo0?oo0=coE`3ooookJP02odCo0003ool00?m4o`3ogOl000;oA?l000Ko
oo]ZokSo0?oo703ooo]Zo`3oU_oo04l2oookJP03o`3oRooonf[o0?ne00;ooo]Z0_l0o``2oiCo013o
0?l<00CoK03oo`3oGOl0oego0?mM1Ol0ojd00ol0/?oo0?n]o`3o[@03o`3o[@04oonW0?l0o`co0?l<
o`3o31;o0?mM1ol0o``3oookJP04ocKo0?l0onSoA?l0oole00GoA?l000Go:@3oodCo0?m4o`3oA?l0
o`3oC@03odCo00;oU?l000?oK03ooookJ_mRo`001ooonfX01?oRo`3oF_l0o`3o__oonfX2onGo00;o
oo]Z00Ko0?m8oookJ_l0ogOooo]ZogT0oonGo`04oookJPKoU?l000Go0?lQoookJ_oonf[oo`3bo`3o
EP03oookJP03ool0X?oonf[oE03o00KoU?l000?oolT0og_o0?nDo`001_nDo`08oookJP03oolP0?oo
nf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX02OoonfX00ol0okGooo]ZoookJP04oookJP03o`3oRooo
nf[ooo]Z00kooo]Z00CoiOl0oookJ_oonf[o0?nF1ooonfX01Ooo703ooo]ZoookJ_oonf[o^?l000_o
oo]Z00?od_l0oookJ_oMo`000_oonfX00ol[0?oooo]ZoookJP03oookJPCoiOl01?oonfX00ooUo`3o
oo]ZoookJP14oookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01OoonfX00oooj03o
oo]Zool02`04oookJP03oole0?oonf[o087o00?ooo]Z00Co0?nGo`3oj?oonf[o=_l03?oonfX01Ol0
hooooo]ZoookJ_oonf[oo`3/00[ooo]Z00?o0?o]oookJ_oonfX02_oonfX00ooo6P3o7@3ooookJP03
oookJP03ool0]?ooY`3ooo]Z00Oooo]Z00Wo0?l9oookJ_oonf[ooo]Zog`0ooldo`3ooo]Zo`0;oooo
01P00_oonfX00on`o`3ooo]Zo`3ko`02oookJP04odh0oooonf[ooo]Zool050?ooo]Z00?oolL0oook
J_oonfX00_oonfX01OooZ03oo`2WoookJ_oo0;Coob4000Gooo]Z00So0?nGoookJ_oonf[oS_l0ool0
>Ooonf[o0?o0ool01a3ooo]Z00Soo`0hogT0oooonf[o^?l0oookJ_oo0;cooo]Zof`0o`Gooo]Z00_o
k@3ooigo0?oo0=cooo]ZoeL0oonC0?oooo]Zonco0?oo003ogOl0om;o0003oookJP04oolL0?oonf[o
0?nFool0C`?ooo]Z00?o0?n;o`3o]OoonfX00_oonfX04_oo0;Gooo]ZoolP0?l0ocSood40oonL0?mk
o`3o:P3oool0X?oo0?;o0?lQo`3oX_l0X_ooN@3ooolW0?l0odSoF_l0o`3o_P;ooo]Z00CoK03oool=
0?l0odgoo`2Z0_l0oo02o`3oj007o`000?oo0>co0000o`3okOoo6P3o7@3ooonW0002ool0]003og`0
ool02ooo00_o00Oo00_o00?o=?l0o`3o2OoonfX00_oonfX01?ooY`3oo`2doad0oolM0?l2oookJP;o
0?o]00Cooo]Zool0k?oo0>co0>?o0ooonfX02Ol0onSo0?nGoole0?oonf[oonP0oookJ_l0oo3ooo]Z
obT0o`02oookJP03ool0Z_l0odgooo]Z00;ooo]Z00Goo`d0oooS0?m/0?oooo]Zof;o0008oookJP05
on;o0?mJo`3o0?nnoookJ_l00ol00_oonfX01ol0odSooo]ZoookJ_l0ogOooo]ZogT0oonGo`001?oo
nfX01_l0X_oookl0o`3oX_l0S?oooo]Zo`3o8@;ooo]Z00?oo`3bo`3oE_oonfX00_oonfX00ooo0:3o
oo]Zoe@0o`02oookJP03obX0oooo2P3ooo]Z00?ooo]Z00?oNol0oookJ_oo@@000ooonfX00ol0ocSo
oo]ZoookJP06oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX02_oonfX00ol0okGo
oo]ZoookJP03oookJP03o`3oRooonf[ooo]Z00kooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP06oook
JP05oolL0?oonf[ooo]ZoookJ_nho`002ooonfX01?oBo`3ooo]ZoookJ_oMo`02oookJP03ob/0oooo
nf[ooo]Z00?ooo]Z00?oo`00oookJ_o/o`001?oonfX00onC0?oooo]ZoookJP0SoookJP009OoonfX0
0olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0oookJ_oo00/01?oonfX0
0ooob@3o087oocOo0002oookJP04o`3oUooonf[o0?oXocKo00gooo]Z00Go0>?ooookJ_oonf[ooo]Z
ool0k00:oookJP03onGo0?oonf[ooo]Z00[ooo]Z00?ooaX0oad0oooonfX00ooonfX00ooo0;CoojL0
oookJP06oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z00?o=?l0o`0]oonDo`001?oUo`000on`o`3ooo]Z
oiCo0005oiCo0004ool05?oonf[ooo]ZonGo00Gooo]Z00GoojP0oookJ_oonf[oo`2doolQ0005oook
JP08o`3oUooonf[oS_l0ool0>Ooonf[o0?o0oookJ_nDo`0?oookJP03ooo90?oonf[oN@3o00;oU?l0
00Coo`2loookJ_oonf[oK03o1OoonfX01Oo]0?ooWOl0ool0g?mG0?oookL000;oA?l000?oo`00odCo
0?oMo`000om4o`001Onho`3ooa`0oookJ_l0oiKoo`1?00?ooo]Z00Co0?n;o`3o]Ooonf[ooo]Z0ol0
o``00onDo`3o0?l<o`3o300?o`3o3003of`0ooooh`3o0?n]00Go0?n]00Co0?oXo`3o[Ol0ojgo0?n]
0ol0oed3oonW00?o0?l<3ol0oed7o`3o30;ooo]Z00Co=_l0o`3oj?m4o`3oocD01Om4o`001OlY0?oo
A?l0odCo0?m4o`3o0?m=00CoA?l000GoU?l0of`0oooonf[ooo]Zof;o0006oookJP03on;o0?oonf[o
F_l000;ooo]Z0ooUo`001ol0odSooo]ZoookJ_l0ogOooo]ZogT0oonGo`001?oonfX5oiCo0006o`3o
8OnDo`3ooo]ZoookJ_oo0?;o0?mF0_oonfX01?oo0:3ooo]ZoookJ_mD0?l5oiCo00;oolT000?oNol0
oiCo0?nDo`001OnDo`07oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX02_oonfX0
0ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z00kooo]Z00GoiOl0oookJ_oonf[ooo]Zo`3o
UP07oookJP04oolL0?oonf[ooo]ZokSo00cooo]Z00God_l0oookJ_oMo`3ooo]Zob/0o`06oookJPCo
iOl01?oonfX00ooUo`3ooo]ZoookJP14oookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oo
nfX01OoonfX00oooj03ooo]Zool02`04oookJP03oole0?oonf[o087o00?ooo]Z00Co0?nGo`3oj?oo
nf[o=_l03?oonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00[ooo]Z00?o0?o]oookJ_oonfX02_oonfX0
0ooo6P3o7@3ooookJP03oookJP03ool0]?ooY`3ooo]Z00Oooo]Z00Wo0?l9oookJ_oonf[ooo]Zog`0
ooldo`3ooo]Zo`0;oooo01P00_oonfX00on`o`3ooo]Zo`3ko`02oookJP04odh0oooonf[ooo]Zool0
50?ooo]Z00?oolL0oookJ_oonfX00_oonfX01OooZ03oo`2WoookJ_oo0;Coob4000Gooo]Z00So0?nG
oookJ_oonf[oS_l0ool0>Ooonf[o0?o0ool01a3ooo]Z00Soo`0hoookJ_mi0?oo^?l0oookJ_oo0;co
oo]Zof`0o`Gooo]Z00_ok@3ooigo0?oo0=cooo]ZoeL0oonC0?oooo]Zonco0?oo003ogOl0om;o0003
oookJP04oolL0?oonf[o0?nFool0C`Cooo]Z01Oo0?n;oookJ_oonf[ooo]Zool0]Ooonf[oob00oook
J_l0ocSood40og_o0?lZ0?ooo`2Po`3oE_oo0?;o0?lQo`3oX_oonf[oN@3oo`3oB?l00oooF_l0on;o
0002oookJP09of`0oooo3@3o0?m=ool0Z_lY0?oo0?o`oooX0?l0onSo000000;oo`3/00?o0?o]oolJ
0?oo6P000oooY`02ool0]003o`3o2Oml0?ooO03o00Co0?l90_oonfX3oonW00;o7@3o0_oonfX2o`3o
k@;ooo]Z00?oo`3/oookJ_l0hol00ooonfX02Ol0onSo0?nGoole0?oonf[oonP0oookJ_l0oo3ooo]Z
obT0o`02oookJP03ool0Z_l0odgooo]Z00;ooo]Z00?oo`d0oooS0?m/0?l00_oonfX00omRo`3ooo]Z
oookJP05oookJP03on;o0?mJo`3o0?nn00;ooo]Z00Co00?ooookJ_oonf[o0?m80_oonfX01?l0ogOo
oo]ZogT0oonGo`04oookJP05o`2Roooo_`3o0?nRo`2<ool0ob400ooonfX00ooo0?;o0?mFoookJP02
oookJP03ool0X?oonf[oE03o00;ooo]Z00?o:P3oool:0?oonfX00_oonfX01?mko`3ooo]ZoookJ_oo
@@03oookJP03o`3o>?oonf[ooo]Z00Gooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]Zoook
JP0;oookJP03o`3o]Ooonf[ooo]Z00?ooo]Z00?o0?n;oookJ_oonfX03_oonfX01Ooo04oooo]Zoook
J_oonf[o0?nF00Kooo]Z00Cooa`0oookJ_oonf[o^?l03?oonfX01_oBo`3ooo]ZoookJ_oMo`3ooo]Z
ob/0o`Kooo]Z00?oo`00oookJ_o/o`001?oonfX00onC0?oooo]ZoookJP0SoookJP009OoonfX00olY
0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0oookJ_oo00/01?oonfX00ooo
b@3o087oocOo0002oookJP04o`3oUooonf[o0?oXocKo00gooo]Z00Go0>?ooookJ_oonf[ooo]Zool0
k00:oookJP;oiOl02_oonfX00ooo6P3ooo]Zoad0o`04oookJP03ool0]?ooY`3ooo]Z00Kooo]Z00?o
0?l9oookJ_oonfX00_oonfX01?ldo`3oiOl0oiCo0?nDo`03onGo0003ok3o0?oonf[oU?l000GoU?l0
00Coo`0DoookJ_oonf[oiOl01OoonfX01OooZ03ooo]ZoookJ_oo0;Coob4000Gooo]Z00Co0?nGoook
J_n>o`3oo`0i0_oonfX00ol0ol3oU?l0oookJP0>oookJP03ooo90?oonf[oN@3o00;oU?l000Coo`2l
oiCo0?oonf[oK03o1OoonfX01Oo]0?ooWOl0ool0g?mG0?oookL000;oA?l000Coo`00odCo0?m4o`3o
gOl00_m4o`001Onho`3ooo]ZoolL0?l0oiKoo`1?00?ooo]Z00Co0?n;oookJ_l0okGooo]Z0ol0o``0
0onDo`3o0?l<o`3o3006o`3o3003o`3o8Ol0o`co0?l<00?o0?l<1?nDo`001Om/0?ooon<0o`3o[Ol0
ojgoA?l000?o0?n]00?o0?oXo`3oGOl0oed00_l0oed4o`3o30KoojL02_l0oed01ol0o`coU?l0oiCo
0?l0oegooo]Zool0k?l0hol00_oonfX01Olfo`3o0?oXo`3oj?m4o`3oocD000GoA?l000?o:@3oodCo
0?m4o`000_m4o`000ol0odgoA?l0odCo0003odCo00;ooo]Z00?oH_l0oookJ_oonfX01OoonfX01?oR
o`3oF_l0o`3o__oonfX6onGo0004oookJ_l0ogOoN@3ooiOo00Gooo]Z1OnDo`001_l0ob7ooo]Zoook
J_oonf[oo`3bo`3oEP;ooo]Z00?oo`2PoookJ_mD0?l01_nDo`02ooo90003og_o0?nDo`3oU?l000Go
U?l01ooonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z00[ooo]Z00?o0?neoookJ_oo
nfX00ooonfX00ol0oh_ooo]ZoookJP0>oookJP05onGo0?oonf[ooo]ZoookJ_l0oiH01ooonfX01?oo
703ooo]ZoookJ_nho`0<oookJP05om;o0?oonf[ogOl0oookJ_l[0?l01_oonfX4onGo00?ooo]Z00?o
iOl0oookJ_oonfX0AOoonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?o
onP0oookJ_oo00/01?oonfX00ooo=@3ooo]Zo`21o`03oookJP04o`3oUol0onSooo]ZocKo00cooo]Z
00Go0>?ooookJ_oonf[ooo]Zool0k00:oookJP03o`3okOoonf[ooo]Z00[ooo]Z00?ooaX0oad0ool0
oo800ooonfX00ooo0;Cooo]ZoonW0007oookJP09o`3o2Ooonf[ooo]ZoookJ_ml0?oo=?l0o`0]ool0
2oooo`0H00;ooo]Z00?o/?l0oookJ_l0nol00_oonfX01?m>0?oooo]ZoookJ_oo01@3oookJP03ooo7
0?oonf[ooo]Z00;ooo]Z00GoojP0ool0Yooonf[oo`2doolQ0005oookJP08o`3oUooonf[ooo]Zohko
0?oo03Wooo]Zo`3o`?oo00L@oookJP08ool0>?oonf[oN@3ookSo0?oonf[oo`2loookJ_m/0?l5oook
JP0<ond0oonMo`3oo`3LoookJ_mG0?ooT`3ooookJ_o/o`3oo`00ob/0oooMo`3od_l00_oonfX01?nh
o`3ooa`0o`3oU_oo04l4oookJP0Go`3oRol0okGooo]ZoookJ_oo0;Gooo]ZoolP0?oonf[o0?lhoom1
0?mko`3o:P3oool0X?oonf[oo`3bo`3o8Ol0oj;o0:;oogT0ool0ogOo0?m8o`03oomJo`000_oonfX0
3?mRo`3oK03oool=0?l0odgoF@3oobT0ool0oo3o=ol0o`3oj?l0003o0>?oool0k0?o0?o]0_oo6P0;
oonW0003ool0]?lM0?oo7@3o00?ooo]Z00Go0?o]oookJ_oonf[ooo]Zool0k002o`3So`;ooo]Z0_l0
onP01?lgo`3oocD0oookJ_ooj002oookJP07o`3ol?lY0?oooo]ZoookJ_mI0?ooo`2Zo`3oC@03oook
JP05ool=0?m/0?oooo]ZoookJ_mRo`001ooonfX02OoRo`3ooo]Zoe[o0?l0okkooo]Zool0m_l00ooo
oo]Zo`3oB002oookJP04o`3oMooonf[oN@3ooiOo00Gooo]Z00Gookl0o`3oX_l0S?oooo]Zo`3o8@03
oookJP0;ool0l_l0oeKooo]ZoookJ_oo0:3ooo]Zoe@0ool09Ooooo]ZobX0oooo2P001?oonfX01?mk
o`3ooo]Zoom10?ooW002oookJP03o`3o>?l80?oooo]Z00Kooo]Z00?oob00oookJ_oonfX00_oonfX0
0ooo0;Gooo]ZoookJP0:oookJP03o`3o]Ooonf[ooo]Z00?ooo]Z00?o0?n;oookJ_oonfX03ooonfX0
1Ooo04oooo]ZoookJ_oonf[o0?nF00Kooo]Z00Cooa`0oookJ_oonf[o^?l03?oonfX00ooBo`3ooo]Z
omgo0002oookJP03ob/0oooonf[ooo]Z00?ooo]Z00Cooi/0ool00?oonf[ok?l00ooonfX00onC0?oo
oo]ZoookJP0ToookJP009OoonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Gooo]Z
00?oonP0oookJ_oo00/01?oonfX00ooob@3o087oocOo0002oookJP04o`3oUooonf[o0?oXocKo00go
oo]Z00Go0>?ooookJ_oonf[ooo]Zool0k009oookJP?oiOl02_oonfX00ooo6P3ooo]Zoad0o`04oook
JP03ool0]?ooY`3ooo]Z00Kooo]Z00?o0?l9oookJ_oonfX00_oonfX01?ldo`3oiOl0oiCo0?nDo`03
onGo0003ok3o0?oUo`3oU?l000GoU?l000Coo`0DoookJ_oonf[oiOl01OoonfX01OooZ03oo`2Woook
J_oonf[oob4000Gooo]Z00Co0?nGoookJ_n>o`3oo`0i0_oonfX00ol0ol3oo`07oookJP0>oookJP;o
olT000GoN@3ooiCo0?nDo`3oU?l0ool0_002oookJP03of`0oooonf[ooo]Z00;ooo]Z00cok@3ooigo
0?oonf[oE`3ooong0?oonf[oT`3oonco0?oo003o:`3oomgo0?oBo`02oookJP04okSo0?oo703o0?nF
ool0C`?ooo]Z00Co0?n;oookJ_l0okGooo]Z3?l0o``00ol0ob7o0?l<o`3o3004o`3o30CoU?l00ol0
o``00ol0odgo0?n]o`3oG@02o`3oG@;o0?l<0ol0oed<o`3o30Oo0?mM0onDo`02odCo00?ooo]Z00?o
=_l0o`3oj?l0oiL00_oo=@03odCo0004o`3ol?m4o`3o:@3ooookJP?oA?l000?o0?m=odCo0?m4o`00
1Om4o`000ooonf[oH_l0oookJP05oookJP05on;o0?oonf[oF_l0o`3o__oonfX01_oUo`001?l0ogOo
oo]ZogT0oonGo`05oookJPGoU?l000Go0?lQoookJ_oonf[oo`3bo`3oEP03oookJP03ool0X?oUo`3o
iOl000GoU?l00_oob@000omko`3oU?l0oiCo0003oiCo0003oookJ_nDo`3ooo]Z00Oooo]Z00Goob00
oookJ_oonf[ooo]Zool0]@0<oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX03_oo
nfX01OoUo`3ooo]ZoookJ_oonf[o0?nF00Kooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP05
om;o0?oonf[ogOl0oookJ_l[0?l01OoonfX2onGo0003oookJ_oUo`3ooo]Z00?ooo]Z00?oiOl0oook
J_oonfX0AOoonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0oook
J_oo00/01?oonfX00ooo=@3ooo]Zo`21o`03oookJP04o`3oUol0onSooo]ZocKo00cooo]Z00Go0>?o
oookJ_oonf[ooo]Zool0k00:oookJP03o`3okOoonf[ooo]Z00[ooo]Z00?ooaX0oad0ool0oo800ooo
nfX00ooo0;Cooo]ZoonW0007oookJP0>o`3o2Ooonf[ooo]ZoookJ_ml0?oo=?l0o`0]ool02ooooo]Z
ool06?oonf[o/?l0oookJ_l0nol2oookJP04odh0oooonf[ooo]Zool050?ooo]Z00?oolL0oookJ_oo
nfX00_oonfX01OooZ03oo`2WoookJ_oonf[oob4000Gooo]Z00So0?nGoookJ_oonf[oS_l0ool0>Ooo
nf[o0?o0ool01a3ooo]Z00Koo`0hoookJ_mi0?oo^?l0oookJ_oo0;`2oookJP03of`0oooonf[ooo]Z
00;ooo]Z00cok@3ooookJ_nMo`3oo`3LoeL0oooonf[oT`3oonco0?oo003o:`3oomgo0?oBo`02oook
JP04okSo0?oo703o0?nFool0C`Cooo]Z00?o0?n;o`3o]OoonfX00_oonfX04ooo0;Gooo]ZoolP0?l0
ocSo203ooom10?mko`3o:P3oool0X?l0oeKoo`3bo`3o8Ol0oj;ooo]ZogT0ool0ogOo00?ooe[o0?oR
o`000_oonfX00omRo`3oK03oool=0002o`3oC@03obT0ool0oo3o0?o`00;o0?oX00Co0>?oool0k?oo
nf[ooo]Z0ol0ond00ol0oo;ooaX0oolJ0007oad0o`03oolJ0?oonf[ooo]Z00?o0?o]0_oonfX2ool0
k006o`3Soooonf[ooo]ZoookJ_l0onSo0?nG0_oo=@02oooX0004oookJ_l0oo3o0?o`obT0o`;ooo]Z
00?oF@3oool0Z_l0odd00ooonfX00ooo3@3oon<0of`0o`02oookJP03of;o0?oonf[ooo]Z00Gooo]Z
00Koh_l0oe[o0?oonf[o0?nnoookJ_l00ol2oookJP07o`3oB?oonf[ooo]Zo`3oMomi0?ooobL0oiOo
0004oookJP06o`2Roooo_`3o0?nRo`2<oooonf[o0?lQ0_oonfX00ooo0?;o0?mFoookJP02oookJP03
ool0X?oonf[oE03o00;ooo]Z00?o:P3oool:0?oonfX00ooonfX01?mko`3ooo]Zoom10?ooW002oook
JP03o`3o>?oonf[ooo]Z00Kooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP0:oook
JP03o`3o]Ooonf[ooo]Z00?ooo]Z00?o0?n;oookJ_oonfX03_oonfX00ooo04oooo]ZoookJP02oook
JP03o`3oU_oonf[ooo]Z00?ooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oookJP03om;o0?oonf[o
gOl000;ooo]Z00?o:`3ooookJ_oonfX00ooonfX01?oo003ooo]ZoookJ_o/o`03oookJP03oi<0oooo
nf[ooo]Z02Cooo]Z000ZoookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0ool02ooonfX00ooonfX0
1?oob@3ooo]Zo`21oolgo`02oookJP03o`3oUol0onSo=_l000kooo]Z00Go0>?ooookJ_oonf[ooo]Z
ool0k009oookJP?oiOl02_oonfX00ooo6P3ooo]Zoad0o`04oookJP03ool0]?ooY`3ooo]Z00Oooo]Z
00Ko0?l9oookJ_oonf[ooo]ZocCo0?oUo`02oiCo00CoiOl000?o/?l0oiCo0?nDo`001OnDo`000ooo
01Cooo]ZonGo0005oookJP05oonX0?oo0:Oooo]ZoookJ_oo8@001OoonfX01?l0oiOooo]Zohko0?oo
03T2oookJP03o`3o`?oo00Oooo]Z00kooo]Z0_oob@001Omi0?ooU?l0oiCo0?nDo`3oo`2l00;ooo]Z
00?oK03ooookJ_oonfX00_oonfX03?o]0?ooWOl0oookJ_oo0=coE`3ooookJ_nC0?ook?l0ool00?l[
0?oogOl0om;o00;ooo]Z00Go^?l0oolL0?oonf[o0?nFool0C`03oookJP03o`3oRol0okGooo]Z00co
0?l<00?o0?lQo`3o3?l0o``01Ol0o``3odCo00Co0?l<00Co0?m=o`3oGOl0oego0?mM3_l0o``00onD
o`3o0?l<o`3o3003o`3o30Co0?mM0onDo`02odCo00;ooo]Z00Co=_l0o`3oj?l0oiOoocD01?m4o`00
1?l0oo3oA?l0obT0oooonfX3odCo0003o`3oCOm4o`3oA?l000OoA?l01_oonfX01?oRo`3ooo]Zoe[o
0?l0okh2oookJPKoiOl000?o0?mgogT0oonGo`001_oonfX4oiCo0006o`3o8Ooonf[ooo]ZoookJ_oo
0?;o0?mF0_oonfX01?oo0:3ooo]ZonGo0?oUo`04oiCo00;oolT000?ooo]Zog_o0?nDo`000onDo`02
oookJP03o`3o>?oonf[ooo]Z00Gooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP0:
oookJP03o`3o]Ooonf[ooo]Z00?ooo]Z00?o0?n;oookJ_oonfX03ooonfX01OoUo`3ooo]ZoookJ_oo
nf[o0?nF00Kooo]Z00Cooa`0oookJ_oonf[o^?l03?oonfX01OoBo`3ooo]Zomgo0?oonf[o:`3o00Ko
oo]Z0_oUo`000ooonf[ok?l0oookJP03oookJP03onGo0?oonf[ooo]Z04[ooo]Z00?o0?o`oookJ_oo
nfX01OoonfX00oooj03ooo]Zool02`04oookJP03oole0?oonf[o087o00?ooo]Z00?o0?oXoookJ_lf
o`003OoonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00[ooo]Z00?o0?o]oookJ_oonfX02_oonfX00ooo
6P3o7@3oo`3olP03oookJP03ool0]?oonf[oojL000Sooo]Z00Wo0?l9oookJ_oonf[oO03oocCo0?l0
;Ooo00_ooookJ_oo01P00_oonfX01On`o`3o0?_ooookJ_oonf[oCP3o00?ooo]Z00Coo`0DoookJ_oo
nf[oolL01?oonfX01OooZ03oo`2WoookJ_oonf[oob4000Gooo]Z00So0?nGoookJ_oonf[oS_l0ool0
>Ooonf[o0?o0ool01a3ooo]Z00Koo`0hoookJ_mi0?oo^?l0oookJ_oo0;`2oookJP03of`0oooonf[o
oo]Z00;ooo]Z00cok@3ooookJ_nMo`3oo`3LoookJ_mG0?ooT`3oonco0?oo003o:`3oomgo0?oBo`03
oookJP04oolL0?oonf[o0?nFool0C`Cooo]Z01Oo0?n;oookJ_oonf[ooo]Zool0]Ooonf[oob00oook
J_l0ocSood40og_o0?lZ0?ooE03oool0X?oo0?;o0?lQo`3oX_l0X_ooUol0ogT0ool0ogOo00?ooe[o
0003oookJP09of;o0?m/0?ooo`d0ool0Z_l0odgo:@3ooooX0?l0oo3o0?nG00;o0?oX1?oo0>`2oook
JPCo0?o]1?oonfX4o`3ok@?ooo]Z0_oo0>`00ol0hooooo]ZoookJP02oookJP0<o`3oj?l0oiOoocD0
oookJ_ooj03oo`0;oookJ_l0oo3ooo]ZobT0oooonf[oF@3o0_oo0:X00ol0odgooo]ZoookJP02oook
JP05oooS0?m/0?oooo]ZoookJ_mRo`001ooonfX01?oRo`3ooo]Zoe[o0?l0okh2oookJP04o`03oooo
nf[ooo]Zo`3oB0;ooo]Z00?o0?mgogT0oonGo`001OoonfX01Ol0X_oookl0o`3oX_l0S?oo0?lQ00?o
oo]Z00?oo`3bo`3oE_oonfX00_oonfX00ooo0:3ooo]Zoe@0o`02oookJP03obX0oooonf[ooo]Z00;o
oo]Z00CoNol0oookJ_oonf[ood400ooonfX00ol0ocSooo]ZoookJP05oookJP03oolP0?oonf[ooo]Z
00;ooo]Z00?oo`2eoookJ_oonfX02ooonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z
00kooo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP03oookJP04oolL0?oonf[ooo]Z
okSo00cooo]Z00Kod_l0oookJ_oonf[ogOl0oookJ_l[0?l6oookJP04ool00?oonf[ooo]Zonco00?o
oo]Z00?oT`3ooookJ_oonfX09?oonfX002[ooo]Z00?o0?o`oookJ_oonfX01OoonfX00oooj03oo`0;
oookJP03oookJP09ooo90?oonf[o087oocOo0?oonf[o0?nGoookJ_l0onSo=_l000kooo]Z00Go0>?o
oookJ_oonf[ooo]Zool0k009oookJPCoiOl02OoonfX00ooo6P3ooo]Zoad0o`04oookJP03ool0]?oo
nf[oojL000Oooo]Z00Go0?l9oookJ_oonf[ooo]ZocCo0004oiCo00?ooo]Z00?o/?l0oiCo0?nDo`00
1OnDo`000ooo01Cooo]ZonGo0005oookJP05oonX0?oo0:Oooo]ZoookJ_oo8@001OoonfX01?l0oiOo
oo]ZoookJ_n>o`02oookJP03o`3o`?oo00Oooo]Z00kooo]Z0_oob@002?nDo`3oN@3ooiCo0?nDo`3o
o`2loiCo0?oonf[oK03o1?oonfX03?o]0?ooWOl0oookJ_oo0=coE`3ooookJ_nC0?ook?l0ool00?oo
nf[ogOl0om;o00;ooo]Z00Go^?l0oolL0?oonf[o0?nFool0C`03oookJP03o`3oRooonf[o0?ne00go
0?l<00Go0?lQo`3o3?l0o`co0?l<ogT0o`03o`3o30?oA?l01?l0o``01?l0odgo0?mMo`3o3?l0oed<
o`3o30CoU?l00ol0o``01?l0oegoU?l0oiCo0?l0oed3oiCo00;oA?l000Go0?l<ocKo0?l0onSo0?nG
oole0004odCo0004o`3ol?lY0?oo:@3ooookJP?oA?l000Co0?m=odCo0?m4o`3ooo]Z2?m4o`05oook
JP03on;o0?oonf[oF_l000;ooo]Z1_oUo`001?l0ogOooo]ZogT0oonGo`05oookJP03o`2RoonDo`3o
U?l000;oU?l000Go0?lQoookJ_oonf[ooo]Zool0lP03oookJP04ool0X?oonf[oiOl0onGo00CoU?l0
0_oob@000ooonf[oNol0oiCo0003oiCo0003oookJ_l0ocSo203o00Oooo]Z00?oob00oookJ_oonfX0
0_oonfX00ooo0;Gooo]ZoookJP0:oookJP03o`3o]Ooonf[ooo]Z00?ooo]Z00?o0?n;oookJ_oonfX0
2_oonfX3onGo0003oookJ_oUo`3ooo]Z00;ooo]Z00?o0?nFoookJ_oonfX01OoonfX01?oo703ooo]Z
oookJ_nho`0<oookJP05om;o0?oonf[ogOl0oookJ_l[0?l01_oonfX2onGo0003onco0?oonf[ooo]Z
00?ooo]Z00?oiOl0oookJ_oonfX0B_oonfX00ol0oo3ooo]ZoookJP05oookJP03oooX0?oonf[oo`0;
00Cooo]Z00?oocD0oookJ_l0POl00_oonfX01?l0oiOo0?oXoookJ_lfo`0>oookJP04o`3Soooonf[o
oo]Zool0k0[ooo]Z00?o0?o]oookJ_oonfX02_oonfX00ooo6P3o7@3oo`3olP03oookJP03ool0]?oo
nf[oojL000Sooo]Z00Wo0?l9oookJ_oonf[ooo]ZocCo0?l0;Ooo00_ooookJ_oo01P00_oonfX00on`
o`3o0?_ooookJP02oookJP04odh0oooonf[ooo]Zool050;ooo]Z00?oolL0oookJ_oonfX00_oonfX0
1OooZ03ooo]Zool0Yooonf[oob4000Gooo]Z00So0?nGoookJ_oonf[ooo]Zohko0?oonf[o0?o0ool0
1a7ooo]Z00Goo`0hogT0oonho`3ooo]Zool0_002oookJP03of`0oooonf[ooo]Z00;ooo]Z00cok@3o
oookJ_nMo`3oo`3LoookJ_mG0?ooT`3oonco0?oo003ooo]Zomgo0?oBo`03oookJP04oolL0?oonf[o
0?nFool0C`Cooo]Z01So0?n;o`3o]Ooonf[ooo]Zool0]Ooonf[oob00oookJ_l0ocSood40og_o0?lZ
0?oo04coool0X?l0oeKoo`3bo`3o8Ol0oj;ooo]ZogT0ool0ogOooo]Zoe[o0?l0okh3oookJP0:of;o
0?m/0?ooo`d0ool0Z_l0odgo:@3ooooX0?l0oo3oo`0;oole00;o0?oX0_l0hol4ool0k0;ooo]Z1?l0
ond6oookJP03ool0k?l0hooo0>?o00Cooo]Z00So0?oXo`3oUooo=@3ooo]ZoooX0?oo00_ooo]Zo`3o
l0;o:@3o00Gooo]ZoeT0oooo0:[ooo]Zo`3oC@04oookJP05oooS0?oonf[oK03ooookJ_mRo`001ooo
nfX01?oRo`3ooo]Zoe[o0?l0okh2oookJP04o`03oooonf[ooo]Zo`3oB0;ooo]Z00?o0?mgogT0oonG
o`001OoonfX01_l0X_oookl0o`3oX_l0S?oooo]Zo`3o8@?ooo]Z00Ooo`3boookJ_oonf[ooo]Zool0
X?oonf[oE03o00;ooo]Z00?o:P3oool:0?oonfX00ooonfX01?mko`3ooo]Zoom10?ooW002oookJP03
o`3o>?l80?oooo]Z00Kooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP0:oookJP03
o`3o]Ooonf[ooo]Z00?ooo]Z00?o0?n;oookJ_oonfX03ooonfX01Ooo04oooo]ZoookJ_oonf[o0?nF
00Kooo]Z00Cooa`0oookJ_oonf[o^?l03?oonfX01_oBo`3ooo]ZoookJ_oMo`3ooo]Zob/0o`Gooo]Z
00Cooi/0ool00?oonf[ok?l01?oonfX00onC0?oooo]ZoookJP0ToookJP00:_oonfX00ol0oo3ooo]Z
oookJP05oookJP03oooX0?oo00_ooo]Z00?ooo]Z00WoolT0oookJ_l0POoo=ol0oookJ_l0oiOooo]Z
o`3oj?lfo`003_oonfX01?l0hooooo]ZoookJ_oo0>`:oookJPCoiOl02OoonfX00ooo6P3ooo]Zoad0
o`04oookJP03ool0]?oonf[oojL000Oooo]Z00?o0?l9oookJ_oonfX00_oonfX4oiCo00?ooo]Z00?o
/?l0oiCo0?nDo`001OnDo`000ooo01Cooo]ZonGo0005oookJP05oonX0?oo0:Oooo]ZoookJ_oo8@00
1OoonfX02Ol0oiOooo]ZoookJ_n>o`3oo`0ioookJ_l0ol3ooo]Zool01`0>oookJP04ooo90?nDo`3o
U?l0ogT0o`;oU?l000Coo`2loiCo0?oonf[oK03o1?oonfX03?o]0?ooWOl0oookJ_oo0=coE`3ooook
J_nC0?oooo]Zool00?oonf[o:`3oomgo00;ooo]Z00Go^?l0oookJ_oo703o0?nFool0C`04oookJP03
o`3oRol0okGoU?l000go0?l<00Go0?lQoono0?l0o`co0?l<ogT0o`03o`3o30?oA?l01ol0o``00ol0
oego0?l<o`3o3008o`3o30OoU?l000?o0?l<odCo0?m4o`000om4o`02oiCo00;oA?l00_l0onP00olg
o`3oocD0odCo0002odCo0003oookJ_l0oo3o:@3o00;ooo]Z00GoF@3oodCo0?m4o`3o0?m=odCo0002
oookJP[oA?l00ooonfX01_oRo`3ooo]Zoe[o0?l0okkooo]Zool0mPKoiOl000?o0?mgogT0oonGo`00
1_oonfX01Ol0X_ooU?l0oiCo0?nDo`3o0?lQ00?ooo]Z00Koo`3bo`3oE_oonf[ooo]Zool0X?oonfX3
onGo00?oU?l00_oob@000ooUo`3ooo]Zog_o0003oiCo00;ooo]Z00?o0?lhoookJ_oonfX01_oonfX0
1Ooo803ooo]ZoookJ_oonf[oo`2e00gooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]Zoook
JP0:oookJPOoiOl000?ooo]Zo`3oU_oonfX01OoonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z
00God_l0oookJ_oMo`3ooo]Zob/0o`05oookJP;oiOl000?oo`2Yonco0?oonfX00ooonfX00ooUo`3o
oo]ZoookJP1;oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0oookJ_oo00/00ooonfX01?oo=@3o
oo]Zo`21oolgo`02oookJP04o`3oUol0onSooo]ZocKo00kooo]Z00?o0>?ooookJ_oo0>`02ooonfX0
0ol0ongooo]ZoookJP0:oookJP03oolJ0?oonf[o7@3o00?ooo]Z00?oo`2doookJ_ooY`002?oonfX0
2Ol0o`Wooo]ZoookJ_oonf[oO03oocCo0?oonf[o00_oool06002oookJP03ok3o0?l0nooooo]Z00;o
oo]Z00CoCP3ooookJ_oonf[oo`0D0_oonfX00oooa`3ooo]ZoookJP02oookJP05oonX0?oonf[oo`2W
oookJ_oo8@001OoonfX02Ol0oiOooo]ZoookJ_oonf[oS_l0ool0>Ol0ol3ooo]Zool01`0@oookJP05
ool0>?mi0?oo^?l0oookJ_oo0;`00_oonfX00om/0?oooo]ZoookJP02oookJP0<ond0oooonf[oWOl0
oookJ_oo0=coE`3ooookJ_nC0?ooo`00oookJ_l[0?oogOl00ooonfX01?nho`3ooa`0o`3oU_oo04l4
oookJP03o`3oRol0okGooo]Z00;ooo]Z01Coo`2eoookJ_oo803ooo]Zo`3o>?oo@@3oNol0obX0oomD
0?ooo`2Pool0l_oonf[o0?lQo`2RoonGo`3oN@3oo`3oMol00oooF_l0o`3o_P?ooo]Z00GoH_l0of`0
oooo3@3o0000o`3oC@02obT0o`;o0?o`0_oo=@03o`3oj003oookJ_l0hooo0>?o00coo`3/00?o0>?o
oookJ_oonfX00_oonfX2o`3oj008ocOo0?oo=@3ooo]ZoooX0?oo00_ooo]Zo`3ol?lY0?l2oookJP04
oeT0oooo0:[ooo]Zo`3oC@Cooo]Z00Goon<0oookJ_m/0?oooo]Zof;o0008oookJP03on;o0?mJo`3o
0?nn00;ooo]Z00[o00?ooookJ_oonf[ooo]Zo`3oB?oonf[o0?mgoookJ_mi0?ooUol01OoonfX01Ol0
X_oookl0o`3oX_l0S?oo0?lQ00?ooo]Z00?oo`3bo`3oE_oonfX00_oonfX00ooo0:3ooo]Zoe@0o`02
oookJP03obX0oooo2P3ooo]Z00?ooo]Z00CoNol0oookJ_oo@@3ooi`00_oonfX00ol0ocSooo]Zoook
JP06oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX02_oonfX00ol0okGooo]Zoook
JP03oookJP03o`3oRooonf[ooo]Z00kooo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]Zoook
JP03oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX00ooBo`3ooo]Zomgo0002oookJP03ob/0
oooonf[ooo]Z00?ooo]Z00Coo`00ool0ZOoonf[ok?l00ooonfX00onC0?oooo]ZoookJP0UoookJP00
:_oonfX00ol0oo3ooo]ZoookJP05oookJP03oooX0?oo00_ooo]Z00?ooo]Z00WoolT0oookJ_l0POoo
=ol0oookJ_l0oiOooo]Zo`3oj?lfo`003_oonfX01?l0hooooo]ZoookJ_oo0>`:oookJPCoiOl02Ooo
nfX00ooo6P3ooo]Zoad0o`04oookJP03ool0]?oonf[oojL000Oooo]Z00?o0?l9oookJ_oonfX00_oo
nfX5oiCo00;ooo]Z00?o/?l0oiCo0?oonfX00_oonfX01_nDo`3ooo]ZoookJ_oo01Cooo]Zooo700Go
oo]Z00GoojP0ool0Yooonf[ooo]ZoolQ0005oookJP09o`3oUooonf[ooo]Zohko0?oo03Wooo]Zo`3o
`?oonf[oo`0700kooo]Z00CoolT0oiCo0?nDo`3oN@3o0_nDo`001?oo0;coU?l0oookJ_m/0?l4oook
JP0=ond0oooonf[oWOl0ool0g?oo]`3oE`3ooookJ_nC0?ooo`00oonK0?l[0?oogOl0om;o0002oook
JP04okSo0?oo703ooo]Zool0C`Cooo]Z00?o0?n;oookJ_nDo`001Ol0o``2oiCo0003og_o0?l0o`co
0?l<00Co0?l<00Go0?lQo`3o3?l0o`co0?l<ogT0o`03o`3o30;oA?l05?l0o``5oiCo00OoA?l00ol0
onP01_l0o`coocD0oole0?ooj03oA?l0oookJP;o0?o`00Go:@3ooookJ_oonf[oF@3oodCo0002o`3o
C@?ooo]Z2Om4o`05oookJP03on;o0?oonf[oF_l000;ooo]Z00?oo`3fonGo0?oUo`000ooUo`001?l0
ogOooo]ZogT0oonGo`05oookJP06o`2RoonDo`3oU?l0oiCo0?oonf[o0?lQ0ooonfX01_oo0?;ooo]Z
oookJ_oonf[oo`2PoookJP?oiOl00onDo`001Ooob@3oiOl0onGo0?mko`3ooo]Z00?oU?l000?ooo]Z
o`3o>?l80?l02?oonfX01Ooo803ooo]ZoookJ_oonf[oo`2e00cooo]Z00?o0?neoookJ_oonfX00ooo
nfX00ol0oh_ooo]ZoookJP0;oookJPWoiOl01_oonfX01?oo703ooo]ZoookJ_nho`0=oookJP05om;o
0?oMo`3ooo]ZoookJ_l[0?l01OoonfX2onGo0003ool0ZOo/o`3ooo]Z00?ooo]Z00?oiOl0oookJ_oo
nfX0BooonfX00ol0oo3ooo]ZoookJP05oookJP03oooX0?oonf[oo`0;00?ooo]Z00CoocD0oookJ_l0
POoo=ol00_oonfX01?l0oiOo0?oXoookJ_lfo`0>oookJP03o`3Soooonf[oo`3/00cooo]Z00?o0?o]
oookJ_oonfX02OoonfX00ooo6P3ooo]Zoad0o`03oookJP03ool0]?oonf[oojL000Sooo]Z00Wo0?l9
oookJ_oonf[ooo]Zog`0ooldo`3ooo]Zo`0;oooo01P00_oonfX00on`o`3o0?_ooookJP02oookJP04
odh0oooonf[ooo]Zool050;ooo]Z00?oolL0oookJ_oonfX00_oonfX01OooZ03ooo]Zool0Yooonf[o
ob4000Gooo]Z00Wo0?nGoookJ_oonf[ooo]Zohko0?oo03Wooo]Zo`3o`?oo00L04?oonfX01Ooo03So
N@3ooookJ_nho`3oo`2l00;ooo]Z00?oK03ooookJ_oonfX00ooonfX03?o]0?ooWOl0oookJ_oo0=co
E`3ooookJ_nC0?ook?l0ool00?l[0?oogOl0om;o00?ooo]Z00?ooa`0oookJ_oo04l01OoonfX06Ol0
oh_o0?neoookJ_oonf[oo`2eoookJ_oo803ooo]Zo`P0ool0ocSoNol0ool:0?lZ0?oooo]Zool0X?oo
0?;o0?lQo`3oX_oonf[oUol0ogT0ool0ogOo00?ooe[o0?l0okh00ooonfX01?mRo`3oK03oof`0oooo
3@02o`3oC@;o:@3o0_l0oo03oole00;o0?oX00Co=_l0oookJ_oonf[ooo]Z1ol0hol4oookJP?o0?oX
00?o=ol0oole0?oo=@000_ooj0001?oo00_o0?o`o`3ol?lY0?l2oookJP04oeT0oooo0:[o0?m=o`3o
C@Cooo]Z00Goon<0oookJ_m/0?oooo]Zof;o0008oookJP03on;o0?oonf[oF_l000;ooo]Z00Goo`3f
o`03oooonf[ooo]Zo`3oB002oookJP03o`3oMomi0?ooUol000Gooo]Z00Ko0:;ooono0?l0oj;o08co
oookJ_l0ob43oookJP08ool0l_oonf[ooo]ZoookJ_oo0:3ooo]Zoe@0ool09Ol2oookJP03obX0oooo
nf[ooo]Z00;ooo]Z00CoNol0oookJ_oonf[ood400_oonfX00ol0ocSo203ooookJP07oookJP05oolP
0?oonf[ooo]ZoookJ_oo0;D03OoonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z00ko
oo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP03oookJP04oolL0?oonf[ooo]ZokSo
00gooo]Z00?od_l0oookJ_oMo`000_oonfX00ol[0?oooo]ZoookJP03oookJP04ool00?oo0:Wooo]Z
onco00?ooo]Z00?oT`3ooookJ_oonfX09OoonfX002[ooo]Z00?o0?o`oookJ_oonfX01OoonfX00ooo
j03oo`0;oookJP03oookJP09ooo90?l0POoooo]ZocOo0?oonf[o0?nGoookJ_l0onSo=_l000kooo]Z
00Co0>?ooookJ_oonf[oo`3/2OoonfX6onGo00Sooo]Z00?ooaX0oookJ_lM0?l01?oonfX00ooo0;Co
oo]ZoonW0007oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z1OnDo`02oookJP03ok3o0?nDo`3ooo]Z00;o
oo]Z00KoU?l0oookJ_oonf[oo`0DoookJ_ooa`05oookJP05oonX0?oo0:Oooo]ZoookJ_oo8@001Ooo
nfX02Ol0oiOooo]ZoookJ_n>o`3oo`0ioookJ_l0ol3ooo]Zool01`0>oookJP04ooo90?nDo`3oU?l0
ogT0o`;oU?l000Goo`2loiCo0?nDo`3ooo]Zof`0o`04oookJP0<ond0oonMo`3ooo]Zool0g?mG0?oo
oo]Zoi<0ooo/o`3oo`00ob/0oooMo`3od_l00_oonfX01Onho`3ooa`0oookJ_l0oiKoo`1?00?ooo]Z
00?o0?n;oookJ_nDo`001_l0o``00ooonf[o0?l<og_o0006o`3o3004o`3o8Ol0o`co0?l<ogT0o`Co
0?l<0_m4o`0Do`3o30OoA?l01?l0onP01?m4o`3oocD0oole0?oo=@02oooX0004oookJ_l0oo3o0?o`
obT0o`?ooo]Z00?oF@3oodCo0?l0odd01?oonfX00ooo3@3oA?l0odCo0005odCo00Kooo]Z00?oh_l0
oookJ_mJo`000_oonfX00ooo0?KoiOl0onGo0003onGo0004oookJ_l0ogOoN@3ooiOo00Kooo]Z00Go
okl0oiCo0?nDo`3oU?l0o`3o8@03oookJP05ool0l_l0oeKooo]ZoookJ_oo0:000_oonfX3onGo00;o
U?l000KoolT0onGo0?oUo`3ooo]Zog_o0?oonfX2oiCo00;ooo]Z00?o0?lho`P0oooonfX01_oonfX0
1Ooo803ooo]ZoookJ_oonf[oo`2e00gooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]Zoook
JP0;oookJPWoiOl01_oonfX01?oo703ooo]ZoookJ_nho`0<oookJP05om;o0?oonf[ogOl0oookJ_l[
0?l01_oonfX2onGo0003onco0?oonf[ooo]Z00?ooo]Z00?oiOl0oookJ_oonfX0BooonfX00ol0oo3o
oo]ZoookJP05oookJP03oooX0?oonf[oo`0;00?ooo]Z00CoocD0oookJ_l0POoo=ol00_oonfX01?l0
oiOo0?oXoookJ_lfo`0>oookJP03o`3Soooonf[oo`3/00cooo]Z00?o0?o]oookJ_oonfX02OoonfX0
0ooo6P3ooo]Zoad0o`03oookJP03ool0]?oonf[oojL000Sooo]Z00Wo0?l9oookJ_oonf[ooo]Zog`0
ooldo`3ooo]Zo`0;oooo01P00_oonfX00on`o`3o0?_ooookJP02oookJP04odh0oooonf[ooo]Zool0
50;ooo]Z00?oolL0oookJ_oonfX00_oonfX01OooZ03ooo]Zool0Yooonf[oob4000Gooo]Z00Wo0?nG
oookJ_oonf[ooo]Zohko0?oo03Wooo]Zo`3o`?oo00L04?oonfX01Ooo03SoN@3ooookJ_nho`3oo`2l
00?ooo]Z00?oK03ooookJ_oonfX00_oonfX03?o]0?oooo]Zoigo0?oo0=coE`3ooookJ_nC0?ook?l0
ool00?l[0?oogOl0om;o00?ooo]Z00Cooa`0oookJ_l0oiKoo`1?1?oonfX00ol0oh_o0?neoookJP02
oookJP0Aool0]Ooo803ooo]ZoookJ_l0ocSood40og_o0?oo2P3o:P3oool0X?l0oeKoo`3bo`3o8Ol0
oj;ooo]ZogT0ool0ogL00_l0odP00omJo`3o0?nnon;o0002oookJP05o`000?ooh`3oK03oool=0?mI
0?l00_l0odd00ooonf[o:@3oo`3ol002oooX00;oocD00ol0onP4ocKo00Cooo]Z1?l0onP01?l0oiOo
ocD0oole0?oo=@02oooX0005ool02ol0oo3o0?o`oookJ_lY0?l00_oonfX00omI0?ooo`2Zo`3oC@05
oookJP05oooS0?oonf[oK03ooookJ_mRo`002?oonfX01ooRo`3ooo]Zoe[o0?l0okkooo]Zool0m_l0
0ol00_oonfX01ol0odSooo]ZoookJ_l0ogOoN@3ooolW0?nGo`001OoonfX01Ooo_`3ooo]Zo`3oX_l0
S?oo0?lQ00?ooo]Z00?oo`3bo`3oE_oonfX00_oonfX00ooo0:3ooo]Zoe@0o`02oookJP03obX0oooo
2P3ooo]Z00?ooo]Z00CoNol0oookJ_oo@@3ooi`00_oonfX00ol0ocSo203ooookJP06oookJP03oolP
0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX02_oonfX00ol0okGooo]ZoookJP03oookJP03o`3o
Rooonf[ooo]Z00oooo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP03oookJP04oolL
0?oonf[ooo]ZokSo00cooo]Z00Kod_l0oookJ_oonf[ogOl0oookJ_l[0?l5oookJP04oonK0?oo003o
oo]Zonco00Cooo]Z00?oT`3ooookJ_oonfX09OoonfX002[ooo]Z00?o0?o`oookJ_oonfX01OoonfX0
0oooj03oo`0;oookJP03oookJP09ooo90?l0POoooo]ZocOo0?oonf[o0?nGoookJ_l0onSo=_l000ko
oo]Z00Co0>?ooookJ_oonf[oo`3/2OoonfX6onGo00Sooo]Z00?ooaX0oookJ_lM0?l01?oonfX00ooo
0;Cooo]ZoonW0007oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z1OnDo`02oookJP03ok3o0?nDo`3ooo]Z
00;ooo]Z00KoU?l0oookJ_oonf[oo`0DoookJ_ooa`05oookJP05oonX0?oo0:Oooo]ZoookJ_oo8@00
1OoonfX02Ol0oiOooo]ZoookJ_n>o`3oo`0ioookJ_l0ol3ooo]Zool01`0>oookJP04ooo90?nDo`3o
U?l0ogT0o`;oU?l000Gooo]Zool0_?oonf[ooo]Zof`0o`04oookJP0<ond0oonMo`3ooo]Zool0g?mG
0?oooo]Zoi<0ooo/o`3oo`00oookJ_oMo`3od_l00_oonfX01Onho`3ooo]ZoolL0?l0oiKoo`1?00Co
oo]Z00?o0?n;oiCo0?l0o``01Ol0o``02?oonf[o0?l<o`3o3?mko`3o0?l<obX0ool0o`coo`2P0_l0
o``01?l0ob7o0?l<o`3o3?mi0?l4o`3o3003odCo0?l0o`co0?l<01;o0?l<1ol0onP3odCo00;oocD0
00CoA?l0oooX0?ooj03o0?l<0_l0oo02obT0o`;ooo]Z00CoF@3oool0Z_m4o`3o0?m=1?oonfX00ooo
h`3oA?l0odCo0004odCo00Sooo]Z00Koh_l0oookJ_mJo`3ooo]Zool0m_l00ol4onGo0005oookJ_l0
ogOooo]ZogT0oonGo`001_oonfX01?oo_`3oU?l0oiCo0?l0ob43oookJP03ool0l_l0oeKooo]Z00;o
oo]Z00?oo`2PoookJ_mD0?l00_oUo`001Ooob@3oU?l0ooo90?oob@3oiOl000;ooo]Z00?oNol0oonL
0?nDo`000_oonfX00ol0ocSo203ooookJP07oookJP05oolP0?oonf[ooo]ZoookJ_oo0;D03OoonfX0
0ol0okGooo]ZoookJP02oookJP03o`3oRooonf[ooo]Z00cooo]Z2?oUo`06oookJP05oolL0?oonf[o
oo]ZoookJ_nho`003?oonfX01OoBo`3ooo]Zomgo0?oonf[o:`3o00Gooo]Z0_oUo`000ooo0:Wok?l0
oookJP03oookJP03onGo0?oonf[ooo]Z04cooo]Z00?o0?o`oookJ_oonfX01OoonfX00oooj03ooo]Z
ool02`03oookJP04oole0?oonf[o087oocOo00;ooo]Z00Co0?nGo`3oj?oonf[o=_l03_oonfX00ol0
hooooo]Zool0k00<oookJP03o`3okOoonf[ooo]Z00Wooo]Z00?ooaX0oookJ_lM0?l00ooonfX00ooo
0;Cooo]ZoonW0008oookJP09o`3o2Ooonf[ooo]ZoookJ_ml0?oo=?l0oookJ_l02oooo`0H00;ooo]Z
00?o/?l0o`3koooonfX00_oonfX01?m>0?oooo]ZoookJ_oo01@2oookJP03ooo70?oonf[ooo]Z00;o
oo]Z00GoojP0oookJ_oo0:Oooo]ZoolQ0005oookJP09o`3oUooonf[ooo]ZoookJ_n>o`3oo`0ioook
J_l0ol3oo`07013ooo]Z00Koo`0hoookJ_mi0?oo^?l0oookJ_oo0;`2oookJP03of`0oooonf[ooo]Z
00;ooo]Z00cok@3ooookJ_nMo`3oo`3LoookJ_mG0?oooo]Zoi<0oooo003ooo]Zomgo0?oBo`03oook
JP04okSo0?oo703o0?nFool0C`Cooo]Z00?o0?n;o`3o]OoonfX00_oonfX05?oo0;Gooo]ZoolP0?oo
nf[o203oo`3o>?oo@@3oNol0obX0oomD0?ooo`2Pool0l_oonf[o0?lQo`2Roooonf[oN@3oo`3oMooo
nf[o0?m80_mJo`001ooRo`3ooo]Zo`000?l0003oon<0of`0oooo3@000_oonfX00ol0odgoo`2ZoeT0
o`02o`3ol003oookJ_ooj03oocD000;oocD02?l0onP00ol0oiOoocD0oole0002oole0004ool02ooo
j03oonP0oookJP;o0?o`00Gooo]ZobT0oolY0?oooo]ZoeT0o`02ool0ZP03o`3oCOoonf[ooo]Z00;o
oo]Z0_ooh`001?oonf[oK03oof;o0?mRo`09oookJP03on;o0?oonf[oF_l000;ooo]Z00Co00?ooook
J_oonf[o0?m80_oonfX01?l0ogOooo]ZogT0oonGo`06oookJP04oono0?oonf[o0?nRo`3o8@?ooo]Z
00?oo`3bo`3oE_oonfX00ooonfX00ooo0:3oE03oo`0Uo`02oookJP03obX0oooonf[ooo]Z00?ooo]Z
00?oNol0oookJ_oo@@000ooonfX00ol0ocSooo]ZoookJP06oookJP05oolP0?oonf[ooo]ZoookJ_oo
0;D03OoonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z00oooo]Z00Goo`1?oookJ_oo
nf[ooo]Zo`3oUP05oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX00ooBo`3ooo]Zomgo0002
oookJP03ob/0oooonf[ooo]Z00?ooo]Z00Coo`00ool0ZOoonf[ok?l00ooonfX00onC0?oooo]Zoook
JP0VoookJP00:_oonfX00ol0oo3ooo]ZoookJP05oookJP03oooX0?oo00_ooo]Z00?ooo]Z00WoolT0
o`21oooonf[o=ol0oookJ_l0oiOooo]Zo`3oj?lfo`003_oonfX01?l0hooooo]ZoookJ_oo0>`9oook
JPKoiOl02?oonfX01?oo6P3ooo]Zoad0ool0oo83oookJP03oomi0?oonf[oojL000Oooo]Z00?o0?l9
oookJ_oonfX00_oonfX6oiCo0003oookJ_n`o`3oU?l000?ooo]Z00CoU?l0oookJ_oonf[oo`0D0_oo
nfX00oooa`3ooo]ZoookJP02oookJP03oonX0?oo0:Oooo]Z00;ooo]Z00?oob40oookJ_oonfX00_oo
nfX02Ol0oiOooo]ZoookJ_n>o`3oo`0ioookJ_l0ol3ooo]Zool01`0>oookJPCoolT000CoN@3ooiCo
0?oonf[oo`2l0_oonfX00om/0?oooo]ZoookJP02oookJP0=ond0oooonf[oWOl0ool0g?mG0?oooo]Z
oi<0oooonf[oo`00oookJ_l[0?oogOl0om;o0002oookJP05okSo0?oo703o0?nFoookJ_oo04l00ooo
nfX00ol0oh_ooo]Zo`3o3007o`3o3004o`3o>?mko`3o0?l<obX0o`;o0?l<00Coo`2Po`3o3?l0ob7o
0?nR0_l0o``00omi0?oo0?l<o`3o3002o`3o3003odCo0?l0o`co0?l<01Co0?l<1om4o`03oooX0003
odCo0?l0oo3o0?o`00;o:@3o0_oonfX2oeT0o`03ool0Z_oonf[o0?m=00Cooo]Z00?oon<0odCo0?m4
o`000om4o`07oookJP05oiCo0?oonf[oh_l0oookJ_mJo`000_oonfX00ol00ooooo]ZonGo0002onGo
0005oookJ_l0ogOooo]ZogT0oonGo`001_oonfX01Ooo_`3o08cooiCo0?oonf[o0?lQ00?ooo]Z00?o
o`3bo`3oE_oonfX00_oonfX00ooo0:3ooo]Zoe@0o`02onGo0004ooo90?lZ0?ooolT0onGo00;ooo]Z
00CoNol0oookJ_ooW03ood400_oonfX00ol0ocSo203ooookJP07oookJP04oolP0?oonf[ooo]Zool0
]@kooo]Z00?o0?neoookJ_oonfX00_oonfX00ol0oh_ooo]ZoookJP0<oookJPOoiOl000?o0?nFoook
J_oonfX01?oonfX01?oo703ooo]ZoookJ_nho`0=oookJP05om;o0?oonf[ogOl0oookJ_l[0?l01Ooo
nfX2onGo0003ool0ZOo/o`3oiOl000;oiOl000?ooo]ZonGo0?oonfX01_oonfX00ooob@3ooo]Zoook
JP14oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0oookJ_oo00/00ooonfX01?oo=@3ooo]Zo`21
oolgo`02oookJP04o`3oUol0onSooo]ZocKo00kooo]Z00?o0>?ooookJ_oo0>`03?oonfX00ol0ongo
oo]ZoookJP09oookJP03oolJ0?oonf[o7@3o00?ooo]Z00?oo`2doookJ_ooY`002?oonfX02Ol0o`Wo
oo]ZoookJ_oonf[oO03oocCo0?oonf[o00_oool06002oookJP03ok3o0?l0nooooo]Z00;ooo]Z00Co
CP3ooookJ_oonf[oo`0D0ooonfX01oooa`3ooo]ZoookJ_oonf[oojP0oookJ_oo0:L00_oonfX00ooo
8@3ooo]ZoookJP02oookJP09o`3oUooonf[ooo]ZoookJ_n>o`3oo`0ioookJ_l0ol3oo`07017ooo]Z
00Goo`0hogT0oonho`3ooo]Zool0_002oookJP03of`0oooonf[ooo]Z00?ooo]Z00cok@3ooigo0?oo
nf[oo`3LoeL0oooonf[oT`3oool00?oo0:Wo:`3oomgo0?oBo`03oookJP04oolL0?l0oiKooo]Zool0
C`Cooo]Z00?o0?n;o`3o]OoonfX00_oonfX03_oo0;Goob00oookJ_oonf[o0?lhoom10?mko`3oo`X0
obX0oomD0?ooo`2Pool0l_l0ob7o0?nR0_oonfX01omi0?oo0?mgoookJ_l0odSooo]Zoe[o0?oRo`00
0ol000000omRo`3oK03ooooS0002oookJP;o0?m=0_mI0?l3o`3ol003oookJ_ooj03oocD000SoocD0
00?oo`0;oooX0?ooj0000_ooj0000ooonf[o0?o`o`3ol003obT0o`06oookJ_mI0?ooF@3oool0Z_oo
nf[o0?m=1?oonfX01Oooh`3oo`d0oookJ_m/0?ooH_l000[ooo]Z00?oh_l0oookJ_mJo`000_oonfX0
1?l00ooooo]ZoookJ_l0odP3oookJP03o`3oMomi0?ooUol000Kooo]Z00Gookl0oookJ_l0oj;ooo]Z
o`3o8@03oookJP03ool0l_l0oeKooo]Z00;ooo]Z00?oo`2PoookJ_mD0?l00ooonfX00olZ0?oooo]Z
oookJP02oookJP04og_o0?oonf[ooo]Zoom100;ooo]Z00?o0?lho`P0oooonfX01ooonfX01Ooo803o
oo]ZoookJ_oonf[oo`2e00gooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0>oook
JP03ool0Cooonf[ooo]Z00;ooo]Z00?o0?nFoookJ_oonfX00ooonfX01?oo703ooo]ZoookJ_nho`0=
oookJP03om;o0?oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX00ooonfX01?oo003oo`2YoookJ_o/
o`03oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?oE`3ooookJ_oonfX07OoonfX002[ooo]Z00?o0?o`
oookJ_oonfX01?oonfX00oooj03ooo]Zool02`04oookJP09oole0?l0POoooo]ZocOo0?oonf[o0?nG
oookJ_l0onSo=_l000kooo]Z00Co0>?ooookJ_oonf[oo`3/2OoonfX7onGo00Sooo]Z00?ooaX0oad0
ool0oo800ooonfX00oooN@3ooo]ZoonW0007oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z1_nDo`000ooo
nf[o/?l0oiCo0003oookJP04oiCo0?oonf[ooo]Zool050;ooo]Z00?oolL0oookJ_oonfX00_oonfX0
0oooZ03ooo]Zool0Y`02oookJP03oolQ0?oonf[ooo]Z00;ooo]Z00Wo0?nGoookJ_oonf[oS_l0oook
J_oo03Wo0?o0oookJ_oo00L03_oonfX4ooo90004ogT0oonho`3ooo]Zool0_0;ooo]Z00?oK03ooook
J_oonfX00ooonfX03?o]0?ooWOl0ool0g?oo]`3oE`3ooi<0oooonf[ok?l0ool00?l[0?oogOl0om;o
00;ooo]Z00Go^?l0oolL0?oonf[o0?nFool0C`04oookJP03odCo0?l0o`co0?l<00Ko0?l<00_ooo]Z
o`3o>?mko`3o0?l<obX0ool0o`coo`2Pool0l_l0o`co0?lQo`3oXP02o`3o3003ogT0ool0o`coA?l0
00?oA?l04?l0o``3o`3ol0Go0?l<0om4o`02o`3o30?o0?o`0_lY0?l2oookJP;oF@3o0_oo0:X00ooo
nf[o0?m=oookJP02oookJP;oon<000Cooo]ZodCo0?m4o`3oA?l02OoonfX01?nDo`3oh_l0o`3o__mJ
o`02oookJP03ool0m_l00oooiOl000;oiOl00_oonfX01?l0ogOooo]ZogT0oonGo`06oookJP04oono
0?l0S?oo0?nRo`3o8@?ooo]Z00?oo`3boookJ_l0oeH00_oonfX00ooo0:3ooo]Zoe@0o`03onGo0003
obX0oooob@3oiOl000;ooo]Z00CoNol0oookJ_ooW03ood400_oonfX00ol0ocSo203ooookJP07oook
JP05oolP0?oonf[ooo]ZoookJ_oo0;D03OoonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[o
oo]Z00cooo]Z1ooUo`000ol0oiKooo]ZoookJP04oookJP04oolL0?oonf[ooo]ZokSo00cooo]Z00Go
d_l0oookJ_oMo`3ooo]Zob/0o`06oookJP;oiOl000?ok?l0oookJ_oUo`001OoUo`02oookJP?oolT0
00?ooo]Zooo90?oonfX0AOoonfX00ol0oo3ooo]ZoookJP04oookJP04oooX0?oonf[ooo]Zool02`?o
oo]Z00CoocD0oookJ_l0POoo=ol00_oonfX01?l0oiOo0?oXoookJ_lfo`0>oookJP03o`3Soooonf[o
o`3/00cooo]Z00?o0?o]oookJ_oonfX02_oonfX00ooo6P3o7@3ooookJP02oookJP03ool0]?oonf[o
ojL000Sooo]Z00Wo0?l9oookJ_oonf[ooo]Zog`0ooldo`3ooo]Zo`0;oooo01P00_oonfX00on`o`3o
0?_ooookJP02oookJP04odh0oooonf[ooo]Zool050?ooo]Z00OoolL0oookJ_oonf[ooo]ZoonX0?oo
nf[oo`2W00;ooo]Z00?oob40oookJ_oonfX00ooonfX02Ol0oiOooo]ZoookJ_n>o`3oo`0ioookJ_l0
ol3ooo]Zool01`0@oookJP05ool0>?mi0?oo^?l0oookJ_oo0;`00_oonfX00om/0?oooo]ZoookJP03
oookJP0<ond0oonMo`3ooo]Zool0g?mG0?oooo]Zoi<0ooo/o`3oo`00ob/0oooMo`3od_l00ooonfX0
1?oo703ooo]Zo`3oU_oo04l4oookJP03o`3oRol0okGooo]Z00?ooo]Z00koo`2eoookJ_oonf[ooo]Z
o`3o>?oo@@3oNol0oookJ_lZ0?ooo`2Pool0l_l0oeKo0?lQo`3oXP;ooo]Z00GoN@3oo`3oMooonf[o
0?m8oookJP02oe[o00?o000000CoH_l0of`0oom/0?ooon<00_oonfX2o`3oC@03ool0Z_lY0?oo:@3o
00Co0?o`2?ooj002oookJP?o0?o`0_lY0?l2oookJP;oF@3o0_oo0:X00ooonf[o0?m=oookJP03oook
JP05oooS0?oo3@3ooo]Zof`0oomRo`002_oonfX00ooRo`3ooo]Zoe[o0002oookJP05ool0m_l00ooo
oo]ZoookJ_l0odP00_oonfX01?l0ogOooo]ZogT0oonGo`06oookJP04oono0?oonf[o0?nRo`3o8@?o
oo]Z00?oo`3boookJ_l0oeH00ooonfX00ooo0:3oE03oo`0Uo`02oookJP03obX0oooo2P3ooo]Z00;o
oo]Z00CoNol0oookJ_oonf[ood400ooonfX00ol0ocSooo]ZoookJP06oookJP03oolP0?oonf[ooo]Z
00;ooo]Z00?oo`2eoookJ_oonfX02_oonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z
00oooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP06oookJP04oolL0?oonf[ooo]ZokSo00cooo]Z00Ko
d_l0oookJ_oonf[ogOl0oookJ_l[0?l5oookJP04oonK0?oo003oo`2Yonco00Cooo]Z00?oT`3ooook
J_oonfX01_oonfX00omG0?oooo]ZoookJP0MoookJP00:_oonfX00ol0oo3ooo]ZoookJP04oookJP03
oooX0?oonf[oo`0;00Cooo]Z00WoocD0o`21oooonf[o=ol0oookJ_l0oiOooo]Zo`3oj?lfo`003_oo
nfX01?l0hooooo]ZoookJ_oo0>`9oookJPOoiOl02?oonfX00ooo6P3o7@3oo`3olP03oookJP;oogT0
00?oojL0oookJ_oonfX01OoonfX00ol0o`Wooo]ZoookJP02oookJPOoU?l000?o/?l0o`3koooonfX0
0_oonfX01?nDo`3ooo]ZoookJ_oo01@2oookJP03ooo70?oonf[ooo]Z00;ooo]Z00?oojP0oookJ_oo
0:L00_oonfX00ooo8@3ooo]ZoookJP03oookJP08o`3oUooonf[ooo]Zohko0?oo03Wo0?o0oookJ_oo
00L>oookJPCoolT000CoN@3ookSo0?oonf[oo`2l0_oonfX00om/0?oooo]ZoookJP03oookJP0<ond0
oonMo`3oo`3LoookJ_mG0?oooo]Zoi<0ooo/o`3oo`00oookJ_oMo`3od_l00ooonfX01Onho`3ooa`0
odCo0?oonf[oo`1?00?ooo]Z00?oA?l0o`3o3?l0o``00ol0o``02ooo0;Goob00oookJ_oonf[o0?lh
og_o0?m4o`3o:P3oodCo0?l0o`coo`2P00;o0?l<00Go0?lQo`3o3?l0o`coA?l0ogT0o`04odCo01?o
0?l<2_l0oo03obT0o`CoiOl000?ooo]Zool0Z_l0odd00_l0odd2oookJP04ool=0?ooh`3ooo]Zoook
JP;oA?l02_oonfX3oiCo0006oe[o0?oonf[oo`3fool0m_l00ooooo]Z0_oUo`02oookJP04o`3oMooo
nf[oN@3ooiOo00Kooo]Z00Gookl0o`2<ool0oj;ooo]Zo`3o8@03oookJP03ool0l_l0oeKooo]Z00;o
oo]Z00?oo`2Poe@0ool09Ol00_oUo`000olZ0?ooolT0onGo0003oookJP04og_o0?oonf[ooi`0oom1
00;ooo]Z00?o0?lho`P0oooonfX01ooonfX01Ooo803ooo]ZoookJ_oonf[oo`2e00gooo]Z00?o0?ne
oookJ_oonfX00_oonfX00ol0oh_ooo]ZoookJP0=oookJPKoiOl000?o0?nFoookJ_oonfX01?oonfX0
1?oo703ooo]ZoookJ_nho`0=oookJP05om;o0?oonf[ogOl0oookJ_l[0?l01OoonfX2onGo0003ool0
ZOo/o`3ooo]Z00SoiOl01Ooob@16oookJP03o`3ol?oonf[ooo]Z00Cooo]Z00CoonP0oookJ_oonf[o
o`0;0ooonfX01?oo=@3ooo]Zo`21oolgo`02oookJP04o`3oUol0onSooo]ZocKo00kooo]Z00?o0>?o
oookJ_oo0>`03?oonfX00ol0ongooo]ZoookJP0:oookJP03oolJ0?lM0?oooo]Z00;ooo]Z00?oo`2d
oookJ_ooY`002?oonfX02Ol0o`Wooo]ZoookJ_oonf[oO03oocCo0?oonf[o00_oool06002oookJP03
ok3o0?l0nooooo]Z00;ooo]Z00CoCP3ooookJ_oonf[oo`0D0ooonfX01oooa`3ooo]ZoookJ_oonf[o
ojP0oookJ_oo0:L00_oonfX00ooo8@3ooo]ZoookJP03oookJP09o`3oUooonf[ooo]ZoookJ_n>o`3o
oo]Zo`3o`?oonf[oo`07013ooo]Z00Goo`0hogT0oooonf[o^?l0ool0_002oookJP03of`0oooonf[o
oo]Z00?ooo]Z00cok@3ooookJ_nMo`3oo`3LoeL0oooo]`3ooo]Zoi<0oooo003ooo]Zomgo0?oBo`03
oookJP05okSo0?oo703o0?nFoookJ_oo04l00ooonfX00ol0oh_ooo]Zo`3o]@03oookJP0?ool0]Ooo
803ooo]ZoookJ_l80?oo0?lhog_o0?oo2P3o:P3ooe@0oooo0:3oo`3boookJ_l0ob7ookl000;ooo]Z
00WoN@3oo`3oMooonf[o0?m8oookJ_l0okkoF_l0on;o0?l000000_oonfX01?mRo`3oK03oof`0oooo
h`02oookJP05o`3oCOoo0:[oo`2Zool0Z_oonfX00_lY0?l:o`3ol0?o:@3o00Kooo]ZoeT0oomI0?oo
F@3ooookJ_oo0:X3o`3oC@?ooo]Z00Goo`d0oooS0?oonf[ooo]Zof`0o`0;oookJP04on;o0?oonf[o
F_l0oookJP;oo`3f00Co00?ooookJ_oonf[o0?m80ooonfX00ol0ogOoN@3ooiOo0006oookJP05oono
0?oonf[o0?nRoookJ_l0ob400ooonfX00ooo0?;o0?mFoookJP03oookJP06ool0X?mD0?oooo]Zoook
J_lZ0?ooo`X01?oonfX01?mko`3ooo]ZoookJ_oo@@02oookJP03o`3o>?l80?oooo]Z00Oooo]Z00Go
ob00oookJ_oonf[ooo]Zool0]@0=oookJP03o`3o]Ooonf[ooo]Z00?ooo]Z00?o0?n;oookJ_oonfX0
3ooonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Gooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000<oook
JP06om;o0?oonf[ooo]Zomgo0?oonf[o:`3o1OoonfX01?oo003oo`2YoookJ_o/o`04oookJP03oi<0
oooonf[ooo]Z00Gooo]Z00?ookL0oeL0oooonfX07_oonfX002[ooo]Z00?o0?o`oookJ_oonfX01?oo
nfX00oooj03ooo]Zool02`04oookJP0:oole0?l0POoooo]ZocOo0?oonf[o0?nGoookJ_l0onSooo]Z
ocKo00gooo]Z00Co0>?ooookJ_oonf[oo`3/2?oonfX8onGo00Sooo]Z00?ooaX0oad0ool0oo800ooo
nfX2oomi0003oonW0?oonf[ooo]Z00Gooo]Z00Co0?l9oookJ_oonf[ooo]Z2?nDo`000on`o`3o0?_o
oookJP02oookJP04oiCo0?oonf[ooo]Zool050;ooo]Z00?oolL0oookJ_oonfX00ooonfX01OooZ03o
o`2WoookJ_oonf[oob4000Gooo]Z00Wo0?nGoookJ_oonf[oS_l0ool0>Ooonf[o0?o0oookJ_oo00L0
3OoonfX4ooo90005ogT0oooob@3o^?l0oookJ_oo0;`00_oonfX00om/0?oooo]ZoookJP02oookJP0=
ond0oooonf[oWOl0ool0g?mG0?oooo]Zoi<0oooonf[oo`00oookJ_l[0?oogOl0om;o0002oookJP05
okSo0?oo703oA?l0oookJ_oo04l00ooonfX2odCo0003o`3o3?oonf[ooo]Z00;ooo]Z00_oo`2eoolP
0?oonf[ooo]Zo`3o>?mko`3oA?l0obX0oom4o`3oo`2PodCo0002o`3o3004o`3o8Ooo_`3oA?l0odCo
00;oN@3o0om4o`06o`3o3003odCo0?l0o`co0?l<00Go0?l<0_m4o`06o`3o30Go:@3o2?oUo`02o`3o
C@?oA?l000Oooo]Zool=0?ooh`3ooo]Zof`0oom4o`3oH_l000[ooo]Z1OnDo`000ooo0?Ko00?oo`03
o`02oookJP08onGo0?oonf[ooo]ZoookJ_l0ogOoN@3ooolW0?nGo`05oookJP05oono0?oonf[o0?nR
oookJ_l0ob400ooonfX00ooo0?;ooo]Zo`3oEP02oookJP04ool0X?oonf[oE03ooookJP;oiOl000?o
:P3oool:0?oUo`000_oonfX01?mko`3ooo]ZoonL0?oo@@02oookJP03o`3o>?l80?oooo]Z00Oooo]Z
00Goob00oookJ_oonf[ooo]Zool0]@0>oookJP03o`3o]Ooonf[ooo]Z00;ooo]Z00?o0?n;oookJ_oo
nfX03OoonfX6onGo0003o`3oU_oonf[ooo]Z00Cooo]Z00Cooa`0oookJ_oonf[o^?l03OoonfX01OoB
o`3ooo]Zomgo0?oonf[o:`3o00Gooo]Z0_oUo`000ooo0:Wok?l0oookJP08onGo00GoolT0A_oonfX0
0ol0oo3ooo]ZoookJP04oookJP04oooX0?oonf[ooo]Zool02`?ooo]Z00CoocD0oookJ_l0POoo=ol0
0_oonfX01?l0oiOo0?oXoookJ_lfo`0>oookJP03o`3Soooonf[oo`3/00cooo]Z00?o0?o]oookJ_oo
nfX02_oonfX00ooo6P3o7@3ooookJP02oookJP04ool0]?oonf[ooo]ZoonW00Oooo]Z00Wo0?l9oook
J_oonf[ooo]Zog`0ooldo`3ooo]Zo`0;oooo01P00_oonfX00on`o`3o0?_ooookJP02oookJP04odh0
oooonf[ooo]Zool050?ooo]Z00?oolL0oookJ_oonfX00_oonfX01OooZ03oo`2WoookJ_oonf[oob40
00Gooo]Z00Wo0?nGoookJ_oonf[ooo]Zohko0?oo03Wo0?o0oookJ_oo00L04?oonfX01_oo03SoN@3o
oookJ_nho`3ooo]Zool0_0;ooo]Z00?oK03ooookJ_oonfX00ooonfX03?o]0?ooWOl0oookJ_mG0?oo
okL0oookJ_nC0?ooo`00oonK0?l[0?oogOl0om;o00?ooo]Z00Cooa`0o`3oU_oonf[oo`1?1?oonfX0
0ol0oh_o0?neoookJP03oookJP0?ool0]Ooo803ooo]ZoookJ_l0ocSood40og_o0?oo2P3o:P3oool0
X?oonf[oo`3boookJ_l0ob7ookl000;ooo]Z0_mi0?l01?oonf[o0?m8o`3oB?l00002oe[o00Cooo]Z
00GoH_l0of`0oom/0?ooon<0oookJP05o`3oC@;oo`2Z0ooonfX5obT0o`;ooo]Z0omI0?l2ool0ZP?o
0?m=1OoonfX00ooo3@3oon<0oookJP02of`0o`_ooo]Z00Goh_l0oookJ_mJo`3ooo]Zool0mP02o`03
o`;ooo]Z00So0?m8oookJ_oonf[ooo]Zo`3oMomi0?ooobL0oiOo00Gooo]Z00Gookl0oookJ_l0oj;o
08coo`3o8@03oookJP03ool0l_oonf[o0?mF00?ooo]Z00?oo`2PoookJ_mD0?l00_oonfX00olZ0?oo
o`X0oookJP02oookJP04og_o0?oonf[ooo]Zoom100?ooo]Z00?o0?lhoookJ_oonfX01_oonfX00ooo
803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z00_ooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0
oh_ooo]ZoookJP0>oookJP03ool0Cooonf[ooo]Z00;ooo]Z00?o0?nFoookJ_oonfX00ooonfX01?oo
703ooo]ZoookJ_nho`0=oookJP03om;o0?oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX00ooonfX0
0ooo003oo`2Yonco0004oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?oE`3ooookJ_oonfX07_oonfX0
02[ooo]Z00?o0?o`oookJ_oonfX01?oonfX00oooj03ooo]Zool02`04oookJP0:oole0?l0POoooo]Z
ocOo0?oonf[o0?nGoookJ_l0onSooo]ZocKo00kooo]Z00?o0>?ooookJ_oob@002?oonfX9onGo00Oo
oo]Z00?ooaX0oad0ool0oo800ooonfX2oomi0003oonW0?oonf[ooo]Z00Gooo]Z00Co0?l9oookJ_oo
nf[ooo]Z2?nDo`000on`o`3o0?_ooookJP02oookJP04oiCo0?oonf[ooo]Zool050;ooo]Z00?oolL0
oookJ_oonfX00ooonfX01OooZ03oo`2WoookJ_oonf[oob4000Gooo]Z00Wo0?nGoookJ_oonf[oS_l0
ool0>Ooonf[o0?o0oookJ_oo00L03OoonfX4ooo90005ogT0oooob@3o^?l0oookJ_oo0;`00_oonfX0
0om/0?oooo]ZoookJP02oookJP0=ond0oooonf[oWOl0ool0g?oonf[oE`3ooi<0oooonf[ok?l0ool0
0?oonf[ogOl0om;o0003oookJP04oolL0?m4o`3oA?l0ool0C`Cooo]Z0_m4o`001_l0okGooo]Zoook
J_oonf[oo`2eoolP00;ooo]Z00co203oo`3o>?mko`3oA?l0obX0oom4o`3oo`2Po`3o3?oo0?;o0?lQ
o`3oX_oo_`02odCo0004o`3oMomi0?ooA?l0odCo00Go0?l<00?ooo]ZodCo0?m4o`000ol0o``00om/
0?oo0?l<odCo0003odCo00Go0?l<0om4o`0:onGo00GoA?l000Coon<0of`0oom/0?ooK03o0_mRo`0:
oookJPKoU?l000Go00?ooookJ_oonf[o0?m8onGo0002oookJP;o0?mg00?oN@3ooookJ_nGo`001Ooo
nfX00ol0X_oookl0o`3oXP02oookJP06o`3o8Ooonf[ooo]ZoookJ_oo0?;o0?mF0ooonfX02?oo0:3o
E03oo`0Uoooonf[oiOl0obX0oooo2P3oiOl00ooonfX00omko`3ooo]Zoom10003oookJP03o`3o>?l8
0?oooo]Z00Kooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP0;oookJP03o`3o]Ooo
nf[ooo]Z00?ooo]Z00?o0?n;oookJ_oonfX03OoonfX5onGo0003o`3oU_oonf[ooo]Z00Cooo]Z00Go
oa`0oookJ_oonf[ooo]ZokSo000<oookJP06om;o0?oonf[ooo]Zomgo0?oonf[o:`3o1OoonfX2onGo
0003onco0?oonf[ooo]Z00OoiOl000?ooo]Zooo90?oob@000ooob@16oookJP03o`3ol?oonf[ooo]Z
00Cooo]Z00CoonP0oookJ_oonf[oo`0;0ooonfX01?oo=@3ooo]Zo`21oolgo`02oookJP04o`3oUol0
onSooo]ZocKo00kooo]Z00?o0>?ooookJ_oo0>`03?oonfX00ol0ongooo]ZoookJP0:oookJP03oolJ
0?lM0?oooo]Z00?ooo]Z00?oo`2doookJ_ooY`001ooonfX02Ol0o`Wooo]ZoookJ_oonf[oO03oocCo
0?oonf[o00_oool06002oookJP03ok3o0?l0nooooo]Z00;ooo]Z00CoCP3ooookJ_oonf[oo`0D0ooo
nfX00oooa`3ooo]ZoookJP02oookJP05oonX0?oo0:Oooo]ZoookJ_oo8@001OoonfX02Ol0oiOooo]Z
oookJ_oonf[oS_l0ool0>Ooonf[o0?o0ool01`0@oookJP06ool0>?mi0?oooo]ZokSo0?oonf[oo`2l
0_oonfX00om/0?oooo]ZoookJP03oookJP0<ond0oonMo`3ooo]Zool0g?mG0?oooo]Zoi<0ooo/o`3o
o`00oookJ_oMo`3od_l00ooonfX01?oo703ooo]Zo`3oU_oo04l4oookJP03o`3oRooonf[o0?ne00?o
oo]Z00ooo`2eoookJ_oo803ooo]Zo`P0ool0ocSood40og_o0?oo2P3o:P3oool0X?oonf[oo`3bo`3o
8Ol0oj800_oo_`002_oonf[oUol0ogT0oooonf[o0000o`3oB?oo0?Ko0?nnoe[o0?oRo`04oookJP05
of;o0?m/0?ooK03oof`0oooo3@000ooonfX6o`3oC@Koo`2Z1Ol0odd6oookJP03ool=0?ooh`3oK03o
00;oK03o00?oH_l0oookJ_oonfX02OoonfX01_oRo`3ooo]Zoe[o0?oonf[oo`3fo`03o`;ooo]Z0_l0
odP3oookJP04o`3oMomi0?ooobL0oiOo00Gooo]Z00Ko0:;ooono0?l0oj;o08cooookJ_l0ob43oook
JP03ool0l_l0oeKooo]Z00?ooo]Z00Koo`2Poe@0ool09Ooooo]ZobX0oooo2P04oookJP03og_o0?oo
nf[ood4000?ooo]Z00?o0?lho`P0oooonfX01_oonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooo
nf[ooo]Z00_ooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0?oookJP05ool0Cooo
nf[ooo]ZoookJ_l0oiH01OoonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00Cod_l0oookJ_oo
nf[ogOl00_oonfX00ol[0?oooo]ZoookJP02oookJP04oonK0?oo003oo`2Yonco00Cooo]Z00?oT`3o
oookJ_oonfX01_oonfX00omG0?oooo]ZoookJP0NoookJP00:_oonfX00ol0oo3ooo]ZoookJP04oook
JP03oooX0?oonf[oo`0;00Cooo]Z00[oocD0o`21oooonf[o=ol0oookJ_l0oiOooo]Zo`3oj?oonf[o
=_l03_oonfX00ol0hooooo]Zooo90008oookJPWoiOl01ooonfX00ooo6P3o7@3oo`3olP02oookJP?o
ogT000?oojL0oookJ_oonfX01OoonfX01?l0o`Wooo]ZoookJ_oonfX9oiCo0005oookJ_l0nooooo]Z
oookJ_nDo`000_oonfX01Ooo01Cooo]ZoookJ_oonf[oolL000Cooo]Z00GoojP0ool0Yooonf[ooo]Z
oolQ0005oookJP09o`3oUooonf[ooo]Zohko0?oo03Wooo]Zo`3o`?oonf[oo`0700gooo]Z1Ooob@00
1?mi0?oo^?l0ooo90?oo0;`2oookJP03oiCo0?oonf[ooo]Z00?ooo]Z00cok@3ooigo0?oo0=cooo]Z
oeL0oooonf[oT`3oool0ZOoo003ooo]Zomgo0?oBo`03oookJP05okSo0?oo703oA?l0odCo0?oo04l0
0ooonfX3odCo000Do`3o]Ooonf[ooo]ZoookJ_oo0;Goob00oookJ_m4o`3o0?lhoom10?mko`3o04co
obX0oom4o`3oo`2PodCo0?oo0?;o0?lQo`3oX_oo_`02odCo0004o`3oMomi0?ooA?l0odCo00?o0?l<
00?oF_l0on;o0?oonfX00_m4o`000ol0o`coA?l0odCo0003of`0o`;oA?l01?l0o``3onGo0003odCo
0?oUo`3oiOl000SoiOl00_m4o`02oooS00;oK03o00?ooo]Zof;o0?mRo`002ooonfX8oiCo0003oook
J_l0odSooo]Z00;ooo]Z00Go0?mgoookJ_mi0?oooo]ZoiOo0005oookJP06o`2Roooo_`3ooo]Zo`3o
X_oonf[o0?lQ0ooonfX00ooo0?;ooo]Zo`3oEP02oookJP03ool0X?oonf[oE03o00;ooo]Z00?o:P3o
ool:0?oUo`000ooonfX01?mko`3ooo]ZoookJ_oo@@02oookJP03o`3o>?l80?oooo]Z00Oooo]Z00Go
ob00oookJ_oonf[ooo]Zool0]@0>oookJP03o`3o]Ooonf[ooo]Z00;ooo]Z00?o0?n;oookJ_oonfX0
3_oonfX4onGo0003oookJ_l0oiKooo]Z00Gooo]Z00Cooa`0oookJ_oonf[o^?l03OoonfX01OoBo`3o
oo]Zomgo0?oonf[o:`3o00Gooo]Z0_oUo`001?oonf[ok?l0oookJ_oonfX7onGo0003oookJ_oob@3o
olT000?oolT0A_oonfX00ol0oo3ooo]ZoookJP04oookJP03oooX0?oonf[oo`0;00Cooo]Z00CoocD0
oookJ_l0POoo=ol00_oonfX01Ol0oiOooo]Zo`3oj?oonf[o=_l000gooo]Z00?o0>?ooookJ_oo0>`0
3?oonfX00ol0ongooo]ZoookJP0:oookJP03oolJ0?lM0?oooo]Z00?ooo]Z00?oo`2doookJ_ooY`00
1ooonfX01_l0o`Wooo]ZoookJ_oonf[oO03oocCo00;ooo]Z00Ko00_ooookJ_oonf[o/?l0oookJ_l0
nol2oookJP04odh0oooonf[ooo]Zool050?ooo]Z00?oolL0oookJ_oonfX00_oonfX01OooZ03oo`2W
oookJ_oonf[oob4000Gooo]Z00Wo0?nGoookJ_oonf[ooo]Zohko0?oo03Wooo]Zo`3o`?oo00L04?oo
nfX01_oo03Sooo]ZogT0oooonf[o^?l0ool0_0;ooo]Z00?oK03ooookJ_oonfX00ooonfX03?o]0?oo
oo]Zoigo0?oo0=coE`3ooong0?oonf[oT`3oool00?ooV`3o:`3oomgo00?ooo]Z00Go^?l0oolL0?l0
oiKooo]Zool0C`04oookJP03o`3oRooonf[o0?ne00?ooo]Z00[oo`2eoolP0?oonf[ooo]Zo`P0ool0
ocSoNol0oookJ_lZ0?ooE03o0_oo0:002?oo0?;o0?lQo`3oX_l0X_oookl0oookJ_nGo`3oN@3o0_l0
00001Ol0odSoo`3foookJ_mJo`3oh_l000Gooo]Z0_mRo`03of`0o`03ool=0?oonf[ooo]Z00Cooo]Z
1_l0odd8oookJP03ool=0?ooh`3oK03o00;oK03o0_mRo`0<oookJP06on;o0?oonf[oF_l0oookJ_oo
0?Ko00?o0_oonfX00ol0odSooo]ZoookJP02oookJP04o`3oMomi0?ooobL0oiOo00Gooo]Z00Ko0:;o
oono0?oonf[o0?nRo`2<ool0ob43oookJP03ool0l_oonf[o0?mF00?ooo]Z00Ooo`2PoookJ_mD0?oo
oo]ZobX0oooo2P3o04co00?ooo]Z00CoNol0oookJ_oonf[ood400ooonfX00ol0ocSooo]ZoookJP06
oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX02ooonfX00ol0okGooo]ZoookJP03
oookJP03o`3oRooonf[ooo]Z00oooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP05oookJP05oolL0?oo
nf[ooo]ZoookJ_nho`003?oonfX01_oBo`3ooo]ZoookJ_oMo`3ooo]Zob/0o`Gooo]Z00Coo`00oook
J_oo0:Wok?l01?oonfX00onC0?oooo]ZoookJP05oookJP03oong0?mG0?oooo]Z01oooo]Z000Zoook
JP03o`3ol?oonf[ooo]Z00Cooo]Z00?oonP0oookJ_oo00/01?oonfX02_oo=@3o087ooookJ_lgo`3o
oo]Zo`3oUooonf[o0?oXoookJ_lfo`0>oookJP04o`3Soooonf[oolT0ooo900_ooo]Z00?oiOl0oook
J_oonfX02OoonfX00ooo6P3o7@3oo`3olP02oookJP?oogT000?oojL0oookJ_oonfX01OoonfX01?l0
o`Wooo]ZoookJ_oonfX5oiCo00?ooo]Z00?o/?l0oookJ_l0nol00_oonfX01?nDo`3ooo]ZoookJ_nD
o`03oookJP03ooo70?oonf[ooo]Z00;ooo]Z00KoojP0ool0Yooonf[ooo]Zool0]?oo8@04oookJP09
o`3oUooonf[ooo]Zohko0?oonf[oo`0io`3o`?oonf[oo`0700gooo]Z1?oob@001Ooonf[oN@3ooook
J_nho`3oo`2l00;ooo]Z00?oU?l0oookJ_oonfX00ooonfX03Oo]0?oooo]Zoigo0?oo0=coE`3ooook
J_nC0?oooo]Zonco0?oo003ooo]Zomgo0?oBo`000_oonfX01Onho`3ooa`0odCo0?m4o`3oo`1?00?o
oo]Z1?m4o`03oookJP0>ool0]Ooo803ooo]ZoookJ_m4o`3o0?lhoom10?mko`3o:P3oool:0?m4o`3o
o`2PodCo0?oo0?82o`3o8@05oono0?m4o`3oA?l0o`3oMomi0?l00_nDo`001?l0o`coU?l0o`3o__mJ
o`02on;o00OoA?l01?m/0?l2o`3o3003ool=0?oonf[ooo]Z00[oiOl000?oA?l0oooS0?m/0?l00_m/
0?l00om4o`3ooo]Zof;o000<oookJP[oU?l00ooonfX01Ol0ogOooo]ZogT0oooonf[oUol000Gooo]Z
00Co0:;ooono0?oonf[o0?nR0_oonfX01_l0ob7ooo]ZoookJ_oo0?;ooo]Zo`3oEP;ooo]Z00Soo`2P
oookJ_mD0?oo02GooookJ_oUo`3o:P3oool:00?ooo]Z00CoNol0oookJ_oonf[ood400ooonfX00ol0
ocSooo]ZoookJP06oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX03?oonfX00ol0
okGooo]ZoookJP02oookJP03o`3oRooonf[ooo]Z00kooo]Z1?oUo`000ooonf[o0?nFoookJP05oook
JP04oolL0?oonf[ooo]ZokSo00cooo]Z00Kod_l0oookJ_oonf[ogOl0oookJ_l[0?l5oookJP;oiOl0
00Coo`2Yonco0?oonf[ooo]Z1_oUo`02oookJPGoolT0A_oonfX00ol0oo3ooo]ZoookJP04oookJP03
oooX0?oonf[oo`0;00Gooo]Z00?oocD0o`21oolgo`000_oonfX01Ol0oiOooo]Zo`3oj?oonf[o=_l0
00gooo]Z00?o0>?ooookJ_oo0>`03?oonfX00ol0ongooo]ZoookJP0:oookJP03oolJ0?lM0?oooo]Z
00?ooo]Z00?oo`2doookJ_ooY`001ooonfX02Ol0o`Wooo]ZoookJ_oonf[oO03oo`0]ooldo`3ooo]Z
o`0;o`02oookJP03ok3o0?oonf[o0?_o00;ooo]Z00CoCP3ooookJ_oonf[oo`0D0ooonfX00oooa`3o
oo]ZoookJP02oookJP06oonX0?oo0:Oooo]ZoookJ_oo0;Coob401OoonfX02Ol0oiOooo]ZoookJ_n>
o`3oo`0ioookJ_l0ol3ooo]Zool01`0@oookJP05ool0>?mi0?oooo]ZokSo0?oo0;`00_oonfX00om/
0?oooo]ZoookJP04oookJP0<ond0oonMo`3ooo]ZoeL0oooo]`3ooo]Zoi<0ooo/o`3oo`00oookJ_oM
o`3od_l00ooonfX01?oo703ooo]Zo`3oU_oo04l4oookJP03o`3oRooonf[o0?ne00?ooo]Z00?oo`2e
oookJ_oo80000_oonfX02Ol0ocSood40og_o0?oonf[o:P3ooe@0oooonf[oo`2Pool0lP02o`3o8@08
o`2Roooo_`3ooo]ZoiOo0?mi0?oo0?mgo`000?l0odP2ool0mP03oe[o0?l0okkoh_l000Gooo]Z0_mR
o`001?oonf[oK03oof`0oom/0?l3ool=00cooo]Z0_oo3@03of`0o`;ooo]Z00?oH_l0oookJ_oonfX0
2_oonfX2on;o00;oF_l000?ooo]Zool0m_l00ol00_oonfX00ol0odSooo]ZoookJP02oookJP04o`3o
Momi0?ooobL0oiOo00Kooo]Z00Kookl0oookJ_l0oj;o08cooookJ_l0ob42oookJP03ool0l_oonf[o
0?mF00?ooo]Z00Ooo`2PoookJ_mD0?oo02GooookJ_lZ0?ooo`X000?ooo]Z00CoNol0oookJ_oonf[o
od400ooonfX00ol0ocSooo]ZoookJP06oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?oo`2eoookJ_oo
nfX02ooonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z00kooo]Z00Goo`1?oookJ_oo
nf[ooo]Zo`3oUP06oookJP04oolL0?oonf[ooo]ZokSo00cooo]Z00Cod_l0oookJ_oonf[ogOl00_oo
nfX00ol[0?oooo]ZoookJP03oookJP03ool00?oo0:Wok?l000Gooo]Z00?oT`3ooookJ_oonfX01Ooo
nfX00ooo]`3oE`3ooookJP0OoookJP00:_oonfX00ol0oo3ooo]ZoookJP04oookJP03oooX0?oonf[o
o`0;00Gooo]Z00GoocD0o`21oolgo`3ooo]Zo`3oU`02oookJP03o`3oj?lfo`3ooo]Z00gooo]Z00Co
0>?ooookJ_oob@3oolT02ooonfX00ooUo`3ooo]ZoookJP09oookJP03oolJ0?lM0?oo0?ob00;ooo]Z
0oooN@000oooY`3oogT0oookJP05oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z00CoO03oocCo0?l0;Ooo
U?l00ooonfX00on`o`3ooo]Zo`3ko`02oookJP04oiCo0?oonf[ooo]ZoiCo00?ooo]Z00?oolL0oook
J_oonfX00_oonfX01_ooZ03oo`2WoookJ_oonf[oo`2doolQ00Cooo]Z00Wo0?nGoookJ_oonf[oS_l0
oookJ_oo03Wo0?o0oookJ_oo00L04OoonfX01Ooob@3oN@3ooookJ_nho`3oo`2l00;ooo]Z0_nDo`04
oookJP0=ond0oooonf[oWOl0ool0g?oonf[oE`3ooookJ_nC0?ook?l0ool00?oonf[ogOl0oiCo0003
oookJP05okSo0?oo703oA?l0odCo0?oo04l00_oonfX5odCo00?ooo]Z017oo`2eoolP0?oonf[oA?l0
o`3o>?m4o`3ood40og_o0?lZ0?ooo`X0odCo0?oo0:3oA?l0ool0l_m4o`3o0?lQoono0002odCo0003
oiOo0?mi0?ooU?l000CoU?l000?oF_l0o`3o__oRo`001_m4o`03of;o0004o`3o3?m/0?ooK03oof`0
o`_oon<00om/0?l3odCo00;oH_l02OoonfX2oiCo0003on;o0?nDo`3oU?l000OoU?l000Wo0?m8oook
J_oonf[ooo]Zo`3oMooonf[oN@3ooookJ_nGo`001OoonfX01?l0X_oookl0oookJ_l0oj82oookJP06
o`3o8Ooonf[ooo]ZoookJ_oo0?;o0?mF0_oonfX01?oo0:3ooo]ZoookJ_mD0?l2oookJP03obX0oooo
2P3ooo]Z00?ooo]Z00CoNol0oookJ_oonf[ood400_oonfX00ol0ocSo203ooookJP07oookJP05oolP
0?oonf[ooo]ZoookJ_oo0;D03_oonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z00ko
oo]Z0ooUo`000ooonf[o0?nFoookJP05oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX01ooB
o`3ooo]ZoookJ_oMo`3ooo]Zob/0oooonfX00ooUo`001?oonf[oiOl0onGo0?o/o`03oookJPKoiOl0
0_oonfX5ooo904Kooo]Z00?o0?o`oookJ_oonfX01?oonfX00oooj03ooo]Zool02`05oookJP03oole
0?l0POoo=ol000;ooo]Z00Go0?nGoookJ_l0onSooo]ZocKo000=oookJP03o`3Soooonf[oo`3/00co
oo]Z00?o0?o]oookJ_oonfX02_oonfX00ooo6P3o7@3ooookJP03oookJP03ool0]?oonf[oojL000Oo
oo]Z00Wo0?l9oookJ_oonf[ooo]Zog`0oooonf[o=?l0oookJ_l02ol00_oonfX00on`o`3ooo]Zo`3k
o`02oookJP04odh0oooonf[ooo]Zool050Cooo]Z00[oolL0oookJ_oonf[ooo]ZoonX0?oonf[oo`2W
oookJ_oo0;Coob401OoonfX02Ol0oiOooo]ZoookJ_n>o`3oo`0ioookJ_l0ol3ooo]Zool01`0@oook
JP05ool0>?mi0?oooo]ZokSo0?oo0;`00ooonfX00om/0?oooo]ZoookJP03oookJP0<ond0oonMo`3o
oo]Zool0g?mG0?oooo]Zoi<0ooo/o`3oo`00oookJ_l[0?oogOl00ooonfX01Onho`3ooa`0o`3oU_oo
nf[oo`1?00Cooo]Z00?o0?n;oookJ_l0okD00ooonfX06ooo0;Gooo]ZoolP0?oonf[o203oo`3o>?oo
@@3oNol0obX0oooo2P3oE03ooookJ_oo0:3oo`3boookJ_l0ob7o0:;ooono0?oonf[oUol0ogT0ool0
ogOo0000o`3oB?oonf[oo`3foe[o0002o`3o_P03on;o0?oonf[ooo]Z00?ooo]Z0omRo`001?oonf[o
K03oof`0oom/0?l;oooS00?oK03o0ooonfX2of;o00_ooo]Z0_oRo`001_oonf[oF_l0o`3o__oonf[o
o`3fo`03o`;ooo]Z00?o0?m8oookJ_oonfX00_oonfX01?l0ogOoN@3ooolW0?nGo`06oookJP03oono
0?oonf[o0?nR00;ooo]Z00Oo0?lQoookJ_oonf[ooo]Zool0l_oonf[o0?mF00;ooo]Z00Soo`2Poook
J_oonf[oE03ooookJ_lZ0?ooo`X0o`1<o`?ooo]Z00CoNol0oookJ_oonf[ood400ooonfX00ol0ocSo
oo]ZoookJP06oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX02ooonfX00ol0okGo
oo]ZoookJP03oookJP03o`3oRooonf[ooo]Z00oooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP05oook
JP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX01?oBo`3ooo]ZoookJ_oMo`02oookJP03ob/0oooo
nf[ooo]Z00;ooo]Z00Cooi/0ool00?oo0:Wok?l01?oonfX00onC0?oooo]ZoookJP06oookJP03oeL0
oooonf[ooo]Z01oooo]Z000ZoookJP03o`3ol?oonf[ooo]Z00Cooo]Z00?oonP0oookJ_oo00/01Ooo
nfX01Ooo=@3o087oocOo0?oonf[o0?nG00;ooo]Z00?o0?oXocKo0?oonfX03OoonfX00ol0hooooo]Z
ooo90002ooo900[ooo]Z00?oiOl0oookJ_oonfX02OoonfX00ooo6P3o7@3oo`3olP02oookJP?oogT0
00?oojL0oomi0?oonfX01OoonfX00ol0o`Wooo]ZoookJP02oookJP04og`0ooldo`3o02gooiCo00Co
oo]Z00Go/?l0o`3koooonf[ooo]Zodh0o`02oookJP;oU?l00_oonfX00oooa`3ooo]ZoookJP03oook
JP05oonX0?oonf[ooo]ZoookJ_oo8@001OoonfX02?l0oiOooo]Zohko0?oonf[oo`0io`3o`?oonf[o
o`074OoonfX01ooob@3ooo]ZogT0oonho`3ooo]Zool0_?oonfX00onDo`04oookJP0<ond0oonMo`3o
oo]Zool0g?mG0?oooo]Zoi<0oooonf[oo`00oookJ_l[0?oogOl00ooonfX01_nho`3ooa`0odCo0?m4
o`3oo`1?odCo00;ooo]Z1Om4o`03oookJP09ool0]Ooo803oA?l0odCo0?l0ocSoA?l0oom10?mko`3o
:P3o00;oA?l000Woo`2PodCo0?oo0?;oA?l0o`3o8Ol0oj;o0:;oodCo0?nGo`000_mi0?l4oiCo00;o
F_l000?ooo]ZodCo0?m4o`000om4o`03oookJP04of;o0?l0o`coH_l0oookJP_oK03o00?oiOl0odCo
0?m4o`000_m4o`000omRo`3oA?l0oookJP07oookJP_oU?l000?oA?l0o`3oB?m4o`000ooonfX01Ol0
ogOooo]ZogT0oooonf[oUol000Gooo]Z00Oo0:;ooono0?oonf[o08coo`3oX_oonf[o0?lQ00?ooo]Z
00?oo`3bo`3oE_oonfX00_oonfX01?oo0:3ooo]Zoe@0ool09Ol2oookJP03obX0oooonf[ooo]Z00;o
oo]Z00CoNol0oookJ_oonf[ood400ooonfX00ol0ocSooo]ZoookJP06oookJP03oolP0?oonf[ooo]Z
00;ooo]Z00?oo`2eoookJ_oonfX02ooonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z
00oooo]Z0ooUo`000ooonf[o0?nFoookJP05oookJP04oolL0?oonf[ooo]ZokSo00gooo]Z00God_l0
oookJ_oonf[ogOl0ob/0o`02oookJPKoiOl000Cok?l0oookJ_oonf[ooo]Z1OoUo`03oookJPGoolT0
A_oonfX00ol0oo3ooo]ZoookJP04oookJP03oooX0?oonf[oo`0;00Gooo]Z00?oocD0oookJ_l0POl0
0_oonfX01Ol0oiOooo]Zo`3oj?oonf[o=_l000gooo]Z00Co0>?ooookJ_oonf[oo`3/2ooonfX00ol0
ongooo]ZoookJP0:oookJP03oolJ0?lM0?oo0?ob00?ooo]Z00?oo`2doookJ_ooY`001ooonfX02Ol0
o`Wooo]ZoookJ_oonf[oO03ooookJ_ldo`3ooo]Zo`0;o`03oookJP05ok3o0?l0nooooo]ZoookJ_m>
0?l00_oonfX00ooo01Cooo]ZoookJP02oookJP03ooo70?oonf[ooo]Z00;ooo]Z00GoojP0ool0Yooo
nf[ooo]ZoolQ0005oookJP09o`3oUooonf[ooo]Zohko0?oo03Wooo]Zo`3o`?oonf[oo`07013ooo]Z
00Koo`0hoookJ_mi0?oooo]ZokSo0?oo0;`2oookJP03of`0oooonf[ooo]Z00?ooo]Z00cok@3ooigo
0?oonf[oo`3LoeL0oooo]`3ooo]Zoi<0oooo003ooi/0ob/0oooMo`03oookJP05okSo0?oo703ooo]Z
o`3oU_oo04l01OoonfX00ol0oh_o0?neoookJP03oookJP0Dool0]Ooonf[oob00oookJ_l80?oo0?lh
oom10?mko`3o:P3oo`1<oomD0?oooo]Zool0X?oo0?;ooo]Zo`3o8Ol0oj;ookl0o`000?nGo`02ogT0
o`04o`3oMol0odSo0?m8oookJP;oF_l000?o0?nnon;o0?oonfX01_oonfX4of;o00_oK03o00?ooo]Z
of;o0?mRo`000omRo`0;oookJP;oh_l000Oooo]Zoe[o0?mJo`3o0?nnoookJ_oo0?Ko00?o00;ooo]Z
00?o0?m8oookJ_oonfX00_oonfX01?l0ogOoN@3ooolW0?nGo`06oookJP06oono0?oonf[o08coo`3o
X_oonf[o0?lQ0ooonfX00ooo0?;ooo]Zo`3oEP02oookJP08ool0X?oonf[ooo]Zoe@0ool09Ooooo]Z
obX0ool0C?l3oookJP04og_o0?oonf[ooo]Zoom100?ooo]Z00?o203oo`3o>?oonfX01_oonfX00ooo
803ooo]ZoookJP03oookJP03ool0]Ooonf[ooo]Z00_ooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0
oh_ooo]ZoookJP0?oookJP04ool0Cooonf[ooo]Zo`3oUPKooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo
000<oookJP06om;o0?oonf[ooo]Zomgo0?oonf[o:`3o1OoonfX00ooo003ooo]Zonco0005oookJP03
oi<0oooonf[ooo]Z00Gooo]Z00?ookL0oeL0oooonfX08?oonfX002[ooo]Z00?o0?o`oookJ_oonfX0
1?oonfX00oooj03ooo]Zool02`05oookJP05oole0?l0POoo=ol0oookJ_l0oiL00_oonfX00ol0onSo
=_l0oookJP0=oookJP03o`3Soooob@3oolT000;oolT02ooonfX00ooUo`3ooo]ZoookJP08oookJP03
oolJ0?lM0?oo0?ob00;ooo]Z0oooN@000oooY`3oogT0oomi0006oookJP09o`3o2Ooonf[ooo]Zoook
J_ml0?oo=?l0o`0]oooo04ooU?l000?ooo]Z00Go/?l0o`3koooonf[ooo]Zodh0o`02oookJP;oU?l0
0_oonfX00oooa`3ooo]ZoookJP03oookJP05oonX0?oo0:Oooo]ZoookJ_oo8@001OoonfX02?l0oiOo
oo]ZoookJ_n>o`3oo`0io`3o`?oonf[oo`074OoonfX01ooo03Sooo]ZogT0oooonf[o^?l0ool0_?oo
nfX00onDo`04oookJP0=ond0oooonf[oWOl0ool0g?mG0?oookL0oookJ_nC0?ook?l0ool00?oonf[o
gOl0oiCo0003oookJP07odCo0?oo703oA?l0odCo0?oo04ooA?l0oookJP06odCo00;ooo]Z00Woo`2e
oolP0?oonf[oA?l0o`3o>?m4o`3ood40odCo0?mko`000_lZ0?l01omD0?ooo`2PodCo0?oo0?;oA?l0
o`3o8Ol0oj800_l0X_l00onDo`3oUol0ogT0o`05oiCo00;oF_l00om4o`07oookJP03of;o0?m4o`3o
A?l000WoA?l000?oiOl0odCo0?m4o`001?m4o`07oookJPWoU?l00om4o`000ol0odSoA?l0odCo0002
oookJP05o`3oMomi0?ooN@3ooookJ_nGo`001OoonfX01ol0X_oookl0oookJ_l0S?oo0?nRoookJ_l0
ob400ooonfX00ooo0?;o0?mFoookJP02oookJP04ool0X?oonf[ooo]Zoe@0o`;ooo]Z00?o:P3oool:
0?oonfX00ooonfX01?mko`3ooo]ZoookJ_oo@@02oookJP03o`3o>?l80?oooo]Z00Oooo]Z00?oob00
oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP0;oookJP03o`3o]Ooonf[ooo]Z00?ooo]Z00?o0?n;
oookJ_oonfX03ooonfX2onGo0003oookJ_l0oiKooo]Z00Kooo]Z00Cooa`0oookJ_oonf[o^?l03?oo
nfX01_oBo`3ooo]ZoookJ_oMo`3ooo]Zob/0o`;ooo]Z1_oUo`001?o/o`3oiOl0oookJ_oonfX5onGo
00?ooo]Z1Ooob@16oookJP03o`3ol?oonf[ooo]Z00Cooo]Z00?oonP0oookJ_oo00/01OoonfX00ooo
=@3ooo]Zo`21o`02oookJP05o`3oUooonf[o0?oXoookJ_lfo`003OoonfX01?l0hooooo]ZoookJ_oo
0>`<oookJP03o`3okOoonf[ooo]Z00Wooo]Z00?ooaX0oad0ool0oo800ooonfX00ooo0;Cooo]ZoonW
0008oookJP08o`3o2Ooonf[ooo]Zog`0oooonf[o=?l0oookJ_l02ol3oookJP05ok3o0?l0nooooo]Z
oookJ_m>0?l00ooonfX01Ooo01Cooo]ZoookJ_oonf[oolL000Cooo]Z00GoojP0ool0Yooonf[ooo]Z
oolQ0005oookJP09o`3oUooonf[ooo]ZoookJ_n>o`3ooo]Zo`3o`?oonf[oo`07013ooo]Z00Koo`0h
oookJ_mi0?oooo]ZokSo0?oo0;`2oookJP03of`0oooonf[ooo]Z00Cooo]Z00cok@3ooigo0?oonf[o
o`3LoeL0oooonf[oT`3oonco0?oo003ooo]Zomgo0?oBo`03oookJP05okSo0?oo703ooo]Zo`3oU_oo
04l01?oonfX00ol0oh_ooo]Zo`3o]@04oookJP08ool0]Ooo803ooo]ZoookJ_l0ocSood40oookJ_mk
o`02obX0o`0Aoe@0oooonf[oo`2Pool0l_oonf[o0?lQo`3oX_oo_`3o0:;oo`000?nGo`3oN@3oo`3o
Mooonf[o0?m8o`03oooonfX00omJo`000ooRo`3ooo]ZoookJP07oookJPcoH_l03_oonfX2on;o0005
oookJ_mJo`3oF_l0o`3o__oonfX00_oo0?H01?l00ooooo]ZoookJ_l0odP4oookJP;oN@3o00?oobL0
oiOo0?oonfX01OoonfX01_oo_`3ooo]Zo`2<ool0oj;ooo]Zo`3o8@?ooo]Z00?oo`3boookJ_l0oeH0
0_oonfX02Ooo0:3ooo]ZoookJ_mD0?oo02GooookJ_lZ0?ooo`X0o`1<o`03oookJP04og_o0?oonf[o
oo]Zoom100?ooo]Z00?o0?lhoookJ_oonfX01_oonfX00ooo803ooo]ZoookJP03oookJP03ool0]Ooo
nf[ooo]Z00[ooo]Z00?o0?neoookJ_oonfX01?oonfX00ol0oh_ooo]ZoookJP0>oookJP05ool0Cooo
nf[ooo]ZoookJ_l0oiH01_oonfX01?oo703ooo]ZoookJ_nho`0<oookJP07om;o0?oonf[ooo]Zoook
J_oMo`3ooo]Zob/0o`05oookJP03ool00?oonf[ok?l000Gooo]Z00?oT`3ooookJ_oonfX01OoonfX0
0ooo]`3oE`3ooookJP0PoookJP00:_oonfX00ol0oo3ooo]ZoookJP04oookJP03oooX0?oonf[oo`0;
00Gooo]Z00GoocD0o`21oolgo`3ooo]Zo`3oU`02oookJP03o`3oj?lfo`3ooo]Z00gooo]Z00?o0>?o
ooo90?oob@000_oob@0;oookJP03onGo0?oonf[ooo]Z00Wooo]Z00Co7@3oo`3ol_oonf[ooo]Z0ooo
N@000oooY`3oogT0oomi0006oookJP09o`3o2Ooonf[ooo]ZoookJ_ml0?oo=?l0o`0]oooo04ooU?l0
00?ooo]Z00?o/?l0o`3koooonfX00_oonfX00om>0?oooo]ZoiCo0002oiCo00;ooo]Z00?oolL0oook
J_oonfX00_oonfX01OooZ03oo`2WoookJ_oonf[oob4000Gooo]Z00Wo0?nGoookJ_oonf[oS_l0ool0
>Ooonf[o0?o0oookJ_oo00L04OoonfX01_oo03SoN@3ooookJ_nho`3oo`2loookJPCoU?l00ooonfX0
3?o]0?oooo]ZoiCo0?oonf[oo`3LoeL0oooonf[oT`3oonco0?oo003ooo]Zomgo00;oU?l00_oonfX0
0onho`3ooa`0odCo0002odCo0003ool0Com4o`3oA?l000KoA?l00_oonfX05_oo0;Goob00odCo0?m4
o`3o0?lhodCo0?oo@@3oA?l0og_o0?oo2P3o:P3ooe@0oooo0:3oA?l0ool0l_m4o`3o0?lQo`3oX_oo
_`3o0:;ooiCo0?nGo`02ogT0o`GoU?l000?o0?nnodCo0?mJo`002?m4o`03oookJPooA?l01OoonfX8
oiCo00GoA?l000?o0?m8odCo0?m4o`000_m4o`001Ol0ogOoN@3ooolW0?oonf[oUol000?ooo]Z00Wo
U?l0o`2Rool0X_oookl0oookJ_l0S?oo0?nRoookJ_l0ob400ooonfX00ooo0?;o0?mFoookJP02oook
JP04ool0X?oonf[ooo]Zoe@0o`;ooo]Z00?o:P3oool:0?oonfX00ooonfX01?mko`3ooo]ZoookJ_oo
@@03oookJP03o`3o>?oonf[ooo]Z00Kooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]Zoook
JP0;oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX03ooonfX01?oUo`3ooo]Zoook
J_l0oiH6oookJP04oolL0?oonf[ooo]ZokSo00gooo]Z00Kod_l0oookJ_oonf[ogOl0oookJ_l[0?l2
oookJPSoiOl00_oonfX4onGo00Cooo]Z1Ooob@16oookJP03o`3ol?oonf[ooo]Z00Cooo]Z00?oonP0
oookJ_oo00/01OoonfX00ooo=@3ooo]Zo`21o`02oookJP05o`3oUooonf[o0?oXoookJ_lfo`003Ooo
nfX01?l0hooooo]ZoookJ_oo0>`<oookJP03o`3okOoonf[ooo]Z00[ooo]Z00?o7@3oo`3ol_oonfX0
0_oonfX00ooo0;Cooo]ZoonW0008oookJP09o`3o2Ooonf[ooo]Zog`0oooonf[o=?l0oookJ_l02ooo
o`0H00;ooo]Z00?o/?l0o`3koooonfX00_oonfX01?m>0?oooo]ZoookJ_oo01@3oookJP03ooo70?oo
nf[ooo]Z00;ooo]Z00GoojP0ool0Yooonf[ooo]ZoolQ0005oookJP09o`3oUooonf[ooo]ZoookJ_n>
o`3oo`0ioookJ_l0ol3oo`07017ooo]Z00Goo`0hogT0oooonf[o^?l0ool0_003oookJP03of`0oooo
nf[ooo]Z00?ooo]Z00Gok@3ooigo0?oonf[oo`3LoeL0o`02oookJP05oi<0oooo003ooi/0ob/0oooM
o`000ooonfX01_nho`3ooo]ZoolL0?l0oiKooo]Zool0C`Cooo]Z00?o0?n;oookJ_l0okD01?oonfX0
2_oo0;Goob00oookJ_oonf[o0?lhoom10?oonf[oNol0ool:0?lZ0?l2oe@0o`05ool0X?oo0?;ooo]Z
o`3o8Ol0oj800_oo_`001Ol0003oUol0ogT0oomi0?oooo]Z00;o0?m800?o00?oool0m_oo0?H00_mJ
o`02on;o01kooo]Z0_oRo`001Ooonf[o0?nnoe[o0?l0okkooo]Z00;oo`3f0_l00ol2oookJP03o`3o
B?oonf[ooo]Z00;ooo]Z00CoN@3ooookJ_oo9`3oUol01OoonfX01ol0X_oookl0oookJ_l0S?oo0?nR
oookJ_l0ob400ooonfX00ooo0?;ooo]Zo`3oEP03oookJP08ool0X?oonf[oE03oo`0Uoooonf[o:P3o
ool:0?l0C?l3oookJP04og_o0?oonf[ooo]Zoom100?ooo]Z00?o203oo`3o>?oonfX01_oonfX00ooo
803ooo]ZoookJP03oookJP03ool0]Ooonf[ooo]Z00_ooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0
oh_ooo]ZoookJP0?oookJP04ool0Cooonf[ooo]Zo`3oUPKooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo
000<oookJP04om;o0?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX00_oonfX01?ooV`3oo`00
ool0ZOo/o`05oookJP03oi<0oooonf[ooo]Z00Gooo]Z00?ookL0oeL0oooonfX08?oonfX002[ooo]Z
00?o0?o`oookJ_oonfX01?oonfX00oooj03ooo]Zool02`05oookJP05oole0?l0POoo=ol0oookJ_l0
oiL00_oonfX00ol0onSo=_l0oookJP0=oookJP03o`3Soooob@3oolT000?oolT02_oonfX00ooUo`3o
oo]ZoookJP09oookJP04oad0ool0oo;ooo]ZoookJPCoogT000?oojL0oomi0?ooN@001OoonfX00ol0
o`Wooo]ZoookJP02oookJP04ocCo0?l0;Oooo`1?oiCo00?ooo]Z00?o/?l0oookJ_l0nol00_oonfX0
0om>0?oooo]ZoiCo0002oiCo00;ooo]Z00?oolL0oookJ_oonfX00_oonfX01OooZ03oo`2WoookJ_oo
nf[oob4000Gooo]Z00Wo0?nGoookJ_oonf[oS_l0oookJ_oo03Wo0?o0oookJ_oo00L04OoonfX01_oo
03Sooo]ZogT0oonho`3oo`2loookJPGoU?l00ooonfX02Oo]0?ooU?l0oookJ_oo0=coE`3ooong0?oo
nf[oT`3oool00002oookJP03omgo0?nDo`3oU?l000;ooo]Z00GoA?l0oolL0?m4o`3oA?l0ool0C`09
odCo00;ooo]Z00coo`2eoolP0?m4o`3oA?l0o`3o>?m4o`3ood40odCo0?mko`3oo`X0obX0oom4o`02
ool0X006ool0l_m4o`3o0?lQo`3oX_oo_`3o0:;o0_nDo`000ol0ogOoN@3ooiCo0004oiCo0003ool0
m_l0okkoF_l000;oF_l05Om4o`05oookJPGoU?l000CoF_l0oiCo0?nDo`3oU?l01?m4o`02o`3oB0Co
A?l000?o0?mgogT0oooo9`000_nGo`03oookJP05oiCo0?l0X_oooo]Zoono0?oonfX00_l0oj800ooo
nf[o0?lQoookJP02oookJP03ool0l_l0oeKooo]Z00;ooo]Z00Coo`2PoookJ_oonf[oE03o0ooonfX0
0olZ0?ooo`X0oookJP02oookJP05og_o0?oonf[ooo]ZoookJ_oo@@000_oonfX00ol0ocSo203ooook
JP07oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX02ooonfX00ol0okGooo]Zoook
JP03oookJP03o`3oRooonf[ooo]Z013ooo]Z00?oo`1?oookJ_l0oiH01ooonfX01?oo703ooo]Zoook
J_nho`0=oookJP06om;o0?oonf[ooo]Zomgo0?oonf[o:`3o0_oonfX8onGo00;ooo]Z1?oUo`04oook
JPGoolT0A_oonfX00ol0oo3ooo]ZoookJP05oookJP03oooX0?oo00_ooo]Z00Cooo]Z00?oocD0oook
J_l0POl00_oonfX01Ol0oiOooo]Zo`3oj?oonf[o=_l000gooo]Z00Co0>?ooookJ_oonf[oo`3/3?oo
nfX00ol0ongooo]ZoookJP0:oookJP03oad0ool0oo;ooo]Z00?ooo]Z00?oo`2doonW0?oonfX01ooo
nfX02Ol0o`Wooo]ZoookJ_oonf[oO03oocCo0?oonf[o00_oool06002oookJP03ok3o0?oonf[o0?_o
00;ooo]Z00CoCP3ooookJ_oonf[oo`0D0ooonfX00oooa`3ooo]ZoookJP02oookJP05oonX0?oo0:Oo
oo]ZoookJ_oo8@001_oonfX02Ol0oiOooo]ZoookJ_n>o`3oo`0ioookJ_l0ol3ooo]Zool01`0@oook
JP05ool0>?oonf[oN@3ooookJ_oo0;`00ooonfX00om/0?oooo]ZoookJP04oookJP0<ond0oooonf[o
oo]Zool0g?mG0?oooo]Zoi<0oooo003ooi/0oookJ_oMo`3od_l00ooonfX01Onho`3ooa`0oookJ_l0
oiKoo`1?00Cooo]Z00?o0?n;oookJ_l0okD01?oonfX00ooo0;Gooo]ZoolP0002oookJP08o`3o>?oo
@@3ooo]Zog_o0?oo2P3o:P3oo`0UoomD0?l2ool0X005oookJ_l0ob7o0?nRo`3oX_oo_`000_oonfX0
1?nGo`3oN@3oogT0oooonfX2o`3oB003o`03oooo0?Koo`3f00?oF_l00ooRo`0GoookJP?oh_l000Go
oo]Zo`3o__mJo`3oF_l0oookJP02ool0mP;o00?o0_oonfX2o`3oB0Cooo]Z00CoN@3ooolW0?nGo`3o
Uol01OoonfX00ol0X_oookl0oookJP02o`3oXP03oookJ_l0ob7ooo]Z00;ooo]Z00?oo`3boookJ_l0
oeH00ooonfX01?oo0:3ooo]Zoe@0ool09Ol2oookJP03obX0oooo2P3ooo]Z00;ooo]Z00GoNol0oook
J_oonf[ooo]Zoom10003oookJP03o`3o>?oonf[ooo]Z00Kooo]Z00?oob00oookJ_oonfX00ooonfX0
0ooo0;Gooo]ZoookJP0:oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX03ooonfX0
1?oo04oooo]ZoookJ_l0oiH6oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX01?oBo`3ooo]Z
oookJ_oMo`02oookJP03ob/0oooonf[ooo]Z00;ooo]Z00?oo`00oookJ_o/o`001OoonfX00onC0?oo
oo]ZoookJP05oookJP03oong0?mG0?oooo]Z027ooo]Z000UoookJP03obT0oooonf[ooo]Z00;ooo]Z
00?o0?o`oookJ_oonfX01OoonfX00oooj03oo`0;oookJP04oookJP05oole0?l0POoo=ol0oookJ_l0
oiL00_oonfX00ol0onSooo]ZocKo000=oookJP03o`3Soooob@3oolT000?oolT02_oonfX00ooUo`3o
oo]ZoookJP09oookJP04oad0ool0oo;ooo]ZoookJPCoogT000?oojL0oomi0?ooN@001OoonfX00ol0
o`Wooo]ZoookJP02oookJP04ocCo0?l0;Oooo`1?oiCo00?ooo]Z00?o/?l0oookJ_l0nol00_oonfX0
0om>0?oooo]ZoiCo0003oiCo0003oookJ_ooa`3ooo]Z00?ooo]Z00GoojP0ooo90?oonf[ooo]ZoolQ
0005oookJP09o`3oUooonf[ooo]ZonGo0?oonf[oo`0io`3o`?oonf[oo`07017ooo]Z00Koo`0hoook
J_mi0?oo^?l0oookJ_oo0;`5oiCo00?ooo]Z00cok@3ooiCo0?nDo`3ooo]Zool0g?mG0?oooo]Zoi<0
ooo/o`3oo`00oookJ_oMo`03oiCo0003oookJ_m4o`3ooa`000?oA?l000?oo`1?odCo0?m4o`001om4
o`004_oonf[oo`2eoookJ_oo803ooo]ZodCo0?l0ocSoA?l0oom10?m4o`3oNol0ool:0?lZ0?oo02Go
oe@0oooo0:3oo`3bo`0000;o0?lQ0_oo_`02oiCo0003oiOo0?mi0?oo0?mg00;oU?l00_l00ol01?oo
nf[oo`3fool0m_l0okh4oe[o00SoA?l00ooonfX6odCo00;ooo]Z00?oh_l0oiCo0?nDo`000_nDo`03
oe[o00GoU?l01om4o`000ol0ogOoN@3oogT0o`02oiOo00Cooo]Z00KoU?l0o`2RoonDo`3ookl0oook
J_l0oj82oookJP06o`3o8Ooonf[ooo]ZoookJ_oo0?;o0?mF1?oonfX00ooo0:3ooo]Zoe@0o`03oook
JP03obX0oooo2P3ooo]Z00?ooo]Z00CoNol0oookJ_oonf[ood400ooonfX00ol0ocSooo]ZoookJP06
oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX02ooonfX00ol0okGooo]ZoookJP04
oookJP03o`3oRooonf[ooo]Z00oooo]Z00Coo`1?oookJ_oonf[o0?nF1_oonfX01Ooo703ooo]Zoook
J_oonf[o^?l000cooo]Z00Kod_l0oookJ_oonf[ooo]Zomgo0?l[0?l3oookJPOoiOl00ooonfX3onGo
00Gooo]Z1Ooob@11oookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01OoonfX00ooo
j03oo`0;oookJP04oookJP03oole0?oonf[o087o00;ooo]Z00Go0?nGoookJ_l0onSooo]ZocKo000=
oookJP04o`3Soooonf[ooo]Zool0k0cooo]Z00?o0?o]oookJ_oonfX02_oonfX00olM0?oo0?oboook
JP03oookJP03ool0]?ooY`3ooo]Z00Oooo]Z00Wo0?l9oookJ_oonf[ooo]Zog`0ooldo`3ooo]Zo`0;
oooo01P00_oonfX00on`o`3ooo]Zo`3ko`02oookJP04odh0oooonf[ooo]Zool050?ooo]Z00?oolL0
oookJ_oonfX00_oonfX01OooZ03oo`2WoookJ_oonf[oob4000Kooo]Z00Wo0?nGoookJ_oonf[oS_l0
ool0>Ooonf[o0?o0oookJ_oo00L04?oonfX01_oo03Sooo]ZogT0oooonf[o^?l0ool0_0;ooo]Z00?o
K03ooookJ_oonfX01?oonfX03?o]0?ooWOl0oookJ_oo0=coE`3ooookJ_nC0?ook?l0ool00?ooV`3o
:`3oomgo00Cooo]Z00Go^?l0oolL0?l0oiKooo]Zool0C`04oookJP03o`3oRooonf[o0?ne00Cooo]Z
00Koo`2eoookJ_oo803ooo]Zo`P0ool0ocP2oom10008og_o0?oo2P3o:P3ooookJ_mD0?oooo]Zool0
X?l00002o`3o8@03o`3oX_oo_`3ookl000;ooo]Z00GoUol0ogT0ool0ogOooo]Zo`3oB002o`03o`?o
o`3f1?mJo`03on;o013ooo]Z0ooRo`02oookJP?oF_l00_oonfX3o`03o`;ooo]Z0_l0odP4oookJP;o
N@3o0_nGo`06oookJP04o`2Roooo_`3ooo]Zo`3oXP;ooo]Z00Oo0?lQoookJ_oonf[ooo]Zool0l_oo
nf[o0?mF00?ooo]Z00Coo`2PoookJ_mD0?oo02Go0_oonfX00olZ0?ooo`X0oookJP03oookJP04og_o
0?oonf[ooo]Zoom100?ooo]Z00?o203oo`3o>?oonfX01_oonfX00ooo803ooo]ZoookJP03oookJP03
ool0]Ooonf[ooo]Z00[ooo]Z00?o0?neoookJ_oonfX01OoonfX00ol0oh_ooo]ZoookJP0>oookJP05
ool0Cooonf[ooo]ZoookJ_l0oiH01OoonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00Ood_l0
oookJ_oonf[ooo]Zomgo0?oonf[o:`3o00Gooo]Z00?oo`00oookJ_o/o`001OoonfX00onC0?oooo]Z
oookJP05oookJP03oong0?mG0?oooo]Z027ooo]Z000UoookJP03obT0oooonf[ooo]Z00;ooo]Z00?o
0?o`oookJ_oonfX01OoonfX00oooj03oo`0;oookJP04oookJP05oole0?l0POoo=ol0oookJ_l0oiL0
0_oonfX00ol0onSooo]ZocKo000=oookJP03o`3Soooob@3oolT000CoolT02OoonfX00ooUo`3ooo]Z
oookJP09oookJP03oad0ool0oo;ooo]Z00GoogT000?oojL0oomi0?ooN@001OoonfX00ol0o`Wooo]Z
oookJP02oookJP04ocCo0?l0;Oooo`1?oiCo00?ooo]Z00?o/?l0oookJ_l0nol00_oonfX00om>0?oo
oo]ZoiCo0003oiCo0003oookJ_ooa`3ooo]Z00Cooo]Z00GoojP0oookJ_oonf[oo`2doolQ0004oook
JP09o`3oUooonf[ooo]ZonGo0?oonf[oo`0ioookJ_l0ol3oo`0701;ooo]Z00Koo`0hogT0oooonf[o
^?l0ool0_?oonfX5oiCo00?ooo]Z00cok@3ooiCo0?nDo`3oo`3LoeL0oooonf[oT`3ooookJ_oo003o
oo]Zomgo0?l[0?l3oiCo00;oA?l000Gooa`0odCo0?m4o`3oA?l0ool0C`09odCo0004oookJ_oo0;Go
oo]ZoolP00;oA?l000[o0?lhodCo0?oo@@3oA?l0og_o0?oo2P3o:P3oo`0UoomD0?ooo`2P0_oo0?80
0ol0003o0?lQo`2<o`02oono0005oiCo0?nGo`3oN@3oogT0ool0ogL00ol0odP2o`03o`03oookJ_oo
0?KoA?l000;o0?nn1omJo`000om4o`3ooo]ZoookJP03oookJP;oh_l00_m4o`02on;o00;oU?l00omJ
o`07oiCo00CoA?l00_oonfX2o`3oM`04ogT0oooo9`3oUol0oookJP;oU?l00_oonfX01_nDo`3o0:;o
oiCo0?oo_`3oU?l0o`3oXP;ooo]Z00Ko0?lQoiCo0?oonf[ooo]Zool0l_l0oeH4oookJP03ool0X?oo
nf[oE03o00?ooo]Z00?o:P3oool:0?oonfX00ooonfX01Omko`3ooo]ZoookJ_oo@@3ooi`000;ooo]Z
00?o0?lho`P0oooonfX01_oonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z00_ooo]Z
00?o0?neoookJ_oonfX01?oonfX00ol0oh_ooo]ZoookJP0?oookJP05ool0Cooonf[ooo]ZoookJ_l0
oiH01_oonfX01?oo703ooo]ZoookJ_nho`0=oookJP06om;o0?oonf[ooo]Zomgo0?oonf[o:`3o0ooo
nfX6onGo00Cooo]Z0ooUo`05oookJP?oolT000?ooo]Zooo90?oonfX0@?oonfX00olY0?oooo]Zoook
JP02oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0ool02ooonfX01?oonfX00ooo=@3ooo]Zo`21
o`02oookJP05o`3oUooonf[o0?oXoookJ_lfo`003OoonfX01?l0hooooo]ZoookJ_oo0>`<oookJP03
o`3okOoonf[ooo]Z00[ooo]Z00?o7@3oo`3ol_oonfX00ooonfX00ooo0;CoojL0oookJP07oookJP09
o`3o2Ooonf[ooo]ZoookJ_ml0?oo=?l0oookJ_l02oooo`0H00;ooo]Z00?o/?l0oookJ_l0nol00_oo
nfX01Om>0?oooo]ZoookJ_oonf[oo`0D00?ooo]Z00?oolL0oookJ_oonfX00_oonfX01OooZ03ooo]Z
oookJ_oo0;Coob4000Gooo]Z00Go0?nGoookJ_oonf[oS_l0ool0>@02oookJP03o`3o`?oo00Oooo]Z
013ooo]Z00Goo`0hogT0oooonf[o^?l0ool0_003oookJP03of`0oooonf[ooo]Z00Cooo]Z00cok@3o
oookJ_oo0=cookL0oeL0oooonf[oT`3oool00?ooV`3ooo]Zomgo0?oBo`03oookJP06okSo0?oo703o
oo]Zo`3oU_oonf[oo`1?0ooonfX00ol0oh_ooo]Zo`3o]@05oookJP0Dool0]Ooonf[oob00oookJ_l8
0?oo0?lhoonL0?oo@@3oNol0ool:0?lZ0?oooo]Zoe@0oooonf[oo`2Pool0l_l0003o0?lQo`3oX_l0
S?l2oono0005oookJ_nGo`3oN@3oogT0ool0ogL00_l0odP3o`03o`?oo`3f00?o0?nnoe[o0?mJo`00
1OmJo`000ooRo`3ooo]ZoookJP03oookJPKoh_l00_oonfX3oe[o00?ooo]Z0_l00ol3oookJP;o0?m8
1?oonfX01?l0ogOoN@3ooolW0?nGo`07oookJP04o`2Roooo_`3ooo]Zo`3oXP;ooo]Z00Oo0?lQoook
J_oonf[ooo]Zool0l_oonf[o0?mF00?ooo]Z00Coo`2PoookJ_mD0?oo02Go0_oonfX00olZ0?ooo`X0
oookJP03oookJP05og_o0?oonf[ooo]Zoom10?ooW0000ooonfX00ol0ocSooo]ZoookJP05oookJP03
oolP0?oonf[ooo]Z00?ooo]Z00?oo`2eoookJ_oonfX02ooonfX00ol0okGooo]ZoookJP04oookJP03
o`3oRooonf[ooo]Z00oooo]Z00Coo`1?oookJ_oonf[o0?nF1_oonfX01Ooo703ooo]ZoookJ_oonf[o
^?l000cooo]Z00Cod_l0oookJ_oonf[ogOl00_oonfX00ol[0?oooo]ZoookJP02oookJP04oonK0?oo
003oo`2Yonco00Gooo]Z00?oT`3ooookJ_oonfX01OoonfX00ooo]`3oE`3ooookJP0QoookJP009Ooo
nfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0ool02ooonfX01?oo
nfX01Ooo=@3ooo]Zo`21oooonf[o0?nG00;ooo]Z00?o0?oXoookJ_lfo`003OoonfX00ol0hoooolT0
ooo90004ooo900Wooo]Z00?oiOl0oookJ_oonfX02OoonfX00olM0?oo0?oboookJP05oomi0004oonW
0?ooN@3oogT0oomi00Cooo]Z00?o0?l9oookJ_oonfX00_oonfX01Oldo`3o02goool0ConDo`3oo`0H
00;ooo]Z00?oU?l0oookJ_l0nol00ooonfX00om>0?ooU?l0oiCo0003oiCo0003ooo70?oonf[ooo]Z
00?ooo]Z00GoojP0ooo90?oonf[ooo]ZoolQ0005oookJP08o`3oUooonf[oiOl0onGo0?oo03Wooo]Z
o`3o`?oo00LBoookJP06ool0>?oonf[oN@3ookSo0?oo0;cooo]Z1_nDo`02oookJP0<ond0oonDo`3o
U?l0ool0g?mG0?oookL0oookJ_nC0?ook?l0ool00?oonf[ogOl00onDo`02odCo0005oolL0?m4o`3o
A?l0odCo0?oo04l01om4o`04oookJP03ool0]Ooonf[oob0000;oA?l000ko0?lhodCo0?oo@@3oA?l0
og_o0?oo2P3o:P3oo`0UoomD0?ooo`2Po`3oE_oo0?;o0000o`3o8@;oA?l000Cookl0oiCo0?nDo`3o
Uol00_mi0?l00ol0ogOooo]Zo`3oB002o`3oB0;o00?o00?ooo]ZodCo0?m4o`001Ol0okh00om4o`3o
F_l0oe[o000<oe[o00SoU?l01_m4o`02o`3oM`05oookJ_mi0?ooUol0oiOo0?oonfX00onDo`000ooo
nf[oU?l0o`2Ro`02oono0005oiCo0?l0oj;oU?l0oookJ_l0ob400onDo`000ooo0?;o0?mFoookJP03
oookJP03ool0X?oonf[oE03o00?ooo]Z00?o:P3ooookJ_oo2P000ooonfX01Omko`3ooo]ZoookJ_oo
nf[ood4000;ooo]Z00?o0?lho`P0oooonfX01ooonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooo
nf[ooo]Z00_ooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0@oookJP04ool0Cooo
nf[ooo]Zo`3oUPOooo]Z00Cooa`0oookJ_oonf[o^?l03?oonfX01ooBo`3ooo]ZoookJ_oonf[oogT0
oookJ_l[0?l00ooonfX6onGo00Cooo]Z0_oUo`06oookJPGoolT0@OoonfX00olY0?oooo]ZoookJP02
oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0ool02ooonfX01?oonfX00ooo=@3ooo]Zo`21o`02
oookJP05o`3oUooonf[ooo]Zo`3oj?lfo`003_oonfX00ol0hooooo]Zool0k00<oookJP03o`3okOoo
nf[ooo]Z00[ooo]Z00?o7@3oo`3ol_oonfX00ooonfX00ooo0;Cooo]ZoonW0007oookJP09o`3o2Ooo
nf[ooo]ZoookJ_ml0?oo=?l0oookJ_l02oooo`0H00;ooo]Z00?o/?l0oookJ_l0nol00ooonfX01?m>
0?oooo]ZoookJ_oo01@3oookJP03ooo70?oonf[ooo]Z00;ooo]Z00GoojP0oookJ_oonf[ooo]ZoolQ
0005oookJP05o`3oUooonf[ooo]ZoookJ_n>o`000_oonfX00ol0ol3oo`07oookJP0@oookJP05ool0
>?oonf[oN@3ooookJ_oo0;`00ooonfX00om/0?oooo]ZoookJP04oookJP0=ond0oonMo`3ooo]Zool0
g?mG0?oooo]Zoi<0ooo/o`3oo`00oonK0?l[0?oogOl0om;o0003oookJP05okSo0?oo703o0?nFoook
J_oo04l01?oonfX00ol0oh_ooo]Zo`3o]@05oookJP0Aool0]Ooo803ooo]ZoookJ_l80?oo0?lhoonL
0?oo@@3oNol0ool:0?lZ0?oooo]Zoe@0ool0003oo`2Pool0l_l000000_l0ob401_l0oj;o08cooono
0?l0X_oooo]ZoiOo00;oN@3o00Co0?mgo`3oB?l0odSo0?m80ol00ol3ool0mPCo0?nn00?ooo]Zoe[o
0?mJo`003?mJo`03oookJP?o00?o0ooonfX2o`3oB0Cooo]Z0_l0ogL00omi0?ooUol0oiOo0006oook
JP05o`2Roooo_`3ookl0oookJ_l0oj800_oonfX01ol0ob7ooo]ZoookJ_oonf[oo`3boookJ_l0oeH0
0ooonfX01?oo0:3ooo]Zoe@0ool09Ol2oookJP03obX0ool0C?ooo`X000Cooo]Z00CoNol0oookJ_oo
nf[ood400ooonfX00ol0ocSooo]ZoookJP06oookJP03oolP0?oonf[ooo]Z00;ooo]Z00?oo`2eoook
J_oonfX02ooonfX00ol0okGooo]ZoookJP04oookJP03o`3oRooonf[ooo]Z00oooo]Z00Goo`1?oook
J_oonf[ooo]Zo`3oUP06oookJP05oolL0?oonf[ooo]ZoookJ_nho`002ooonfX01OoBo`3ooo]Zoook
J_oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX00_oonfX00ooo003ooo]Zonco0006oookJP03oi<0
oooonf[ooo]Z00Cooo]Z00?ookL0oookJ_mG0?l08_oonfX002Gooo]Z00?o:@3ooookJ_oonfX00_oo
nfX00ol0oo3ooo]ZoookJP05oookJP03oooX0?oo00_ooo]Z00Cooo]Z00GoocD0oookJ_l0POoooo]Z
onGo0002oookJP03o`3oj?oonf[o=_l000gooo]Z00?o0>?oooo90?oob@001Ooob@08oookJP03onGo
0?oonf[ooo]Z00Wooo]Z00?ooaX0oad0oooonfX01OooN@000oooY`3ooo]ZoookJP05oookJP03o`3o
2Ooonf[ooo]Z00;ooo]Z00Go=?l0o`0]oooonf[oU?l0ool06002oookJP03oiCo0?oonf[o0?_o00?o
oo]Z00?oCP3ooiCo0?nDo`000onDo`000ooonf[oolL0oookJP03oookJP05oonX0?oob@3ooo]Zoook
J_oo8@001OoonfX00ol0oiOooo]ZonGo0002onGo0004ool0>Ol0ol3ooo]Zool01a7ooo]Z00Koo`0h
oookJ_mi0?oo^?l0oookJ_oo0;`6oiCo00?ooo]Z00cok@3ooiCo0?nDo`3oo`3LoeL0oooonf[oT`3o
oookJ_oo003ooi/0omgo0?l[0?l3oiCo00;oA?l000Gooa`0odCo0?l0oiKooo]Zool0C`03odCo0004
oookJ_l0oh_ooo]Zo`3o]@Cooo]Z00?oo`2eoookJ_oo80000_m4o`002ol0ocSoA?l0oom10?m4o`3o
Nol0ool:0?lZ0?oo02Gooe@0oooo0:3o0?mF00;oo`3b0_l0ob44odCo0003oookJ_nGo`3oN@3o00;o
N@3o00?o0?mgoookJ_l0odP00_l0odP00ol00oooA?l0odCo0004odCo00[o0?nn2onDo`09odCo0003
oolW0?mi0?ooUol000;ooo]Z1OnDo`02oono0004oiCo0?l0oj;o0?nRoiCo00;o0?lQ0onDo`000ooo
0?;oU?l0oookJP02oookJP;oo`2P00?ooo]Zoe@0oooonfX00_oonfX00olZ0?oo04coool:0003oook
JP03og_o0?oonf[ooo]Z00;ood400_oonfX00ol0ocSooo]Zo`P0o`07oookJP03oolP0?oonf[ooo]Z
00;ooo]Z00?oo`2eoookJ_oonfX02ooonfX00ol0okGooo]ZoookJP04oookJP03o`3oRooonf[ooo]Z
00oooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP06oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oo
nfX01_oBo`3ooo]ZoookJ_oonf[oogT0ob/0o`?ooo]Z1_oUo`05oookJP;oiOl01OoonfX01?oo]`3o
olT0ooo90?oonfX2ooo9047ooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP05oook
JP03oooX0?oo00_ooo]Z00Gooo]Z00GoocD0o`21oooonf[ooo]Zo`3oU`02oookJP03o`3oj?lfo`3o
oo]Z00gooo]Z00Co0>?ooookJ_oonf[oo`3/2ooonfX00ol0ongooo]ZoookJP0:oookJP03oad0ool0
oo;ooo]Z00?ooo]Z00?oo`2doookJ_ooY`001ooonfX01_l0o`Wooo]ZoookJ_oonf[oO03oocCo00;o
oo]Z00Ko00_oool06?oonf[o/?l0oookJ_l0nol3oookJP04odh0oooonf[ooo]Zool050?ooo]Z00?o
olL0oookJ_oonfX00_oonfX01OooZ03oo`2WoookJ_oonf[oob4000Gooo]Z00[o0?nGoookJ_oonf[o
oo]Zohko0?oo03Wooo]Zo`3o`?oonf[oo`074?oonfX01_oo03Sooo]ZogT0oooonf[o^?l0ool0_0;o
oo]Z00?oK03ooookJ_oonfX01?oonfX01Oo]0?ooWOl0oookJ_oo0=coE`3o00;ooo]Z00KoT`3oonco
0?oo003ooo]Zomgo0?oBo`03oookJP06okSo0?oonf[ooa`0o`3oU_oonf[oo`1?1?oonfX00ol0oh_o
oo]Zo`3o]@04oookJP03ool0]Ooonf[oob0000;ooo]Z00_o203oo`3o>?oonf[ood40og_o0?oo2P3o
:P3oo`1<oomD0?oo0000ool0X002ool0lP04oookJ_l0ob7o0?nRo`2<o`;ookl00_oonfX00onGo`3o
N@3oogT0o`02o`3oM`?o0?m81_l00ol00ooo0?Ko0?nno`3o_P0:o`3o_P03oookJ_l00ooo00?o00?o
00?o1?oonfX2o`3oB0Cooo]Z0_l0ogL00ooo9`3oN@3ooiOo0007oookJP;ookl000Cooo]Zo`3oX_l0
oj;ooo]Z0_l0ob43oookJP03ool0l_oonf[o0?mF00;ooo]Z0_oo0:000ooonf[oE03oo`0Uo`02oook
JP03obX0ool0C?ooo`X000Cooo]Z00CoNol0oookJ_oonf[ood400ooonfX00ol0ocSo203ooookJP06
oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?oo`2eoookJ_oonfX02ooonfX00ol0okGooo]ZoookJP04
oookJP03o`3oRooonf[ooo]Z00kooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP06oookJP05oolL0?oo
nf[ooo]ZoookJ_nho`003?oonfX01ooBo`3ooo]ZoookJ_oonf[ogOl0oookJ_l[0?l01OoonfX00ooo
003oo`2Yonco0005oookJP03oi<0oooonf[ooo]Z00Gooo]Z00?ookL0oeL0oooonfX08_oonfX002Go
oo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP05oookJP03oooX0?oo00_ooo]Z00Co
oo]Z00GoocD0oookJ_l0POoooo]ZonGo0002oookJP03o`3oj?oonf[o=_l000gooo]Z2?oob@08oook
JP03onGo0?oonf[ooo]Z00Wooo]Z00?ooaX0oad0oooonfX00_ooN@02oookJP03oomi0?ooY`3ooo]Z
00Kooo]Z00?oU?l0oookJ_oonfX00ooonfX01?ldo`3o02goool0ConDo`02oookJP;oU?l000Gooo]Z
o`3koooonf[ooo]Zodh0o`06oiCo0003ooo70?oonf[ooo]Z00;ooo]Z00GoojP0ooo90?oob@3ooo]Z
oolQ0005oookJP03o`3oUooonf[oiOl000;oiOl000Coo`0ioookJ_l0ol3oo`074_oonfX01Ooo03So
N@3ooookJ_nho`3oo`2l00OoU?l00_oonfX03?o]0?ooU?l0oiCo0?oo0=coE`3ooong0?oonf[oT`3o
oookJ_oo003oU?l0omgo00?oU?l00_m4o`001_oo703ooo]ZoookJ_l0oiKoo`1?odCo00Cooo]Z00?o
0?n;oookJ_l0okD01?oonfX00ooo0;Gooo]ZoolP0002odCo00;o0?lh00Cood40odCo0?mko`3ooo]Z
0_lZ0?l01omD0?ooo`2Po`000?l0oeKoo`3boookJ_l0ob401_m4o`001?oonf[oUol0ogT0oomi0?l2
o`3oM`04oookJ_l0odSo0?m8o`3oB0GoA?l03?l00ol6oookJP03o`3oB?m4o`3oA?l000KoA?l00omi
0?l2oookJPGoU?l00_oo_`02oiCo0004o`3oX_nDo`3oU?l0o`3o8@CoU?l000Koo`3boiCo0?nDo`3o
U?l0oookJ_oo0:02oookJP05oe@0oooonf[ooo]ZoookJ_lZ0?l00_oo2P03oookJP05og_o0?oonf[o
oo]Zoom10?ooW0000_oonfX00ol0ocSooo]Zo`P0o`08oookJP05oolP0?oonf[ooo]ZoookJ_oo0;D0
3_oonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z013ooo]Z00Coo`1?oookJ_oonf[o
0?nF1ooonfX01?oo703ooo]ZoookJ_nho`0=oookJP06om;o0?oonf[ooo]Zoomi0?oonf[o:`3o0ooo
nfX6onGo00Gooo]Z00?oiOl0oookJ_oonfX01?oonfX01?oo]`3oolT0oookJ_oonfX2ooo9047ooo]Z
00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP05oookJP03oooX0?oo00_ooo]Z00Gooo]Z
00GoocD0o`21oooonf[ooo]Zo`3oU`02oookJP03o`3oj?oonf[o=_l000gooo]Z00Co0>?ooookJ_oo
nf[oo`3/2ooonfX00ol0ongooo]ZoookJP0:oookJP03oolJ0?lM0?oooo]Z00?ooo]Z00?oo`2doook
J_ooY`001ooonfX00ol0o`Wooo]ZoookJP02oookJP07og`0ooldo`3ooo]Zo`0;oooo01Sooo]Zok3o
0002oookJP04o`3koooonf[ooo]Zodh0o`;ooo]Z00Goo`0DoookJ_oonf[ooo]Zooo70004oookJP05
oonX0?oo0:Oooo]ZoookJ_oo8@001_oonfX01Ol0oiOooo]ZoookJ_n>o`3oo`0i00;ooo]Z00?o0?o0
ool01ooonfX04?oonfX01Ooo03SoN@3ooookJ_nho`3oo`2l00?ooo]Z00?oK03ooookJ_oonfX01?oo
nfX03Oo]0?ooWOl0oookJ_oo0=coE`3ooookJ_nC0?oooo]Zool00?ooV`3o:`3oomgo0?oBo`000ooo
nfX01Onho`3ooa`0oookJ_l0oiKoo`1?00Gooo]Z00?o0?n;oookJ_l0okD01?oonfX00ooo0;Gooo]Z
oolP0003oookJP;o0?lh00?ood40og_o0?oonfX00_lZ0?l01_mD0?oo0000ool0X?l0oeKoo`3boook
JP;o0?lQ00Co0?nRo`2<oooo_`3ookl00_oonfX00onGo`3oN@3oogT0o`03o`3oM`?o0?m80ooonfX>
o`03o`Kooo]Z0ol0odP4oookJP;o0?mg0omi0?l8oookJP04oono0?oonf[o08coo`3oXP;ooo]Z00?o
0?lQoookJ_oonfX00_oonfX00ooo0?;o0?mFo`3oEP02oookJP05ool0X?oonf[ooo]Zoe@0ool09Ol0
0_oonfX00olZ0?ooo`X0ool:0004oookJP04og_o0?oonf[ooo]Zoom100?ooo]Z00?o0?lho`P0oooo
nfX01ooonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z00_ooo]Z00?o0?neoookJ_oo
nfX01?oonfX00ol0oh_ooo]ZoookJP0?oookJP05ool0Cooonf[ooo]ZoookJ_l0oiH01_oonfX01Ooo
703ooo]ZoookJ_oonf[o^?l000cooo]Z00Cod_l0oookJ_oonf[ogOl00_oonfX00ol[0?oooo]Zoook
JP02oookJP03oonK0?oo003ok?l000Kooo]Z00?oT`3ooookJ_oonfX01OoonfX00ooo]`3oE`3ooook
JP0RoookJP009OoonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0
ool02ooonfX01?oonfX01?oo=@3ooo]Zo`21oooonfX2onGo0004oookJ_l0onSooo]ZocKo00gooo]Z
2?oob@08oookJP03onGo0?oonf[ooo]Z00Wooo]Z00?ooaX0oad0oooonfX01?oonfX00oooN@3oojL0
oookJP06oookJP03oiCo0?oonf[ooo]Z00?ooo]Z00Co=?l0o`0]oooo04ooU?l00_oonfX2oiCo0005
oookJ_l0nooooo]ZoookJ_m>0?l01_nDo`000oooa`3ooo]ZoookJP02oookJP05oonX0?oob@3oolT0
oookJ_oo8@001OoonfX00ol0oiOooo]ZoookJP03onGo0003oookJ_l0ol3oo`0701;ooo]Z00Koo`0h
oookJ_mi0?oo^?l0oookJ_oo0;`7oiCo0003oookJ_nDo`3ok@3o00;oU?l000Woo`3LoeL0oooonf[o
T`3ooookJ_o/o`3oo`00oiCo0?oMo`000_nDo`002?m4o`3oU?l0oiCo0?oo703ooo]Zo`3oU_oonf[o
o`1?1OoonfX00ol0oh_ooo]Zo`3o]@04oookJP03ool0]Om4o`3oob0000?oA?l000_o0?lhoom10?oo
W03oNol0oookJ_oo2P3o:P3ooe@0oooo0:3o0000o`3oEP02ool0lP03o`3o8Om4o`3oA?l000OoA?l0
0omi0?l2o`3oM`03odCo0?l0odSo0?m800?o0?m81?m4o`07oookJPCoA?l00_l0odP7odCo00?oN@3o
0_m4o`02oookJPGoU?l000Kookl0oiCo0?nDo`3oU?l0o`3oX_nDo`02o`3o8@CoU?l000?oo`3boiCo
0?nDo`000_nDo`001?oo0:3ooo]ZoookJ_mD0?l3oookJP03obX0oooo2P3ooo]Z00?ooo]Z00GoNol0
oookJ_oonf[ood40oonL0002oookJP03o`3o>?oonf[o203o00Sooo]Z00?oob00oookJ_oonfX00_oo
nfX00ooo0;Gooo]ZoookJP0;oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX03ooo
nfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Oooo]Z00Cooa`0oookJ_oonf[o^?l03?oonfX01ooBo`3o
oo]ZoookJ_oonf[oogT0oookJ_l[0?l00ooonfX5onGo00Kooo]Z00?oT`3ooookJ_oonfX01?oonfX0
1?oo]`3oE`3ooookJ_oonfX2ooo904;ooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol007oookJP03oooX
0?oo00_ooo]Z00Gooo]Z00GoocD0ocOo0?l0POoooo]Zo`3oU`02oookJP03o`3oj?oonf[o=_l000go
oo]Z00Co0>?ooookJ_oonf[oo`3/2ooonfX00ol0ongooo]ZoookJP0:oookJP03oolJ0?lM0?oooo]Z
00?ooo]Z00?oo`2doookJ_ooY`001ooonfX00ol0o`Wooo]ZoookJP02oookJP05og`0ooldo`3ooo]Z
o`0;oooo01P00_oonfX00on`o`3ooo]Zo`3ko`02oookJP05odh0oooonf[ooo]ZoookJ_oo01@00_oo
nfX00oooa`3ooo]ZoookJP02oookJP06oonX0?oo0:Oooo]ZoookJ_oo8@3oo`2d1OoonfX01Ol0oiOo
oo]ZoookJ_oonf[oS_l000;ooo]Z00?o0?o0ool01ooonfX04?oonfX01_oo03Sooo]ZogT0oooonf[o
^?l0ool0_0;ooo]Z00?oK03ooookJ_oonfX01?oonfX03Oo]0?ooWOl0oookJ_oo0=coE`3ooookJ_nC
0?oooo]Zonco0?oo003ooo]Zomgo0?oBo`001?oonfX01Onho`3ooa`0oookJ_l0oiKoo`1?00Gooo]Z
00?o0?n;oookJ_l0okD01?oonfX01?oo0;Gooo]ZoolP0?oo8002oookJP07o`P0ool0ocSood40og_o
0?oonf[oo`X0obX0o`02oe@0o`06ool0X?l0oeKoo`3bool0l_oonf[o0?lQ0_l0oj801_l0S?oookl0
oono0?oonf[oobL0oiOo00?oN@3o0ol0ogL5o`3oB0gooo]Z1Ol0odP4oookJP;o0?mg0omi0?l2oiOo
00Oooo]Z0_oo_`001?oonf[o08coo`3oX_oonfX2o`3o8@Cooo]Z00?oo`3bo`3oE_oonfX00_oonfX0
1Ooo0:3ooo]ZoookJ_mD0?oo02Go00;ooo]Z00?o:P3oool:0?oonfX01?oonfX01?mko`3ooo]Zoook
J_oo@@03oookJP03o`3o>?l80?oooo]Z00Oooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]Z
oookJP0<oookJP03o`3o]Ooonf[ooo]Z00?ooo]Z00?o0?n;oookJ_oonfX03ooonfX01Ooo04oooo]Z
oookJ_oonf[o0?nF00Oooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000;oookJP05om;o0?oonf[ooo]Z
oookJ_oMo`000_oonfX00ol[0?oooo]ZoookJP02oookJP03ool00?oo0:Wok?l000Kooo]Z00?oT`3o
oookJ_oonfX01?oonfX00ooo]`3ooo]ZoeL0o`0SoookJP009_oonfX01OlY0?oooo]ZoookJ_oonf[o
0?o`00Oooo]Z00?oonP0ool02ooonfX01OoonfX00ooo=@3o087ooookJP02onGo00;ooo]Z00?o0?oX
ocKo0?oonfX03?oonfX9ooo900Oooo]Z00?oiOl0oookJ_oonfX02OoonfX00ooo6P3o7@3oo`3olP05
oookJP03oonW0?oonf[ooo]Z00Gooo]Z0_nDo`04oookJP06ocCo0?l0;Oooo`1?oiCo0?oo01Sooo]Z
0onDo`001?l0nooooo]ZoookJ_oonfX7oiCo00Cooo]Z00KoolT0oonX0?oob@3oolT0oolQ0?oo0;@4
oookJP03o`3oUooonf[ooo]Z00CoiOl000?o0?o0oookJ_oo00L04_oonfX01Ooo03SoN@3ookSo0?oo
nf[oo`2l00GoU?l01?oonfX03Oo]0?ooU?l0oiCo0?oo0=coE`3ooong0?oonf[oT`3ooookJ_oo003o
U?l0omgo0?l[0?l01?nDo`001_oo703ooo]ZoookJ_l0oiKooo]Zool0C`Cooo]Z00?o0?n;oookJ_l0
okD01OoonfX00ooo0;GoA?l0oolP0002odCo0007oookJ_l0ocSood40oonL0?mko`3o0000ool:0002
obX0o`;oo`2P00?ooo]Zo`3oE_oo0?800_l0ob49odCo0004oiOo0?mi0?ooN@3oogT0o`Go0?mg1_l0
odP?odCo00?oN@3o1_m4o`04oiCo00;ookl00onDo`000ol0oj;o0?lQo`3o8@04oiCo00;oo`3b0onD
o`02ool0X003oiCo0?l09OooE03o00?ooo]Z00?o:P3oool:0?oonfX00ooonfX01Omko`3ooo]Zoook
J_oo@@3ooi`000;ooo]Z00?o0?lhoookJ_l80?l02OoonfX01Ooo803ooo]ZoookJ_oonf[oo`2e00go
oo]Z00?o0?neoookJ_oonfX01?oonfX00ol0oh_ooo]ZoookJP0?oookJP03ool0Cooonf[ooo]Z00;o
oo]Z00?o0?nFoookJ_oonfX01?oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00Kod_l0oook
J_oonf[oogT0oookJ_l[0?l4oookJPCoiOl01_oonfX00onC0?oooo]ZoookJP05oookJP04oeL0oooo
nf[ooo]ZoookJP;oolT0@_oonfX01OlY0?oooo]ZoookJ_oonf[o0?o`00Sooo]Z00?oonP0oookJ_oo
nfX01?oonfX01Ooo=@3o=ol0o`21oooonf[o0?nG00;ooo]Z00?o0?oXoookJ_lfo`003OoonfX01?l0
hooooo]ZoookJ_oo0>`;oookJP03o`3okOoonf[ooo]Z00[ooo]Z00?ooaX0oad0ool0oo801?oonfX0
0ooo0;CoojL0oookJP06oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z00GoO03oocCo0?oonf[o00_oool0
6002oookJP03ok3o0?oonf[o0?_o00?ooo]Z00CoCP3ooookJ_oonf[oo`0D0_oonfX00oooa`3ooo]Z
oookJP03oookJP05oonX0?oo0:Oooo]ZoolQ0?oo0;@01OoonfX02_l0oiOooo]ZoookJ_oonf[oS_l0
ool0>Ooonf[o0?o0oookJ_oo00LAoookJP05ool0>?mi0?oooo]ZokSo0?oo0;`00_oonfX00om/0?oo
oo]ZoookJP05oookJP0=ond0oonMo`3oo`3LoookJ_mG0?oooo]Zoi<0oooonf[ok?l0ool00?oonf[o
gOl0om;o0003oookJP06okSo0?oo703ooo]Zo`3oU_oonf[oo`1?1?oonfX01?l0oh_ooo]ZoookJ_l0
okD4oookJP04ool0]Ooonf[ooo]ZoolP00;ooo]Z00Ko203oo`3o>?oo@@3oNol0o`000?oo2P02obX0
o`06oe@0oooo0:3oo`2Po`3oE_oo0?;ooo]Z0_l0ob401Ol0oj;o08coo`2<oooo_`3o0:;o00?ooo]Z
00CoUol0ogT0oomi0?ooN@3o1_l0ogL<o`3oB0Cooo]Z1?l0ogL3ogT0o`;oUol02?oonfX2oono0004
o`2Rool0S?oo08coo`3oXP;o0?lQ1?oonfX2ool0lP03o`3oE_oonf[ooo]Z00;oo`2P0_oonfX01_mD
0?oo02GooookJ_oonf[o:P3oool:00Gooo]Z00CoNol0oookJ_oonf[ood400ooonfX00ol0ocSo203o
oookJP08oookJP05oolP0?oonf[ooo]ZoookJ_oo0;D03_oonfX00ol0okGooo]ZoookJP04oookJP03
o`3oRooonf[ooo]Z00oooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP06oookJP05oolL0?oonf[ooo]Z
oookJ_nho`003?oonfX01?oBo`3ooo]ZoookJ_oMo`02oookJP03ob/0oooonf[ooo]Z00?ooo]Z00?o
o`00ool0ZOo/o`001OoonfX00onC0?oooo]ZoookJP05oookJP03oong0?mG0?oooo]Z00?ooo]Z00?o
o`3LoookJ_oonfX07OoonfX002Kooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol007oookJP03oooX0?oo
nf[oo`0;00Gooo]Z00?oocD0o`21oooonfX00ooUo`000ooonf[o0?oXocKo000=oookJPGoolT02ooo
nfX00ooUo`3ooo]ZoookJP0:oookJP03oad0ool0oo;ooo]Z00Cooo]Z00?oojL0oookJ_oonfX01Ooo
nfX2oiCo00Cooo]Z00Ko=?l0o`0]oooo04ooU?l0ool06?oonfX3oiCo0004o`3koooonf[ooo]Zoook
JPOoU?l01?oonfX00ooob@3oojP0ooo90002ooo90003oolQ0?oonf[ooo]Z00;ooo]Z00?o0?nGoook
J_oonfX01OoUo`000ol0ol3oo`07oookJP0AoookJP05ool0>?mi0?oooo]ZokSo0?oo0;`00_nDo`00
0ooonf[oU?l0oookJP04oookJP0=oiCo0?o]0?ooU?l0oiCo0?mG0?oookL0oookJ_nC0?oooo]Zonco
0?oo003oU?l0omgo0003oiCo00;ooo]Z00Gooa`0oookJ_oonf[o0?nFool0C`05oookJP03o`3oRooo
nf[o0?ne00Gooo]Z00?oo`2eodCo0?oo80000ooonfX00ol0ocSood40oonL0002og_o0004oiCo0?oo
2P3o:P3ooe@0o`;oo`2P00?o0?mFool0l_m4o`000ol0ob49odCo0004oiOo0?mi0?ooN@3oogT0o`;o
A?l000?o0?mgodCo0?m4o`003?m4o`06ogT0o`WoA?l00_nDo`02oono00?oU?l00_l0oj800ol0ob7o
U?l0oookJP02oookJP;oo`3b1?nDo`000ooo0:3oU?l0oiCo0002oe@0o`?ooo]Z00?o:P3oool:0?oo
nfX00ooonfX01Omko`3ooo]ZoookJ_oo@@3ooi`000?ooo]Z00?o0?lho`P0oooonfX02?oonfX01Ooo
803ooo]ZoookJ_oonf[oo`2e00kooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0@
oookJP05ool0Cooonf[ooo]ZoookJ_l0oiH01ooonfX01?oo703ooo]ZoookJ_nho`0=oookJP06om;o
0?oonf[ooo]Zoomi0?oonf[o:`3o1?oonfX4onGo00Kooo]Z00?oT`3ooookJ_oonfX01?oonfX00ooo
]`3oE`3ooookJP02oookJP;oolT0@_oonfX01OlY0?oooo]ZoookJ_oonf[o0?o`00Sooo]Z00?oonP0
ool02ooonfX01?oonfX00ooo=@3o=ol0o`21o`02oookJP05o`3oUooonf[o0?oXoookJ_lfo`003Ooo
nfX01?l0hooooo]ZoookJ_oo0>`;oookJP03o`3okOoonf[ooo]Z00_ooo]Z00?o7@3oo`3ol_oonfX0
0ooonfX00ooo0;CoojL0oookJP07oookJP09o`3o2Ooonf[ooo]ZoookJ_ml0?oo=?l0oookJ_l02ooo
o`0H00;ooo]Z00?o/?l0oookJ_l0nol00ooonfX01?m>0?oooo]ZoookJ_oo01@2oookJP03ooo70?oo
nf[ooo]Z00?ooo]Z00GoojP0ool0Yooonf[ooo]ZoolQ0005oookJP06o`3oUooonf[ooo]ZoookJ_n>
o`3oo`0i0_oonfX00ol0ol3oo`07oookJP0@oookJP06ool0>?mi0?oooo]ZoookJ_nho`3oo`2l0_oo
nfX00om/0?oooo]ZoookJP04oookJP0=ond0oonMo`3ooo]Zool0g?mG0?oookL0oi<0oooonf[ok?l0
ool00?oonf[o:`3oomgo0004oookJP05okSo0?oo703ooo]Zo`3oU_oo04l01OoonfX01?l0oh_ooo]Z
oookJ_l0okD4oookJP04ool0]Ooonf[ooo]ZoolP00;ooo]Z00?o203oo`3o>?oo@@000_mko`000ol0
003oo`X0obX0o`02oe@0o`05ool0X?l0oeKoo`3bool0l_oonfX00_l0ob401?l0oj;o08cooono0?oo
_`02o`2Ro`?ooo]Z00CoUol0ogT0oomi0?ooN@3o0ooo9`0=o`3oM`OoN@3o0_nGo`09oookJP03o`2R
oooo_`3o0:;o00;o08co0_l0oj800ol0ob7ooo]ZoookJP02oookJP;oo`3b00Go0?mFoookJ_oonf[o
oo]Zool0X002oookJP;oE03o0ooonfX00olZ0?ooo`X0oookJP04oookJP04og_o0?oonf[ooo]Zoom1
00?ooo]Z00?o0?lho`P0oooonfX02?oonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z
00cooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0?oookJP05ool0Cooonf[ooo]Z
oookJ_l0oiH01ooonfX01Ooo703ooo]ZoookJ_oonf[o^?l000cooo]Z00Cod_l0oookJ_oonf[ogOl0
0_oonfX00ol[0?oooo]ZoookJP02oookJP03oonK0?oo003ok?l000Kooo]Z00?oT`3ooookJ_oonfX0
1OoonfX00ooo]`3oE`3ooookJP03oookJP03ool0g?oonf[ooo]Z01gooo]Z000VoookJP05obT0oooo
nf[ooo]ZoookJ_l0oo002?oonfX00oooj03oo`0;oookJP04oookJP03oole0?l0POoooo]Z00?oiOl0
00?ooo]Zo`3oj?lfo`003OoonfX01Ol0hooooo]ZoookJ_oonf[oolT000_ooo]Z00?oiOl0oookJ_oo
nfX02_oonfX00ooo6P3o7@3ooookJP04oookJP03oonW0?oonf[ooo]Z00Gooo]Z0onDo`03oookJP06
ocCo0?ml0?ooo`1?o`0;oooo01Sooo]Z0onDo`001?l0nooooo]ZoookJ_oonfX8oiCo00?ooo]Z00?o
olT0oonX0?oob@000_oob@000ooo8@3ooo]ZoookJP03oookJP03o`3oUooonf[oiOl000CoiOl000?o
0?o0oookJ_oo00L04OoonfX01_oo03Sooo]ZogT0oonho`3oU?l0ool0_0;ooo]Z00?oU?l0oookJ_oo
nfX00ooonfX02onDo`3ok@3ooiCo0?nDo`3oo`3LoeL0oooo]`3ooo]Zoi<0oooonf[oo`0000;oU?l0
00?ogOl0oiCo0?oonfX00_oonfX01_nho`3ooa`0oookJ_l0oiKooo]Zool0C`Gooo]Z00?o0?n;oook
J_l0okD01OoonfX00ooo0;Gooo]ZoolP0003oookJP;o0?lh00Good40o`000?mko`3oU?l0ool:0002
obX0o`04oiCo0?oo0:3ooo]Zo`3oEP?oA?l00_l0ob43odCo0003oono0?l0X_oo0:;o00CoA?l000?o
Uol0odCo0?m4o`006?m4o`03oookJP?oU?l00_oo_`02oiCo00?o0?nR0_l0ob42oiCo0003oookJ_oo
0?;oo`3b00CoU?l00_oo0:02oiCo0003oe@0oooonf[ooo]Z00;ooo]Z00?o:P3oool:0?oonfX00ooo
nfX01Omko`3ooo]ZoookJ_oo@@3ooi`000?ooo]Z00?o0?lho`P0oooonfX02?oonfX01Ooo803ooo]Z
oookJ_oonf[oo`2e00kooo]Z00?o0?neoookJ_oonfX01?oonfX00ol0oh_ooo]ZoookJP0?oookJP03
ool0Cooonf[ooo]Z00;ooo]Z00?o0?nFoookJ_oonfX01OoonfX01?oo703ooo]ZoookJ_nho`0<oook
JP06om;o0?oonf[ooo]Zoomi0?oonf[o:`3o1OoonfX3onGo0003onco0?oonf[ooo]Z00?ooo]Z00?o
T`3ooookJ_oonfX01OoonfX00omG0?oooo]ZoookJP02oookJP;oolT0@_oonfX01OlY0?oooo]Zoook
J_oonf[o0?o`00Sooo]Z00?oonP0ool02ooonfX01?oonfX00ooo=@3o=ol0o`21o`02oookJP05o`3o
Uooonf[o0?oXoookJ_lfo`003OoonfX01?l0hooooo]ZoookJ_oo0>`;oookJP03o`3okOoonf[ooo]Z
00_ooo]Z00?o7@3oo`3ol_oonfX00ooonfX00ooo0;CoojL0oookJP07oookJP03o`3o2Ooonf[ooo]Z
00;ooo]Z00Wo=?l0o`0]ool02ooooo]Zool06?oonf[o/?l0oookJ_l0nol00ooonfX01?m>0?oooo]Z
oookJ_oo01@3oookJP03ooo70?oonf[ooo]Z00;ooo]Z00KoojP0ool0Yooonf[ooo]ZoolQ0?oo0;@4
oookJP03o`3oUooonf[ooo]Z00;ooo]Z00GoS_l0oookJ_oonf[o0?o0ool01`0AoookJP06ool0>?oo
nf[oN@3ooookJ_nho`3oo`2l0_oonfX00om/0?oooo]ZoookJP05oookJP0=ond0oonMo`3oo`3Loook
J_mG0?oooo]Zoi<0oooonf[ok?l0ool00?oonf[ogOl0om;o0003oookJP06okSo0?oonf[ooa`0oook
J_l0oiKoo`1?1OoonfX01?l0oh_ooo]ZoookJ_l0okD4oookJP04ool0]Ooonf[ooo]ZoolP00;ooo]Z
00Oo203oo`3o>?oo@@3ood40og_o0?l0003oo`X000;o:P3o00CoE03oool0X?oo0:3o0?mF0_oo0?80
1Ooonf[o0?lQo`3o8Ol0ob7o0?nR00?ookl000?o0:;ooookJ_oonfX00_oonfX00onGo`3oN@3oogT0
o`0>ogT0o`KoUol02OoonfX2o`2Ro`;ookl000Cooo]Zo`3oX_l0oj;o0?nR0_l0ob43oookJP;oo`3b
0_l0oeH2oookJP;oo`2P0_oonfX00omD0?oo02GooookJP02oookJP03obX0oooo2P3ooo]Z00Cooo]Z
00CoNol0oookJ_oonf[ood400ooonfX00ol0ocSo203ooookJP08oookJP03oolP0?oonf[ooo]Z00;o
oo]Z00?oo`2eoookJ_oonfX03?oonfX00ol0okGooo]ZoookJP03oookJP03o`3oRooonf[ooo]Z013o
oo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP07oookJP05oolL0?oonf[ooo]ZoookJ_nho`002ooonfX0
1?oBo`3ooo]ZoookJ_oMo`02oookJP03ob/0oooonf[ooo]Z00?ooo]Z00?oo`00ool0ZOo/o`001Ooo
nfX00onC0?oooo]ZoookJP05oookJP03oong0?mG0?oooo]Z00?ooo]Z00?oo`3LoookJ_oonfX07_oo
nfX002Kooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol008oookJP03oooX0?oo00_ooo]Z00Cooo]Z00?o
ocD0o`21oooonfX01?oUo`000ol0onSooo]ZocKo000<oookJP05o`3Soooonf[ooo]ZoookJ_oob@00
2ooonfX00ooUo`3ooo]ZoookJP0:oookJP03oolJ0?lM0?oooo]Z00Cooo]Z00?oogT0oonW0?oonfX0
1OoonfX4oiCo00;ooo]Z00Ko=?l0og`0oooo04oo00_oool06?oonfX3oiCo0004o`3koonDo`3ooo]Z
oookJPGoU?l00_oonfX01_ooa`3ooo]ZoookJ_oonf[oolT0oonX00?oolT000?oU?l0ool0]?oonfX0
0ooonfX00ol0oiOooo]ZonGo0005onGo0003oookJ_oo00Oooo]Z017ooo]Z00Goo`0hogT0oooonf[o
^?l0ool0_002oookJP03oiCo0?oonf[ooo]Z00?ooo]Z0_nDo`003Oo]0?ooU?l0oiCo0?mG0?oookL0
oiCo0?oonf[oT`3oonco0?oo003oU?l0omgo0?oBo`001?oonfX01_nho`3ooa`0oookJ_l0oiKooo]Z
ool0C`Gooo]Z00?o0?n;oookJ_l0okD01OoonfX00ooo0;Gooo]ZoolP0003oookJP0:o`P0ool0ocSo
od40oonL0?mko`3oU?l0ool:0?nDo`3o:P3ooiCo00;oo`2P00?o0?mFodCo0?m4o`000_m4o`03o`3o
8@04o`3oX_oo_`3ookl0oono00;o0:;o7?m4o`02oookJP05oiCo0?oo_`3ookl0oono0?nDo`000ol0
oj82oiCo0003o`3o8Ooonf[ooo]Z00;ooo]Z00?oo`3boiCo0?nDo`000onDo`000ooo0:3oU?l0oiCo
0002oe@0o`Cooo]Z00?o:P3oool:0?oonfX00ooonfX01Omko`3ooo]ZoookJ_oo@@3ooi`000?ooo]Z
00?o0?lho`P0oooonfX02?oonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z00cooo]Z
00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0@oookJP05ool0Cooonf[ooo]ZoookJ_l0
oiH01ooonfX01?oUo`3ooo]ZoookJ_nho`0=oookJP06om;o0?oonf[ooo]Zoomi0?oonf[o:`3o1Ooo
nfX3onGo00Gooo]Z00?oT`3ooookJ_oonfX01_oonfX00omG0?oooo]ZoookJP02oookJP03ooo90?oo
nf[ooo]Z047ooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol008oookJP03oooX0?oo00_ooo]Z00Cooo]Z
00?oocD0ocOo0?l0POl00_oonfX01Ol0oiOooo]Zo`3oj?oonf[o=_l000gooo]Z00Co0>?ooookJ_oo
nf[oo`3/2ooonfX00ol0ongooo]ZoookJP0;oookJP03oolJ0?lM0?oooo]Z00?ooo]Z00?oo`2doook
J_ooY`001ooonfX00ol0o`Wooo]ZoookJP02oookJP05ocCo0?l0;Ooo00_ooookJ_oo01P00_oonfX0
0on`o`3o0?_ooookJP02oookJP05odh0oooonf[ooo]ZoookJ_oo01@00_oonfX00oooa`3ooo]Zoook
JP02oookJP06oonX0?oonf[oo`2WoookJ_oo8@3oo`2d1OoonfX02_l0oiOooo]ZoookJ_oonf[oS_l0
ool0>Ooonf[o0?o0oookJ_oo00LAoookJP08ool0>?mi0?oooo]ZoookJ_nho`3oo`2loookJ_m/0?l7
oookJP0=ond0oonMo`3ooo]Zool0g?mG0?oookL0oookJ_nC0?ook?l0ool00?ooV`3o:`3oomgo0004
oookJP06okSo0?oo703ooo]ZoookJ_l0oiKoo`1?1OoonfX01?l0oh_ooo]ZoookJ_l0okD4oookJP04
ool0]Ooonf[ooo]ZoolP00;ooo]Z00Co203oo`3o>?l0003ood400_mko`000ooo2P3o04coobX0o`02
oe@0o`03ool0X?l0oeKo0?mF00;oo`3b0_oonfX2o`3o8@03o`3oX_l0S?oookl000;ookl000?o0:;o
oookJ_oonfX01_oonfX9oiOo00gooo]Z0_l0X_l3oono00?o0?nR0_oonfX00ol0ob7ooo]ZoookJP02
oookJP03ool0l_oonf[o0?mF00?ooo]Z00Goo`2PoookJ_oonf[ooo]Zoe@0o`04oookJP03obX0oooo
2P3ooo]Z00Cooo]Z00CoNol0oookJ_oonf[ood400ooonfX00ol0ocSo203ooookJP08oookJP03oolP
0?oonf[ooo]Z00;ooo]Z00?oo`2eoookJ_oonfX03?oonfX00ol0okGooo]ZoookJP04oookJP03o`3o
Rooonf[ooo]Z00oooo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP04oookJP05oolL
0?oonf[ooo]ZoookJ_nho`003?oonfX01_oBo`3ooo]ZoookJ_oMo`3ooo]Zob/0o`Kooo]Z00?oo`00
onco0?oonfX01OoonfX00onC0?oooo]ZoookJP05oookJP03oong0?mG0?oooo]Z00?ooo]Z00?oo`3L
oookJ_oonfX07_oonfX002Kooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol008oookJP03oooX0?oo00_o
oo]Z00Cooo]Z00?oocD0ocOo0?l0POl01?oUo`000ol0onSooo]ZocKo000<oookJP03o`3Soooonf[o
oo]Z00;ooo]Z00?oolT0oookJ_oonfX02OoonfX00ooUo`3ooo]ZoookJP09oookJP03oolJ0?lM0?oo
0?ob00Cooo]Z00?oogT0oonW0?oonfX01OoonfX4oiCo00;ooo]Z00Ko=?l0og`0ool0;Oooo`1?o`0;
oooo01P4oiCo0003o`3koooonf[ooo]Z00;oU?l00_oonfX01?nDo`3ooo]ZoookJ_ooa`03oookJP03
ooo90?ooZ03oolT000;oolT000?oU?l0ool0]?oonfX00ooonfX00ol0oiOooo]ZonGo0006onGo0003
ool01ooonf[ooo]Z013ooo]Z00Koo`0hogT0oooonf[o^?l0oookJ_oo0;`2oookJP03oiCo0?oonf[o
oo]Z00;ooo]Z0_nDo`003_o]0?ooU?l0oiCo0?oo0=coE`3ooong0?nDo`3oT`3ooookJ_oo003ooi/0
oookJ_oMo`3od_l01?oonfX01_oo703ooo]ZoookJ_l0oiKooo]Zool0C`Gooo]Z00Co0?n;oookJ_nD
o`3oU?l01?oonfX00ooo0;Gooo]ZoolP0003oookJP04o`P0ool0ocSood40oom100;oNol00_oUo`03
odCo00;oo`2P1Om4o`000ooonf[oA?l0odCo000PodCo00?ookl000CoU?l0o`3oX_l0oj;o0?nR0ooo
nfX2o`3o8@?ooo]Z0_oo0?85oiCo0004ool0X?oonf[ooo]Zoe@0o`Cooo]Z00?o04coobX0oooonfX0
1?oonfX01Omko`3ooo]ZoookJ_oo@@3ooi`000?ooo]Z00?o0?lho`P0oooonfX02?oonfX00ooo803o
oo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z00cooo]Z00?o0?neoookJ_oonfX01?oonfX00ol0oh_o
oo]ZoookJP0?oookJP03ool0Cooonf[ooo]Z00;ooo]Z00?o0?nFoookJ_oonfX01OoonfX00ooUo`3o
oo]ZokSo000=oookJP06om;o0?oonf[ooo]Zoomi0?oonf[o:`3o1_oonfX2onGo0003onco0?oonf[o
oo]Z00?ooo]Z00?oT`3ooookJ_oonfX01OoonfX00omG0?oooo]ZoookJP03oookJP03ool0g?oonf[o
oo]Z047ooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol008oookJP03oooX0?oo00_ooo]Z00Cooo]Z00?o
ocD0ocOo0?l0POl00_oonfX01Ol0oiOooo]Zo`3oj?oonf[o=_l000gooo]Z00Go0>?ooookJ_oonf[o
oo]Zool0k00;oookJP03o`3okOoonf[ooo]Z00[ooo]Z00?ooaX0oad0oooonfX00ooonfX00ooo0;Co
oo]ZoonW0007oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z00Go=?l0o`0]oooonf[o00_oool06002oook
JP03ok3o0?oonf[o0?_o00?ooo]Z00CoCP3ooookJ_oonf[oo`0D0_oonfX00oooa`3ooo]ZoookJP02
oookJP06oonX0?oonf[oo`2WoookJ_oo8@3oo`2d1OoonfX02_l0oiOooo]ZoookJ_oonf[oS_l0ool0
>Ooonf[o0?o0oookJ_oo00LAoookJP06ool0>?mi0?oooo]ZoookJ_nho`3oo`2l0_oonfX00om/0?oo
oo]ZoookJP04oookJP0>ond0oooonf[oWOl0oookJ_oo0=coE`3ooookJ_nC0?oooo]Zonco0?oo003o
oo]Zomgo0?oBo`04oookJP06okSo0?oo703ooo]Zo`3oU_oonf[oo`1?1OoonfX01?l0oh_ooo]Zoook
J_l0okD4oookJP04ool0]Ooonf[ooo]ZoolP00;ooo]Z00?o203oo`3o>?l000000_oo@@000omko`3o
o`X0ool:0002obX0o`03oe@0oooo0:3oo`2P00;o0?mF0_oo0?82oookJP?o0?lQ00?o0?nRo`2<oooo
_`000_oo_`000ol0X_oooo]ZoookJP0EoookJP?o0:;o0ooo_`03o`3oXP03o`2<oooonf[ooo]Z00;o
0?lQ0ooonfX2ool0lP;o0?mF0ooonfX00ooo0:3ooo]ZoookJP02oe@0o`?ooo]Z00?o04coobX0oooo
nfX01OoonfX01?mko`3ooo]ZoookJ_oo@@03oookJP03o`3o>?l80?oooo]Z00Sooo]Z00?oob00oook
J_oonfX00_oonfX00ooo0;Gooo]ZoookJP0=oookJP03o`3o]Ooonf[ooo]Z00?ooo]Z00?o0?n;oook
J_oonfX03ooonfX00ooo04oooo]ZoookJP02oookJP03o`3oU_oonf[ooo]Z00Gooo]Z00Cooa`0oook
J_oonf[o^?l03?oonfX01?oBo`3ooo]ZoookJ_oMo`02oookJP03ob/0oooonf[ooo]Z00?ooo]Z00?o
oi/0ool00?o/o`001OoonfX00onC0?oooo]ZoookJP06oookJP03oeL0oooonf[ooo]Z00?ooo]Z00?o
o`3LoookJ_oonfX07_oonfX002Kooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol008oookJP03oooX0?oo
00_ooo]Z00Cooo]Z00?oocD0oookJ_l0POl01?oUo`000ol0onSooo]ZocKo000<oookJP03o`3Soooo
nf[ooo]Z00;ooo]Z00?oolT0oookJ_oonfX02OoonfX00ooUo`3ooo]ZoookJP09oookJP03oolJ0?lM
0?oo0?ob00Cooo]Z00?oogT0oonW0?oonfX01OoonfX5oiCo00;ooo]Z00Go=?l0o`0]oooo04oo00_o
ool06004oiCo0005o`3koonDo`3ooo]ZoookJ_m>0?l00_oonfX01?nDo`3ooo]ZoookJ_ooa`03oook
JP;oolT000?oojP0ooo90?oob@000_nDo`04oookJP03o`3oUooonf[oiOl000KoiOl000?ooo]Zool0
1ooonfX04?oonfX01_oo03Sooo]ZogT0oooonf[o^?l0ool0_0;ooo]Z00?oK03ooookJ_oonfX00ooo
nfX2oiCo0005ond0oonDo`3oU?l0ool0g?mG0?l00_oonfX01onC0?oooo]Zool00?oonf[ogOl0oook
J_oBo`000ooonfX01_nho`3ooa`0oookJ_l0oiKooo]Zool0C`Gooo]Z00?o0?n;oookJ_nDo`000onD
o`03oookJP;oo`2e00coob00oookJ_oonf[o0000o`P0ool0ocSo0000oom10?ooW03oNol0oiCo0?oU
o`04odCo0005ool0X?m4o`3oA?l0odCo0?oo0?800ooonfXGodCo00;ooo]Z0ol0X_l01?m4o`3ookl0
oono0?oo_`04o`3oXP?ooo]Z0ol0ob43oookJP;oo`3b00?ooo]ZoiCo0?nDo`000_nDo`02ool0X003
oookJ_mD0?ooE03o00Cooo]Z00?o04coobX0oooonfX01?oonfX01Omko`3ooo]ZoookJ_oo@@3ooi`0
00?ooo]Z00?o0?lho`P0oooonfX02?oonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[ooo]Z
00cooo]Z00?o0?neoookJ_oonfX01?oonfX00ol0oh_ooo]ZoookJP0?oookJP03ool0Cooonf[ooo]Z
00?ooo]Z00?o0?nFoookJ_oonfX01?oonfX01?oUo`3ooo]ZoookJ_nho`0=oookJP03om;o0?oonf[o
ogT000;ooo]Z00?o:`3ooookJ_oonfX01?oonfX00ooUo`3ooo]Zonco0004oookJP03oi<0oooonf[o
oo]Z00Kooo]Z00?oE`3ooookJ_oonfX00_oonfX00ooo0=cooo]ZoookJP12oookJP05obT0oooonf[o
oo]ZoookJ_l0oo002?oonfX00oooj03oo`0;oookJP04oookJP03oole0?oonf[o087o00;ooo]Z00Go
0?nGoookJ_oonf[o0?oXocKo000=oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`02ooonfX00ol0ongo
oo]ZoookJP0:oookJP03oolJ0?lM0?oo0?ob00?ooo]Z00?oo`2doookJ_ooY`002?oonfX02Ol0o`Wo
oo]ZoookJ_oonf[oO03oocCo0?oonf[o00_oool06002oookJP03ok3o0?oonf[o0?_o00?ooo]Z00Co
CP3ooookJ_oonf[oo`0D0_oonfX00oooa`3ooo]ZoookJP03oookJP06oonX0?oo0:Oooo]ZoookJ_oo
8@3oo`2d1?oonfX00ol0oiOooo]ZoookJP02oookJP05ohko0?oo03Wooo]Zo`3o`?oo00L04OoonfX0
0ooo03Sooo]ZogT0o`02oookJP04okSo0?oo0;cooo]Zof`0o`Oooo]Z00kok@3ooigo0?oonf[oo`3L
oookJ_mG0?oooo]Zoi<0oooonf[ok?l0ool00?l[0?oogOl0om;o00Cooo]Z00Ko^?l0oolL0?oonf[o
0?nFoookJ_oo04l5oookJP04o`3oRooonf[ooo]Zo`3o]@Cooo]Z0_oo0;D02ooonf[oob00oookJ_l0
003o203oo`3o>?l0003ooo]Zoom10?mko`3ooo]Z00;oo`X00_lZ0?l01OmD0?ooo`2PoookJ_oonf[o
0?mF00;oo`3b0ooonfX4o`3o8@03o`3oX_oo_`3ookl000Gookl03?oonfX5o`2Ro`;ookl01?l0oj80
0ol0S?oooo]ZoookJP03o`3o8@?ooo]Z0_oo0?800ooonf[o0?mFoookJP02oookJP;oo`2P0_oonfX0
0omD0?oooo]ZoookJP02oookJP03o`1<oolZ0?oooo]Z00Gooo]Z00CoNol0oookJ_oonf[ood400ooo
nfX00ol0ocSo203ooookJP08oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?oo`2eoookJ_oonfX03?oo
nfX00ol0okGooo]ZoookJP04oookJP03o`3oRooonf[ooo]Z00oooo]Z00?oo`1?oookJ_oonfX00_oo
nfX00ol0oiKooo]ZoookJP04oookJP05oolL0?oonf[ooo]ZoookJ_nho`003?oonfX00ooBo`3ooo]Z
omgo0002oookJP03ob/0oooonf[ooo]Z00Cooo]Z00?oo`00oookJ_o/o`001OoonfX00onC0?oooo]Z
oookJP05oookJP03oong0?mG0?oooo]Z00?ooo]Z00?oo`3LoookJ_oonfX07ooonfX002Kooo]Z00Go
:@3ooookJ_oonf[ooo]Zo`3ol008oookJP03oooX0?oo00_ooo]Z00Cooo]Z00?oocD0oookJ_l0POl0
1?oUo`000ol0onSooo]ZocKo000<oookJP03o`3Soooonf[ooo]Z00;ooo]Z00?oolT0oookJ_oonfX0
2OoonfX00ooUo`3ooo]ZoookJP09oookJP03oolJ0?oonf[o7@3o00Cooo]Z00?oogT0oonW0?oonfX0
1OoonfX5oiCo00;ooo]Z00Go=?l0o`0]oooo04oo00_oool06004oiCo0005o`3koonDo`3ooo]Zoook
J_m>0?l00_oonfX01OnDo`3ooo]ZoookJ_oonf[oolL000;ooo]Z0_oob@000oooZ03oolT0ooo90003
oiCo00Cooo]Z00?o0?nGoookJ_oUo`001_oUo`000ooo00Oooo]ZoookJP0@oookJP06ool0>?mi0?oo
oo]ZokSo0?oonf[oo`2l0_oonfX00om/0?oooo]ZoookJP02oookJP;oU?l001Sok@3ooiCo0?oonf[o
oo]ZoeL0oooo]`3o001ooi<0ool007ook?l0ool00?oonf[ogOl0o`00OooBo`3o001ooookJ_l007oo
^?l0oolL0?l007oo0?nFo`00Oooo04l2o`00O`?ooo]Z00?o0?n;o`00OonDo`000onDo`04oookJP03
ool0]Ooo803ooo]Z00?o00000_l0ocP01Ooo@@3ooi`0og_o0?nDo`3oiOl000CoA?l000Coo`2PodCo
0?m4o`3oA?l00ooo0?800ooonf[oA?l0odCo000DodCo00?ookl01_l0oj801?l0S?oooo]ZodCo0?m4
o`03o`3o8@Cooo]Z0_oo0?801Ooonf[o0?mFoiCo0?nDo`3ooo]Z00;oo`2P0_oonfX00omD0?oooo]Z
oookJP02oookJP03o`1<oolZ0?oo:P3o00Gooo]Z00GoNol0oookJ_oonf[ood40oonL0002oookJP;o
0?lh00?o203ooookJ_oonfX01ooonfX00ooo803ooo]ZoookJP03oookJP03ool0]Ooonf[ooo]Z00co
oo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0@oookJP03ool0Cooonf[ooo]Z00;o
oo]Z00?o0?nFoookJ_oonfX01?oonfX01?oUo`3ooo]ZoookJ_nho`0>oookJP05om;o0?oonf[oogT0
oookJ_l[0?l01_oonfX00oooV`3oo`00onco0005oookJP03oi<0oooonf[ooo]Z00Gooo]Z00?oE`3o
oong0?oonfX00ooonfX00ooo0=cooo]ZoookJP12oookJP05obT0oooonf[ooo]ZoookJ_l0oo002?oo
nfX00oooj03oo`0;oookJP05oookJP05oole0?l0POoooo]ZoookJ_l0oiL00_oonfX00ol0onSo=_l0
oookJP0<oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`02ooonfX00ol0ongooo]ZoookJP0:oookJP03
oolJ0?lM0?oo0?ob00?ooo]Z00?oo`2doookJ_ooY`002?oonfX02Ol0o`Wooo]ZoookJ_oonf[oO03o
ocCo0?l0;Ooo00_oool06002oookJP03ok3o0?oonf[o0?_o00?ooo]Z00CoCP3ooookJ_oonf[oo`0D
0ooonfX00oooa`3ooo]ZoookJP02oookJP06oonX0?oonf[oo`2WoookJ_oo8@3oo`2d1OoonfX02_l0
oiOooo]ZoookJ_oonf[oS_l0ool0>Ooonf[o0?o0oookJ_oo00LAoookJP06ool0>?mi0?oooo]Zoook
J_nho`3oo`2l0_oonfX00om/0?oooo]ZoookJP04oookJP0Jond0oooonf[oWOl0oookJ_oo0=coE`3o
o`00OonC0?oo001oonco0?oo003ooo]Zomgo0?l007ood_l0o`00Oooonf[o001ookSo0?l007oooa`0
o`00Ool0oiKo001oool0Col007l3oookJP05o`00Ool0oh_o001oo`00Ool0okD01OoonfX00ooo0;Go
oo]ZoolP0003o`0000;o0?lh00Gooo]Zoom10?mko`3oNol0oookJP02ool:00;o:P3o0_oo0:02oook
JP04o`3oE_oo0?;oo`3bool0lPCooo]Z0ol0ob43o`3oXP;o0:;o3_oo_`05o`3oXP;o08co0_oonfX3
o`3o8@Cooo]Z0_oo0?800ooonf[o0?mFo`3oEP02oookJP;oo`2P0_oonfX2oe@0o`?ooo]Z00?o04co
obX0oolZ0?l01_oonfX01?mko`3ooo]ZoonL0?oo@@02oookJP;o0?lh00?o203ooookJ_oonfX01ooo
nfX00ooo803ooo]ZoookJP03oookJP03ool0]Ooonf[ooo]Z00gooo]Z00?o0?neoookJ_oonfX00ooo
nfX00ol0oh_ooo]ZoookJP0?oookJP03ool0Cooonf[ooo]Z00;ooo]Z00?o0?nFoookJ_oonfX01?oo
nfX01Ooo703ooo]ZoookJ_oonf[o^?l000gooo]Z00?od_l0oookJ_oMo`000_oonfX00ol[0?oooo]Z
oookJP03oookJP03oonK0?oo003ok?l000Gooo]Z00?oT`3ooookJ_oonfX01_oonfX00omG0?oooo]Z
oookJP03oookJP03ool0g?oonf[ooo]Z01oooo]Z000VoookJP05obT0oooonf[ooo]ZoookJ_l0oo00
2?oonfX00oooj03ooo]Zool02`04oookJP03oole0?oonf[o087o00CoiOl000?o0?oXonGo0?lfo`00
3?oonfX00ol0hooooo]ZoookJP02oookJP03ooo90?oonf[ooo]Z00Wooo]Z00?oiOl0oookJ_oonfX0
2OoonfX00ooo6P3ooo]Zoad0o`05oookJP03oomi0?ooY`3ooo]Z00Cooo]Z1_nDo`001_oonf[o=?l0
og`0ool0;Oooo`1?o`0;o`CoU?l000Go0?_ooiCo0?nDo`3ooo]Zodh0o`02oookJP05oiCo0?oonf[o
oo]ZoookJ_ooa`000_oonfX2ooo90003oiCo0?oob@3oolT000CoU?l00ooonfX00ol0oiOooo]ZonGo
0007onGo0003ool01ooonf[ooo]Z00oooo]Z00Koo`0hoookJ_mi0?oooo]ZokSo0?oo0;`2oookJP03
of`0oooonf[ooo]Z00;ooo]Z00SoU?l0oookJ_oonf[ok@3ooookJ_l007ooo`3LoeL0o`;o001o00Wo
T`3oo`00Oooo003ooi/0oookJ_oMo`3od_l0o`00OooonfX00_l007l01onho`3ooa`0o`00Ool0oiKo
001oool0Col007l00_oonfX2o`00O`03o`3oRol007ooU?l000CoU?l00ooonfX00ooo0;Goob00o`00
0003o`000007o`P0ool0ocSo0?lhoom10?mko`3oU?l0onGo0005odCo00?oo`2P0om4o`02ool0lP_o
A?l01ol0oj800om4o`3o0?nRo`3oXP02o`3oXPCo08co00?ooo]ZodCo0?m4o`000ol0ob44oookJP?o
o`3b0ol0oeH2oookJP;oo`2P0_oonfX2oe@0o`Cooo]Z0_lZ0?l00ooo2P3ooo]ZoookJP02oookJP;o
Nol00_oonfX01ooo@@3oU?l0oookJ_oonf[o0?lhoookJ_l80?l02OoonfX00ooo803ooo]ZoookJP03
oookJP03ool0]Ooonf[ooo]Z00cooo]Z00?oiOl0oookJ_oonfX01?oonfX00ol0oh_ooo]ZoookJP0?
oookJP03ool0Cooonf[ooo]Z00?ooo]Z00?o0?nFoookJ_oonfX00ooonfX01OoUo`3ooo]ZoookJ_oo
nf[o^?l000gooo]Z00God_l0oookJ_ooN@3ooo]Zob/0o`06oookJP04oonK0?oo003ooo]Zonco00Co
oo]Z00?oT`3ooookJ_oonfX01OoonfX00omG0?oookL0oookJP03oookJP03ool0g?oonf[ooo]Z04?o
oo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol009oookJP03oooX0?oo00_ooo]Z00Cooo]Z00?oocD0o`21
oooonfX00_oonfX01?l0oiOooo]Zo`3oj?lfo`0=oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`02ooo
nfX00ol0ongooo]ZoookJP0:oookJP03oolJ0?lM0?oo0?ob00Cooo]Z00?oo`2doookJ_ooY`001ooo
nfX00ol0o`Wooo]ZoookJP02oookJP05ocCo0?l0;Ooooo]Zo`0;oooo01P00_oonfX00on`o`3o0?_o
oookJP02oookJP04odh0oooonf[ooo]Zool050?ooo]Z00?oolL0oookJ_oonfX00_oonfX01_ooZ03o
oo]Zool0Yooonf[oob40ool0]0Gooo]Z00[o0?nGoookJ_oonf[ooo]Zohko0?oo03Wooo]Zo`3o`?oo
nf[oo`074OoonfX00ooo03Sooo]ZogT0o`02oookJP05okSo0?oo0;cooo]ZoookJ_m/0?l01_oonfX0
4?o]0?ooWOl0o`00Oooo0=co001ooeL0ool007ooT`3oo`00Ooo/o`3oo`00oookJ_oMo`3od_l0o`00
OooonfX2o`00O`07okSo0?oo703o001oo`00Ool0oiKoo`1?o`00O`02oookJP?o001o00Co0?n;o`00
Ool007oo0?ne1OoonfX00ooo0;Gooo]ZoolP0003o`000003o`P0ool0ocSo0?lh00;ood4000?oNol0
oookJ_oonfX00_oo2P000olZ0?ooE03oool0X002ool0X0;ooo]Z00?o0?mFool0l_oo0?800_oo0?83
oookJPGo0?lQ3_l0oj84o`2<o`;ooo]Z0ol0ob44oookJP?oo`3b0ol0oeH2oookJP;oo`2P0ooonfX0
0omD0?oooo]ZoookJP02oookJP;o:P3o00?oo`X0oookJ_oonfX00ooonfX2og_o0003oookJ_ooW03o
od4000;ooo]Z00?o0?lhoookJ_l80?l02_oonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooonf[o
oo]Z00gooo]Z00?o0?neoookJ_oonfX00ooonfX00ol0oh_ooo]ZoookJP0@oookJP03ool0Cooonf[o
oo]Z00;ooo]Z00?o0?nFoookJ_oonfX00ooonfX01Ooo703ooo]ZoookJ_oonf[o^?l000gooo]Z00?o
d_l0oookJ_oMo`000_oonfX00ol[0?oooo]ZoookJP03oookJP04oonK0?oo003ooo]Zonco00Cooo]Z
00?oT`3ooookJ_oonfX01_oonfX00omG0?oookL0oookJP03oookJP03ool0g?oonf[ooo]Z023ooo]Z
000VoookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01OoonfX00oooj03ooo]Zool0
2`04oookJP03oole0?oonf[o087o00CoiOl000?o0?oXonGo0?lfo`003OoonfX01Ol0hooooo]Zoook
J_oonf[oolT000_ooo]Z00?oiOl0oookJ_oonfX02OoonfX01?oo6P3ooo]Zoad0ool0oo84oookJP03
oomi0?ooY`3ooo]Z00Cooo]Z1_nDo`02oookJP04ocCo0?l0;Oooo`1?o`0;o`CoU?l000Go0?_ooiCo
0?nDo`3ooo]Zodh0o`03oookJP04oiCo0?oonf[ooo]Zooo700;ooo]Z0_oob@001?nDo`3oolT0ooo9
0?oonfX3oiCo00?ooo]Z00?o0?nGoookJ_oUo`001?oUo`001?oonf[o0?o0oookJ_oo00LAoookJP07
ool0>?oonf[oN@3ooookJ_nho`3ooo]Zool0_002oookJP03of`0oooonf[ooo]Z00Cooo]Z00Kok@3o
oiCo0?l007oo001oool0g?mG0?l2o`00O`08oi<0ooo/o`3oo`00oookJ_oMo`3o001oom;o0?oonfX3
o`00O`03okSo0?oo703o0?nF00;ooo]Z00?oo`1?oookJ_l007l00ol007l00ol0oh_oU?l0oiCo0005
oiCo00;ooo]Z00?oo`2eoolP0?oo80000_l00002oookJP03o`P0ool0ocSood4000;oNol000?oiOl0
odCo0?m4o`001Om4o`03ool0X0;oA?l000?o0?mFool0l_m4o`001om4o`05o`3o8@CoA?l01?oonfX7
o`3o8@?oA?l000Cooo]Zool0l_oo0?;oo`3b0ol0oeH3oookJP;oo`2P0ooonfX00omD0?oo02Gooook
JP02oookJP;o:P3o0_oo2P03oookJP;oNol00_oonfX2oom100;oU?l00_l0ocP00ooonf[o203ooook
JP08oookJP03oolP0?oonf[ooo]Z00;ooo]Z0_oo0;D>oookJP03onGo0?oonf[ooo]Z00Cooo]Z00?o
0?n;oookJ_oonfX04?oonfX00ooo04oooo]ZoookJP02oookJP03o`3oU_oonf[ooo]Z00Cooo]Z00Co
iOl0oookJ_oonf[o^?l03_oonfX01OoBo`3ooo]Zoomi0?oonf[o:`3o00Kooo]Z00Coo`00ool0ZOoo
nf[ok?l01?oonfX00onC0?oooo]ZoookJP05oookJP03oeL0oooo]`3ooo]Z00?ooo]Z00?oo`3Loook
J_oonfX0A?oonfX01OlY0?oooo]ZoookJ_oonf[o0?o`00Sooo]Z00?oonP0ool02ooonfX01?oonfX0
0ooo=@3o=ol0o`21o`02oookJP04o`3oUooonf[o0?oXocKo00kooo]Z00Co0>?ooookJ_oonf[oo`3/
2ooonfX00ol0ongooo]ZoookJP0:oookJP03oolJ0?oonf[o7@3o00Cooo]Z00?oo`2doookJ_ooY`00
1ooonfX00ol0o`Wooo]ZoookJP02oookJP05og`0ooldo`3ooo]Zo`0;oooo01P00_oonfX00on`o`3o
0?_ooookJP02oookJP05odh0oooonf[ooo]ZoookJ_oo01@00_oonfX00oooa`3ooo]ZoookJP02oook
JP03oonX0?oonf[oo`2W00;ooo]Z00?oob40oookJ_oonfX00ooonfX00ol0oiOooo]ZoookJP02oook
JP05ohko0?oo03Wooo]Zo`3o`?oo00L04OoonfX00ooo03Sooo]ZogT0o`02oookJP05okSo0?oo0;co
oo]ZoookJ_m/0?l01_oonfX04?o]0?oooo]Zoigo0?l007ooo`3Loong0?mG0?oo001ooi<0ooo/o`3o
oi/0ool00?l[0?oogOl0om;o0?oonfX3o`00O`07okSo0?oo703ooo]Zo`3oU_oonf[oo`1?oookJP04
o`00O`05oookJ_l0oh_o001oo`00Ool0okD01OoonfX01Ooo0;Go0000oolP0?oo803o000000;ooo]Z
00Co203oo`3o>?l0ocSood400_mko`02oookJP05ool:0?lZ0?oo:P3oo`0UoomD0?l00ooo0:02oook
JP;o0?mF0ooo0?85oookJPGo0?lQ2?oonfX7o`3o8@Cooo]Z0ooo0?83o`3oEP?ooo]Z0_oo0:03oook
JP03o`0UoomD0?oooo]Z00;ooo]Z0_lZ0?l2ool:00Cooo]Z0_mko`001Ooonf[ooi`0oom10?oo@@3o
oo]Z00;o0?lh00?ooo]Zo`P0oooonfX02OoonfX01?oo803ooo]ZoookJ_oonfX2ool0]@oooo]Z00?o
0?neoookJ_oonfX01?oonfX00ol0oh_ooo]ZoookJP0?oookJP03ool0Cooonf[ooo]Z00;ooo]Z00?o
0?nFoookJ_oonfX01?oonfX01Ooo703ooo]ZoookJ_oonf[o^?l000gooo]Z00?od_l0oookJ_oMo`00
0_oonfX00ol[0?oooo]ZoookJP03oookJP04ool00?oo0:Wooo]Zonco00Cooo]Z00?oT`3ooookJ_oo
nfX01_oonfX00omG0?oooo]ZoookJP02oookJP03ool0g?oonf[ooo]Z027ooo]Z000VoookJP03obT0
oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01OoonfX00oooj03ooo]Zool02`04oookJP03oole
0?oonf[o087o00CoiOl000?o0?oXonGo0?lfo`003OoonfX01Ol0hooooo]ZoookJ_oonf[oolT000_o
oo]Z00?oiOl0oookJ_oonfX02OoonfX01?oo6P3ooo]Zoad0ool0oo84oookJP03oomi0?ooY`3ooo]Z
00Cooo]Z1onDo`001Ooonf[o=?l0o`0]oooo04oo00_o00CoU?l000Ko0?_ooiCo0?nDo`3oU?l0oook
J_m>0?l2oookJP06oiCo0?oonf[ooo]ZoookJ_ooa`3ooo]Z0_oob@02oiCo0003ooo90?oonf[oU?l0
00?oU?l00ooonfX02_l0oiOoiOl0onGo0?oonf[oiOl0oookJ_oo03Wo0?o0oookJ_oo00LBoookJP06
ool0>?oonf[oN@3ooookJ_nho`3oo`2l0ooonfX00om/0?oooo]ZoookJP04oookJP0@ond0ool007oo
001oool0g?mG0?oooo]Zo`00OonC0?oo001oool00?ooV`3ooo]Zomgo0?oonf[od_l0oookJP;o001o
00Oo^?l0oolL0?oonf[o0?nFoookJ_oo04oooo]Z00?o001o0_oonfX00ol0oh_oU?l0oiCo0006oiCo
0003oookJ_oo0;Goo`2e00;oob000ooonfX01?l80?oo0?lho`3o>?nDo`03og_o00SoA?l00ooo0:02
oookJPOoA?l00ooonfX2odCo00So0?lQ2_m4o`000ooo0?;o0?mFodCo0003odCo00;ooo]Z0_oo0:02
oookJP03o`0UoomD0?ooE03o00;ooo]Z0olZ0?l2ool:00?ooo]Z0_mko`02oookJP03oonL0?oo@@3o
U?l000;oU?l000Co0?lhoiCo0?nDo`3oU?l02OoonfX00ooo803ooo]ZoookJP02oookJP03ool0]Ooo
nf[ooo]Z00Sooo]Z0_oUo`03oookJP03onGo0?oonf[ooo]Z00Gooo]Z00?o0?n;oookJ_oonfX03ooo
nfX00ooo04oooo]ZoookJP02oookJP03o`3oU_oonf[ooo]Z00Cooo]Z00CoiOl0oookJ_oonf[o^?l0
2ooonfX2oomi00;ooo]Z00Cod_l0oomi0?oonf[o:`3o1_oonfX01?ooV`3oo`00oookJ_o/o`04oook
JP03oi<0oooonf[ooo]Z00Gooo]Z00?oE`3ooookJ_oo]`000ooonfX00ooo0=cooo]ZoookJP15oook
JP05obT0oooonf[ooo]ZoookJ_l0oo002?oonfX00oooj03oo`0;oookJP04oookJP03oole0?lgo`3o
087o00;ooo]Z00Go0?nGoookJ_l0onSooo]ZocKo000=oookJP04o`3Soooonf[ooo]Zool0k0_ooo]Z
00?o0?o]oookJ_oonfX02_oonfX00ooo6P3ooo]Zoad0o`04oookJP03ool0]?oonf[oojL000Oooo]Z
00?o0?l9oookJ_oonfX00_oonfX01Oml0?oo=?l0oookJ_l02oooo`0H00;ooo]Z00?o/?l0o`3koooo
nfX00ooonfX01?m>0?oooo]ZoookJ_oo01@3oookJP03ooo70?oonf[ooo]Z00;ooo]Z00KoojP0ool0
Yooonf[ooo]ZoolQ0?oo0;@5oookJP0:o`3oUooonf[ooo]ZoookJ_n>o`3oo`0ioookJ_l0ol3ooo]Z
ool01a7ooo]Z00?oo`0hoookJ_mi0?l00_oonfX01Onho`3oo`2loookJ_oonf[oK03o00Kooo]Z013o
k@3ooigo0?l007oooo]Zool0g?mG0?oo001ooi<0ool007ook?l0ool00?oonf[ogOl0oookJ_oBo`3o
oo]Z0ol007l01_nho`3ooa`0oookJ_l0oiKooo]Zool0C`?o001o0ooonfX01?l0oh_o001oo`00Ool0
okD5oookJP;oo`2e00?o0000oolP0?oonfX00_oonfX00ol80?oooo]Zo`3o>002oom100;oNol00_oo
nfX01?oo2P3o:P3oobX0oooonfX2oe@0o`?oo`2P0ooonfX00ol0oeKoo`3bool0lP03ool0lPGooo]Z
2?l0ob48oookJP?oo`3b0ol0oeH4oookJP;oo`2P0_oonfX01?l09OooE03ooe@0oomD0?l2oookJP;o
:P3o0_oo2P04oookJP;oNol000Cooo]ZoonL0?oo@@3ood400_oonfX01?l0ocSooo]Zo`P0ool80?l:
oookJP05oolP0?oonf[ooo]ZoookJ_oo0;D04?oonfX00ol0okGooo]ZoookJP04oookJP03o`3oRooo
nf[ooo]Z013ooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP06oookJP05oolL0?oonf[ooo]ZoookJ_nh
o`003_oonfX01OoBo`3ogOl0oookJ_oonf[o:`3o00Gooo]Z00Cooi/0ool00?oonf[ok?l01?oonfX0
0onC0?oooo]ZoookJP06oookJP03oeL0oooo]`3ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX08OoonfX0
02Kooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP06oookJP03oooX0?oo00_ooo]Z
00?ooo]Z00?oocD0oookJ_l0POl01?oUo`000ol0onSoiOl0ocKo000=oookJP05o`3Soooonf[ooo]Z
oookJ_oob@002ooonfX00ol0ongooo]ZoookJP0:oookJP03oolJ0?lM0?oo0?ob00Cooo]Z00?oogT0
oonW0?oonfX01?oonfX8oiCo0004ocCo0?l0;Ooooo]Zo`0;o`GoU?l000Go0?_ooookJ_oonf[ooo]Z
odh0o`02oookJP05oiCo0?oonf[ooo]ZoookJ_ooa`000ooonfX3oiCo0003ooo90?nDo`3oU?l000?o
U?l00_oonfX02?l0oiOooo]ZoookJ_oonf[oiOl0oookJ_oo03Wo0?o00_oonfX00ooo00Oooo]Zoook
JP0?oookJP06ool0>?oonf[oN@3ooookJ_nho`3oo`2l0ooonfX00om/0?oooo]ZoookJP04oookJP06
o`00Ooo]0?oo001ooookJ_oo0=coE`3o0_l007l01onC0?oooo]Zool00?oonf[o:`3oomgo0?oBo`00
0_oonfX2o`00O`06okSo0?oo703o001oo`3oU_oonf[oo`1?1_oonfX00ol0oh_oU?l0oiCo0006oiCo
00;o000000Coo`2eo`000?oo803o00000_oonfX2o`P0o`;o0?lh00CoU?l0onGo0?mko`3oNol01om4
o`02oe@0o`?oo`2P00?ooo]ZodCo0?m4o`000om4o`05ool0lQSoA?l00_oo0:000ooonf[o02Gooe@0
o`02oe@0o`;ooo]Z0_lZ0?l00ol0C?ooo`X0ool:0003oookJP;oNol00ooonfX2oom100;oU?l00_l0
ocP3oiCo00Wooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP09oookJP?oiOl000?o
oo]ZonGo0?oonfX01_oonfX00ol0oh_ooo]ZoookJP0?oookJP03ool0Cooonf[ooo]Z00;ooo]Z00?o
0?nFoookJ_oonfX01?oonfX01OoUo`3ooo]ZoookJ_oonf[o^?l000_ooo]Z1_ooN@000ooonf[o:`3o
oookJP05oookJP04ool00?oonf[ooo]Zonco00?ooo]Z00?oT`3ooookJ_oonfX01_oonfX00omG0?oo
okL0oookJP03oookJP03ool0g?oonf[ooo]Z04Gooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol008oook
JP03oooX0?oo00_ooo]Z00Cooo]Z00?oocD0oookJ_l0POl00_oonfX01Ol0oiOooo]Zo`3oj?oonf[o
=_l000gooo]Z00Co0>?ooookJ_oonf[oo`3/2ooonfX00ol0ongooo]ZoookJP0;oookJP03oolJ0?lM
0?oo0?ob00?ooo]Z00?oo`2doookJ_ooY`002?oonfX02Ol0o`Wooo]ZoookJ_oonf[oO03oocCo0?l0
;Ooo00_oool06002oookJP03ok3o0?oonf[o0?_o00?ooo]Z00CoCP3ooookJ_oonf[oo`0D0ooonfX0
0oooa`3ooo]ZoookJP02oookJP06oonX0?oonf[oo`2WoookJ_oo8@3oo`2d1OoonfX02_l0oiOooo]Z
oookJ_oonf[oS_l0ool0>Ooonf[o0?o0oookJ_oo00LAoookJP03ool0>?oonf[oN@3o00;ooo]Z00Go
^?l0ool0_?oonf[ooo]Zof`0o`06oookJP0?o`00Ooo]0?ooWOl0oookJ_oo0=cooo]ZoeL0ool007oo
T`3ooookJ_o/o`3oo`00ob/0oooMo`3od_l000;ooo]Z0ol007l01_oo703o001ooookJ_l0oiKooo]Z
ool0C`Gooo]Z00Go001oo`3oRol007oooo]Zo`3o]@04oookJP;o000000Coo`2eo`000?oo803oob00
0_oonfX2o`P0o`;o0?lh0_oo@@03og_o0005oookJ_oo2P3o:P3oobX0oooonfX00omD0?l3ool0X0?o
oo]Z0ol0oeH5ool0lPSooo]Z2?oo0?83o`3oEPGooo]Z0_oo0:000ooonf[o02Gooe@0o`02oe@0o`?o
oo]Z0_lZ0?l2ool:00Cooo]Z0_mko`02oookJP04oonL0?oo@@3ooo]ZoookJP;o0?lh00?ooo]Zo`P0
oooonfX02_oonfX01Ooo803ooo]ZoookJ_oonf[oo`2e013ooo]Z00?o0?neoookJ_oonfX01?oonfX0
0ol0oh_ooo]ZoookJP0@oookJP05ool0Cooonf[ooo]ZoookJ_l0oiH01_oonfX01Ooo703ooo]Zoook
J_oonf[o^?l000kooo]Z00God_l0oookJ_oMo`3ooo]Zob/0o`06oookJP04ool00?oo0:Wooo]Zonco
00Cooo]Z00?oT`3ooookJ_oonfX01_oonfX00omG0?oookL0oookJP02oookJP03ool0g?oonf[ooo]Z
02;ooo]Z000WoookJP05obT0oooonf[ooo]ZoookJ_l0oo002?oonfX00oooj03oo`0;oookJP03oook
JP03oole0?oonf[o087o00GoiOl000?o0?oXocKo0?oUo`003?oonfX00ol0hooooo]ZoookJP02oook
JP03ooo90?oonf[ooo]Z00Sooo]Z00?o0?o]oookJ_oonfX02_oonfX00ooo6P3ooo]Zoad0o`04oook
JP03oomi0?oonf[oojL000Cooo]Z2?nDo`001_ml0?oo=?l0oookJ_oo04oo00_ooiCo00;ooo]Z00?o
U?l0o`3koooonfX00_oonfX01?m>0?oooo]ZoookJ_nDo`03oookJP04ooo70?oonf[ooo]ZoookJP?o
U?l000?oolT0oiCo0?nDo`001?nDo`02oookJP0:o`3oUooonf[ooo]ZoookJ_oUo`3oo`0ioookJ_l0
ol3ooo]Zool01a;ooo]Z00Koo`0hoookJ_mi0?oo^?l0oookJ_oo0;`3oookJP03of`0oooonf[ooo]Z
00?ooo]Z00Wo001oond0oonMo`3ooo]Zool0g?oo]`3oE`3oo`00OonC0?l00_oonfX01Ooo003ooo]Z
omgo0?oonf[od_l000?ooo]Z00Oo001ookSo0?oo703o001oo`3oU_oonf[oo`1?00Gooo]Z00?o001o
o`3oRonDo`002?nDo`000ol0003oo`2eoookJP02oolP00?ooo]Z00Ko203ooookJ_l0ocSoU?l0onGo
0?m4o`02og_o00GoA?l000?o:P3ooookJ_mD0?l00_mD0?l3ool0X0;oA?l01_oonfX2ool0lQ;oA?l0
1?oo0:001?oonf[oE03ooe@0oomD0?l3oookJP;o:P3o0ooo2P02oookJP;oU?l000CoNol0oookJ_oo
nf[ooo]Z0_oo@@001?oonf[oU?l0oiCo0?l0ocP6oiCo00Oooo]Z00?oob00oookJ_oonfX00_oonfX0
0ooo0;Gooo]ZoookJP09oookJPGoiOl01ooonfX00ol0oh_ooo]ZoookJP0@oookJP03ool0Cooonf[o
oo]Z00;ooo]Z00?o0?nFonGo0?oUo`001?oonfX01?oUo`3ooo]ZoookJ_nho`0<oookJPOoogT01_oo
nfX01?ooV`3oo`00oookJ_o/o`04oookJP03oi<0oooonf[ooo]Z00Gooo]Z00?oE`3ooookJ_oo]`00
0ooonfX00ooo0=cooo]ZoookJP16oookJP05obT0oooonf[ooo]ZoookJ_l0oo002?oonfX00oooj03o
o`0;oookJP04oookJP03oole0?oonf[o087o00;ooo]Z00Go0?nGoookJ_l0onSooo]ZocKo000=oook
JP05o`3Soooonf[ooo]ZoookJ_oo0>`02_oonfX00ol0ongooo]ZoookJP0;oookJP03oolJ0?lM0?oo
0?ob00?ooo]Z00Coo`2doookJ_oonf[oojL01ooonfX02Ol0o`Wooo]ZoookJ_oonf[oO03oocCo0?l0
;Ooooo]Zo`0;o`03oookJP03ok3o0?l0nooooo]Z00;ooo]Z00CoCP3ooookJ_oonf[oo`0D0ooonfX0
0oooa`3ooo]ZoookJP02oookJP03oonX0?oonf[oo`2W00;ooo]Z00?oob40oookJ_oonfX01?oonfX0
2Ol0oiOooo]ZoookJ_oonf[oS_l0ool0>Ooonf[o0?o0ool01`0BoookJP07ool0>?oonf[oN@3ooook
J_nho`3ooo]Zool0_002oookJP03of`0oooonf[ooo]Z00?ooo]Z00Wo001oond0ool007ooWOl0oook
J_oo0=cookL0oeL0oonC0?l00_oonfX01Oo/o`3oo`00omgo0?oonf[od_l000?ooo]Z00So001ookSo
0?oo703o001ooookJ_l0oiKooo]Zool0C`Cooo]Z0_l007l01?l0oh_ooo]ZoookJ_l0okD3oookJP?o
000000?oo`2eoookJ_oonfX00_oo8002oookJP04o`P0oooonf[o0?lho`3o>0;ood4000?ooo]Zog_o
0?mko`000_oonfX3obX0o`04oookJ_mD0?ooE03ooe@0o`Coo`2P1ooonfX8ool0lPCo0?mF2?oonfX4
ool0X004oookJ_mD0?ooE03ooe@0o`Cooo]Z0_lZ0?l2ool:00Gooo]Z00CoNol0oookJ_oonf[ooi`0
0_oo@@02oookJP04o`3o>?oonf[o203oo`P0o`_ooo]Z00Goob00oookJ_oonf[ooo]Zool0]@0@oook
JP03o`3o]Ooonf[ooo]Z00Gooo]Z00?o0?n;oookJ_oonfX04?oonfX01Ooo04oooo]ZoookJ_oonf[o
0?nF00Kooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000>oookJP05om;o0?oMo`3ooo]ZoookJ_l[0?l0
1OoonfX01?ooV`3oo`00ool0ZOo/o`04oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?oE`3ooong0?oo
nfX00ooonfX00ooo0=cooo]ZoookJP0RoookJP009ooonfX01OlY0?oooo]ZoookJ_oonf[o0?o`00So
oo]Z00?oonP0ool02ooonfX01?oonfX00ooo=@3oiOl0o`21o`04onGo0003o`3oj?oonf[o=_l000co
oo]Z00?o0>?ooookJ_oonfX00_oonfX00ooob@3ooo]ZoookJP09oookJP03o`3okOoonf[ooo]Z00Wo
oo]Z00CooaX0oookJ_lM0?oo0?ob0ooonfX00oooN@3ooo]ZoonW0004oookJPWoU?l000Co=?l0o`0]
oooo04oo00_o0ooonfX00onDo`3o0?_ooookJP02oookJP05odh0oooonf[ooo]ZoookJ_nDo`000ooo
nfX00oooa`3ooo]ZoookJP0:oiCo00;ooo]Z00[o0?nGoookJ_oonf[ooo]ZonGo0?oonf[oo`0ioiCo
0?oonf[oo`074_oonfX01_oo03Sooo]ZogT0oooonf[o^?l0ool0_0?ooo]Z00?oK03ooookJ_oonfX0
0ooonfX2o`00O`0?ond0oooonf[ooo]Zool0g?mG0?ooU?l0o`00OonC0?oooo]Zonco0?oo003ooo]Z
omgo0?oonf[od_l000?ooo]Z00So^?l0o`00Oooo703ooo]Zo`3oU_oonf[oo`1?o`00O`;ooo]Z0ol0
07l00ol0oh_oU?l0oiCo0007oiCo0004o`000?oo0;Gooo]ZoookJP;oob000_oonfX2o`P0o`GoA?l0
0omko`02odCo0006ool:0?lZ0?oo:P3oobX0oooonf[o02Go0omD0?l01?m4o`3oo`2Pool0X?oo0:03
oookJPkoA?l01_oo0:02odCo00?oE03o0ooonfX3obX0o`;oo`X01?oonfX00onDo`3oNol0og_o0002
oookJP04oonL0?oo@@3ooo]ZoookJP;oU?l000?o0?lhoiCo0?nDo`001_nDo`05oookJP04oolP0?oo
nf[ooo]ZoookJP;oo`2e2ooonfX7onGo00Kooo]Z00?o0?n;oookJ_oonfX03ooonfX00ooo04oooo]Z
oookJP02oookJP03o`3oU_oonf[oiOl000?oiOl000Gooo]ZonGo0?oonf[ooo]ZokSo000<oookJPWo
ogT01?oonfX01?ooV`3oo`00oookJ_o/o`04oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?oE`3ooook
J_oo]`000_oonfX00ooo0=cooo]ZoookJP03oookJP03oigo0?oonf[ooo]Z047ooo]Z00Go:@3ooook
J_oonf[ooo]Zo`3ol008oookJP03oooX0?oo00_ooo]Z00Cooo]Z00?oocD0oookJ_l0POl00_oonfX0
1Ol0oiOooo]Zo`3oj?oonf[o=_l000gooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00;oookJP03o`3o
kOoonf[ooo]Z00[ooo]Z00?ooaX0oad0ool0oo800ooonfX01?oo0;Cooo]ZoookJ_ooY`07oookJP03
o`3o2Ooonf[ooo]Z00;ooo]Z00GoO03oocCo0?oonf[o00_oool06002oookJP03ok3o0?l0nooooo]Z
00;ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05003oookJP03ooo70?oonf[ooo]Z00;ooo]Z00KoojP0
ool0Yooonf[ooo]ZoolQ0?oo0;@5oookJP0:o`3oUooonf[ooo]ZoookJ_n>o`3oo`0ioookJ_l0ol3o
oo]Zool01a7ooo]Z00?oo`0hoookJ_mi0?l00_oonfX00onho`3oo`2loookJP02oookJP03of`0oooo
nf[ooo]Z00;ooo]Z0_l007l03oo]0?ooWOl0oookJ_oonf[oo`3LoeL0ool007ooT`3ooookJ_o/o`3o
oi/0ool00?oMo`3ooo]Zom;o0003oookJP03o`00Oonho`3ooa`000;ooo]Z00?o0?nFo`00Oooo04l0
0_oonfX4o`00O`04o`3oRooonf[ooo]Zo`3o]@;ooo]Z1?l000001Ooo0;Gooo]ZoookJ_oonf[oob00
00;ooo]Z0_l80?l01_oonf[o0?lho`3o>?oo@@3ooi`0oookJP;oNol00_oonfX01?oo2P3o:P3oobX0
oolZ0?l2oookJP?oE03o1?oo0:0@oookJPOoo`2P0_oonfX3oe@0o`Cooo]Z0olZ0?l2ool:00Gooo]Z
0_mko`001?oonf[ooi`0oom10?oo@@03oookJP03o`3o>?l80?oo203o00cooo]Z00Goob00oookJ_oo
nf[ooo]Zool0]@0@oookJP03o`3o]Ooonf[ooo]Z00Gooo]Z00?o0?n;oookJ_oonfX04?oonfX01Ooo
04oooo]ZoookJ_oonf[o0?nF00Kooo]Z00Gooa`0oookJ_oonf[ooo]ZokSo000>oookJP05om;o0?oo
nf[ogOl0oookJ_l[0?l01OoonfX01?ooV`3oo`00ool0ZOo/o`05oookJP03oi<0oooonf[ooo]Z00Ko
oo]Z00?oE`3ooong0?oonfX00_oonfX00ooo0=cooo]ZoookJP03oookJP03oigo0?oonf[ooo]Z01go
oo]Z000WoookJP05obT0oooonf[ooo]ZoookJ_l0oo002?oonfX00oooj03oo`0;oookJP04oookJP03
oole0?oUo`3o087o00;ooo]Z00GoiOl0oookJ_l0onSooo]ZocKo000=oookJP05o`3Soooonf[ooo]Z
oookJ_oob@002ooonfX00ol0ongooo]ZoookJP09oookJP04oolJ0?oonf[o7@3oo`3olP?ooo]Z00?o
ogT0oookJ_ooY`001?oonfX6oiCo00?ooo]Z00Go=?l0o`0]oooo04oo00_oool06002oookJP03oiCo
0?l0nooooo]Z00?ooo]Z00CoCP3ooookJ_oonf[oU?l00ooonfX00oooa`3ooo]ZoookJP0;oiCo0003
oookJ_l0oiOooo]Z00;ooo]Z00CoiOl0oookJ_oo03WoU?l00_oonfX00ooo00Oooo]ZoookJP0@oook
JP05ool0>?oonf[oN@3ookSo0?oonfX00_oUo`02oookJP03of`0oooonf[ooo]Z00;ooo]Z0ol007l0
3oo]0?oooo]Zool0g?nDo`3oE`3ooiCo0?oonf[oT`3ooookJ_o/o`3oo`00oookJ_oMo`3ooo]Zom;o
0003oookJP07okSo0?l007oooa`0oookJ_l0oiKo001oool0C`05o`00O`03oookJ_l0oh_oU?l000Ko
U?l00_l000000ooonf[oo`2eoookJP02oookJP05oolP0?oonf[ooo]ZoookJ_l80?l01om4o`03og_o
0003odCo0?oo2P3oo`X000?o:P3o00?ooo]Zo`0UoomD0?l00omD0?l00ooo0:3oA?l0odCo000HodCo
0005oookJ_lZ0?oo:P3oobX0ool0C?l00_oo2P04oookJP03oiCo0?mko`3oNol000;oU?l000?ooo]Z
oom10?oo@@000_oonfX00onDo`3o0?lho`3o>007oiCo00Gooo]Z0_oo8003oookJP03ool0]Ooonf[o
oo]Z00_ooo]Z2?oUo`03oookJP;o0?n;4_oonfX01_oo04oooo]ZoookJ_oonf[o0?nFoookJPKoiOl0
0ooonfX00onho`3ooo]ZoookJP0:oookJPWoogT01?oonfX01?oo003oo`2YoookJ_o/o`04oookJP03
oi<0oooonf[ooo]Z00Gooo]Z00?oE`3ooookJ_oo]`000ooonfX00ooo0=cooo]ZoookJP03oookJP03
oigo0?oonf[ooo]Z047ooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP05oookJP03
oooX0?oo00_ooo]Z00Cooo]Z00?oocD0oookJ_l0POl00ooonfX01?l0oiOo0?oXoookJ_lfo`0>oook
JP04o`3Soooonf[ooo]Zool0k0_ooo]Z00?o0?o]oookJ_oonfX02_oonfX00ooo6P3ooo]Zoad0o`03
oookJP04ool0]?oonf[ooo]ZoonW00Oooo]Z00?o0?l9oookJ_oonfX00_oonfX01Oml0?oo=?l0oook
J_l02oooo`0H00;ooo]Z00?o/?l0o`3koooonfX00ooonfX01?m>0?oooo]ZoookJ_oo01@3oookJP03
ooo70?oonf[ooo]Z00;ooo]Z00?oojP0oookJ_oo0:L00_oonfX00ooo8@3ooo]ZoookJP03oookJP0:
o`3oUooonf[ooo]ZoookJ_n>o`3ooo]Zool0>Ol0ol3ooo]Zool01a;ooo]Z00Ooo`0hoookJ_mi0?oo
oo]ZokSo0?oonf[oo`2l00;ooo]Z00?oK03ooookJ_oonfX00_oonfX3o`00O`0?ond0oonMo`3ooo]Z
ool0g?oo]`3oE`3ooookJ_nC0?oooo]Zonco0?oo003ooo]Zomgo0?oonf[od_l000?ooo]Z00?o001o
okSo0?oo70000_oonfX00ol0oiKo001oool0C`04o`00O`;ooo]Z00Go0?n;oookJ_oonf[o0?neoook
JP04o`000003oookJ_oo0;Gooo]Z00;ooo]Z0_oo8002oookJP?o203o0_l0ocP00ooo@@3ooi`0oook
JP03og_o0003oookJ_oo2P3oo`X000?o:P3o00?o04cooookJ_l09Ol00omD0?l@ool0X003oookJ_mD
0?ooE03o00KoE03o1?oonfX3obX0o`03oookJ_oo2P3oo`X000Gooo]Z0_mko`02oookJP;ood400ooo
nfX2o`3o>003o`P0oooonf[ooo]Z00[ooo]Z0_oo8003oookJP03ool0]Ooonf[ooo]Z00kooo]Z00?o
0?neoookJ_oonfX01?oonfX2o`3oRa;ooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP06oookJP05oolL
0?oonf[ooo]ZoookJ_nho`003_oonfX00ooBo`3ooo]Zomgo0002oookJP03ob/0oooonf[ooo]Z00?o
oo]Z00Coo`00oookJ_oo0:Wok?l01?oonfX00onC0?oooo]ZoookJP06oookJP03oeL0oooo]`3ooo]Z
00?ooo]Z00?oo`3LoookJ_oonfX00ooonfX00onMo`3ooo]ZoookJP0MoookJP009ooonfX00olY0?oo
oo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0oookJ_oo00/01?oonfX00ooo=@3o
oo]Zo`21o`02oookJP05onGo0?oonf[o0?oXoookJ_lfo`003OoonfX01Ol0hooooo]ZoookJ_oonf[o
olT000_ooo]Z00?o0?o]oookJ_oonfX02OoonfX01?oo6P3ooo]Zoad0ool0oo84oookJP03oomi0?oo
Y`3ooo]Z00?ooo]Z0_nDo`02oookJP03oiCo0?oonf[ooo]Z00;ooo]Z00Go=?l0o`0]oooonf[o00_o
ool06003oookJP03oiCo0?l0nooooo]Z00;ooo]Z00CoCP3ooookJ_oonf[oU?l00ooonfX00oooa`3o
oo]ZoookJP0<oiCo0003oookJ_l0oiOooo]Z00;ooo]Z00KoiOl0ool0>OnDo`3oU?l0oookJ_oo00LB
oookJP05ool0>?oonf[oN@3ooookJ_nho`000ooUo`000ooonf[oK03ooookJP03oookJP?o001o00So
k@3ooigo0?oonf[oo`3LoiCo0?mG0?ooU?l0oi<0o`;ooo]Z00Goo`00oonK0?l007oogOl0om;o0003
oookJP08o`00OonDo`3oU?l0oolL0?oonf[o0?nFo`00Oooo04l3o`00O`?ooo]Z00?o0?n;oiCo0?nD
o`000onDo`03o`0000;ooo]Z0_oo0;D2oookJP;oob000ooonfX9odCo00?oNol000?ooo]Zool:0?oo
2P001?lZ0?l6o`0UoaGoA?l00olZ0?l4ool:00Cooo]Z0omko`03oiCo00;ood400ooonfX00onDo`3o
0?lhoiCo0005oiCo00Oooo]Z00?oob00oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP0;oookJP[o
iOl000?ooo]Zo`3oRooonfX04_oonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00;ooo]Z2?oUo`000onh
o`3ooo]ZoookJP0;oookJPSoogT01?oonfX01?ooV`3oo`00oookJ_o/o`04oookJP03oi<0oooonf[o
oo]Z00Kooo]Z00?oE`3ooong0?oonfX00_oonfX00ooo0=cooo]ZoookJP03oookJP03oigo0?oonf[o
oo]Z04;ooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP06oookJP03oooX0?oo00_o
oo]Z00?ooo]Z00?oocD0oookJ_l0POl00ooonfX01?l0oiOooo]Zo`3oj?lfo`0>oookJP04o`3Soooo
nf[ooo]Zool0k0_ooo]Z00?o0?o]oookJ_oonfX02_oonfX01?oo6P3ooo]Zoad0ool0oo83oookJP03
ool0]?oonf[oojL000Sooo]Z00Wo0?l9oookJ_oonf[ooo]Zog`0ooldo`3o02goo`0;oooo01P00ooo
nfX00on`o`3o0?_ooookJP02oookJP04odh0oooonf[ooo]Zool050?ooo]Z00?oolL0oookJ_oonfX0
0ooonfX01OooZ03oo`2WoookJ_oonf[oob4000Kooo]Z00Wo0?nGoookJ_oonf[ooo]Zohko0?oo03Wo
oo]Zo`3o`?oo00L04_oonfX01ooo03Sooo]ZoookJ_mi0?oooo]ZokSo0?oo0;`00ooonfX01?m/0?oo
oo]ZoookJ_oonfX3o`00O`08ond0oooonf[oWOl0o`00Oooo0=cookL0oeL0oonC0?l2oookJP05onco
0?oo003o001oomgo0?oBo`000ooonfX2o`00O`07okSo0?oo703ooo]Zo`00Ool0oiKo001oool0C`02
o`00O`Cooo]Z00?o0?n;oookJ_oonfX00_l0okD3o`0000;ooo]Z0_oo0;D3oookJP03oolP0?oonf[o
oo]Z00;ooo]Z0_l80?l2o`3o>004oom10?ooW03ooo]ZoookJP?oNol000?ooo]Zool:0?oo2P001?lZ
0?l00ol0C?oo02Goo`0Uo`04o`0Uo`coE03o1?l09Ol4oookJPCo:P3o1?oo2P04oookJP?oNol00_oo
nfX00oooW03ood40oookJP03oookJP03o`3o>?l80?oo203o00_ooo]Z0_oo8003oookJP;oo`2e4?oo
nfX00ol0okGooo]ZoookJP04oookJP03o`3oRooonf[ooo]Z01;ooo]Z00Coo`1?oookJ_oonf[o0?nF
1_oonfX00ooo703ooo]ZoookJP02oookJP03okSo0?oonf[ooo]Z00_ooo]Z00Kod_l0oookJ_oonf[o
gOl0oookJ_l[0?l5oookJP04oonK0?oo003oo`2Yonco00Gooo]Z00?oT`3ooookJ_oonfX01_oonfX0
0omG0?oooo]ZoookJP02oookJP03ool0g?oonf[ooo]Z00?ooo]Z00?oWOl0oookJ_oonfX07_oonfX0
02Oooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP05oookJP03oooX0?oonf[oo`0;
00Cooo]Z00?oocD0oookJ_l0POl00_oonfX01OoUo`3ooo]Zo`3oj?oonf[o=_l000gooo]Z00Go0>?o
oookJ_oonf[ooo]Zooo9000;oookJP03o`3okOoonf[ooo]Z00Wooo]Z00CooaX0oookJ_oonf[o7@3o
1?oonfX00oooN@3ooo]ZoonW0007oookJP03oiCo0?oonf[ooo]Z00;ooo]Z00GoO03oocCo0?oonf[o
o`1?o`0;o`03oookJP03oiCo0?l0nooooo]Z00;ooo]Z00CoCP3ooookJ_oonf[oU?l01?oonfX00ooo
a`3ooo]ZoookJP0<oiCo0007o`3oUooonf[ooo]ZoookJ_oUo`3ooo]Zool0>@02oiCo0003oookJ_oo
00Oooo]Z017ooo]Z00Goo`0hogT0oooonf[o^?l0oookJP03onGo0003oookJ_m/0?oooo]Z00;ooo]Z
0ol007l01_oonf[ok@3ooookJ_l007ooo`3LoeL0o`;oU?l000SoT`3ooookJ_nDo`3oo`00oiCo0?l[
0?oogOl0om;o00;ooo]Z00Wo001ooiCo0?nDo`3oU?l0oolL0?l007oo0?nFoookJ_oo04l01OoonfX0
0onDo`3o0?n;o`3oR`02oiCo0004o`000?l0okGo0000o`0000Cooo]Z0_oo0;D2oookJP;oob000ooo
nfX:odCo00?oNol00_oonfX2ool:00Oo:P3o0_l0C?l00ol09OooA?l0odCo0009odCo00;o04co00Co
o`X0obX0oolZ0?oo:P3o0ooo2P05oookJP?oNol01OnDo`000ooo@@3oU?l0oiCo0002oookJP;o0?lh
1?nDo`08oookJP;oob001?oonfX00ooo0;Gooo]ZoookJP0<oookJPSoiOl00_oonfX00ol0oh_ooo]Z
oookJP0AoookJP03ool0Cooonf[ooo]Z00;ooo]Z00?o0?nFoookJ_oonfX02OoUo`0=oookJPOoogT0
1OoonfX00ooo003oo`2Yonco0005oookJP03oi<0oooonf[ooo]Z00Gooo]Z00?oE`3ooookJ_oo]`00
0ooonfX00ooo0=cooo]ZoookJP03oookJP03oigo0?oonf[ooo]Z04;ooo]Z00?o:@3ooookJ_oonfX0
0_oonfX00ol0oo3ooo]ZoookJP06oookJP03oooX0?oo00_ooo]Z00Cooo]Z00?oocD0o`21oooonfX0
0_oonfX01?l0oiOooo]Zo`3oj?lfo`0>oookJP04o`3Soooonf[ooo]Zool0k0_ooo]Z00?o0?o]oook
J_oonfX02_oonfX01?oo6P3ooo]Zoad0ool0oo83oookJP04ool0]?oonf[ooo]ZoonW00Oooo]Z00Wo
0?l9oookJ_oonf[ooo]Zog`0ooldo`3o02gooookJ_l02ol00ooonfX00on`o`3o0?_ooookJP02oook
JP04odh0oooonf[ooo]Zool050Cooo]Z00?oolL0oookJ_oonfX00_oonfX01_ooZ03oo`2WoookJ_oo
nf[oob40ool0]0Gooo]Z00[o0?nGoookJ_oonf[ooo]Zohko0?oo03Wooo]Zo`3o`?oonf[oo`074_oo
nfX01ooo03Sooo]ZogT0oooonf[o^?l0oookJ_oo0;`00_oonfX01?m/0?oooo]ZoookJ_oonfX3o`00
O`0@oookJ_o]0?ooWOl0o`00Oooo0=co001ooeL0oooonf[oT`3ooookJ_oo0:Wok?l0ool00?l007oo
gOl0om;o00;ooo]Z0_l007l00onho`3ooo]ZoolL0002o`00O`03o`3oU_oonf[oo`1?00Kooo]Z0_l0
oh/00ooonf[o0000o`3o]@02o`0000Cooo]Z0_oo0;D2oookJP;oob001OoonfX00ol80?oo0?lho`3o
>002oom100?ooo]Z0omko`02oookJP;oo`X01olZ0?l3o`1<o`Oo02Go1OoonfX2o`1<o`?o:P3o1?oo
2P05oookJP?oNol00_oonfX2oonL00;ood400ooonfX2o`3o>003o`P0oooonf[ooo]Z00[ooo]Z00?o
ob00oookJ_oonfX00_oonfX00ooo0;Gooo]ZoookJP0?oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o
0?n;oookJ_oonfX04_oonfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Kooo]Z00Gooa`0oookJ_oonf[o
oo]ZokSo000>oookJP03om;o0?oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX00ooonfX00ooo003o
oo]Zonco0005oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?oE`3ooong0?oonfX00ooonfX00ooo0=co
oo]ZoookJP03oookJP03oigo0?oonf[ooo]Z01kooo]Z000WoookJP03obT0oooonf[ooo]Z00;ooo]Z
00?o0?o`oookJ_oonfX01OoonfX00oooj03ooo]Zool02`04oookJP0:oole0?oonf[o087oocOo0?oo
nf[oiOl0oookJ_l0onSooo]ZocKo00gooo]Z00Go0>?ooookJ_oonf[ooo]Zooo9000<oookJP03o`3o
kOoonf[ooo]Z00Wooo]Z00CooaX0oookJ_lM0?oo0?ob0ooonfX00oooN@3ooo]ZoonW0008oookJP03
oiCo0?oonf[ooo]Z00;ooo]Z00Co=?l0oookJ_oo04oo00_o0ooonfX00onDo`3o0?_ooookJP02oook
JP05odh0oooonf[ooo]ZoookJ_nDo`000ooonfX00oooa`3ooo]ZoookJP0:oiCo00?ooo]Z00Ko0?nG
oookJ_oonf[oiOl0oookJ_oo03T3oiCo0003ool01ooonf[ooo]Z017ooo]Z00Coo`0hogT0oooonf[o
^?l01?oUo`000om/0?oooo]ZoookJP02oookJP?o001o017ooo]Zond0ool007ooo`3LoiCo0?mG0?oo
U?l0oi<0oonDo`3ooo]Zonco0?oo003oU?l0ob/0oooMo`3od_l0oookJP02o`00O`?oU?l000Gooa`0
o`00Ool0oiKooo]Zool0C`05oookJP;oU?l000Ko0?n;oookJ_l0003o0000o`3o]Ol00006oookJP04
ool0]Ooonf[ooo]ZoookJP;oob000_oonfX;odCo0004oookJ_mko`3oNol0og_o00Gooo]Z0ooo2P0<
odCo00Go:P3o1Om4o`02oookJPCoNol01OnDo`03oom100;oU?l00ol0ocP3oiCo00[ooo]Z00?oob00
oookJ_oonfX00_oonfX2ool0]@kooo]Z1ooUo`03oookJP03o`3oRooonf[ooo]Z01;ooo]Z00Goo`1?
oookJ_oonf[ooo]Zo`3oUP02oookJPSoiOl000?o^?l0oookJ_oonfX03?oonfX6oomi00Gooo]Z00Co
oi/0ool00?oonf[ok?l01?oonfX00onC0?oooo]ZoookJP06oookJP03oeL0oooo]`3ooo]Z00;ooo]Z
00?oo`3LoookJ_oonfX00ooonfX00onMo`3ooo]ZoookJP14oookJP05obT0oooonf[ooo]ZoookJ_l0
oo002?oonfX00oooj03oo`0;oookJP04oookJP03oole0?l0POoo=ol000;ooo]Z00Co0?nGoookJ_l0
onSo=_l03_oonfX01?l0hooooo]ZoookJ_oo0>`<oookJP03o`3okOoonf[ooo]Z00[ooo]Z00?ooaX0
oad0ool0oo800ooonfX01?oo0;Cooo]ZoookJ_ooY`07oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z00Co
O03oocCo0?oonf[o00_o0ooonfX00on`o`3o0?_ooookJP02oookJP05odh0oooonf[ooo]ZoookJ_oo
01@00ooonfX00oooa`3ooo]ZoookJP02oookJP03oonX0?oonf[oo`2W00;ooo]Z00?oob40oookJ_oo
nfX01?oonfX02Ol0oiOooo]ZoookJ_n>o`3ooo]Zool0>Ooonf[o0?o0ool01`0CoookJP07ool0>?oo
nf[oN@3ooookJ_nho`3ooo]Zool0_002oookJP04of`0oooonf[ooo]ZoookJP?o001o00Sooo]Zond0
oonMo`3o001oool0g?oonf[oE`3ooi<0o`;ooo]Z00Ook?l0oonK0?oo003o001oomgo0?oBo`3ooo]Z
00?o001o00So^?l0oookJ_oo703o001ooookJ_l0oiKooo]Zool0C`Oooo]Z00?o0?n;o`000?l00000
0_l0okD6oookJP;oo`2e0_oonfX2oolP00Gooo]Z00?o203oo`3o>?l0ocP00ooo@@03oookJP?oNol0
1_oonfX2ool:017o:P3o2?oonfX4og_o00;ooo]Z0_ooW003oom100;ooo]Z0ol0ocP00ol80?oooo]Z
oookJP0:oookJP;oob001?oonfX00ooo0;Gooo]ZoookJP0?oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z
00?o0?n;oookJ_oonfX04ooonfX01?oo04oooo]ZoookJ_l0oiH6oookJP05oolL0?oonf[ooo]Zoook
J_nho`003_oonfX01_oBo`3ooo]ZoookJ_oMo`3ooo]Zob/0o`Gooo]Z00Cooi/0ool00?oo0:Wok?l0
1OoonfX00onC0?oooo]ZoookJP06oookJP03oeL0oooonf[ooo]Z00;ooo]Z00?oo`3LoookJ_oonfX0
0ooonfX00onMo`3ooo]ZoookJP0OoookJP009ooonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oo
nf[ooo]Z00Gooo]Z00?oonP0oookJ_oo00/01?oonfX01?oo=@3ooo]Zo`21oolgo`02oookJP04onGo
0?l0onSooo]ZocKo00kooo]Z00Co0>?ooookJ_oonf[oolT03?oonfX00ol0ongooo]ZoookJP09oook
JP04oolJ0?oonf[o7@3oo`3olP?ooo]Z00?oo`2doookJ_ooY`002?oonfX00onDo`3ooo]ZoookJP02
oookJP04ocCo0?l0;Ooooo]Zo`0;o`?ooo]Z00?oU?l0oookJ_l0nol00ooonfX01?m>0?oooo]Zoook
J_nDo`03oookJP03ooo70?oonf[ooo]Z00SoU?l01OoonfX01_l0oiOooo]ZoookJ_oonf[oiOl0ool0
>@?oU?l000?oo`07oookJ_oonfX04OoonfX01?oo03SoN@3ooookJ_nho`05onGo0004of`0oooonf[o
oo]ZoookJPCo001o00Sok@3ooigo0?l007ooo`3LoiCo0?mG0?ooU?l0oi<0o`;oU?l000Kok?l0ool0
0?nDo`3o:`3oomgo0?oBo`02o`00O`09oookJ_nDo`3oU?l0oiCo0?oo703oU?l0o`3oU_l007ooo`1?
00;o001o0ooonfX01?nDo`3ooo]Zo`3oRol0oh/2o`0000;o0?ne1_oonfX2ool0]@?ooo]Z0_oo8000
0ooonf[oA?l0odCo0007odCo00;ood4000?ooi`0oookJ_oonfX04?m4o`02oookJP;oA?l01_oonfX3
odCo00?oNol00_oonfX4oiCo00?ood400onDo`02o`3o>003o`P0oonDo`3oU?l000_ooo]Z0_oo8004
oookJP03ool0]Ooonf[ooo]Z00gooo]Z1ooUo`03oookJP03o`3oRooonf[ooo]Z01;ooo]Z00Goo`1?
oookJ_oonf[ooo]Zo`3oUP03oookJPOoiOl000?o^?l0oookJ_oonfX03?oonfX6oomi00Gooo]Z00Co
oi/0ool00?oo0:Wok?l01OoonfX00onC0?oooo]ZoookJP05oookJP03oeL0oooo]`3ooo]Z00?ooo]Z
00?oo`3LoookJ_oonfX00ooonfX00onMo`3ooo]ZoookJP14oookJP05obT0oooonf[ooo]ZoookJ_l0
oo002?oonfX00oooj03oo`0;oookJP04oookJP03oole0?oonf[o087o00;ooo]Z00Co0?nGoookJ_l0
onSo=_l03ooonfX00ol0hooooo]Zool0k00<oookJP03o`3okOoonf[ooo]Z00[ooo]Z00?ooaX0oad0
ool0oo800ooonfX01?oo0;Cooo]ZoookJ_ooY`07oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z00GoO03o
ocCo0?oonf[o00_oool06002oookJP03ok3o0?oonf[o0?_o00?ooo]Z00CoCP3ooookJ_oonf[oo`0D
0ooonfX00oooa`3ooo]ZoookJP03oookJP05oonX0?oo0:Oooo]ZoookJ_oo8@001_oonfX02Ol0oiOo
oo]ZoookJ_oonf[oS_l0ool0>Ooonf[o0?o0ool01`0CoookJP07ool0>?oonf[oN@3ooookJ_nho`3o
oo]Zool0_003oookJP03of`0oooonf[ooo]Z00Co001o00Sok@3oo`00OonMo`3ooo]Zool0g?oonf[o
E`3ooi<0o`;ooo]Z00Kok?l0ool00?l007oo:`3oomgo0?oBo`02o`00O`;ooo]Z00?o^?l0oookJ_oo
70000_l007l01?l0oiKo001oool0Col007l6oookJP;o0?n;0_l000000ol0okGooo]ZoookJP05oook
JP;oo`2e0_oonfX2oolP00Kooo]Z0_l0ocP01?l80?oood40oom10?oo@@02oonL0003oookJ_mko`3o
Nol000?oNol06OoonfX3og_o00?ooo]Z0_ooW003oom100?ooo]Z0_l0ocP00ooonf[o203oo`P0o`0;
oookJP;oob001OoonfX00ooo0;Gooo]ZoookJP0?oookJP03o`3o]Ooonf[ooo]Z00Cooo]Z00?o0?n;
oookJ_oonfX04ooonfX01?oo04oooo]ZoookJ_l0oiH6oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o
^?l0oookJ_oonfX02ooonfX01_oBo`3ooo]ZoookJ_oMo`3ooo]Zob/0o`Gooo]Z00Cooi/0ool00?oo
nf[ok?l01OoonfX00onC0?oooo]ZoookJP06oookJP03oeL0oooonf[ooo]Z00;ooo]Z00?oo`3Loook
J_oonfX01?oonfX00onMo`3ooo]ZoookJP0OoookJP009ooonfX00olY0?oooo]ZoookJP02oookJP03
o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0oookJ_oo00/01?oonfX01?oo=@3ooo]Zo`21oolgo`02oook
JP04onGo0?l0onSooo]ZocKo00kooo]Z00Go0>?ooookJ_oonf[ooo]Zooo9000;oookJP03o`3okOoo
nf[ooo]Z00Wooo]Z00CooaX0oookJ_lM0?oo0?ob0ooonfX00ooo0;Cooo]ZoonW0008oookJP03oiCo
0?oonf[ooo]Z00;ooo]Z00GoO03oocCo0?oonf[oo`1?o`0;o`03oookJP03oiCo0?l0nooooo]Z00;o
oo]Z00CoCP3ooookJ_oonf[oo`0D1?oonfX00oooa`3ooo]ZoiCo0007oiCo00Gooo]Z00Ko0?nGoook
J_oonf[ooo]ZonGo0?oonfX4oiCo0003ool01ooonf[ooo]Z017ooo]Z00Coo`0hogT0oooonf[o^?l0
1_oUo`03oookJPCo001o00Gok@3ooigo0?oo0=coU?l0oeL0o`02oiCo0009oi<0oonDo`3oU?l0onco
0?oo003oU?l0ob/0oooMo`3od_l000;ooo]Z1?nDo`001_oo703oU?l0o`3oU_l007ooo`1?o`00O`Ko
oo]Z00Ko0000o`3oRol0003o0000oookJ_l0okD7oookJP;oo`2e0ooonfX2oolP00SoA?l000?o0?lh
oookJ_oo@@000_oo@@02oonL00koA?l01OoonfX8og_o00Cooo]Z00?oU?l0oom10?oo@@000_oo@@03
oiCo00?o0?lh0_l80?l2oiCo00[ooo]Z0_oo8005oookJP03ool0]Ooonf[ooo]Z00kooo]Z1OoUo`04
oookJP03o`3oRooonf[ooo]Z01;ooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP04oookJPKoiOl000?o
oo]ZokSo0?oonfX03?oonfX00ooBo`3oogT0oomi0003oomi0003ob/0oooonf[ooo]Z00?ooo]Z00?o
o`00ool0ZOo/o`001OoonfX00onC0?oooo]ZoookJP06oookJP03oeL0oooo]`3ooo]Z00;ooo]Z00?o
o`3LoookJ_oonfX00ooonfX00onMo`3ooo]ZoookJP15oookJP03obT0oooonf[ooo]Z00;ooo]Z00?o
0?o`oookJ_oonfX01OoonfX00oooj03oo`0;oookJP04oookJP03oole0?oonf[o087o00;ooo]Z00Co
0?nGoookJ_l0onSo=_l03ooonfX01?l0hooooo]ZoookJ_oo0>`;oookJP03o`3okOoonf[ooo]Z00[o
oo]Z00?ooaX0oookJ_lM0?l01?oonfX00ooo0;Cooo]ZoonW0008oookJP09o`3o2Ooonf[ooo]Zoook
J_ml0?oo=?l0o`0]oooonf[o00_o00?ooo]Z00?o/?l0o`3koooonfX00_oonfX01?m>0?oooo]Zoook
J_oo01@4oookJP03ooo70?oonf[ooo]Z00;ooo]Z00KoojP0ool0Yooonf[ooo]ZoolQ0?oo0;@5oook
JP06o`3oUooonf[ooo]ZoookJ_n>o`3oo`0i0_oonfX00ol0ol3oo`07oookJP0BoookJP07ool0>?oo
nf[oN@3ooookJ_nho`3ooo]Zool0_002oookJP04of`0oooonf[ooo]ZoookJPCo001o00Sok@3ooook
J_nMo`3oo`3LoookJ_mG0?oooo]Zoi<0o`;ooo]Z00Kok?l0ool00?l007oo:`3oomgo0?oBo`04oook
JP03okSo0?l007oooa`000;o001o00?o0?nFo`00Oooo04l01_oonfX2o`000003o`3oRol0003ooo]Z
00;o0?ne1ooonfX01?oo0;Gooo]ZoookJ_oonfX2oolP00Kooo]Z0ol0ocP01?l80?oood40oom10?oo
@@03oonL00;ooo]Z1omko`09oookJPWoNol00ooonfX00oooW03ood40oom10002oom100Cooo]Z0_l0
ocP3o`P0o`cooo]Z00?oob00oookJ_oonfX01?oonfX00ooo0;Gooo]ZoookJP0?oookJP03o`3o]Ooo
nf[ooo]Z00Cooo]Z00?o0?n;oookJ_oonfX04ooonfX01?oo04oooo]ZoookJ_l0oiH6oookJP03oolL
0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX02ooonfX01?oBo`3ooo]ZoookJ_oMo`02oookJP03
ob/0oooonf[ooo]Z00?ooo]Z00?oo`00oookJ_o/o`001_oonfX00onC0?oooo]ZoookJP06oookJP03
oeL0oooonf[ooo]Z00;ooo]Z00?oo`3LoookJ_oonfX00ooonfX00onMo`3ooo]ZoookJP0PoookJP00
9ooonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0ool02ooonfX0
0ooonfX01?oo=@3ooo]ZoookJ_l0POl2oookJP04onGo0?l0onSooo]ZocKo00kooo]Z00Go0>?ooook
J_oonf[ooo]Zooo9000<oookJP03o`3okOoonf[ooo]Z00Wooo]Z00?ooaX0oad0ool0oo801?oonfX0
0ooo0;Cooo]ZoonW0007oookJP03oiCo0?oonf[ooo]Z00;ooo]Z00GoO03oocCo0?oonf[oo`1?o`0;
o`03oookJP03oiCo0?l0nooooo]Z00;ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05003oookJP03ooo7
0?oonf[oU?l000SoU?l01OoonfX01Ol0oiOooo]ZoookJ_n>o`3ooo]Z00CoU?l000?oo`07oookJ_oo
nfX04OoonfX01?oo03SoN@3ooookJ_nho`07onGo00Kooo]Z00Kok@3ooigo0?oonf[oo`3LoiCo0?mG
0?l2oiCo0009oi<0oonDo`3oU?l0ool00?nDo`3o:`3ooiCo0?oMo`3od_l000;ooo]Z1?nDo`001Ooo
703oU?l0o`3oU_l0oiKoo`1?00Kooo]Z0_l00002o`3oR`;ooo]Z00?o0?neoookJ_oonfX01_oonfX0
0ooo0;Gooo]ZoookJP02oookJP03oolP0?m4o`3oA?l000CoA?l00_oonfX5o`3o>0Cood402om4o`05
og_o00Oooo]Z0oooW003oom100GoU?l00_l0ocP2o`P0o`kooo]Z00?oob00oookJ_oonfX01?oonfX0
0ooo0;Gooo]ZoookJP0>oookJPCoiOl01OoonfX00ol0oh_ooo]ZoookJP0BoookJP05ool0Cooonf[o
oo]ZoookJ_l0oiH01?oonfX6onGo0003oookJ_nho`3ooo]Z00gooo]Z00?od_l0oomi0?ooN@000ooo
N@05oookJP04oonK0?oo003oo`2Yonco00Cooo]Z00?oT`3ooookJ_oonfX01_oonfX00omG0?oookL0
oookJP03oookJP03ool0g?oonf[ooo]Z00?ooo]Z00?oWOl0oookJ_oonfX0AOoonfX00olY0?oooo]Z
oookJP02oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0ool02ooonfX01?oonfX00ooo=@3ooo]Z
o`21o`03oookJP03o`3oUol0onSo=_l000oooo]Z00Co0>?ooookJ_oonf[oo`3/3?oonfX00ol0ongo
oo]ZoookJP0:oookJP03oolJ0?lM0?oo0?ob00?ooo]Z00Coo`2doookJ_oonf[oojL01ooonfX02Ol0
o`Wooo]ZoookJ_oonf[oO03ooookJ_ldo`3ooo]Zo`0;o`03oookJP03ok3o0?l0nooooo]Z00;ooo]Z
00GoCP3ooookJ_oonf[ooo]Zool05003oookJP03ooo70?oonf[ooo]Z00?ooo]Z00GoojP0ool0Yooo
nf[ooo]ZoolQ0006oookJP09o`3oUooonf[ooo]Zohko0?oonf[oo`0ioookJ_l0ol3oo`0701?ooo]Z
00Ooo`0hoookJ_mi0?oooo]ZokSo0?oonf[oo`2l00?ooo]Z00?oK03ooookJ_oonfX01?oonfX04Oo]
0?oooo]Zoigo0?oonf[oo`3LoookJ_mG0?oooo]Zoi<0oooonf[ok?l0oonK0?oo003ooo]Zob/0oooM
o`3od_l000Cooo]Z00?o^?l0oookJ_oo70000_oonfX2o`3oUP03ool0Cooonf[ooo]Z00?ooo]Z0ol0
0002o`3oR`;ooo]Z00?o0?neoookJ_oonfX01OoonfX2ool0]@?ooo]Z00?oob00oookJ_oonfX01_oo
nfX5o`3o>0Good400oooW003oookJPWoNol02?oonfX2oonL00?ood401OoonfX3o`3o>0;o203o3Ooo
nfX2oolP00Kooo]Z00?oo`2eoookJ_oonfX03ooonfX00ol0okGooo]ZoookJP04oookJP03o`3oRooo
nf[ooo]Z01?ooo]Z00Coo`1?oookJ_oonf[o0?nF1ooonfX01Ooo703ooo]ZoookJ_oonf[o^?l000ko
oo]Z00Kod_l0oookJ_oonf[ogOl0oookJ_l[0?l5oookJP04oonK0?oo003ooo]Zonco00Gooo]Z00?o
T`3ooookJ_oonfX01_oonfX00omG0?oooo]ZoookJP02oookJP03ool0g?oonf[ooo]Z00Cooo]Z00?o
WOl0oookJ_oonfX08?oonfX002Oooo]Z00?o:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP05
oookJP03oooX0?oonf[oo`0;00?ooo]Z00CoocD0oookJ_oonf[o087o0_oonfX01?oUo`3o0?oXoook
J_lfo`0>oookJP05o`3Soooonf[ooo]ZoookJ_oob@003?oonfX00ol0ongooo]ZoookJP09oookJP03
oolJ0?oonf[o7@3o00Cooo]Z00?oo`2doookJ_ooY`002?oonfX01_nDo`3ooo]ZoookJ_oonf[oO03o
ocCo00;ooo]Z00Oo00_ooookJ_oonf[ooo]ZoiCo0?oonf[o0?_o00?ooo]Z00CoCP3ooookJ_oonf[o
o`0D0ooonfX00oooa`3ooo]ZoiCo0005oiCo0003oookJ_nDo`3oU?l000Gooo]Z00Ko0?nGoookJ_oo
nf[ooo]Zohko0?oo03T4oiCo0003ool01ooonf[ooo]Z017ooo]Z00?oo`0hogT0oooonfX02?oUo`06
oookJP06ond0oonMo`3oU?l0ool0g?nDo`3oE`3o0_nDo`002_nC0?ooU?l0oiCo0?oo003oU?l0ob/0
oonDo`3ogOl0om;o0?oonfX5oiCo0005oolL0?nDo`3oU?l0o`3oU_oo04l01OoonfX4o`000003o`3o
Rooonf[ooo]Z00;o0?ne1ooonfX2ool0]@?ooo]Z0_oo8004odCo00Kooo]Z00?o203oo`3o>?l0ocP0
0_l0ocP2oom100SoA?l01_oonfX00oooW03ood40oom10007oom100Gooo]Z0ol0ocP00ol80?oooo]Z
oookJP0=oookJP;oob001OoonfX2ool0]A7ooo]Z0_oUo`05oookJP;o0?n;5?oonfX00ooo04oooo]Z
oookJP02oookJP03o`3oU_oonf[ooo]Z00;ooo]Z1OoUo`000ooonf[o^?l0oookJP0=oookJP03om;o
0?oonf[oogT000?oogT01_oonfX00ooo003oo`2Yonco0005oookJP03oi<0oooonf[ooo]Z00Kooo]Z
00?oE`3ooookJ_oonfX00_oonfX00ooo0=cooo]ZoookJP03oookJP03oigo0?oonf[ooo]Z04Kooo]Z
00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP05oookJP03oooX0?oonf[oo`0;00Cooo]Z
00?oocD0oookJ_l0POl00ooonfX01?l0oiOo0?oXoookJ_lfo`0>oookJP04o`3Soooonf[ooo]Zool0
k0cooo]Z00?o0?o]oookJ_oonfX02_oonfX00ooo6P3o7@3oo`3olP03oookJP04ool0]?oonf[ooo]Z
oonW00Oooo]Z00Wo0?l9oookJ_oonf[ooo]Zog`0oooonf[o=?l0oookJ_l02ol00ooonfX00on`o`3o
oo]Zo`3ko`03oookJP04odh0oooonf[ooo]Zool050?ooo]Z00?oolL0oookJ_oonfX00ooonfX01Ooo
Z03oo`2WoookJ_oonf[oob4000Kooo]Z00[o0?nGoookJ_oonf[ooo]Zohko0?oo03Wooo]Zo`3o`?oo
nf[oo`074ooonfX01ooo03Sooo]ZogT0oooonf[o^?l0oookJ_oo0;`00_oonfX00om/0?oooo]Zoook
JP05oookJP0<ond0oooonf[oWOl0oookJ_oo0=cooo]ZoeL0oooonf[oT`3ooookJ_o/o`3oo`000_oo
nfX00ol[0?oogOl0om;o0004oookJP03okSo0?oonf[ooa`000?ooo]Z00?o0?nFool0CooonfX00ooo
nfX4o`000005oookJ_l0oh_ooo]ZoookJ_l0okD02?oonfX2ool0]@;ooo]Z0_oo800:oookJP03o`P0
ool0ocSo0?lh00?o0?lh1ooo@@03oonL00Kooo]Z2Ooo@@06oookJP;o0?lh0_l80?l>oookJP;oob00
1_oonfX2ool0]A7ooo]Z00?o0?neoookJ_oonfX00ooonfX2o`3oRaGooo]Z00Goo`1?oookJ_oonf[o
oo]Zo`3oUP06oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX02ooonfX01?oBo`3o
oo]ZoookJ_oMo`02oookJP03ob/0oooonf[ooo]Z00?ooo]Z00?oo`00oookJ_o/o`001_oonfX00onC
0?oooo]ZoookJP05oookJP03oong0?mG0?oooo]Z00?ooo]Z00?oo`3LoookJ_oonfX00ooonfX00onM
o`3ooo]ZoookJP0QoookJP009ooonfX00olY0?oooo]ZoookJP03oookJP03o`3ol?oonf[ooo]Z00Go
oo]Z00?oonP0oookJ_oo00/00ooonfX02?oo=@3ooo]ZoookJ_l0POoo=ol0oookJ_oUo`3o0?oX0_oo
nfX00olfo`3ooo]ZoookJP0;oookJP05o`3Soooonf[ooo]ZoookJ_oob@003?oonfX00ol0ongooo]Z
oookJP09oookJP04oolJ0?oonf[o7@3oo`3olP?ooo]Z00?oo`2doookJ_ooY`002?oonfX00onDo`3o
oo]ZoookJP02oookJP05og`0ooldo`3ooo]Zo`0;oooo01P00_oonfX00onDo`3ooo]Zo`3ko`03oook
JP04odh0oooonf[ooo]Zool050Cooo]Z00SoolL0oiCo0?nDo`3oU?l0oookJ_nDo`3oo`2WoookJP;o
U?l01_oonfX01Ol0oiOooo]ZoookJ_n>o`3ooo]Z00CoU?l000?oo`07oiCo0?oonfX04OoonfX01?oo
03SoN@3ooookJ_oonfX8onGo00Kooo]Z00Kok@3ooigo0?nDo`3oo`3LoiCo0?mG0?l2oiCo000:oi<0
oonDo`3oU?l0ool00?nDo`3o:`3ooiCo0?oMo`3od_l0oookJPGoU?l000Gooa`0oiCo0?nDo`3o0?nF
ool0C`04oookJPGo000000Go0?n;oookJ_oonf[ooo]Zo`3o]@08oookJP?oo`2e0_oonfX01?oo803o
A?l0odCo0?m4o`09oookJP;o203o1?l0ocP6odCo00Oood402_oonfX4o`3o>003o`P0oooonf[ooo]Z
00oooo]Z00?oob00oookJ_oonfX00ooonfX2ool0]A;ooo]Z0_oUo`05oookJP03o`3oRooonf[ooo]Z
01?ooo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP03oookJP?oiOl00ooonfX00onh
o`3ooo]ZoookJP0;oookJP03om;o0?oonf[ooo]Z00?oogT000?o:`3ooookJ_oonfX00ooonfX00ooo
V`3oo`00onco0005oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?oE`3ooong0?oonfX00ooonfX00ooo
0=cooo]ZoookJP03oookJP05oigo0?oonf[ooo]ZoookJ_o]0?l0A?oonfX00olY0?oooo]ZoookJP02
oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0ool02ooonfX00ooonfX01?oo=@3ooo]Zo`21oolg
o`02oookJP04o`3oUol0onSooo]ZocKo00kooo]Z00Co0>?ooookJ_oonf[oo`3/3?oonfX00ol0ongo
oo]ZoookJP0:oookJP03oolJ0?lM0?oo0?ob00Cooo]Z00?oo`2doookJ_ooY`001ooonfX00ol0o`Wo
oo]ZoookJP02oookJP05og`0ooldo`3ooo]Zo`0;oooo01P00_oonfX00on`o`3ooo]Zo`3ko`03oook
JP05odh0oooonf[ooo]ZoookJ_oo01@00ooonfX00oooa`3ooo]ZoookJP02oookJP06oonX0?oo0:Oo
oo]ZoookJ_oo8@3oo`2d1_oonfX02Ol0oiOooo]ZoookJ_n>o`3ooo]Zool0>Ooonf[o0?o0ool01`0C
oookJP03ool0>?oonf[oN@3o00;ooo]Z00?o^?l0oookJ_oo0;`00_oonfX00om/0?oooo]ZoookJP05
oookJP0<ond0oooonf[oWOl0oookJ_oo0=cooo]ZoeL0oooonf[oT`3ooookJ_o/o`3oo`000_oonfX0
0ol[0?oogOl0om;o0004oookJP03okSo0?oonf[ooa`000?ooo]Z00?o0?nFool0CooonfX00_oonfX5
o`000004oookJ_l0oh_ooo]ZoookJP;o0?ne2?oonfX2ool0]@;ooo]Z0_oo800;oookJP?o203o1_l0
ocP00ooonf[ood40oom10007oom100[ooo]Z1Ol0ocP00ol80?oooo]ZoookJP0>oookJP03oolP0?oo
nf[ooo]Z00Cooo]Z0_oo0;DBoookJP03o`3o]Ooonf[ooo]Z00?ooo]Z00?o0?n;oookJ_oonfX05?oo
nfX01Ooo04oooo]ZoookJ_oonf[o0?nF00Kooo]Z00?ooa`0oookJ_oonfX00_oonfX00onho`3ooo]Z
oookJP0;oookJP07om;o0?oonf[ooo]ZoookJ_oMo`3ooo]Zob/0o`05oookJP04oonK0?oo003ok?l0
ool0Z@Gooo]Z00?oT`3ooookJ_oonfX01_oonfX00omG0?oooo]ZoookJP02oookJP03ool0g?oonf[o
oo]Z00Cooo]Z00GoWOl0oookJ_oonf[ooo]Zond0o`0OoookJP00:?oonfX00olY0?oooo]ZoookJP02
oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0oookJ_oo00/00ooonfX01Ooo=@3ooo]ZoookJ_l0
POoo=ol000;ooo]Z00CoiOl0o`3oj?oonf[o=_l03_oonfX01?l0hooooo]ZoookJ_oob@0<oookJP03
o`3okOoonf[ooo]Z00[ooo]Z00?ooaX0oad0ool0oo801?oonfX00ooo0;CoojL0oookJP07oookJP03
oiCo0?oonf[ooo]Z00;ooo]Z00GoO03oocCo0?oonf[oo`1?o`0;o`03oookJP03oiCo0?oonf[o0?_o
00;ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05003oookJP03ooo70?nDo`3ooo]Z00;ooo]Z00CoU?l0
oookJ_oo0:Oooo]Z0_nDo`05oookJP05o`3oUooonf[ooo]ZoookJ_n>o`001OnDo`000ooo00OoU?l0
oookJP0AoookJP03ool0>?mi0?oooo]Z00WoiOl01OoonfX01oo]0?ooWOl0oiCo0?nDo`3oo`3LoiCo
0?mG0?l00_nDo`002_nC0?ooU?l0onco0?oo003oU?l0ob/0oonDo`3ogOl0om;o0?oonfX5oiCo0005
oolL0?nDo`3oU?l0o`3oU_oo04l00ooonfX4o`0000;ooo]Z0_l0oh/2oookJP03o`3o]Ooonf[ooo]Z
00Sooo]Z0ooo0;D01?oonf[oA?l0oolP0?oo800>oookJP;o203o00Co0?lhodCo0?m4o`3oA?l00ol0
ocP7oookJPOo0?lh0_l80?lAoookJP?oob001?oonfX2ool0]A;ooo]Z00?o0?neonGo0?oonfX01Ooo
nfX00ol0oh_ooo]ZoookJP0CoookJP03ool0Cooonf[ooo]Z00;ooo]Z00?o0?nFoookJ_oonfX00ooo
nfX3onGo00?ooo]Z00?o^?l0oookJ_oonfX02ooonfX00ooBo`3ooo]ZoookJP03oomi0003ob/0oooo
nf[ooo]Z00?ooo]Z00Cooi/0ool00?oo0:Wok?l01OoonfX00onC0?oooo]ZoookJP06oookJP03oeL0
oooonf[ooo]Z00;ooo]Z00?oo`3LoookJ_oonfX01?oonfX01OnMo`3ooo]ZoookJ_oonf[ok@3o04Co
oo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP06oookJP03oooX0?oo00_ooo]Z00?o
oo]Z00CoocD0oookJ_l0POoo=ol00_oonfX01?l0oiOo0?oXoookJ_lfo`0?oookJP03o`3Soooonf[o
o`3/00cooo]Z00?o0?o]oookJ_oonfX02ooonfX00olM0?oo0?oboookJP03oookJP03ool0]?oonf[o
ojL000Sooo]Z00Wo0?l9oookJ_oonf[ooo]Zog`0ooldo`3o02gooookJ_l02ol00ooonfX00on`o`3o
oo]Zo`3ko`02oookJP05odh0oooonf[ooo]ZoookJ_oo01@00ooonfX00oooa`3ooo]ZoookJP03oook
JP05oonX0?oo0:Oooo]ZoookJ_oo8@001_oonfX02_l0oiOooo]ZoookJ_oonf[oS_l0ool0>Ooonf[o
0?o0oookJ_oo00LCoookJP07ool0>?oonf[oN@3ooookJ_nho`3ooo]Zool0_003oookJP03of`0oooo
nf[ooo]Z00Cooo]Z00?ok@3ooookJ_nMo`000_oonfX02?oo0=cooo]ZoeL0oooonf[oT`3ooookJ_o/
o`3oo`000_oonfX00ol[0?oogOl0om;o0004oookJP03okSo0?oonf[ooa`000?ooo]Z00Co0?nFool0
Cooonf[ooo]Z1?l00003oookJP;o0?n;0_oonfX00ol0okGooo]ZoookJP07oookJP?oo`2e00Cooo]Z
oolP0?oo803oob003_oonfX3o`P0o`Oo0?lh1_oonfX7o`3o>0?o203o4?oonfX3oolP00Cooo]Z0ooo
0;DBoookJP;o0?ne1OoonfX00ol0oh_ooo]ZoookJP0DoookJP05ool0Cooonf[ooo]ZoookJ_l0oiH0
1ooonfX01Ooo703ooo]ZoookJ_oonf[o^?l000gooo]Z00God_l0oookJ_oonf[ooo]Zomgo0002oook
JP03ob/0oooonf[ooo]Z00;ooo]Z00Cooi/0ool00?oonf[ok?l01OoonfX00onC0?oooo]ZoookJP06
oookJP03oong0?mG0?oooo]Z00?ooo]Z00?oo`3LoookJ_oonfX01?oonfX01OnMo`3ooo]ZoookJ_oo
nf[ok@3o01oooo]Z000XoookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01OoonfX0
0oooj03ooo]Zool02`04oookJP04oole0?oonf[o087oocOo00;ooo]Z00CoiOl0o`3oj?oonf[o=_l0
3_oonfX01?l0hooooo]ZoookJ_oob@0=oookJP03o`3okOoonf[ooo]Z00Wooo]Z00?ooaX0oad0ool0
oo801?oonfX00ooo0;Cooo]ZoonW0007oookJP03oiCo0?oonf[ooo]Z00;ooo]Z00GoO03oocCo0?oo
nf[ooo]Zo`0;o`03oookJP03oiCo0?oonf[o0?_o00?ooo]Z00CoCP3ooookJ_oonf[oo`0D0ooonfX0
0oooa`3ooo]ZoookJP03oookJP03oiCo0?oo0:Oooo]Z00?oU?l01?oonfX01Ol0oiOooo]ZoookJ_oo
nf[oS_l000GoU?l000?oo`07oiCo0?nDo`004OoonfX00ooo03SoN@3ooookJP0:onGo00Gooo]Z00ko
k@3ooigo0?nDo`3oo`3LoiCo0?mG0?ooU?l0oookJ_nDo`3oT`3ooiCo0?o/o`3oo`00oiCo00;o:`3o
00?ogOl0om;o0?nDo`001OnDo`001Ooo703oU?l0oookJ_l0oiKoo`1?00;ooo]Z1?l00004oookJP03
o`3oRooonf[ooo]Z00;o0?ne2ooonfX3ool0]@04oookJ_oo803oob00oolP013ooo]Z00CoA?l0oook
J_l80?oo203o1ol0ocP00ol80?oooo]ZoookJP0CoookJPCoob001?oonfX3ool0]A?ooo]Z00?o0?ne
oookJ_oonfX01OoonfX00ol0oh_ooo]ZoookJP0CoookJP03ool0Cooonf[ooo]Z00;ooo]Z00?o0?nF
oookJ_oonfX01?oonfX2onGo00Cooo]Z00?o^?l0oookJ_oonfX02ooonfX00ooBo`3ooo]ZoookJP02
oomi0003oookJ_l[0?oooo]Z00Cooo]Z00?oo`00oookJ_o/o`001OoonfX00onC0?oooo]ZoookJP06
oookJP03oeL0oooonf[ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX00ooonfX01OnMo`3ooo]ZoookJ_oo
nf[ok@3o04Gooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP06oookJP03oooX0?oo
00_ooo]Z00?ooo]Z00CoocD0oookJ_l0POoo=ol00_oonfX01?l0oiOooo]Zo`3oj?lfo`0?oookJP03
o`3Soooonf[oo`3/00gooo]Z00?o0?o]oookJ_oonfX02_oonfX00ooo6P3o7@3oo`3olP03oookJP04
ool0]?oonf[ooo]ZoonW00Oooo]Z00Wo0?l9oookJ_oonf[ooo]Zog`0oooonf[o=?l0oookJ_l02ol0
0ooonfX00on`o`3ooo]Zo`3ko`03oookJP04odh0oooonf[ooo]Zool050?ooo]Z00?oolL0oookJ_oo
nfX00ooonfX01_ooZ03oo`2WoookJ_oonf[oob40ool0]0Gooo]Z00[o0?nGoookJ_oonf[ooo]Zohko
0?oonf[oo`0ioookJ_l0ol3oo`074ooonfX00ooo03Sooo]ZogT0o`02oookJP03okSo0?oonf[oo`2l
00;ooo]Z00?oK03ooookJ_oonfX01OoonfX01oo]0?oooo]Zoigo0?oonf[oo`3LoookJ_mG0?l00_oo
nfX02OnC0?oooo]Zool0ZOoo003ooi/0oookJ_l[0?oogOl0om;o0004oookJP03okSo0?oonf[ooa`0
00?ooo]Z00?o0?nFool0CooonfX01?l00005oookJP03o`3oRooonf[ooo]Z00;o0?ne2_oonfX3ool0
]@04oookJ_oo803oob00oolP01;ooo]Z0ol80?l6o`3o>003o`P0oooonf[ooo]Z01?ooo]Z1?oo8005
oookJP;oo`2e4ooonfX2o`3o]@Kooo]Z00?o0?n;oookJ_oonfX05?oonfX01Ooo04oooo]ZoookJ_oo
nf[o0?nF00Oooo]Z00?ooa`0oookJ_oonfX00_oonfX00onho`3ooo]ZoookJP0;oookJP07om;o0?oo
nf[ooo]ZoookJ_oMo`3ooo]Zob/0o`05oookJP04ool00?oonf[ok?l0ool0Z@Gooo]Z00?oT`3ooook
J_oonfX01OoonfX00ooo]`3oE`3ooookJP03oookJP03ool0g?oonf[ooo]Z00Cooo]Z00GoWOl0oook
J_oonf[ooo]Zond0o`0PoookJP00:?oonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z
00Gooo]Z00?oonP0oookJ_oo00/01?oonfX01?oo=@3ooo]Zo`21oolgo`02oookJP04onGo0?l0onSo
oo]ZocKo00kooo]Z00Co0>?ooookJ_oonf[oolT03OoonfX00ol0ongooo]ZoookJP09oookJP03oolJ
0?oonf[o7@3o00Cooo]Z00?oo`2doookJ_ooY`002?oonfX00onDo`3ooo]ZoookJP02oookJP05og`0
ooldo`3ooo]Zo`0;oooo01P00_oonfX00onDo`3ooo]Zo`3ko`03oookJP05odh0oooonf[ooo]Zoook
J_oo01@00ooonfX00oooa`3ooo]ZoookJP02oookJP03oiCo0?oonf[oo`2W00CoU?l01?oonfX01Ol0
oiOooo]ZoookJ_oonf[oS_l000GoU?l000?oo`07oiCo0?nDo`004OoonfX00ooo03SoN@3ooookJP07
onGo00Sooo]Z00Kok@3ooiCo0?nDo`3oo`3LoiCo0?mG0?l2oookJP05oiCo0?nC0?ooU?l0onco0?oo
00000_nDo`000ol[0?oogOl0om;o0008oiCo00;ooo]Z0_oo04l4o`0000Gooo]Z0_l0oh/2oookJP;o
0?ne3?oonfX3ool0]@03oookJ_oo803oob0000;oob003ooonfX5onGo01Gooo]Z1?oo8006oookJP;o
o`2e5?oonfX2o`3o]@Oooo]Z00?o0?n;oookJ_oonfX04ooonfX00ooo04oooo]ZoookJP03oookJP03
o`3oU_oonf[ooo]Z00Cooo]Z00?oiOl0oookJ_oonfX00_oonfX00onho`3ooo]ZoookJP0;oookJP07
om;o0?oonf[ooo]ZoookJ_ooN@3ooo]Zob/0o`05oookJP03oonK0?oo003ok?l000Kooo]Z00?oT`3o
oookJ_oonfX01OoonfX00omG0?oookL0oookJP03oookJP03ool0g?oonf[ooo]Z00Cooo]Z00GoWOl0
oookJ_oonf[ooo]Zond0o`15oookJP03obT0oooonf[ooo]Z00?ooo]Z00?o0?o`oookJ_oonfX01Ooo
nfX00oooj03oo`0;oookJP04oookJP03oole0?l0POoo=ol000;ooo]Z00Co0?nGoookJ_l0onSo=_l0
3ooonfX00ol0hooooo]Zool0k00=oookJP03o`3okOoonf[ooo]Z00[ooo]Z00?ooaX0oad0ool0oo80
1?oonfX00ooo0;Cooo]ZoonW0007oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z00GoO03oocCo0?oonf[o
00_oool06002oookJP03ok3o0?oonf[o0?_o00?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05003oook
JP03ooo70?oonf[ooo]Z00;ooo]Z00?oojP0oookJ_oo0:L00_oonfX00ooo8@3ooo]ZoookJP04oook
JP0:o`3oUooonf[ooo]ZoookJ_n>o`3oo`0ioookJ_l0ol3ooo]Zool01a?ooo]Z00?oo`0hoookJ_mi
0?l00_oonfX00onho`3ooo]Zool0_002oookJP03of`0oooonf[ooo]Z00Gooo]Z00Ook@3ooookJ_nM
o`3ooo]Zool0g?oonf[oE`3o00;ooo]Z00WoT`3ooookJ_oo0:Woo`00oonK0?oonf[o:`3oomgo0?oB
o`001?oonfX01?nho`3ooo]ZoolL0?oo7002oookJP03o`3oU_oo04ooo`1?00?o00001_oonfX2o`3o
R`;ooo]Z0_l0okD;oookJP?oo`2e00?ooo]ZoolP0?oo80000_oo800YoookJPCoob001ooonfX2ool0
]ACooo]Z00?o0?neoookJ_oonfX01OoonfX00ol0oh_ooo]ZoookJP0DoookJP03ool0Cooonf[ooo]Z
00;ooo]Z00?o0?nFoookJ_oonfX01?oonfX00ooo703ooo]ZoookJP02oookJP03okSo0?oonf[ooo]Z
00_ooo]Z00Ood_l0oookJ_oonf[ooo]Zomgo0?oonf[o:`3o00Gooo]Z00Cooi/0ool00?o/o`3oo`2Y
1OoonfX00onC0?oooo]ZoookJP06oookJP03oeL0oooonf[ooo]Z00;ooo]Z00?oo`3LoookJ_oonfX0
1OoonfX01OnMo`3ooo]ZoookJ_oonf[ok@3o023ooo]Z000XoookJP03obT0oooonf[ooo]Z00;ooo]Z
00?o0?o`oookJ_oonfX01OoonfX00oooj03ooo]Zool02`04oookJP04oole0?oonf[o087oocOo00;o
oo]Z00CoiOl0o`3oj?oonf[o=_l03_oonfX01Ol0hooooo]ZoookJ_oonf[oolT000cooo]Z00?o0?o]
oookJ_oonfX02_oonfX00ooo6P3o7@3oo`3olP04oookJP03ool0]?ooY`3ooo]Z00Oooo]Z00?oU?l0
oookJ_oonfX00_oonfX01Oml0?oo=?l0oookJ_l02oooo`0H00;ooo]Z00CoU?l0oookJ_oonf[o0?_o
0ooonfX01?m>0?oooo]ZoookJ_oo01@3oookJP03ooo70?oonf[ooo]Z00;ooo]Z00?oU?l0oookJ_oo
0:L01OnDo`03oookJP03o`3oUooonf[ooo]Z00;ooo]Z00?oS_l0oiCo0?nDo`000_nDo`000ooo00Oo
oo]ZoookJP0BoookJP03ool0>?mi0?ooiOl000GoiOl000?ooo]Zof`0oooonfX01_oonfX02?o]0?oo
U?l0oiCo0?nDo`3oo`3LoookJ_mG0?oooo]Z0_nDo`001?nC0?ooU?l0onco0?oo0002oookJP03ob/0
oooMo`3od_l000[oU?l000?o0?nFool0Col000000_l00007oookJP;o0?n;0_oonfX2o`3o]@gooo]Z
0ooo0;D2oookJP?oob001OoonfX<onGo017ooo]Z1?oo8008oookJP;oo`2e5?oonfX2o`3o]@Sooo]Z
00?o0?n;oookJ_oonfX04ooonfX00ooo04oooo]ZoookJP03oookJP03o`3oU_oonf[ooo]Z00?ooo]Z
00?ooa`0onGo0?oonfX00_oonfX2onGo00gooo]Z00God_l0oookJ_oonf[ooo]Zomgo0002oookJP03
ob/0oooonf[ooo]Z00?ooo]Z00?oo`00oookJ_o/o`001OoonfX00onC0?oooo]ZoookJP06oookJP03
oeL0oooonf[ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX00ooonfX00onMo`3ooo]ZoookJP02oookJP03
ond0oooonf[ooo]Z04Cooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP05oookJP03
oooX0?oo00_ooo]Z00Cooo]Z00?oocD0o`21oolgo`000ooonfX00ol0oiOo0?oXocKo000?oookJP04
o`3Soooonf[ooo]Zool0k0cooo]Z00?o0?o]oookJ_oonfX02ooonfX00olM0?oo0?oboookJP03oook
JP03ool0]?oonf[oojL000Oooo]Z00?o0?l9oookJ_oonfX00_oonfX01Oml0?oo=?l0oookJ_l02ooo
o`0H00;ooo]Z00Co/?l0oookJ_oonf[o0?_o0ooonfX01?m>0?oooo]ZoookJ_oo01@3oookJP03ooo7
0?oonf[ooo]Z00?ooo]Z00KoojP0ool0Yooonf[ooo]ZoolQ0?oo0;@5oookJP0:o`3oUooonf[ooo]Z
oookJ_n>o`3ooo]Zool0>Ooonf[o0?o0ool01aCooo]Z00Ooo`0hoookJ_mi0?oooo]ZokSo0?oonf[o
o`2l00?ooo]Z00?oK03ooookJ_oonfX01?oonfX00oo]0?oooo]Zoigo0002oookJP03ool0g?oonf[o
E`3o00;ooo]Z00WoT`3ooookJ_oo0:Woo`00oonK0?oonf[o:`3oomgo0?oBo`001?oonfX01?nho`3o
oo]ZoookJ_oo7003oookJP04o`3oU_oo04oo0000o`0000Sooo]Z0_l0oh/2oookJP;o0?ne3?oonfX3
ool0]@;ooo]Z0ooo800RoookJPCoob002?oonfX3ool0]ACooo]Z0_l0okD7oookJP03o`3oRooonf[o
oo]Z01Cooo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP03oookJP;ooa`00ooonfX2
okSo00gooo]Z00God_l0oookJ_oonf[ooo]Zomgo0002oookJP03ob/0oooonf[ooo]Z00?ooo]Z00Co
o`00oookJ_o/o`3oo`2Y1OoonfX00onC0?oooo]ZoookJP05oookJP03oong0?mG0?oooo]Z00?ooo]Z
00?oo`3LoookJ_oonfX01?oonfX01OnMo`3ooo]ZoookJ_oonf[ok@3o027ooo]Z000XoookJP03obT0
oooonf[ooo]Z00?ooo]Z00?o0?o`oookJ_oonfX01?oonfX01?ooj03ooo]ZoookJ_oo00/3oookJP0:
oole0?oonf[o087ooookJ_lgo`3ooo]ZonGo0?l0onSooo]ZocKo00oooo]Z00Co0>?ooookJ_oonf[o
olT03?oonfX00ol0ongooo]ZoookJP0:oookJP03oolJ0?lM0?oo0?ob00Cooo]Z00?oo`2doonW0?oo
nfX01ooonfX00onDo`3ooo]ZoookJP02oookJP05og`0ooldo`3ooo]Zool0Col02ol00ooonfX00onD
o`3ooo]Zo`3ko`03oookJP04odh0oooonf[ooo]Zool050?ooo]Z00?oolL0oookJ_oonfX00ooonfX0
0onDo`3oo`2WoiCo0004oiCo00Cooo]Z00Go0?nGoookJ_oonf[ooo]Zohko0002oiCo0004oookJ_nD
o`3ooo]Zool01a?ooo]Z00?oo`0hoookJ_oUo`001?oUo`03oookJP03of`0oooonf[ooo]Z00Gooo]Z
00Sok@3ooiCo0?oonf[ooo]Zool0g?oonf[oE`3ooookJP;oU?l000CoT`3ooiCo0?o/o`3oo`000_oo
nfX00ol[0?oogOl0om;o0002oiCo00;ooo]Z1onDo`02ool0C`03o`000?oonf[ooo]Z00Oooo]Z0_l0
oh/2oookJP?o0?ne3OoonfX3ool0]@;ooo]Z00?oob00onGo0?oUo`003_oUo`06oookJP?oA?l00_oo
nfX6oolP00[ooo]Z0_oo0;DEoookJP03o`3o]Ooonf[ooo]Z00Oooo]Z00?o0?n;oookJ_oonfX04ooo
nfX00ooo04oooo]ZoookJP03oookJP03o`3oU_oonf[ooo]Z00?ooo]Z00?ooa`0oookJ_oonfX00_oo
nfX00ooUo`3ooo]ZoookJP0<oookJP05om;o0?oonf[ooo]ZoookJ_oMo`000_oonfX00ol[0?oooo]Z
oookJP03oookJP03oonK0?oo003ok?l000Gooo]Z00?oT`3ooookJ_oonfX01_oonfX00omG0?oooo]Z
oookJP03oookJP03ool0g?oonf[ooo]Z00Cooo]Z00GoWOl0oookJ_oonf[ooo]Zond0o`17oookJP03
obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01OoonfX00oooj03ooo]Zool02`04oookJP04
oole0?oonf[o087oocOo00;ooo]Z00?o0?nGo`3oj?lfo`004?oonfX00ol0hooooo]Zool0k00<oook
JP03o`3okOoonf[ooo]Z00_ooo]Z00?o7@3oo`3ol_oonfX00ooonfX00ooo0;Cooo]ZoonW0007oook
JP03o`3o2Ooonf[ooo]Z00;ooo]Z00GoO03oocCo0?l0;Ooooo]Zo`0;o`03oookJP03ok3o0?oonf[o
0?_o00?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05002oookJP03ooo70?oonf[ooo]Z00?ooo]Z00Ko
ojP0oookJ_oo0:Oooo]ZoolQ0?oo0;@6oookJP0:o`3oUooonf[ooo]ZoookJ_n>o`3oo`0ioookJ_l0
ol3ooo]Zool01a?ooo]Z00?oo`0hoookJ_mi0?l00_oonfX00onho`3ooo]Zool0_003oookJP03of`0
oooonf[ooo]Z00Cooo]Z00?ok@3ooookJ_nMo`000_oonfX00ooo0=cooo]ZoeL0o`02oookJP09oi<0
oooonf[oo`2Yool00?ooV`3ooo]Zob/0oooMo`3od_l000Cooo]Z00Co^?l0oookJ_oonf[ooa`00_oo
nfX01?l0003o0?nFool0Cooo04l:oookJP04o`3oRooonf[ooo]ZoookJP;o0?ne3OoonfX3ool0]@;o
oo]Z1_oo800FoookJPKoob002_oonfX2ool0]AGooo]Z0_l0okD8oookJP03o`3oRooonf[ooo]Z01Co
oo]Z00?oo`1?oookJ_oonfX00_oonfX00ol0oiKooo]ZoookJP03oookJP03oolL0?oonf[ooo]Z00;o
oo]Z00?o^?l0oookJ_oonfX03?oonfX01OoBo`3ooo]ZoookJ_oonf[ogOl000;ooo]Z00?o:`3ooook
J_oonfX00ooonfX01?ooV`3oo`00onco0?oo0:T5oookJP03oi<0oooonf[ooo]Z00Gooo]Z00?ookL0
oeL0oooonfX00ooonfX00ooo0=cooo]ZoookJP05oookJP05oigo0?oonf[ooo]ZoookJ_o]0?l08Ooo
nfX002Sooo]Z00?o:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP05oookJP03oooX0?oonf[o
o`0;00?ooo]Z00GoocD0oookJ_oonf[o087oocOo0002oookJP03o`3oj?oonf[o=_l000oooo]Z00Co
0>?ooookJ_oonf[oolT03OoonfX00ol0ongooo]ZoookJP09oookJP03oolJ0?lM0?oo0?ob00Cooo]Z
00?oo`2doookJ_ooY`002?oonfX00onDo`3ooo]ZoookJP02oookJP05ocCo0?oonf[ooo]Zo`0;oooo
01P00_oonfX00onDo`3ooo]Zo`3ko`03oookJP05odh0oooonf[ooo]ZoookJ_oo01@00ooonfX00ooo
a`3ooo]ZoookJP02oookJP03oiCo0?oonf[oo`2W00GoU?l00ooonfX02ol0oiOooo]ZoookJ_oonf[o
U?l0ohko0?oo03Wooo]ZoiCo0?oonf[oo`0701Cooo]Z00Ooo`0hogT0oooUo`3oiOl0okSo0?oonf[o
iOl000?ooo]Z00?oK03ooookJ_oonfX01OoonfX02?o]0?ooWOl0oookJ_oonf[oo`3LoookJ_mG0?oo
okL00_nDo`001?nC0?ooU?l0onco0?oo0002oookJP03ob/0oooMo`3od_l000Cooo]Z2?nDo`000ooo
04oooo]ZoookJP09oookJP;o0?n;0ooonfX2o`3o]@kooo]Z1?oo0;D00ooonf[oiOl0onGo000<onGo
00;ooo]Z1om4o`02oolP00cooo]Z1?oo0;DEoookJP;o0?ne2?oonfX2o`3oRaGooo]Z00?oo`1?oook
J_oonfX00_oonfX2o`3oUPGooo]Z00?ooa`0oookJ_oonfX00_oonfX00ooUo`3ooo]ZoookJP0=oook
JP04om;o0?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX00ooonfX00oooV`3oo`00onco0006
oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?oE`3ooookJ_oonfX00ooonfX00ooo0=cooo]ZoookJP03
oookJP03oigo0?oonf[ooo]Z00;ooo]Z00?ok@3ooookJ_oonfX0AOoonfX00olY0?oooo]ZoookJP02
oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0oookJ_oo00/01?oonfX01?oo=@3ooo]Zo`21oolg
o`02oookJP03o`3oUol0onSo=_l0013ooo]Z00?o0>?ooookJ_oo0>`03OoonfX00ol0ongooo]Zoook
JP0:oookJP03oad0ool0oo;ooo]Z00Cooo]Z00?oo`2doookJ_ooY`001ooonfX00ol0o`Wooo]Zoook
JP02oookJP05og`0ooldo`3ooo]Zo`0;oooo01P00_oonfX00on`o`3ooo]Zo`3ko`03oookJP05odh0
oooonf[ooo]ZoookJ_oo01@00ooonfX00oooa`3ooo]ZoookJP03oookJP05oonX0?oo0:Oooo]Zoook
J_oo8@001_oonfX02_l0oiOooo]ZoookJ_oonf[oS_l0oookJ_oo03Wooo]Zo`3o`?oo00LDoookJP03
ool0>?oonf[oN@3o00;ooo]Z00?o^?l0oookJ_oo0;`00ooonfX00om/0?oooo]ZoookJP04oookJP03
ond0oooonf[oWOl000;ooo]Z00?oo`3LoookJ_mG0?l00_oonfX02OnC0?oooo]Zool0ZOoo003ooi/0
oookJ_l[0?oogOl0om;o0004oookJP;o^?l000?ooo]ZoolL0?oo70000_l000000ol0oiKo0000ool0
C`0:oookJP;o0?n;0ooonfX2o`3o]@kooo]Z1?oo0;D4oookJPSoob001ooonfX7oolP00cooo]Z1?oo
0;DFoookJP03o`3o]Ooonf[ooo]Z00Kooo]Z0_l0oh/FoookJP04ool0Cooonf[ooo]ZoookJP;o0?nF
1OoonfX00ooo703ooo]ZoookJP02oookJP03okSo0?oonf[ooo]Z00gooo]Z00Cod_l0oookJ_oonf[o
gOl00ooonfX00ol[0?oooo]ZoookJP02oookJP04oonK0?oo003ok?l0ool0Z@Kooo]Z00?oT`3ooook
J_oonfX01OoonfX00ooo]`3oE`3ooookJP03oookJP03ool0g?oonf[ooo]Z00Cooo]Z00GoWOl0oook
J_oonf[ooo]Zond0o`0RoookJP00:?oonfX00olY0?oooo]ZoookJP03oookJP03o`3ol?oonf[ooo]Z
00Gooo]Z00?oonP0oookJ_oo00/00ooonfX01Ooo=@3ooo]ZoookJ_l0POoo=ol000;ooo]Z00Co0?oX
oookJ_oonf[o=_l03_oonfX01?l0hooooo]ZoookJ_oo0>`=oookJP03o`3okOoonf[ooo]Z00Wooo]Z
00?ooaX0oad0ool0oo801OoonfX00ooo0;CoojL0oookJP07oookJP03oiCo0?oonf[ooo]Z00;ooo]Z
00GoO03oocCo0?oonf[o00_oool06002oookJP04ok3o0?oonf[ooo]Zo`3ko`?ooo]Z00CoCP3ooook
J_oonf[oo`0D0ooonfX00oooa`3ooo]ZoookJP02oookJP03oiCo0?oonf[oo`2W00KoU?l00_oonfX0
0ol0oiOooo]ZoookJP02oookJP07ohko0?oonf[oo`0ioookJ_nDo`3ooo]Zool01`0CoookJP03ool0
>?oonf[oiOl000;ooo]Z00?o^?l0onGo0?oonfX00_oonfX00om/0?oooo]ZoookJP06oookJP08ond0
oonMo`3ooo]ZoookJ_oo0=cooo]ZoeL0oooo]`02oookJP04oi<0oonDo`3ok?l0ool000;ooo]Z00?o
:`3oomgo0?oBo`001OoonfX7oiCo00;oo`1?2ooonfX00ol0oh_ooo]ZoookJP02oookJP;o0?ne4?oo
nfX3ool0]@03oookJ_oUo`3oiOl000SoiOl02_m4o`08oookJPKoo`2e6?oonfX00ol0okGooo]Zoook
JP06oookJP;o0?n;5_oonfX00ooo04oooo]ZoookJP02oookJP03o`3oU_oonf[ooo]Z00Cooo]Z00?o
oa`0oookJ_oonfX00_oonfX00ooUo`3ooo]ZoookJP0=oookJP04om;o0?oonf[ooo]Zomgo00;ooo]Z
00?o:`3ooookJ_oonfX01?oonfX00ooo003oo`2Yonco0005oookJP03oi<0oooonf[ooo]Z00Kooo]Z
00?oE`3ooookJ_oonfX00ooonfX00ooo0=cooo]ZoookJP04oookJP05oigo0?oonf[ooo]ZoookJ_o]
0?l0B?oonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0ool02ooo
nfX00ooonfX01?oo=@3ooo]Zo`21oolgo`02oookJP04o`3oUol0onSooo]ZocKo00oooo]Z00?o0>?o
oookJ_oo0>`03OoonfX00ol0ongooo]ZoookJP0:oookJP03oolJ0?lM0?oo0?ob00Cooo]Z00?oo`2d
oookJ_ooY`001ooonfX00ol0o`Wooo]ZoookJP02oookJP05og`0ooldo`3ooo]Zo`0;oooo01P00_oo
nfX01?n`o`3ooo]ZoookJ_l0nol3oookJP05odh0oooonf[ooo]ZoookJ_oo01@00_oonfX00oooa`3o
oo]ZoookJP03oookJP06oonX0?oonf[oo`2WoookJ_oo8@3oo`2d1OoonfX00ol0oiOooo]ZoookJP02
oookJP06ohko0?oo03Wooo]Zo`3o`?oonf[oo`074ooonfX01?oo03Sooo]ZoookJ_mi0?l2oookJP03
okSo0?oo0;cooo]Z00;ooo]Z00?oK03ooookJ_oonfX01OoonfX00oo]0?oooo]Zoigo0002oookJP03
ool0g?oonf[oE`3o00;ooo]Z00WoT`3ooookJ_oo0:Woo`00oonK0?oonf[o:`3oomgo0?oBo`001Ooo
nfX01?nho`3ooo]ZoookJ_oo7002o`000003o`3oU_oonf[oo`1?00_ooo]Z0_l0oh/3oookJP;o0?ne
4?oonfX3ool0]@Wooo]Z1ooo800>oookJPGoo`2e6?oonfX2o`3o]@Oooo]Z0_l0oh/GoookJP05ool0
Cooonf[ooo]ZoookJ_l0oiH01_oonfX00ooo703ooo]ZoookJP02oookJP03okSo0?oonf[ooo]Z00go
oo]Z00Cod_l0oookJ_oonf[ogOl00ooonfX00ol[0?oooo]ZoookJP03oookJP03ool00?oonf[ok?l0
00Kooo]Z00?oT`3ooookJ_oonfX01OoonfX00ooo]`3oE`3ooookJP03oookJP03ool0g?oonf[ooo]Z
00Gooo]Z00GoWOl0oookJ_oonf[ooo]Zond0o`0RoookJP00:?oonfX00olY0?oooo]ZoookJP03oook
JP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0oookJ_oo00/00ooonfX01Ooo=@3ooo]ZoookJ_l0POoo
=ol000;ooo]Z00Co0?oXoookJ_oonf[o=_l03_oonfX01?l0hooooo]ZoookJ_oo0>`=oookJP03o`3o
kOoonf[ooo]Z00[ooo]Z00?ooaX0oad0ool0oo801?oonfX00ooo0;CoojL0oookJP07oookJP03oiCo
0?oonf[ooo]Z00?ooo]Z00Go=?l0oookJ_oo04oo00_oool06002oookJP03ok3o0?oonf[o0?_o00?o
oo]Z00GoCP3ooookJ_oonf[ooo]Zool05002oookJP03ooo70?oonf[ooo]Z00?ooo]Z00?oU?l0oook
J_nDo`001_nDo`02oookJP03o`3oUooonf[ooo]Z00;ooo]Z00KoS_l0ool0>Ooonf[oU?l0oookJ_oo
00LDoookJP03ool0>?oonf[oN@3o00;ooo]Z00?o^?l0onGo0?oonfX00_oonfX00om/0?oooo]Zoook
JP06oookJP08ond0oonMo`3ooo]Zool0g?oonf[oE`3ooookJ_oo]`02oookJP;oT`3o00Kok?l0ool0
0?oonf[ooo]Zob/0oooMo`02om;o00?ooo]Z2OnDo`000ooo04ooU?l0oookJP09oookJP;o0?n;1?oo
nfX2o`3o]A7ooo]Z1?oo0;D3onGo00koA?l00ooonfX5ool0]Acooo]Z0_l0okD7oookJP;o0?n;5ooo
nfX00ooo04oooo]ZoookJP02oookJP03o`3oU_oonf[ooo]Z00?ooo]Z00?oiOl0oolL0?oonfX00ooo
nfX00ooUo`3ooo]ZoookJP0=oookJP04om;o0?oonf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX0
1?oonfX00oooV`3oo`00onco0006oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?oE`3ooookJ_oonfX0
0_oonfX00ooo0=cooo]ZoookJP04oookJP03oigo0?oonf[ooo]Z00;ooo]Z00?ok@3ooookJ_oonfX0
A_oonfX00olY0?oooo]ZoookJP03oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0ool02ooonfX0
0ooonfX01?oo=@3ooo]Zo`21oolgo`02oookJP04o`3oUol0onSooo]ZocKo00oooo]Z00?o0>?ooook
J_oo0>`03OoonfX00ol0ongooo]ZoookJP0;oookJP03oad0ool0oo;ooo]Z00?ooo]Z00?oo`2doook
J_ooY`001ooonfX00ol0o`Wooo]ZoookJP03oookJP05ocCo0?l0;Ooooo]Zo`0;oooo01P00_oonfX0
0on`o`3ooo]Zo`3ko`03oookJP05odh0oooonf[ooo]ZoookJ_oo01@00_oonfX00oooa`3ooo]Zoook
JP03oookJP06oonX0?oonf[oo`2WoookJ_oo8@3oo`2d1_oonfX02_l0oiOooo]ZoookJ_oonf[oS_l0
oookJ_oo03Wooo]Zo`3o`?oo00LDoookJP08ool0>?oonf[ooo]ZogT0oooonf[o^?l0oookJ_oo0;`3
oookJP03of`0oooonf[ooo]Z00Gooo]Z00Sok@3ooookJ_nMo`3ooo]Zool0g?oonf[oE`3ooong00;o
oo]Z0_nC0?l01_oo0:Woo`00oonK0?oonf[o:`3oomgo00;od_l01?oonfX2okSo0006o`000?oo703o
oa`0o`000?l0oiKooo]Z0_oo04l;oookJP;o0?n;0ooonfX2o`3o]A7ooo]Z1?oo0;DEoookJPGoo`2e
6ooonfX2o`3o]@Oooo]Z0_l0oh/HoookJP05ool0Cooonf[ooo]ZoookJ_l0oiH01_oonfX00ooo703o
oo]ZoookJP02oookJP03okSo0?oonf[ooo]Z00gooo]Z00Cod_l0oookJ_oonf[ogOl00ooonfX00ol[
0?oooo]ZoookJP03oookJP03oonK0?oo003ok?l000Oooo]Z00?oT`3ooookJ_oonfX01OoonfX00ooo
]`3oE`3ooookJP03oookJP03ool0g?oonf[ooo]Z00Cooo]Z00GoWOl0oookJ_oonf[ooo]Zond0o`0S
oookJP00:?oonfX00olY0?oooo]ZoookJP03oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0oook
J_oo00/00ooonfX01Ooo=@3ooo]ZoookJ_l0POoo=ol000;ooo]Z00CoiOl0o`3oj?oonf[o=_l03_oo
nfX01Ol0hooooo]ZoookJ_oonf[oo`3/00gooo]Z00?o0?o]oookJ_oonfX02OoonfX00ooo6P3o7@3o
o`3olP04oookJP03ool0]?ooY`3ooo]Z00Oooo]Z00?oU?l0oookJ_oonfX00ooonfX01Oldo`3ooo]Z
oookJ_l02oooo`0H00;ooo]Z00Co/?l0oookJ_oonf[o0?_o0ooonfX01?m>0?oooo]ZoookJ_oo01@3
oookJP03ooo70?oonf[ooo]Z00;ooo]Z00?oU?l0oookJ_nDo`001onDo`000ooonf[o0?nGoookJP03
oookJP07ohko0?oonf[oo`0ioookJ_nDo`3ooo]Zool01`0CoookJP07ool0>?oonf[ooo]ZogT0oooo
nf[o^?l0onGo0004oookJP03of`0oooonf[ooo]Z00Kooo]Z00Sok@3ooigo0?oonf[oo`3LoookJ_mG
0?oooo]Zoong00?ooo]Z00?oT`3oonco0?oo00000_oonfX01?l[0?oogOl0oookJ_oBo`03oookJPWo
U?l00_oo04l;oookJP;o0?n;1?oonfX3o`3o]A;ooo]Z00?oo`2eodCo0?m4o`003om4o`02ool0]Aoo
oo]Z0_l0okD7oookJP;o0?n;6?oonfX01?oo04oooo]ZoookJ_oonfX2o`3oUPKooo]Z00?ooa`0oook
J_oonfX00_oonfX00ooUo`3ooo]ZoookJP0=oookJP04om;o0?oonf[ooo]Zomgo00;ooo]Z00?o:`3o
oookJ_oonfX01OoonfX00ooo003ok?l0oookJP05oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?oE`3o
oookJ_oonfX00ooonfX00ooo0=cooo]ZoookJP03oookJP03oigo0?oonf[ooo]Z00?ooo]Z00?ok@3o
oookJ_oonfX0A_oonfX00olY0?oooo]ZoookJP03oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0
ool02ooonfX00ooonfX01?oo=@3ooo]Zo`21oolgo`02oookJP04o`3oUooonf[o0?oXocKo00oooo]Z
00Co0>?ooookJ_oonf[oo`3/3OoonfX00ol0ongooo]ZoookJP0:oookJP03oad0ool0oo;ooo]Z00Co
oo]Z00?oo`2doonW0?oonfX01_oonfX00ol0o`Wooo]ZoookJP03oookJP05og`0ooldo`3ooo]Zo`0;
oooo01P00_oonfX01?n`o`3ooo]ZoookJ_l0nol3oookJP04odh0oooonf[ooo]Zool050?ooo]Z00?o
olL0oookJ_oonfX00ooonfX01_ooZ03ooo]Zool0Yooonf[oob40ool0]0Gooo]Z00?o0?nGoookJ_oo
nfX00_oonfX01_n>o`3oo`0ioookJ_l0ol3ooo]Zool01a?ooo]Z00Coo`0hoookJ_oonf[oN@3o0_oo
nfX00onho`3oo`2loookJP03oookJP03of`0oooonf[ooo]Z00Gooo]Z00Sok@3ooookJ_nMo`3ooo]Z
ool0g?oonf[oE`3ooong00?ooo]Z00WoT`3ooookJ_oo003ooi/0oookJ_l[0?oogOl0oookJ_oBo`00
1OoonfX01Onho`3o0000o`000?oo703ooo]Z00;o0?nF00?ooo]Zool0CooonfX02ooonfX00ol0oh_o
oo]ZoookJP02oookJP?o0?ne4_oonfXEool0]Aoooo]Z00?o0?neoookJ_oonfX01OoonfX2o`3oRaWo
oo]Z00?oo`1?oookJ_oonfX00_l0oiH6oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oo
nfX03OoonfX01?oBo`3ooo]ZoookJ_oMo`03oookJP03ob/0oooonf[ooo]Z00Cooo]Z00?oo`00onco
0?oonfX01_oonfX00onC0?oooo]ZoookJP05oookJP03oong0?mG0?oooo]Z00?ooo]Z00?oo`3Loook
J_oonfX01?oonfX00onMo`3ooo]ZoookJP02oookJP03ond0oooonf[ooo]Z027ooo]Z000XoookJP03
obT0oooonf[ooo]Z00Cooo]Z00?o0?o`oookJ_oonfX01?oonfX00oooj03ooo]Zool02`04oookJP04
oole0?oonf[o087oocOo00;ooo]Z00GoiOl0o`3oj?oonf[ooo]ZocKo000>oookJP04o`3Soooonf[o
oo]Zool0k0gooo]Z00?o0?o]oookJ_oonfX02OoonfX00ooo6P3o7@3oo`3olP05oookJP03ool0]?oo
Y`3ooo]Z00Oooo]Z00?oU?l0oookJ_oonfX00_oonfX01Oml0?oo=?l0oookJ_l02oooo`0H00?ooo]Z
00?o/?l0oookJ_l0nol00ooonfX01?m>0?oooo]ZoookJ_oo01@3oookJP03ooo70?oonf[ooo]Z00;o
oo]Z00?oU?l0oookJ_nDo`000_nDo`000ooo8@3oU?l0oiCo0003oiCo0003oookJ_l0oiOooo]Z00?o
oo]Z00CoS_l0ool0>Ooonf[oU?l00_oonfX00ooo00Oooo]ZoookJP0AoookJP03ool0>?oonf[oN@3o
00;ooo]Z00?o^?l0onGo0?oonfX00ooonfX00om/0?oooo]ZoookJP06oookJP08ond0oonMo`3ooo]Z
ool0g?oonf[oE`3ooookJ_oo]`03oookJP03oi<0ooo/o`3oo`0000;ooo]Z00Co:`3oomgo0?oonf[o
d_l00ooonfX:oiCo0003ool0Cooonf[ooo]Z00[ooo]Z0_l0oh/5oookJP?o0?ne4ooonfX=odCo027o
oo]Z00?o0?neoookJ_oonfX01OoonfX2o`3oRaWooo]Z00Goo`1?oookJ_oonf[ooo]Zo`3oUP07oook
JP04oolL0?oUo`3oiOl0oookJP;oiOl04?oonfX00ooBo`3ooo]Zomgo0002oookJP03ob/0oooonf[o
oo]Z00Gooo]Z00?ooi/0ool00?o/o`001OoonfX00onC0?oooo]ZoookJP06oookJP03oong0?mG0?oo
oo]Z00?ooo]Z00?oo`3LoookJ_oonfX00ooonfX00onMo`3ooo]ZoookJP03oookJP03ond0oooonf[o
oo]Z04Oooo]Z00?o:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP05oookJP03oooX0?oo00_o
oo]Z00Cooo]Z00?oocD0o`21oolgo`000ooonfX01?l0oiOo0?oXoookJ_lfo`0?oookJP03o`3Soooo
nf[oo`3/00gooo]Z00?o0?o]oookJ_oonfX02_oonfX00olM0?oo0?oboookJP04oookJP03ool0]?oo
nf[oojL000Oooo]Z00?o0?l9oookJ_oonfX00_oonfX01Oml0?oo=?l0o`0]ool02oooo`0H00?ooo]Z
00?o/?l0oookJ_l0nol00ooonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00;ooo]Z00?oolL0oookJ_oo
nfX00ooonfX01_ooZ03ooo]Zool0Yooonf[oob40ool0]0Kooo]Z00So0?nGoookJ_oonf[ooo]Zohko
0?oonf[oo`0io`3o`0;ooo]Z00?oo`07oookJ_oonfX04OoonfX01?oo03Sooo]ZoookJ_mi0?l2oook
JP03okSo0?oo0;cooo]Z00?ooo]Z00?oK03ooookJ_oonfX01OoonfX02?o]0?oooo]Zoigo0?oonf[o
o`3LoookJ_mG0?oookL00ooonfX02OnC0?oooo]Zool00?ooV`3ooo]Zob/0oooMo`3ooo]Zom;o0004
oookJP05o`000?nho`3o^?l0o`000?oo70000_oonfX2o`3oUP;oo`1?2ooonfX2o`3oR`Gooo]Z0ol0
okE1oookJP;o0?ne1_oonfX2o`3oRa[ooo]Z00Coo`1?oookJ_oonf[o0?nF1ooonfX00ooo703ooo]Z
oookJP02oookJP03okSo0?oonf[ooo]Z00kooo]Z00?od_l0oookJ_oMo`000ooonfX00ol[0?oooo]Z
oookJP04oookJP03oonK0?oo003ok?l000Kooo]Z00?oT`3ooookJ_oonfX01OoonfX00ooo]`3ooo]Z
oeL0o`04oookJP03ool0g?oonf[ooo]Z00?ooo]Z00?oWOl0oookJ_oonfX00_oonfX00oo]0?oooo]Z
oookJP0RoookJP00:?oonfX00olY0?oooo]ZoookJP04oookJP03o`3ol?oonf[ooo]Z00Cooo]Z00Co
onP0oookJ_oonf[oo`0;0ooonfX02?oo=@3ooo]Zo`21oooonf[o=ol0oookJ_oUo`3o0?oX0_oonfX0
0olfo`3ooo]ZoookJP0<oookJP04o`3Soooonf[ooo]Zool0k0gooo]Z00?o0?o]oookJ_oonfX02_oo
nfX00ooo6P3o7@3ooookJP04oookJP03ool0]?ooY`3ooo]Z00Oooo]Z00?oU?l0oookJ_oonfX00ooo
nfX01Oldo`3ooo]Zo`0;oooonf[oo`0H00;ooo]Z00?o/?l0oookJ_l0nol00ooonfX01Om>0?oooo]Z
oookJ_oonf[oo`0D00;ooo]Z00?oolL0oookJ_oonfX00ooonfX00onDo`3ooo]ZoiCo0002oiCo0003
oolQ0?nDo`3oU?l000?ooo]Z00?o0?nGoookJ_oonfX00_oonfX01on>o`3ooo]Zool0>Ooonf[oU?l0
oookJ_oo00L05?oonfX00ooo03Sooo]ZogT0o`02oookJP03okSo0?oUo`3ooo]Z00;ooo]Z00?oK03o
oookJ_oonfX01ooonfX02?o]0?ooWOl0oookJ_oo0=cooo]ZoeL0oooonf[ookL00ooonfX00onC0?oo
k?l0ool00002oookJP04ob/0oooMo`3ooo]Zom;o00?ooo]Z2?nDo`02o`3oUP;oo`1?3?oonfX2o`3o
R`Kooo]Z0ol0okDDoookJPWoA?l07_oonfX3o`3o]@Kooo]Z0_l0oh/JoookJP05ool0Cooonf[ooo]Z
oookJ_l0oiH01ooonfX00ooo703oiOl0onGo0002onGo017ooo]Z00?od_l0oookJ_oMo`000_oonfX0
0ol[0?oooo]ZoookJP04oookJP;ooi/000?oo`00onco0?oonfX01?oonfX00onC0?oooo]ZoookJP07
oookJP03oeL0oooonf[ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX00_oonfX00onMo`3ooo]ZoookJP04
oookJP03ond0oooonf[ooo]Z04Oooo]Z00?o:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP05
oookJP03oooX0?oonf[oo`0;00Cooo]Z00CoocD0o`21oooonf[o=ol00_oonfX01?l0oiOo0?oXoook
J_lfo`0?oookJP03o`3Soooonf[oo`3/00gooo]Z00?o0?o]oookJ_oonfX02ooonfX00olM0?oooo]Z
oookJP03oookJP03ool0]?oonf[oojL000Oooo]Z00?o0?l9oookJ_oonfX00ooonfX01Oldo`3o02go
o`0;oooonf[oo`0H00;ooo]Z00?o/?l0oookJ_l0nol00ooonfX01Om>0?oooo]ZoookJ_oonf[oo`0D
00;ooo]Z00?oolL0oookJ_oonfX01?oonfX01_ooZ03ooo]Zool0Yooonf[oob40ool0]0Gooo]Z00?o
0?nGoookJ_oonfX00_oonfX01_n>o`3oo`0ioookJ_l0ol3ooo]Zool01aCooo]Z00Soo`0hoookJ_oo
nf[oN@3ooookJ_nho`3ooo]Zool0_0?ooo]Z00?oK03ooookJ_oonfX01_oonfX02?o]0?oooo]Zoigo
0?oonf[oo`3LoookJ_mG0?oookL00ooonfX02OnC0?oooo]Zool00?ooV`3ooo]Zob/0oooMo`3ooo]Z
om;o0003oookJP?o000000Co^?l0o`000?oo703ooa`00_oonfX00ol0oiKooo]Zool0C`0<oookJP;o
0?n;1_oonfX4o`3o]C[ooo]Z0ol0okD6oookJP;o0?n;6ooonfX01?oo04oooo]ZoookJ_l0oiH7oook
JP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX03_oonfX00ooBo`3ooo]Zomgo0003oook
JP03ob/0oooonf[ooo]Z00?ooo]Z0_ooV`000ooo003ok?l0oookJP05oookJP03oi<0oooonf[ooo]Z
00Kooo]Z00?ookL0oeL0oooonfX00ooonfX00ooo0=cooo]ZoookJP03oookJP03oigo0?oonf[ooo]Z
00?ooo]Z00?ok@3ooookJ_oonfX08_oonfX002Wooo]Z00?o:@3ooookJ_oonfX00ooonfX00ol0oo3o
oo]ZoookJP04oookJP04oooX0?oonf[ooo]Zool02`?ooo]Z00GoocD0oookJ_oonf[o087oocOo0002
oookJP04onGo0?l0onSooo]ZocKo00kooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00<oookJP03o`3o
kOoonf[ooo]Z00[ooo]Z00?ooaX0oad0ool0oo801?oonfX00ooo0;CoojL0oookJP07oookJP03o`3o
2Ooonf[ooo]Z00?ooo]Z00Go=?l0oookJ_oonf[o00_oool06003oookJP03ok3o0?oonf[o0?_o00?o
oo]Z00CoCP3ooookJ_oonf[oo`0D0ooonfX00oooa`3ooo]ZoookJP02oookJP03oiCo0?oonf[oU?l0
00;oU?l000?oob40oiCo0?oonfX01?oonfX00ol0oiOooo]ZoookJP02oookJP04ohko0?oo03Wooo]Z
oiCo00;ooo]Z00?oo`07oookJ_oonfX04_oonfX00ooo03Sooo]ZogT0o`02oookJP03ool0_?oonf[o
oo]Z00;ooo]Z00?oK03ooookJ_oonfX01_oonfX01?o]0?oooo]Zoigo0?oonfX2ool0g0;oE`3o00Oo
okL0oookJ_oonf[ooo]Zoi<0ooo/o`3oo`0000;ooo]Z00?o:`3oomgo0?oonfX00_oBo`000ooonf[o
U?l0oiCo0006oiCo00;ooo]Z0_l0oiH00ooo04oooo]ZoookJP0;oookJP?o0?n;1_oonfX3o`3o]ACo
oo]Z1_m4o`0JoookJP;oU?l00_l0okD7oookJP;o0?n;6_oonfX2ool0C`;ooo]Z0_l0oiH6oookJP;o
oa`01_oUo`0?oookJP03om;o0?oonf[ogOl000;ooo]Z00?o:`3ooookJ_oonfX01?oonfX01?ooV`3o
o`00ool00?o/o`05oookJP03oi<0oooonf[ooo]Z00Oooo]Z00?oE`3ooookJ_oonfX00ooonfX00ooo
0=cooo]ZoookJP03oookJP03oigo0?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX0B?oonfX00olY
0?oooo]ZoookJP03oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0oookJ_oo00/01?oonfX01?oo
=@3ooo]Zo`21oolgo`02oookJP04o`3oUooonf[o0?oXocKo00oooo]Z00Co0>?ooookJ_oonf[oo`3/
3?oonfX00ol0ongooo]ZoookJP0;oookJP03oad0ool0oo;ooo]Z00Cooo]Z00?oo`2doonW0?oonfX0
1_oonfX00ol0o`Wooo]ZoookJP03oookJP05ocCo0?l0;Ooooo]Zo`0;oooo01P00ooonfX00on`o`3o
oo]Zo`3ko`03oookJP05odh0oooonf[ooo]ZoookJ_oo01@00_oonfX00oooa`3ooo]ZoookJP03oook
JP06oonX0?oonf[oo`2WoookJ_oo8@3oo`2d1_oonfX02?l0oiOooo]ZoookJ_oonf[oS_l0oookJ_oo
03Wo0?o00_oonfX00ooo00Oooo]ZoookJP0BoookJP03ool0>?oonf[oN@3o00;ooo]Z00?o^?l0ool0
_?oonfX00ooonfX00om/0?oooo]ZoookJP06oookJP04ond0oooonf[oWOl0oookJP;oo`3L0_mG0?l3
oookJP08oi<0oooonf[oo`00oonK0?oonf[o:`3oomgo0?oonfX2om;o0003oookJ_l0003o000000;o
000000Co^?l0oookJ_oonf[ooa`00_oonfX2o`3oUP03ool0Cooonf[ooo]Z00_ooo]Z0ol0oh/7oook
JP?o0?ne=?oonfX3o`3o]@Oooo]Z0_l0oh/KoookJP;oo`1?00?ooo]Zo`3oU_l0oiH01_oonfX2oolL
00?ooo]Z0_nho`0@oookJP03om;o0?oonf[ogOl000?ooo]Z00?o:`3ooookJ_oonfX00ooonfX01?oo
V`3oo`00ool00?o/o`06oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?ookL0oeL0oooonfX00ooonfX0
0ooo0=cooo]ZoookJP04oookJP03oigo0?oonf[ooo]Z00;ooo]Z00?ok@3ooookJ_oonfX08ooonfX0
02Wooo]Z00?o:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP04oookJP04oooX0?oonf[ooo]Z
ool02`Cooo]Z00CoocD0oookJ_l0POoo=ol00_oonfX01?oUo`3o0?oXoookJ_lfo`0>oookJP05o`3S
oooonf[ooo]ZoookJ_oo0>`03OoonfX00ol0ongooo]ZoookJP09oookJP03oolJ0?lM0?oo0?ob00Go
oo]Z00?oojL0oookJ_oonfX01ooonfX00ol0o`Wooo]ZoookJP03oookJP05ocCo0?oonf[o00_ooook
J_oo01P00_oonfX00on`o`3ooo]Zo`3ko`03oookJP05odh0oooonf[ooo]ZoookJ_oo01@00_oonfX0
0oooa`3ooo]ZoookJP02oookJP04oiCo0?oonf[oU?l0ool0Y`;ooo]Z00?oob40oookJ_oonfX01?oo
nfX02ol0oiOooo]ZoookJ_oonf[oS_l0oookJ_oo03Wooo]ZoiCo0?oonf[oo`0701Gooo]Z00Koo`0h
oookJ_mi0?oooo]ZokSo0?oo0;`4oookJP03of`0oooonf[ooo]Z00Kooo]Z00?ok@3ooookJ_nMo`00
0_oonfX01?oo0=cooo]ZoeL0oooo]`03oookJP03oi<0ooo/o`3oo`0000;ooo]Z00Ko:`3oomgo0?oo
nf[ooo]Zom;o0?l00005oiCo00;ooo]Z00GoU?l0oookJ_oonf[ooo]Zo`3oUP04oiCo00cooo]Z0ol0
oh/6oookJP?o0?ne5OoonfX2odCo01Oooo]Z00?o0?neoiCo0?nDo`000_nDo`07oookJP;o0?n;6_oo
nfX2ool0C`?ooo]Z00?o0?nFoookJ_oonfX01OoonfX00ooo703ooo]ZonGo0007onGo00cooo]Z0_oB
o`001Ooonf[ogOl0oookJ_oonf[o:`3o00Kooo]Z00Gooi/0ool00?oo0:Wooo]Zonco0004oookJP03
oi<0oooonf[ooo]Z00Oooo]Z00?oE`3ooookJ_oonfX01?oonfX00ooo0=cooo]ZoookJP02oookJP03
oigo0?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX0B_oonfX00olY0?oooo]ZoookJP03oookJP03
o`3ol?oonf[ooo]Z00Cooo]Z00?oonP0oookJ_oo00/01OoonfX00ooo=@3o087oocOo0002oookJP05
o`3oUooonf[o0?oXoookJ_lfo`003_oonfX01?l0hooooo]ZoookJ_oo0>`=oookJP03o`3okOoonf[o
oo]Z00[ooo]Z00?o7@3oo`3ol_oonfX01?oonfX00ooo0;CoojL0oookJP07oookJP03o`3o2Ooonf[o
oo]Z00?ooo]Z00Go=?l0o`0]ool02ooooo]Zool06002oookJP03ok3o0?oonf[o0?_o00?ooo]Z00Go
CP3ooookJ_oonf[ooo]Zool05002oookJP03ooo70?oonf[ooo]Z00?ooo]Z00OoojP0oookJ_oonf[o
o`2WoookJ_oo8@3oo`2d00Kooo]Z00[o0?nGoookJ_oonf[ooo]Zohko0?oo03Wooo]Zo`3o`?oonf[o
o`075OoonfX00ooo03Sooo]ZogT0o`02oookJP03okSo0?oo0;cooo]Z00?ooo]Z00?oK03ooookJ_oo
nfX01_oonfX00oo]0?oooo]Zoigo0002oookJP03ool0g?oonf[oE`3o00?ooo]Z00OoT`3ooookJ_oo
003ooi/0oookJ_l[0?oogOl000;ooo]Z00?od_l0o`000?l000000_l000001Ooonf[o^?l0okSo0?oo
nf[ooa`000?ooo]Z00?o0?nFool0Cooo04l03_oonfX3o`3oR`Oooo]Z0ol0okD]oookJPCo0?ne2?oo
nfX2o`3oRa_ooo]Z0_oo04l2oookJP03o`3oU_oonf[ooo]Z00Gooo]Z00?ooa`0oookJ_oonfX00_oo
nfX00onho`3ooo]ZoookJP0>oookJP;od_l000?ooo]Zomgo0?oonfX00_oonfX00ol[0?oooo]Zoook
JP03oookJP05oonK0?oo003ooo]Zool0ZOo/o`001OoonfX00onC0?oooo]ZoookJP06oookJP03oong
0?mG0?oooo]Z00Cooo]Z00?oo`3LoookJ_oonfX00ooonfX00onMo`3ooo]ZoookJP02oookJP03ond0
oooonf[ooo]Z02Cooo]Z000YoookJP03obT0oooonf[ooo]Z00?ooo]Z00?o0?o`oookJ_oonfX01Ooo
nfX00oooj03ooo]Zool02`04oookJP04oole0?oonf[o087oocOo00;ooo]Z00GoiOl0o`3oj?oonf[o
oo]ZocKo000>oookJP04o`3Soooonf[ooo]Zool0k0gooo]Z00?o0?o]oookJ_oonfX02_oonfX00ooo
6P3o7@3ooookJP04oookJP03ool0]?ooY`3ooo]Z00Oooo]Z00?o0?l9oookJ_oonfX00ooonfX01Old
o`3ooo]Zo`0;oooonf[oo`0H00;ooo]Z00?o/?l0oookJ_l0nol01?oonfX01?m>0?oooo]ZoookJ_oo
01@2oookJP03ooo70?oonf[ooo]Z00?ooo]Z00CoU?l0oookJ_oonf[oo`2W0_oonfX00ooo8@3ooo]Z
oookJP03oookJP03o`3oUooonf[ooo]Z00;ooo]Z00CoS_l0ool0>Ooonf[oU?l00_oonfX00ooo00Oo
oo]ZoookJP0BoookJP03ool0>?oonf[oN@3o00;ooo]Z00?o^?l0ool0_?oonfX00ooonfX00om/0?oo
oo]ZoookJP06oookJP03ond0oooonf[oWOl000;ooo]Z00Coo`3LoookJ_mG0?oookL00ooonfX00onC
0?ook?l0ool00002oookJP06ob/0oooMo`3ooo]ZoookJ_oBo`3o00000onDo`001_oonf[o^?l0okSo
0?oonf[oU?l0oolL00;ooo]Z0_l0oiH7oiCo00[ooo]Z0ol0oh/6oookJPGo0?ne9OoonfX4o`3o]@Go
U?l01OoonfX2o`3oRa_ooo]Z00Coo`1?oookJ_oonf[ooo]Z0_l0oiH7oookJP03oolL0?oonf[oiOl0
00WoiOl02_oonfX01?oBo`3ooo]ZoookJ_oMo`02oookJP03ob/0oooonf[ooo]Z00Cooo]Z00Gooi/0
ool00?oo0:Wooo]Zonco0004oookJP03oi<0oooonf[ooo]Z00Oooo]Z00?oE`3ooong0?oonfX01?oo
nfX00ooo0=cooo]ZoookJP02oookJP03oigo0?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX0Booo
nfX00olY0?oooo]ZoookJP03oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0ool02ooonfX01?oo
nfX00ooo=@3o087oocOo0002oookJP05o`3oUooonf[o0?oXoookJ_lfo`003ooonfX00ol0hooooo]Z
ool0k00=oookJP03o`3okOoonf[ooo]Z00_ooo]Z00?o7@3ooookJ_oonfX00ooonfX00ooo0;Cooo]Z
oonW0007oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z00Go=?l0o`0]ool02ooooo]Zool06002oookJP03
ok3o0?oonf[o0?_o00Cooo]Z00OoCP3ooookJ_oonf[ooo]Zool05?oonf[oolL000Kooo]Z00?oojP0
oookJ_oo0:L00_oonfX00ooo8@3ooo]ZoookJP04oookJP08o`3oUooonf[ooo]ZoookJ_n>o`3ooo]Z
ool0>Ol0ol02oookJP03ool01ooonf[ooo]Z01;ooo]Z00Soo`0hoookJ_oonf[oN@3ooookJ_nho`3o
oo]Zool0_0Cooo]Z00?oK03ooookJ_oonfX01_oonfX00oo]0?oooo]Zoigo0002oookJP03ool0g?oo
nf[oE`3o00?ooo]Z00OoT`3ooookJ_oo003ooi/0oookJ_l[0?oogOl000;ooo]Z00Cod_l0o`000?l0
003o00000ooonfX01?nho`3ooo]ZoolL0?oo7003oookJP03o`3oU_oo04ooo`1?00oooo]Z0ol0oh/7
oookJPGo0?ne9?oonfX4o`3o]@[ooo]Z0_l0oh/KoookJP;oo`1?0_oonfX2o`3oUPOooo]Z00?ooa`0
oookJ_oonfX00_oonfX00onho`3ooo]ZoookJP0>oookJP04om;o0?oonf[ooo]Zomgo00?ooo]Z00?o
:`3ooookJ_oonfX00ooonfX01OooV`3oo`00oookJ_oo0:Wok?l000Gooo]Z00?oT`3ooookJ_oonfX0
1ooonfX00omG0?oooo]ZoookJP03oookJP03ool0g?oonf[ooo]Z00?ooo]Z00?oWOl0oookJ_oonfX0
0_oonfX00oo]0?oooo]ZoookJP0UoookJP00:OoonfX00olY0?oooo]ZoookJP03oookJP03o`3ol?oo
nf[ooo]Z00Gooo]Z00?oonP0oookJ_oo00/01?oonfX01?oo=@3ooo]ZoookJ_l0POl2oookJP05onGo
0?oonf[o0?oXoookJ_lfo`003_oonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00cooo]Z00?o0?o]oook
J_oonfX02_oonfX00ooo6P3o7@3oo`3olP04oookJP03ool0]?oUo`3ooo]Z00Sooo]Z00?o0?l9oook
J_oonfX00_oonfX01Oldo`3o02gooookJ_l02oooo`0H00?ooo]Z00?o/?l0oookJ_l0nol00ooonfX0
1?m>0?oooo]ZoookJ_oo01@3oookJP03ooo70?oonf[ooo]Z00;ooo]Z00CoojP0oookJ_oonf[oo`2W
0_oonfX00ooo8@3ooo]ZoookJP04oookJP0;o`3oUooonf[ooo]ZoookJ_n>o`3ooo]Zool0>Ooonf[o
U?l0oookJ_oo00L05OoonfX00ooo03Sooo]ZogT0o`02oookJP03okSo0?oo0;cooo]Z00?ooo]Z00?o
K03ooookJ_oonfX01_oonfX00oo]0?oooo]Zoigo0002oookJP04ool0g?oonf[oE`3ooong00?ooo]Z
00?oT`3oonco0?oo00000_oonfX01ol[0?oogOl0oookJ_l0003od_l0o`000?nDo`001?oonfX00onh
o`3ooo]ZoookJP02oolL00;ooo]Z00?o0?nFoiCo0?nDo`002OnDo`08oookJP?o0?n;2?oonfX6o`3o
]Acooo]Z0ol0okD2oookJPSoU?l000Cooo]ZoiCo0?nDo`3oU?l06ooonfX2ool0C`?ooo]Z00?o0?nF
oookJ_oonfX01_oonfX00ooo703ooo]ZonGo0008onGo00_ooo]Z00Cod_l0oookJ_oonf[ogOl00_oo
nfX00ol[0?oooo]ZoookJP04oookJP03oonK0?oo003oo`2Y00;ok?l01?oonfX00onC0?oooo]Zoook
JP07oookJP03oeL0oooo]`3ooo]Z00Cooo]Z00?oo`3LoookJ_oonfX00_oonfX00onMo`3ooo]Zoook
JP03oookJP03ond0oooonf[ooo]Z04cooo]Z00?o:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]Zoook
JP05oookJP03oooX0?oo00_ooo]Z00Cooo]Z00?oocD0oookJ_l0POl00_oonfX01Ol0oiOooo]Zoook
J_l0onSo=_l000oooo]Z00Co0>?ooookJ_oonf[oo`3/3?oonfX00ol0ongooo]ZoookJP0;oookJP03
oad0ool0oo;ooo]Z00Cooo]Z00?oo`2doonW0?oonfX01ooonfX00ol0o`Wooo]ZoookJP02oookJP05
ocCo0?oonf[o02goo`0;oooo01P00ooonfX00on`o`3ooo]Zo`3ko`03oookJP05odh0oooonf[ooo]Z
oookJ_oo01@00_oonfX00oooa`3ooo]ZoookJP03oookJP03oonX0?oonf[oo`2W00;ooo]Z00?oob40
ool0]?oonfX01OoonfX02_l0oiOooo]ZoookJ_oonf[oS_l0ool0>Ooonf[o0?o0oookJ_oo00LEoook
JP03ool0>?oonf[oN@3o00;ooo]Z00?o^?l0oookJ_oo0;`01?oonfX00om/0?oooo]ZoookJP06oook
JP03ond0oooonf[oWOl000;ooo]Z00?oo`3LoookJ_mG0?l00ooonfX02_nC0?oooo]Zool00?o/o`3o
oo]Zob/0oooMo`3ooo]Zo`000?oBo`02o`0000Cooo]Z0_nho`000ooonf[ooa`0oolL0002oookJP;o
0?nF0_oo04l@oookJP?o0?n;2OoonfX6o`3o]A_ooo]Z0ol0okD;oookJP?o0?n;7?oonfX01Ooo04oo
oo]ZoookJ_oonf[o0?nF00Sooo]Z00?ooa`0oookJ_oonfX00_oonfX00onho`3ooo]ZoookJP0>oook
JP04om;o0?oonf[ooo]Zomgo00?ooo]Z00?o:`3ooookJ_oonfX00ooonfX00oooV`3oo`00oookJP02
onco00Gooo]Z00?oT`3ooookJ_oonfX01ooonfX00omG0?oooo]ZoookJP03oookJP03ool0g?oonf[o
oo]Z00?ooo]Z00?oWOl0oookJ_oonfX00_oonfX00oo]0?oooo]ZoookJP0VoookJP00:OoonfX00olY
0?oooo]ZoookJP04oookJP03o`3ol?oonf[ooo]Z00Cooo]Z00?oonP0oookJ_oo00/01?oonfX02ooo
=@3ooo]ZoookJ_l0POoo=ol0oookJ_oUo`3ooo]Zo`3oj?oonf[o=_l000kooo]Z00Go0>?ooookJ_oo
nf[ooo]Zool0k00<oookJP03o`3okOoonf[ooo]Z00[ooo]Z00?ooaX0oookJ_lM0?l01?oonfX00ooo
0;CoiOl0oookJP08oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z00Go=?l0oookJ_l02ooooo]Zool06002
oookJP03ok3o0?oonf[o0?_o00Cooo]Z00CoCP3ooookJ_oonf[oo`0D0_oonfX00oooa`3ooo]Zoook
JP03oookJP03oonX0?oonf[oo`2W00?ooo]Z00?oob40oookJ_oonfX00ooonfX00ol0oiOooo]Zoook
JP02oookJP04ohko0?oo03Wooo]Zo`3o`0;ooo]Z00?oo`07oookJ_oonfX04ooonfX00ooo03Sooo]Z
ogT0o`02oookJP03okSo0?oo0;cooo]Z00;ooo]Z00?oK03ooookJ_oonfX01ooonfX00oo]0?oooo]Z
oigo0002oookJP04ool0g?oonf[oE`3ooong00?ooo]Z00KoT`3ooookJ_oo003oo`00oookJ_l[0?l3
ooo90003om;o0?l0003ooo]Z00Cooo]Z00Go^?l0oookJ_oonf[ooo]ZoolL0002oookJP03o`3oU_nD
o`3oU?l000[oU?l02OoonfX3o`3oR`_ooo]Z1_l0okD;oookJP_o0?ne0ooonfX;oiCo01cooo]Z0_oo
04l4oookJP03o`3oU_oonf[ooo]Z00Kooo]Z00?ooa`0oookJ_oonfX01ooUo`0<oookJP04om;o0?oo
nf[ooo]Zomgo00;ooo]Z00?o:`3ooookJ_oonfX01?oonfX01?ooV`3oo`00ool0ZOo/o`05oookJP03
oi<0oooonf[ooo]Z00Oooo]Z00?oE`3ooong0?oonfX01?oonfX00ooo0=cooo]ZoookJP02oookJP03
oigo0?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX0COoonfX00olY0?oooo]ZoookJP03oookJP03
o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0ool02ooonfX01?oonfX01?oo=@3ooo]Zo`21oolgo`02oook
JP05o`3oUooonf[o0?oXoookJ_lfo`003_oonfX01?l0hooooo]ZoookJ_oo0>`<oookJP03o`3okOoo
nf[ooo]Z00_ooo]Z00?ooaX0oad0oooonfX01?oonfX00ooo0;CoojL0oookJP07oookJP03o`3o2Ooo
nf[ooo]Z00?ooo]Z00Go=?l0o`0]ool02ooooo]Zool06002oookJP03ok3o0?oonf[o0?_o00Cooo]Z
00CoCP3ooookJ_oonf[oo`0D0_oonfX00oooa`3ooo]ZoookJP04oookJP03oonX0?oonf[oo`2W00;o
oo]Z00?oob40oookJ_oonfX01?oonfX02?l0oiOooo]ZoookJ_oonf[oS_l0oookJ_oo03Wo0?o00_oo
nfX00ooo00Oooo]ZoookJP0CoookJP03ool0>?oonf[oN@3o00;ooo]Z00?o^?l0oookJ_oo0;`00ooo
nfX00om/0?oooo]ZoookJP07oookJP03ond0oooonf[oWOl000;ooo]Z00?oo`3LoookJ_mG0?l00ooo
nfX01_nC0?oooo]Zool00?oo003ooi/0ob/0o`;ogOl000?o0000om;o0?l000001_oonfX01?nho`3o
oo]ZoookJ_oo7003oookJP;o0?nF0_oo04lAoookJP?o0?n;3?oonfX5o`3o]@_ooo]Z2ol0okD;oook
JP?o0?n;7OoonfX2ool0C`?ooo]Z00?o0?nFoookJ_oonfX01_oonfX00ooo703ooo]ZoookJP02oook
JP03okSo0?oonf[ooo]Z00kooo]Z00Cod_l0oookJ_oonf[ogOl00ooonfX00ol[0?oooo]ZoookJP03
oookJP04oonK0?oo003ooo]Zonco00Kooo]Z00?oT`3ooookJ_oonfX01ooonfX00omG0?oooo]Zoook
JP03oookJP03ool0g?oonf[ooo]Z00?ooo]Z00?oWOl0oookJ_oonfX00_oonfX00oo]0?oooo]Zoook
JP0WoookJP00:OoonfX00olY0?oooo]ZoookJP04oookJP03o`3ol?oonf[ooo]Z00Cooo]Z00?oonP0
oookJ_oo00/01OoonfX01?oo=@3ooo]Zo`21oolgo`02oookJP05onGo0?l0onSooo]ZoookJ_lfo`00
3OoonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00gooo]Z00?o0?o]oookJ_oonfX02_oonfX00ooo6P3o
7@3ooookJP04oookJP;oiOl02?oonfX00ol0o`Wooo]ZoookJP03oookJP05ocCo0?l0;Ooooo]Zo`0;
oooo01P00ooonfX00on`o`3ooo]Zo`3ko`03oookJP04odh0oooonf[ooo]Zool050?ooo]Z00?oolL0
oookJ_oonfX00_oonfX01?ooZ03ooo]ZoookJ_oo0:L2oookJP03oolQ0?oonf[ooo]Z00Cooo]Z00?o
0?nGoookJ_oonfX00_oonfX01_n>o`3oo`0ioookJ_l0ol3ooo]Zool01aKooo]Z00Ooo`0hoookJ_mi
0?oooo]ZokSo0?oonf[oo`2l00?ooo]Z00?oK03ooookJ_oonfX01ooonfX00oo]0?oooo]Zoigo0002
oookJP04ool0g?oonf[oE`3ooong00?ooo]Z00GoT`3ooookJ_o/o`3oo`00oookJP06ooo900Gooo]Z
0_nho`02oookJP;ooa`00_oonfX;oiCo00cooo]Z1?l0oh/=oookJP_o0?ne3?oonfX<oiCo01_ooo]Z
0_oo04l4oookJP;o0?nF2?oonfX00ooo703ooo]ZoookJP06onGo00cooo]Z0_oBo`02oookJP04omgo
0?oonf[ooo]Zob/0o`Kooo]Z00Cooi/0ool00?oo0:Wok?l01OoonfX00onC0?oooo]ZoookJP07oook
JP03oeL0oooonf[ookL000Cooo]Z00?oo`3LoookJ_oonfX00_oonfX00onMo`3ooo]ZoookJP03oook
JP03ond0oooonf[ooo]Z04kooo]Z00?o:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP05oook
JP03oooX0?oo00_ooo]Z00Gooo]Z00?oocD0o`21oolgo`000_oonfX01Ol0oiOooo]Zo`3oj?oonf[o
=_l000kooo]Z00Co0>?ooookJ_oonf[oo`3/3OoonfX00ol0ongooo]ZoookJP0;oookJP03oad0oooo
nf[ooo]Z00?ooo]Z00?oo`2doookJ_ooY`001ooonfX00ol0o`Wooo]ZoookJP03oookJP05ocCo0?oo
nf[o02goo`0;oooo01P00ooonfX00on`o`3ooo]Zo`3ko`03oookJP05odh0oooonf[ooo]ZoookJ_oo
01@00_oonfX00oooa`3ooo]ZoookJP03oookJP03oonX0?oonf[oo`2W00;ooo]Z00?oob40ool0]?oo
nfX01OoonfX02_l0oiOooo]ZoookJ_oonf[oS_l0ool0>Ooonf[o0?o0oookJ_oo00LFoookJP05ool0
>?oonf[oN@3ooookJ_nho`000_oonfX01Ooo0;cooo]ZoookJ_oonf[oK03o00Wooo]Z00?ok@3ooook
J_nMo`000_oonfX00ooo0=cooo]ZoeL0o`03oookJP09oi<0oooonf[ooo]Zool00?ooV`3ooo]Zob/0
oooMo`3o000000;od_l01_oonfX2okSo0003oookJ_oo703ooa`000?ooo]Z00?o0?nFoookJ_oo04l0
0_oo04lAoookJPCo0?n;3OoonfX;o`3o]A;ooo]Z1?l0oh/NoookJP;oo`1?0ooonfX2o`3oUPSooo]Z
00?ooa`0oookJ_oonfX00_oonfX00onho`3ooo]ZoookJP0=oookJP;od_l00_oonfX01OoMo`3ooo]Z
oookJ_oonf[o:`3o00Gooo]Z00Cooi/0ool00?oonf[ok?l01_oonfX00onC0?oooo]ZoookJP07oook
JP03oeL0oooo]`3ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX00ooonfX00onMo`3ooo]ZoookJP02oook
JP03ond0oooonf[ooo]Z02Sooo]Z000YoookJP03obT0oooonf[ooo]Z00Cooo]Z00?o0?o`oookJ_oo
nfX01?oonfX01?ooj03ooo]ZoookJ_oo00/4oookJP04oole0?oonf[o087oocOo00;ooo]Z00GoiOl0
o`3oj?oonf[ooo]ZocKo000=oookJP03o`3Soooonf[ooo]Z00;ooo]Z00?oo`3/oookJ_oonfX02_oo
nfX00ol0ongooo]ZoookJP0:oookJP03oolJ0?lM0?oo0?ob00Cooo]Z00?oo`2donGo0?oUo`002?oo
nfX00ol0o`Wooo]ZoookJP03oookJP04ocCo0?oonf[o00_oool060?ooo]Z00?o/?l0oookJ_l0nol0
0ooonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00;ooo]Z00?oolL0oookJ_oonfX00ooonfX00oooZ03o
oo]Zool0Y`03oookJP03oolQ0?oonf[ooo]Z00Cooo]Z00_o0?nGoookJ_oonf[ooo]Zohko0?oonf[o
o`0ioookJ_l0ol3ooo]Zool01`0FoookJP07ool0>?mi0?oooo]ZoookJ_nho`3ooo]Zool0_003oook
JP03of`0oooonf[ooo]Z00Oooo]Z00?ok@3ooookJ_nMo`000_oonfX01?oo0=cooo]ZoeL0oooo]`03
oookJP05oi<0oooonf[ok?l0ool00?oonfX02?oob@04oookJP;o^?l00_oonfX2oolL0003oookJ_nD
o`3oU?l000OoU?l04OoonfX6o`3oRagooo]Z3OnDo`0JoookJP03ool0Cooonf[ooo]Z00?ooo]Z00?o
0?nFoookJ_oonfX01ooonfX00ooo703ooo]ZoookJP05onGo00gooo]Z00God_l0oookJ_oonf[ooo]Z
omgo0002oookJP03ob/0oooonf[ooo]Z00Cooo]Z00Cooi/0ool00?oo0:Wok?l01OoonfX00onC0?oo
oo]ZoookJP07oookJP03oeL0oooonf[ookL000Cooo]Z00?oo`3LoookJ_oonfX00ooonfX00onMo`3o
oo]ZoookJP03oookJP03ond0oooonf[ooo]Z04kooo]Z00?o:@3ooookJ_oonfX01?oonfX00ol0oo3o
oo]ZoookJP04oookJP03oooX0?oonf[oo`0;00Gooo]Z00?oocD0oookJ_l0POl00_oonfX01Ol0oiOo
oo]Zo`3oj?oonf[o=_l000kooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00<oookJP03o`3okOoonf[o
oo]Z00_ooo]Z00?o7@3oo`3ol_oonfX01?oonfX00ooo0;CoojL0oookJP07oookJP03o`3o2Ooonf[o
oo]Z00?ooo]Z00Co=?l0o`0]ool02oooo`0H0ooonfX00on`o`3ooo]Zo`3ko`03oookJP05odh0oooo
nf[ooo]ZoookJ_oo01@00_oonfX00oooa`3ooo]ZoookJP04oookJP03oonX0?oonf[oo`2W00;ooo]Z
00?oob40oookJ_oonfX01?oonfX02ol0oiOooo]ZoookJ_oonf[oS_l0oookJ_oo03Wooo]Zo`3o`?oo
nf[oo`0701Kooo]Z00Ooo`0hoookJ_mi0?oooo]ZokSo0?oonf[oo`2l00Cooo]Z00?oK03ooookJ_oo
nfX01ooonfX00oo]0?oooo]Zoigo0002oookJP03ool0g?oonf[oE`3o00?ooo]Z00OoT`3ooookJ_oo
nf[oo`00onco0?l0003o:`3o00;ogOl000?ooo]Zom;o0?oonfX01_oonfX2okSo0003oookJ_oo703o
oa`000;ooo]Z0_l0oiH2oookJP;oo`1?4ooonfX6o`3oRb3ooo]Z1?l0oh/PoookJP;oo`1?1?oonfX0
0ol0oiKooo]ZoookJP07oookJP03oolL0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX03OoonfX0
1OoBo`3ooo]ZoookJ_oonf[ogOl000?ooo]Z00?o:`3ooookJ_oonfX00ooonfX01?ooV`3oo`00oook
J_o/o`06oookJP03oi<0oooonf[ooo]Z00Oooo]Z00?oE`3ooong0?oonfX00ooonfX00ooo0=cooo]Z
oookJP04oookJP03oigo0?oonf[ooo]Z00;ooo]Z00?ok@3ooookJ_oonfX0:?oonfX002[ooo]Z00?o
:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP04oookJP04oooX0?oonf[ooo]Zool02`Cooo]Z
00CoocD0oookJ_oonf[o087o0_oonfX01OoUo`3ooo]Zo`3oj?oonf[o=_l000kooo]Z00Go0>?ooook
J_oonf[ooo]Zool0k00<oookJP03o`3okOoonf[ooo]Z00[ooo]Z00?ooaX0oookJ_lM0?l01?oonfX0
1?oo0;CoiOl0onGo0?oUo`07oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z00Go=?l0oookJ_oonf[o00_o
ool06003oookJP03ok3o0?l0nooooo]Z00?ooo]Z00CoCP3ooookJ_oonf[oo`0D0ooonfX00oooa`3o
oo]ZoookJP03oookJP03oonX0?oonf[oo`2W00;ooo]Z00?oob40oookJ_oonfX01?oonfX00ol0oiOo
oo]ZoookJP02oookJP06ohko0?oo03Wooo]Zo`3o`?oonf[oo`075_oonfX00ooo03Sooo]ZogT0o`02
oookJP03okSo0?oonf[oo`2l00?ooo]Z0_m/0?l8oookJP;ok@3o0_nMo`000ooonf[oo`3Lool0g002
oeL0o`?ooo]Z00?oT`3ooookJ_oonfX00_oo000:ooo900?ooo]Z0_nho`02oookJP03oolL0?oonf[o
oo]Z00OoU?l05ooonfX6o`3oRaGooo]Z4?nDo`0GoookJP;oo`1?1OoonfX00ol0oiKooo]ZoookJP07
oookJP04oolL0?oonf[ooo]ZoookJP?oiOl03_oonfX01OoBo`3ooo]ZoookJ_oonf[ogOl000;ooo]Z
00?o:`3ooookJ_oonfX01?oonfX01?ooV`3oo`00oookJ_o/o`05oookJP03oi<0oooonf[ooo]Z00Oo
oo]Z00?oE`3ooong0?oo]`001?oonfX00ooo0=cooo]ZoookJP03oookJP03oigo0?oonf[ooo]Z00?o
oo]Z00?ok@3ooookJ_oonfX0D?oonfX00olY0?oooo]ZoookJP03oookJP03o`3ol?oonf[ooo]Z00Co
oo]Z00?oonP0oookJ_oo00/01OoonfX00ooo=@3ooo]Zo`21o`02oookJP05o`3oUooonf[ooo]Zo`3o
j?lfo`003ooonfX01?l0hooooo]ZoookJ_oo0>`<oookJP03o`3okOoonf[ooo]Z00_ooo]Z00?ooaX0
oad0oooonfX01?oonfX00ooo0;CoojL0oookJP07oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z00Go=?l0
o`0]oooonf[o00_oool06003oookJP03ok3o0?l0nooooo]Z00?ooo]Z00GoCP3ooookJ_oonf[ooo]Z
ool05002oookJP03ooo70?oonf[ooo]Z00?ooo]Z00?oojP0oookJ_oo0:L00_oonfX00ooo8@3oo`2d
oookJP05oookJP0:o`3oUooonf[ooo]ZoookJ_n>o`3oo`0ioookJ_l0ol3ooo]Zool01aKooo]Z00?o
o`0hoookJ_mi0?l00_oonfX00onho`3ooo]Zool0_004oookJP;oK03o2?oonfX2ond0o`;oWOl000Co
oo]Zool0g?oonf[oE`3o0ooonfX00onC0?oooo]ZoookJP02ool00003oonK0?l0003o:`3o00;ogOl0
00?od_l0oookJ_oonfX01_oonfX2okSo0003oookJ_oo703ooo]Z00;ooo]Z0_l0oiH2oookJP;oo`1?
5ooonfX6o`3oRaOooo]Z0ol0oh/RoookJP;oo`1?1OoonfX00ol0oiKooo]ZoookJP07oookJP03oolL
0?oonf[ooo]Z00;ooo]Z00?o^?l0oookJ_oonfX03OoonfX01OoBo`3ooo]ZoookJ_oonf[ogOl000?o
oo]Z00?o:`3ooookJ_oonfX00ooonfX01OooV`3oo`00oookJ_o/o`3oo`2Y00Gooo]Z00?oT`3ooook
J_oonfX01ooonfX00omG0?oookL0oookJP03oookJP03ool0g?oonf[ooo]Z00Cooo]Z00?oWOl0oook
J_oonfX00_oonfX00oo]0?oooo]ZoookJP0YoookJP00:_oonfX00olY0?oooo]ZoookJP03oookJP03
o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0oookJ_oo00/01OoonfX00ooo=@3ooo]Zo`21o`02oookJP05
onGo0?oonf[o0?oXoookJ_lfo`003_oonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00cooo]Z00?o0?o]
oookJ_oonfX02_oonfX01?oo6P3ooo]Zoad0ool0oo84oookJPCoiOl01ooonfX00ol0o`Wooo]Zoook
JP02oookJP05og`0ooldo`3ooo]Zo`0;oooo01P00ooonfX00on`o`3ooo]Zo`3ko`03oookJP04odh0
oooonf[ooo]Zool050?ooo]Z00?oolL0oookJ_oonfX00ooonfX00oooZ03ooo]Zool0Y`03oookJP03
oolQ0?oonf[ooo]Z00Cooo]Z00_o0?nGoookJ_oonf[ooo]Zohko0?oonf[oo`0ioookJ_l0ol3ooo]Z
ool01`0FoookJP03ool0>?oonf[oN@3o00;ooo]Z00?o^?l0oookJ_oo0;`01?oonfX00om/0?oooo]Z
oookJP07oookJP03ond0oooonf[oWOl000;ooo]Z00?oo`3LoookJ_mG0?l00ooonfX01OnC0?oooo]Z
oookJ_o/o`3oo`0000coolT00_oonfX00onho`3ooo]ZoookJP02oolL0003oookJ_nDo`3oU?l000?o
U?l000?ooo]ZoiCo0?nDo`006ooonfXDo`3oRa7oU?l05OoonfX2ool0C`Gooo]Z0_l0oiH9oookJP04
oolL0?oonf[ooo]ZoookJP;oiOl03ooonfX01OoBo`3ooo]ZoookJ_oonf[ogOl000;ooo]Z00?o:`3o
oookJ_oonfX01?oonfX01?ooV`3oo`00oookJ_o/o`06oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?o
E`3ooong0?oonfX01?oonfX00ooo0=cooo]ZoookJP03oookJP03oigo0?oonf[ooo]Z00?ooo]Z00?o
k@3ooookJ_oonfX0DOoonfX00olY0?oooo]ZoookJP03oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?o
onP0ool02ooonfX01OoonfX01Ooo=@3o087ooookJ_oonf[o0?nG00;ooo]Z00?o0?oXoookJ_lfo`00
3_oonfX01?l0hooooo]ZoookJ_oo0>`<oookJP03o`3okOoonf[ooo]Z00_ooo]Z00?ooaX0oad0ool0
oo801?oonfX00ooo0;Cooo]ZoonW0008oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z00GoO03oocCo0?l0
;Ooo00_oool06003oookJP03ok3o0?oonf[o0?_o00?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05003
oookJP03ooo70?oonf[ooo]Z00?ooo]Z00?oojP0oookJ_oo0:L00_oonfX00ooo8@3ooo]ZoookJP04
oookJP0;o`3oUooonf[ooo]ZoookJ_n>o`3ooo]Zool0>Ooonf[o0?o0oookJ_oo00L05_oonfX00ooo
03Sooo]ZogT0o`02oookJP03okSo0?oonf[oo`2l00Gooo]Z00?oK03ooookJ_oonfX01ooonfX01oo]
0?oooo]Zoigo0?oonf[oo`3LoookJ_mG0?l00ooonfX01onC0?oooo]ZoookJ_l0003oo`00oonK0?l0
00000_l[0?l00ooMo`3od_l0oookJP08oookJP04okSo0?oonf[ooa`0oolL00?ooo]Z0ol0oiH00ooo
nf[oo`1?ool0C`0KoookJQOo0?n;9?oonfX00ooo04oooo]ZoookJP03oookJP;o0?nF2OoonfX00ooo
703ooo]ZoookJP02oookJP03okSo0?oonf[ooo]Z00gooo]Z00God_l0oookJ_oonf[ooo]Zomgo0003
oookJP03ob/0oooonf[ooo]Z00?ooo]Z00Gooi/0ool00?oonf[ok?l0ool0Z@06oookJP03oi<0oooo
nf[ooo]Z00Kooo]Z00?oE`3ooookJ_oonfX00ooonfX00ooo0=cooo]ZoookJP04oookJP03oigo0?oo
nf[ooo]Z00;ooo]Z00?ok@3ooookJ_oonfX0:_oonfX002[ooo]Z00?o:@3ooookJ_oonfX00ooonfX0
0ol0oo3ooo]ZoookJP05oookJP03oooX0?oonf[oo`0;00Gooo]Z00?oocD0oookJ_l0POl00_oonfX0
0ooUo`3ooo]Zo`3oj002oookJP03ocKo0?oonf[ooo]Z00_ooo]Z00Go0>?ooookJ_oonf[ooo]Zool0
k00=oookJP03o`3okOoonf[ooo]Z00[ooo]Z00?ooaX0oookJ_lM0?l01?oonfX5onGo00Kooo]Z00?o
0?l9oookJ_oonfX00ooonfX01Oldo`3ooo]Zool0Col02oooo`0H00?ooo]Z00?o/?l0o`3koooonfX0
0ooonfX01?m>0?oooo]ZoookJ_oo01@3oookJP03ooo70?oonf[ooo]Z00?ooo]Z00?oojP0oookJ_oo
0:L00_oonfX00onDo`3oob40oookJP04oookJP03o`3oUooonf[ooo]Z00;ooo]Z00KoS_l0ool0>Ooo
nf[ooo]Zo`3o`?oo00LGoookJP08ool0>?oonf[oiOl0onGo0?oonf[o^?l0oookJ_oo0;`4oookJP03
of`0oooonf[ooo]Z00Oooo]Z00?ok@3ooookJ_nMo`000_oonfX01?oo0=cooo]ZoeL0oooo]`02oook
JP04oi<0oooonf[o0000ool0Z@;oo`002ooob@02oookJP;o^?l00_oonfX2oolL00CoU?l00_l0oiH0
1?oonf[oU?l0ool0Cooo04mAoookJP03ool0Cooonf[ooo]Z00;ooo]Z0ol0oiH9oookJP;ooa`00_oo
nfX00onho`3oiOl0oookJP0>oookJP;od_l00ooonfX01?oMo`3ooo]ZoookJ_l[0?l5oookJP;ooi/0
00?oo`00onco0?o/o`001_oonfX00onC0?oooo]ZoookJP06oookJP03oeL0oooo]`3ooo]Z00Cooo]Z
00?oo`3LoookJ_oonfX00ooonfX00onMo`3ooo]ZoookJP03oookJP03ond0oooonf[ooo]Z05;ooo]Z
00?o:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP05oookJP03oooX0?oo00_ooo]Z00Gooo]Z
00GoocD0ocOo0?l0POoooo]Zo`3oU`02oookJP03o`3oj?oonf[o=_l000kooo]Z00Go0>?ooookJ_oo
nf[ooo]Zool0k00<oookJP03o`3okOoonf[ooo]Z00_ooo]Z00?ooaX0oad0oooonfX01?oonfX00ooo
0;CoojL0oookJP07oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z00Go=?l0o`0]oooonf[o00_oool06003
oookJP03ok3o0?l0nooooo]Z00?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05002oookJP03ooo70?oo
nf[ooo]Z00?ooo]Z00?oojP0oookJ_oo0:L00_oonfX00ooo0;Coob40oookJP05oookJP06o`3oUooo
nf[ooo]ZoookJ_n>o`3oo`0i0_oonfX00ol0ol3oo`07oookJP0FoookJP03ool0>?oonf[oN@3o00;o
oo]Z00?o^?l0oookJ_oo0;`01OoonfX00om/0?oooo]ZoookJP07oookJP08ond0oooonf[oWOl0oook
J_oo0=cooo]ZoeL0oooo]`02oookJP04oi<0oooonf[o0000o`0000;oo`0000?o0000oookJ_l[0?l0
0_oMo`000ooBo`3ooo]ZoookJP06oookJP;o^?l000?ooo]ZoolL0?oo70001?oonfX2o`3oUP04oook
J_oo04ooo`1?ool0Ce7ooo]Z0_oo04l3oookJP?o0?nF2OoonfX2oolL00?ooo]Z0_nho`0>oookJP;o
d_l00ooonfX01OoMo`3ooo]ZoookJ_oonf[o:`3o00Gooo]Z00Gooi/0ool00?o/o`3ok?l0ool0Z@06
oookJP03oi<0oooonf[ooo]Z00Kooo]Z00?oE`3ooookJ_oonfX00ooonfX00ooo0=cooo]ZoookJP04
oookJP03oigo0?oonf[ooo]Z00;ooo]Z00?ok@3ooookJ_oonfX0:ooonfX002_ooo]Z00?o:@3ooook
J_oonfX00ooonfX00ol0oo3ooo]ZoookJP04oookJP03oooX0?oonf[oo`0;00Gooo]Z00CoocD0oook
J_oonf[o087o0_oonfX01OoUo`3ooo]Zo`3oj?oonf[o=_l000gooo]Z00?o0>?ooookJ_oonfX00_oo
nfX00ooo0>cooo]ZoookJP0:oookJP03o`3okOoonf[ooo]Z00[ooo]Z00?ooaX0oookJ_lM0?l01?oo
nfX5onGo00Oooo]Z00?o0?l9oookJ_oonfX00_oonfX01Oldo`3o02gooookJ_l02oooo`0H00?ooo]Z
00?o/?l0o`3koooonfX00ooonfX01?m>0?oooo]ZoookJ_oo01@3oookJP03ooo70?oonf[ooo]Z00?o
oo]Z00?oojP0oookJ_oo0:L00ooonfX00ooo8@3ooo]ZoookJP04oookJP0;o`3oUooonf[ooo]Zoook
J_n>o`3ooo]Zool0>Ooonf[o0?o0oookJ_oo00L05ooonfX01ooo03SoiOl0onGo0?oUo`3ooo]ZokSo
0?oo0;`01OoonfX00om/0?oooo]ZoookJP07oookJP03ond0oooonf[oWOl000;ooo]Z00Coo`3Loook
J_mG0?oookL00_oonfX01_nC0?oo0000o`000?l0003ok?l0ool000[oolT01?oonfX2okSo00;ooo]Z
00Cooa`0oiCo0?nDo`3oU?l00_oonfX3o`3oUP04oookJ_oo04ooo`1?ool0Cdcooo]Z0_oo04l3oook
JP;o0?nF2_oonfX2oolL00;ooo]Z0_nho`0@oookJP03om;o0?oonf[ooo]Z00;ooo]Z00CogOl0oook
J_oonf[o:`3o1OoonfX01OooV`3oo`00ool00?o/o`3oo`2Y00Kooo]Z00?oT`3ooookJ_oonfX01ooo
nfX00omG0?oooo]ZoookJP03oookJP03ool0g?oonf[ooo]Z00?ooo]Z00?oWOl0oookJ_oonfX00ooo
nfX00oo]0?oooo]ZoookJP1DoookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01Ooo
nfX00oooj03oo`0;oookJP05oookJP03oole0?oonf[o087o00;ooo]Z00Go0?nGoookJ_oonf[o0?oX
ocKo000>oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`03?oonfX00ol0ongooo]ZoookJP0;oookJP03
oolJ0?lM0?oo0?ob00Cooo]Z00?oo`2doookJ_ooY`002?oonfX00ol0o`Wooo]ZoookJP02oookJP05
og`0ooldo`3o02goo`0;oooo01P00ooonfX00on`o`3o0?_ooookJP03oookJP05odh0oooonf[ooo]Z
oookJ_oo01@00ooonfX00oooa`3ooo]ZoookJP03oookJP03oonX0?oonf[oo`2W00;ooo]Z00?oob40
oookJ_oonfX01OoonfX01_l0oiOooo]ZoookJ_n>o`3ooo]Zool0>@;ooo]Z00?o0?o0ool01ooonfX0
5_oonfX00ooo03SoN@3ooookJP02oookJP03okSo0?oonf[oo`2l00Gooo]Z00?oK03ooookJ_oonfX0
1ooonfX02?o]0?oooo]Zoigo0?oonf[oo`3LoookJ_mG0?oookL00_oonfX00onC0?oo0000o`000002
o`000003ool00?ooV`3ooo]Z00;o:`3o0_oMo`000ooBo`3ooo]ZoookJP06oookJP;o^?l000?ooo]Z
oolL0?oonfX01?oonfX3o`3oUP04oookJ_oo04ooo`1?ool0Cdcooo]Z0_oo04l3oookJP;o0?nF2_oo
nfX2oolL00?ooo]Z0_nho`0?oookJP03om;o0?oonf[ooo]Z00;ooo]Z00GogOl0oookJ_oonf[ooo]Z
ob/0o`05oookJP;oo`0000?ok?l0oookJ_oo0:T01_oonfX00onC0?oooo]ZoookJP06oookJP03oong
0?mG0?oooo]Z00?ooo]Z00?oo`3LoookJ_oonfX01?oonfX00onMo`3ooo]ZoookJP02oookJP03ond0
oooonf[ooo]Z02cooo]Z000[oookJP03obT0oooonf[ooo]Z00?ooo]Z00?o0?o`oookJ_oonfX01Ooo
nfX00oooj03oo`0;oookJP04oookJP04oole0?oonf[ooo]Zo`21o`;ooo]Z00GoiOl0oookJ_l0onSo
oo]ZocKo000>oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`03?oonfX00ol0ongooo]ZoookJP0:oook
JP04oolJ0?oonf[o7@3oo`3olPCooo]Z1OoUo`06oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z00Co=?l0
oookJ_oo04oo00_o1?oonfX00on`o`3o0?_ooookJP02oookJP05odh0oooonf[ooo]ZoookJ_oo01@0
0ooonfX00oooa`3ooo]ZoookJP03oookJP03oonX0?oonf[oo`2W00;ooo]Z00?oU?l0oolQ0?oonfX0
1OoonfX01_l0oiOooo]ZoookJ_oonf[oS_l0ool0>@;ooo]Z00?o0?o0ool01ooonfX05ooonfX00ooo
03SoiOl0onGo0002onGo0003okSo0?oo0;cooo]Z00Cooo]Z00?oK03ooookJ_oonfX01ooonfX00oo]
0?oooo]Zoigo0002oookJP04ool0g?oonf[oE`3ooong00;ooo]Z0_nC0?l2o`000003onco0?oo003o
olT000OoolT01ooonfX2okSo0003oookJ_oo703oU?l000Kooo]Z0_l0oiH2oookJP?oo`1?A_oonfX3
ool0C`?ooo]Z0_l0oiH:oookJP;ooa`00_oonfX2okSo017ooo]Z00Cod_l0oookJ_oonf[ooo]Z0_oM
o`02oookJP03ob/0oooonf[ooo]Z00?ooo]Z00Gooi/0ool00?oonf[ok?l0ool0Z@06oookJP03oi<0
oooonf[ooo]Z00Oooo]Z00?oE`3ooookJ_oonfX00ooonfX00ooo0=cooo]ZoookJP04oookJP03oigo
0?oonf[ooo]Z00;ooo]Z00?ok@3ooookJ_oonfX0EOoonfX00olY0?oooo]ZoookJP02oookJP03o`3o
l?oonf[ooo]Z00Kooo]Z00?oonP0oookJ_oonfX01?oonfX00ooo=@3ooo]Zo`21o`02oookJP06o`3o
Uooonf[ooo]Zo`3oj?oonf[o=_l03_oonfX01?l0hooooo]ZoookJ_oo0>`<oookJP03o`3okOoonf[o
oo]Z00_ooo]Z00?ooaX0oad0ool0oo801?oonfX00ooo0;Cooo]ZoonW0008oookJP03o`3o2Ooonf[o
oo]Z00?ooo]Z00Co=?l0o`0]oooonf[o00_o1?oonfX00on`o`3o0?_ooookJP02oookJP05odh0oooo
nf[ooo]ZoookJ_oo01@00ooonfX00oooa`3ooo]ZoookJP04oookJP06oonX0?oo0:Oooo]ZoookJ_oo
0;Coob401_oonfX01_l0oiOooo]ZoookJ_oonf[oS_l0ool0>@;ooo]Z00?o0?o0ool01ooonfX05ooo
nfX00ooo03SoN@3ooookJP02oookJP03okSo0?oonf[oo`2l00Gooo]Z00?oK03ooookJ_oonfX01ooo
nfX02?o]0?oooo]Zoigo0?oonf[oo`3LoookJ_mG0?oookL00_oonfX2oi<0o`;o000000?ooo]Zool0
0?ooV`000_oonfX00ol[0?oooo]Zomgo0002om;o00Sooo]Z0_nho`02oolL00Kooo]Z0ol0oiH01?oo
nf[oo`1?ool0Cooo04m6oookJP?oo`1?0ooonfX2o`3oUP[ooo]Z0_oo7003oookJP;o^?l04?oonfX0
1?oBo`3ooo]ZoookJ_oonfX2omgo00?ooo]Z00?o:`3ooookJ_oonfX00ooonfX01Ooo003ooo]Zonco
0?oonf[oo`2Y00Kooo]Z00?oT`3ooookJ_oonfX01_oonfX00ooo]`3oE`3ooookJP03oookJP03ool0
g?oonf[ooo]Z00Gooo]Z00GoWOl0oookJ_oonf[ooo]Zond0o`0_oookJP00:ooonfX00olY0?oooo]Z
oookJP03oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0oookJ_oo00/01OoonfX00ooo=@3ooo]Z
o`21o`02oookJP03onGo0?oonf[o0?oX00;ooo]Z00?o=_l0oookJ_oonfX02ooonfX01Ol0hooooo]Z
oookJ_oonf[oo`3/00gooo]Z00?o0?o]oookJ_oonfX02_oonfX00ooo6P3ooo]Zoad0o`04oookJPKo
iOl01OoonfX00ol0o`Wooo]ZoookJP03oookJP05ocCo0?l0;Ooooo]Zo`0;oooo01P00ooonfX00on`
o`3o0?_ooookJP03oookJP04odh0oooonf[ooo]Zool050?ooo]Z00?oolL0oookJ_oonfX00ooonfX0
0oooZ03ooo]Zool0Y`03oookJP03oolQ0?oonf[ooo]Z00Cooo]Z00Ko0?nGoookJ_oonf[ooo]Zohko
0?oonfX2ooo90003oookJ_l0ol3oo`0701Oooo]Z00?oo`0honGo0?oUo`001?oUo`000ooo0;cooo]Z
oookJP03oookJP03of`0oooonf[ooo]Z00Oooo]Z0_o]0?l2oigo0004oookJ_oo0=cooo]ZoeL0o`;o
okL00_l000001?nC0?oo0000oookJ_oonfX2ool000KoolT000?od_l0oookJ_oonfX01_oonfX2okSo
0003oookJ_oo703ooa`000Kooo]Z0ol0oiH2oookJP?oo`1?@?oonfX3ool0C`?ooo]Z0ol0oiH:oook
JP;ooa`00_oonfX2okSo01;ooo]Z00God_l0oookJ_oonf[ooo]Zomgo0003oookJP03ob/0oooonf[o
oo]Z00?ooo]Z00Gooi/0ool00?oonf[ok?l0ool0Z@06oookJP03oi<0oooonf[ooo]Z00Oooo]Z00?o
E`3ooookJ_oonfX00ooonfX00ooo0=cooo]ZoookJP04oookJP03oigo0?oonf[ooo]Z00;ooo]Z00?o
k@3ooookJ_oonfX0E_oonfX00olY0?oooo]ZoookJP03oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?o
onP0ool02ooonfX01OoonfX01Ooo=@3o087ooookJ_oonf[o0?nG00;ooo]Z00?o0?oXoookJ_lfo`00
3_oonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00cooo]Z00?o0?o]oookJ_oonfX02ooonfX00ooo6P3o
7@3ooookJP04oookJP03ool0]?ooY`3ooo]Z00Oooo]Z00?o0?l9oookJ_oonfX00ooonfX01Oml0?oo
=?l0o`0]ool02oooo`0H00?ooo]Z00?o/?l0o`3koooonfX00ooonfX01Om>0?oooo]ZoookJ_oonf[o
o`0D00?ooo]Z00?oolL0oookJ_oonfX00ooonfX00oooZ03ooo]Zool0Y`02oookJP03oolQ0?oonf[o
oo]Z00Gooo]Z00Ko0?nGoookJ_oonf[oS_l0oookJ_oo03T2oookJP03o`3o`?oo00Oooo]Z01Kooo]Z
00?oo`0hoookJ_mi0?l00_oonfX01?nho`3ooo]ZoookJ_oo0;`5oookJP03of`0oooonf[ooo]Z00Oo
oo]Z00Ook@3ooookJ_nMo`3oWOl0ool0g?oonf[oE`3o00;ookL00_l000001?nC0?oo0000oookJ_oo
nfX2ool000;ooo]Z0_l[0?l2omgo00;od_l02?oonfX2okSo00;ooa`01ooonfX2o`3oUP;ooo]Z0ooo
04m0oookJP?oo`1?0ooonfX3o`3oUP[ooo]Z0_oo7003oookJP;o^?l04OoonfX01OoBo`3ooo]Zoook
J_oonf[ogOl000Cooo]Z00?o:`3ooookJ_oonfX00ooonfX01Ooo003ooo]Zonco0?oonf[oo`2Y00Ko
oo]Z00?oT`3ooookJ_oonfX01_oonfX00ooo]`3oE`3ooookJP03oookJP03ool0g?oonf[ooo]Z00Go
oo]Z00GoWOl0oookJ_oonf[ooo]Zond0o`0`oookJP00;?oonfX00olY0?oooo]ZoookJP02oookJP03
o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0oookJ_oo00/01OoonfX00ooo=@3ooo]Zo`21o`02oookJP06
o`3oUooonf[ooo]Zo`3oj?oonf[o=_l03OoonfX00ol0hooooo]ZoookJP02oookJP03ool0k?oonf[o
oo]Z00[ooo]Z00?o0?o]oookJ_oonfX02_oonfX00ooo6P3ooo]Zoad0o`04oookJPOoiOl01OoonfX0
0ol0o`Wooo]ZoookJP02oookJP05og`0ooldo`3ooo]Zool0Col02ol00ooonfX00on`o`3ooo]Zo`3k
o`03oookJP04odh0oooonf[ooo]Zool050Cooo]Z00?oolL0oookJ_oonfX00ooonfX00oooZ03oo`2W
oookJP02oookJP03oiCo0?oo8@3ooo]Z00Gooo]Z00Go0?nGoookJ_oonf[ooo]Zohko0003ooo90003
o`3o`?oonf[oo`0701Oooo]Z00?oo`0honGo0?oUo`001?oUo`000ooo0;cooo]ZoookJP03oookJP03
of`0oooonf[ooo]Z00Sooo]Z00Wok@3ooookJ_nMo`3ooo]Zool0g?oonf[oE`3ooookJ_oo]`000_l0
0002oi<0o`;ooo]Z00?oolT0ool00?oob@000_oob@001Ol[0?oooo]Zooo90?oob@3od_l000Sooo]Z
00?o^?l0oookJ_oonfX00ooo7006oookJP?o0?nF0_oonfX3ool0CcWooo]Z1?oo04l4oookJP;o0?nF
2ooonfX2oolL00;ooo]Z0_nho`0CoookJP03om;o0?oonf[ooo]Z00;ogOl00ooonfX00ol[0?oooo]Z
oookJP03oookJP05oonK0?oo003ooo]Zonco0?oo0:T01_oonfX00onC0?oooo]ZoookJP07oookJP03
oeL0oooonf[ooo]Z00?ooo]Z00?oo`3LoookJ_oonfX01?oonfX00onMo`3ooo]ZoookJP03oookJP03
ond0oooonf[ooo]Z05Oooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP05oookJP03
oooX0?oo00_ooo]Z00Gooo]Z00GoocD0ocOo0?l0POoooo]Zo`3oU`03oookJP03o`3oj?lfo`3ooo]Z
00gooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00<oookJP03o`3okOoonf[ooo]Z00_ooo]Z00?ooaX0
oad0ool0oo801?oonfX00ooo0;Cooo]ZoonW0008oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z00GoO03o
ocCo0?l0;Ooooo]Zo`0;o`03oookJP03ok3o0?oonf[o0?_o00?ooo]Z00GoCP3ooookJ_oonf[ooo]Z
ool05003oookJP03ooo70?oonf[ooo]Z00Cooo]Z00KoojP0ool0Yooonf[ooo]Zool0]?oo8@06oook
JP06o`3oUooonf[ooo]ZoookJ_n>o`3oo`0i0ooonfX00ol0ol3oo`07oookJP0FoookJP03ool0>?oo
nf[oN@3o00;ooo]Z00?o^?l0oookJ_oo0;`01_oonfX00om/0?oooo]ZoookJP07oookJP09ond0oooo
nf[ooo]Zoigo0?oo0=cooo]ZoeL0oooonf[ookL000;o00000_nC0?l2oookJP03onco0?oo003ooo]Z
00;ooo]Z00Co:`3ooookJ_oMo`3ogOl00_oBo`08oookJP03okSo0?oonf[ooa`000;ooa`01_oonfX3
o`3oUP;ooo]Z0ooo04lioookJPCoo`1?1?oonfX2o`3oUP_ooo]Z0_oo7003oookJP;o^?l04_oonfX0
0ooBo`3ooo]ZoookJP02omgo00Cooo]Z00?o:`3ooookJ_oonfX00ooonfX01Ooo003ooo]Zonco0?oo
nf[oo`2Y00Kooo]Z00?oT`3ooookJ_oonfX01_oonfX00ooo]`3oE`3ooookJP03oookJP03ool0g?oo
nf[ooo]Z00Gooo]Z00?oWOl0oookJ_oonfX00_oonfX00oo]0?oooo]ZoookJP0^oookJP00;?oonfX0
0olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0ool02ooonfX01?oonfX0
1?oo=@3ooo]ZocOo0?l0POl2oookJP05o`3oUooonf[o0?oXoookJ_lfo`003OoonfX00ol0hooooo]Z
oookJP02oookJP03ool0k?oonf[ooo]Z00[ooo]Z00?o0?o]oookJ_oonfX02_oonfX01?oo6P3ooo]Z
oookJ_lM0?l3oookJPSoiOl01?oonfX00ol0o`Wooo]ZoookJP03oookJP05ocCo0?oonf[ooo]Zo`0;
oooo01P00ooonfX00on`o`3o0?_ooookJP03oookJP04odh0oooonf[ooo]Zool050?ooo]Z00?oolL0
oookJ_oonfX01?oonfX00oooZ03oo`2WoookJP02oookJP03oolQ0?oonf[ooo]Z00Cooo]Z00?o0?nG
oookJ_oonfX00_oonfX01on>o`3oolT0ooo90?oob@3o0?o0oookJ_oo00L05ooonfX7onGo0003ool0
_?oonf[ooo]Z00?ooo]Z00?oK03ooookJ_oonfX02?oonfX02Oo]0?oooo]Zoigo0?oonf[oo`3Loook
J_mG0?oo0000oong0002o`000005oookJ_nC0?oooo]ZoookJ_oob@000_oo0002oookJP;o:`3o00Co
oo]Zooo90?oBo`3od_l01ooonfX2okSo00?ooo]Z0ooo7006oookJP?o0?nF0_oonfX3ool0Cbkooo]Z
0_nDo`03oookJP?oo`1?1_oonfX2o`3oUP[ooo]Z0ooo7002oookJP;o^?l04ooonfX2om;o0003oook
J_oMo`3ogOl000?ooo]Z0_l[0?l5oookJP05oonK0?oo003ooo]Zonco0?oUo`001_oonfX00onC0?oo
oo]ZoookJP06oookJP03oong0?mG0?oooo]Z00Cooo]Z00?oo`3LoookJ_oonfX01?oonfX00onMo`3o
oo]ZoookJP03oookJP03ond0oooonf[ooo]Z05Sooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3o
oo]ZoookJP06oookJP03oooX0?oonf[ooo]Z00Cooo]Z00?oocD0ocOo0?l0POl00_oonfX01_l0oiOo
oo]ZoookJ_l0onSooo]ZocKo00gooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00<oookJP03o`3okOoo
nf[ooo]Z00_ooo]Z00?ooaX0oookJ_lM0?l01?oonfX00ooo0;Cooo]ZoonW0008oookJP03o`3o2Ooo
nf[ooo]Z00?ooo]Z00GoO03oocCo0?oonf[o00_oool06003oookJP03ok3o0?l0nooooo]Z00?ooo]Z
00GoCP3ooookJ_oonf[ooo]Zool05003oookJP03ooo70?oonf[ooo]Z00?ooo]Z00?oojP0oookJ_oo
0:L00_oonfX00ooo8@3ooo]ZoookJP05oookJP06o`3oUooonf[ooo]ZoookJ_n>o`3oo`0i0_oonfX0
0ol0ol3ooo]Zool01`0GoookJP03ool0>?oonf[oN@3o00;ooo]Z00?o^?l0oookJ_oo0;`01_oonfX0
0om/0?oooo]ZoookJP07oookJP09ond0oooonf[ooo]Zoigo0?oo0=cooo]ZoeL0ool0003ookL000;o
000000?ooo]Zoi<0oooonfX00_oonfX2ool000;ooo]Z0_l[0?l01?oonf[ogOl0oookJ_oBo`08oook
JP;o^?l00_oonfX3oolL00Kooo]Z0ol0oiH2oookJP?oo`1?<ooonfX3ool0C`Kooo]Z0_l0oiH:oook
JP?ooa`00ooonfX2okSo01;ooo]Z0_oBo`000ooonf[ogOl0omgo0004oookJP;o:`3o1OoonfX00ooo
003ooo]Zonco0002ool0Z@Kooo]Z00?oT`3ooookJ_oonfX01_oonfX00ooo]`3oE`3ooookJP03oook
JP03ool0g?oonf[ooo]Z00Gooo]Z00?oWOl0oookJ_oonfX00_oonfX00oo]0?oooo]ZoookJP0_oook
JP00;?oonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0ool02ooo
nfX01OoonfX00ooo=@3ooo]Zo`21o`02oookJP05o`3oUooonf[o0?oXoookJ_lfo`003OoonfX00ol0
hooooo]ZoookJP02oookJP03ool0k?oonf[ooo]Z00[ooo]Z00?o0?o]oookJ_oonfX02ooonfX00ooo
6P3ooo]Zoad0o`03oookJPWoiOl01?oonfX00ol0o`Wooo]ZoookJP02oookJP05og`0ooldo`3ooo]Z
ool0Col02ol00ooonfX00on`o`3ooo]Zo`3ko`03oookJP04odh0oooonf[ooo]Zool050Cooo]Z00?o
olL0oookJ_oonfX00ooonfX00oooZ03oo`2WoookJP02oookJP03ool0]?oo8@3ooo]Z00Gooo]Z00Go
0?nGoookJ_oonf[ooo]Zohko0004ooo90003o`3o`?oo00Oooo]Z01Oooo]Z1ooUo`000ooo0;coiOl0
oookJP03oookJP03of`0oooonf[ooo]Z00Sooo]Z00Cok@3ooookJ_nMo`3ooo]Z0_oo0=`2oeL0o`04
oong0?l0003ooo]ZoookJP;oT`3o00Cooo]Zooo90?o/o`3oo`000ooonfX01?l[0?oooo]Zooo90?oM
o`02om;o00Oooo]Z0_nho`04oookJP?ooa`01_oonfX4o`3oUP03oookJ_oo04ooo`1?00?oo`1?9_oo
nfX4oiCo00Coo`1?1_oonfX3o`3oUP[ooo]Z0_oo7004oookJP03okSo0?oonf[ooo]Z01;ooo]Z00Co
d_l0oookJ_oonf[ogOl00ooonfX2ob/0o`Kooo]Z00Cooi/0ool00?oonf[ok?l01ooonfX00onC0?oo
oo]ZoookJP06oookJP03oong0?mG0?oooo]Z00Cooo]Z00?oo`3LoookJ_oonfX01?oonfX00onMo`3o
oo]ZoookJP03oookJP03ond0oooonf[ooo]Z05Wooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3o
oo]ZoookJP06oookJP03oooX0?oonf[ooo]Z00Gooo]Z00GoocD0o`21oooonf[ooo]Zo`3oU`02oook
JP03o`3oj?oonf[o=_l000gooo]Z00?o0>?ooookJ_oonfX00_oonfX00ooo0>cooo]ZoookJP09oook
JP03o`3okOoonf[ooo]Z00cooo]Z00?ooaX0oad0ool0oo801?oonfX00ooo0;Cooo]ZoonW0008oook
JP03o`3o2Ooonf[ooo]Z00;ooo]Z00GoO03oocCo0?l0;Ooooo]Zo`0;o`03oookJP03ok3o0?oonf[o
0?_o00?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05003oookJP03ooo70?oonf[ooo]Z00Cooo]Z00Ko
ojP0ool0Yooonf[ooo]Zool0]?oo8@06oookJP03o`3oUooonf[ooo]Z00;ooo]Z00KoS_l0ool0>Ooo
nf[ooo]Zo`3o`?oo00LHoookJP03ool0>?oonf[oN@3o00;ooo]Z00?o^?l0oookJ_oo0;`01_oonfX0
0om/0?oooo]ZoookJP07oookJP;ok@3o00Cooo]Zoigo0?oo0=coo`3L0_mG0?l2oong00;ooo]Z0_nC
0?l2oookJP03onco0?oo003ooo]Z00;ooo]Z00Co:`3ooookJ_oMo`3ogOl00_oBo`08oookJP;o^?l0
0ooonfX3oolL00Kooo]Z1?l0oiH00ooonf[oo`1?ool0C`03ool0Cb[ooo]Z1?oo04l6oookJP?o0?nF
2_oonfX2oolL00Cooo]Z0_nho`0CoookJP04om;o0?oonf[ooo]Zomgo00Cooo]Z0_l[0?l6oookJP04
ool00?oonf[ok?l0ool0Z@Oooo]Z00?oT`3ooookJ_oonfX01_oonfX00ooo]`3oE`3ooookJP03oook
JP03ool0g?oonf[ooo]Z00Gooo]Z00?oWOl0oookJ_oonfX00_oonfX00oo]0?oooo]ZoookJP0`oook
JP00;?oonfX00olY0?oooo]ZoookJP03oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0oookJ_oo
00/01OoonfX00ooo=@3ooo]Zo`21o`02oookJP03o`3oUooonf[o0?oX00;ooo]Z00?o=_l0oookJ_oo
nfX02ooonfX00ol0hooooo]ZoookJP02oookJP03ool0k?oonf[ooo]Z00[ooo]Z00?o0?o]oookJ_oo
nfX02_oonfX01?oo6P3ooo]Zoad0ool0oo83oookJPKoiOl01_oonfX00ol0o`Wooo]ZoookJP03oook
JP04ocCo0?oonf[ooo]Zo`0;o`Cooo]Z00?o/?l0oookJ_l0nol00_oonfX01Om>0?oooo]ZoookJ_oo
nf[oo`0D00?ooo]Z00?oolL0oookJ_oonfX01?oonfX00oooZ03oo`2WoookJP02oookJP03ool0]?oo
8@3ooo]Z00Gooo]Z00Go0?nGoookJ_oonf[ooo]Zohko0003ooo90003o`3o`?oonf[oo`0701Sooo]Z
1ooUo`000ooo0;coiOl0oookJP03oookJP03of`0oooonf[ooo]Z00Sooo]Z00?ok@3ooookJ_nMo`00
0_oonfX00ooo0=co0000oeL0o`02oong00?ooo]Z00GoT`3ooookJ_oonf[ok?l0ool00003oookJP;o
:`3o00?ooo]Zomgo0?oMo`000_oBo`07oookJP?o^?l01?oonfX2oolL00Sooo]Z1?l0oiH2oookJPOo
o`1?7OoonfX3oiCo00?oo`1?00?oU?l0oookJ_oonfX01OoonfX2o`3oUP_ooo]Z0_oo7004oookJP;o
^?l05?oonfX01?oBo`3ooo]Zomgo0?oMo`03oookJP03ob/0oooonf[ooo]Z00Gooo]Z00Cooi/0ool0
0?o/o`3ok?l01ooonfX00onC0?oooo]ZoookJP06oookJP03oong0?mG0?oooo]Z00Cooo]Z00?oo`3L
oookJ_oonfX01?oonfX00onMo`3ooo]ZoookJP03oookJP03ond0oooonf[ooo]Z05[ooo]Z00?o:@3o
oookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP06oookJP03oooX0?oo00_ooo]Z00Gooo]Z00GoocD0
ocOo0?l0POoooo]Zo`3oU`02oookJP03o`3oj?oonf[o=_l000kooo]Z00Go0>?ooookJ_oonf[ooo]Z
ool0k00<oookJP03o`3okOoonf[ooo]Z00_ooo]Z00?ooaX0oad0ool0oo801?oonfX00ooo0;Cooo]Z
oonW0008oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z00CoO03oocCo0?oonf[o00_o1?oonfX00on`o`3o
oo]Zo`3ko`02oookJP03odh0oooonf[ooo]Z00;ooo]Z00Goo`0DoookJ_oonf[ooo]Zooo70005oook
JP03oonX0?oonf[oo`2W00;ooo]Z00?oo`2doolQ0?oonfX01OoonfX01ol0oiOooo]ZoookJ_oonf[o
S_l0oookJ_oo03T00_oonfX00ol0ol3oo`07oookJP0GoookJP03ool0>?oonf[oN@3o00;ooo]Z00?o
^?l0oookJ_oo0;`01_oonfX00om/0?oooo]ZoookJP08oookJP09ond0oooonf[oWOl0oookJ_oo0=co
0000oeL0ool0003ookL000?ooo]Z00GoT`3ooookJ_oonf[ok?l0ool00003oookJP;o:`3o00?ooo]Z
omgo0?oMo`000_oBo`08oookJP?o^?l00ooonfX3oolL00Oooo]Z1?l0oiH2oookJPOoo`1?8?oonfX3
ool0C`Sooo]Z0_l0oiH;oookJP;ooa`01?oonfX2okSo01Cooo]Z00Cod_l0oookJ_oMo`3ogOl00ooo
nfX2ob/0o`Oooo]Z00Coo`00onco0?o/o`3oo`2Y1ooonfX00onC0?oooo]ZoookJP06oookJP03oong
0?mG0?oooo]Z00?ooo]Z00?oo`3LoookJ_oonfX01OoonfX00onMo`3ooo]ZoookJP02oookJP03ond0
oooonf[ooo]Z037ooo]Z000]oookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01_oo
nfX00oooj03oo`0;oookJP04oookJP04oole0?oonf[o=ol0o`21o`;ooo]Z00Go0?nGoookJ_l0onSo
oo]ZocKo000=oookJP03o`3Soooonf[ooo]Z00;ooo]Z00?oo`3/oookJ_oonfX02_oonfX00ol0ongo
oo]ZoookJP0:oookJP04oolJ0?oonf[ooo]Zoad0o`?ooo]Z1?oUo`09oookJP03o`3o2Ooonf[ooo]Z
00;ooo]Z00GoO03oocCo0?oonf[oo`1?o`0;o`03oookJP03ok3o0?oonf[o0?_o00?ooo]Z00GoCP3o
oookJ_oonf[ooo]Zool05003oookJP03ooo70?oonf[ooo]Z00?ooo]Z00?oojP0ool0YooonfX00ooo
nfX00ooo8@3ooo]ZoookJP04oookJP03o`3oUooonf[ooo]Z00;ooo]Z00OoS_l0ooo90?oob@3oolT0
o`3o`?oonf[oo`0701Oooo]Z2?oUo`000ooo0;coiOl0oookJP03oookJP03of`0oooonf[ooo]Z00So
oo]Z00Gok@3ooookJ_nMo`3oWOl0o`000002ool0g0;oE`3o00CookL0oookJ_oonf[ooo]Z0_nC0?l2
oookJP?oU?l00_oonfX2ob/0o`04oookJ_oMo`3ogOl0om;o00Wooo]Z0onho`03oookJP?ooa`02Ooo
nfX4o`3oUPGooo]Z1ooo04l=oookJPcoo`1?1?nDo`03oookJPCoU?l02ooonfX2oolL00Cooo]Z0_nh
o`0EoookJP03om;o0?oMo`3ogOl000?ooo]Z0_l[0?l7oookJP03oonK0?oo003ok?l000Sooo]Z00?o
T`3ooookJ_oonfX01_oonfX00ooo]`3oE`3ooookJP04oookJP03ool0g?oonf[ooo]Z00Gooo]Z00?o
WOl0oookJ_oonfX00_oonfX00oo]0?oooo]ZoookJP1LoookJP03obT0oooonf[ooo]Z00;ooo]Z00?o
0?o`oookJ_oonfX01_oonfX00oooj03ooo]ZoookJP04oookJP03oole0?lgo`3o087o00;ooo]Z00Ko
0?nGoookJ_oonf[o0?oXoookJ_lfo`0=oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`03?oonfX00ol0
ongooo]ZoookJP0;oookJP03oolJ0?oonf[o7@3o00Cooo]Z00Coo`2doookJ_oonf[oojL02?oonfX0
0ol0o`Wooo]ZoookJP02oookJP05og`0ooldo`3o02gooookJ_l02ol00ooonfX00on`o`3ooo]Zo`3k
o`03oookJP05odh0oooonf[ooo]ZoookJ_oo01@01?oonfX00oooa`3ooo]ZoookJP03oookJP03oonX
0?oo0:Oooo]Z00;ooo]Z00?oob40oookJ_oonfX01?oonfX00ol0oiOooo]ZoookJP02oookJP07ohko
0?oo03Wooo]ZoookJ_l0ol3ooo]Zool01`0HoookJP03ool0>?oonf[oN@3o00;ooo]Z00?o^?l0oook
J_oo0;`01_oonfX00om/0?oooo]ZoookJP08oookJP04ond0oooonf[oWOl0oigo00;oo`3L0_mG0?l2
oong00;ooo]Z0_nC0?l2oookJP;oo`000ooonfX2ob/0o`03oookJ_oMo`3ogOl000;od_l02OoonfX3
okSo00?ooo]Z0ooo7008oookJPCo0?nF1OoonfX7ool0C`gooo]Z3?oo04l7oookJPCo0?nF2ooonfX2
oolL00Cooo]Z0_nho`0EoookJP03om;o0?oMo`3ogOl000Cooo]Z00?o:`3ooookJ_oonfX01_oonfX0
0ooo003ok?l0ool0Z@08oookJP03oi<0oooonf[ooo]Z00Gooo]Z0_oo]`000omG0?oooo]ZoookJP02
oookJP03ool0g?oonf[ooo]Z00Kooo]Z00GoWOl0oookJ_oonf[ooo]Zond0o`0doookJP00;OoonfX0
0olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0ool02ooonfX01?oonfX0
1?oo=@3ooo]ZocOo0?l0POl2oookJP05o`3oUooonf[o0?oXoookJ_lfo`003OoonfX00ol0hooooo]Z
oookJP02oookJP03ool0k?oonf[ooo]Z00[ooo]Z00?o0?o]oookJ_oonfX02ooonfX00ooo6P3ooo]Z
oad0o`03oookJP04onGo0?oo0;Cooo]ZonGo00Wooo]Z00?o0?l9oookJ_oonfX00_oonfX01Oml0?oo
=?l0oookJ_oonf[o00_o00Cooo]Z00?o/?l0oookJ_l0nol00_oonfX01Om>0?oooo]ZoookJ_oonf[o
o`0D00Cooo]Z00?oolL0oookJ_oonfX00ooonfX00oooZ03oo`2WoookJP02oookJP03ool0]?oo8@3o
oo]Z00Gooo]Z00Ko0?nGoookJ_oonf[ooo]Zooo90?n>o`02ooo90003o`3o`?oob@3oo`0701Sooo]Z
1ooUo`000ooonf[oo`2lool0_004oookJP03of`0oooonf[ooo]Z00Sooo]Z0_o]0?l02?oonf[oWOl0
o`000?l0003oo`3LoookJ_mG0?oookL01?oonfX01?nC0?oooo]ZoookJ_oo0:T5oiCo00;o:`3o00Co
oo]Zomgo0?oMo`3od_l02_oonfX3okSo00?ooo]Z0ooo700:oookJPCo0?nF2?oonfX=ool0C`Cooo]Z
3onDo`0=oookJP;ooa`01?oonfX2okSo01Gooo]Z0_oBo`001?oMo`3ooo]ZoookJ_oonfX2ob/0o`?o
oo]Z00?oiOl0oookJ_oonfX00_oonfX00oooV`3oo`00onco0007oookJP;oT`3o2?oonfX00ooo]`3o
E`3ooookJP04oookJP03ool0g?oonf[ooo]Z00Gooo]Z00?oWOl0oookJ_oonfX00_oonfX00oo]0?oo
oo]ZoookJP1MoookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01_oonfX00oooj03o
oo]ZoookJP04oookJP03oole0?lgo`3o087o00;ooo]Z00Ko0?nGoookJ_oonf[o0?oXoookJ_lfo`0=
oookJP03o`3Soooonf[ooo]Z00;ooo]Z00?oo`3/oookJ_oonfX02OoonfX00ol0ongooo]ZoookJP0<
oookJP03oolJ0?lM0?oo0?ob00Cooo]Z00?oo`2doookJ_ooY`002?oonfX00ol0o`Wooo]ZoookJP02
oookJP05og`0oooonf[o=?l0oookJ_l02ol01?oonfX00on`o`3ooo]Zo`3ko`02oookJP03odh0oooo
nf[ooo]Z00;ooo]Z00Goo`0DoookJ_oonf[ooo]Zooo70005oookJP03oonX0?oonf[oo`2W00;ooo]Z
00?oo`2doolQ0?oonfX01OoonfX00ol0oiOooo]ZoookJP02oookJP07ohko0?oo03Wooo]ZoookJ_l0
ol3ooo]Zool01`0HoookJP05ool0>?oonf[oN@3ooookJ_nho`000_oonfX2ool0_0Gooo]Z00?oK03o
oookJ_oonfX02?oonfX02_o]0?oooo]Zo`000?nMo`3o0000ool0g?oonf[oE`3ooookJ_oo]`03oook
JP04oi<0oooonf[ooo]ZoookJP;oo`000ooonfX2ob/0o`03oookJ_oMo`3ogOl000;od_l02_oonfX3
okSo00?ooo]Z0ooo7009oookJPCo0?nF2?oonfX=ool0C`cooo]Z1ol0oiH=oookJP;ooa`01?oonfX2
okSo01Gooo]Z0_oBo`000ooMo`3ooo]ZoookJP02oookJP;o:`3o2?oonfX00ooo003ok?l0oookJP07
oookJP;oT`3o1ooonfX00ooo]`3ooo]ZoeL0o`04oookJP03ool0g?oonf[ooo]Z00Kooo]Z00GoWOl0
oookJ_oonf[ooo]Zond0o`0eoookJP00;OoonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[o
oo]Z00Kooo]Z00?oonP0oookJ_oo00/01OoonfX00ooo=@3ooo]Zo`21o`02oookJP03o`3oUooonf[o
0?oX00;ooo]Z00?o=_l0oookJ_oonfX02ooonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00gooo]Z00?o
0?o]oookJ_oonfX02_oonfX01?oo6P3ooo]ZoookJ_lM0?l3oookJP04ool0]?oonf[ooo]ZonGo00So
oo]Z00?o0?l9oookJ_oonfX00ooonfX01Oml0?oo=?l0oookJ_oo04oo00_o00?ooo]Z00?o/?l0oook
J_l0nol00ooonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00?ooo]Z00?oolL0oookJ_oonfX00ooonfX0
0oooZ03ooo]Zool0Y`03oookJP03oolQ0?oonf[ooo]Z00Cooo]Z00Ko0?nGoookJ_oonf[ooo]Zooo9
0?n>o`03ooo90003o`3o`?oob@3oo`0701Oooo]Z1_oUo`001Onho`3ooo]ZoookJ_oonf[oo`2l00Co
oo]Z00?oK03ooookJ_oonfX02OoonfX00oo]0?oo0000oigo0002o`000005ool0g?oonf[oE`3ooeL0
oooo]`000ooonfX01?nC0?oooo]ZoookJ_oonfX7oiCo0005ob/0oooonf[ogOl0omgo0?oBo`002ooo
nfX3okSo00?ooo]Z1?oo700:oookJPgo0?nF2_oonfX?oiCo00_ooo]Z1?oo7004oookJP;o^?l05Ooo
nfX2om;o00;ogOl00_oonfX2ob/0o`Gooo]Z00?oiOl0oookJ_oonfX00_ooV`000ooo003ok?l0oook
JP06oookJP03oi<0oooonf[ooo]Z00Oooo]Z00?ookL0oeL0oooonfX01?oonfX00ooo0=cooo]Zoook
JP05oookJP03oigo0?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX0GOoonfX00olY0?oooo]Zoook
JP02oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0ool02ooonfX01OoonfX01Ooo=@3o=ol0o`21
oooonf[o0?nG00;ooo]Z00?o0?oXoookJ_lfo`003_oonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00co
oo]Z00?o0?o]oookJ_oonfX02ooonfX00ooo6P3ooo]Zoad0o`04oookJP03ool0]?oonf[oojL000So
oo]Z00?o0?l9oookJ_oonfX00ooonfX01Oml0?oo=?l0o`0]oooo01So00_o00?ooo]Z00?o/?l0oook
J_l0nol00ooonfX00om>0?oooo]ZoookJP02oookJP05ool05?oonf[ooo]ZoookJ_ooa`001OoonfX0
0oooZ03ooo]Zool0Y`02oookJP03oolQ0?oonf[ooo]Z00Gooo]Z00Oo0?nGoookJ_oonf[ooo]Zohko
0?oonf[oo`0i00;ooo]Z00?o0?o0ool01ooonfX06?oonfX01Ooo03Sooo]ZogT0oooonf[o^?l000?o
oo]Z00?oo`2loookJ_oonfX00ooonfX00om/0?oooo]ZoookJP08oookJP07ond0ool0003o0000oigo
0?l0003oo`3LoookJP02oeL0o`05oong0?oonf[ooo]ZoookJ_nC0?l00ooonfX00oo/o`3oo`00ool0
0003oookJP;o:`3o00?ooo]Zomgo0?oMo`000_oBo`0;oookJP?o^?l00ooonfX4oolL00Wooo]Z3Ol0
oiH=oookJPOo0?nF4?oonfX4oolL00Cooo]Z0_nho`0EoookJP;od_l00_oMo`03oookJP;o:`3o2?oo
nfX00oooV`3oo`00onco0007oookJP;oT`3o2?oonfX00ooo]`3ooo]ZoeL0o`04oookJP03ool0g?oo
nf[ooo]Z00Kooo]Z00?oWOl0oookJ_oonfX00_oonfX00oo]0?oooo]ZoookJP0coookJP00;_oonfX0
1OlY0?oooo]ZoookJ_oonf[o0?o`00Wooo]Z00?oonP0ool02ooonfX01?oonfX00ooo=@3ooo]Zo`21
o`03oookJP05o`3oUooonf[o0?oXoookJ_lfo`003OoonfX00ol0hooooo]ZoookJP02oookJP03ool0
k?oonf[ooo]Z00[ooo]Z00?o0?o]oookJ_oonfX02_oonfX01?oo6P3ooo]ZoookJ_lM0?l4oookJP03
ool0]?oonf[oiOl000Wooo]Z00?o0?l9oookJ_oonfX00_oonfX01Oml0?oo=?l0oookJ_oo04oo00_o
00Cooo]Z00?o/?l0oookJ_l0nol00ooonfX01?m>0?oooo]ZoookJ_oo01@4oookJP03ooo70?oonf[o
oo]Z00?ooo]Z00?oojP0ool0YooonfX00ooonfX00ooo8@3ooo]ZoookJP04oookJP06o`3oUooonf[o
oo]ZoookJ_oob@3oS_l00ooob@000ol0ol3oolT0ool01`0GoookJPCoiOl00_oonfX01Onho`3ooo]Z
oookJ_oonf[oo`2l00Cooo]Z00?oK03ooookJ_oonfX02OoonfX00oo]0?oo0000oigo0002o`0000;o
o`3L00?ooo]ZoeL0oooo]`000ooonfX2oi<0o`;ooo]Z2_nDo`02omgo00;od_l02ooonfX3okSo00Co
oo]Z1Ooo700BoookJPWo0?nF4?nDo`06oookJPGooa`01OoonfX3okSo01Cooo]Z0ooBo`02omgo00;o
oo]Z0_l[0?l6oookJP;oiOl00_ooV`02ool00003onco0?oonf[ooo]Z00Cooo]Z0_nC0?l9oookJP03
oong0?mG0?oooo]Z00Cooo]Z00?oo`3LoookJ_oonfX01OoonfX00onMo`3ooo]ZoookJP03oookJP03
ond0oooonf[ooo]Z05oooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol009oookJP03oooX0?oonf[ooo]Z
00Cooo]Z00?oocD0ocOo0?l0POl00_oonfX01Ol0oiOooo]ZoookJ_l0onSo=_l000kooo]Z00Go0>?o
oookJ_oonf[ooo]Zool0k00<oookJP03o`3okOoonf[ooo]Z00_ooo]Z00CooaX0oookJ_lM0?oo0?ob
0ooonfX01?oo0;Cooo]ZoookJ_ooY`08oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z00GoO03ooookJ_ld
o`3ooo]Zo`0;o`04oookJP03ok3o0?oonf[o0?_o00?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05003
oookJP03ooo70?oonf[ooo]Z00?ooo]Z00?oojP0oookJ_oo0:L00ooonfX00ooo8@3ooo]ZoookJP04
oookJP03o`3oUooonf[ooo]Z00;ooo]Z00OoS_l0ool0>Ooonf[ooo]Zo`3o`?oonf[oo`0701Wooo]Z
00Goo`0hogT0oooonf[ooo]ZokSo0003oookJP03ool0_?oonf[ooo]Z00?ooo]Z00?oK03ooookJ_oo
nfX02?oonfX01Oo]0?oo0000o`000?nMo`3o000000;oo`3L00Cooo]ZoeL0oooo]`3ookL00_oonfX2
oi<0o`?ooo]Z00?ok?l0ool00?ooV`000ooonfX2ob/0o`03oookJ_oMo`3ogOl000?od_l02ooonfX3
okSo00Cooo]Z1Ooo700AoookJPgo0?nF4_oonfX5oolL00Gooo]Z0onho`0DoookJP?od_l00_oMo`03
oookJP;o:`3o2?oonfX01?ooV`3oo`00ool00?o/o`07oookJP03oi<0oooonf[ooo]Z00Oooo]Z00?o
okL0oookJ_mG0?l01?oonfX00ooo0=cooo]ZoookJP06oookJP03oigo0?oonf[ooo]Z00;ooo]Z00?o
k@3ooookJ_oonfX0=?oonfX002kooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol009oookJP03oooX0?oo
00_ooo]Z00Cooo]Z00CoocD0oookJ_lgo`3o087o0_oonfX01Ol0oiOooo]Zo`3oj?oonf[o=_l000go
oo]Z00?o0>?ooookJ_oonfX00_oonfX00ooo0>cooo]ZoookJP0;oookJP03o`3okOoonf[ooo]Z00[o
oo]Z00CooaX0oookJ_lM0?oo0?ob0ooonfX01?oo0;Cooo]ZoookJ_oUo`08oookJP03o`3o2Ooonf[o
oo]Z00?ooo]Z00Co=?l0oookJ_oonf[o00_o1?oonfX00on`o`3ooo]Zo`3ko`03oookJP05odh0oooo
nf[ooo]ZoookJ_oo01@00ooonfX00oooa`3ooo]ZoookJP03oookJP03oonX0?oonf[oo`2W00?ooo]Z
00?oob40oookJ_oonfX01OoonfX00ol0oiOooo]ZoookJP02ooo90004ohko0?oob@3oolT0o`3o`0;o
olT000?oo`07oookJ_oonfX05?oonfX3onGo0005ool0>?oUo`3ooo]ZoookJ_nho`000ooonfX00ooo
0;cooo]ZoookJP02oookJP03of`0oooonf[ooo]Z00Sooo]Z00Co0000ond0ool0003oWOl00ooonfX0
1?oo0=cooo]ZoeL0oomG0?l4oookJP03oi<0oooonf[ooo]Z00_oU?l00_oMo`02om;o00cooo]Z0onh
o`06oookJPGooa`07ooonfX7oiCo00Kooa`01OoonfX5okSo01Gooo]Z0_oBo`02oookJP05omgo0?oo
nf[ooo]ZoookJ_l[0?l01ooonfX00ooUo`3ooi/0oonK0002ool00003oookJ_o/o`3ooo]Z00Cooo]Z
0_nC0?l9oookJP03oong0?mG0?ooE`3o00Gooo]Z00?oo`3LoookJ_oonfX01?oonfX2oigo00Gooo]Z
00?ok@3ooookJ_oonfX0H?oonfX01OlY0?oooo]ZoookJ_oonf[o0?o`00Wooo]Z00?oonP0oookJ_oo
nfX01?oonfX00ooo=@3o=ol0o`21o`02oookJP06o`3oUooonf[ooo]Zo`3oj?oonf[o=_l03OoonfX0
0ol0hooooo]ZoookJP02oookJP03ool0k?oonf[ooo]Z00[ooo]Z00?o0?o]oookJ_oonfX02ooonfX0
0ooo6P3o7@3oo`3olP04oookJP03ool0]?oonf[oojL000Sooo]Z00?o0?l9oookJ_oonfX00ooonfX0
1?ml0?oo=?l0oookJ_l02ol4oookJP03ok3o0?oonf[o0?_o00?ooo]Z00?oCP3ooookJ_oonfX00_oo
nfX01Ooo01Cooo]ZoookJ_oonf[oolL000Gooo]Z00?oojP0oookJ_oo0:L00_oonfX00ooo8@3ooo]Z
oookJP05oookJP03o`3oUooonf[ooo]Z00;ooo]Z00OoS_l0ool0>Ooonf[ooo]Zo`3o`?oonf[oo`07
01Wooo]Z00Goo`0hogT0oooonf[ooo]ZokSo0003oookJP03ool0_?oonf[ooo]Z00?ooo]Z00?oK03o
oookJ_oonfX01ooonfX01Ol0003ok@3oo`000?l0003oWOl000;ooo]Z00Goo`3LoookJ_mG0?ooE`3o
oong0003oookJP05oi<0oooonf[ooo]ZoookJ_oo0:T00_oo00001?ooV`3ooo]ZoookJ_oonfX2ob/0
o`04oookJ_oMo`3ogOl0oookJP;od_l03?oonfX3okSo00Kooo]Z1Ooo700UoookJPKooa`01OoonfX5
okSo01Gooo]Z0_oBo`02oookJP04omgo0?oonf[ooo]ZoookJP;o:`3o2?oonfX01OooV`3oo`00ool0
0?oo0:Wok?l000Kooo]Z0_nC0?l9oookJP03oong0?mG0?ooE`3o00Cooo]Z00?oo`3LoookJ_oonfX0
1OoonfX2oigo00Cooo]Z00?ok@3ooookJ_oonfX0=OoonfX002kooo]Z00?o:@3ooookJ_oonfX00_oo
nfX00ol0oo3ooo]ZoookJP06oookJP03oooX0?oonf[oo`0;00Gooo]Z00?oocD0oookJ_l0POl00_oo
nfX01Ol0oiOooo]Zo`3oj?oonf[o=_l000kooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00=oookJP03
o`3okOoonf[ooo]Z00[ooo]Z00CooaX0oookJ_oonf[o7@3o0ooonfX01?oo0;Cooo]ZoookJ_oUo`09
oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z00GoO03oocCo0?oonf[oo`1?o`0;o`04oookJP03ok3o0?oo
nf[o0?_o00?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05003oookJP03ooo70?oonf[ooo]Z00?ooo]Z
00?oojP0oookJ_oo0:L00ooonfX00ooo8@3ooo]ZoookJP04oookJP03o`3oUooonf[ooo]Z00;oolT0
00OoS_l0ooo90?oob@3oolT0o`3o`?oob@3oo`0701Oooo]Z00GoiOl0oookJ_oonf[oo`0honGo0002
oookJP05okSo0?oonf[ooo]ZoookJ_oo0;`01?oonfX00om/0?oooo]ZoookJP07oookJP;o000000Co
k@3oo`000?nMo`3oWOl00_oonfX2ool0g003oookJ_mG0?ooE`3o00?ooo]Z0_nC0?l00ooonf[oU?l0
oiCo0008oiCo0004ob/0oooonf[ogOl0omgo00;od_l03OoonfX4okSo00Oooo]Z1Ooo700LoookJPGo
oa`01_oonfX5okSo01Sooo]Z0_oBo`02oookJP;ogOl00_oonfX2ob/0o`Oooo]Z00GoiOl0oonK0?oo
003oo`00onGo0002onco00Gooo]Z00?oT`3ooookJ_oonfX02?oonfX00ooo]`3oE`3ooookJP05oook
JP03ool0g?oonf[ooo]Z00Cooo]Z00?oWOl0oookJ_oonfX01?oonfX00oo]0?oooo]ZoookJP1Qoook
JP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01_oonfX00oooj03oo`0;oookJP05oook
JP05oole0?lgo`3o087ooookJ_l0oiL00_oonfX00ol0onSooo]ZocKo000>oookJP05o`3Soooonf[o
oo]ZoookJ_oo0>`03?oonfX00ol0ongooo]ZoookJP0;oookJP04oolJ0?oonf[o7@3oo`3olP?ooo]Z
00Coo`2doookJ_oonf[oojL02?oonfX00ol0o`Wooo]ZoookJP02oookJP05og`0ooldo`3o02gooook
J_l02ol01?oonfX00on`o`3ooo]Zo`3ko`03oookJP05odh0oooonf[ooo]ZoookJ_oo01@00ooonfX0
0oooa`3ooo]ZoookJP03oookJP03oonX0?oonf[oo`2W00?ooo]Z00?oob40oookJ_oonfX01?oonfX0
0ol0oiOooo]ZoookJP03oookJP07ohko0?oo03Wooo]ZoookJ_l0ol3ooo]Zool01`0IoookJP05ool0
>?mi0?oooo]ZoookJ_nho`000ooonfX00ooo0;cooo]ZoookJP03oookJP03of`0oooonf[ooo]Z00Ko
oo]Z0_l000000oo]0?oo0000oookJP02oigo0004oookJ_oo0=coo`3LoookJP;oE`3o0ooonfX2oi<0
o`;ooo]Z00Goo`2Yonco0?oo003oo`00oonK0003oookJP;o:`3o00Cooo]Zomgo0?oMo`3ooo]Z0_oB
o`0=oookJPCo^?l01ooonfX5oolL01_ooo]Z1Ooo7007oookJPCo^?l06?oonfX2om;o00;ooo]Z0_oM
o`02oookJP;o:`3o2?oonfX01?ooV`3oo`00ool00?oo0:T2onco00Gooo]Z0_nC0?l:oookJP03oong
0?mG0?oooo]Z00Cooo]Z00?oo`3LoookJ_oonfX01OoonfX00onMo`3ooo]ZoookJP03oookJP03ond0
oooonf[ooo]Z03Kooo]Z000_oookJP05obT0oooonf[ooo]ZoookJ_l0oo002OoonfX00oooj03oo`0;
oookJP04oookJP03oole0?oonf[o087o00?ooo]Z00Go0?nGoookJ_l0onSooo]ZocKo000=oookJP03
o`3Soooonf[ooo]Z00;ooo]Z00?oo`3/oookJ_oonfX02_oonfX00ol0ongooo]ZoookJP0;oookJP03
oolJ0?oonf[o7@3o00Cooo]Z00Coo`2doookJ_oonf[oiOl02?oonfX00ol0o`Wooo]ZoookJP02oook
JP06og`0ooldo`3ooo]ZoookJ_l02oooo`0H0ooonfX00on`o`3ooo]Zo`3ko`03oookJP05odh0oooo
nf[ooo]ZoookJ_oo01@00ooonfX00oooa`3ooo]ZoookJP04oookJP03oonX0?oo0:Oooo]Z00?ooo]Z
00?oob40oookJ_oonfX01?oonfX2ooo90004oookJ_oob@3oolT0ohko00?oolT000?o0?o0oookJ_oo
00L06_oonfX01Ooo03SoiOl0oookJ_oonf[o^?l000?ooo]Z00?oo`2loookJ_oonfX00_oonfX00om/
0?oooo]ZoookJP06oookJP?o00000_o]0?l00ooonf[oWOl0oookJP02oookJP04ool0g?oonf[ookL0
oeL0o`Cooo]Z00?oT`3ooookJ_nDo`001onDo`02oookJP;o:`3o00?ooo]Zomgo0?oMo`000ooBo`0>
oookJPGo^?l01ooonfXLoolL00Oooo]Z1?nho`0JoookJP?od_l00_oonfX2omgo00;ooo]Z0_l[0?l8
oookJP04oonK0?oo003oo`00onGo00;ok?l00_oUo`03oookJP;oT`3o2_oonfX2oeL0o`Kooo]Z00?o
o`3LoookJ_oonfX01?oonfX00onMo`3ooo]ZoookJP04oookJP03ond0oooonf[ooo]Z06?ooo]Z00Go
:@3ooookJ_oonf[ooo]Zo`3ol009oookJP03oooX0?oonf[ooo]Z00Cooo]Z00?oocD0ocOo0?l0POl0
0_oonfX01Ol0oiOooo]ZoookJ_l0onSo=_l000kooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00<oook
JP03o`3okOoonf[ooo]Z00cooo]Z00?ooaX0oad0ool0oo801?oonfX00ooo0;Cooo]ZoonW0008oook
JP03o`3o2Ooonf[ooo]Z00;ooo]Z00KoO03ooookJ_ldo`3ooo]Zo`0;oooo01P3oookJP03ok3o0?oo
nf[o0?_o00?ooo]Z00?oCP3ooookJ_oonfX00_oonfX01Ooo01Cooo]ZoookJ_oonf[oolL000Gooo]Z
00?oojP0oookJ_oo0:L00ooonfX00ooo8@3ooo]ZoookJP04oookJP03o`3oUooonf[ooo]Z00;ooo]Z
00?oS_l0oookJ_oo03T00_oonfX00ol0ol3ooo]Zool01`0IoookJP05ool0>?mi0?oooo]ZoookJ_nh
o`000ooonfX00ooo0;cooo]ZoookJP03oookJP03of`0oooonf[ooo]Z00Gooo]Z0ol00002ond0o`;o
oo]Z00CoWOl0oookJ_oonf[oo`3L0_oonfX00omG0?oookL0oookJP02oookJP06oi<0oooonf[ooo]Z
oookJ_oo0:Wok?l00_oo0004oookJP;o:`3o00Cooo]Zomgo0?oMo`3ooo]Z0ooBo`0>oookJPGo^?l0
1ooonfXKoolL00Sooo]Z1?nho`0IoookJP?od_l00_oonfX2omgo00;ooo]Z0_l[0?l8oookJP04oonK
0?oo003oo`00ool0Z@;ok?l01_oonfX00onC0?oooo]ZoookJP09oookJP;oE`3o1OoonfX00ooo0=co
oo]ZoookJP05oookJP03oigo0?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX0=ooonfX002oooo]Z
00Go:@3ooookJ_oonf[ooo]Zo`3ol009oookJP03oooX0?oo00_ooo]Z00Cooo]Z00CoocD0oookJ_lg
o`3o087o0_oonfX01Ol0oiOooo]Zo`3oj?oonf[o=_l000kooo]Z00Go0>?ooookJ_oonf[ooo]Zool0
k00=oookJP03o`3okOoonf[ooo]Z00[ooo]Z00CooaX0oookJ_oonf[o7@3o0ooonfX01?oo0;Cooo]Z
oookJ_oUo`09oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z00GoiOl0ocCo0?oonf[oo`1?o`0;o`03oook
JP04ok3o0?oonf[ooo]Zo`3ko`?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05003oookJP03ooo70?oo
nf[ooo]Z00?ooo]Z00?oojP0oookJ_oo0:L00ooonfX00ooo8@3ooo]ZoookJP04oookJPKoolT000Co
S_l0ooo90?oonf[o0?o00_oonfX00ooo00Oooo]ZoookJP0HoookJP04ool0>?oUo`3ooo]ZoookJP;o
^?l00_oonfX00ooo0;cooo]ZoookJP02oookJP;oK03o1_oonfX4o`000003oookJ_o]0?oooo]Z00;o
WOl00_oonfX2ool0g003oookJ_mG0?ooE`3o00?ooo]Z2OnDo`04oookJP;o:`3o00Cooo]Zomgo0?oM
o`3ooo]Z0_oBo`0AoookJPKo^?l07ooonfX5okSo01cooo]Z0_oBo`04oookJP03omgo0?oonf[ooo]Z
00;o:`3o2?oonfX01?ooV`3oo`00ool00?oUo`02onco00GoiOl000?ooo]Zoi<0oooonfX02_oonfX0
0omG0?oooo]ZoookJP05oookJP03ool0g?oonf[ooo]Z00?ooo]Z0_nMo`06oookJP03ond0oooonf[o
oo]Z06Cooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol009oookJP03oooX0?oonf[ooo]Z00Cooo]Z00?o
ocD0ocOo0?l0POl00_oonfX01_l0oiOooo]ZoookJ_l0onSooo]ZocKo00kooo]Z00Go0>?ooookJ_oo
nf[ooo]Zool0k00<oookJP03o`3okOoonf[ooo]Z00_ooo]Z00?ooaX0oookJ_lM0?l01?oonfX00ooo
0;Cooo]ZoonW0009oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z00GoO03oocCo0?l0;Ooooo]Zo`0;o`03
oookJP04ok3o0?oonf[ooo]Zo`3ko`?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05003oookJP03ooo7
0?oonf[ooo]Z00?ooo]Z00CoojP0oookJ_oonf[oo`2W0_oonfX00ooo8@3oo`2doookJP04oookJP03
o`3oUooonf[ooo]Z00?ooo]Z00OoS_l0ool0>Ooonf[ooo]Zo`3o`?oonf[oo`0701[ooo]Z00Coo`0h
ogT0oooonf[ooo]Z0_nho`02oookJP;oo`2l1?oonfX2of`0o`Gooo]Z1?l000001?oonf[ok@3ooook
J_oonfX2oigo0004oookJ_oo0=coo`3LoookJP;oE`3o00?ookL0oookJ_oonfX00_nC0?l4oookJP03
onco0?oo003oo`0000Cooo]Z0_l[0?l00ooonf[ogOl0omgo0002oookJP;od_l04OoonfX5okSo023o
oo]Z1Onho`0KoookJP;od_l01?oonfX01OoMo`3ooo]ZoookJ_oonf[o:`3o00Sooo]Z00Cooi/0ool0
0?oo003oo`2Y0_o/o`06oookJP;oT`3o2_oonfX2oeL0o`Kooo]Z00?oo`3LoookJ_oonfX01?oonfX2
oigo00Gooo]Z00?ok@3ooookJ_oonfX0>?oonfX002oooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol009
oookJP03oooX0?oonf[oo`0;00Gooo]Z00?oocD0oookJ_l0POl00_oonfX01Ol0oiOooo]Zo`3oj?oo
nf[o=_l000kooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00=oookJP03o`3okOoonf[ooo]Z00_ooo]Z
00?ooaX0oookJ_lM0?l01?oonfX00ooo0;Cooo]ZonGo0009oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z
00KoiOl0ocCo0?oonf[ooo]Zo`0;oooo01P3oookJP04ok3o0?oonf[ooo]Zo`3ko`?ooo]Z00CoCP3o
oookJ_oonf[oo`0D0ooonfX00oooa`3ooo]ZoookJP04oookJP03oonX0?oonf[oo`2W00?ooo]Z00?o
ob40oookJ_oonfX01?oonfX5ooo90007ohko0?oonf[oolT0oookJ_l0ol3ooo]Zool01`0KoookJP03
ool0>?oUo`3ooo]Z00;ooo]Z00Co^?l0oookJ_oonf[oo`2l1OoonfX00om/0?oooo]ZoookJP03oook
JPCo00000_oonfX2ond0o`03oookJ_nMo`3oWOl000;ooo]Z00Goo`3LoookJ_oonf[oE`3ooong0003
oookJPSoU?l01OoonfX2ob/0o`04oookJ_oMo`3ogOl0omgo00;od_l05OoonfX5okSo00gooo]Z3Onh
o`0OoookJP;od_l01?oonfX2omgo00;ooo]Z00?o:`3ooookJ_oonfX01_oonfX01?ooV`3oo`00ool0
0?oUo`02onco00GoiOl000?ooo]Zoi<0oonC0?l02_oonfX2oeL0o`Kooo]Z0_oo0=`5oookJP03oigo
0?oonf[ooo]Z00Cooo]Z0_o]0?lIoookJP;oK03oC?oonfX01OlY0?oooo]ZoookJ_oonf[o0?o`00Wo
oo]Z00?oonP0ool02ooonfX01OoonfX00ooo=@3o087ooookJP02oookJP05o`3oUooonf[o0?oXoook
J_lfo`003_oonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00cooo]Z00?o0?o]oookJ_oonfX03?oonfX0
0ooo6P3o7@3oo`3olP04oookJP03ool0]?oonf[oojL000Sooo]Z00?o0?l9oookJ_oonfX00_oonfX0
1_ml0?oooo]ZocCo0?oonf[o00_oool060?ooo]Z00Co/?l0oookJ_oonf[o0?_o0ooonfX01Om>0?oo
oo]ZoookJ_oonf[oo`0D00?ooo]Z00?oolL0oookJ_oonfX00ooonfX00oooZ03ooo]Zool0Y`03oook
JP03oolQ0?oonf[ooo]Z00Cooo]Z00?o0?nGoookJ_oonfX00ooonfX01on>o`3oo`0ioookJ_oonf[o
0?o0oookJ_oo00L06_oonfX00ooo03SoN@3ooookJP02oookJP05okSo0?oonf[ooo]ZoookJ_oo0;`0
1OoonfX00om/0?oooo]ZoookJP02oookJPCo00000_oonfX2ond0o`;ooo]Z00CoWOl0oookJ_oonf[o
o`3L0_oonfX00omG0?oookL0oookJP02oookJP;oT`3o0ooonfX2onco0003ool00?ooV`3ooo]Z00?o
oo]Z0_l[0?l01Ooonf[ogOl0omgo0?oMo`3ooo]Z00;od_l05?oonfX5okSo00kooo]Z3Onho`0Noook
JP;od_l01?oonfX2omgo00;ooo]Z0_l[0?l7oookJP04oonK0?oo003oo`00oookJP;ok?l01_oonfX2
oi<0o`_ooo]Z00?oE`3ooong0?oonfX01?oonfX2ool0g0Kooo]Z00?oWOl0oookJ_oonfX00ooonfX2
ond0oa[ooo]Z0_m/0?lOoookJP00;ooonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z
00Kooo]Z00?oonP0oookJ_oo00/01OoonfX00ooo=@3ooo]Zo`21o`03oookJP05o`3oUol0onSooo]Z
oookJ_lfo`003_oonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00gooo]Z00?o0?o]oookJ_oonfX02_oo
nfX01?oo6P3ooo]Zoad0ool0oo83oookJP04ool0]?oonf[ooo]ZonGo00Sooo]Z00?o0?l9oookJ_oo
nfX00_oonfX2onGo0004ocCo0?oonf[oo`1?o`0;o`?ooo]Z00Co/?l0oookJ_oonf[o0?_o0ooonfX0
1Om>0?oooo]ZoookJ_oonf[oo`0D00?ooo]Z00?oolL0oookJ_oonfX00ooonfX00oooZ03ooo]Zool0
Y`03oookJP03oolQ0?oo0;Cooo]Z00Cooo]Z1?oob@02oookJP07ohko0?oonf[oolT0oookJ_l0ol3o
oo]Zool01`0KoookJP03ool0>?oUo`3ooo]Z00;ooo]Z00Co^?l0oookJ_oonf[oo`2l1OoonfX00om/
0?oooo]ZoookJP02oookJPCo00001?oonfX01?o]0?oooo]ZoookJ_nMo`02oookJP03ool0g?oonf[o
oo]Z00;oE`3o0ooonfX;oiCo00?ooo]Z1?nDo`03omgo00;oU?l05ooonfX=okSo02Wooo]Z0ooBo`03
oookJP?ogOl00_oonfX2ob/0o`Oooo]Z00Cooi/0ool00?oo003oiOl00_o/o`04onGo00;ooo]Z0_nC
0?l:oookJP;oE`3o00?ookL0oookJ_oonfX00ooonfX2ool0g0Gooo]Z0_nMo`06oookJP03ond0oooo
nf[ooo]Z01Sooo]Z00?oK03ooookJ_oonfX0C?oonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oo
nf[ooo]Z00Kooo]Z00?oonP0ool02ooonfX01OoonfX00ooo=@3o=ol0o`21o`02oookJP05o`3oUooo
nf[o0?oXoookJ_lfo`003_oonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00gooo]Z00?o0?o]oookJ_oo
nfX02ooonfX00ooo6P3o7@3oo`3olP04oookJP03ool0]?oonf[oojL000Sooo]Z00?o0?l9oookJ_oo
nfX00ooonfX01Oml0?oo=?l0o`0]oooonf[o00_o00?ooo]Z00Co/?l0oookJ_oonf[o0?_o0ooonfX0
0om>0?oooo]ZoookJP02oookJP04ool05?oonf[ooo]Zooo700Kooo]Z00?oojP0oookJ_oo0:L00_oo
nfX00ooo8@3oo`2doookJP05oookJP03o`3oUooonf[ooo]Z00?ooo]Z00OoS_l0ool0>Ooonf[ooo]Z
o`3o`?oonf[oo`0701[ooo]Z00?oo`0hogT0oooonfX00_oonfX01Onho`3ooo]ZoookJ_oonf[oo`2l
00Gooo]Z00CoK03ooookJ_oonf[ooo]Z1?l00004oookJP;ok@3o00Gooo]Zoigo0?nMo`3ooo]Zool0
g002oookJP;oE`3o00CookL0oookJ_oonf[ooo]Z0onC0?l2oookJP04onco0?oo003oo`00oonK00Co
oo]Z0ol[0?l01?oonf[ogOl0omgo0?oMo`03om;o01Kooo]Z3_nho`0XoookJP?od_l00ooonfX3omgo
00;ooo]Z0_l[0?l8oookJP;oo`0000?ooo]Zonco0?o/o`001ooonfX00onC0?oooo]ZoookJP09oook
JP;oE`3o00?ookL0oookJ_oonfX00ooonfX00ooo0=cooo]ZoookJP04oookJP;oWOl01OoonfX00oo]
0?oooo]ZoookJP0IoookJP03of`0oooonf[ooo]Z01oooo]Z000`oookJP05obT0oooonf[ooo]Zoook
J_l0oo002OoonfX00oooj03oo`0;oookJP04oookJP04oole0?oonf[o=ol0o`21o`;ooo]Z00Go0?nG
oookJ_l0onSooo]ZocKo000>oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`03OoonfX00ol0ongooo]Z
oookJP0;oookJP03oolJ0?oonf[o7@3o00Cooo]Z00?oo`2doookJ_oUo`002OoonfX00ol0o`Wooo]Z
oookJP02oookJP06onGo0?ldo`3ooo]ZoookJ_l02oooo`0H0ooonfX01?n`o`3ooo]ZoookJ_l0nol3
oookJP05odh0oooonf[ooo]ZoookJ_oo01@00_oonfX00oooa`3ooo]ZoookJP04oookJP03oonX0?oo
nf[oo`2W00?ooo]Z00?oob40oookJ_oonfX00ooonfX5ooo900;ooo]Z00CoS_l0oookJ_oob@3o0?o0
0_oonfX00ooo00Oooo]ZoookJP0?oookJPGo001o1?oonfX00ol007ooo`0honGo0003oookJP03okSo
0?l007oo001o00;oo`2l1?oonfX2of`0o`;ooo]Z1?l00005oookJP;ok@3o00Cooo]Zoigo0?nMo`3o
oo]Z0_oo0=`2oookJP04oeL0oooo]`3ooo]ZoookJPcoU?l00ooonfX5oiCo00?ogOl01_nDo`0goook
JP;oiOl02ooonfX2om;o00?ooo]Z0ooMo`02oookJP?o:`3o1ooonfX01?ooV`3oo`00ool00?oonfX2
onco00?oiOl01?oonfX00onC0?oooo]ZoookJP09oookJP03oeL0oooonf[ookL000Gooo]Z00?oo`3L
oookJ_oonfX01?oonfX00onMo`3ooo]ZoookJP04oookJP;ok@3o6_oonfX00om/0?oooo]ZoookJP1>
oookJP05obT0oooonf[ooo]ZoookJ_l0oo002OoonfX00oooj03ooo]ZoookJP04oookJP03oole0?lg
o`3o087o00;ooo]Z00Ko0?nGoookJ_oonf[o0?oXoookJ_lfo`0>oookJP05o`3Soooonf[ooo]Zoook
J_oo0>`03?oonfX00ol0ongooo]ZoookJP0<oookJP03oolJ0?lM0?oo0?ob00Cooo]Z00?oo`2doook
J_ooY`002?oonfX00ol0o`Wooo]ZoookJP02oookJP06og`0oooonf[o=?l0oookJ_l02oooo`0H0ooo
nfX01?n`o`3ooo]ZoookJ_l0nol3oookJP05odh0oooonf[ooo]ZoookJ_oo01@00ooonfX00oooa`3o
oo]ZoookJP03oookJP04oonX0?oonf[ooo]Zool0Y`;ooo]Z00?oob40ool0]?oonfX01OoonfX00ol0
oiOooo]ZoookJP02oookJP05ohko0?oonf[oo`0ioookJ_l0ol000_oonfX00ooo00Oooo]ZoookJP0>
oookJPGo001o1?oonfX00ol007ooo`0hogT0o`03oookJP05okSo0?l007oo001oo`00Oooo0;`01Ooo
nfX2of`0o`03oookJ_l0003o000000;o00001_oonfX01Oo]0?oooo]ZoookJ_nMo`3ooo]Z00;oo`3L
0_oonfX00omG0?oookL0oong0004oookJP;oT`3o0_oonfX01?o/o`3oo`00ool00?ooV`05oookJP?o
:`3o00Cooo]Zomgo0?oMo`3ogOl00_oBo`18oookJP;od_l00ooonfX3omgo00?ooo]Z0_l[0?l8oook
JP;oo`0000?ooo]Zonco0?o/o`001ooonfX2oi<0o`[ooo]Z0_mG0?l00ooonf[ookL0oookJP03oook
JP;oo`3L1_oonfX00onMo`3ooo]ZoookJP03oookJP;ok@3o6ooonfX00om/0?oooo]ZoookJP0Poook
JP00<?oonfX01OlY0?oooo]ZoookJ_oonf[o0?o`00Wooo]Z00?oonP0oookJ_oo00/01?oonfX01?oo
=@3ooo]ZoookJ_l0POl2oookJP05o`3oUooonf[o0?oXoookJ_lfo`003_oonfX01Ol0hooooo]Zoook
J_oonf[oo`3/00kooo]Z00?o0?o]oookJ_oonfX02_oonfX00ooo6P3ooo]Zoad0o`04oookJP04ool0
]?oonf[ooo]ZonGo00Sooo]Z00?o0?l9oookJ_oonfX00_oonfX2onGo0005ocCo0?oonf[oo`1?o`0;
oooo01P00_oonfX01?n`o`3ooo]ZoookJ_l0nol3oookJP05odh0oooonf[ooo]ZoookJ_oo01@00ooo
nfX00oooa`3ooo]ZoookJP03oookJP04oonX0?oonf[ooo]Zool0Y`?ooo]Z00?oob40oookJ_oonfX0
0ooonfX6ooo90005ohko0?oonf[oolT0oookJ_l0ol000_oonfX00ooo00Oooo]ZoookJP0=oookJPOo
001o0ooonfX2o`00O`03ool0>?oUo`3ooo]Z00;o001o0_nho`02o`00O`03ool0_?oonf[ooo]Z00?o
oo]Z00?oK03ooookJ_l000000ol00007oookJP04ond0oooonf[ooo]Zoigo00;ooo]Z00?oo`3Loook
J_oonfX01?oUo`0:oiCo0003ool00?nDo`3oU?l000WoU?l00ooMo`03oiCo03Cooo]Z1OoUo`08oook
JP?oiOl00_oonfX3omgo00;ooo]Z0ol[0?l8oookJP03oonK0?oo003oo`0000?ok?l00_oUo`05oook
JP;oT`3o2_oonfX2oeL0o`;oiOl01?oonfX2ool0g0Kooo]Z00?oWOl0oookJ_oonfX01?oonfX00oo]
0?oooo]ZoookJP0IoookJP03of`0oooonf[ooo]Z04oooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol009
oookJP03oooX0?oo00_ooo]Z00Cooo]Z00?oocD0oookJ_l0POl00ooonfX01Ol0oiOooo]Zo`3oj?oo
nf[o=_l000kooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00=oookJP03o`3okOoonf[ooo]Z00_ooo]Z
00?ooaX0oad0ool0oo801?oonfX00ooo0;Cooo]ZoonW0008oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z
00KoO03oocCo0?oonf[ooo]Zo`0;oooo01P2oookJP04ok3o0?oonf[ooo]Zo`3ko`?ooo]Z00?oCP3o
oookJ_oonfX00_oonfX01Ooo01Cooo]ZoookJ_oonf[oolL000Gooo]Z00?oojP0oookJ_oo0:L00ooo
nfX00ooo8@3ooo]ZoookJP05oookJP03o`3oUooonf[ooo]Z00;ooo]Z00OoS_l0ool0>Ooonf[ooo]Z
o`3o`?oonf[oo`0700oooo]Z1ol007l3oookJP;o001o00?oo`0hogT0oooonfX00_l007l2okSo00;o
001o00?oo`2loookJ_oonfX01?oonfX00om/0?oo0000o`000002o`0000Oooo]Z0_o]0?l01Ooonf[o
WOl0oigo0?oonf[oo`3L00;ooo]Z0_mG0?l2oong00Cooo]Z0_nC0?l00ooonf[ok?l0onco0002ool0
00;ooi/01OoonfX3ob/0o`04oookJ_oMo`3ogOl0omgo00?od_l0@OoonfX3om;o00;ooo]Z0ooMo`03
oookJP?o:`3o2?oonfX2ool00003oookJ_o/o`3ok?l000Oooo]Z0_nC0?l;oookJP04oeL0oooonf[o
okL0oong00?ooo]Z0_oo0=`7oookJP03oigo0?oonf[ooo]Z00?ooo]Z00?ok@3ooookJ_oonfX06_oo
nfX00om/0?oooo]ZoookJP0QoookJP00<?oonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[o
oo]Z00Kooo]Z00?oonP0oookJ_oo00/01OoonfX00ooo=@3ooo]Zo`21o`03oookJP04o`3oUol0onSo
oo]ZocKo00oooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00=oookJP03o`3okOoonf[ooo]Z00_ooo]Z
00?ooaX0oookJ_lM0?l01?oonfX00ooo0;Cooo]ZonGo0009oookJP04o`3o2Ooonf[ooo]ZoookJP;o
iOl000Go=?l0onGo0?oonf[o00_oool06003oookJP04ok3o0?oonf[ooo]Zo`3ko`?ooo]Z00GoCP3o
oookJ_oonf[ooo]Zool05002oookJP03ooo70?oonf[ooo]Z00Cooo]Z00?oojP0oookJ_oo0:L01?oo
nfX00ooo8@3ooo]ZoookJP02oookJPOoolT000OoS_l0oookJ_oob@3ooo]Zo`3o`?oonf[oo`0700oo
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?oo`0honGo0?mi0?l00_l007l01Ooo
nf[o^?l0o`00Ool007ooo`2l00Gooo]Z00?oK03oo`000?l000000_l00008oookJP;ok@3o00Cooo]Z
oigo0?nMo`3ooo]Z2ooUo`06oiCo00?oo`002onDo`03omgo00God_l0;OoonfX7onGo00?ooo]Z1OoU
o`02oookJP?ogOl00_oonfX3ob/0o`[ooo]Z0_oo0002onco0003ool0ZOoUo`3ooo]Z00Kooo]Z00?o
T`3ooookJ_oonfX02OoonfX00omG0?ooiOl0onGo0004oookJP;oo`3L1_oonfX2oigo00Gooo]Z0_o]
0?lKoookJP03of`0oooonf[ooo]Z053ooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]Zoook
JP06oookJP03oooX0?oo00_ooo]Z00Gooo]Z00?oocD0ocOo0?l0POl00_oonfX01Ol0oiOooo]Zo`3o
j?oonf[o=_l000oooo]Z00Co0>?ooookJ_oonf[oo`3/3OoonfX00ol0ongooo]ZoookJP0<oookJP03
oolJ0?lM0?oooo]Z00Cooo]Z00?oo`2doonW0?oonfX02?oonfX00ol0o`Wooo]ZoookJP03oookJP05
og`0ooldo`3ooo]Zo`0;oooo01P00ooonfX01?n`o`3ooo]ZoookJ_l0nol3oookJP05odh0oooonf[o
oo]ZoookJ_oo01@00ooonfX00oooa`3ooo]ZoookJP03oookJP04oonX0?oonf[ooo]Zool0Y`?ooo]Z
00?oob40oookJ_oonfX01?oonfX00ol0oiOooo]ZoookJP03oookJP07ohko0?oo03Wooo]ZoookJ_l0
ol3ooo]Zool01`0>oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03ool0>?mi0?oo
N@3o00;o001o00Gooo]ZokSo0?l007oo001oool0_006oookJP04of`0ool0003o0000o`0000Wooo]Z
00Gok@3ooookJ_oonf[oWOl0oookJP02ool0g0;ooo]Z0_mG0?l00ooo]`3ooo]ZoookJP03oookJP;o
T`3o00?ooo]Zonco0?o/o`000ooo0002oonK00Gooo]Z1?l[0?l3omgo00Kod_l0=_oonfX5om;o00;o
oo]Z0ooMo`03oookJP?o:`3o2OoonfX2ool00004oookJ_o/o`3ok?l0ool0Z@Oooo]Z00?oT`3ooook
J_oonfX02OoonfX2oeL0o`;ookL01?oonfX00ooo0=cooo]ZoookJP05oookJP;oWOl01?oonfX2ond0
oacooo]Z00?oK03ooookJ_oonfX08_oonfX0037ooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol009oook
JP03oooX0?oo00_ooo]Z00Cooo]Z00?oocD0oookJ_l0POl00ooonfX01Ol0oiOooo]Zo`3oj?oonf[o
=_l000kooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00>oookJP03o`3okOoonf[ooo]Z00[ooo]Z00?o
oaX0oookJ_lM0?l01?oonfX01?oo0;Cooo]ZoookJ_oUo`08oookJP04o`3o2Ooonf[ooo]ZoookJP?o
iOl000Go=?l0onGo0?oo04oo00_oool06003oookJP03ok3o0?oonf[o0?_o00Cooo]Z00CoCP3ooook
J_oonf[oo`0D0ooonfX00oooa`3ooo]ZoookJP04oookJP03oonX0?oonf[oo`2W00?ooo]Z00?oob40
oookJ_oonfX00ooonfX7ooo90004ohko0?oonf[oolT0o`3o`0;ooo]Z00?oo`07oookJ_oonfX02ooo
nfX3o`00O`?ooo]Z0ol007l6oookJP03ool0>?l007ooN@3o00?ooo]Z00Co^?l0o`00Ool007ooo`2l
1OoonfX01?m/0?oo0000o`000?l0000:oookJP04ond0oooonf[ooo]Zoigo00;ooo]Z3_oUo`04oiCo
00?oo`002_nDo`001?oonf[ogOl0omgo0?oMo`02oookJPGod_l09_oonfX<onGo00Cooo]Z0ooMo`02
oookJP?o:`3o2ooonfX2ool000;ok?l00_oo0:T7oookJP;oT`3o2_oonfX2oeL0o`03onGo0?oonf[o
oo]Z00?ooo]Z00?oo`3LoookJ_oonfX01OoonfX00onMo`3ooo]ZoookJP04oookJP03ond0oooonf[o
oo]Z01[ooo]Z00?oK03ooookJ_oonfX0D_oonfX01OlY0?oooo]ZoookJ_oonf[o0?o`00Wooo]Z00?o
onP0oookJ_oonfX01?oonfX00ooo=@3o=ol0o`21o`02oookJP05o`3oUooonf[ooo]Zo`3oj?lfo`00
3ooonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00gooo]Z00?o0?o]oookJ_oonfX02ooonfX00ooo6P3o
7@3oo`3olP04oookJP03ool0]?oonf[oojL000Sooo]Z00?o0?l9oookJ_oonfX00ooonfX01_ml0?oo
=?l0oookJ_oonf[o00_oool060?ooo]Z00?o/?l0oookJ_l0nol01?oonfX01Om>0?oooo]ZoookJ_oo
nf[oo`0D00?ooo]Z00?oolL0oookJ_oonfX00ooonfX01?ooZ03ooo]ZoookJ_oo0:L2oookJP03oolQ
0?oo0;Cooo]Z00Gooo]Z00?o0?nGoookJ_oonfX00ooonfX01?n>o`3oo`0ioookJ_l0ol02oookJP03
ool01ooonf[ooo]Z00[ooo]Z0ol007l3oookJP?o001o1_oonfX00ooo03So001oogT0o`03oookJP03
okSo0?l007oo001o00;oo`2l1?oonfX01?l0003oK03oo`000?l0000:oookJP;ok@3o00Cooo]Zoigo
0?nMo`3ooo]Z0_oo0=`2oookJP;oE`3o00?ookL0oookJ_oonfX00ooonfX2oi<0o`;ooo]Z0_o/o`03
ool000;ooi/01_oonfX3ob/0o`?ogOl00ooonfX5om;o02cooo]Z1OoBo`04oookJP?ogOl00ooonfX3
ob/0o`[ooo]Z0_oo00001?oonf[ok?l0onco0?oo0:T7oookJP;oT`3o2ooonfX00omG0?oookL0oong
0004oookJP;oo`3L1ooonfX00onMo`3ooo]ZoookJP03oookJP03ond0oooonf[ooo]Z01_ooo]Z00?o
K03ooookJ_oonfX08ooonfX002Gooo]Z00?oF@3ooookJ_oonfX02OoonfX01OlY0?oooo]ZoookJ_oo
nf[o0?o`00Wooo]Z00?oonP0oookJ_oo00/01?oonfX01?oo=@3ooo]ZoookJ_l0POl2oookJP05o`3o
Uooonf[o0?oXoookJ_lfo`003ooonfX01?l0hooooo]ZoookJ_oo0>`>oookJP03o`3okOoonf[ooo]Z
00_ooo]Z00?ooaX0oad0ool0oo801?oonfX00ooo0;Cooo]ZonGo0009oookJP04o`3o2Ooonf[ooo]Z
oookJP;oiOl000Go=?l0onGo0?oUo`3o00_oool06003oookJP04ok3o0?oonf[ooo]Zo`3ko`?ooo]Z
00GoCP3ooookJ_oonf[ooo]Zool05002oookJP03ooo70?oonf[ooo]Z00Cooo]Z00CoojP0oookJ_oo
nf[oo`2W0ooonfX00ooo8@3ooo]ZoookJP02oookJPSoolT000CoS_l0oookJ_oob@3o0?o00_oonfX0
0ooo00Oooo]ZoookJP0:oookJP?o001o0ooonfX3o`00O`Oooo]Z00?oo`0hoookJ_mi0?l00_oonfX0
1Ol007oo^?l0o`00Oooonf[oo`2l00Cooo]Z00?o0000of`0oom/0?l00ol00009oookJP;ok@3o00Co
oo]Zoigo0?nMo`3ooo]Z3ooUo`05oiCo00?oo`002_nDo`001?oonf[ogOl0omgo0?oMo`04oookJPKo
d_l07OoonfX=onGo00?ooo]Z0ooMo`02oookJP?o:`3o3?oonfX2ool000;ok?l000?oo`2YoookJ_oo
nfX01_oonfX2oi<0o`?ooo]Z0_oUo`06oookJP03oeL0oooUo`3ooo]Z00Cooo]Z0_oo0=`7oookJP03
oigo0?oonf[ooo]Z00?ooo]Z0_o]0?lLoookJP03of`0oooonf[ooo]Z04Kooo]Z00?oF@3ooookJ_oo
nfX02_oonfX01OlY0?oooo]ZoookJ_oonf[o0?o`00Wooo]Z00?oonP0ool02ooonfX01?oonfX00ooo
=@3ooo]Zo`21o`03oookJP05o`3oUooonf[o0?oXoookJ_lfo`003_oonfX01Ol0hooooo]ZoookJ_oo
nf[oo`3/00gooo]Z00?o0?o]oookJ_oonfX03?oonfX00olM0?oo0?oboookJP04oookJP03ool0]?oo
Y`3ooo]Z00Sooo]Z00?o0?l9oookJ_oonfX00ooonfX01Oml0?oo=?l0oookJ_l02oooo`0H00?ooo]Z
00Co/?l0oookJ_oonf[o0?_o0ooonfX00om>0?oooo]ZoookJP02oookJP04ool05?oonf[ooo]Zooo7
00Gooo]Z00CoojP0oookJ_oonf[oo`2W0ooonfX00ooo8@3ooo]ZoookJP05oookJP03o`3oUooonf[o
oo]Z00;ooo]Z00GoS_l0oookJ_oo03Wooo]Zo`3o`002oookJP03ool01ooonf[ooo]Z00Wooo]Z0ol0
07l3oookJP?o001o1ooonfX00ooo03Sooo]ZogT0o`02oookJP03o`00Oonho`3o001o00;ooo]Z00Co
o`2loookJ_oonf[ooo]Z0_l00002of`0o`;o00002_oonfX01?o]0?oooo]ZoookJ_nMo`02oookJP;o
o`3L0_oonfX2oeL0o`03oong0?oonf[ooo]Z00?ooo]Z0onC0?l2oookJP;ok?l00ooo0003oonK00Go
oo]Z0ol[0?l3omgo00Gooo]Z1_oBo`0QoookJPGod_l01_oonfX3omgo00?ooo]Z0ol[0?l;oookJP;o
o`0000?oo`2Yonco0?o/o`002?oonfX2oi<0o`_ooo]Z0_mG0?l00ooo]`3ooo]ZoookJP02oookJP;o
o`3L2?oonfX00onMo`3ooo]ZoookJP02oookJP;ok@3o7OoonfX00om/0?oooo]ZoookJP0ToookJP00
9OoonfX00omI0?oooo]ZoookJP09oookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX0
1_oonfX00oooj03ooo]Zool02`05oookJP03oole0?oonf[o087o00?ooo]Z00Co0?nGo`3oj?oonf[o
=_l03ooonfX01?l0hooooo]ZoookJ_oo0>`>oookJP03o`3okOoonf[ooo]Z00_ooo]Z00?ooaX0oook
J_lM0?l01OoonfX00ooo0;CoiOl0oookJP08oookJP04o`3o2Ooonf[ooo]ZoookJP;oiOl000Ko=?l0
onGo0?oUo`3oiOl0o`0;oooo01P3oookJP03ok3o0?oonf[o0?_o00Cooo]Z00GoCP3ooookJ_oonf[o
oo]Zool05002oookJP03ooo70?oonf[ooo]Z00Cooo]Z00?oojP0oookJ_oo0:L00ooonfX00ooo0;Co
ob40oookJP02oookJPSoolT000OoS_l0oookJ_oob@3ooo]Zo`3o`?oonf[oo`0700cooo]Z0ol007l3
oookJP?o001o2?oonfX01?oo03Sooo]ZogT0oooonfX2o`00O`04okSo0?oonf[ooo]Zool0_0?ooo]Z
0ol000000om/0?oooo]ZoookJP0;oookJP03ond0oooonf[ooo]Z00;oWOl03_oUo`08oiCo00?oo`00
1?nDo`03oookJP?oU?l000?ooo]Zomgo0?oMo`001?oMo`04oookJPood_l03?oonfX?onGo00?ogOl0
0_oonfX3ob/0o`cooo]Z0ooo0002onco00[ooo]Z00?oT`3ooookJ_oonfX00_oonfX3onGo00Cooo]Z
0_mG0?l5oookJP;oo`3L1ooonfX2oigo00Gooo]Z00?ok@3ooookJ_oonfX06ooonfX00om/0?oooo]Z
oookJP17oookJP03oeT0oooonf[ooo]Z00[ooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]Z
oookJP06oookJP03oooX0?oo00_ooo]Z00Gooo]Z00?oocD0ocOo0?l0POl00_oonfX01Ol0oiOooo]Z
o`3oj?oonf[o=_l000oooo]Z00Co0>?ooookJ_oonf[oo`3/3OoonfX00ol0ongooo]ZoookJP0<oook
JP03oolJ0?lM0?oo0?ob00Gooo]Z00?oo`2doonW0?oonfX01ooonfX00ol0o`Wooo]ZoookJP03oook
JP06og`0ooldo`3o02gooookJ_l02oooo`0H0ooonfX00on`o`3ooo]Zo`3ko`04oookJP05odh0oooo
nf[ooo]ZoookJ_oo01@00ooonfX00oooa`3ooo]ZoookJP03oookJP04oonX0?oonf[ooo]Zool0Y`?o
oo]Z00?oob40oookJ_oonfX01OoonfX00ol0oiOooo]ZoookJP02oookJP07ohko0?oo03Wooo]Zoook
J_l0ol3ooo]Zool01`0;oookJP?o001o0ooonfX3o`00O`Sooo]Z00Coo`0hoookJ_mi0?oooo]Z0_l0
07l01Onho`3ooo]ZoookJ_oonf[oo`2l00;ooo]Z1?l000000om/0?oooo]ZoookJP0:oookJP;ok@3o
00?ooo]Zoigo0?nMo`000_oonfX3ool0g004oookJ_mG0?ooE`3ooong00Kooo]Z0_nC0?l3oookJP;o
k?l00ooo0003oonK00Gooo]Z0ol[0?l6omgo00Gooo]Z3ooBo`0=oookJPGod_l02?oonfX3omgo00?o
oo]Z0ol[0?l;oookJP?oo`0000?oo`2Yonco0?o/o`002OoonfX00onC0?oooo]ZoookJP09oookJP;o
E`3o00?ookL0oookJ_oonfX00ooonfX00ooo0=cooo]ZoookJP06oookJP;oWOl01?oonfX00oo]0?oo
oo]ZoookJP0LoookJP03of`0oooonf[ooo]Z02Gooo]Z000VoookJP03oeT0oooonf[ooo]Z00Wooo]Z
00Go:@3ooookJ_oonf[ooo]Zo`3ol009oookJP03oooX0?oo00_ooo]Z00Cooo]Z00CoocD0oookJ_l0
POoo=ol00_oonfX01Ol0oiOooo]Zo`3oj?oonf[o=_l000kooo]Z00Go0>?ooookJ_oonf[ooo]Zool0
k00>oookJP03o`3okOoonf[ooo]Z00_ooo]Z00?ooaX0oad0oooonfX01?oonfX00ooo0;Cooo]ZonGo
0008oookJP04o`3o2Ooonf[ooo]ZoookJP?oiOl000Ko=?l0onGo0?oUo`3o00_ooookJ_oo01P2oook
JP04ok3o0?oonf[ooo]Zo`3ko`?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05002oookJP03ooo70?oo
nf[ooo]Z00Cooo]Z00CoojP0oookJ_oonf[oo`2W0ooonfX00ooo8@3ooo]ZoookJP02oookJPSoolT0
00OoS_l0oookJ_oob@3ooo]Zo`3o`?oonf[oo`0700_ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00
O`04ool0>?oonf[oN@3oogT0o`;o001o0_nho`001?oonf[oo`2loookJ_oonfX4o`000003of`0oooo
nf[ooo]Z00_ooo]Z0_o]0?l2oookJP03oigo0?oUo`3oiOl000[oiOl00ooonfX9oiCo00?oo`000_oo
V`05oookJP;oU?l01?l[0?l00ooonf[ogOl0omgo0006omgo00_ooo]Z2ooBo`08onGo00SogOl000?o
iOl0oookJ_l[0?l00_l[0?l;oookJPCoo`0000?oo`2Yonco0?o/o`002_oonfX2oi<0o`Cooo]Z1OoU
o`000ooonf[oE`3ooeL0o`06oookJP03ool0g?oonf[ooo]Z00Kooo]Z00?oWOl0oookJ_oonfX00ooo
nfX2ond0oagooo]Z00?oK03ooookJ_oonfX0BOoonfX00omI0?oooo]ZoookJP0:oookJP05obT0oooo
nf[ooo]ZoookJ_l0oo002OoonfX00oooj03ooo]ZoookJP04oookJP03oole0?oonf[o087o00;ooo]Z
00Go0?nGoookJ_oonf[o0?oXocKo000?oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`03OoonfX00ol0
ongooo]ZoookJP0<oookJP03oad0ool0oo;ooo]Z00Cooo]Z00?oo`2doonW0?oonfX01ooonfX00ol0
o`Wooo]ZoookJP04oookJP06og`0ooldo`3ooo]Zo`0;oooonf[oo`0H0ooonfX00on`o`3ooo]Zo`3k
o`03oookJP03odh0oooonf[ooo]Z00;ooo]Z00Coo`0DoookJ_oonf[oolL01OoonfX01?ooZ03ooo]Z
oookJ_oo0:L4oookJP03oolQ0?oonf[ooo]Z00Cooo]Z00?o0?nGoookJ_oonfX00ooonfX01on>o`3o
o`0ioookJ_oonf[o0?o0oookJ_oo00L02_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o00Coo`0h
oookJ_mi0?ooN@3o0_l007l2okSo00;ooo]Z00?oo`2loookJ_l000000ol000000ooonf[oK03ooook
JP0<oookJP;ok@3o00?ooo]Zoigo0?oonfX00ooonfX2ool0g004oookJ_mG0?ooE`3ooeL0o`Kooo]Z
0_nC0?l4oookJP;ok?l00ooo0003oonK00Gooo]Z1_l[0?l8omgo00cooo]Z3OoBo`05oookJPSogOl0
0ooonfX3ob/0o`[ooo]Z00Cooi/0ool00?oo003oo`000_oo0:T2onco00Wooo]Z0_nC0?l;oookJP03
oeL0oooo]`3ooo]Z00Cooo]Z0_oo0=`8oookJP03oigo0?oonf[ooo]Z00;ooo]Z0_o]0?lNoookJP03
of`0oooonf[ooo]Z02Kooo]Z000VoookJP03oeT0oooonf[ooo]Z00Wooo]Z00Go:@3ooookJ_oonf[o
oo]Zo`3ol009oookJP03oooX0?oonf[oo`0;00Cooo]Z00CoocD0oookJ_oonf[o087o0_oonfX01Ol0
oiOooo]Zo`3oj?oonf[o=_l000oooo]Z00Co0>?ooookJ_oonf[oo`3/3_oonfX00ol0ongooo]Zoook
JP0;oookJP03oolJ0?oonf[o7@3o00Gooo]Z00?oo`2donGo0?oonfX02?oonfX01?l0o`Wooo]Zoook
J_oonfX2onGo0006ocCo0?oUo`3oiOl0onGo0?l02oooo`0H0ooonfX01?n`o`3ooo]ZoookJ_l0nol3
oookJP05odh0oooonf[ooo]ZoookJ_oo01@00_oonfX00oooa`3ooo]ZoookJP04oookJP04oonX0?oo
nf[ooo]Zool0Y`?ooo]Z00Coob40oookJ_oonf[ooo]Z1ooob@02oookJP07ohko0?oonf[oolT0oook
J_l0ol3ooo]Zool01`0:oookJP?o001o0ooonfX3o`00O`Oooo]Z0ol007l01?oo03So001oo`00Oomi
0?l3oookJP04okSo0?oonf[oo`2loookJPCo000000?ooo]Zof`0oom/0?l03OoonfX01?o]0?oooo]Z
oookJ_nMo`0;onGo00Gooo]Z00?oU?l0oi<0oonC0?l00onDo`02oookJP;oU?l00ooo0002oonK00So
oo]Z2?l[0?l00ooonf[ogOl0omgo0006omgo00Wooo]Z3OoMo`000ooonf[oiOl0onGo0004onGo00?o
:`3o2_oonfX01?ooV`3oo`00ool00?oo0002ool0Z@?ok?l02OoonfX3oi<0o`Gooo]Z1_oUo`000omG
0?oooo]ZoookJP04oookJP;oo`3L2?oonfX00onMo`3ooo]ZoookJP03oookJP03ond0oooonf[ooo]Z
01cooo]Z00?oK03ooookJ_oonfX0B_oonfX00omI0?oooo]ZoookJP0:oookJP05obT0oooonf[ooo]Z
oookJ_l0oo002OoonfX00oooj03oo`0;oookJP04oookJP03oole0?oonf[o087o00?ooo]Z00Go0?nG
oookJ_l0onSooo]ZocKo000?oookJP04o`3Soooonf[ooo]Zool0k0gooo]Z00?o0?o]oookJ_oonfX0
3?oonfX00ooo6P3o7@3ooookJP05oookJP03ool0]?ooY`3ooo]Z00Oooo]Z00?o0?l9oookJ_oonfX0
1?oonfX01Oldo`3o02gooookJ_l02oooo`0H00?ooo]Z00Co/?l0oookJ_oonf[o0?_o0ooonfX01Om>
0?oooo]ZoookJ_oonf[oo`0D00?ooo]Z00?oolL0oookJ_oonfX00ooonfX01?ooZ03ooo]ZoookJ_oo
0:L3oookJP03oolQ0?oonf[ooo]Z00Gooo]Z00?o0?nGoookJ_oonfX00_oonfX00on>o`3ooo]Zool0
>@02oookJP03o`3o`?oonf[oo`0700Wooo]Z0ol007l3oookJP?o001o1ooonfX3o`00O`04ool0>?l0
07oo001oogT0o`?ooo]Z00Co^?l0oookJ_oonf[oo`2l1?l00002oookJP;oK03o3OoonfX01?o]0?oo
oo]Zoigo0?nMo`04oookJP;oo`3L00Cooo]Zoong0?mG0?ooE`3o1_oonfX3oi<0o`Cooo]Z0_o/o`03
ool000?ooi/02?oonfX8ob/0o`SogOl02OoonfX=omgo00Sooo]Z0ol[0?l9oookJP03oonK0?oo003o
o`0000;oo`000_oo0:T3onco00Sooo]Z0onC0?l:oookJP03oong0?mG0?ooE`3o00Kooo]Z00?oo`3L
oookJ_oonfX01ooonfX00onMo`3ooo]ZoookJP02oookJP03ond0oooonf[ooo]Z01gooo]Z00?oK03o
oookJ_oonfX09ooonfX002Kooo]Z00?oF@3ooookJ_oonfX02OoonfX00olY0?oooo]ZoookJP02oook
JP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0oookJ_oo00/01?oonfX01?oo=@3ooo]ZoookJ_l0POl3
oookJP04o`3oUol0onSooo]ZocKo00oooo]Z00Co0>?ooookJ_oonf[oo`3/3ooonfX00ol0ongooo]Z
oookJP0;oookJP03oolJ0?lM0?oooo]Z00Cooo]Z00?oo`2doookJ_oUo`002?oonfX01?l0o`Wooo]Z
oookJ_oonfX3onGo0006ocCo0?oUo`3oiOl0o`0;oooUo`3oo`0H0ooonfX00on`o`3ooo]Zo`3ko`04
oookJP04odh0oooonf[ooo]Zool050?ooo]Z00?oolL0oookJ_oonfX01?oonfX00oooZ03ooo]Zool0
Y`03oookJP03ool0]?oo8@3ooo]Z00;ooo]Z1Ooob@03oookJP03ohko0?oonf[oolT000;ooo]Z00?o
0?o0oookJ_oo00L02OoonfX3o`00O`?ooo]Z0ol007l7oookJPCo001o00Coo`0ho`00Oooonf[oN@3o
0ooonfX00onho`3ooo]Zool0_004o`0000?ooo]Z00?oK03ooookJ_oonfX02ooonfX2ond0o`;ooo]Z
00?oWOl0onGo0?oUo`001_oUo`000ooo]`3oiOl0onGo0006oookJP?oT`3o1OoonfX2oiCo00?oo`00
1?ooV`0;oookJPSo:`3o00?ooo]Zomgo0?oMo`001ooMo`06oookJPko:`3o2?oonfX2oonK00Coo`00
1Oo/o`09oookJP?oT`3o1ooonfX5onGo00;oE`3o00?oiOl0oookJ_oonfX00_oonfX2ool0g0Sooo]Z
0_nMo`04oookJP;ok@3o7OoonfX2of`0odgooo]Z00?oF@3ooookJ_oonfX02_oonfX00olY0?oooo]Z
oookJP02oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0ool02ooonfX01?oonfX01?oo=@3ooo]Z
ocOo0?l0POl2oookJP05o`3oUooonf[o0?oXoookJ_lfo`003ooonfX01?l0hooooo]ZoookJ_oo0>`>
oookJP03o`3okOoonf[ooo]Z00cooo]Z00?o7@3oo`3ol_oonfX01?oonfX00ooo0;CoojL0oookJP07
oookJP03o`3o2Ooonf[ooo]Z00Cooo]Z00KoO03oocCo0?oonf[o00_ooookJ_oo01P3oookJP03ok3o
0?oonf[o0?_o00Cooo]Z00GoCP3ooookJ_oonf[ooo]Zool05003oookJP03ooo70?oonf[ooo]Z00?o
oo]Z00CoojP0oookJ_oonf[oo`2W0ooonfX00ooo8@3ooo]ZoookJP05oookJP03o`3oUooonf[ooo]Z
00;ooo]Z00?oS_l0ool0>OoonfX00_oonfX00ol0ol3ooo]Zool01`08oookJP?o001o0ooonfX3o`00
O`Oooo]Z1?l007l01?oo03So001ooookJ_mi0?l3oookJP04okSo0?oonf[ooo]Zool0_0?o00001?oo
nfX00om/0?oooo]ZoookJP0;oookJP;ok@3o00?ooo]Zoigo0?oonfX01?oonfX2ool0g004oookJ_oo
]`3oE`3ooeL0o`Oooo]Z0onC0?l4oookJP;ok?l00ooo0005oonK00_ooo]Z2?l[0?l9omgo00Oooo]Z
3_l[0?l7oookJP;ooi/01?oo00000ooonf[ok?l0onco0003onco00Sooo]Z0onC0?l;oookJP03oong
0?mG0?ooE`3o00Kooo]Z0_oo0=`8oookJP;oWOl00ooonfX2ond0oakooo]Z0_m/0?lZoookJP009ooo
nfX00omI0?oooo]ZoookJP08oookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01ooo
nfX00oooj03oo`0;oookJP04oookJP04oole0?oonf[o087oocOo00;ooo]Z00Co0?nGo`3oj?oonf[o
=_l04?oonfX01?l0hooooo]ZoookJ_oo0>`>oookJP03o`3okOoonf[ooo]Z00_ooo]Z00?ooaX0oad0
oooonfX01OoonfX00ooo0;CoiOl0oookJP08oookJP03o`3o2Ooonf[ooo]Z00?oiOl000Ko=?l0onGo
0?oUo`3oo`1?o`0;oooo01P3oookJP04ok3o0?oonf[ooo]Zo`3ko`?ooo]Z00GoCP3ooookJ_oonf[o
oo]Zool05003oookJP03ooo70?oonf[ooo]Z00Cooo]Z00?oojP0oookJ_oo0:L00ooonfX01?oo0;Co
ob40oookJ_oonfX4ooo90003oookJ_oob@3ooo]Z00;ooo]Z00?oS_l0oookJ_oob@000_oonfX00ol0
ol3oo`07oookJP08oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l3oookJP;oo`0h00?ooo]ZogT0
oomi0?l00_oonfX01?nho`3ooo]Zool0_?oo0;`2o`0000Cooo]Z00?oK03ooookJ_oonfX03?oonfX0
1?o]0?oooo]ZoookJ_nMo`08onGo0004oookJ_oo]`3oiOl0onGo00Gooo]Z00?oU?l0oookJ_nC0?l0
0onC0?l4oookJP03oiCo0?o/o`3oo`0000?oo`001_ooV`0=oookJQ3o:`3o4_oonfX2oonK00Coo`00
1?o/o`0;oookJP?oT`3o2?oonfX6onGo0004oeL0oooUo`3oiOl0onGo00?ooo]Z00?oo`3LoookJ_oo
nfX01ooonfX00onMo`3ooo]ZoookJP03oookJP03ond0oooonf[ooo]Z01cooo]Z00?oK03ooookJ_oo
nfX0C_oonfX00omI0?oooo]ZoookJP09oookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oo
nfX01ooonfX00oooj03ooo]ZoookJP04oookJP03oole0?oonf[o087o00?ooo]Z00Co0?nGo`3oj?oo
nf[o=_l03ooonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00gooo]Z00?o0?o]oookJ_oonfX03?oonfX0
0olM0?oo0?oboookJP05oookJP03oonW0?oonf[ooo]Z00Oooo]Z00?o0?l9oookJ_oonfX01?oonfX0
1Oldo`3o02gooookJ_l02oooo`0H00Cooo]Z00?o/?l0oookJ_l0nol00ooonfX01Om>0?oooo]Zoook
J_oonf[oo`0D00Cooo]Z00?oolL0oookJ_oonfX00ooonfX00oooZ03ooo]Zool0Y`04oookJP03oolQ
0?oonf[ooo]Z00Gooo]Z00?o0?nGoookJ_oonfX00_oonfX00on>o`3oo`0ioookJP02oookJP03o`3o
`?oo00Oooo]Z00Oooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`?ooo]Z0_oo03P00ooonf[oN@3o
ogT0o`02oookJP03okSo0?oonf[o000000;oo`2l00?o0000oookJ_oonfX00ooonfX00om/0?oooo]Z
oookJP0<oookJP04ond0oooonf[oWOl0oigo00Gooo]Z0_oo0=`01?oonf[ookL0oeL0oomG0?l8oook
JPCoT`3o0ooonfX2onco00Coo`0000?oo`2YoonK0?ooV`001?ooV`0=oookJQ3o:`3o4OoonfX3oonK
00?oo`0000?ooo]Zonco0?o/o`000_o/o`0:oookJP?oT`3o3?oonfX2oong0003oeL0oooonf[ooo]Z
00Cooo]Z0_oo0=`9oookJP03oigo0?oonf[ooo]Z00;ooo]Z00?ok@3ooookJ_oonfX07OoonfX00om/
0?oooo]ZoookJP0ZoookJP009ooonfX00omI0?oooo]ZoookJP09oookJP03obT0oooonf[ooo]Z00;o
oo]Z00?o0?o`oookJ_oonfX01_oonfX00oooj03ooo]Zool02`04oookJP04oole0?oonf[o087oocOo
00;ooo]Z00Go0?nGoookJ_l0onSooo]ZocKo000?oookJP04o`3Soooonf[ooo]Zool0k0oooo]Z00?o
0?o]oookJ_oonfX02ooonfX00ooo6P3o7@3ooookJP04oookJP03ool0]?oonf[oiOl000Sooo]Z00?o
0?l9oookJ_oonfX01?oUo`001_ldo`3o02goool0Col02ooooo]Zool060?ooo]Z00?o/?l0oookJ_l0
nol01?oonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00;ooo]Z00?oolL0oookJ_oonfX01?oonfX01?oo
Z03ooo]ZoookJ_oo0:L3oookJP03oolQ0?oonf[ooo]Z00?oolT00ooonfX01ooob@3ooo]ZoookJ_oo
nf[oS_l0oookJ_oob@000_oonfX00ol0ol3oo`07oookJP08oookJP?o001o00Cooo]Zo`00Ool007oo
001o2?oonfX2o`00O`Gooo]Z00Coo`0hoookJ_oonf[oN@3o0_oonfX2okSo0003o`000?oo0;co0000
00Gooo]Z00?oK03ooookJ_oonfX03?oonfX:onGo0003oookJ_oUo`3oiOl000;ooo]Z0_oUo`000ooo
]`3ooo]ZoookJP06oookJPCoT`3o1?oonfX2onco00Koo`001oooV`0ToookJP?ooi/00ooo0004onco
0003ool0ZOoonf[ooo]Z00Wooo]Z0onC0?l:oookJPGoiOl00_mG0?l4onGo0003oookJ_oo0=coo`3L
00Sooo]Z0_nMo`04oookJP;ok@3o7_oonfX00om/0?oooo]ZoookJP1?oookJP03oeT0oooonf[ooo]Z
00[ooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP06oookJP03oooX0?oo00_ooo]Z
00Cooo]Z00?oocD0oookJ_l0POl00ooonfX01Ol0oiOooo]Zo`3oj?oonf[o=_l000oooo]Z00Co0>?o
oookJ_oonf[oo`3/3_oonfX00ol0ongooo]ZoookJP0<oookJP03oad0ool0oo;ooo]Z00Cooo]Z00?o
o`2doonW0?oonfX01ooonfX00ol0o`Wooo]ZoookJP04oookJP06og`0ooldo`3o02goo`0;oooonf[o
o`0H0ooonfX00on`o`3ooo]Zo`3ko`04oookJP05odh0oooonf[ooo]ZoookJ_oo01@00ooonfX00ooo
a`3ooo]ZoookJP04oookJP03oonX0?oonf[oo`2W00Cooo]Z00?oob40oookJ_oonfX01OoonfX00ol0
oiOooo]ZoookJP02oookJP03ohko0?oo03Wooo]Z00;ooo]Z00?o0?o0ool01ooonfX01ooonfX3o`00
O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l5oookJP04ool0>?oonf[ooo]ZogT0o`;ooo]Z0_nh
o`02o`000003ool0_?oonf[ooo]Z00Cooo]Z00?oK03ooookJ_oonfX03?oonfX2ond0o`04oookJ_nM
o`3oWOl0oigo00Cooo]Z0ooo0=`01?oonf[oE`3ooeL0oooo]`09oookJP?oT`3o1?oonfX2onco00Ko
o`0000?ooo]ZoonK0?ooV`001?ooV`0ToookJP?ooi/01?oo0004onco0003ool0ZOoonf[ooo]Z00So
oo]Z0onC0?l=oookJP;ookL00_mG0?l6oookJP03ool0g?oonf[ooo]Z00Oooo]Z0_nMo`03oookJP;o
k@3o7ooonfX00om/0?oooo]ZoookJP0[oookJP009ooonfX00omI0?oooo]ZoookJP09oookJP03obT0
oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01_oonfX00oooj03ooo]Zool02`04oookJP04oole
0?oonf[ooo]Zo`21o`?ooo]Z00Co0?nGo`3oj?oonf[o=_l04?oonfX00ol0hooooo]Zool0k00?oook
JP03o`3okOoonf[ooo]Z00_ooo]Z00?ooaX0oad0oooonfX01OoonfX00ooo0;CoiOl0oookJP08oook
JP03o`3o2Ooonf[ooo]Z00;oiOl000Sooo]ZocCo0?oUo`3ooo]Zool0Col02ooooo]Zool060?ooo]Z
00?o/?l0oookJ_l0nol00ooonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00?ooo]Z00?oolL0oookJ_oo
nfX01?oonfX00oooZ03ooo]Zool0Y`03oookJP05ool0]?oo8@3ooo]ZoookJ_oob@001?oonfX01Ooo
b@3ooo]ZoookJ_oonf[oS_l000;ooo]Z00GoolT0oookJ_oonf[o0?o0ool01`08oookJPOo001o2Ooo
nfX7o`00O`04ool0>?oonf[ooo]ZogT0o`;ooo]Z00?o0000okSo0?l000000_oo0;`5oookJP;oK03o
3_oonfX7onGo00Cooo]Z0_oUo`02oookJP;oiOl000?ookL0oookJ_oonfX02?oonfX3oi<0o`Oooo]Z
0_o/o`07ool000Kooi/03ooonfX>oonK00Coo`000oo/o`02ool0Z@_ooo]Z0onC0?l<oookJP?oiOl0
0omG0?l5onGo00;oo`3L2OoonfX00onMo`3ooo]ZoookJP03oookJP03ond0oooonf[ooo]Z01gooo]Z
00?oK03ooookJ_oonfX0D?oonfX00omI0?oooo]ZoookJP0:oookJP03obT0oooonf[ooo]Z00;ooo]Z
00?o0?o`oookJ_oonfX01_oonfX00oooj03oo`0;oookJP04oookJP03oole0?oonf[o087o00?ooo]Z
00Go0?nGoookJ_l0onSooo]ZocKo000?oookJP04o`3Soooonf[ooo]Zool0k0kooo]Z00?o0?o]oook
J_oonfX03?oonfX00olM0?oo0?oboookJP05oookJP03oonW0?oonf[ooo]Z00Oooo]Z00?o0?l9oook
J_oonfX01?oonfX01_ldo`3o02gooookJ_l02ooooo]Zool060?ooo]Z00?o/?l0oookJ_l0nol00ooo
nfX00om>0?oooo]ZoookJP02oookJP05ool05?oonf[ooo]ZoookJ_ooa`001OoonfX01?ooZ03ooo]Z
oookJ_oo0:L3oookJP03oolQ0?oonf[ooo]Z00Gooo]Z00?o0?nGoookJ_oonfX00_oonfX00on>o`3o
oo]Zool0>@03oookJP03o`3o`?oo00Oooo]Z00Kooo]Z1ol007l9oookJPOo001o00Coo`0hoookJ_oo
nf[oN@3o0_oonfX01?l0003o^?l0o`000?l00002ool0_0Gooo]Z0_m/0?l>oookJP;ok@3o0_oonfX2
oigo00Gooo]Z0_oo0=`00ooonf[oE`3ooeL0o`02oong00Wooo]Z0onC0?l7oookJP;ok?l01ooo0006
oonK00oooo]Z3oooV`03ool000Cok?l00_oo0:T:oookJP?oT`3o3_oonfX01?oo]`3oE`3ooeL0oomG
0?l6oookJP;oo`3L2OoonfX00onMo`3ooo]ZoookJP02oookJP03ond0oooonf[ooo]Z01kooo]Z00?o
K03ooookJ_oonfX0;?oonfX002Sooo]Z00?oF@3ooookJ_oonfX02?oonfX00olY0?oooo]ZoookJP02
oookJP03o`3ol?oonf[ooo]Z00Oooo]Z00?oonP0ool02ooonfX01?oonfX01?oo=@3ooo]Zo`21oolg
o`02oookJP04o`3oUol0onSooo]ZocKo013ooo]Z00Co0>?ooookJ_oonf[oo`3/3ooonfX00ol0ongo
oo]ZoookJP0;oookJP03oolJ0?lM0?oooo]Z00Cooo]Z00?oo`2donGo0?oonfX02OoonfX00ol0o`Wo
oo]ZonGo0003oookJP06ocCo0?l0;Ooooo]Zool0Col02oooo`0H0ooonfX00on`o`3ooo]Zo`3ko`04
oookJP05odh0oooonf[ooo]ZoookJ_oo01@00ooonfX00oooa`3ooo]ZoookJP04oookJP03oonX0?oo
nf[oo`2W00?ooo]Z00?oo`2doolQ0?oonfX01_oonfX01ooob@3ooo]ZoookJ_oonf[oS_l0oookJ_oo
03T00ooonfX00ol0ol3oo`07oookJP07oookJPGo001o2_oonfX7o`00O`06oookJ_oo03Soo`0hoook
J_mi0?oooo]Z0_l000001?nho`3o0000oookJ_oo0;`6oookJP03of`0oooonf[ooo]Z00cooo]Z2ooU
o`000ooonf[oiOl0onGo0002oookJP04onGo0?mG0?ooE`3ooong00[ooo]Z1?nC0?l9oookJP?ok?l0
1_oo000?oonK00koo`000_o/o`0?oookJP?oT`3o3_oonfX01?oUo`3oE`3ooeL0oomG0?l7onGo0003
ool0g?oonf[ooo]Z00Sooo]Z00?oWOl0oookJ_oonfX00_oonfX2ond0oaoooo]Z00?oK03ooookJ_oo
nfX03OoonfX00ooo0;cooo]ZoookJP12oookJP03oeT0oooonf[ooo]Z00Wooo]Z00?o:@3ooookJ_oo
nfX00_oonfX00ol0oo3ooo]ZoookJP07oookJP03oooX0?oonf[ooo]Z00Cooo]Z00?oocD0oookJ_l0
POl00ooonfX01?l0oiOo0?oXoookJ_lfo`0@oookJP04o`3Soooonf[ooo]Zool0k0kooo]Z00?o0?o]
oookJ_oonfX03?oonfX00olM0?oo0?oboookJP04oookJP03ool0]?ooY`3ooo]Z00Sooo]Z00?o0?l9
oookJ_oonfX01?oonfX01Oldo`3o02gooookJ_l02oooo`0H00Cooo]Z00?o/?l0o`3koooonfX00ooo
nfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Cooo]Z00?oolL0oookJ_oonfX00ooonfX00oooZ03ooo]Z
ool0Y`04oookJP03oolQ0?oonf[ooo]Z00Gooo]Z00?o0?nGoookJ_oonfX00_oonfX00on>o`3oo`0i
oookJP03oookJP03o`3o`?oo00Oooo]Z00Kooo]Z1Ol007l:oookJPOo001o00Kooo]Zool0>?oo03So
oo]ZogT0oooonfX2o`000005okSo0?l0003ooo]ZoookJ_oo0;`01_oonfX00om/0?oooo]ZoookJP0=
oookJP?ok@3o00Cooo]Zoigo0?nMo`3oWOl01?oonfX2ool0g004oookJ_mG0?ooE`3ooeL0o`;ookL0
2OoonfX4oi<0o`[ooo]Z0_o/o`06ool000oooi/03ooo0002onco00kooo]Z0onC0?l?oookJP?oE`3o
1ooonfX2ool0g0[ooo]Z00CoWOl0oookJ_oonf[ooo]Z0_o]0?lPoookJP03of`0oooonf[ooo]Z00go
oo]Z00?oo`2loookJ_oonfX07OoonfX002Sooo]Z00?oF@3ooookJ_oonfX02OoonfX00olY0?oooo]Z
oookJP02oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0oookJ_oo00/01?oonfX01?oo=@3ooo]Z
o`21oolgo`03oookJP04o`3oUol0onSooo]ZocKo00oooo]Z00Co0>?ooookJ_oonf[oo`3/3ooonfX0
0ol0ongooo]ZoookJP0<oookJP03oad0oooonf[ooo]Z00Cooo]Z00?oo`2donGo0?oonfX02?oonfX0
0ol0o`Wooo]ZoookJP04oookJP06ocCo0?l0;Oooo`1?o`0;oooonf[oo`0H0ooonfX00on`o`3ooo]Z
o`3ko`04oookJP04odh0oooonf[ooo]Zool050Cooo]Z00?oolL0oookJ_oonfX01?oonfX00oooZ03o
oo]Zool0Y`03oookJP03ool0]?oo8@3ooo]Z00Kooo]Z00OoolT0oookJ_oonf[ooo]Zohko0?oonf[o
o`0i00?ooo]Z00?o0?o0ool01ooonfX07ooonfX01?oo03Sooo]ZogT0oomi0?l2o`000003okSo0?oo
nf[ooo]Z00;oo`2l1OoonfX00om/0?oooo]ZoookJP0=oookJPgoiOl00_oo0=`2oookJP?oE`3o00?o
okL0oookJ_oonfX02OoonfX3oi<0o`cooo]Z0oo/o`0?ool000cok?l04?oonfX3oi<0o`oooo]Z0omG
0?l5onGo00?ooo]Z0_oo0=`9oookJP;oWOl01?oonfX00oo]0?oooo]ZoookJP0NoookJP03of`0oooo
nf[ooo]Z00gooo]Z00?oo`2loookJ_oonfX0@ooonfX00omI0?oooo]ZoookJP0:oookJP03obT0oooo
nf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01_oonfX00oooj03oo`0;oookJP04oookJP03oole0?oo
nf[o087o00?ooo]Z00Go0?nGoookJ_l0onSooo]ZocKo000?oookJP04o`3Soooonf[ooo]Zool0k0ko
oo]Z00?o0?o]oookJ_oonfX03?oonfX00olM0?oo0?oboookJP05oookJP03oonW0?oonf[ooo]Z00Oo
oo]Z00?o0?l9oookJ_oonfX01?oonfX01_ml0?oo=?l0oookJ_l02ooooo]Zool060?ooo]Z00?o/?l0
oookJ_l0nol01?oonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00?ooo]Z00?oolL0oookJ_oonfX01?oo
nfX00oooZ03ooo]Zool0Y`04oookJP03oolQ0?oonf[ooo]Z00Gooo]Z00?o0?nGoookJ_oonfX00_oo
nfX00on>o`3oo`0ioookJP03oookJP03o`3o`?oo00Oooo]Z01kooo]Z00Coo`0hoookJ_mi0?ooN@3o
0_l000001?nho`3ooo]ZoookJ_oonfX2ool0_0Gooo]Z00?oK03ooookJ_oonfX03ooonfX2ond0o`;o
oo]Z0_nMo`04oookJP?oo`3L00Gooo]ZoeL0oomG0?ooE`3ooong000;oookJP?oT`3o3OoonfX2onco
00ooo`003Oo/o`0?oookJP?oT`3o3ooonfX3oeL0o`Wooo]Z00?oo`3LoookJ_oonfX02?oonfX2oigo
00?ooo]Z00?ok@3ooookJ_oonfX07ooonfX00om/0?oooo]ZoookJP0=oookJP03ool0_?oonf[ooo]Z
01kooo]Z000XoookJP03oeT0oooonf[ooo]Z00Wooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3o
oo]ZoookJP06oookJP03oooX0?oonf[oo`0;00Cooo]Z00CoocD0oookJ_oonf[o087o0ooonfX01?l0
oiOo0?oXoookJ_lfo`0@oookJP03o`3Soooonf[oo`3/00oooo]Z00?o0?o]oookJ_oonfX03?oonfX0
0ooo6P3o7@3ooookJP04oookJP03ool0]?oUo`3ooo]Z00Wooo]Z00?o0?l9oookJ_oonfX00ooonfX0
1_ldo`3o02gooookJ_oo04oo00_oool060?ooo]Z00?o/?l0oookJ_l0nol01?oonfX01Om>0?oooo]Z
oookJ_oonf[oo`0D00?ooo]Z00?oolL0oookJ_oonfX01OoonfX00oooZ03oo`2WoookJP02oookJP03
ool0]?oo8@3ooo]Z00Oooo]Z00OoolT0oookJ_oonf[ooo]Zohko0?oonf[oo`0i00?ooo]Z00?o0?o0
ool01ooonfX07ooonfX01?oo03Sooo]Zo`000?mi0?l2o`000004okSo0?oonf[ooo]ZoookJP;oo`2l
1?oonfX2of`0o`kooo]Z2ooUo`03oookJP?oo`3L0_oonfX4oeL0o`_ooo]Z1_nC0?laoookJP?oT`3o
3ooonfX3oeL0o`?oiOl01OoonfX3ool0g0Sooo]Z0onMo`04oookJP;ok@3o8?oonfX00om/0?oooo]Z
oookJP0=oookJP03ool0_?oonf[ooo]Z04Cooo]Z00?oF@3ooookJ_oonfX02_oonfX00olY0?oooo]Z
oookJP02oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0ool02ooonfX01?oonfX00ooo=@3ooo]Z
o`21o`03oookJP05o`3oUooonf[o0?oXoookJ_lfo`003ooonfX01?l0hooooo]ZoookJ_oo0>`>oook
JP03o`3okOoonf[ooo]Z00cooo]Z00?ooaX0oad0oooonfX01OoonfX00oooY`3ooo]ZoookJP08oook
JP03o`3o2Ooonf[ooo]Z00Cooo]Z00Go=?l0o`0]oooonf[o00_oool06004oookJP03ok3o0?l0nooo
oo]Z00?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05004oookJP03ooo70?oonf[ooo]Z00Cooo]Z00?o
ojP0oookJ_oo0:L00ooonfX00ooo0;Coob40oookJP06oookJP03o`3oUooonf[ooo]Z00;ooo]Z00?o
S_l0ool0>OoonfX00ooonfX00ol0ol3oo`07oookJP0NoookJP;oo`0h00Go0000ogT0ool0003o0000
okSo0004oookJP03ool0_?oonf[ooo]Z00?ooo]Z0_m/0?lAoookJP;ok@3o0_oonfX3oigo00Cooo]Z
0ooo0=`00ooonf[oE`3ooeL0o`02oeL0o`_ooo]Z1_nC0?laoookJP?oT`3o3ooonfX3oeL0o`03oong
0?oonf[ooo]Z00Kooo]Z0ooo0=`8oookJP?oWOl00ooonfX2ond0ob7ooo]Z00?oK03ooookJ_oonfX0
3OoonfX00ooo0;cooo]ZoookJP0OoookJP00:OoonfX00omI0?oooo]ZoookJP08oookJP03obT0oooo
nf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01_oonfX01?ooj03ooo]ZoookJ_oo00/3oookJP05oole
0?oonf[ooo]Zo`21oolgo`000_oonfX01?l0oiOo0?oXoookJ_lfo`0@oookJP04o`3Soooonf[ooo]Z
ool0k0oooo]Z00?o0?o]oookJ_oonfX03?oonfX00ooo6P3o7@3ooookJP04oookJP03ool0]?oUo`3o
oo]Z00Sooo]Z00?o0?l9oookJ_oonfX01?oonfX01_ldo`3o02gooookJ_oo04oo00_oool060?ooo]Z
00?o/?l0oookJ_l0nol01?oonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00?ooo]Z00?oolL0oookJ_oo
nfX01?oonfX00oooZ03ooo]Zool0Y`03oookJP03ool0]?oo8@3ooo]Z00Oooo]Z00OoolT0oookJ_oo
nf[ooo]Zohko0?oonf[oo`0i00?ooo]Z00?o0?o0ool01ooonfX07ooonfX2ool0>004o`000?mi0?oo
0000o`0000;o^?l00ooonfX00ooo0;cooo]ZoookJP03oookJP;oK03o3_oonfX8onGo0003oookJ_nM
o`3oWOl000Cooo]Z0ooo0=`2oookJP03oong0?mG0?ooE`3o00;oE`3o3OoonfX9oi<0ob3ooo]Z2?nC
0?l?oookJP?oE`3o00?ookL0oookJ_oonfX01OoonfX3ool0g0Wooo]Z0_nMo`06oookJP03ond0oooo
nf[ooo]Z01oooo]Z00?oK03ooookJ_oonfX03?oonfX2ool0_4Sooo]Z00?oF@3ooookJ_oonfX02Ooo
nfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0oookJ_oo00/01?oo
nfX01?oo=@3ooo]ZoookJ_l0POl3oookJP04o`3oUol0onSooo]ZocKo013ooo]Z00Co0>?ooookJ_oo
nf[oo`3/3_oonfX00ol0ongooo]ZoookJP0<oookJP03oolJ0?lM0?oooo]Z00Gooo]Z00?oojL0oook
J_oonfX02?oonfX00ol0o`Wooo]ZoookJP03oookJP06og`0ooldo`3o02gooookJ_l02oooo`0H1?oo
nfX00on`o`3o0?_ooookJP03oookJP05odh0oooonf[ooo]ZoookJ_oo01@01?oonfX00oooa`3ooo]Z
oookJP04oookJP03oonX0?oo0:Oooo]Z00?ooo]Z00?oo`2doolQ0?oonfX01_oonfX00ol0oiOooo]Z
oookJP02oookJP03ohko0?oo03Wooo]Z00?ooo]Z00?o0?o0ool01ooonfX07ooonfX00ooo03So0000
ogT0o`02o`0000;o^?l00ooonfX2ool0_0Gooo]Z0_m/0?lAoookJP?ok@3o0_oonfX2oigo00Gooo]Z
0ooo0=`2oookJPCoE`3o3OoonfX9oi<0ob3ooo]Z2?nC0?l?oookJP?oE`3o00?ookL0oookJ_oonfX0
1_oonfX3ool0g0Wooo]Z0_nMo`05oookJP03ond0oooonf[ooo]Z023ooo]Z00?oK03ooookJ_oonfX0
3?oonfX2ool0_2;ooo]Z000YoookJP03oeT0oooonf[ooo]Z00Sooo]Z00?o:@3ooookJ_oonfX00ooo
nfX00ol0oo3ooo]ZoookJP06oookJP03oooX0?oonf[oo`0;00Cooo]Z00CoocD0oookJ_l0POoo=ol0
0ooonfX01?l0oiOo0?oXoookJ_lfo`0@oookJP03o`3Soooonf[oo`3/00oooo]Z00?o0?o]oookJ_oo
nfX03?oonfX00ooo6P3o7@3ooookJP04oookJP03ool0]?ooY`3ooo]Z00Wooo]Z00?o0?l9oookJ_oo
nfX01?oonfX01_ldo`3o02goool0Col02ooooo]Zool060?ooo]Z00?o/?l0oookJ_l0nol00ooonfX0
1Om>0?oooo]ZoookJ_oonf[oo`0D00Cooo]Z00?oolL0oookJ_oonfX01?oonfX00oooZ03ooo]Zool0
Y`03oookJP03ool0]?oo8@3ooo]Z00Kooo]Z00?oolT0oookJ_oonfX00_oonfX00on>o`3ooo]Zool0
>@02oookJP03o`3o`?oonf[oo`07023ooo]Z00?o0000ool0>?l000000_mi0?l2oookJP04okSo0?oo
nf[ooo]ZoookJP;oo`2l1OoonfX2of`0o`gooo]Z1ooUo`03oookJP?oWOl01?oonfX3ool0g0;ooo]Z
0_oo]`03oeL0oa?ooo]Z2OnC0?l:oookJPgoT`3o4ooonfX01?oo]`3oE`3ooeL0oomG0?l7oookJPCo
o`3L2OoonfX3oigo00Kooo]Z0_o]0?lQoookJP03of`0oooonf[ooo]Z00cooo]Z00?oo`2loookJ_oo
nfX0B?oonfX00omI0?oooo]ZoookJP09oookJP03obT0oooonf[ooo]Z00?ooo]Z00?o0?o`oookJ_oo
nfX01_oonfX00oooj03oo`0;oookJP04oookJP03oole0?oonf[o087o00?ooo]Z00Go0?nGoookJ_l0
onSooo]ZocKo000?oookJP04o`3Soooonf[ooo]Zool0k0kooo]Z00?o0?o]oookJ_oonfX03?oonfX0
0ooo6P3o7@3ooookJP05oookJP03oonW0?oonf[ooo]Z00Sooo]Z00?o0?l9oookJ_oonfX01?oonfX0
1_ml0?oo=?l0oookJ_l02ooooo]Zool060?ooo]Z00?o/?l0oookJ_l0nol00ooonfX01Om>0?oooo]Z
oookJ_oonf[oo`0D00Gooo]Z00?oolL0oookJ_oonfX00ooonfX00oooZ03ooo]Zool0Y`04oookJP03
oolQ0?oonf[ooo]Z00Gooo]Z00?o0?nGoookJ_oonfX00ooonfX00on>o`3oo`0ioookJP02oookJP03
o`3o`?oonf[oo`0701oooo]Z00?o0000ool0>?l000000_mi0?l2oookJP03okSo0?oonf[ooo]Z00;o
oo]Z00?oo`2loookJ_oonfX01?oonfX00om/0?oooo]ZoookJP0AoookJP;ok@3o0_oonfX3oigo00Go
oo]Z0ooo0=`2oookJP04oong0?mG0?ooE`3ooeL0oa?ooo]Z2OnC0?l:oookJPgoT`3o4ooonfX01?oo
]`3oE`3ooeL0oomG0?l8oookJPCoo`3L2OoonfX3oigo00Gooo]Z0_o]0?lRoookJP03of`0oooonf[o
oo]Z00cooo]Z00?oo`2loookJ_oonfX08_oonfX002Gooo]Z00Goo`2ZoookJ_oonf[ooo]ZoeT0o`0;
oookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01_oonfX00oooj03ooo]Zool02`04
oookJP05oole0?oonf[o087ooookJ_lgo`000_oonfX01?l0oiOo0?oXoookJ_lfo`0@oookJP04o`3S
oooonf[ooo]Zool0k0oooo]Z00?o0?o]oookJ_oonfX03?oonfX00ooo6P3o7@3ooookJP04oookJP03
ool0]?ooY`3ooo]Z00Wooo]Z00?o0?l9oookJ_oonfX00ooonfX01_ldo`3o02gooookJ_oo04oo00_o
ool060?ooo]Z00?o/?l0oookJ_l0nol01?oonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Cooo]Z00?o
olL0oookJ_oonfX01?oonfX00oooZ03oo`2WoookJP02oookJP03ool0]?oo8@3ooo]Z00Oooo]Z00?o
olT0oookJ_oonfX00_oonfX00on>o`3ooo]Zool0>@02oookJP03o`3o`?oonf[oo`0701oooo]Z0_l0
00001?oo03So0000oookJ_mi0?l2oookJP;o^?l00ooonfX00ooo0;cooo]ZoookJP04oookJP;oK03o
3?oonfX5onGo0003oookJ_oUo`3oiOl000Cooo]Z0_nMo`05oookJPCoo`3L00?ooo]Zoong0?oo]`00
1?mG0?lHoookJP[oT`3o7?oonfX2oong00?oE`3o1ooonfX3ool0g0_ooo]Z0_nMo`06oookJP?ok@3o
8_oonfX00om/0?oooo]ZoookJP0;oookJP;oo`2lAooonfX01Ooo0:[ooo]ZoookJ_oonf[oF@3o00co
oo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP06oookJP03oooX0?oo00_ooo]Z00Co
oo]Z00CoocD0oookJ_l0POoo=ol00ooonfX01?l0oiOo0?oXoookJ_lfo`0?oookJP05o`3Soooonf[o
oo]ZoookJ_oo0>`03_oonfX00ol0ongooo]ZoookJP0<oookJP03oolJ0?lM0?oooo]Z00Gooo]Z00?o
ojL0oookJ_oonfX02?oonfX00ol0o`Wooo]ZoookJP04oookJP05ocCo0?l0;Ooooo]Zo`0;oooo01P0
1?oonfX00on`o`3o0?_ooookJP03oookJP05odh0oooonf[ooo]ZoookJ_oo01@01?oonfX00oooa`3o
oo]ZoookJP04oookJP03oonX0?oo0:Oooo]Z00?ooo]Z00?oo`2doolQ0?oonfX01_oonfX00ol0oiOo
oo]ZoookJP03oookJP03ohko0?oo03Wooo]Z00;ooo]Z00?o0?o0oookJ_oo00L07_oonfX2o`0000;o
o`0h00Cooo]ZogT0oooonf[ooo]Z0_nho`03oookJP;oo`2l1OoonfX2of`0oa?ooo]Z0_o]0?l3oook
JP;oWOl01_oonfX3ool0g0;ooo]Z00?ookL0oeL0oomG0?l00_mG0?lHoookJP[oT`3o7?oonfX2oong
00?oE`3o2?oonfX3ool0g0_ooo]Z0_nMo`05oookJP?ok@3o8ooonfX00om/0?oooo]ZoookJP0;oook
JP;oo`2l9OoonfX002Gooo]Z00?oo`2ZoookJ_oonfX00_oonfX00omI0?oooo]ZoookJP08oookJP03
obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01_oonfX01?ooj03ooo]ZoookJ_oo00/3oook
JP05oole0?oonf[ooo]Zo`21oolgo`000_oonfX01Ol0oiOo0?oXoookJ_oonf[o=_l000oooo]Z00Co
0>?ooookJ_oonf[oo`3/3ooonfX00ol0ongooo]ZoookJP0<oookJP03oolJ0?lM0?oooo]Z00Cooo]Z
00?oo`2doookJ_ooY`002OoonfX00ol0o`Wooo]ZoookJP04oookJP06ocCo0?l0;Ooooo]Zool0Col0
2oooo`0H0ooonfX00on`o`3ooo]Zo`3ko`04oookJP04odh0oooonf[ooo]Zool050Cooo]Z00?oolL0
oookJ_oonfX01OoonfX00oooZ03oo`2WoookJP02oookJP03ool0]?oo8@3ooo]Z00Oooo]Z00?oolT0
oookJ_oonfX00_oonfX00on>o`3ooo]Zool0>@02oookJP03o`3o`?oonf[oo`0701kooo]Z0ol00002
ool0>003oookJ_mi0?oooo]Z00;ooo]Z0_nho`02oookJP;oo`2l1_oonfX00om/0?oooo]ZoookJP0;
oookJP?oiOl00ooonfX2onGo00Cooo]Z0onMo`06oookJP?oo`3L0_oonfX2oong00?oE`3o0_oo]`0e
oookJP?ookL00omG0?l6oookJPCoo`3L2ooonfX3oigo00Gooo]Z0oo]0?lToookJP03of`0oooonf[o
oo]Z00_ooo]Z00?oo`2loookJ_oonfX01?oonfX2okSo047ooo]Z00?oo`2ZoookJ_oonfX00_oonfX0
0omI0?oooo]ZoookJP09oookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01_oonfX0
0oooj03ooo]Zool02`04oookJP04oole0?oonf[ooo]Zo`21o`?ooo]Z00Go0?nGo`3oj?oonf[ooo]Z
ocKo000?oookJP04o`3Soooonf[ooo]Zool0k0kooo]Z00?o0?o]oookJ_oonfX03?oonfX00ooo6P3o
7@3ooookJP05oookJP03ool0]?ooY`3ooo]Z00Wooo]Z00?o0?l9oookJ_oonfX00ooonfX01_ml0?oo
=?l0oookJ_oonf[o00_oool060Cooo]Z00?o/?l0o`3koooonfX00ooonfX01Om>0?oooo]ZoookJ_oo
nf[oo`0D00Cooo]Z00?oolL0oookJ_oonfX01?oonfX00oooZ03oo`2WoookJP03oookJP03ool0]?oo
8@3ooo]Z00Kooo]Z00?o0?nGoookJ_oonfX00ooonfX00on>o`3oo`0ioookJP02oookJP03o`3o`?oo
nf[oo`0701gooo]Z1?l000000ooo03Sooo]ZogT0o`03oookJP;o^?l00ooonfX00ooo0;cooo]Zoook
JP04oookJP;oK03o4ooonfX2ond0o`?ooo]Z0onMo`06oookJP?oo`3L0ooonfX01?oo]`3oE`3ooeL0
oomG0?l3oong03Gooo]Z0_oo]`03oeL0o`Oooo]Z1?oo0=`;oookJP?oWOl01OoonfX2ond0obGooo]Z
00?oK03ooookJ_oonfX02ooonfX00ooo0;cooo]ZoookJP04oookJP;o^?l07ooonfX002Kooo]Z00Go
o`2ZoookJ_oonf[ooo]ZoeT0o`0:oookJP03obT0oooonf[ooo]Z00?ooo]Z00?o0?o`oookJ_oonfX0
1_oonfX00oooj03ooo]Zool02`04oookJP04oole0?oonf[o087oocOo00?ooo]Z00Co0?nGo`3oj?oo
nf[o=_l04?oonfX01?l0hooooo]ZoookJ_oo0>`?oookJP03o`3okOoonf[ooo]Z00cooo]Z00?ooaX0
oad0oooonfX01?oonfX00ooo0;CoojL0oookJP09oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z00KoiOl0
ocCo0?l0;Oooo`1?o`0;oooo01P4oookJP03ok3o0?l0nooooo]Z00?ooo]Z00GoCP3ooookJ_oonf[o
oo]Zool05004oookJP03ooo70?oonf[ooo]Z00Cooo]Z00?oojP0oookJ_oo0:L00ooonfX00ooo0;Co
ob40oookJP07oookJP03ooo90?oonf[ooo]Z00;ooo]Z00?oS_l0oookJ_oo03T00_oonfX00ol0ol3o
oo]Zool01`0MoookJPCo000000Cooo]Zool0>?oonf[oN@3o1?oonfX01Onho`3ooo]ZoookJ_oonf[o
o`2l00Kooo]Z0_m/0?l<oookJP03onGo0?oonf[ooo]Z00Cooo]Z0ooUo`04oookJP?oWOl01_oonfX3
ool0g0Cooo]Z1omG0?l2oong02[ooo]Z1omG0?l6oookJP?oo`3L3?oonfX3oigo00Kooo]Z0_o]0?lU
oookJP;oK03o3?oonfX2ool0_0Kooo]Z00?o^?l0oookJ_oonfX0@_oonfX01Ooo0:[ooo]ZoookJ_oo
nf[oF@3o00_ooo]Z00?o:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP06oookJP03oooX0?oo
00_ooo]Z00Cooo]Z00?oocD0oookJ_l0POl00ooonfX01Ol0oiOooo]Zo`3oj?oonf[o=_l000oooo]Z
00Go0>?ooookJ_oonf[ooo]Zool0k00>oookJP03o`3okOoonf[ooo]Z00cooo]Z00?ooaX0oad0oooo
nfX01OoonfX00oooY`3ooo]ZoookJP08oookJP03o`3o2Ooonf[ooo]Z00Cooo]Z00GoO03oocCo0?oo
nf[o00_oool06004oookJP03ok3o0?l0nooooo]Z00?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05005
oookJP03ooo70?oonf[ooo]Z00Cooo]Z00?oojP0ool0YooonfX00ooonfX00ooo0;Coob40oookJP06
oookJP03o`3oUooonf[ooo]Z00?ooo]Z00?oS_l0ool0>OoonfX00_oonfX00ol0ol3ooo]Zool01`0L
oookJPCo000000Cooo]Zool0>?oo03SoN@3o1?oonfX01?nho`3ooo]ZoookJ_oonfX2ool0_0Kooo]Z
0_m/0?lCoookJP?ok@3o0ooonfX3oigo00Kooo]Z0ooo0=`4oookJPOoE`3o0_oo]`0ZoookJPOoE`3o
1ooonfX3ool0g0cooo]Z0onMo`05oookJP?ok@3o9OoonfX2of`0o`cooo]Z0_oo0;`6oookJP03okSo
0?oonf[ooo]Z01oooo]Z000VoookJP05ool0Z_oonf[ooo]ZoookJ_mI0?l02ooonfX00olY0?oooo]Z
oookJP02oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0oookJ_oo00/01?oonfX01Ooo=@3ooo]Z
o`21oooonf[o=ol000;ooo]Z00Go0?nGo`3oj?oonf[ooo]ZocKo000?oookJP04o`3Soooonf[ooo]Z
ool0k0oooo]Z00?o0?o]oookJ_oonfX03?oonfX00ooo6P3o7@3ooookJP04oookJP03ool0]?oonf[o
ojL000[ooo]Z00?o0?l9oookJ_oonfX00ooonfX01_ldo`3o02gooookJ_oo04oo00_oool060?ooo]Z
00?o/?l0oookJ_l0nol01?oonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Cooo]Z00?oolL0oookJ_oo
nfX01?oonfX00oooZ03oo`2WoookJP03oookJP03ool0]?oo8@3ooo]Z00Kooo]Z00?oolT0oookJ_oo
nfX00ooonfX00on>o`3ooo]Zool0>@02oookJP03o`3o`?oonf[oo`0701cooo]Z1?l00002oookJP04
ool0>?oonf[oN@3oogT0o`?ooo]Z0_nho`02oookJP;oo`2l1_oonfX2of`0oaCooo]Z0_oUo`05oook
JPCoWOl01OoonfX3ool0g0Sooo]Z2OmG0?lJoookJPWoE`3o2OoonfX4ool0g0gooo]Z0_nMo`06oook
JP?ok@3o9OoonfX2of`0o`gooo]Z00?oo`2loookJ_oonfX01OoonfX00onho`3ooo]ZoookJP13oook
JP05ool0Z_oonf[ooo]ZoookJ_mI0?l03?oonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[o
oo]Z00Kooo]Z00?oonP0ool02ooonfX01?oonfX01?oo=@3ooo]Zo`21oolgo`03oookJP04o`3oUol0
onSooo]ZocKo013ooo]Z00Co0>?ooookJ_oonf[oo`3/3_oonfX00ol0ongooo]ZoookJP0<oookJP03
oolJ0?lM0?oo0?ob00Gooo]Z00?oo`2doonW0?oonfX02OoonfX00ol0o`Wooo]ZoookJP03oookJP06
og`0ooldo`3o02gooookJ_l02oooo`0H1?oonfX00on`o`3o0?_ooookJP03oookJP05odh0oooonf[o
oo]ZoookJ_oo01@01?oonfX00oooa`3ooo]ZoookJP05oookJP03oonX0?oonf[ooo]Z00?ooo]Z00?o
ob40oookJ_oonfX01OoonfX00ol0oiOooo]ZoookJP04oookJP03ohko0?oo03Wooo]Z00;ooo]Z00?o
0?o0oookJ_oo00L06ooonfX4o`0000?ooo]Z00?oo`0hogT0oomi0?l00ooonfX2okSo00?ooo]Z00?o
o`2loookJ_oonfX01OoonfX2of`0oaCooo]Z0_o]0?l4oookJPCoWOl01OoonfX3ool0g0Sooo]Z2OmG
0?lJoookJPWoE`3o00?ookL0oookJ_oonfX01ooonfX4ool0g0gooo]Z0_nMo`06oookJP;ok@3o9_oo
nfX2of`0o`gooo]Z00?oo`2loookJ_oonfX01?oonfX2okSo02;ooo]Z000VoookJP03ool0Z_oonf[o
oo]Z00;ooo]Z00?oF@3ooookJ_oonfX02?oonfX00olY0?oooo]ZoookJP03oookJP03o`3ol?oonf[o
oo]Z00Gooo]Z00CoonP0oookJ_oonf[oo`0;0ooonfX01Ooo=@3ooo]ZoookJ_l0POoo=ol000;ooo]Z
00Go0?nGoookJ_l0onSooo]ZocKo000@oookJP04o`3Soooonf[ooo]Zool0k0oooo]Z00?o0?o]oook
J_oonfX03?oonfX00ooo6P3o7@3ooookJP04oookJP03ool0]?ooY`3ooo]Z00Wooo]Z00?o0?l9oook
J_oonfX00ooonfX01ooUo`3o=?l0o`0]oooo04oooo]Zo`0;oooo01P00ooonfX00on`o`3ooo]Zo`3k
o`03oookJP05odh0oooonf[ooo]ZoookJ_oo01@01OoonfX00oooa`3ooo]ZoookJP04oookJP03oonX
0?oo0:Oooo]Z00?ooo]Z00?oob40oookJ_oonfX01_oonfX00ooob@3ooo]ZoookJP03oookJP03ohko
0?oonf[oo`0i00;ooo]Z00?o0?o0oookJ_oo00L06ooonfX4o`0000?ooo]Z0_oo03P00ooonf[oN@3o
ogT0o`03oookJP;o^?l00_oonfX2ool0_0Kooo]Z0_m/0?lDoookJP03onGo0?o]0?ook@3o00Kooo]Z
1?nMo`04oookJPOoo`3L2_oonfX9oeL0o`SookL02OmG0?l5oong00[ooo]Z0ooo0=`>oookJP?oWOl0
1OoonfX3ond0obKooo]Z0_m/0?l=oookJP;oo`2l1_oonfX2okSo04Kooo]Z00?oo`2ZoookJ_oonfX0
0_oonfX00omI0?oooo]ZoookJP09oookJP03obT0oooonf[ooo]Z00?ooo]Z00?o0?o`oookJ_oonfX0
1OoonfX00oooj03ooo]Zool02`04oookJP04oole0?oonf[ooo]Zo`21o`?ooo]Z00Go0?nGoookJ_l0
onSooo]ZocKo000?oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`03_oonfX00ol0ongooo]ZoookJP0<
oookJP03oolJ0?lM0?oooo]Z00Gooo]Z00?oo`2doonW0?oonfX02OoonfX00ol0o`Wooo]ZoookJP03
oookJP06og`0ooldo`3ooo]Zool0Col02oooo`0H0ooonfX00on`o`3ooo]Zo`3ko`03oookJP05odh0
oooonf[ooo]ZoookJ_oo01@01OoonfX00oooa`3ooo]ZoookJP04oookJP03oonX0?oo0:Oooo]Z00Co
oo]Z00?oob40oookJ_oonfX01OoonfX00ol0oiOooo]ZoookJP04oookJP03ohko0?oo03Wooo]Z00;o
oo]Z00?o0?o0oookJ_oo00L06_oonfX4o`0000Cooo]Z00Coo`0hoookJ_mi0?ooN@3o0ooonfX2okSo
00;ooo]Z0_oo0;`7oookJP03of`0oooonf[ooo]Z01?ooo]Z0oo]0?l5oookJPCoWOl01?oonfX7ool0
g0[ooo]Z2OmG0?l8oong00WoE`3o1_oo]`0:oookJP?oo`3L3_oonfX3oigo00Gooo]Z0oo]0?lVoook
JP;oK03o3OoonfX2ool0_0Kooo]Z00?o^?l0oookJ_oonfX08_oonfX002Oooo]Z00Goo`2ZoookJ_oo
nf[ooo]ZoeT0o`0:oookJP03obT0oooonf[ooo]Z00?ooo]Z00?o0?o`oookJ_oonfX01_oonfX00ooo
j03ooo]Zool02`04oookJP04oole0?oonf[o087oocOo00?ooo]Z00Go0?nGo`3oj?oonf[ooo]ZocKo
000?oookJP04o`3Soooonf[ooo]Zool0k0oooo]Z00?o0?o]oookJ_oonfX03?oonfX00ooo6P3o7@3o
oookJP04oookJP03ool0]?oonf[oojL000[ooo]Z00?o0?l9oookJ_oonfX00ooonfX01_oUo`3o=?l0
oookJ_oo04oo00_oool060Cooo]Z00?o/?l0oookJ_l0nol00ooonfX01Om>0?oooo]ZoookJ_oonf[o
o`0D00Cooo]Z00?oolL0oookJ_oonfX01OoonfX00oooZ03oo`2WoookJP03oookJP03oolQ0?oonf[o
oo]Z00Kooo]Z00?oolT0oookJ_oonfX00ooonfX00on>o`3ooo]Zool0>@02oookJP03o`3o`?oonf[o
o`0701[ooo]Z1?l00005oookJP04ool0>?oonf[ooo]ZogT0o`Cooo]Z00Go^?l0oookJ_oonf[ooo]Z
ool0_007oookJP;oK03o5OoonfX4ond0o`Kooo]Z1?nMo`07oookJPWoo`3L2_oonfX8oeL0o`oooo]Z
2Ooo0=`?oookJP;oWOl01_oonfX2ond0obOooo]Z0_m/0?l>oookJP03ool0_?oonf[ooo]Z00Gooo]Z
00?o^?l0oookJ_oonfX0AooonfX01Ooo0:[ooo]ZoookJ_oonf[oF@3o00_ooo]Z00?o:@3ooookJ_oo
nfX00ooonfX00ol0oo3ooo]ZoookJP06oookJP03oooX0?oo00_ooo]Z00Cooo]Z00?oocD0oookJ_l0
POl00ooonfX01Ol0oiOooo]Zo`3oj?oonf[o=_l000oooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00>
oookJP03o`3okOoonf[ooo]Z00cooo]Z00?ooaX0oad0ool0oo801OoonfX00ooo0;CoojL0oookJP09
oookJP03o`3o2Ooonf[ooo]Z00Cooo]Z00Go=?l0o`0]oooonf[o00_oool06004oookJP03ok3o0?oo
nf[o0?_o00?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05005oookJP03ooo70?oonf[ooo]Z00Cooo]Z
00?oojP0ool0YooonfX01?oonfX00ooo8@3ooo]ZoookJP05oookJP03o`3oUooonf[ooo]Z00Cooo]Z
00?oS_l0ool0>OoonfX00_oonfX00ol0ol3ooo]Zool01`0IoookJPCo00001OoonfX2ool0>003oook
J_mi0?oooo]Z00?ooo]Z00Go^?l0oookJ_oonf[ooo]Zool0_007oookJP;oK03o5_oonfX4ond0o`Go
oo]Z1?nMo`07oookJPWoo`3L2_oonfX8oeL0oa3ooo]Z2Ooo0=`?oookJP;oWOl01OoonfX3ond0obOo
oo]Z0_m/0?l>oookJP03ool0_?oonf[ooo]Z00Gooo]Z00?o^?l0oookJ_oonfX08ooonfX002Oooo]Z
00Goo`2ZoookJ_oonf[ooo]ZoeT0o`0;oookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oo
nfX01_oonfX00oooj03ooo]Zool02`04oookJP05oole0?oonf[o087ooookJ_lgo`000_oonfX01Ol0
oiOooo]Zo`3oj?oonf[o=_l0013ooo]Z00Co0>?ooookJ_oonf[oo`3/3_oonfX00ol0ongooo]Zoook
JP0=oookJP03oolJ0?lM0?oooo]Z00Cooo]Z00?oo`2doookJ_ooY`002_oonfX00ol0o`Wooo]Zoook
JP02oookJP07onGo0?ldo`3o02gooookJ_oo04oo00_oool06003oookJP03ok3o0?oonf[o0?_o00Co
oo]Z00GoCP3ooookJ_oonf[ooo]Zool05004oookJP03ooo70?oonf[ooo]Z00Cooo]Z00?oojP0oook
J_oo0:L01?oonfX00ooo8@3ooo]ZoookJP06oookJP03ooo90?oonf[ooo]Z00?ooo]Z00?oS_l0oook
J_oo03T00_oonfX00ol0ol3ooo]Zool01`0IoookJPCo00001_oonfX00ooo03Sooo]ZoookJP02ogT0
o`?ooo]Z0_nho`02oookJP;oo`2l1ooonfX2of`0oaOooo]Z1?o]0?l6oookJP?oWOl03OoonfX9ool0
g0[ooo]Z3_oo0=`00ooonf[oiOl0onGo0003onGo00oooo]Z0onMo`05oookJP?ok@3o9ooonfX2of`0
o`kooo]Z0_oo0;`7oookJP03okSo0?oonf[ooo]Z04Sooo]Z00Goo`2ZoookJ_oonf[ooo]ZoeT0o`0<
oookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01_oonfX00oooj03oo`0;oookJP04
oookJP04oole0?oonf[o087oocOo00?ooo]Z00Go0?nGoookJ_l0onSooo]ZocKo000?oookJP05o`3S
oooonf[ooo]ZoookJ_oo0>`03OoonfX00ol0ongooo]ZoookJP0=oookJP03oolJ0?lM0?oooo]Z00Go
oo]Z00?oo`2doonW0?oonfX02OoonfX00ol0o`Wooo]ZoookJP03oookJP06og`0ooldo`3o02gooook
J_l02oooo`0H1?oonfX00on`o`3o0?_ooookJP03oookJP05odh0oooonf[ooo]ZoookJ_oo01@01Ooo
nfX00oooa`3ooo]ZoookJP04oookJP03oonX0?oo0:Oooo]Z00Cooo]Z00?oob40oookJ_oonfX01Ooo
nfX00ol0oiOooo]ZoookJP04oookJP03ohko0?oo03Wooo]Z00;ooo]Z00?o0?o0oookJ_oo00L06?oo
nfX4o`0000Oooo]Z00Coo`0hoookJ_mi0?ooN@3o0ooonfX2okSo00;ooo]Z0_oo0;`7oookJP;oK03o
6?oonfX4ond0o`Gooo]Z0onMo`0=oookJPWoo`3L2ooonfX>ool0g1Gooo]Z0onMo`05oookJP;ok@3o
:?oonfX2of`0o`kooo]Z0_oo0;`6oookJP;o^?l09_oonfX002Oooo]Z00?oo`2ZoookJ_oonfX00_oo
nfX00omI0?oooo]ZoookJP08oookJP03obT0oooonf[ooo]Z00?ooo]Z00?o0?o`oookJ_oonfX01Ooo
nfX01?ooj03ooo]ZoookJ_oo00/4oookJP04oole0?oonf[o087oocOo00;ooo]Z00Go0?nGoookJ_l0
onSooo]ZocKo000@oookJP04o`3Soooonf[ooo]Zool0k0oooo]Z00?o0?o]oookJ_oonfX03?oonfX0
0ooo6P3o0?oboad0o`04oookJP03ool0]?oonf[oojL000[ooo]Z00?o0?l9oookJ_oonfX00ooonfX0
1_oUo`3o=?l0o`0]oooo04oooo]Zo`0;o`Cooo]Z00?o/?l0oookJ_l0nol00ooonfX00om>0?oooo]Z
oookJP02oookJP03ool05?oonf[ooo]Z00;ooo]Z00?oolL0oookJ_oonfX01?oonfX00oooZ03ooo]Z
ool0Y`03oookJP03oolQ0?oo0;Cooo]Z00Oooo]Z00?oolT0o`3oUooonfX00ooonfX00on>o`3ooo]Z
ool0>@02oookJP03o`3o`?oonf[oo`0701Sooo]Z1?l00007oookJP;oo`0h0_oonfX2ogT0o`?ooo]Z
00Go^?l0oookJ_oonf[ooo]Zool0_008oookJP;oK03o6OoonfX4ond0o`Gooo]Z1?nMo`0BoookJP[o
o`3L3OoonfX7onGo00[ooo]Z1OoUo`06oookJP;ok@3o:?oonfX2of`0o`oooo]Z00?oo`2loookJ_oo
nfX01OoonfX2okSo04_ooo]Z00?oo`2ZoookJ_oonfX00_oonfX00omI0?oooo]ZoookJP09oookJP03
obT0oooonf[ooo]Z00?ooo]Z00?o0?o`oookJ_oonfX01OoonfX00oooj03ooo]Zool02`05oookJP03
oole0?oonf[o087o00?ooo]Z00Go0?nGoookJ_l0onSooo]ZocKo000?oookJP05o`3Soooonf[ooo]Z
oookJ_oo0>`03_oonfX00ol0ongooo]ZoookJP0<oookJP03oolJ0?oonf[o7@3o00Gooo]Z00?oo`2d
oookJ_ooY`002_oonfX00ol0o`Wooo]ZoookJP03oookJP05og`0ooldo`3ooo]Zool0Col02ol01?oo
nfX00on`o`3ooo]Zo`3ko`03oookJP03odh0oooonf[ooo]Z00;ooo]Z00?oo`0DoookJ_oonfX00_oo
nfX00oooa`3ooo]ZoookJP05oookJP03oonX0?oo0:Oooo]Z00?ooo]Z00?oob40oookJ_oonfX01_oo
nfX2o`3oU`Cooo]Z00?oS_l0oookJ_oo03T00ooonfX00ol0ol3ooo]Zool01`0GoookJPCo00002?oo
nfX2ool0>003oookJ_mi0?ooN@3o00?ooo]Z00Go^?l0oookJ_oonf[ooo]Zool0_008oookJP;oK03o
6_oonfX4ond0o`Cooo]Z1?nMo`0BoookJP_oo`3L7_oonfX5oigo00Gooo]Z0oo]0?lXoookJP;oK03o
3ooonfX00ooo0;cooo]ZoookJP05oookJP03okSo0?oonf[ooo]Z02Kooo]Z000XoookJP05ool0Z_oo
nf[ooo]ZoookJ_mI0?l02_oonfX00olY0?oooo]ZoookJP03oookJP03o`3ol?oonf[ooo]Z00Kooo]Z
00?oonP0oookJ_oo00/01?oonfX01?oo=@3ooo]Zo`21oolgo`03oookJP05o`3oUooonf[o0?oXoook
J_lfo`003ooonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00kooo]Z00?o0?o]oookJ_oonfX03OoonfX0
0ooo6P3o7@3ooookJP04oookJP03ool0]?oonf[oojL000[ooo]Z00?o0?l9oookJ_oonfX00ooonfX0
1_oUo`3o=?l0oookJ_oo04oo00_oool060?ooo]Z00Co/?l0oookJ_oonf[o0?_o0ooonfX00om>0?oo
oo]ZoookJP02oookJP03ool05?oonf[ooo]Z00;ooo]Z00?oolL0oookJ_oonfX01?oonfX00oooZ03o
oo]Zool0Y`03oookJP03oolQ0?oo0;Cooo]Z00Sooo]Z00?o0?nGoookJ_oonfX00_oonfX00on>o`3o
oo]Zool0>@02oookJP03o`3o`?oonf[oo`0701Oooo]Z1?l00009oookJP05ool0>?oonf[ooo]Zoook
J_mi0?l00ooonfX2okSo00;ooo]Z0_oo0;`8oookJP03of`0oooonf[ooo]Z01[ooo]Z1?o]0?l5oook
JPCoWOl08ooonfX9onGo00?ooo]Z1ooUo`08oookJP?ok@3o:?oonfX2of`0o`oooo]Z0_oo0;`7oook
JP03okSo0?oonf[ooo]Z00?ooo]Z00?oolT0oookJ_oonfX0A_oonfX01Ooo0:[ooo]ZoookJ_oonf[o
F@3o00_ooo]Z00?o:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP06oookJP03oooX0?oo00_o
oo]Z00Cooo]Z00?oocD0oookJ_l0POl00ooonfX00ol0oiOooo]Zo`3oj002oookJP03ocKo0?oonf[o
oo]Z00gooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00=oookJP03o`3okOoonf[ooo]Z00gooo]Z00?o
oaX0oad0ool0oo801OoonfX00ooo0;CoojL0oookJP09oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z00Ko
O03oocCo0?l0;Ooooo]Zo`0;oooo01P4oookJP03ok3o0?oonf[o0?_o00?ooo]Z00?oCP3ooookJ_oo
nfX00_oonfX00ooo01Cooo]ZoookJP02oookJP03ooo70?oonf[ooo]Z00Gooo]Z00?oojP0ool0Yooo
nfX00ooonfX00ooo8@3ooo]ZoookJP07oookJP03o`3oUooonf[ooo]Z00;ooo]Z00?oS_l0oookJ_oo
03T00ooonfX00ol0ol3ooo]Zool01`0FoookJPCo00002_oonfX01?oo03Sooo]ZoookJ_mi0?l3oook
JP;o^?l00_oonfX2ool0_0Sooo]Z0_m/0?lLoookJP?ok@3o1OoonfX4oigo033ooo]Z1onMo`08oook
JP;ok@3o:OoonfX2of`0o`oooo]Z0_oo0;`6oookJP;o^?l0:OoonfX002Sooo]Z00?oo`2ZoookJ_oo
nfX00_oonfX00omI0?oooo]ZoookJP07oookJP03obT0oooonf[ooo]Z00?ooo]Z00?o0?o`oookJ_oo
nfX01_oonfX00oooj03ooo]Zool02`05oookJP04oole0?oonf[o087oocOo00;ooo]Z00Go0?nGoook
J_l0onSooo]ZocKo000@oookJP04o`3Soooonf[ooo]Zool0k0oooo]Z00?o0?o]oookJ_oonfX03?oo
nfX00ooo6P3o0?oboad0o`05oookJP03ool0]?oonf[oojL000Wooo]Z00?o0?l9oookJ_oonfX00ooo
nfX01ooUo`3o=?l0o`0]oooonf[oo`1?o`0;oooo01P00ooonfX01?n`o`3ooo]ZoookJ_l0nol3oook
JP03odh0oooonf[ooo]Z00;ooo]Z00Goo`0DoookJ_oonf[ooo]Zooo70007oookJP03oonX0?oonf[o
o`2W00?ooo]Z00?oob40ool0]?oonfX02?oonfX00ol0oiOooo]ZoookJP02oookJP03ohko0?oonf[o
o`0i00;ooo]Z00?o0?o0oookJ_oo00L05_oonfX5o`0000Wooo]Z00Coo`0hoookJ_oonf[ooo]Z0_mi
0?l3oookJP;o^?l00_oonfX2ool0_0Oooo]Z0_m/0?lNoookJPCok@3o1OoonfX9oigo01Oooo]Z3ooU
o`0<oookJP?ok@3o:OoonfX2of`0oa3ooo]Z00?oo`2loookJ_oonfX01OoonfX2okSo00Kooo]Z00?o
olT0oookJ_oonfX00_oob@14oookJP03ool0Z_oonf[ooo]Z00;ooo]Z00?oF@3ooookJ_oonfX02?oo
nfX00olY0?oooo]ZoookJP03oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0ool02ooonfX01Ooo
nfX00ooo=@3ooo]Zo`21o`03oookJP05o`3oUooonf[o0?oXoookJ_lfo`003ooonfX01Ol0hooooo]Z
oookJ_oonf[oo`3/00kooo]Z00?o0?o]oookJ_oonfX03?oonfX00ooo6P3ooo]Zoad0o`06oookJP03
ool0]?ooY`3ooo]Z00Wooo]Z00?o0?l9oookJ_oonfX00ooonfX01_ml0?oo=?l0oookJ_oonf[o00_o
ool060Cooo]Z00?o/?l0oookJ_l0nol00ooonfX00om>0?oooo]ZoookJP02oookJP03ool05?oonf[o
oo]Z00;ooo]Z00?oolL0oookJ_oonfX01?oonfX00oooZ03ooo]Zool0Y`04oookJP03oolQ0?oonf[o
oo]Z00Oooo]Z00?o0?nGoookJ_oonfX00_oonfX00on>o`3ooo]Zool0>@03oookJP03o`3o`?oonf[o
o`0701Gooo]Z1Ol0000:oookJP03ool0>?oonf[ooo]Z00;oN@3o0ooonfX2okSo00;ooo]Z0_oo0;`8
oookJP03of`0oooonf[ooo]Z01cooo]Z1?o]0?l5oookJPWoWOl07ooonfX8oigo00cooo]Z0oo]0?lY
oookJP;oK03o4?oonfX00ooo0;cooo]ZoookJP05oookJP03okSo0?oonf[ooo]Z00Sooo]Z0_mi0?lO
oookJP00:?oonfX00ooo0:[ooo]ZoookJP02oookJP03oeT0oooonf[ooo]Z00Sooo]Z00?o:@3ooook
J_oonfX00ooonfX00ol0oo3ooo]ZoookJP05oookJP04oooX0?oonf[ooo]Zool02`Cooo]Z00CoocD0
oookJ_l0POoo=ol00_oonfX01_l0oiOooo]ZoookJ_l0onSooo]ZocKo00oooo]Z00Go0>?ooookJ_oo
nf[ooo]Zool0k00>oookJP03o`3okOoonf[ooo]Z00gooo]Z00?ooaX0oad0oooonfX01?oonfX00ooo
0;Cooo]ZoonW000:oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z00KoiOl0ocCo0?l0;Oooo`1?oookJ_l0
2ol4oookJP03ok3o0?oonf[o0?_o00Cooo]Z00GoCP3ooookJ_oonf[ooo]Zool05004oookJP03ooo7
0?oonf[ooo]Z00Cooo]Z00CoojP0oookJ_oonf[oo`2W0ooonfX00ooo8@3ooo]ZoookJP08oookJP03
o`3oUooonf[ooo]Z00;ooo]Z00?oS_l0oookJ_oo03T00_oonfX2o`3o`003ool01ooonf[ooo]Z01?o
oo]Z1?l0000;oookJP;oo`0h0ooonfX2ogT0o`?ooo]Z00Co^?l0oookJ_oonf[ooo]Z0_oo0;`7oook
JP;oK03o8?oonfX4ond0o`[ooo]Z3_nMo`07oookJPooiOl02?oonfX6ond0ob_ooo]Z00?oK03ooook
J_oonfX03ooonfX00ooo0;cooo]ZoookJP05oookJP03okSo0?oonf[ooo]Z00Gooo]Z1?oob@16oook
JP03ool0Z_oonf[ooo]Z00;ooo]Z00?oF@3ooookJ_oonfX02OoonfX00olY0?oooo]ZoookJP03oook
JP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0oookJ_oo00/01OoonfX00ooo=@3ooo]Zo`21o`03oook
JP03o`3oUooonf[o0?oX00;ooo]Z00?o=_l0oookJ_oonfX03?oonfX00ol0hooooo]ZoookJP02oook
JP03ool0k?oonf[ooo]Z00_ooo]Z00?o0?o]oookJ_oonfX03OoonfX00ooo6P3o7@3oo`3olP05oook
JP03ool0]?ooY`3ooo]Z00[ooo]Z00?o0?l9oookJ_oonfX00ooonfX01Oml0?oo=?l0oookJ_oo04oo
00_o00Cooo]Z00?o/?l0oookJ_l0nol01?oonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Cooo]Z00?o
olL0oookJ_oonfX01OoonfX00oooZ03ooo]Zool0Y`04oookJP03oolQ0?oonf[ooo]Z00Oooo]Z00?o
0?nGoookJ_oonfX00_oonfX00on>o`3ooo]Zool0>@03oookJP;o0?o000?oo`07oookJ_oonfX04_oo
nfX4o`0000cooo]Z0_oo03P2oookJP;oN@3o0ooonfX01?nho`3ooo]ZoookJ_oonfX2ool0_0Oooo]Z
0_m/0?lPoookJPCok@3o2_oonfX>oigo00[ooo]Z1onMo`0>oookJPKok@3o:ooonfX00om/0?oooo]Z
oookJP0?oookJP03ool0_?oonf[ooo]Z00Gooo]Z00?o^?l0oookJ_oonfX02?oonfX00omi0?oooo]Z
oookJP0OoookJP009OoonfX01Ol0odgooo]ZoookJ_oonf[oo`2Z00?ooo]Z00?oF@3ooookJ_oonfX0
2?oonfX00olY0?oooo]ZoookJP03oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0oookJ_oo00/0
1OoonfX00ooo=@3ooo]Zo`21o`03oookJP05o`3oUooonf[o0?oXoookJ_lfo`004?oonfX01?l0hooo
oo]ZoookJ_oo0>`?oookJP03o`3okOoonf[ooo]Z00cooo]Z00?ooaX0o`3ol_lM0?l01OoonfX00ooo
0;Cooo]ZoonW000:oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z00OoiOl0oookJ_ldo`3ooo]Zool0Col0
2oooo`0H00?ooo]Z00Co/?l0oookJ_oonf[o0?_o1?oonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Co
oo]Z00?oolL0oookJ_oonfX01?oonfX01?ooZ03ooo]ZoookJ_oo0:L3oookJP03oolQ0?oonf[ooo]Z
00Sooo]Z00?o0?nGoookJ_oonfX00_oonfX00on>o`3ooo]Zool0>@03oookJP03o`3o`?oo00Oooo]Z
01?ooo]Z1?l0000=oookJP;oo`0h0ooonfX01?mi0?oooo]ZoookJ_oonfX2okSo00?ooo]Z0ooo0;`6
oookJP;oK03o8_oonfX9ond0o`oooo]Z1_nMo`0>onGo00[ok@3o;ooonfX2of`0oa3ooo]Z0_oo0;`7
oookJP03okSo0?oonf[ooo]Z00Gooo]Z1Ooob@13oookJP05o`3oCOoonf[ooo]ZoookJ_oo0:X00ooo
nfX00omI0?oooo]ZoookJP09oookJP03obT0oooonf[ooo]Z00?ooo]Z00?o0?o`oookJ_oonfX01_oo
nfX00oooj03oo`0;oookJP04oookJP04oole0?oonf[o=ol0o`21o`?ooo]Z00Go0?nGoookJ_l0onSo
oo]ZocKo000?oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`03_oonfX00ol0ongooo]ZoookJP0<oook
JP03oolJ0?oonf[o7@3o00Kooo]Z00?oo`2doonW0?oonfX02OoonfX00ol0o`Wooo]ZoookJP03oook
JP06og`0ooldo`3o02gooookJ_l02oooo`0H1?oonfX00on`o`3ooo]Zo`3ko`04oookJP05odh0oooo
nf[ooo]ZoookJ_oo01@01?oonfX00oooa`3ooo]ZoookJP05oookJP03oonX0?oonf[oo`2W00?ooo]Z
00?oob40ool0]?oonfX02?oonfX00ol0oiOooo]ZoookJP02oookJP03ohko0?oonf[oo`0i00Cooo]Z
00?o0?o0ool01ooonfX04_oonfX4o`0000kooo]Z0_oo03P2oookJP04ogT0oooonf[ooo]ZoookJP;o
^?l00ooonfX3ool0_0Kooo]Z0_m/0?lRoookJPWok@3o3ooonfX:oigo00_ooo]Z2_o]0?l_oookJP;o
K03o4?oonfX2ool0_0Kooo]Z0_nho`0:oookJP03ogT0oooonf[ooo]Z023ooo]Z000UoookJP05o`3o
COoonf[ooo]ZoookJ_oo0:X01?oonfX00omI0?oooo]ZoookJP07oookJP03obT0oooonf[ooo]Z00?o
oo]Z00?o0?o`oookJ_oonfX01_oonfX00oooj03ooo]Zool02`05oookJP04oole0?oonf[o087oocOo
00;ooo]Z00Ko0?nGoookJ_oonf[o0?oXoookJ_lfo`0?oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`0
3_oonfX00ol0ongooo]ZoookJP0=oookJP03oolJ0?lM0?oooo]Z00Cooo]Z00?oo`2doookJ_ooY`00
2_oonfX00ol0o`Wooo]ZoookJP03oookJP06onGo0?oonf[o=?l0oookJ_oo04oo00_o1?oonfX01?n`
o`3ooo]ZoookJ_l0nol3oookJP03odh0oooonf[ooo]Z00;ooo]Z00?oo`0DoookJ_oonfX00_oonfX0
0oooa`3ooo]ZoookJP04oookJP04oonX0?oonf[ooo]Zool0Y`?ooo]Z00?oob40oookJ_oonfX02?oo
nfX00ol0oiOooo]ZoookJP02oookJP03ohko0?oonf[oo`0i00?ooo]Z00?o0?o0ool01ooonfX04_oo
nfX4o`0000oooo]Z0_oo03P2oookJP;oN@3o0ooonfX2okSo00Cooo]Z0_oo0;`6oookJP?oK03o:?oo
nfX?ond0o`_ooo]Z2Oo]0?l2onGo03Gooo]Z0_m/0?lAoookJP03ool0_?oonf[ooo]Z00Gooo]Z0_nh
o`07oookJPKoolT0@ooonfX01Ol0odgooo]ZoookJ_oonf[oo`2Z00Cooo]Z00?oF@3ooookJ_oonfX0
2?oonfX00olY0?oooo]ZoookJP03oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0ool02ooonfX0
1OoonfX00ooo=@3ooo]Zo`21o`03oookJP03o`3oUooonf[o0?oX00;ooo]Z00?o=_l0oookJ_oonfX0
3?oonfX00ol0hooooo]ZoookJP02oookJP03ool0k?oonf[ooo]Z00_ooo]Z00?o0?o]oookJ_oonfX0
3OoonfX00ooo6P3o7@3oo`3olP05oookJP03ool0]?oonf[oojL000[ooo]Z00?o0?l9oookJ_oonfX0
0ooonfX01Oml0?oo=?l0oookJ_oonf[o00_o00Gooo]Z00?o/?l0oookJ_l0nol00ooonfX00om>0?oo
oo]ZoookJP02oookJP03ool05?oonf[ooo]Z00;ooo]Z00?oolL0oookJ_oonfX01OoonfX00oooZ03o
oo]Zool0Y`03oookJP03oolQ0?oo0;Cooo]Z00Sooo]Z00?o0?nGoookJ_oonfX00_oonfX00on>o`3o
oo]Zool0>@04oookJP03o`3o`?oo00Oooo]Z017ooo]Z1?l0000@oookJP03ool0>?oonf[ooo]Z00;o
N@3o0ooonfX2okSo00Cooo]Z0_oo0;`6oookJP?oK03o:?oonfX?ond0o`_ooo]Z2_o]0?lgoookJP;o
K03o4OoonfX00ooo0;cooo]ZoookJP05oookJP03okSo0?oonf[ooo]Z00Wooo]Z00?oN@3ooookJ_oo
nfX08OoonfX002Gooo]Z00Go0?m=oookJ_oonf[ooo]Zool0ZP04oookJP03oeT0oooonf[ooo]Z00So
oo]Z00?o:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP05oookJP04oooX0?oonf[ooo]Zool0
2`Gooo]Z00?oocD0oookJ_l0POl00_oonfX01_l0oiOooo]ZoookJ_l0onSooo]ZocKo00oooo]Z00Go
0>?ooookJ_oonf[ooo]Zool0k00?oookJP03o`3okOoonf[ooo]Z00cooo]Z00?ooaX0oookJ_lM0?l0
1OoonfX00ooo0;Cooo]ZoonW000:oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z00OoiOl0oookJ_ldo`3o
02goool0Cooonf[o00_o00Cooo]Z00Co/?l0oookJ_oonf[o0?_o0ooonfX00om>0?oooo]ZoookJP02
oookJP05ool05?oonf[ooo]ZoookJ_ooa`001ooonfX00oooZ03ooo]Zool0Y`04oookJP03oolQ0?oo
nf[ooo]Z00Sooo]Z00?o0?nGoookJ_oonfX00_oonfX00on>o`3ooo]Zool0>@03oookJP03o`3o`?oo
00Oooo]Z017ooo]Z1?l0000AoookJP04ool0>?oonf[ooo]ZoookJP;oN@3o0ooonfX00onho`3ooo]Z
oookJP03oookJP;oo`2l1ooonfX3of`0ocCooo]Z2oo]0?lnoookJP;oK03o4OoonfX2ool0_0Oooo]Z
00?o^?l0oookJ_oonfX01_oonfX8ooo904;ooo]Z00Go0?m=oookJ_oonf[ooo]Zool0ZP04oookJP03
oeT0oooonf[ooo]Z00Wooo]Z00?o:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP05oookJP03
oooX0?oonf[oo`0;00Gooo]Z00?oocD0oookJ_l0POl00ooonfX01_l0oiOooo]ZoookJ_l0onSooo]Z
ocKo00oooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00>oookJP03o`3okOoonf[ooo]Z00cooo]Z00Co
oaX0oookJ_lM0?oo0?ob1OoonfX00ooo0;CoojL0oookJP09oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z
00KoO03ooookJ_ldo`3ooo]Zool0Col02ol4oookJP04ok3o0?oonf[ooo]Zo`3ko`?ooo]Z00?oCP3o
oookJ_oonfX00_oonfX00ooo01Cooo]ZoookJP02oookJP03ooo70?oonf[ooo]Z00Gooo]Z00?oojP0
ool0YooonfX00ooonfX00ooo8@3oo`2doookJP08oookJP03o`3oUooonf[ooo]Z00;ooo]Z00?oS_l0
oookJ_oo03T01?oonfX00ol0ol3oo`07oookJP0@oookJPCo00004OoonfX2ool0>0;ooo]Z0_mi0?l3
oookJP03okSo0?oonf[ooo]Z00?ooo]Z0_oo0;`7oookJP?oK03o=?oonfX;ond0ocoooo]Z0_m/0?lA
oookJP;oo`2l1_oonfX2okSo00[ooo]Z0_mi0?lToookJP009_oonfX01Ol0odgooo]ZoookJ_oonf[o
o`2Z00?ooo]Z00?oF@3ooookJ_oonfX02?oonfX00olY0?oooo]ZoookJP03oookJP03o`3ol?oonf[o
oo]Z00Kooo]Z00?oonP0oookJ_oo00/01OoonfX01?oo=@3ooo]Zo`21oolgo`02oookJP06o`3oUooo
nf[ooo]Zo`3oj?oonf[o=_l03ooonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00kooo]Z00?o0?o]oook
J_oonfX03OoonfX00ooo6P3o7@3ooookJP04oookJP04ool0]?oonf[ooo]ZoonW00[ooo]Z00?o0?l9
oookJ_oonfX00_oonfX01ooUo`3ooo]ZocCo0?oonf[oo`1?o`0;oooo01P00ooonfX01?n`o`3ooo]Z
oookJ_l0nol4oookJP03odh0oooonf[ooo]Z00;ooo]Z00Goo`0DoookJ_oonf[ooo]Zooo70007oook
JP03oonX0?oonf[oo`2W00Cooo]Z00?oob40oookJ_oonfX02?oonfX00ol0oiOooo]ZoookJP02oook
JP03ohko0?oonf[oo`0i00?ooo]Z00?o0?o0ool01ooonfX04?oonfX4o`0001;ooo]Z0_oo03P3oook
JP04ogT0oooonf[ooo]ZoookJP;o^?l01OoonfX2ool0_0Sooo]Z0om/0?mhoookJP;oK03o4_oonfX0
0ooo0;cooo]ZoookJP06oookJP03okSo0?oonf[ooo]Z00Kooo]Z2_oob@12oookJP05o`3oCOoonf[o
oo]ZoookJ_oo0:X00ooonfX00omI0?oooo]ZoookJP09oookJP03obT0oooonf[ooo]Z00?ooo]Z00?o
0?o`oookJ_oonfX01_oonfX00oooj03oo`0;oookJP05oookJP03oole0?oonf[o087o00?ooo]Z00Go
0?nGoookJ_l0onSooo]ZocKo000?oookJP03o`3Soooonf[ooo]Z00;ooo]Z00?oo`3/oookJ_oonfX0
2ooonfX00ol0ongooo]ZoookJP0=oookJP03oolJ0?lM0?oo0?ob00Gooo]Z00?oo`2doookJ_ooY`00
2_oonfX00ol0o`Wooo]ZoookJP03oookJP06og`0ooldo`3ooo]ZoookJ_l02oooo`0H1?oonfX00on`
o`3ooo]Zo`3ko`04oookJP03odh0oooonf[ooo]Z00;ooo]Z00Goo`0DoookJ_oonf[ooo]Zooo70007
oookJP03oonX0?oonf[oo`2W00Cooo]Z00?oob40ool0]?oonfX02?oonfX00ol0oiOooo]ZoookJP02
oookJP03ohko0?oonf[oo`0i00Cooo]Z00?o0?o0ool01ooonfX03ooonfX4o`0001?ooo]Z0_oo03P2
oookJP04ogT0oooonf[ooo]ZoookJP;o^?l01OoonfX2ool0_0Sooo]Z0om/0?mioookJP;oK03o4_oo
nfX00ooo0;cooo]ZoookJP05oookJP03okSo0?oonf[ooo]Z00Wooo]Z00?oN@3ooookJ_oonfX09?oo
nfX002Kooo]Z00Go0?m=oookJ_oonf[ooo]Zool0ZP04oookJP03oeT0oooonf[ooo]Z00Oooo]Z00?o
:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP06oookJP03oooX0?oonf[oo`0;00Kooo]Z00?o
ocD0oookJ_l0POl00_oonfX01_l0oiOooo]ZoookJ_l0onSooo]ZocKo00oooo]Z00Go0>?ooookJ_oo
nf[ooo]Zool0k00>oookJP03o`3okOoonf[ooo]Z00gooo]Z00?ooaX0oookJ_lM0?l01OoonfX00ooo
0;Cooo]ZoonW000:oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z00OoiOl0oookJ_ldo`3ooo]Zool0Col0
2oooo`0H00?ooo]Z00Co/?l0oookJ_oonf[o0?_o1?oonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Co
oo]Z00?oolL0oookJ_oonfX01?oonfX01?ooZ03ooo]ZoookJ_oo0:L4oookJP03oolQ0?oonf[ooo]Z
00Sooo]Z00?o0?nGoookJ_oonfX00_oonfX00on>o`3ooo]Zool0>@03oookJP03o`3o`?oo00Oooo]Z
00oooo]Z1?l0000DoookJP;oo`0h0_oonfX2ogT0o`?ooo]Z0onho`04oookJP;oo`2l2OoonfX3of`0
og?ooo]Z0_m/0?lBoookJP;oo`2l1ooonfX2okSo00Wooo]Z2?oob@000ooonf[oo`0hoookJP11oook
JP05o`3oCOoonf[ooo]ZoookJ_oo0:X01?oonfX00omI0?oooo]ZoookJP08oookJP03obT0oooonf[o
oo]Z00?ooo]Z00?o0?o`oookJ_oonfX01_oonfX00oooj03oo`0;oookJP05oookJP03oole0?oonf[o
087o00?ooo]Z00Ko0?nGoookJ_oonf[o0?oXoookJ_lfo`0>oookJP03o`3Soooonf[ooo]Z00;ooo]Z
00?oo`3/oookJ_oonfX02ooonfX00ol0ongooo]ZoookJP0=oookJP04oolJ0?oonf[o7@3oo`3olPGo
oo]Z00?oo`2doookJ_ooY`002_oonfX00ol0o`Wooo]ZoookJP03oookJP06og`0ooldo`3ooo]Zoook
J_l02oooo`0H1?oonfX00on`o`3ooo]Zo`3ko`04oookJP05odh0oooonf[ooo]ZoookJ_oo01@01?oo
nfX00oooa`3ooo]ZoookJP05oookJP03oonX0?oonf[oo`2W00Cooo]Z00?oob40oookJ_oonfX02?oo
nfX00ol0oiOooo]ZoookJP02oookJP03ohko0?oonf[oo`0i00Cooo]Z00?o0?o0ool01ooonfX03_oo
nfX4o`0001Gooo]Z0_oo03P00ooonf[oN@3oogT0o`03oookJP?o^?l01?oonfX2ool0_0Wooo]Z0om/
0?mdoookJP;oK03o4_oonfX2ool0_0Oooo]Z00?o^?l0oookJ_oonfX02OoonfX00omi0?oooo]Zoook
JP05oookJP03ool0>?oonf[ooo]Z01gooo]Z000VoookJP05o`3oCOoonf[ooo]ZoookJ_oo0:X01?oo
nfX00omI0?oooo]ZoookJP08oookJP03obT0oooonf[ooo]Z00?ooo]Z00?o0?o`oookJ_oonfX01Ooo
nfX01?ooj03ooo]ZoookJ_oo00/5oookJP03oole0?oonf[o087o00;ooo]Z00Co0?nGoookJ_oonf[o
0?oX0_oonfX00olfo`3ooo]ZoookJP0=oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`03_oonfX00ol0
ongooo]ZoookJP0=oookJP03oolJ0?l0oo;o7@3o00Cooo]Z00Coo`2doookJ_oonf[oojL02_oonfX0
0ol0o`Wooo]ZoookJP02oookJP07onGo0?oonf[o=?l0oookJ_oo04oooo]Zo`0;o`03oookJP05ok3o
0?oonf[ooo]ZoookJ_l0nol01?oonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Cooo]Z00?oolL0oook
J_oonfX01?oonfX01?ooZ03ooo]ZoookJ_oo0:L4oookJP03oolQ0?oonf[ooo]Z00Sooo]Z00?o0?nG
oookJ_oonfX00_oonfX00on>o`3ooo]Zool0>@04oookJP;oo`073_oonfX4o`0001Kooo]Z0_oo03P2
oookJP;oN@3o1?oonfX2okSo00Cooo]Z0_oo0;`:oookJP?oK03oK_oonfX2of`0oa?ooo]Z00?oo`2l
oookJ_oonfX01_oonfX00onho`3ooo]ZoookJP08oookJPKoolT00_oonfX2ool0>4?ooo]Z00Go0?m=
oookJ_oonf[ooo]Zool0ZP04oookJP03oeT0oooonf[ooo]Z00Wooo]Z00?o:@3ooookJ_oonfX00ooo
nfX00ol0oo3ooo]ZoookJP05oookJP03oooX0?oonf[oo`0;00Kooo]Z00?oocD0ocOo0?l0POl00_oo
nfX01_l0oiOooo]ZoookJ_l0onSooo]ZocKo00oooo]Z00?o0>?ooookJ_oonfX00_oonfX00ooo0>co
oo]ZoookJP0;oookJP03o`3okOoonf[ooo]Z00gooo]Z00?ooaX0oookJ_lM0?l01OoonfX00ooo0;Co
oo]ZoonW000:oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z00OoO03ooookJ_ldo`3ooo]Zool0Col02ooo
o`0H00?ooo]Z00Co/?l0oookJ_oonf[o0?_o1?oonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Cooo]Z
00?oolL0oookJ_oonfX01OoonfX00oooZ03ooo]Zool0Y`04oookJP03oolQ0?oonf[ooo]Z00Sooo]Z
00?o0?nGoookJ_oonfX00_oonfX00on>o`3ooo]Zool0>@04oookJP03o`3o`?oo00Ooo`0700gooo]Z
1?l0000GoookJP03ool0>?oonf[ooo]Z00;oN@3o1?oonfX2okSo00Cooo]Z0_oo0;`:oookJP?oK03o
KooonfX2of`0oa?ooo]Z00?oo`2loookJ_oonfX01OoonfX2okSo00[ooo]Z0_mi0?l6oookJP;oo`0h
8?oonfX002Kooo]Z00?o0?m=oookJ_oonfX00_oonfX01Ooo0:[ooo]ZoookJ_oonf[oF@3o00[ooo]Z
00?o:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP06oookJP03oooX0?oonf[oo`0;00Kooo]Z
00?oocD0oookJ_l0POl00_oonfX01_l0oiOooo]ZoookJ_l0onSooo]ZocKo00oooo]Z00Go0>?ooook
J_oonf[ooo]Zool0k00>oookJP03o`3okOoonf[ooo]Z00gooo]Z00?ooaX0oookJ_lM0?l01OoonfX0
1?oo0;Cooo]ZoookJ_ooY`09oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z00OoiOl0oookJ_ldo`3ooo]Z
ool0Col02oooo`0H00?ooo]Z00Go/?l0oookJ_oonf[ooo]Zo`3ko`03oookJP03odh0oooonf[ooo]Z
00;ooo]Z00Goo`0DoookJ_oonf[ooo]Zooo70007oookJP04oonX0?oonf[ooo]Zool0Y`Cooo]Z00?o
ob40oookJ_oonfX02?oonfX00ol0oiOooo]ZoookJP02oookJP03ohko0?oonf[oo`0i00Cooo]Z00?o
0?o0ool01ooonfX03?oonfX4o`0001Sooo]Z0_oo03P2oookJP03ogT0oooonf[ooo]Z00?ooo]Z0_nh
o`04oookJP;oo`2l2ooonfX3of`0ofWooo]Z0_m/0?lCoookJP;oo`2l2?oonfX00onho`3ooo]Zoook
JP08oookJPGoolT00_oonfX2ool0>4Kooo]Z00Go0?m=oookJ_oonf[ooo]Zool0ZP03oookJP03oeT0
oooonf[ooo]Z00Wooo]Z00?o:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP06oookJP03oooX
0?oo00_ooo]Z00Gooo]Z00?oocD0oookJ_l0POl00ooonfX01_l0oiOooo]ZoookJ_l0onSooo]ZocKo
00kooo]Z00?o0>?ooookJ_oonfX00_oonfX00ooo0>cooo]ZoookJP0;oookJP03o`3okOoonf[ooo]Z
00gooo]Z00CooaX0oookJ_lM0?oo0?ob1OoonfX00ooo0;Cooo]ZoonW000:oookJP03o`3o2Ooonf[o
oo]Z00?ooo]Z00KoO03oocCo0?oonf[ooo]Zo`0;oooo01P4oookJP04ok3o0?oonf[ooo]Zo`3ko`?o
oo]Z00?oCP3ooookJ_oonfX00_oonfX01Ooo01Cooo]ZoookJ_oonf[oolL000Sooo]Z00?oojP0oook
J_oo0:L01?oonfX00ooo8@3ooo]ZoookJP08oookJP03o`3oUooonf[ooo]Z00;ooo]Z00?oS_l0oook
J_oo03T01OoonfX00ol0ol3oo`07oookJP0;oookJPCo00006?oonfX2ool0>0;ooo]Z00?oN@3ooook
J_oonfX00ooonfX2okSo00Cooo]Z0_oo0;`;oookJP?oK03oJ_oonfX2of`0oa?ooo]Z0_oo0;`7oook
JP03okSo0?oonf[ooo]Z00Wooo]Z00?oN@3ooookJ_oonfX01?oonfX2ool0>2;ooo]Z000WoookJP05
o`3oCOoonf[ooo]ZoookJ_oo0:X01?oonfX00omI0?oooo]ZoookJP07oookJP03obT0oooonf[ooo]Z
00Cooo]Z00?o0?o`oookJ_oonfX01OoonfX00oooj03ooo]Zool02`06oookJP03oole0?oonf[o087o
00;ooo]Z00Co0?nGoookJ_oonf[o0?oX0_oonfX00olfo`3ooo]ZoookJP0=oookJP05o`3Soooonf[o
oo]ZoookJ_oo0>`03_oonfX00ol0ongooo]ZoookJP0=oookJP03oolJ0?oonf[o7@3o00Cooo]Z00Co
o`2doookJ_oonf[oojL02_oonfX00ol0o`Wooo]ZoookJP02oookJP08og`0oooonf[ooo]ZocCo0?oo
nf[oo`1?o`0;oooo01P3oookJP04ok3o0?oonf[ooo]Zo`3ko`Cooo]Z00?oCP3ooookJ_oonfX00_oo
nfX01Ooo01Cooo]ZoookJ_oonf[oolL000Oooo]Z0_ooZ0000ooonf[oo`2WoookJP03oookJP03oolQ
0?oonf[ooo]Z00Sooo]Z00?o0?nGoookJ_oonfX00_oonfX00on>o`3ooo]Zool0>@04oookJP03o`3o
`?oo00Oooo]Z00_ooo]Z1?l0000JoookJP03ool0>?oonf[ooo]Z00;oN@3o1OoonfX3okSo00?ooo]Z
0ooo0;`;oookJP?oK03oHooonfX3of`0oaCooo]Z00?oo`2loookJ_oonfX01_oonfX2okSo00[ooo]Z
1?oob@02oookJP;oo`0hB?oonfX01Ol0odgooo]ZoookJ_oonf[oo`2Z00Cooo]Z00?oF@3ooookJ_oo
nfX02?oonfX00olY0?oooo]ZoookJP04oookJP03o`3ol?oonf[ooo]Z00Gooo]Z00?oonP0ool02ooo
nfX01_oonfX00ooo=@3o=ol0o`21o`02oookJP06o`3oUooonf[ooo]Zo`3oj?oonf[o=_l03ooonfX0
0ol0hooooo]ZoookJP02oookJP03ool0k?oonf[ooo]Z00_ooo]Z00?o0?o]oookJ_oonfX03OoonfX0
1?oo6P3ooo]Zoad0ool0oo84oookJP04ool0]?oonf[ooo]ZoonW00[ooo]Z00?o0?l9oookJ_oonfX0
0_oonfX00oml0?oooo]ZocCo0002oookJP03o`0;oooo01Sooo]Z00?ooo]Z00?o/?l0oookJ_l0nol0
1?oonfX00om>0?oooo]ZoookJP02oookJP05ool05?oonf[ooo]ZoookJ_ooa`002?oonfX00oooZ03o
oo]Zool0Y`04oookJP03oolQ0?oonf[ooo]Z00Sooo]Z00?o0?nGoookJ_oonfX00_oonfX00on>o`3o
oo]Zool0>@05oookJP03o`3o`?oo00Oooo]Z00[ooo]Z1?l0000JoookJP;oo`0h00?ooo]ZogT0oomi
0?l01OoonfX3okSo00?ooo]Z0ooo0;`;oookJP?oK03oI?oonfX3of`0oaCooo]Z00?oo`2loookJ_oo
nfX01OoonfX2okSo00_ooo]Z00?oN@3ooookJ_oonfX00ooonfX2ool0>2Cooo]Z000WoookJP03o`3o
COoonf[ooo]Z00;ooo]Z00Goo`2ZoookJ_oonf[ooo]ZoeT0o`0:oookJP03obT0oooonf[ooo]Z00?o
oo]Z00?o0?o`oookJ_oonfX01_oonfX00oooj03ooo]Zool02`05oookJP06oole0?oonf[o=ol0o`21
oooonf[o0?nG0ooonfX00ol0onSooo]ZocKo000?oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`03_oo
nfX00ol0ongooo]ZoookJP0>oookJP03oolJ0?lM0?oooo]Z00Cooo]Z00Coo`2doookJ_oonf[oojL0
2_oonfX00ol0o`Wooo]ZoookJP02oookJP08og`0oooonf[o=?l0oookJ_oo04oooo]Zo`0;oooo01P2
oookJP05ok3o0?oonf[ooo]ZoookJ_l0nol01?oonfX00om>0?oooo]ZoookJP02oookJP05ool05?oo
nf[ooo]ZoookJ_ooa`002?oonfX00oooZ03ooo]Zool0Y`03oookJP03ool0]?oo8@3ooo]Z00Wooo]Z
00?o0?nGoookJ_oonfX00_oonfX2ohko0003ool0>Ooonf[ooo]Z00;ooo]Z00?o0?o0ool01ooo00L0
2_oonfX5o`0001[ooo]Z0_oo03P2oookJP;oN@3o1_oonfX2okSo00Cooo]Z0_oo0;`<oookJP?oK03o
FooonfX5of`0oaGooo]Z0_oob@06oookJP?o^?l02ooonfX2ooo900?ooo]Z0_oo03Q:oookJP03o`3o
COoonf[ooo]Z00;ooo]Z00Goo`2ZoookJ_oonf[ooo]ZoeT0o`0;oookJP03obT0oooonf[ooo]Z00?o
oo]Z00?o0?o`oookJ_oonfX01_oonfX00oooj03oo`0;oookJP05oookJP03oole0?lgo`3o087o00;o
oo]Z00Oo0?nGoookJ_oonf[ooo]Zo`3oj?oonf[o=_l000kooo]Z00?o0>?ooookJ_oonfX00_oonfX0
0ooo0>cooo]ZoookJP0;oookJP03o`3okOoonf[ooo]Z00kooo]Z00?ooaX0oad0ool0oo801OoonfX0
0ooo0;Cooo]ZoonW000:oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z00OoO03oo`0]ooldo`3ooo]Zool0
Col02oooo`0H00?ooo]Z00Co/?l0oookJ_oonf[o0?_o1?oonfX00om>0?oooo]ZoookJP02oookJP05
ool05?oonf[ooo]ZoookJ_ooa`002?oonfX00oooZ03ooo]Zool0Y`04oookJP03oolQ0?oonf[ooo]Z
00Sooo]Z00?o0?nGoookJ_oonfX00_oonfX2ohko0003ool0>Ooonf[ooo]Z00?ooo]Z00?o0?o0ool0
1ooo00L02OoonfX5o`0001_ooo]Z0_oo03P00ooonf[oN@3oogT0o`06oookJP;o^?l01?oonfX2ool0
_0cooo]Z0om/0?mLoookJPGoK03o5?oonfX3ool0_0Gooo]Z0onho`0<oookJP03ogT0oooonf[ooo]Z
00;ooo]Z0_oo03PVoookJP009ooonfX00ol0odgooo]ZoookJP02oookJP05ool0Z_oonf[ooo]Zoook
J_mI0?l02_oonfX00olY0?oooo]ZoookJP03oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0oook
J_oo00/01_oonfX00ooo=@3ooo]Zo`21o`02oookJP04o`3oUooonf[ooo]Zo`3oj0;ooo]Z00?o=_l0
oookJ_oonfX03?oonfX00ol0hooooo]ZoookJP02oookJP03ool0k?oonf[ooo]Z00cooo]Z00?o0?o]
oookJ_oonfX03OoonfX00ooo6P3ooo]Zoad0o`05oookJP03ool0]?oonf[oojL000[ooo]Z00?o0?l9
oookJ_oonfX00ooonfX01oml0?oooo]ZocCo0?oonf[oo`1?o`0;oooo01P00ooonfX01On`o`3ooo]Z
oookJ_oonf[o0?_o00Cooo]Z00?oCP3ooookJ_oonfX00_oonfX01Ooo01Cooo]ZoookJ_oonf[oolL0
00Sooo]Z00?oojP0oookJ_oo0:L00ooonfX00ooo0;Coob40oookJP09oookJP03o`3oUooonf[ooo]Z
00?ooo]Z00?oS_l0ool0>Ooo03T00ooonfX2o`3o`003ool01ooonf[ooo]Z00Oooo]Z1?l0000Moook
JP;oo`0h0_oonfX3ogT0o`Gooo]Z0onho`03oookJP;oo`2l3OoonfX3of`0oeCooo]Z1?m/0?lGoook
JP?oolT01OoonfX3okSo00cooo]Z00?oN@3oooo90?oonfX00_oonfX2ool0>4gooo]Z00Go0?m=oook
J_oonf[ooo]Zool0ZP03oookJP03oeT0oooonf[ooo]Z00Wooo]Z00?o:@3ooookJ_oonfX00ooonfX0
0ol0oo3ooo]ZoookJP06oookJP03oooX0?oo00_ooo]Z00Kooo]Z00?oocD0ocOo0?l0POl00_oonfX0
1_l0oiOooo]ZoookJ_l0onSooo]ZocKo00kooo]Z00?o0>?ooookJ_oonfX00ooonfX00ooo0>cooo]Z
oookJP0;oookJP03o`3okOoonf[ooo]Z00gooo]Z00CooaX0oookJ_lM0?oo0?ob1OoonfX00ooo0;Co
oo]ZoonW000:oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z00OoO03oocCo0?oonf[ooo]Zo`0;oooonf[o
o`0H00?ooo]Z00Co/?l0oookJ_oonf[o0?_o1?oonfX00om>0?oooo]ZoookJP02oookJP05ool05?oo
nf[ooo]ZoookJ_ooa`002?oonfX00oooZ03ooo]Zool0Y`04oookJP03oolQ0?oonf[ooo]Z00Sooo]Z
0_l0oiL4oookJP03ohko0?oo03Woo`0i00Cooo]Z00?o0?o0oookJ_oo00L02?oonfX4o`0001kooo]Z
00?oo`0hoookJ_oonfX00omi0?l5oookJP?o^?l00ooonfX2ool0_0gooo]Z0om/0?mEoookJPCoK03o
5_oonfX3ool0_0Gooo]Z0onho`0=oookJP;oN@3o0ooonfX2ool0>2Sooo]Z000WoookJP03o`3oCOoo
nf[ooo]Z00;ooo]Z00?oo`2ZoookJ_oonfX00_oonfX00omI0?oooo]ZoookJP08oookJP03obT0oooo
nf[ooo]Z00?ooo]Z00?o0?o`oookJ_oonfX01_oonfX00oooj03oo`0;oookJP05oookJP03oole0?oo
nf[o087o00;ooo]Z00Oo0?nGoookJ_oonf[ooo]Zo`3oj?oonf[o=_l000oooo]Z00?o0>?ooookJ_oo
nfX00_oonfX00ooo0>cooo]ZoookJP0<oookJP03o`3okOoonf[ooo]Z00gooo]Z00?ooaX0oad0oooo
nfX01OoonfX00ooo0;Cooo]ZoonW000:oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z00OoO03ooookJ_ld
o`3oo`1?oookJ_l02oooo`0H00?ooo]Z00Co/?l0oookJ_oonf[o0?_o1OoonfX01Om>0?oooo]Zoook
J_oonf[oo`0D00?ooo]Z00?oolL0oookJ_oonfX01ooonfX00oooZ03ooo]Zool0Y`03oookJP03ool0
]?oo8@3ooo]Z00Wooo]Z00?o0?nGoookJ_oonfX00ooonfX00on>o`3ooo]Zool0>@04oookJP03o`3o
`?oo00Ooo`0700Oooo]Z1?l0000OoookJP;oo`0h0ooonfX2ogT0o`Kooo]Z0_nho`03oookJP?oo`2l
3OoonfX4of`0od_ooo]Z1Om/0?lHoookJP?oolT01_oonfX2okSo00cooo]Z0omi0?l4oookJP03ool0
>?oonf[ooo]Z04gooo]Z00Go0?m=oookJ_oonf[ooo]Zool0ZP04oookJP03oeT0oooonf[ooo]Z00Wo
oo]Z00?o:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP06oookJP03oooX0?oonf[ooo]Z00Go
oo]Z00?oocD0ocOo0?l0POl00_oonfX01?l0oiOooo]ZoookJ_l0onP2oookJP03ocKo0?oonf[ooo]Z
00cooo]Z00?o0>?ooookJ_oonfX00_oonfX00ooo0>cooo]ZoookJP0<oookJP03o`3okOoonf[ooo]Z
00gooo]Z00?ooaX0oad0ool0oo801OoonfX01?oo0;Cooo]ZoookJ_ooY`0:oookJP03o`3o2Ooonf[o
oo]Z00?ooo]Z00KoO03oocCo0?oonf[oo`1?o`0;oooo01P4oookJP03ok3o0?oonf[o0?_o00Gooo]Z
00GoCP3ooookJ_oonf[ooo]Zool05003oookJP03ooo70?oonf[ooo]Z00Oooo]Z00?oojP0oookJ_oo
0:L01?oonfX00ooo8@3ooo]ZoookJP09oookJP03o`3oUooonf[ooo]Z00;ooo]Z00?oS_l0oookJ_oo
03T01?oonfX00ol0ol3ooo]Zool01`07oookJPCo00007ooonfX2ool0>0?ooo]Z0_mi0?l6oookJP;o
^?l00ooonfX3ool0_0gooo]Z1?m/0?m<oookJPGoK03o5ooonfX3ool0_0Kooo]Z0_nho`0=oookJP?o
N@3o0ooonfX2ool0>2[ooo]Z000WoookJP03o`3oCOoonf[ooo]Z00?ooo]Z00Goo`2ZoookJ_oonf[o
oo]ZoeT0o`0:oookJP03obT0oooonf[ooo]Z00?ooo]Z00?o0?o`oookJ_oonfX01_oonfX00oooj03o
oo]Zool02`06oookJP03oole0?lgo`3o087o00;ooo]Z00Co0?nGoookJ_oonf[o0?oX0_oonfX00olf
o`3ooo]ZoookJP0<oookJP03o`3Soooonf[ooo]Z00;ooo]Z00?oo`3/oookJ_oonfX03?oonfX00ol0
ongooo]ZoookJP0>oookJP03oolJ0?lM0?oooo]Z00Cooo]Z00Coo`2doookJ_oonf[oojL02_oonfX0
0ol0o`Wooo]ZoookJP03oookJP07og`0ooldo`3oolT0ool0Cooonf[o00_oool06003oookJP04ok3o
0?oonf[ooo]Zo`3ko`Cooo]Z00?oCP3ooookJ_oonfX00_oonfX01Ooo01Cooo]ZoookJ_oonf[oolL0
00Wooo]Z00?oojP0oookJ_oo0:L00ooonfX00ooo0;Coob40oookJP09oookJP03o`3oUooonf[ooo]Z
00?ooo]Z00?oS_l0oookJ_oo03T01?oonfX00ol0ol3ooo]Zool01`06oookJPCo00008OoonfX2ool0
>0?ooo]Z0_mi0?l6oookJP?o^?l00ooonfX3ool0_0kooo]Z1_m/0?lRoookJP?oiOl06ooonfX5of`0
o`oooo]Z0_oob@09oookJP?oolT01_oonfX3okSo00cooo]Z0_mi0?l5oookJP;oo`0hD?oonfX00ol0
odgooo]ZoookJP02oookJP05ool0Z_oonf[ooo]ZoookJ_mI0?l02ooonfX00olY0?oooo]ZoookJP03
oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0ool02ooonfX01_oonfX00ooo=@3ooo]Zo`21o`02
oookJP06o`3oUooonf[ooo]Zo`3oj?oonf[o=_l03_oonfX00ol0hooooo]ZoookJP02oookJP03ool0
k?oonf[ooo]Z00cooo]Z00?o0?o]oookJ_oonfX03_oonfX00ooo6P3o7@3oo`3olP05oookJP03ool0
]?oonf[oojL000[ooo]Z00?o0?l9oookJ_oonfX01?oonfX01_ldo`3ooo]ZoookJ_oo04oo00_oool0
60Cooo]Z00?o/?l0oookJ_l0nol01?oonfX00om>0?oooo]ZoookJP02oookJP05ool05?oonf[ooo]Z
oookJ_ooa`002OoonfX00oooZ03ooo]Zool0Y`03oookJP03ool0]?oo8@3ooo]Z00[ooo]Z00?o0?nG
oookJ_oonfX00_oonfX00on>o`3ooo]Zool0>@04oookJP;o0?o00_oo00L5oookJPCo00008OoonfX2
ool0>0?ooo]Z0_mi0?l6oookJP?o^?l00ooonfX3ool0_0kooo]Z1_m/0?m1oookJPGoK03o6OoonfX3
ool0_0Kooo]Z0onho`0=oookJP;oN@3o1?oonfX2ool0>2cooo]Z000XoookJP03o`3oCOoonf[ooo]Z
00;ooo]Z00Goo`2ZoookJ_oonf[ooo]ZoeT0o`0;oookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`
oookJ_oonfX01ooonfX00oooj03oo`0;oookJP05oookJP03oole0?oonf[o087o00;ooo]Z00Oo0?nG
oookJ_oonf[ooo]Zo`3oj?oonf[o=_l000oooo]Z00?o0>?ooookJ_oonfX00_oonfX00ooo0>cooo]Z
oookJP0<oookJP03o`3okOoonf[ooo]Z00gooo]Z00?ooaX0oad0ool0oo801OoonfX00ooo0;Cooo]Z
oonW000:oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z00SoO03ooookJ_ldo`3oolT0ool0Col02ooooo]Z
ool060?ooo]Z00Co/?l0oookJ_oonf[o0?_o1?oonfX00om>0?oooo]ZoookJP02oookJP05ool05?oo
nf[ooo]ZoookJ_ooa`002OoonfX00oooZ03oo`2WoookJP03oookJP03ool0]?oo8@3ooo]Z00Wooo]Z
00?o0?nGoookJ_oonfX00ooonfX00on>o`3ooo]Zool0>@04oookJP03o`3o`?oonf[oo`0700Gooo]Z
1?l0000SoookJP03ool0>?oonf[ooo]Z00;ooo]Z0omi0?l6oookJP;o^?l01?oonfX4ool0_13ooo]Z
1om/0?lGoookJPOoiOl05ooonfX4of`0oa?ooo]Z0ooob@06oookJP?oolT01ooonfX2okSo00cooo]Z
0omi0?l5oookJP;oo`0hDooonfX01Ol0odgooo]ZoookJ_oonf[oo`2Z00?ooo]Z00?oF@3ooookJ_oo
nfX02_oonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Oooo]Z00?oonP0oookJ_oo
nfX01OoonfX00ooo=@3o=ol0o`21o`02oookJP04o`3oUooonf[ooo]Zo`3oj0;ooo]Z00?o=_l0oook
J_oonfX03?oonfX00ol0hooooo]ZoookJP02oookJP03ool0k?oonf[ooo]Z00cooo]Z00?o0?o]oook
J_oonfX03OoonfX01?oo6P3o7@3ooookJ_l0oo85oookJP03ool0]?oonf[oojL000[ooo]Z00?o0?l9
oookJ_oonfX00ooonfX01oml0?oo=?l0oookJ_oonf[o00_ooookJ_oo01P01?oonfX00on`o`3ooo]Z
o`3ko`04oookJP03odh0oooonf[ooo]Z00;ooo]Z00Goo`0DoookJ_oonf[ooo]Zooo70009oookJP03
oonX0?oo0:Oooo]Z00?ooo]Z00?oo`2doolQ0?oonfX02_oonfX00ol0oiOooo]ZoookJP02oookJP;o
S_l000?oo`0ioookJ_oonfX00ooonfX00ol0ol3ooo]Zool01`04oookJPCo00008ooonfX2ool0>0?o
oo]Z0omi0?l6oookJP;o^?l01?oonfX4ool0_13ooo]Z1om/0?lfoookJPCoK03o6ooonfX3ool0_0Oo
oo]Z0_nho`0=oookJP?oN@3o1?oonfX2ool0>2kooo]Z000XoookJP03ool00?oonf[ooo]Z00;ooo]Z
00?oo`2ZoookJ_oonfX00_oonfX00omI0?oooo]ZoookJP08oookJP03obT0oooonf[ooo]Z00?ooo]Z
00?o0?o`oookJ_oonfX01_oonfX00oooj03oo`0;oookJP06oookJP03oole0?lgo`3o087o00;ooo]Z
00Co0?nGoookJ_oonf[o0?oX0_oonfX00olfo`3ooo]ZoookJP0<oookJP03o`3Soooonf[ooo]Z00;o
oo]Z00?oo`3/oookJ_oonfX03?oonfX00ol0ongooo]ZoookJP0>oookJP03oolJ0?lM0?oooo]Z00Go
oo]Z00?oo`2doookJ_ooY`002_oonfX00ol0o`Wooo]ZoookJP03oookJP07og`0oooob@3o=?l0ool0
Cooob@3o00_oool06004oookJP04ok3o0?oonf[ooo]Zo`3ko`Cooo]Z00?oCP3ooookJ_oonfX00_oo
nfX01Ooo01Cooo]ZoookJ_oonf[oolL000Wooo]Z00?oojP0ool0YooonfX00ooonfX00ooo0;Coob40
oookJP09oookJP03o`3oUooonf[ooo]Z00?ooo]Z0_n>o`02ool0>@?ooo]Z0_l0ol02ool01`?ooo]Z
1?l0000ToookJP;oo`0h1OoonfX2ogT0o`Kooo]Z0_nho`06oookJP?oo`2l5?oonfX6of`0o`kooo]Z
2_oUo`0BoookJPGoK03o5OoonfX5ooo900?ooo]Z0ooob@07oookJP?o^?l03?oonfX2ogT0o`Kooo]Z
0_oo03QEoookJP05o`3oCOoonf[ooo]ZoookJ_oo0:X01?oonfX00omI0?oooo]ZoookJP09oookJP03
obT0oooonf[ooo]Z00?ooo]Z00?o0?o`oookJ_oonfX01_oonfX00oooj03ooo]ZoookJP06oookJP03
oole0?oonf[o087o00;ooo]Z00Ko0?nGoookJ_oonf[o0?oXoookJ_lfo`0?oookJP05o`3Soooonf[o
oo]ZoookJ_oo0>`03ooonfX00ol0ongooo]ZoookJP0=oookJP03oolJ0?lM0?oo0?ob00Gooo]Z00Co
o`2doookJ_oonf[oojL02_oonfX00ol0o`Wooo]ZoookJP03oookJP07og`0ooldo`3ooo]Zool0Col0
2ooooo]Zool06004oookJP03ok3o0?oonf[o0?_o00Cooo]Z00?oCP3ooookJ_oonfX00_oonfX01Ooo
01Cooo]ZoookJ_oonf[oolL000Wooo]Z00?oojP0ool0YooonfX00ooonfX00ooo0;Coob40oookJP0:
oookJP03o`3oUooonf[ooo]Z00?ooo]Z00?oS_l0ool0>Ooo03T01?oonfX00ol0ol3ooo]Zool01`03
oookJPCo00009OoonfX00ooo03Sooo]ZoookJP03oookJP;oN@3o1_oonfX2okSo00Kooo]Z0ooo0;`D
oookJPKoK03o:ooonfX5of`0oacooo]Z0ooo0;`7oookJP?o^?l03OoonfX2ogT0o`Gooo]Z0_oo03P`
oookJP00:?oonfX00ooo003ooo]ZoookJP03oookJP05ool0Z_oonf[ooo]ZoookJ_mI0?l02ooonfX0
0olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Oooo]Z00?oonP0ool02ooonfX01OoonfX0
0ooo=@3o=ol0o`21o`02oookJP07o`3oUooonf[ooo]ZoookJ_l0onSooo]ZocKo000?oookJP03o`3S
oooonf[ooo]Z00;ooo]Z00?oo`3/oookJ_oonfX03?oonfX00ol0ongooo]ZoookJP0>oookJP03oolJ
0?lM0?oooo]Z00Cooo]Z00Coo`2doookJ_oonf[oojL02_oonfX00ol0o`Wooo]ZoookJP03oookJP07
og`0ooldo`3oolT0ool0Cooob@3o00_oool06004oookJP03ok3o0?oonf[o0?_o00Gooo]Z00?oCP3o
oookJ_oonfX00_oonfX01Ooo01Cooo]ZoookJ_oonf[oolL000Wooo]Z00?oojP0ool0YooonfX00ooo
nfX00ooo0;Coob40oookJP09oookJP03o`3oUooonf[ooo]Z00Cooo]Z00?oS_l0oookJ_oo03T01?oo
nfX00ol0ol3ooo]Zool01`02oookJPCo00009_oonfX2ool0>0Gooo]Z0omi0?l5oookJP?o^?l01_oo
nfX4ool0_1Kooo]Z1_m/0?l4oookJQooiOl000?oK03ooookJ_oonfX05_oonfX:ooo900Oooo]Z0onh
o`0=oookJP;oN@3o1_oonfX2ool0>5Oooo]Z00?o0?m=oookJ_oonfX00_oonfX01Ooo0:[ooo]Zoook
J_oonf[oF@3o00cooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP07oookJP03oooX
0?oonf[ooo]Z00Gooo]Z00?oocD0oookJ_l0POl00_oonfX01_l0oiOooo]ZoookJ_l0onSooo]ZocKo
00oooo]Z00?o0>?ooookJ_oonfX00_oonfX00ooo0>cooo]ZoookJP0<oookJP03o`3okOoonf[ooo]Z
00kooo]Z00?ooaX0oad0ool0oo801OoonfX00ooo0;Cooo]ZoonW000:oookJP03o`3o2Ooonf[ooo]Z
00Cooo]Z00Oo=?l0o`0]oooonf[oo`1?o`0;oooonf[oo`0H00Cooo]Z00?o/?l0o`3koooonfX01?oo
nfX00om>0?oooo]ZoookJP02oookJP05ool05?oonf[ooo]ZoookJ_ooa`002OoonfX00oooZ03oo`2W
oookJP03oookJP03ool0]?oo8@3ooo]Z00[ooo]Z00?o0?nGoookJ_oonfX00ooonfX00on>o`3ooo]Z
ool0>@04oookJP05o`3o`?oonf[oo`07ool01ooonfX01?l0000VoookJP;oo`0h1OoonfX3ogT0o`Go
oo]Z0onho`06oookJPCoo`2l5_oonfX6of`0oa?ooo]Z4_m/0?lNoookJP?oo`2l1ooonfX3okSo00go
oo]Z0omi0?l6oookJP03ool0>?oonf[ooo]Z033ooo]Z000XoookJP;oo`001?oonfX00ooo0:[ooo]Z
oookJP02oookJP03oeT0oooonf[ooo]Z00Sooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]Z
oookJP07oookJP03oooX0?oo00_ooo]Z00Kooo]Z00?oocD0ocOo0?l0POl00_oonfX01_l0oiOooo]Z
oookJ_l0onSooo]ZocKo013ooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00?oookJP03o`3okOoonf[o
oo]Z00gooo]Z00?ooaX0oad0oooonfX01OoonfX00ooo0;Cooo]ZoonW000:oookJP03o`3o2Ooonf[o
oo]Z00Cooo]Z00OoO03oocCo0?oob@3oo`1?o`0;oooob@3oo`0H00?ooo]Z00Co/?l0oookJ_oonf[o
0?_o1?oonfX00om>0?oooo]ZoookJP02oookJP03ool05?oonf[ooo]Z00;ooo]Z00?oolL0oookJ_oo
nfX01ooonfX00oooZ03oo`2WoookJP03oookJP03ool0]?oo8@3ooo]Z00Wooo]Z00?o0?nGoookJ_oo
nfX01?oonfX00on>o`3ooo]Zool0>@04oookJP04o`3o`?oonf[oo`07oookJPCo0000:?oonfX2ool0
>0Kooo]Z0_mi0?l6oookJP[oiOl00ooo0;`4onGo01Gooo]Z0_m/0?l@onGo02Wooo]Z2Ooob@07oook
JP;o^?l03OoonfX3ogT0o`Kooo]Z0_oo03QJoookJP05o`3oCOoonf[ooo]ZoookJ_oo0:X01?oonfX0
0omI0?oooo]ZoookJP09oookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01ooonfX0
0oooj03ooo]ZoookJP05oookJP04oole0?lgo`3ooo]Zo`21o`;ooo]Z00Ko0?nGoookJ_oonf[o0?oX
oookJ_lfo`0?oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`03ooonfX00ol0ongooo]ZoookJP0=oook
JP03oolJ0?lM0?oo0?ob00Kooo]Z00?oo`2doookJ_ooY`002_oonfX00ol0o`Wooo]ZoookJP04oook
JP06ocCo0?l0;Ooooo]Zo`0;oooonf[oo`0H1?oonfX00on`o`3ooo]Zo`3ko`04oookJP03odh0oooo
nf[ooo]Z00;ooo]Z00?oo`0DoookJ_oonfX00_oonfX00oooa`3ooo]ZoookJP07oookJP03oonX0?oo
0:Oooo]Z00?ooo]Z00?oo`2doolQ0?oonfX02_oonfX00ol0oiOooo]ZoookJP03oookJP03ohko0?oo
nf[oo`0i00Cooo]Z00Co0?o0oookJ_oonf[oo`071?l0000XoookJP;oo`0h1_oonfX2ogT0o`Kooo]Z
0onho`07oookJP?oo`2l6OoonfXCof`0obgooo]Z0ooo0;`8oookJP;o^?l03_oonfX2ogT0o`Oooo]Z
0_oo03PcoookJP00:OoonfX2ool000?ooo]Z00?oo`2ZoookJ_oonfX00_oonfX00omI0?oooo]Zoook
JP09oookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01ooonfX00oooj03oo`0;oook
JP05oookJP03oole0?lgo`3o087o00?ooo]Z00Ko0?nGoookJ_oonf[o0?oXoookJ_lfo`0?oookJP03
o`3Soooonf[ooo]Z00;ooo]Z00?oo`3/oookJ_oonfX03?oonfX00ol0ongooo]ZoookJP0>oookJP03
oolJ0?lM0?oooo]Z00Gooo]Z00?oo`2doookJ_ooY`002_oonfX00ol0o`Wooo]ZoookJP04oookJP07
og`0ooldo`3oo`1?ooo90?l02oooolT0ool06003oookJP04ok3o0?oonf[ooo]Zo`3ko`Cooo]Z00?o
CP3ooookJ_oonfX00_oonfX00ooo01Cooo]ZoookJP02oookJP03ooo70?oonf[ooo]Z00Oooo]Z00?o
ojP0ool0YooonfX00ooonfX00ooo0;Coob40oookJP09oookJP03o`3oUooonf[ooo]Z00Cooo]Z00?o
S_l0oookJ_oo03T01?oonfX01?l0ol3ooo]Zool01ooo00L3o`0002[ooo]Z0ooo03P5oookJP;oN@3o
1_oonfX;onGo00?oo`2l00?oiOl0oookJ_oonfX06OoonfX<onGo02Oooo]Z2ooob@04oookJP?o^?l0
3OoonfX2ogT0o`Oooo]Z0_oo03QLoookJP05o`3oCOoonf[ooo]ZoookJ_oo0:X01?oonfX00omI0?oo
oo]ZoookJP09oookJP03obT0oooonf[ooo]Z00?ooo]Z00?o0?o`oookJ_oonfX01ooonfX00oooj03o
oo]ZoookJP05oookJP03oole0?oonf[o087o00;ooo]Z00Ko0?nGoookJ_oonf[o0?oXoookJ_lfo`0?
oookJP03o`3Soooonf[ooo]Z00;ooo]Z00?oo`3/oookJ_oonfX03OoonfX00ol0ongooo]ZoookJP0=
oookJP03oolJ0?lM0?oo0?ob00Kooo]Z00?oo`2doookJ_ooY`002_oonfX00ol0o`Wooo]ZoookJP03
oookJP07og`0ooldo`3o02goool0Col02ooooo]Zool06004oookJP03ok3o0?oonf[o0?_o00Cooo]Z
00?oCP3ooookJ_oonfX00_oonfX00ooo01Cooo]ZoookJP02oookJP03ooo70?oonf[ooo]Z00Oooo]Z
00?oojP0ool0YooonfX00ooonfX00ooo0;Coob40oookJP0:oookJP03o`3oUooonf[ooo]Z00?ooo]Z
0_n>o`000ooo03Wooo]ZoookJP02oookJP04o`3o`?oonf[ooo]Zool01`?o0000:_oonfX3ool0>0Go
oo]Z0_mi0?l7oookJPCo^?l01_oonfX3ool0_5?ooo]Z0ooo0;`8oookJP?o^?l03OoonfX3ogT0o`Oo
oo]Z0_oo03PeoookJP00:OoonfX3ool000?ooo]Z00Goo`2ZoookJ_oonf[ooo]ZoeT0o`0;oookJP03
obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01ooonfX00oooj03oo`0;oookJP06oookJP03
oole0?lgo`3o087o00;ooo]Z00Ko0?nGoookJ_oonf[o0?oXoookJ_lfo`0@oookJP05o`3Soooonf[o
oo]ZoookJ_oo0>`03ooonfX00ol0ongooo]ZoookJP0>oookJP03oad0ool0oo;ooo]Z00Gooo]Z00?o
o`2doonW0?oonfX02OoonfX00ol0o`Wooo]ZoookJP04oookJP07ooo90?ldo`3oolT0ool0Cooob@3o
00_oooo90004oookJP04ok3o0?oonf[ooo]Zo`3ko`Cooo]Z00?oCP3ooookJ_oonfX00_oonfX00ooo
01Cooo]ZoookJP02oookJP03ooo70?oonf[ooo]Z00Oooo]Z00?oojP0ool0YooonfX00ooonfX00ooo
0;Coob40oookJP09oookJP03o`3oUooonf[ooo]Z00Cooo]Z00CoS_l0oookJ_oo03Woo`0i0ooonfX0
1?l0ol3ooo]Zo`000?oo00L2o`0002gooo]Z0ooo03P4oookJP?oN@3o1OoonfX<onGo00Coo`2l7Ooo
nfX7onGo02Gooo]Z3_oob@000ooonf[o^?l0okSo000=oookJP?oN@3o1ooonfX2ool0>5oooo]Z00Go
0?m=oookJ_oonf[ooo]Zool0ZP03oookJP03oeT0oooonf[ooo]Z00[ooo]Z00?o:@3ooookJ_oonfX0
0_oonfX00ol0oo3ooo]ZoookJP07oookJP03oooX0?oonf[ooo]Z00Gooo]Z00?oocD0ocOo0?l0POl0
0ooonfX01_l0oiOooo]ZoookJ_l0onSooo]ZocKo00oooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00?
oookJP03o`3okOoonf[ooo]Z00kooo]Z00?o7@3ooookJ_l0oo801OoonfX00ooo0;Cooo]ZoonW000:
oookJP03o`3o2Ooonf[ooo]Z00Cooo]Z00Oo=?l0o`0]oooonf[oo`1?o`0;oooonf[oo`0H00Cooo]Z
00?o/?l0oookJ_l0nol01?oonfX00om>0?oooo]ZoookJP02oookJP03ool05?oonf[ooo]Z00;ooo]Z
00?oolL0oookJ_oonfX01ooonfX00oooZ03oo`2WoookJP03oookJP03ool0]?oo8@3ooo]Z00[ooo]Z
00?o0?nGoookJ_oonfX01?oonfX00on>o`3oo`0iool0>@03oookJP;o0?o000Co0000ool01ol0003o
0000;OoonfX3ool0>0Cooo]Z0omi0?l8oookJPCo^?l01OoonfX4ool0_4cooo]Z0ooo0;`9oookJP;o
^?l03_oonfX2ogT0o`Sooo]Z0_oo03PgoookJP00:OoonfX4ool000;ooo]Z00?oo`2ZoookJ_oonfX0
0_oonfX00omI0?oooo]ZoookJP09oookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX0
1ooonfX00oooj03oo`0;oookJP05oookJP03oole0?lgo`3o087o00?ooo]Z00Ko0?nGoookJ_oonf[o
0?oXoookJ_lfo`0?oookJP03o`3Soooonf[ooo]Z00;ooo]Z00?oo`3/oookJ_oonfX03OoonfX00ol0
ongooo]ZoookJP0=oookJP03oolJ0?lM0?oooo]Z00Gooo]Z00?oo`2doookJ_ooY`002_oonfX00ol0
o`Wooo]ZoookJP04oookJP05og`0ooldo`3oolT0ool0Col02ol00_oob@04oookJP03ok3o0?oonf[o
0?_o00Gooo]Z00?oCP3ooookJ_oonfX00_oonfX00ooo01Cooo]ZoookJP02oookJP03ooo70?oonf[o
oo]Z00Oooo]Z00?oojP0ool0YooonfX01?oonfX00ooo8@3ooo]ZoookJP08oookJP03o`3oUooonf[o
oo]Z00Cooo]Z0_n>o`000ooonf[oo`0ioookJP02oookJP;o0?o000?o0000ool01ol00000<?oonfX3
ool0>0Cooo]Z0_mi0?l4oookJP_oiOl01?oonfX3ool0_1oooo]Z0_oUo`0ToookJPooolT000?o^?l0
oookJ_oonfX02ooonfX2ogT0o`Sooo]Z0_oo03QQoookJP05o`3oCOoonf[ooo]ZoookJ_oo0:X01?oo
nfX00omI0?oooo]ZoookJP09oookJP03obT0oooonf[ooo]Z00?ooo]Z00?o0?o`oookJ_oonfX01ooo
nfX00oooj03ooo]ZoookJP05oookJP03oole0?oonf[o087o00;ooo]Z00Ko0?nGoookJ_oonf[o0?oX
oookJ_lfo`0@oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`03ooonfX00ol0ongooo]ZoookJP0=oook
JP03oolJ0?lM0?oo0?ob00Kooo]Z00?oo`2doookJ_ooY`002_oonfX00ol0o`Wooo]ZoookJP04oook
JP04ocCo0?l0;Ooooo]Zo`0;o`;ooo]Z00?oo`0HoookJ_oonfX00_oonfX00on`o`3o0?_ooookJP04
oookJP03odh0oooonf[ooo]Z00;ooo]Z00?oo`0DoookJ_oonfX00_oonfX00oooa`3ooo]ZoookJP07
oookJP03oonX0?oo0:Oooo]Z00Cooo]Z00?oob40oookJ_oonfX02OoonfX00ol0oiOooo]ZoookJP04
oookJP03ohko0?oonf[oo`0i00Cooo]Z00Co0?o0o`000?oo00Ooo`07<?oonfX3ool0>0Cooo]Z0_mi
0?l:oookJPCo^?l01OoonfX3ool0_4Kooo]Z0ooo0;`9oookJP?o^?l03OoonfX3ogT0o`Sooo]Z0_oo
03PioookJP00:OoonfX5ool00003oookJ_oo0:[ooo]Z00?ooo]Z00?oF@3ooookJ_oonfX02OoonfX0
0olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Oooo]Z00?oonP0ool02ooonfX01_oonfX0
0ooo=@3o=ol0o`21o`02oookJP06o`3oUooonf[ooo]Zo`3oj?oonf[o=_l04?oonfX01Ol0hooooo]Z
oookJ_oonf[oo`3/00oooo]Z00?o0?o]oookJ_oonfX03_oonfX00olM0?oo0?oboookJP05oookJP03
ool0]?oonf[oojL000[ooo]Z00?o0?l9oookJ_oonfX00ooonfX01_oob@3oO03oocCo0?oo04ooolT0
o`0;o`;oolT01?oonfX00on`o`3ooo]Zo`3ko`05oookJP03odh0oooonf[ooo]Z00;ooo]Z00?oo`0D
oookJ_oonfX00_oonfX00oooa`3ooo]ZoookJP07oookJP03oonX0?oo0:Oooo]Z00Cooo]Z00?oob40
oookJ_oonfX02?oonfX00ol0oiOooo]ZoookJP05oookJP03ohko0?oonf[oo`0i00?ooo]Z00?o0000
o`3o`?l000000_oo00LboookJP?oo`0h0ooonfX2ogT0o`Cooo]Z3?oUo`04oookJPSoo`2l=_oonfX6
ool0_0SoolT00ooonfX3okSo00gooo]Z0omi0?l9oookJP03ool0>?oonf[ooo]Z06;ooo]Z00Co0?m=
oookJ_oonf[oo`2Z1?oonfX00omI0?oooo]ZoookJP0:oookJP03obT0oooonf[ooo]Z00;ooo]Z00?o
0?o`oookJ_oonfX01ooonfX00oooj03ooo]ZoookJP05oookJP03oole0?lgo`3o087o00?ooo]Z00Ko
0?nGoookJ_oonf[o0?oXoookJ_lfo`0?oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`04?oonfX00ol0
ongooo]ZoookJP0=oookJP03oad0oooonf[o0?ob00Kooo]Z00?oo`2doonW0?oonfX02_oonfX00ol0
o`Wooo]ZoookJP04oookJP04ocCo0?l0;Oooo`1?o`0;o`;ooo]Z00?oo`0HoookJ_oonfX00_oonfX0
0on`o`3o0?_ooookJP04oookJP03odh0oooonf[ooo]Z00;ooo]Z00?oo`0DoookJ_oonfX00_oonfX0
0oooa`3ooo]ZoookJP07oookJP03oonX0?oo0:Oooo]Z00Cooo]Z00?oob40oookJ_oonfX02OoonfX0
0ol0oiOooo]ZoookJP04oookJP03ohko0?oonf[oo`0i00?ooo]Z00Go0000o`3o`?l0003o0000ool0
1`0boookJP?oo`0h0ooonfX2ogT0o`cooo]Z1Onho`03oookJPSoo`2l=ooonfX7ool0_0Wooo]Z0onh
o`0>oookJP;oN@3o2OoonfX2ool0>3_ooo]Z000YoookJPGoo`000_oonfX01Ooo0:[ooo]ZoookJ_oo
nf[oF@3o00cooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol00:oookJP03oooX0?oo00_ooo]Z00Gooo]Z
00?oocD0ocOo0?l0POl00ooonfX01_l0oiOooo]ZoookJ_l0onSooo]ZocKo013ooo]Z00Go0>?ooook
J_oonf[ooo]Zool0k00?oookJP03o`3okOoonf[ooo]Z00kooo]Z00?o7@3ooookJ_oonfX01OoonfX0
0ooo0;CoojL0oookJP09oookJP03o`3o2Ooonf[ooo]Z00Cooo]Z00KoolT0ocCo0?oob@3oo`1?ooo9
0?l02ol2ooo900Cooo]Z00?o/?l0oookJ_l0nol01?oonfX00om>0?oooo]ZoookJP03oookJP03ool0
5?oonf[ooo]Z00;ooo]Z00?oolL0oookJ_oonfX01ooonfX00oooZ03oo`2WoookJP04oookJP03oolQ
0?oonf[ooo]Z00Sooo]Z00?o0?nGoookJ_oonfX01OoonfX00on>o`3ooo]Zool0>@02oookJP;o0000
00Co0?o0o`000?oonf[oo`07=?oonfX3ool0>0;ooo]Z0omi0?l3oookJPOoiOl00ooonfX4onGo00So
oo]Z2ooo0;`PoookJP_oo`2l3OoonfX4okSo00kooo]Z0_mi0?l:oookJP;oo`0hIOoonfX01Ol0odgo
oo]ZoookJ_oonf[oo`2Z00?ooo]Z00?oF@3ooookJ_oonfX02_oonfX00olY0?oooo]ZoookJP02oook
JP03o`3ol?oonf[ooo]Z00Oooo]Z00?oonP0ool02ooonfX01_oonfX00ooo=@3o=ol0o`21o`03oook
JP05o`3oUooonf[o0?oXoookJ_lfo`004?oonfX01Ol0hooooo]ZoookJ_oonf[oo`3/00oooo]Z00?o
0?o]oookJ_oonfX03_oonfX00olM0?oo0?oboookJP05oookJP03ool0]?oonf[oojL000[ooo]Z00?o
0?l9oookJ_oonfX01?oonfX01oldo`3oO03oo`0]oooo04oo00_ooookJ_oo01P01OoonfX00on`o`3o
0?_ooookJP03oookJP03odh0oooonf[ooo]Z00?ooo]Z00?oo`0DoookJ_oonfX00_oonfX00oooa`3o
oo]ZoookJP07oookJP03oonX0?oo0:Oooo]Z00Cooo]Z00?oob40oookJ_oonfX02OoonfX00ol0oiOo
oo]ZoookJP04oookJP;oS_l000?oo`0ioookJ_oonfX00_l000001?l0ol3o0000oookJ_oo00Ldoook
JP?oo`0h0_oonfX3ogT0o`kooo]Z1?nho`07oookJP_oo`2l8OoonfX;ool0_0cooo]Z1?nho`0>oook
JP?oN@3o2OoonfX2ool0>3gooo]Z000ZoookJPGoo`0000?ooo]Zool0Z_oonfX00ooonfX00omI0?oo
oo]ZoookJP09oookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01ooonfX00oooj03o
o`0;oookJP06oookJP03oole0?lgo`3o087o00;ooo]Z00Ko0?nGoookJ_oonf[o0?oXoookJ_lfo`0@
oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`04?oonfX00ol0ongooo]ZoookJP0=oookJP03oad0ool0
oo;ooo]Z00Gooo]Z00?oo`2doookJ_ooY`002_oonfX00ol0o`Wooo]ZoookJP03oookJP;oolT000Oo
=?l0ooo90?oo04ooolT0o`0;oooonf[oo`0H00Cooo]Z00?o/?l0oookJ_l0nol01?oonfX00om>0?oo
oo]ZoookJP02oookJP03ool05?oonf[ooo]Z00?ooo]Z00?oolL0oookJ_oonfX01ooonfX00oooZ03o
o`2Wool0Y`04oookJP03oolQ0?oonf[ooo]Z00Sooo]Z00?o0?nGoookJ_oonfX01OoonfX01?n>o`3o
oo]Zool0>Ooo03T3o`000003o`3o`?oonf[ooo]Z00;oo`07=OoonfX3ool0>0;ooo]Z0omi0?l2oook
JPGoiOl01ooonfX4onGo00oooo]Z2ooo0;`:oookJP_oo`2l4OoonfX7okSo013ooo]Z0_mi0?l:oook
JP;oo`0hIooonfX01Ol0odgooo]ZoookJ_oonf[oo`2Z00Cooo]Z00?oF@3ooookJ_oonfX02_oonfX0
0olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Oooo]Z00?oonP0oookJ_oonfX01OoonfX0
0ooo=@3o=ol0o`21o`03oookJP06o`3oUooonf[ooo]Zo`3oj?oonf[o=_l03ooonfX01Ol0hooooo]Z
oookJ_oonf[oo`3/013ooo]Z00?o0?o]oookJ_oonfX03OoonfX00olM0?oooo]Zo`3olP06oookJP03
ool0]?oonf[oojL000[ooo]Z00?o0?l9oookJ_oonfX01?oonfX01oldo`3ooo]Zo`0]oooo04oo00_o
oookJ_oo01P01OoonfX00on`o`3o0?_ooookJP03oookJP03odh0oooonf[ooo]Z00;ooo]Z00?oo`0D
oookJ_oonfX00ooonfX00oooa`3ooo]ZoookJP07oookJP03oonX0?oo0:Ooo`2W00Cooo]Z00?oob40
ool0]?oonfX02OoonfX00ol0oiOooo]ZoookJP05oookJP03ohko0?oo03Woo`0i00?o000000?o0?o0
oookJ_oonfX00_oo00LeoookJP?oo`0h0_oonfX3ogT0o`oooo]Z1?nho`0>oookJP_oo`2l2ooonfX;
ool0_13ooo]Z1onho`0@oookJP;oN@3o2_oonfX2ool0>3oooo]Z000ZoookJPKoo`0000?oo`2Zoook
J_oonfX00_oonfX00omI0?oooo]ZoookJP0:oookJP05obT0oooonf[ooo]ZoookJ_l0oo002_oonfX0
0oooj03oo`0;oookJP05oookJP03oole0?oonf[o087o00?ooo]Z00Ko0?nGoookJ_oonf[o0?oXoook
J_lfo`0@oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`03ooonfX00ol0ongooo]ZoookJP0>oookJP03
oad0ool0oo;ooo]Z00Gooo]Z00?oo`2doookJ_ooY`002_oonfX00ol0o`Wooo]ZoookJP03oookJP;o
olT000Ko=?l0ooo90?oo04oooo]Zo`0;oooo01P4oookJP03ok3o0?oonf[o0?_o00Gooo]Z00?oCP3o
oookJ_oonfX00_oonfX00ooo01Cooo]ZoookJP03oookJP03ooo70?oonf[ooo]Z00Oooo]Z00?oojP0
oookJ_oo0:L01?oonfX00ooo8@3oo`2doookJP08oookJP;o0?nG1_oonfX01?n>o`3ooo]ZoookJ_oo
03T3o`000005o`3o`?oonf[ooo]ZoookJ_oo00L0=ooonfX3ool0>0;ooo]Z1Omi0?l00ooUo`3ooo]Z
oookJP0:oookJPCoiOl05_oonfX:ool0_1Gooo]Z1onho`0DoookJP?oN@3o2_oonfX2ool0>6[ooo]Z
00Co0?m=oookJ_oonf[oo`2Z1?oonfX00omI0?oooo]ZoookJP0:oookJP03obT0oooonf[ooo]Z00;o
oo]Z00?o0?o`oookJ_oonfX01ooonfX00oooj03oo`0;oookJP06oookJP03oole0?lgo`3o087o00?o
oo]Z00Go0?nGoookJ_l0onSooo]ZocKo000@oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`03ooonfX0
0ol0ongooo]ZoookJP0>oookJP03oad0oooonf[o0?ob00Kooo]Z00?oo`2doonW0?oonfX02_oonfX0
0ol0o`Wooo]ZoookJP04oookJP07ocCo0?oonf[o02goool0Col02ooooo]Zool06004oookJP03ok3o
0?l0nooooo]Z00Cooo]Z00?oCP3ooookJ_oonfX00_oonfX00ooo01Cooo]ZoookJP03oookJP03ooo7
0?oonf[ooo]Z00Oooo]Z00?oojP0oookJ_oo0:L01?oonfX00ooo8@3oo`2doookJP09oookJP;o0?nG
1_oonfX00on>o`3ooo]Zool0>@03o`000005o`3o`?oonf[ooo]ZoookJ_oo00L0=ooonfX3ool0>0;o
oo]Z1Omi0?l>oookJPCo^?l05OoonfX;ool0_1Cooo]Z1onho`0DoookJP?oN@3o2_oonfX2ool0>47o
oo]Z000ZoookJPOoo`0000Goo`2ZoookJ_oonf[ooo]ZoeT0o`0<oookJP05obT0oooonf[ooo]Zoook
J_l0oo002_oonfX00oooj03ooo]Zool02`06oookJP03oole0?lgo`3o087o00;ooo]Z00Ko0?nGoook
J_oonf[o0?oXoookJ_lfo`0@oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`04?oonfX00ol0ongooo]Z
oookJP0>oookJP03oad0oooonf[ooo]Z00Gooo]Z00?oo`2doonW0?oonfX02_oonfX00ol0o`Wooo]Z
oookJP02oookJP;oolT000OoO03oocCo0?oob@3oo`1?oookJ_l02oooo`0H00Cooo]Z00?o/?l0oook
J_l0nol01OoonfX00om>0?oooo]ZoookJP02oookJP03ool05?oonf[ooo]Z00?ooo]Z00?oolL0oook
J_oonfX01ooonfX00oooZ03ooo]Zool0Y`04oookJP03oolQ0?oo0;Cooo]Z00Wooo]Z00?o0?nGoook
J_oonfX01?oonfX2ohko0005o`000?oo03Wo0000o`000?oonfX00_l0ol02oookJP03ool01ooonf[o
oo]Z03Oooo]Z0ooo03P4oookJPGoN@3o3?oonfX2onGo00Wo^?l08ooonfX7okSo01Oooo]Z1?mi0?l:
oookJP?oo`0hK?oonfX01Ol0odgooo]ZoookJ_oonf[oo`2Z00?ooo]Z00?oF@3ooookJ_oonfX02ooo
nfX01OlY0?oooo]ZoookJ_oonf[o0?o`00[ooo]Z00?oonP0ool02ooonfX01OoonfX00ooo=@3o=ol0
o`21o`03oookJP06o`3oUooonf[ooo]Zo`3oj?oonf[o=_l04?oonfX01?l0hooooo]ZoookJ_oo0>`@
oookJP03o`3okOoonf[ooo]Z00kooo]Z00?o7@3oo`3ol_oonfX01OoonfX00ooo0;Cooo]ZoonW000;
oookJP03o`3o2Ooonf[ooo]Z00Cooo]Z00Oo=?l0o`0]oooonf[oo`1?o`0;oooonf[oo`0H00Cooo]Z
00?o/?l0o`3koooonfX01?oonfX00om>0?oooo]ZoookJP02oookJP03ool05?oonf[ooo]Z00?ooo]Z
00?oolL0oookJ_oonfX01ooonfX00oooZ03ooo]Zool0Y`04oookJP03oolQ0?oo0;Cooo]Z00[ooo]Z
00?o0?nGoookJ_oonfX01?oonfX00on>o`3o0000ool0>@02o`000003oookJ_l0ol3o0?o000;ooo]Z
00?oo`07oookJ_oonfX0=ooonfX3ool0>0Cooo]Z1Omi0?l=oookJP_o^?l08_oonfX7okSo01Oooo]Z
1?mi0?l:oookJP?oo`0h@ooonfX002[ooo]Z2?oo0004oookJP03oeT0oooonf[ooo]Z00Wooo]Z00?o
:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP08oookJP03oooX0?oo00_ooo]Z00Gooo]Z00?o
ocD0oookJ_l0POl00ooonfX01_l0oiOooo]ZoookJ_l0onSooo]ZocKo013ooo]Z00Go0>?ooookJ_oo
nf[ooo]Zool0k00?oookJP03o`3okOoonf[ooo]Z00kooo]Z00?o7@3oo`3ol_oonfX01_oonfX00ooo
0;CoojL0oookJP0:oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z00WoolT0oookJ_ml0?oo=?l0ooo90?oo
04oooo]Zo`0;oooo01P01?oonfX00on`o`3ooo]Zo`3ko`05oookJP03odh0oooonf[ooo]Z00;ooo]Z
00?oo`0DoookJ_oonfX00ooonfX00oooa`3ooo]ZoookJP07oookJP03oonX0?oonf[oo`2W00Cooo]Z
00?oob40ool0]?oonfX02OoonfX00ol0oiOooo]ZoookJP05oookJP04ohko0?l0003oo`0io`0000?o
oo]Z00?o0?o0oookJ_oonfX00_oo00LjoookJP?oo`0h1_oonfX5ogT0oa;ooo]Z4Onho`0;oookJPOo
^?l06?oonfX6ogT0o`[ooo]Z1?oo03Q`oookJP04o`3oCOoonf[ooo]Zool0ZPCooo]Z00?oF@3ooook
J_oonfX02_oonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Oooo]Z00?oonP0ool0
2ooonfX01_oonfX00ooo=@3o=ol0o`21o`03oookJP05o`3oUooonf[o0?oXoookJ_lfo`004?oonfX0
1Ol0hooooo]ZoookJ_oonf[oo`3/013ooo]Z00?o0?o]oookJ_oonfX03OoonfX00olM0?oooo]Zo`3o
lP06oookJP03ool0]?oonf[oojL000_ooo]Z00?o0?l9oookJ_oonfX01?oonfX01_ldo`3o02gooook
J_oo04oo00_oool060Gooo]Z00?o/?l0o`3koooonfX01?oonfX00om>0?oooo]ZoookJP02oookJP03
ool05?oonf[ooo]Z00?ooo]Z00?oolL0oookJ_oonfX01ooonfX00oooZ03ooo]Zool0Y`04oookJP03
oolQ0?oo0;Cooo]Z00[ooo]Z00?o0?nGoookJ_oonfX01?oonfX01?n>o`3o0000ool0>Ol00003oook
JP03o`3o`?oonf[ooo]Z00;oo`07>_oonfX3ool0>0Kooo]Z1Omi0?lCoookJQ7o^?l02_oonfX7okSo
01Sooo]Z1_mi0?l:oookJPCoo`0hA_oonfX002[ooo]Z2Ooo0003oookJP03oeT0oooonf[ooo]Z00[o
oo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol00:oookJP03oooX0?oonf[oo`0;00Kooo]Z00?oocD0ocOo
0?l0POl00_oonfX01_l0oiOooo]ZoookJ_l0onSooo]ZocKo017ooo]Z00Co0>?ooookJ_oonf[oo`3/
4?oonfX00ol0ongooo]ZoookJP0>oookJP03oad0oooonf[ooo]Z00Gooo]Z00?oo`2doonW0?oonfX0
2ooonfX00ol0o`Wooo]ZoookJP04oookJP07og`0ooldo`3oolT0ool0Cooonf[o00_oool06004oook
JP03ok3o0?oonf[o0?_o00Cooo]Z00?oCP3ooookJ_oonfX00ooonfX2ool050Cooo]Z00?oolL0oook
J_oonfX01ooonfX00oooZ03ooo]Zool0Y`04oookJP03oolQ0?oo0;Cooo]Z00Wooo]Z0_l0oiL5oook
JP03o`000?n>o`3o000000;oo`0i0ooonfX2o`3o`0;ooo]Z00?oo`07oookJ_oonfX0>_oonfX3ool0
>0Sooo]Z1?mi0?l4oomi01_ooo]Z2onho`0IoookJPKoN@3o3?oonfX4ool0>7Cooo]Z00Go0?m=oook
J_oonf[ooo]Zool0ZP03oookJP03oeT0oooonf[ooo]Z00_ooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3o
l00:oookJP03oooX0?oo00_ooo]Z00Gooo]Z00?oocD0ocOo0?l0POl00ooonfX01Ol0oiOooo]Zo`3o
j?oonf[o=_l0017ooo]Z00Co0>?ooookJ_oonf[oo`3/4?oonfX00ol0ongooo]ZoookJP0>oookJP03
oad0ool0oo;ooo]Z00Kooo]Z00?oo`2doonW0?oonfX02ooonfX00ol0o`Wooo]ZoookJP04oookJP06
ocCo0?l0;Ooooo]Zool0Col02oooo`0H1OoonfX00on`o`3o0?_ooookJP03oookJP03odh0oooonf[o
oo]Z00?ooo]Z0_oo01@4oookJP03ooo70?oonf[ooo]Z00Oooo]Z00?oojP0oookJ_oo0:L01?oonfX0
0ooo8@3oo`2doookJP0:oookJP;o0?nG1?oonfX00ol0003oS_l0ohko0002ool0>@?ooo]Z0_l0ol02
oookJP03ool01ooonf[ooo]Z03[ooo]Z0ooo03P8oookJPCoN@3o8?oonfX:okSo01Wooo]Z1_mi0?l<
oookJPCoo`0hB_oonfX002_ooo]Z1_oo00000ooonf[oo`2ZoookJP02oookJP03oeT0oooonf[ooo]Z
00[ooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol00;oookJP03oooX0?oo00_ooo]Z00Gooo]Z00?oocD0
oookJ_l0POl00ooonfX01_l0oiOooo]ZoookJ_l0onSooo]ZocKo013ooo]Z00Go0>?ooookJ_oonf[o
oo]Zool0k00@oookJP03o`3okOoonf[ooo]Z00gooo]Z00?o7@3ooolJ0?oonfX01_oonfX00ooo0;Co
ojL0oookJP0;oookJP03o`3o2Ooonf[ooo]Z00Cooo]Z00KoO03oocCo0?oob@3oo`1?oookJ_l02ol5
oookJP03ok3o0?oonf[o0?_o00Cooo]Z00?oCP3ooookJ_oonfX01?oonfX00ooo01Cooo]Zo`00O`02
o`00O`03ooo70?l007oooo]Z00?ooo]Z0ol007l01?oonf[oojP0oookJ_oo0:L2o`00O`;ooo]Z00?o
ob40ool0]?oonfX00_oonfX5o`00O`?ooo]Z00?o0?nGoookJ_oonfX00_oonfX2o`000004ohko0?l0
003ooo]Zool0>@Cooo]Z00Co0?o0oookJ_oonf[oo`07?_oonfX<oomi00GoN@3o>?oonfX6ogT0o`ko
oo]Z1?oo03QioookJP04o`3oCOoonf[ooo]Zool0ZP?ooo]Z00?oF@3ooookJ_oonfX02ooonfX01OlY
0?oooo]ZoookJ_oonf[o0?o`00[ooo]Z00?oonP0ool02ooonfX01_oonfX00ooo=@3o=ol0o`21o`03
oookJP05o`3oUooonf[o0?oXoookJ_lfo`004?oonfX01Ol0hooooo]ZoookJ_oonf[oo`3/013ooo]Z
00?o0?o]oookJ_oonfX03OoonfX00olM0?oooaX0o`3olP06oookJP03ool0]?oonf[oojL000_ooo]Z
00?o0?l9oookJ_oonfX01?oonfX01oml0?oo=?l0o`0]oooonf[oo`1?o`0;oooo01P01OoonfX00on`
o`3o0?_ooookJP03oookJP03odh0oooonf[ooo]Z00Cooo]Z00?oo`0DoookJ_l007l00_l007l00ooo
a`3o001ooookJP03oookJP?o001o00Cooo]ZoonX0?oonf[oo`2W0_l007l2oookJP03oolQ0?oo0;Co
o`2d00;ooo]Z1Ol007l4oookJP04o`3oUooonf[ooo]ZoookJP?o000000?oS_l0oookJ_oo03T01?oo
nfX01?l0ol3ooo]ZoookJ_oo00LnoookJPCoo`0h2?oonfX5ogT0ocSooo]Z1_mi0?l>oookJPCoo`0h
C_oonfX002_ooo]Z1?oo0003oookJP03ool0Z_oonf[ooo]Z00;ooo]Z00?oF@3ooookJ_oonfX02_oo
nfX01OlY0?oooo]ZoookJ_oonf[o0?o`00[ooo]Z00?oonP0oookJ_oo00/01_oonfX00ooo=@3o=ol0
o`21o`03oookJP05o`3oUooonf[o0?oXoookJ_lfo`004OoonfX01?l0hooooo]ZoookJ_oo0>`@oook
JP03o`3okOoonf[ooo]Z00kooo]Z00?o7@3oo`3ol_oonfX01_oonfX00ooo0;CoojL0oookJP0;oook
JP03o`3o2Ooonf[ooo]Z00Cooo]Z00Ko=?l0oookJ_oob@3oo`1?o`0;oooo01P5oookJP03ok3o0?oo
nf[o0?_o00Cooo]Z00?oCP3ooookJ_oonfX01?oonfX00ooo01Co001oo`00O`02o`00O`03ooo70?l0
07oooo]Z00;ooo]Z0ol007l2oookJP04oonX0?l007ooo`2Wool0Y`?ooo]Z00?oob40ool0]?oonfX0
1ol007l3oookJP04o`3oUooonf[ooo]ZoookJP?o000000CoS_l0oookJ_oonf[oo`0i1?oonfX2o`3o
`003oookJ_oo00Ooo`0703kooo]Z3_ooN@000ooonf[oN@3oogT0o`03ogT0obgooo]Z1_mi0?l@oook
JPCoo`0hOOoonfX01?l0odgooo]ZoookJ_oo0:X4oookJP03oeT0oooonf[ooo]Z00_ooo]Z00Go:@3o
oookJ_oonf[ooo]Zo`3ol00:oookJP03oooX0?oo00_ooo]Z00Gooo]Z00?oocD0oookJ_l0POl00ooo
nfX01Ol0oiOooo]Zo`3oj?oonf[o=_l0017ooo]Z00Co0>?ooookJ_oonf[oo`3/4OoonfX00ol0ongo
oo]ZoookJP0=oookJP03oad0oooonf[o0?ob00Kooo]Z00?oo`2doookJ_ooY`002ooonfX00ol0o`Wo
oo]ZoookJP04oookJP07og`0ooldo`3o02gooookJ_l02ooooo]Zool06005oookJP03ok3o0?l0nooo
oo]Z00?ooo]Z00?oCP3ooookJ_oonfX01?oonfX00ooo01Co001oo`00O`02o`00O`03ooo70?l007oo
oo]Z00;ooo]Z0ol007l2oookJP04oonX0?l007ooo`2Wool0Y`?ooo]Z00?oob40oookJ_oo0;@01ol0
07l4oookJP03o`3oUooonf[ooo]Z00Co000000?oS_l0oookJ_oo03T01?oonfX2o`3o`003oookJ_oo
00Ooo`07043ooo]Z1_oo03P7oookJPGoN@3o;OoonfX6ogT0oa3ooo]Z1?oo03QBoookJP00:ooonfX0
1Ooo003ooo]ZoookJ_oonf[oo`0000?ooo]Z00Goo`2ZoookJ_oonf[ooo]ZoeT0o`0<oookJP05obT0
oooonf[ooo]ZoookJ_l0oo002ooonfX00oooj03oo`0;oookJP05oookJP03oole0?oonf[o087o00?o
oo]Z00Ko0?nGoookJ_oonf[o0?oXoookJ_lfo`0@oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`04?oo
nfX00ol0ongooo]ZoookJP0>oookJP03oad0oooonf[ooo]Z00Gooo]Z00?oo`2doonW0?oonfX02ooo
nfX00ol0o`Wooo]ZoookJP04oookJP07og`0ooldo`3ooo]Zooo90?oo04oo00_oool06005oookJP03
ok3o0?oonf[o0?_o00Cooo]Z00?oCP3ooookJ_oonfX00ooonfX01?l007ooo`0Do`00OooonfX2o`00
O`04ooo70?oonf[ooo]ZoookJP?o001o0ooonfX01?ooZ03o001oo`00Oooo0:L3oookJP;oob4000Co
o`2do`00Ool007oooo]Z0ol007l4oookJP;o0?nG00?ooo]Zo`000?l000000_l00002ohko0003oook
J_oo03Wooo]Z00Cooo]Z00?o0?o0oookJ_oonfX00_oo00LooookJP_oogT01_oonfXDogT0oa?ooo]Z
1_mi0?lBoookJPCoo`0hP_oonfX01?l0odgooo]ZoookJ_oo0:X3oookJP03oeT0oooonf[ooo]Z00_o
oo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol00:oookJP03oooX0?oo00_ooo]Z00Gooo]Z00CoocD0oook
J_lgo`3o087o0ooonfX01Ol0oiOooo]Zo`3oj?oonf[o=_l0017ooo]Z00Co0>?ooookJ_oonf[oo`3/
4?oonfX00ol0ongooo]ZoookJP0>oookJP03oad0ool0oo;ooo]Z00Kooo]Z00?oo`2doonW0?oonfX0
2ooonfX00ol0o`Wooo]ZoookJP04oookJP07og`0ooldo`3o02goool0Col02ooooo]Zool06005oook
JP03ok3o0?l0nooooo]Z00?ooo]Z00?oCP3ooookJ_oonfX00ooonfX01?l007ooo`0Do`00OooonfX2
o`00O`04ooo70?oonf[ooo]ZoookJP?o001o0ooonfX01?ooZ03o001oo`00Oooo0:L3oookJP;oob40
00Coo`2do`00Ool007oooo]Z0ol007l5oookJP;o0?nG1?l000001?oonf[oS_l0oookJ_oo03T5oook
JP;o0?o000?ooo]Zool01ooo00L0A?oonfX6ool0>0Kooo]Z5?mi0?lCoookJPKoN@3o4_oonfX4ool0
>5Kooo]Z000_oookJP05ool00?oonf[ooo]ZoookJ_oo0:X00ooonfX00omI0?oooo]ZoookJP0;oook
JP05obT0oooonf[ooo]ZoookJ_l0oo002_oonfX00oooj03ooo]Zool02`06oookJP03oole0?lgo`3o
087o00?ooo]Z00Go0?nGoookJ_l0onSooo]ZocKo000AoookJP04o`3Soooonf[ooo]Zool0k17ooo]Z
00?o0?o]oookJ_oonfX03OoonfX00ooo6P3o7@3ooookJP06oookJP03ool0]?ooY`3ooo]Z00_ooo]Z
00?o0?l9oookJ_oonfX01?oonfX01oml0?oo=?l0oookJ_oob@3oo`1?o`0;oooo01P01?oonfX01?n`
o`3ooo]ZoookJ_l0nol4oookJP;oCP3o0_oonfX3o`00O`03ool05?oonf[ooo]Z00;o001o00?oolL0
oookJ_oonfX01ooonfX01?ooZ03o001ooookJ_oo0:L3oookJP03o`00Oooo8@3oo`2d00?ooo]Z0ol0
07l5oookJP03o`3oUol0003o000000;o00000_oonfX01?n>o`3ooo]Zool0>Ooo03T4oookJP;o0?o0
0_oonfX00ooo00Oooo]ZoookJP0noookJPSoogT000?ooo]Zoomi0?ooN@000oooN@0EoookJQ?oN@3o
5?oonfX4ool0>8Kooo]Z00Co0?m=oookJ_oonf[oo`2Z0ooonfX00omI0?oooo]ZoookJP0<oookJP05
obT0oooonf[ooo]ZoookJ_l0oo002_oonfX00oooj03oo`0;oookJP05oookJP03oole0?oonf[o087o
00?ooo]Z00Go0?nGoookJ_l0onSooo]ZocKo000AoookJP04o`3Soooonf[ooo]Zool0k17ooo]Z00?o
0?o]oookJ_oonfX03OoonfX00ooo6P3o7@3oo`3olP07oookJP03ool0]?ooY`3ooo]Z00_ooo]Z00?o
0?l9oookJ_oonfX01?oonfX01_ldo`3ooo]Zo`0]oooo04oo00_oool060Gooo]Z00?o/?l0oookJ_l0
nol01?oonfX2odh0o`;ooo]Z0ol007l00ooo01Cooo]ZoookJP02o`00O`03ooo70?oonf[ooo]Z00Oo
oo]Z00CoojP0o`00Oooonf[oo`2W0ooonfX00ol007ooob40ool0]003oookJP?o001o1_oonfX01?l0
oiOo0000o`000?l00002oookJP;oS_l00_oo03T5oookJP04o`3o`?oonf[ooo]Zool01dWooo]Z1Ooo
03PEoookJQ?oN@3o5?oonfX4ool0>5[ooo]Z000`oookJP04ool00?oonf[ooo]Zool0ZPCooo]Z00?o
F@3ooookJ_oonfX02_oonfX01OlY0?oooo]ZoookJ_oonf[o0?o`00_ooo]Z00?oonP0ool02ooonfX0
1OoonfX00ooo=@3ooo]Zo`21o`03oookJP06o`3oUooonf[ooo]Zo`3oj?oonf[o=_l04?oonfX01Ol0
hooooo]ZoookJ_oonf[oo`3/013ooo]Z00?o0?o]oookJ_oonfX03_oonfX00ooo6P3o7@3ooookJP06
oookJP03ool0]?ooY`3ooo]Z00_ooo]Z00?o0?l9oookJ_oonfX01?oonfX01_ml0?oo=?l0ooo90?oo
nf[oo`1?o`0;o`Gooo]Z00Co/?l0oookJ_oonf[o0?_o1OoonfX00om>0?oooo]Zo`00O`02o`00O`03
oookJ_oo01Cooo]Z00?o001o00?oolL0oookJ_oonfX01_oonfX01Ol007ooojP0o`00Oooonf[oo`2W
00Cooo]Z00Coob40ool0]?oonf[ooo]Z0ol007l6oookJP;o0?nG1?l000001Ooonf[oS_l0oookJ_oo
nf[oo`0i00Gooo]Z00?o0?o0oookJ_oonfX00_oo00M0oookJPKoogT01_oonfX6oomi03;ooo]Z1?oo
03R;oookJP03o`3oCOoonf[oo`2Z00Cooo]Z00?oF@3ooookJ_oonfX02ooonfX01OlY0?oooo]Zoook
J_oonf[o0?o`00[ooo]Z00?oonP0ool02ooonfX01OoonfX00ooo=@3ooo]Zo`21o`04oookJP05o`3o
Uooonf[o0?oXoookJ_lfo`004OoonfX01?l0hooooo]ZoookJ_oo0>`AoookJP03o`3okOoonf[ooo]Z
00gooo]Z00?ooaX0oad0oooonfX01_oonfX00ooo0;Cooo]ZoonW000<oookJP03o`3o2Ooonf[ooo]Z
00?ooo]Z00OoO03oocCo0?l0;Ooooo]Zool0Col02oooo`0H00Gooo]Z00?o/?l0oookJ_l0nol01Ooo
nfX00om>0?oooo]Zo`00O`02o`00O`03oookJ_oo01Cooo]Z00?o001o00?oolL0oookJ_oonfX01_oo
nfX01Ol007ooojP0o`00Oooonf[oo`2W00Cooo]Z00Coob40ool0]?oo0;Cooo]Z0ol007l6oookJP03
o`000?l0oiOo000000?o00000_oonfX00on>o`3ooo]Zool0>@05oookJP;o0?o000?ooo]Zool01ooo
00L0C?oonfX6ool0>3;ooo]Z1?oo03QNoookJP00<?oonfX01Ooo003ooo]ZoookJ_oonf[oo`2Z00?o
oo]Z00?oF@3ooookJ_oonfX02ooonfX01OlY0?oooo]ZoookJ_oonf[o0?o`00[ooo]Z00?oonP0oook
J_oo00/01_oonfX00ooo=@3ooo]Zo`21o`03oookJP05o`3oUooonf[o0?oXoookJ_lfo`004OoonfX0
1?l0hooooo]ZoookJ_oo0>`AoookJP03o`3okOoonf[ooo]Z00kooo]Z00?o7@3ooookJ_oonfX01_oo
nfX00ooo0;CoojL0oookJP0;oookJP03o`3o2Ooonf[ooo]Z00Cooo]Z00KoO03oocCo0?oob@3oo`1?
oookJ_l02ol5oookJP04ok3o0?oonf[ooo]Zo`3ko`Gooo]Z00CoCP3oo`00Ool007oo001o0_oonfX0
1_oo01Co001oo`00Ool007oooo]Zooo700Oooo]Z0_l007l01?ooZ03ooo]ZoookJ_oo0:L4oookJP;o
ob4000Cooo]Zo`00Ool007oo001o1_oonfX2o`000003o`3oUol0003ooo]Z00?ooo]Z00CoS_l0oook
J_oonf[oo`0i1OoonfX2o`3o`0;ooo]Z0_oo00M1oookJP?oogT03?oonfX6oomi02Sooo]Z1?oo03R?
oookJP04o`3oCOoonf[ooo]Zool0ZP?ooo]Z00?oF@3ooookJ_oonfX02ooonfX00olY0?oooo]Zoook
JP02oookJP03o`3ol?oonf[ooo]Z00Sooo]Z00?oonP0ool02ooonfX01OoonfX00ooo=@3ooo]Zo`21
o`03oookJP05o`3oUooonf[o0?oXoookJ_lfo`004OoonfX01?l0hooooo]ZoookJ_oo0>`AoookJP03
o`3okOoonf[ooo]Z00kooo]Z00?o7@3oo`3ol_oonfX01_oonfX00ooo0;Cooo]ZoonW000<oookJP03
o`3o2Ooonf[ooo]Z00?ooo]Z00OoO03oocCo0?l0;Ooooo]Zool0Col02oooo`0H00Gooo]Z00?o/?l0
oookJ_l0nol01OoonfX01?m>0?oo001oo`00Ool007l2oookJP06ool05?l007oo001oo`00Oooonf[o
olL01ooonfX2o`00O`04oonX0?oonf[ooo]Zool0Y`Cooo]Z0_oo8@001?oo0;Co001oo`00Ool007l6
oookJP;o00000_l0oiL5oookJP03ohko0?oonf[oo`0i00Kooo]Z00?o0?o0oookJ_oonfX00_oo00M@
oookJPKoo`0h:?oonfX4ool0>6;ooo]Z000aoookJP04ool00?oonf[ooo]Zool0ZP?ooo]Z00?oF@3o
oookJ_oonfX02ooonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Sooo]Z00?oonP0
ool02ooonfX01OoonfX00ooo=@3ooo]Zo`21o`03oookJP05o`3oUooonf[o0?oXoookJ_lfo`004_oo
nfX01?l0hooooo]ZoookJ_oo0>`@oookJP03o`3okOoonf[ooo]Z00kooo]Z00?ooaX0oad0oooonfX0
1_oonfX00ooo0;Cooo]ZoonW000<oookJP03o`3o2Ooonf[ooo]Z00Cooo]Z00KoO03oocCo0?oob@3o
o`1?oookJ_l02ol5oookJP04ok3o0?oonf[ooo]Zo`3ko`Gooo]Z00?oCP3oo`00Ool007l00ooonfX0
0ooo01Co001oo`00O`02oookJP03ooo70?oonf[ooo]Z00Gooo]Z0_l007l00oooZ03ooo]ZoookJP02
ool0Y`;o001o0_oonfX01?oo8@3o001oo`00Ool007l6oookJP?o000000?o0?nGoookJ_oonfX00ooo
nfX01?n>o`3ooo]ZoookJ_oo03T6oookJP04o`3o`?oonf[ooo]ZoookJP;oo`07@OoonfX00oooN@3o
oo]ZoookJP0@oookJP?oogT09Ooo03RCoookJP04o`3oCOoonf[ooo]Zool0ZP?ooo]Z00?oF@3ooook
J_oonfX03?oonfX01OlY0?oooo]ZoookJ_oonf[o0?o`00[ooo]Z00?oonP0ool02ooonfX01OoonfX0
0ooo=@3ooo]Zo`21o`04oookJP05o`3oUooonf[o0?oXoookJ_lfo`004OoonfX01?l0hooooo]Zoook
J_oo0>`AoookJP03o`3okOoonf[ooo]Z00gooo]Z00?ooaX0oad0ool0oo801ooonfX00ooo0;Cooo]Z
oonW000<oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z00OoO03oocCo0?l0;Ooooo]Zool0Col02oooo`0H
00Gooo]Z00?o/?l0oookJ_l0nol01OoonfX00om>0?oo001oo`00O`03oookJP03ool05?l007oo001o
00;ooo]Z00?oolL0oookJ_oonfX01OoonfX2o`00O`03oonX0?oonf[ooo]Z00;oo`2W0_l007l2oook
JP04oolQ0?oo0;Co001oo`00O`Kooo]Z1?l000000ol0oiOooo]ZoookJP03oookJP03ohko0?oonf[o
o`0i00Kooo]Z0_l0ol02oookJP;oo`07E?oonfXXool0>6Kooo]Z000aoookJP04ool00?oonf[ooo]Z
ool0ZPCooo]Z00?oF@3ooookJ_oonfX02ooonfX01OlY0?oooo]ZoookJ_oonf[o0?o`00[ooo]Z00?o
onP0oookJ_oo00/01_oonfX00ooo=@3ooo]Zo`21o`03oookJP05o`3oUooonf[o0?oXoookJ_lfo`00
4OoonfX01?l0hooooo]ZoookJ_oo0>`AoookJP03o`3okOoonf[ooo]Z00kooo]Z00?ooaX0oad0oooo
nfX01_oonfX00ooo0;Cooo]ZoonW000<oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z00OoO03ooookJ_ld
o`3oolT0ool0Cooonf[o00_o00Gooo]Z00Co/?l0oookJ_oonf[o0?_o1?oonfX00ol007ooCP3oo`00
O`03oookJP03o`00Oooo01Co001o00?ooo]Z00?oolL0oookJ_oonfX01?oonfX3o`00O`05oonX0?oo
nf[ooo]ZoookJ_oo0:L01?l007l00ooo8@3oo`2doookJP06oookJPCo00000_l0oiL4oookJP;oS_l0
00?ooo]Zool0>Ooo03T01OoonfX2o`3o`0?ooo]Z00?oo`07oookJ_oonfX0oooonfX>oookJP03o`3o
COoonf[oo`2Z00Cooo]Z00?oF@3ooookJ_oonfX02ooonfX00olY0?oooo]ZoookJP02oookJP03o`3o
l?oonf[ooo]Z00Sooo]Z00?oonP0ool02ooonfX01OoonfX00ooo=@3ooo]Zo`21o`03oookJP05o`3o
Uooonf[o0?oXoookJ_lfo`004_oonfX00ol0hooooo]Zool0k00BoookJP03o`3okOoonf[ooo]Z00go
oo]Z00?ooaX0oad0ool0oo801_oonfX01?oo0;Cooo]ZoookJ_ooY`0;oookJP03o`3o2Ooonf[ooo]Z
00Cooo]Z00KoO03oocCo0?l0;Ooooo]Zool0Col02ol6oookJP03ok3o0?oonf[o0?_o00Cooo]Z00?o
001oodh0ool007l00ooonfX00ol007ooo`0Do`00O`03oookJP03ooo70?oonf[ooo]Z00Cooo]Z0ol0
07l01OooZ03ooo]ZoookJ_oonf[oo`2W00Co001o00?oob40ool0]?oonfX01_oonfX4o`000003oook
J_l0oiOooo]Z00Cooo]Z0_n>o`02ool0>@Kooo]Z00Go0?o0oookJ_oonf[ooo]Zool01`3QoookJP00
<_oonfX01?oo003ooo]ZoookJ_oo0:X3oookJP03oeT0oooonf[ooo]Z00_ooo]Z00?o:@3ooookJ_oo
nfX00_oonfX00ol0oo3ooo]ZoookJP08oookJP03oooX0?oo00_ooo]Z00Gooo]Z00?oocD0oookJ_l0
POl00ooonfX01Ol0oiOooo]Zo`3oj?oonf[o=_l001;ooo]Z00Co0>?ooookJ_oonf[oo`3/4OoonfX0
0ol0ongooo]ZoookJP0>oookJP03oolJ0?lM0?oooo]Z00Kooo]Z00?oo`2doookJ_ooY`003?oonfX0
0ol0o`Wooo]ZoookJP03oookJP07og`0oooonf[o=?l0ooo90?oo04ooo`0Ho`0;o`05oookJP04ok3o
0?oonf[ooo]Zo`3ko`?ooo]Z0_l007l01?m>0?oooo]ZoookJ_oonfX2o`00O`03ool05?oonf[ooo]Z
00;ooo]Z00?oolL0oookJ_oonfX01?oonfX2o`00O`06oookJ_ooZ03ooo]ZoookJ_l007ooo`2W1?l0
07l2oolQ00Kooo]Z1?l00002oookJP03o`3oUooonf[ooo]Z00?ooo]Z0_n>o`000ooonf[oo`0iool0
>@05oookJP04o`3o`?oonf[ooo]ZoookJP;oo`07oooonfX>oookJP04o`3oCOoonf[ooo]Zool0ZP?o
oo]Z00?oF@3ooookJ_oonfX03?oonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Oo
oo]Z00?oonP0ool02ooonfX01OoonfX01?oo=@3ooo]Zo`21oolgo`03oookJP05o`3oUooonf[o0?oX
oookJ_lfo`004OoonfX01?l0hooooo]ZoookJ_oo0>`AoookJP03o`3okOoonf[ooo]Z00kooo]Z00?o
oaX0oad0ool0oo801_oonfX00ooo0;Cooo]ZoonW000<oookJP03o`3o2Ooonf[ooo]Z00Cooo]Z00Ko
O03oocCo0?l0;Ooooo]Zool0Col02ol6oookJP03ok3o0?oonf[o0?_o00?ooo]Z0_l007l01?m>0?oo
oo]ZoookJ_oonfX2o`00O`03ool05?oonf[ooo]Z00;ooo]Z00?oolL0oookJ_oonfX01?oonfX2o`00
O`06oookJ_ooZ03ooo]ZoookJ_l007ooo`2W1?l007l2oolQ00Kooo]Z1?l00002oookJP;o0?nG1Ooo
nfX2ohko00;oo`0i1OoonfX2o`3o`0;ooo]Z0_oo00OOoookJP00<_oonfX01?oo003ooo]ZoookJ_oo
0:X4oookJP03oeT0oooonf[ooo]Z00_ooo]Z00Go:@3ooookJ_oonf[ooo]Zo`3ol00:oookJP03oooX
0?oonf[oo`0;00Gooo]Z00CoocD0oookJ_oonf[o087o0ooonfX01Ol0oiOooo]Zo`3oj?oonf[o=_l0
017ooo]Z00Co0>?ooookJ_oonf[oo`3/4OoonfX00ol0ongooo]ZoookJP0>oookJP03oolJ0?l0oo;o
7@3o00Kooo]Z00?oo`2doookJ_ooY`003?oonfX00ol0o`Wooo]ZoookJP04oookJP07og`0ooldo`3o
oo]Zooo90?oo04ooo`0Ho`0;o`05oookJP04ok3o0?oonf[ooo]Zo`3ko`;ooo]Z0ol007l00om>0?oo
oo]ZoookJP03o`00O`03ool05?oonf[ooo]Z00;ooo]Z00?oolL0oookJ_oonfX01?oonfX2o`00O`03
oookJ_ooZ03ooo]Z00;o001o00?oo`2WoookJ_oonfX00ooonfX00ooo8@3ooo]ZoookJP03oookJPCo
00000ooonfX00ol0oiOooo]ZoookJP04oookJP03ohko0?oonf[ooo]Z00;oo`0i1?oonfX2o`3o`0?o
oo]Z0_oo00OooookJPgooo]Z00?o0?m=oookJ_oo0:X01?oonfX00omI0?oooo]ZoookJP0;oookJP03
obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX02?oonfX00oooj03oo`0;oookJP05oookJP03
oole0?oonf[o087o00?ooo]Z00Go0?nGoookJ_l0onSooo]ZocKo000BoookJP03o`3Soooonf[oo`3/
01;ooo]Z00?o0?o]oookJ_oonfX03OoonfX00ooo6P3ooo]Zoad0o`07oookJP03ool0]?oonf[oojL0
00cooo]Z00?o0?l9oookJ_oonfX00ooonfX01oml0?oooo]ZocCo0?l0;Ooooo]Zool0Col02ol01_oo
nfX00on`o`3ooo]Zo`3ko`02oookJP?o001o00?oCP3ooookJ_oonfX00ol007l2ool050?ooo]Z00?o
olL0oookJ_oonfX01?oonfX2o`00O`03oookJ_ooZ03ooo]Z00;o001o00?oo`2WoookJ_oonfX00ooo
nfX00ooo8@3oo`2doookJP03oookJPCo00001?oonfX00ol0oiOooo]ZoookJP04oookJP04ohko0?oo
nf[oo`0iool0>@Gooo]Z00Co0?o0oookJ_oonf[ooo]Z0_oo00OMoookJP00<ooonfX00ooo003ooo]Z
ool0ZP04oookJP03oeT0oooonf[ooo]Z00_ooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]Z
oookJP08oookJP03oooX0?oo00_ooo]Z00Gooo]Z00?oocD0oookJ_l0POl00ooonfX01Ol0oiOooo]Z
o`3oj?oonf[o=_l001;ooo]Z00Co0>?ooookJ_oonf[oo`3/4OoonfX00ol0ongooo]ZoookJP0>oook
JP03oolJ0?lM0?oooo]Z00Kooo]Z00?oo`2doookJ_ooY`003?oonfX00ol0o`Wooo]ZoookJP04oook
JP06og`0ooldo`3oolT0oookJ_oo04oo00_o1OoonfX01On`o`3ooo]ZoookJ_oonf[o0?_o00;ooo]Z
0ol007l01?m>0?oo001oo`00Ool007l2oookJP03ool05?oonf[ooo]Z00;ooo]Z00?oolL0oookJ_oo
nfX00ooonfX2o`00O`;ooo]Z00GoojP0o`00Ool007oooo]Zool0Y`05oookJP03oolQ0?oonf[ooo]Z
00;ooo]Z1?l00004oookJP;o0?nG1OoonfX2ohko00;ooo]Z00?oo`0ioookJ_oonfX00ooonfX00ol0
ol3ooo]ZoookJP02oookJP;oo`07oooonfX;oookJP03o`3oCOoonf[oo`2Z00Cooo]Z00?oF@3ooook
J_oonfX03?oonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Oooo]Z00?oonP0ool0
2ooonfX01OoonfX01?oo=@3ooo]Zo`21oolgo`03oookJP04o`3oUooonf[o0?oXocKo01?ooo]Z00?o
0>?ooookJ_oo0>`04_oonfX00ol0ongooo]ZoookJP0=oookJP03oolJ0?lM0?oo0?ob00Kooo]Z00Co
o`2doookJ_oonf[oojL03?oonfX00ol0o`Wooo]ZoookJP03oookJP03og`0oooonf[o=?l000;ooo]Z
00?o00_oool06?oonfX01?oonfX01?n`o`3ooo]ZoookJ_l0nol2oookJP?o001o00CoCP3oo`00Ool0
07oo001o0ooonfX01Ooo01Cooo]ZoookJ_oonf[oolL000Gooo]Z0_l007l2oookJP05oonX0?l007oo
001ooookJ_oo0:L01OoonfX00ooo8@3oo`2doookJP02oookJPCo00001OoonfX00ol0oiOooo]Zoook
JP04oookJP;oS_l000?ooo]Zool0>OoonfX01?oonfX2o`3o`0?ooo]Z0_oo00OKoookJP00<ooonfX0
1?oo003ooo]ZoookJ_oo0:X4oookJP03oeT0oooonf[ooo]Z00_ooo]Z00Go:@3ooookJ_oonf[ooo]Z
o`3ol00:oookJP03oooX0?oonf[oo`0;00Gooo]Z00CoocD0oookJ_l0POoo=ol00ooonfX01Ol0oiOo
oo]Zo`3oj?oonf[o=_l001;ooo]Z00Co0>?ooookJ_oonf[oo`3/4OoonfX00ol0ongooo]ZoookJP0>
oookJP03oolJ0?lM0?oooo]Z00Kooo]Z00?oo`2doookJ_ooY`003?oonfX00ol0o`Wooo]ZoookJP04
oookJP07og`0ooldo`3oolT0oookJ_oo04oo00_oool06004oookJP06ok3o0?oonf[ooo]ZoookJ_l0
nooooo]Z1?l007l00om>0?oo001oo`00O`03oookJP06ool05?oonf[ooo]ZoookJ_l007ooolL01ol0
07l2oookJP;oojP00_l007l01?oo0:Oo001oo`00Ool007l2oookJP04oolQ0?oonf[ooo]ZoookJPCo
00001_oonfX00ol0oiOooo]ZoookJP04oookJP;oS_l000?ooo]Zool0>Ooo03T01?oonfX2o`3o`0Co
oo]Z00?oo`07oookJ_oonfX0oooonfX9oookJP03o`3oCOoonf[oo`2Z00Cooo]Z00?oF@3ooookJ_oo
nfX02ooonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Sooo]Z00?oonP0ool02ooo
nfX01OoonfX00ooo=@3ooo]Zo`21o`04oookJP04o`3oUol0onSooo]ZocKo01;ooo]Z00Co0>?ooook
J_oonf[oo`3/4OoonfX00ol0ongooo]ZoookJP0>oookJP03oolJ0?lM0?oo0?ob00Kooo]Z00Coo`2d
oookJ_oonf[oojL03?oonfX00ol0o`Wooo]ZoookJP03oookJP06og`0oooonf[o=?l0oookJ_oo04oo
00_o0_oo01P4oookJP05ok3o0?oonf[ooo]Zo`3koooonfX01?l007l00om>0?oo001oo`00O`04oook
JP05ool05?oonf[ooo]Zo`00Ooooa`001ol007l2oookJP;oojP00_l007l01?oo0:Oo001oo`00Ool0
07l2oookJP;oob400_oonfX4o`0000Kooo]Z00?o0?nGoookJ_oonfX01OoonfX2ohko00;oo`0i1Ooo
nfX00ol0ol3ooo]ZoookJP02oookJP03ool01ooonf[ooo]Z0=Sooo]Z000doookJP03ool00?oonf[o
o`2Z00Cooo]Z00?oF@3ooookJ_oonfX02ooonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[o
oo]Z00Sooo]Z00?oonP0oookJ_oo00/01OoonfX00ooo=@3ooo]Zo`21o`04oookJP04o`3oUol0onSo
oo]ZocKo01;ooo]Z00Co0>?ooookJ_oonf[oo`3/4OoonfX00ol0ongooo]ZoookJP0>oookJP03oolJ
0?oonf[o7@3o00Oooo]Z00?oo`2doookJ_ooY`003?oonfX00ol0o`Wooo]ZoookJP04oookJP07og`0
ooldo`3oolT0oookJ_oo04oo00_oool06004oookJP06ok3o0?oonf[ooo]ZoookJ_l0nooooo]Z1?l0
07l00om>0?oooo]ZoookJP03oookJP03ool05?oonf[ooo]Z00;o001o00?oolL0o`00Ool007l01?l0
07l3oookJP04o`00OoooZ03o001oo`00O`;oo`2W00Co001ooookJ_oonf[ooo]Z0_oo8@000ooonf[o
0000o`000002o`0000Oooo]Z00?o0?nGoookJ_oonfX01OoonfX00on>o`3ooo]ZoookJP02ool0>@Co
oo]Z00?o0?o0oookJ_oonfX00_oonfX2ool01ooooo]Z2OoonfX00ol0odgooo]Zool0ZP04oookJP03
oeT0oooonf[ooo]Z00cooo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP07oookJP03
oooX0?oonf[oo`0;00Gooo]Z00CoocD0oookJ_l0POoo=ol00ooonfX01?l0oiOo0?oXoookJ_lfo`0C
oookJP04o`3Soooonf[ooo]Zool0k17ooo]Z00?o0?o]oookJ_oonfX03OoonfX01?oo6P3ooo]Zoad0
ool0oo86oookJP04ool0]?oonf[ooo]ZoonW00cooo]Z00?o0?l9oookJ_oonfX00ooonfX02?ml0?oo
oo]ZocCo0?oonf[oo`1?o`0;oooonf[oo`0H1?oonfX01On`o`3ooo]ZoookJ_l0nooooo]Z00Co001o
00?oCP3ooookJ_oonfX01?oonfX01Ooo01Cooo]Zo`00Ool007ooolL000Ko001o0ooonfX01?l007oo
ojP0o`00Ool007l2ool0Y`03o`00Oooonf[ooo]Z00;ooo]Z00?oob40oookJ_l000000ol00007oook
JP;o0?nG1ooonfX01?n>o`3ooo]Zool0>Ooo03T4oookJP;o0?o00ooonfX2ool01mSooo]Z000doook
JP03ool00?oonf[oo`2Z00Gooo]Z00?oF@3ooookJ_oonfX02ooonfX01OlY0?oooo]ZoookJ_oonf[o
0?o`00[ooo]Z00?oonP0oookJ_oo00/01OoonfX01?oo=@3ooo]Zo`21oolgo`03oookJP05o`3oUooo
nf[o0?oXoookJ_lfo`004_oonfX01?l0hooooo]ZoookJ_oo0>`AoookJP03o`3okOoonf[ooo]Z00ko
oo]Z00?ooaX0oookJ_lM0?l01_oonfX01?oo0;Cooo]ZoookJ_ooY`0<oookJP03o`3o2Ooonf[ooo]Z
00?ooo]Z00SoO03ooookJ_ldo`3oolT0oookJ_oo04oo00_oool060Cooo]Z00Go/?l0oookJ_oonf[o
oo]Zo`3ko`05oookJP03odh0oooonf[ooo]Z00?ooo]Z00?oo`0DoookJ_oonfX00_oonfX00oooa`3o
oo]ZoookJP08oookJP05oonX0?oonf[ooo]ZoookJ_oo0:L01?oonfX00ooo0;Coob40o`000003o`00
00Sooo]Z0_l0oiL6oookJP;oS_l00_oonfX2ool0>@?ooo]Z0_l0ol04oookJP;oo`07oooonfX8oook
JP03o`3oCOoo0:[ooo]Z00Cooo]Z00?oF@3ooookJ_oonfX02ooonfX00olY0?oooo]ZoookJP02oook
JP03o`3ol?oonf[ooo]Z00Sooo]Z00?oonP0ool02ooonfX01OoonfX00ooo=@3ooo]Zo`21o`04oook
JP04o`3oUol0onSooo]ZocKo01;ooo]Z00Co0>?ooookJ_oonf[oo`3/4_oonfX00ol0ongooo]Zoook
JP0=oookJP04oolJ0?oonf[o7@3oo`3olPGooo]Z00Goo`2doookJ_oonf[ooo]ZoonW000;oookJP03
o`3o2Ooonf[ooo]Z00?ooo]Z00WoO03ooookJ_ldo`3o02gooookJ_oo04oo00_ooookJ_oo01P01?oo
nfX01?n`o`3ooo]ZoookJ_l0nol5oookJP03odh0oooonf[ooo]Z00Cooo]Z00Goo`0DoookJ_oonf[o
oo]Zooo7000:oookJP05oonX0?oonf[ooo]ZoookJ_oo0:L01OoonfX00ooo8@3oo`2do`000002o`00
00Wooo]Z00?o0?nGoookJ_oonfX01OoonfX2ohko0003oookJ_oo03Woo`0i00Cooo]Z0_l0ol03oook
JP;oo`07e_oonfX003Cooo]Z00Coo`00oookJ_oonf[oo`2Z1?oonfX00omI0?oooo]ZoookJP0;oook
JP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX02?oonfX00oooj03ooo]Zool02`05oook
JP04oole0?oonf[o087oocOo00?ooo]Z00Co0?nGo`3oj?oonf[o=_l04_oonfX01Ol0hooooo]Zoook
J_oonf[oo`3/013ooo]Z00?o0?o]oookJ_oonfX03ooonfX00ooo6P3o7@3oo`3olP06oookJP04ool0
]?oonf[ooo]ZoonW00cooo]Z00?o0?l9oookJ_oonfX00ooonfX02?ml0?oooo]ZocCo0?oob@3ooo]Z
ool0Col02oooo`0H1?oonfX01On`o`3ooo]ZoookJ_oonf[o0?_o00Gooo]Z0_m>0?l4oookJP;oo`0D
0ooonfX2ooo700Wooo]Z0_ooZ002oookJP03ool0Yooonf[ooo]Z00?ooo]Z00Coob40o`000?l0003o
00002_oonfX00ol0oiOooo]ZoookJP05oookJP;oS_l00_oonfX2ool0>@?ooo]Z00?o0?o0oookJ_oo
nfX00ooonfX2ool01ooooo]Z1_oonfX00ol0odgooo]Zool0ZP04oookJP03oeT0oooonf[ooo]Z00co
oo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP07oookJP03oooX0?oonf[oo`0;00Go
oo]Z00CoocD0oookJ_l0POoo=ol00ooonfX01?l0oiOo0?oXoookJ_lfo`0CoookJP04o`3Soooonf[o
oo]Zool0k17ooo]Z00?o0?o]oookJ_oonfX03_oonfX00ooo6P3o7@3oo`3olP06oookJP04ool0]?oo
nf[ooo]ZoonW00cooo]Z00?o0?l9oookJ_oonfX00ooonfX02Oml0?oooo]ZocCo0?l0;Ooooo]Zool0
Col02ooooo]Zool06004oookJP04ok3o0?oonf[ooo]Zo`3ko`Gooo]Z0_m>0?l5oookJP04ool05?oo
nf[ooo]ZoookJP;oolL02OoonfX2oonX00;ooo]Z00?oo`2WoookJ_oonfX00ooonfX2oolQ00;o0000
2_oonfX00ol0oiOooo]ZoookJP06oookJP;oS_l000?ooo]Zool0>Ooo03T01?oonfX00ol0ol3ooo]Z
oookJP02oookJP;oo`07e?oonfX003Gooo]Z00?oo`00oookJ_oo0:X01OoonfX00omI0?oooo]Zoook
JP0;oookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01ooonfX00oooj03ooo]Zool0
2`05oookJP04oole0?oonf[o087oocOo00?ooo]Z00Go0?nGoookJ_l0onSooo]ZocKo000BoookJP05
o`3Soooonf[ooo]ZoookJ_oo0>`04?oonfX00ol0ongooo]ZoookJP0>oookJP03oolJ0?oonf[o7@3o
00Oooo]Z00Coo`2doookJ_oonf[oojL03?oonfX00ol0o`Wooo]ZoookJP03oookJP08og`0oooonf[o
=?l0ooo90?oonf[oo`1?o`0;oooo01P4oookJP05ok3o0?oonf[ooo]ZoookJ_l0nol01_oonfX00om>
0?oooo]ZoookJP03oookJP03ool05?oonf[ooo]Z00;ooo]Z00?oolL0oookJ_oonfX02?oonfX01?oo
Z03ooo]ZoookJ_oo0:L4oookJP03o`000?oo8@3oob4000;o00002_oonfX2o`3oU`Oooo]Z0_n>o`02
oookJP04ool0>Ooonf[ooo]ZoookJP;o0?o01OoonfX00ooo00Oooo]ZoookJP3ooookJPCooo]Z00?o
0?m=ool0Z_oonfX01?oonfX00omI0?oooo]ZoookJP0;oookJP03obT0oooonf[ooo]Z00;ooo]Z00?o
0?o`oookJ_oonfX02?oonfX00oooj03oo`0;oookJP05oookJP04oole0?oonf[o087oocOo00?ooo]Z
00Co0?nGo`3oj?oonf[o=_l04ooonfX01?l0hooooo]ZoookJ_oo0>`AoookJP03o`3okOoonf[ooo]Z
00gooo]Z00CooaX0oookJ_lM0?oo0?ob1_oonfX01?oo0;Cooo]ZoookJ_ooY`0<oookJP03o`3o2Ooo
nf[ooo]Z00?ooo]Z00WoO03ooookJ_ldo`3o02gooookJ_oo04oo00_ooookJ_oo01P01?oonfX01?n`
o`3ooo]ZoookJ_l0nol6oookJP03odh0oooonf[ooo]Z00?ooo]Z00?oo`0DoookJ_oonfX00_oonfX0
0oooa`3ooo]ZoookJP08oookJP04oonX0?oonf[ooo]Zool0Y`Cooo]Z0_l000000ooo8@3o0000o`00
000:oookJP;o0?nG2?oonfX01?n>o`3ooo]ZoookJ_oo03T4oookJP;o0?o01?oonfX00ooo00Oooo]Z
oookJP3AoookJP00=OoonfX01?oo003ooo]ZoookJ_oo0:X5oookJP03oeT0oooonf[ooo]Z00[ooo]Z
00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP08oookJP03oooX0?oonf[oo`0;00Gooo]Z
00CoocD0oookJ_l0POoo=ol00ooonfX01Ol0oiOo0?oXoookJ_oonf[o=_l001;ooo]Z00Co0>?ooook
J_oonf[oo`3/4OoonfX00ol0ongooo]ZoookJP0>oookJP03oolJ0?oonf[o7@3o00Kooo]Z00Coo`2d
oookJ_oonf[oojL03OoonfX00ol0o`Wooo]ZoookJP03oookJP03og`0ooldo`3oolT000;ooo]Z00?o
o`1?o`0;oooo01P01?oonfX2ok3o00;ooo]Z00?o0?_ooookJ_oonfX01?oonfX00om>0?oooo]Zoook
JP03oookJP03ool05?oonf[ooo]Z00;ooo]Z00?oolL0oookJ_oonfX02?oonfX01?ooZ03ooo]Zoook
J_oo0:L3oookJP;o000000?oo`2doolQ0?oonfX03?oonfX00ol0oiOooo]ZoookJP06oookJP03ohko
0?oonf[ooo]Z00;oo`0i0ooonfX00ol0ol3ooo]ZoookJP03oookJP;oo`07oooonfX4oookJP03o`3o
COoonf[oo`2Z00Gooo]Z00?oF@3ooookJ_oonfX02ooonfX00olY0?oooo]ZoookJP02oookJP03o`3o
l?oonf[ooo]Z00Oooo]Z00?oonP0oookJ_oo00/01OoonfX01?oo=@3ooo]Zo`21oolgo`03oookJP05
o`3oUol0onSooo]ZoookJ_lfo`004_oonfX01?l0hooooo]ZoookJ_oo0>`BoookJP03o`3okOoonf[o
oo]Z00gooo]Z00CooaX0oookJ_lM0?oo0?ob1_oonfX01?oo0;Cooo]ZoookJ_ooY`0<oookJP03o`3o
2Ooonf[ooo]Z00?ooo]Z00?oO03ooookJ_ldo`000_oonfX01?oo04oo00_ooookJ_oo01P4oookJP;o
/?l000?ooo]Zo`3koooonfX01OoonfX00om>0?oooo]ZoookJP03oookJP03ool05?oonf[ooo]Z00;o
oo]Z00?oolL0oookJ_oonfX02?oonfX01?ooZ03ooo]ZoookJ_oo0:L3oookJP?o00000_oo8@0<oook
JP03o`3oUooonf[ooo]Z00Kooo]Z0_n>o`000ooonf[oo`0iool0>@04oookJP03o`3o`?oonf[ooo]Z
00;ooo]Z0_oo00OAoookJP00=_oonfX00ooo003ooo]Zool0ZP05oookJP03oeT0oooonf[ooo]Z00_o
oo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP07oookJP03oooX0?oonf[oo`0;00Go
oo]Z00CoocD0oookJ_l0POoo=ol00ooonfX01Ol0oiOooo]Zo`3oj?oonf[o=_l001;ooo]Z00Go0>?o
oookJ_oonf[ooo]Zool0k00@oookJP03o`3okOoonf[ooo]Z00oooo]Z00?ooaX0oookJ_lM0?l01_oo
nfX01?oo0;Cooo]ZoookJ_ooY`0<oookJP03o`3o2Ooonf[ooo]Z00Cooo]Z00SoO03oocCo0?oob@3o
oo]Zool0Cooonf[o00_oool060Gooo]Z00Co/?l0oookJ_oonf[o0?_o1_oonfX00om>0?oooo]Zoook
JP03oookJP03ool05?oonf[ooo]Z00;ooo]Z00?oolL0oookJ_oonfX02?oonfX2oonX0004oookJ_oo
0:Ooo`2WoookJP?o000000?oo`2doolQ0?oonfX03?oonfX00ol0oiOooo]ZoookJP06oookJP;oS_l0
0_oonfX2ool0>@;ooo]Z0_l0ol05oookJP;oo`07oooonfX2oookJP03o`3oCOoonf[oo`2Z00Gooo]Z
00?oF@3ooookJ_oonfX02ooonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Sooo]Z
00?oonP0ool02ooonfX01?oonfX01Ooo=@3ooo]ZoookJ_l0POoo=ol000?ooo]Z00Co0?nGo`3oj?oo
nf[o=_l04ooonfX01?l0hooooo]ZoookJ_oo0>`AoookJP03o`3okOoonf[ooo]Z00kooo]Z00CooaX0
oookJ_lM0?oo0?ob1OoonfX01Ooo0;Cooo]ZoookJ_oonf[oojL000cooo]Z00?o0?l9oookJ_oonfX0
0ooonfX2og`0o`07ocCo0?oonf[ooo]Zool0Col02ooooo]Zool06005oookJP03ok3o0?oonf[o0?_o
00Kooo]Z00?oCP3ooookJ_oonfX00ooonfX00ooo01Cooo]ZoookJP02oookJP;oolL02OoonfX2oonX
0004oookJ_oo0:Ooo`2WoookJPCo000000?oo`2doolQ0?oonfX02ooonfX00ol0oiOooo]ZoookJP07
oookJP;oS_l000?ooo]Zool0>Ooo03T00ooonfX2o`3o`0Cooo]Z0_oo00O?oookJP00=_oonfX01?oo
003ooo]ZoookJ_oo0:X5oookJP03oeT0oooonf[ooo]Z00[ooo]Z00?o:@3ooookJ_oonfX00_oonfX0
0ol0oo3ooo]ZoookJP08oookJP03oooX0?oonf[oo`0;00Gooo]Z00CoocD0oookJ_l0POoo=ol00ooo
nfX01Ol0oiOo0?oXoookJ_oonf[o=_l001;ooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00@oookJP03
o`3okOoonf[ooo]Z00kooo]Z00CooaX0oookJ_oonf[o7@3o1_oonfX01?oo0;Cooo]ZoookJ_ooY`0<
oookJP03o`3o2Ooonf[ooo]Z00Gooo]Z00Oo=?l0ooo90?oonf[oo`1?oookJ_l02oooo`0H00Gooo]Z
00Co/?l0oookJ_oonf[o0?_o1_oonfX00om>0?oooo]ZoookJP03oookJP03ool05?oonf[ooo]Z00;o
oo]Z0_ooa`0:oookJP04oonX0?oonf[ooo]Zool0Y`Co000000?oo`2doolQ0?oo8@003?oonfX2o`3o
U`Sooo]Z0_n>o`02oookJP;oo`0i0_oonfX00ol0ol3ooo]ZoookJP04oookJP;oo`07oooonfX1oook
JP03o`3oCOoonf[oo`2Z00Gooo]Z00?oF@3ooookJ_oonfX02ooonfX00olY0?oooo]ZoookJP02oook
JP03o`3ol?oonf[ooo]Z00Oooo]Z00?oonP0oookJ_oo00/01OoonfX01?oo=@3ooo]Zo`21oolgo`03
oookJP05o`3oUol0onSooo]ZoookJ_lfo`004_oonfX01Ol0hooooo]ZoookJ_oonf[oo`3/017ooo]Z
00?o0?o]oookJ_oonfX03OoonfX01?oo6P3ooo]ZoookJ_lM0?l6oookJP05ool0]?oonf[ooo]Zoook
J_ooY`003?oonfX00ol0o`Wooo]ZoookJP04oookJP08og`0ooldo`3ooo]ZoookJ_oo04oo00_ooook
J_oo01P5oookJP03ok3o0?oonf[o0?_o00Kooo]Z00?oCP3ooookJ_oonfX00ooonfX00ooo01Cooo]Z
oookJP03oookJP03ooo70?oonf[ooo]Z00Sooo]Z00CoojP0oookJ_oonf[oo`2W1?l000000ooonf[o
o`2doolQ000<oookJP;o0?nG2OoonfX00on>o`3ooo]ZoookJP02ool0>@?ooo]Z00?o0?o0oookJ_oo
nfX00ooonfX2ool01lgooo]Z000goookJP03ool00?oonf[oo`2Z00Gooo]Z00?oF@3ooookJ_oonfX0
2ooonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Oooo]Z00?oonP0oookJ_oo00/0
1OoonfX01?oo=@3ooo]Zo`21oolgo`03oookJP03o`3oUooonf[o0?oX00;ooo]Z00?o=_l0oookJ_oo
nfX03ooonfX01Ol0hooooo]ZoookJ_oonf[oo`3/017ooo]Z00?o0?o]oookJ_oonfX03_oonfX01?oo
6P3ooo]Zoad0ool0oo86oookJP04ool0]?oonf[ooo]ZoonW00cooo]Z00?o0?l9oookJ_oonfX01Ooo
nfX01oldo`3oolT0oookJ_oo04oo00_ooookJ_oo01P01OoonfX01?n`o`3ooo]ZoookJ_l0nol6oook
JP03odh0oooonf[ooo]Z00?ooo]Z00?oo`0DoookJ_oonfX00ooonfX00oooa`3ooo]ZoookJP08oook
JP04oonX0?oonf[ooo]Zool0Y`?o00000_oonfX00ooo0;Coob40oookJP0<oookJP03o`3oUooonf[o
oo]Z00Oooo]Z00CoS_l0oookJ_oonf[ooo]Z0_oo03T00ooonf[o0?o0o`3o`006oookJP03ool01ooo
nf[ooo]Z0?gooo]Z00?o0?m=oookJ_oo0:X01OoonfX00omI0?oooo]ZoookJP0;oookJP03obT0oooo
nf[ooo]Z00?ooo]Z00?o0?o`oookJ_oonfX01ooonfX00oooj03oo`0;oookJP04oookJP05oole0?oo
nf[o087ooookJ_lgo`000ooonfX01Ol0oiOo0?oXoookJ_oonf[o=_l001;ooo]Z00Go0>?ooookJ_oo
nf[ooo]Zool0k00@oookJP03o`3okOoonf[ooo]Z00kooo]Z00CooaX0oookJ_lM0?oo0?ob1_oonfX0
1Ooo0;Cooo]ZoookJ_oonf[oojL000_ooo]Z00?o0?l9oookJ_oonfX01OoonfX01Oml0?oo=?l0oook
J_oonf[o00_o00;ooo]Z00?oo`0HoookJ_oonfX00ooonfX00on`o`3ooo]Zo`3ko`06oookJP03odh0
oooonf[ooo]Z00?ooo]Z00?oo`0DoookJ_oonfX00ooonfX00oooa`3ooo]ZoookJP08oookJP04oonX
0?oonf[ooo]Zool0Y`?o00000ooonfX2oolQ00cooo]Z00?o0?nGoookJ_oonfX01ooonfX2ohko00;o
oo]Z0_oo03T2oookJP;o0?o01OoonfX00ooo00Oooo]ZoookJP3:oookJP009OoonfX00ooo3@3ooo]Z
oookJP0?oookJP04ool00?oonf[ooo]Zool0ZPGooo]Z00?oF@3ooookJ_oonfX02_oonfX00olY0?oo
oo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Sooo]Z00?oonP0oookJ_oo00/01OoonfX01?oo=@3o
oo]Zo`21oolgo`03oookJP05o`3oUooonf[o0?oXoookJ_lfo`004_oonfX01Ol0hooooo]ZoookJ_oo
nf[oo`3/013ooo]Z00?o0?o]oookJ_oonfX03ooonfX00ooo6P3ooo]Zoad0o`06oookJP05ool0]?oo
nf[ooo]ZoookJ_ooY`003?oonfX00ol0o`Wooo]ZoookJP05oookJP07ocCo0?oob@3ooo]Zool0Col0
2ooooo]Zool06005oookJP04ok3o0?oonf[ooo]Zo`3ko`Kooo]Z00?oCP3ooookJ_oonfX00ooonfX0
0ooo01Cooo]ZoookJP03oookJP03ooo70?oonf[ooo]Z00Sooo]Z0_ooZ0001?l0003oo`2Wo`000?l0
0003oookJP03ool0]?oo8@3ooo]Z00cooo]Z00?o0?nGoookJ_oonfX01ooonfX2ohko00?ooo]Z00?o
o`0ioookJ_oonfX00ol0ol04oookJP;oo`07jooonfX00ooo3@3ooo]ZoookJP0@oookJP03o`3oCOoo
nf[oo`2Z00Gooo]Z00?oF@3ooookJ_oonfX02_oonfX00olY0?oooo]ZoookJP03oookJP03o`3ol?oo
nf[ooo]Z00Oooo]Z00?oonP0oookJ_oo00/01OoonfX01?oo=@3ooo]Zo`21oolgo`03oookJP05o`3o
Uooonf[o0?oXoookJ_lfo`004ooonfX01?l0hooooo]ZoookJ_oo0>`AoookJP03o`3okOoonf[ooo]Z
00kooo]Z00CooaX0oookJ_lM0?oo0?ob1OoonfX01Ooo0;Cooo]ZoookJ_oonf[oojL000cooo]Z00?o
0?l9oookJ_oonfX01OoonfX01Oml0?oo=?l0oookJ_oo04oo00_o00;ooo]Z00?oo`0HoookJ_oonfX0
0ooonfX00on`o`3ooo]Zo`3ko`06oookJP03odh0oooonf[ooo]Z00?ooo]Z0_oo01@4oookJP;oolL0
2OoonfX2oonX0004o`000?oo0:Oo0000o`0000Cooo]Z00?oo`2doolQ0?oonfX02ooonfX00ol0oiOo
oo]ZoookJP08oookJP;oS_l00_oonfX01?oo03Wooo]ZoookJ_oonfX3o`3o`0?ooo]Z0_oo00O:oook
JP009OoonfX00ooo3@3ooo]ZoookJP0@oookJP04ool00?oonf[ooo]Zool0ZPCooo]Z00?oF@3ooook
J_oonfX02ooonfX00olY0?oooo]ZoookJP02oookJP03o`3ol?oonf[ooo]Z00Oooo]Z00?oonP0oook
J_oo00/01OoonfX01?oo=@3ooo]Zo`21oolgo`03oookJP03o`3oUooonf[o0?oX00;ooo]Z00?o=_l0
oookJ_oonfX03ooonfX00ol0hooooo]ZoookJP02oookJP03ool0k?oonf[ooo]Z00kooo]Z00?o0?o]
oookJ_oonfX03_oonfX01?oo6P3ooo]ZoookJ_lM0?l6oookJP05ool0]?oonf[ooo]ZoookJ_ooY`00
3?oonfX00ol0o`Wooo]ZoookJP05oookJP07ocCo0?oob@3o02goool0Col02ooooo]Zool06005oook
JP04ok3o0?oonf[ooo]Zo`3ko`Kooo]Z00?oCP3ooookJ_oonfX00ooonfX00ooo01Cooo]ZoookJP03
oookJP;oolL02_oonfX01?ooZ03o0000ool0Yol00005oookJP;oob403?oonfX2o`3oU`Wooo]Z0_n>
o`02oookJP;oo`0i0ooonfX2o`3o`0Cooo]Z1OoUo`3VoookJP03ool=0?oonf[ooo]Z013ooo]Z00Co
0?m=oookJ_oonf[oo`2Z1?oonfX00omI0?oooo]ZoookJP0;oookJP03obT0oooonf[ooo]Z00?ooo]Z
00?o0?o`oookJ_oonfX01ooonfX00oooj03oo`0;oookJP04oookJP05oole0?oonf[o087ooookJ_lg
o`000ooonfX01Ol0oiOo0?oXoookJ_oonf[o=_l001;ooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00A
oookJP03o`3okOoonf[ooo]Z00gooo]Z00GooaX0oookJ_oonf[o7@3oo`3olP05oookJP05ool0]?oo
nf[ooo]ZoookJ_ooY`003?oonfX00ol0o`Wooo]ZoookJP05oookJP05og`0ooldo`3o02goool0Col0
2ol00_oonfX00ooo01Sooo]ZoookJP03oookJP03ok3o0?oonf[o0?_o00Kooo]Z00?oCP3ooookJ_oo
nfX01?oonfX00ooo01Cooo]ZoookJP03oookJP03ooo70?oonf[ooo]Z00Sooo]Z00CoojP0o`000?oo
0:Oo00001_oonfX00ooo8@3ooo]ZoookJP0:oookJP;o0?nG2_oonfX00on>o`3ooo]ZoookJP02ool0
>@Cooo]Z0_l0ol03oookJP;oo`07b?oonfX002Kooo]Z00?oo`d0oookJ_oonfX03ooonfX01?oo003o
oo]ZoookJ_oo0:X5oookJP03oeT0oooonf[ooo]Z00[ooo]Z00?o:@3ooookJ_oonfX00ooonfX00ol0
oo3ooo]ZoookJP07oookJP03oooX0?oonf[oo`0;00Gooo]Z00CoocD0oookJ_l0POoo=ol00ooonfX0
0ol0oiOooo]Zo`3oj002oookJP03ocKo0?oonf[ooo]Z00oooo]Z00Go0>?ooookJ_oonf[ooo]Zool0
k00AoookJP03o`3okOoonf[ooo]Z00kooo]Z00CooaX0oookJ_oonf[o7@3o1_oonfX01Ooo0;Cooo]Z
oookJ_oonf[oojL000cooo]Z00?o0?l9oookJ_oonfX01OoonfX01oldo`3ooo]Zo`0]oooo04oo00_o
oookJ_oo01P01OoonfX01?n`o`3ooo]ZoookJ_l0nol6oookJP03odh0oooonf[ooo]Z00?ooo]Z00?o
o`0DoookJ_oonfX01?oonfX00oooa`3ooo]ZoookJP07oookJP04o`000?ooZ03o0000ool0Y`Kooo]Z
00?oo`2doolQ0?oonfX03?oonfX2o`3oU`Wooo]Z0_n>o`02oookJP;oo`0i0ooonfX3o`3o`0?ooo]Z
2_oUo`3PoookJP03ool=0?oonf[ooo]Z013ooo]Z00?o0?m=oookJ_oo0:X01OoonfX00omI0?oooo]Z
oookJP0:oookJP03obT0oooonf[ooo]Z00?ooo]Z00?o0?o`oookJ_oonfX01ooonfX00oooj03ooo]Z
ool02`05oookJP05oole0?oonf[o087ooookJ_lgo`000_oonfX00ol0oiOooo]Zo`3oj002oookJP03
ocKo0?oonf[ooo]Z013ooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00@oookJP03o`3okOoonf[ooo]Z
00kooo]Z00GooaX0oookJ_oonf[o7@3oo`3olP05oookJP05ool0]?oonf[ooo]ZoookJ_ooY`003?oo
nfX00ol0o`Wooo]ZoookJP05oookJP05ocCo0?oonf[o02goool0Col02ol00_oonfX00ooo01Sooo]Z
oookJP03oookJP03ok3o0?oonf[o0?_o00Kooo]Z00?oCP3ooookJ_oonfX01?oonfX00ooo01Cooo]Z
oookJP03oookJP03ooo70?oonf[ooo]Z00Oooo]Z00Co0000oonX0?l0003oo`2W1ooonfX2oolQ00co
oo]Z0_l0oiL9oookJP;oS_l00_oonfX2ool0>@Cooo]Z0_l0ol03oookJP?oo`07aOoonfX002Kooo]Z
00?oo`d0oookJ_oonfX04?oonfX01?oo003ooo]ZoookJ_oo0:X4oookJP03oeT0oooonf[ooo]Z00_o
oo]Z00?o:@3ooookJ_oonfX00_oonfX00ol0oo3ooo]ZoookJP07oookJP03oooX0?oonf[oo`0;00Go
oo]Z00GoocD0oookJ_l0POoooo]ZocOo0003oookJP05o`3oUooonf[o0?oXoookJ_lfo`004_oonfX0
1Ol0hooooo]ZoookJ_oonf[oo`3/013ooo]Z00?o0?o]oookJ_oonfX03ooonfX2ooo90003oookJ_lM
0?oooo]Z00Cooo]Z00Goo`2doookJ_oonf[ooo]ZoonW000=oookJP03o`3o2Ooonf[ooo]Z00Gooo]Z
00Oo=?l0oookJ_l0;Oooo`1?o`0;oooonf[oo`0H00Gooo]Z00Co/?l0oookJ_oonf[o0?_o1_oonfX0
0om>0?oooo]ZoookJP03oookJP03ool05?oonf[ooo]Z00Cooo]Z00?oolL0oookJ_oonfX01_oonfX2
o`0000;oojP00_oo0:L6oookJP03oolQ0?oo0;Cooo]Z00cooo]Z0_l0oiL9oookJP04ohko0?oonf[o
oo]ZoookJP;oo`0i1?oonfX2o`3o`0;ooo]Z3OoUo`3LoookJP03ool=0?oonf[ooo]Z013ooo]Z00Co
0?m=oookJ_oonf[oo`2Z1?oonfX00omI0?oooo]ZoookJP0;oookJP03obT0oooonf[ooo]Z00?ooo]Z
00?o0?o`oookJ_oonfX01_oonfX00oooj03ooo]Zool02`05oookJP05oole0?oonf[o087ooookJ_lg
o`000ooonfX01Ol0oiOooo]Zo`3oj?oonf[o=_l001;ooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00A
oookJP03o`3okOoonf[ooo]Z00kooo]Z00CooaX0oookJ_oonf[o7@3o1OoonfX00ooo0;Cooo]Zoook
JP02oookJP03oonW0?oonf[ooo]Z00[ooo]Z00?o0?l9oookJ_oonfX01OoonfX01Oldo`3ooo]Zo`0]
oooo04oo00_o00;ooo]Z00?oo`0HoookJ_oonfX00ooonfX00on`o`3ooo]Zo`3ko`06oookJP03odh0
oooonf[ooo]Z00Cooo]Z00?oo`0DoookJ_oonfX00ooonfX00oooa`3ooo]ZoookJP06oookJP;o0000
0_ooZ002ool0Y`Oooo]Z00?oob40oookJ_oonfX02ooonfX2o`3oU`Wooo]Z0_n>o`02oookJP;oo`0i
1?oonfX3o`3o`0?ooo]Z0ooo00O2oookJP009_oonfX00ooo3@3ooo]ZoookJP0@oookJP04ool00?oo
nf[ooo]Zool0ZPGooo]Z00?oF@3ooookJ_oonfX02_oonfX00olY0?oooo]ZoookJP03oookJP03o`3o
l?oonf[ooo]Z00Oooo]Z00?oonP0oookJ_oo00/01OoonfX01?oo=@3ooo]Zooo90?oob@03oookJP03
o`3oUooonf[o0?oX00;ooo]Z00?o=_l0oookJ_oonfX03ooonfX00ol0hooooo]ZoookJP02oookJP03
ool0k?oonf[ooo]Z00kooo]Z00?o0?o]oookJ_oonfX03_oonfX3ooo90003oad0ool0oo;ooo]Z00Co
oo]Z00Goo`2doookJ_oonf[ooo]ZoonW000<oookJP03o`3o2Ooonf[ooo]Z00Gooo]Z00So=?l0og`0
oooonf[o02goool0Col02ooooo]Zool060Gooo]Z0_n`o`000ooonf[o0?_ooookJP05oookJP;oCP3o
1?oonfX00ooo01Cooo]ZoookJP04oookJP03ooo70?oonf[ooo]Z00Gooo]Z1?l000000oooZ03ooo]Z
ool0Y`06oookJP03oolQ0?oo0;Cooo]Z00gooo]Z0_l0oiL8oookJP;oS_l00ooonfX2ool0>@Cooo]Z
0_l0ol000ooonf[oiOl0onGo000:onGo0=cooo]Z00?oo`d0oookJ_oonfX04OoonfX00ol0odgooo]Z
ool0ZP05oookJP03oeT0oooonf[ooo]Z00[ooo]Z00?o:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]Z
oookJP07oookJP03oooX0?oonf[oo`0;00Gooo]Z00GoocD0oookJ_l0POoooo]ZocOo0002oookJP03
o`3oUooonf[o0?oX00;ooo]Z00?o=_l0oookJ_oonfX04?oonfX01Ol0hooooo]ZoookJ_oonf[oo`3/
017ooo]Z00?o0?o]oookJ_oonfX03OoonfX01Ooo6P3ooo]ZoookJ_lM0?oo0?ob00Gooo]Z00?oo`2d
oookJ_oonfX00_oonfX00oooY`3ooo]ZoookJP0:oookJP03o`3o2Ooonf[ooo]Z00Gooo]Z00Go=?l0
oookJ_l0;Oooo`1?o`0;o`02oookJP03ool06?oonf[ooo]Z00?ooo]Z00?o/?l0oookJ_l0nol01_oo
nfX2odh0o`Gooo]Z00?oo`0DoookJ_oonfX00ooonfX2ooo700Kooo]Z1?l000000oooZ03ooo]Zool0
Y`07oookJP03oolQ0?oo0;Cooo]Z00cooo]Z0_l0oiL9oookJP04ohko0?oonf[ooo]ZoookJP;oo`0i
1OoonfX2o`3o`0Cooo]Z0_oo00O0oookJP009ooonfX00ooo3@3ooo]ZoookJP0@oookJP04ool00?oo
nf[ooo]Zool0ZPCooo]Z00?oF@3ooookJ_oonfX02ooonfX00olY0?oooo]ZoookJP02oookJP03o`3o
l?oonf[ooo]Z00Oooo]Z00CoonP0oookJ_oonf[oo`0;1OoonfX01?oo=@3oolT0ooo90?oob@03oook
JP03o`3oUooonf[o0?oX00;ooo]Z00?o=_l0oookJ_oonfX03ooonfX00ol0hooooo]ZoookJP02oook
JP03ool0k?oonf[ooo]Z00gooo]Z00?o0?o]oookJ_oonfX03ooonfX3ooo90003oad0ool0oo;ooo]Z
00Cooo]Z00Goo`2doookJ_oonf[ooo]ZoonW000<oookJP03o`3o2Ooonf[ooo]Z00Gooo]Z00So=?l0
og`0oooonf[o02goool0Col02ooooo]Zool060Kooo]Z00?o/?l0oookJ_l0nol01ooonfX00om>0?oo
oo]ZoookJP02oookJP03ool05?oonf[ooo]Z00Cooo]Z0_ooa`05oookJPCo000000?ooo]ZoonX0?oo
nfX00_oo0:L5oookJP;oob4000?oo`2doookJ_oonfX03?oonfX2o`3oU`Sooo]Z0_n>o`03oookJP03
ool0>Ooonf[ooo]Z00?ooo]Z0ol0ol09onGo0=kooo]Z00?oo`d0oookJ_oonfX04?oonfX01?l0odgo
oo]ZoookJ_oo0:X4oookJP03oeT0oooonf[ooo]Z00_ooo]Z00?o:@3ooookJ_oonfX00ooonfX00ol0
oo3ooo]ZoookJP06oookJP04oooX0?oonf[ooo]Zool02`Gooo]Z00CoocD0o`21oooonf[o=ol00ooo
nfX00ol0oiOooo]Zo`3oj002oookJP03ocKo0?oonf[ooo]Z013ooo]Z00Go0>?ooookJ_oonf[ooo]Z
ool0k00@oookJP03o`3okOoonf[ooo]Z00kooo]Z00GooaX0oookJ_oonf[o7@3oo`3olP05oookJP05
ool0]?oonf[ooo]ZoookJ_ooY`003OoonfX00ol0o`Wooo]ZoookJP05oookJP05ocCo0?oonf[o02go
ool0Col02ol00_oonfX00ooo01Sooo]ZoookJP03oookJP03ok3o0?oonf[o0?_o00Oooo]Z00?oCP3o
oookJ_oonfX00ooonfX00ooo01Cooo]ZoookJP04oookJP03ooo70?oonf[ooo]Z00?ooo]Z1?l00000
0ooonf[oojP0oookJP02ool0Y`Kooo]Z0_oo8@0>oookJP;o0?nG2?oonfX2ohko00?ooo]Z00?oo`0i
oookJ_oonfX01?oonfX2o`3o`0Cooo]Z0ooo00NmoookJP009ooonfX00ooo3@3ooo]ZoookJP0@oook
JP04ool00?oonf[ooo]Zool0ZPGooo]Z00?oF@3ooookJ_oonfX02_oonfX00olY0?oooo]ZoookJP03
oookJP03o`3ol?oonf[ooo]Z00Oooo]Z00?oonP0oookJ_oo00/01OoonfX00ooo=@3ooo]Zooo90002
ooo900;ooo]Z00Ko0?nGoookJ_oonf[o0?oXoookJ_lfo`0AoookJP03o`3Soooonf[ooo]Z00;ooo]Z
00?oo`3/oookJ_oonfX03_oonfX00ol0ongooo]ZoookJP0>oookJPCoolT000?o7@3oooo90?oonfX0
1?oonfX01Ooo0;Cooo]ZoookJ_oonf[oojL000cooo]Z00?o0?l9oookJ_oonfX01OoonfX02?ldo`3o
O03ooookJ_l0;Oooo`1?o`0;oooonf[oo`0H1_oonfX00on`o`3ooo]Zo`3ko`07oookJP03odh0oooo
nf[ooo]Z00;ooo]Z00?oo`0DoookJ_oonfX01OoonfX00oooa`3ooo]ZoookJP02oookJPGo000000Go
oo]ZoonX0?ooZ03ooo]Zool0Y`06oookJP03oolQ0?oo0;Cooo]Z00kooo]Z0_l0oiL8oookJP04ohko
0?oonf[ooo]ZoookJP;oo`0i1_oonfX00ol0ol3oiOl0onGo0006onGo0=kooo]Z00?oo`d0oookJ_oo
nfX04OoonfX00ol0odgooo]Zool0ZP05oookJP03oeT0oooonf[ooo]Z00[ooo]Z00?o:@3ooookJ_oo
nfX00ooonfX00ol0oo3ooo]ZoookJP07oookJP03oooX0?oonf[oo`0;00Gooo]Z00GoocD0oookJ_l0
POoooo]ZocOo0002oookJP06o`3oUooonf[ooo]Zo`3oj?oonf[o=_l04_oonfX00ol0hooooo]Zoook
JP02oookJP03ool0k?oonf[ooo]Z00kooo]Z00?o0?o]oookJ_oonfX03_oonfX01Ooo6P3ooo]Zoook
J_lM0?oo0?ob00Gooo]Z00Goo`2doookJ_oonf[ooo]ZoonW000<oookJP03o`3o2Ooonf[ooo]Z00Ko
oo]Z00Go=?l0oookJ_l0;Oooo`1?o`0;o`02oookJP03ool06?oonf[ooo]Z00?ooo]Z00?o/?l0oook
J_l0nol01ooonfX00om>0?oooo]ZoookJP03oookJP03ool05?oonf[ooo]Z00Cooo]Z00?oolL0oook
J_oonfX00_oonfX5o`000005oookJ_ooZ03oojP0oookJ_oo0:L01ooonfX00ooo8@3oo`2doookJP0=
oookJP;o0?nG2?oonfX2ohko00;ooo]Z0_oo03T6oookJP?o0?o01?oonfX2ool01k_ooo]Z000Woook
JP03ool=0?oonf[ooo]Z017ooo]Z00Coo`00oookJ_oonf[oo`2Z1?oonfX00omI0?oooo]ZoookJP0;
oookJP03obT0oooonf[ooo]Z00;ooo]Z00?o0?o`oookJ_oonfX01ooonfX01?ooj03ooo]ZoookJ_oo
00/5oookJP03oole0?oob@3oolT000;oolT00_oonfX00ol0oiOooo]Zo`3oj002oookJP03ocKo0?oo
nf[ooo]Z00oooo]Z00?o0>?ooookJ_oonfX00_oonfX00ooo0>cooo]ZoookJP0>oookJP03o`3okOoo
nf[ooo]Z00kooo]Z1?oob@000olM0?ooolT0oookJP04oookJP05ool0]?oonf[ooo]ZoookJ_ooY`00
3?oonfX00ol0o`Wooo]ZoookJP05oookJP05ocCo0?ml0?oooo]Zo`0]oooo04l00_l02ol00ooo01So
oo]ZoookJP04oookJP03ok3o0?oonf[o0?_o00Oooo]Z00?oCP3ooookJ_oonfX00_oonfX00ooo01Co
oo]ZoookJP05oookJP04ooo70?oonf[ooo]ZoookJPCo00001?oonfX01?ooZ03ooo]Zool0Yooo0:L5
oookJP03oolQ0?oo0;Coo`2d00oooo]Z0_l0oiL7oookJP;oS_l00ooonfX2ool0>@Kooo]Z1_oUo`00
1?oonf[oiOl0onGo0?oUo`3LoookJP03ool=0?oonf[ooo]Z013ooo]Z00Co0?m=oookJ_oonf[oo`2Z
1?oonfX00omI0?oooo]ZoookJP0;oookJP03obT0oooonf[ooo]Z00?ooo]Z00?o0?o`oookJ_oonfX0
1_oonfX01?ooj03ooo]ZoookJ_oo00/5oookJP04oole0?oonf[o087oocOo00?ooo]Z00?o0?nGoook
J_l0onP00_oonfX00olfo`3ooo]ZoookJP0@oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`04OoonfX0
0ol0ongooo]ZoookJP0>oookJP05oolJ0?oonf[ooo]Zoad0ool0oo801OoonfX01Ooo0;Cooo]Zoook
J_oonf[oojL000cooo]Z00?o0?l9oookJ_oonfX01_oonfX01?ldo`3ooo]Zo`0]oooo04l2o`0;o`03
oookJ_oo01Sooo]Z00Cooo]Z0_n`o`000ol0nooooo]ZoookJP05oookJP03odh0oooonf[ooo]Z00?o
oo]Z00?oo`0DoookJ_oonfX01?oonfX2ooo700;ooo]Z1?l00004oookJP04oonX0?oonf[oo`2Wool0
Y`Kooo]Z00?oob40ool0]?oonfX03_oonfX2o`3oU`Sooo]Z00CoS_l0oookJ_oonf[ooo]Z0_oo03T7
oookJP;o0?o01?oonfX3ool01kSooo]Z000UoookJP04oooS0?oonf[ooo]Zool=01;ooo]Z00Coo`00
oookJ_oonf[oo`2Z1OoonfX00omI0?oooo]ZoookJP0:oookJP03obT0oooonf[ooo]Z00?ooo]Z00?o
0?o`oookJ_oonfX01ooonfX00oooj03ooo]Zool02`06oookJP03oole0?oob@3oolT000;oolT000Go
oo]Zo`3oUooonf[ooo]Zo`3oj002oookJP03ocKo0?oonf[ooo]Z00oooo]Z00?o0>?ooookJ_oonfX0
0_oonfX00ooo0>cooo]ZoookJP0=oookJP03o`3okOoonf[ooo]Z00kooo]Z1Ooob@000olM0?ooolT0
ooo90004oookJP05ool0]?oonf[ooo]ZoookJ_ooY`003?oonfX00ol0o`Wooo]ZoookJP05oookJP04
ocCo0?ml0?oooo]Zo`0]o`;oo`1?00?o00_oool06?oo01P01OoonfX00on`o`3ooo]Zo`3ko`07oook
JP03odh0oooonf[ooo]Z00;ooo]Z00?oo`0DoookJ_oonfX01OoonfX2ooo70003oookJ_l0003o0000
00;o00001OoonfX00oooZ03ooo]ZoookJP02ool0Y`Cooo]Z0_oo8@000ooo0;Cooo]ZoookJP0>oook
JP;o0?nG1ooonfX2ohko00?ooo]Z0ooo03T5oookJPCoiOl01?oonfX3onGo0=Kooo]Z00Coon<0oook
J_oonf[oo`d04_oonfX01?l0odgooo]ZoookJ_oo0:X5oookJP03oeT0oooonf[ooo]Z00[ooo]Z00?o
:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP07oookJP03oooX0?oonf[oo`0;00Kooo]Z00Co
ocD0o`21oooonf[o=ol00_oonfX01?l0oiOooo]ZoookJ_l0onP2oookJP03ocKo0?oonf[ooo]Z00oo
oo]Z00?o0>?ooookJ_oonfX00_oonfX00ooo0>cooo]ZoookJP0>oookJP03o`3okOoonf[ooo]Z00oo
oo]Z00CooaX0oookJ_oonf[o7@3o1_oonfX01Ooo0;Cooo]ZoookJ_oonf[oojL000cooo]Z00?o0?l9
oookJ_oonfX01_oonfX00oldo`3ooo]Zo`0]o`02ool0C`03o`0;oooonf[oo`0H00Kooo]Z00?o/?l0
o`3koooonfX01_oonfX00om>0?oooo]ZoookJP03oookJP03ool05?oonf[ooo]Z00Gooo]Z00?oolL0
oookJ_l000000ol00005oookJP03oonX0?oonf[ooo]Z00;oo`2W1OoonfX2oolQ0003ool0]?oonf[o
oo]Z00gooo]Z0_l0oiL7oookJP;oS_l00ooonfX3ool0>@Kooo]Z0ol0ol04oookJP?oo`07]OoonfX0
02Gooo]Z00Coon<0oookJ_oonf[oo`d04_oonfX01Ooo003ooo]ZoookJ_oonf[oo`2Z00Cooo]Z00?o
F@3ooookJ_oonfX02_oonfX00olY0?oooo]ZoookJP03oookJP03o`3ol?oonf[ooo]Z00Oooo]Z00Co
onP0oookJ_oonf[oo`0;1OoonfX00ooo=@3oolT0ooo90003ooo90007oookJ_l0oiOooo]ZoookJ_l0
onSooo]ZocKo000AoookJP03o`3Soooonf[ooo]Z00;ooo]Z00?oo`3/oookJ_oonfX03_oonfX00ol0
ongooo]ZoookJP0>oookJPCoolT000?o7@3oooo90?oob@000_oob@03oookJP04ool0]?oonf[ooo]Z
oonW00gooo]Z00?o0?l9oookJ_oonfX01OoonfX02Oldo`3oO03ooookJ_l0;Ooooo]Zool0Col02ooo
oo]Zool06005oookJP03ok3o0?oonf[o0?_o00Oooo]Z00?oCP3ooookJ_oonfX00_oonfX00ooo01Co
oo]ZoookJP06oookJP03ooo70?l0003o000000;o00001_oonfX2oonX00;ooo]Z00?oo`2WoookJ_oo
nfX00ooonfX2oolQ0003ool0]?oonf[ooo]Z00kooo]Z0_l0oiL7oookJP?oS_l00ooonfX2ool0>@Co
oo]Z0ooUo`02o`3o`0Gooo]Z0_oUo`3DoookJP04oooS0?oonf[ooo]Zool=01?ooo]Z00Co0?m=oook
J_oonf[oo`2Z1?oonfX00omI0?oooo]ZoookJP0;oookJP03obT0oooonf[ooo]Z00?ooo]Z00?o0?o`
oookJ_oonfX01_oonfX01?ooj03ooo]ZoookJ_oo00/5oookJP05oole0?oonf[o087ooookJ_lgo`00
0_oonfX01_l0oiOooo]ZoookJ_l0onSooo]ZocKo01;ooo]Z00?o0>?ooookJ_oonfX00_oonfX00ooo
0>cooo]ZoookJP0>oookJP03o`3okOoonf[ooo]Z00oooo]Z00CooaX0oookJ_lM0?oo0?ob1_oonfX0
1Ooo0;Cooo]ZoookJ_oonf[oojL000cooo]Z00?o0?l9oookJ_oonfX01_oonfX02?ldo`3ooo]Zo`0]
oooonf[oo`1?o`0;oooonf[oo`0H1_oonfX00on`o`3o0?_ooookJP06oookJP03odh0oooonf[ooo]Z
00?ooo]Z00?oo`0DoookJ_oonfX01OoonfX00oooa`3o0000o`000002o`0000Kooo]Z0_ooZ002oook
JP03ool0Yooonf[ooo]Z00Cooo]Z0_oo8@0@oookJP;o0?nG1ooonfX3ohko00?ooo]Z0_oo03T7oook
JP;o0?o01OoonfX2ool01k?ooo]Z000VoookJP03oooS0?oonf[oo`d001?ooo]Z00Coo`00oookJ_oo
nf[oo`2Z1OoonfX00omI0?oooo]ZoookJP0:oookJP03obT0oooonf[ooo]Z00?ooo]Z00?o0?o`oook
J_oonfX01ooonfX00oooj03ooo]Zool02`06oookJP03oole0?oob@3oolT000?oolT000Co0?nGoook
J_oonf[o0?oX0_oonfX00olfo`3ooo]ZoookJP0?oookJP03o`3Soooonf[ooo]Z00;ooo]Z00?oo`3/
oookJ_oonfX03_oonfX00ol0ongooo]ZoookJP0>oookJPCoolT000?o7@3oooo90?oob@000_oob@03
oookJP04ool0]?oonf[ooo]ZoonW00gooo]Z00?o0?l9oookJ_oonfX01OoonfX2ooo90007oookJ_l0
;Ooooo]Zool0Col02ooooo]Zool06005oookJP03ok3o0?oonf[o0?_o00Oooo]Z00?oCP3ooookJ_oo
nfX00_oonfX2ool050Oooo]Z00CoolL0o`000?l0003o00002?oonfX00oooZ03ooo]ZoookJP02ool0
Y`Gooo]Z0_oo8@000ooo0;Cooo]ZoookJP0>oookJP;o0?nG2?oonfX2ohko00?ooo]Z0ooo03T2oook
JP04onGo0?oonf[ooo]ZoookJP;o0?o01OoonfX3onGo0=;ooo]Z00Coon<0oookJ_oonf[oo`d04_oo
nfX01?l0odgooo]ZoookJ_oo0:X5oookJP03oeT0oooonf[ooo]Z00[ooo]Z00?o:@3ooookJ_oonfX0
1?oonfX00ol0oo3ooo]ZoookJP06oookJP03oooX0?oonf[oo`0;00Kooo]Z00CoocD0oookJ_l0POoo
=ol00ooonfX01_l0oiOooo]ZoookJ_l0onSooo]ZocKo01;ooo]Z00Go0>?ooookJ_oonf[ooo]Zool0
k00AoookJP03o`3okOoonf[ooo]Z00oooo]Z00CooaX0oookJ_lM0?oo0?ob1_oonfX01Ooo0;Cooo]Z
oookJ_oonf[oojL000cooo]Z00?o0?l9oookJ_oonfX01_oonfX2ocCo0006o`0]oooonf[oo`1?o`0;
oooonf[oo`0H1_oonfX00on`o`3o0?_ooookJP06oookJP03odh0oooonf[ooo]Z00?ooo]Z0_oo01@6
oookJP;oolL00_l00008oookJP03oonX0?oonf[ooo]Z00;oo`2W1_oonfX2oolQ013ooo]Z0_l0oiL8
oookJP;oS_l00ooonfX3ool0>@Kooo]Z0_l0ol05oookJP?oo`07/?oonfX002Kooo]Z00Coon<0oook
J_oonf[oo`d04_oonfX01Ooo003ooo]ZoookJ_oonf[oo`2Z00Cooo]Z00?oF@3ooookJ_oonfX02_oo
nfX00olY0?oooo]ZoookJP04oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00CoonP0oookJ_oonf[oo`0;
1OoonfX00ooo=@3oolT0ooo90004ooo90004o`3oUooonf[ooo]Zo`3oj0;ooo]Z00?o=_l0oookJ_oo
nfX03_oonfX00ol0hooooo]ZoookJP03oookJP03ool0k?oonf[ooo]Z00kooo]Z00?o0?o]oookJ_oo
nfX03OoonfX5ooo90003oad0oooob@3oolT000;oolT00ooonfX01?oo0;Cooo]ZoookJ_ooY`0=oook
JP;o0?l91OoonfX4ooo90006o`0]oooonf[oo`1?o`0;oooonf[oo`0H1OoonfX00on`o`3ooo]Zo`3k
o`07oookJP03odh0oooonf[ooo]Z00?ooo]Z00?oo`0DoookJ_oonfX01?oonfX01?l0003oolL0o`00
0?l00009oookJP05oonX0?oonf[ooo]ZoookJ_oo0:L01_oonfX2oolQ017ooo]Z00?o0?nGoookJ_oo
nfX01ooonfX3ohko00?ooo]Z0_oo03T6oookJP;o0?o01_oonfX2onGo0=3ooo]Z00Coon<0oookJ_oo
nf[oo`d04ooonfX01?l0odgooo]ZoookJ_oo0:X4oookJP03oeT0oooonf[ooo]Z00_ooo]Z00?o:@3o
oookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP06oookJP04oooX0?oonf[ooo]Zool02`Kooo]Z00Co
ocD0oookJ_l0POoo=ol00_oonfX01?l0oiOooo]ZoookJ_l0onP2oookJP03ocKo0?oonf[ooo]Z00oo
oo]Z00?o0>?ooookJ_oonfX00_oonfX00ooo0>cooo]ZoookJP0?oookJP03o`3okOoonf[ooo]Z00oo
oo]Z00CooaX0oookJ_lM0?oo0?ob1_oonfX01?oo0;Cooo]ZoookJ_ooY`0=oookJP;o0?l91ooonfX0
2?ml0?oo=?l0o`0]oooonf[oo`1?o`0;oooonf[oo`0H1_oonfX00on`o`3o0?_ooookJP06oookJP03
odh0oooonf[ooo]Z00Cooo]Z00?oo`0DoookJ_oonfX00ooonfX2o`000003ooo70?l0003ooo]Z00So
oo]Z00GoojP0oookJ_oonf[ooo]Zool0Y`07oookJP03oolQ0?oo0;Cooo]Z00oooo]Z00?o0?nGoook
J_oonfX01ooonfX3ohko00?ooo]Z0ooo03T5oookJP?o0?o01OoonfX2ool01jkooo]Z000WoookJP03
oooS0?oonf[oo`d001?ooo]Z00Goo`00oookJ_oonf[ooo]Zool0ZP04oookJP03oeT0oooonf[ooo]Z
00[ooo]Z00?o:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP07oookJP03oooX0?oonf[oo`0;
00Kooo]Z00?oocD0ooo90?oob@001?oob@03oookJP03o`3oj?oonf[o=_l0017ooo]Z00?o0>?ooook
J_oonfX00_oonfX00ooo0>cooo]ZoookJP0?oookJP03o`3okOoonf[ooo]Z00gooo]Z1Ooob@000olM
0?ooolT0oookJP05oookJP04ool0]?oonf[ooo]ZoonW00kooo]Z00?o0?l9oookJ_oonfX00ooonfX5
ooo90005oookJ_oo04oo00_ooookJ_oo01P01OoonfX00on`o`3ooo]Zo`3ko`07oookJP03odh0oooo
nf[ooo]Z00?ooo]Z0_oo01@4oookJP;o00000_ooa`0:oookJP;oojP00_oonfX2ool0Y`Kooo]Z00?o
ob40ool0]?oonfX03ooonfX2o`3oU`[ooo]Z0on>o`02oookJP?oo`0i1OoonfX3o`3o`0Gooo]Z0ooU
o`3>oookJP04oooS0?oonf[ooo]Zool=01;ooo]Z00Go0?m=oookJ_oonf[ooo]Zool0ZP04oookJP03
oeT0oooonf[ooo]Z00[ooo]Z00?o:@3ooookJ_oonfX01?oonfX00ol0oo3ooo]ZoookJP06oookJP03
oooX0?oonf[oo`0;00Kooo]Z00CoocD0oookJ_l0POoo=ol00ooonfX01_l0oiOooo]ZoookJ_l0onSo
oo]ZocKo01;ooo]Z00?o0>?ooookJ_oonfX00_oonfX00ooo0>cooo]ZoookJP0?oookJP03o`3okOoo
nf[ooo]Z00oooo]Z00CooaX0oookJ_lM0?oo0?ob1_oonfX01?oo0;Cooo]ZoookJ_ooY`0>oookJP03
o`3o2Ooonf[ooo]Z00Gooo]Z00SoO03oocCo0?l0;Ooooo]Zool0Col02ooooo]Zool060Kooo]Z00?o
/?l0o`3koooonfX01_oonfX00om>0?oooo]ZoookJP04oookJP;oo`0D0ooonfX3o`000003ooo70?oo
nf[ooo]Z00Sooo]Z0_ooZ002oookJP;oo`2W1_oonfX2oolQ013ooo]Z0_l0oiL:oookJP?oS_l00ooo
nfX2ool0>@Kooo]Z0_l0ol05oookJP?oo`07ZooonfX002Oooo]Z00?oon<0oookJ_oo3@004ooonfX0
1Ooo003ooo]ZoookJ_oonf[oo`2Z00Gooo]Z00?oF@3ooookJ_oonfX02OoonfX00olY0?oooo]Zoook
JP04oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00CoonP0oookJ_oonf[oo`0;1OoonfX00ooob@3oocD0
ooo90005ooo900;ooo]Z00Co0?oXoookJ_oonf[o=_l04OoonfX00ol0hooooo]ZoookJP02oookJP03
ool0k?oonf[ooo]Z00oooo]Z00?o0?o]oookJ_oonfX03?oonfX5ooo90003oad0ool0oo;ooo]Z00Ko
oo]Z00Coo`2doookJ_oonf[oojL03_oonfX00ol0o`Wooo]ZoookJP03oookJPKoolT000Coo`1?o`0;
ool02oooo`0H1OoonfX2ok3o00;o0?_o1_oonfX00om>0?oooo]ZoookJP04oookJP04ool05?oonf[o
oo]ZoookJPCo000000?oolL0oookJ_oonfX02OoonfX01OooZ03ooo]ZoookJ_oonf[oo`2W00Kooo]Z
0_oo8@0AoookJP;o0?nG2ooonfX2ohko00?ooo]Z0_oo03T6oookJP;o0?o01_oonfX3onGo0<_ooo]Z
00Coon<0oookJ_oonf[oo`d04ooonfX01?l0odgooo]ZoookJ_oo0:X5oookJP03oeT0oooonf[ooo]Z
00[ooo]Z00?o:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP06oookJP04oooX0?oonf[ooo]Z
ool02`Kooo]Z00CoocD0oookJ_l0POoo=ol00_oonfX01ol0oiOooo]ZoookJ_oonf[o0?oXoookJ_lf
o`004OoonfX00ol0hooooo]ZoookJP03oookJP03ool0k?oonf[ooo]Z00oooo]Z00?o0?o]oookJ_oo
nfX03ooonfX00ooo6P3o7@3oo`3olP07oookJP04ool0]?oonf[ooo]ZoonW00kooo]Z00?o0?l9oook
J_oonfX01OoonfX01Oml0?oo=?l0o`0]ool0;Oooo`1?00;o00_o00?oo`0HoookJ_oonfX01?oonfX0
0on`o`3o0?_oo`3ko`06oookJP03odh0oooonf[ooo]Z00Gooo]Z00?oo`0DoookJ_oonfX01?l00002
ooo700[ooo]Z00GoojP0oookJ_oonf[ooo]Zool0Y`07oookJP;oob404?oonfX2o`3oU`_ooo]Z0_n>
o`03oookJP?oo`0i1OoonfX2o`3o`0Kooo]Z0ooo00NXoookJP00:?oonfX00oooh`3ooo]Zool=000C
oookJP05ool00?oonf[ooo]ZoookJ_oo0:X01?oonfX00omI0?oooo]ZoookJP0:oookJP03obT0oooo
nf[ooo]Z00?ooo]Z00?o0?o`oookJ_oonfX01ooonfX00oooj03ooo]Zool02`05oookJP03ooo90?oo
=@3oolT000KoolT00_oonfX01?l0onSooo]ZoookJ_lfo`0@oookJP03o`3Soooonf[ooo]Z00?ooo]Z
00?oo`3/oookJ_oonfX03ooonfX00ol0ongooo]ZoookJP0<oookJPGoolT000?o7@3oo`3ol_oonfX0
1_oonfX01?oo0;Cooo]ZoookJ_ooY`0>oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z2?oob@000ooo04oo
00_oool06006oookJP03ok3o0?oonf[o0?_o00Kooo]Z00?oCP3ooookJ_oonfX01?oonfX00ooo01Co
oo]ZoookJP04o`000003oookJ_ooa`3ooo]Z00[ooo]Z00CoojP0oookJ_oonf[ooo]Z0_oo0:L6oook
JP;oob404OoonfX2o`3oU`_ooo]Z0on>o`02oookJP?oo`0i1OoonfX3o`3o`0Kooo]Z0_oUo`3:oook
JP03oooS0?oonf[oo`d001?ooo]Z00Go0?m=oookJ_oonf[ooo]Zool0ZP04oookJP03oeT0oooonf[o
oo]Z00[ooo]Z00?o:@3ooookJ_oonfX01?oonfX00ol0oo3ooo]ZoookJP06oookJP03oooX0?oonf[o
o`0;00Oooo]Z00?oocD0oookJ_l0POl00ooonfX01?l0oiOooo]ZoookJ_l0onP2oookJP03ocKo0?oo
nf[ooo]Z00oooo]Z00?o0>?ooookJ_oonfX00_oonfX00ooo0>cooo]ZoookJP0?oookJP03o`3okOoo
nf[ooo]Z013ooo]Z00?ooaX0oad0ool0oo801ooonfX01?oo0;Cooo]ZoookJ_ooY`0>oookJP03o`3o
2Ooonf[ooo]Z00Gooo]Z00SoO03oocCo0?oonf[o02gooookJ_oo04oo00_oool060Kooo]Z00?o/?l0
oookJ_l0nol01_oonfX00om>0?oooo]ZoookJP05oookJP03ool05?oonf[o000000?o00000_oonfX0
0oooa`3ooo]ZoookJP08oookJP04oonX0?oonf[ooo]ZoookJP;oo`2W1ooonfX2oolQ013ooo]Z0_l0
oiL;oookJP?oS_l00ooonfX2ool0>@Gooo]Z0ol0ol06oookJP;oo`07Y_oonfX002Sooo]Z00?oon<0
oookJ_oo3@004ooonfX01Ooo003ooo]ZoookJ_oonf[oo`2Z00Gooo]Z00?oF@3ooookJ_oonfX02Ooo
nfX00olY0?oooo]ZoookJP04oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00CoonP0oookJ_oonf[oo`0;
1OoonfX00ooob@3oocD0ooo90003ooo90003oookJ_l0oiOooo]Z00;ooo]Z00?o0?oXoookJ_lfo`00
4OoonfX00ol0hooooo]ZoookJP03oookJP03ool0k?oonf[ooo]Z00oooo]Z00?o0?o]oookJ_oonfX0
2ooonfX3ooo900;ooo]Z00?oolT0oad0ool0oo801ooonfX01?oo0;Cooo]ZoookJ_ooY`0>oookJP03
o`3o2Ooonf[ooo]Z00;ooo]Z2Ooob@000ol02oooo`0HoookJP05oookJP03ok3o0?oonf[o0?_o00Ko
oo]Z0_m>0?l5oookJP;oo`0D1?l00002oookJP03ooo70?oonf[ooo]Z00Wooo]Z0_ooZ003oookJP;o
o`2W1_oonfX2oolQ017ooo]Z0_l0oiL<oookJP;oS_l00ooonfX2ool0>@Kooo]Z0ol0ol05oookJP?o
iOl0aooonfX01?ooh`3ooo]ZoookJ_oo3@0CoookJP04o`3oCOoonf[ooo]Zool0ZPGooo]Z00?oF@3o
oookJ_oonfX02OoonfX00olY0?oooo]ZoookJP04oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00CoonP0
oookJ_oonf[oo`0;1_oonfX01?oo=@3ooo]Zo`21oolgo`02oookJP07o`3oUooonf[ooo]ZoookJ_l0
onSooo]ZocKo000BoookJP03o`3Soooonf[ooo]Z00;ooo]Z00?oo`3/oookJ_oonfX03ooonfX00ol0
ongooo]ZoookJP0@oookJP03oolJ0?lM0?oo0?ob00Oooo]Z00Coo`2doookJ_oonf[oojL03_oonfX0
0ol0o`Wooo]ZoookJP05oookJP08og`0ooldo`3ooo]Zo`0]oooonf[oo`1?o`0;oooo01P6oookJP03
ok3o0?oonf[o0?_o00Kooo]Z0_m>0?l6oookJP;oo`0D0ol00003oookJP03ooo70?oonf[ooo]Z00So
oo]Z0_ooZ003oookJP;oo`2W1_oonfX00ooo0;Coob40oolQ000@oookJP;o0?nG3?oonfX2ohko00?o
oo]Z0ooo03T5oookJP?o0?o01OoonfX3ool01j?ooo]Z000YoookJP03oooS0?oo3@3ooo]Z01?ooo]Z
00Goo`00oookJ_oonf[ooo]Zool0ZP04oookJP03oeT0oooonf[ooo]Z00[ooo]Z00?o:@3ooookJ_oo
nfX00ooonfX00ol0oo3ooo]ZoookJP07oookJP;oolT000?oo`0;oookJ_oonfX00ooonfX2ooo90003
oole0?oob@3oolT000?ooo]Z00Co0?nGoookJ_oonf[o0?oX0_oonfX00olfo`3ooo]ZoookJP0>oook
JP03o`3Soooonf[ooo]Z00?ooo]Z00?oo`3/oookJ_oonfX03ooonfX00ol0ongooo]ZoookJP0<oook
JP07ooo90?oonf[ooo]ZoookJ_oob@3ooo]Zoad0o`08oookJP03ool0]?oonf[oojL000oooo]Z00?o
0?l9oookJ_oonfX00_oonfX9ooo90003o`0;oooo01Sooo]Z00Gooo]Z00Co/?l0oookJ_l0nooo0?_o
1_oonfX00om>0?oooo]ZoookJP04oookJP04ool05?l0003o0000o`0000?ooo]Z0_ooa`0;oookJP03
oonX0?oonf[ooo]Z00;ooo]Z00?oo`2WoookJ_oonfX01?oonfX00ooo0;Coob40oolQ000AoookJP;o
0?nG3?oonfX3ohko00;ooo]Z0ooo03T6oookJPCo0?o01?oonfX00ooUo`3oo`07ool01`1moookJP?o
o`07AOoonfX00oooh`3ooo]Zool=000CoookJP05o`3oCOoonf[ooo]ZoookJ_oo0:X01?oonfX00omI
0?oooo]ZoookJP0:oookJP03obT0oooonf[ooo]Z00Cooo]Z00?o0?o`oookJ_oonfX01_oonfX00ooo
j03ooo]Zool02`07oookJP04oole0?oonf[o087oocOo00;ooo]Z00Oo0?nGoookJ_oonf[ooo]Zo`3o
j?oonf[o=_l0017ooo]Z00?o0>?ooookJ_oonfX00ooonfX00ooo0>cooo]ZoookJP0?oookJP03o`3o
kOoonf[ooo]Z013ooo]Z00?ooaX0oad0ool0oo801ooonfX01?oo0;Cooo]ZoookJ_ooY`0>oookJP03
o`3o2Ooonf[ooo]Z00Kooo]Z0_ldo`001Ol0;Ooooo]Zool0Col02oooo`0H00Kooo]Z00Co/?l0oook
J_l0nooo0?_o1_oonfX00om>0?oooo]ZoookJP04oookJP04o`000?oo01Co0000o`0000Cooo]Z00?o
olL0oookJ_oonfX02OoonfX00oooZ03ooo]ZoookJP02oookJP03ool0Yooonf[ooo]Z00Gooo]Z00?o
o`2doolQ0?oonfX04?oonfX2o`3oU`cooo]Z0on>o`03oookJP;oo`0i1_oonfX4o`3o`0Cooo]Z0ooo
00MnoookJP?oo`077ooonfX002Wooo]Z00?oon<0oookJ_oo3@004ooonfX01Ooo003ooo]ZoookJ_oo
nf[oo`2Z00Gooo]Z00?oF@3ooookJ_oonfX02OoonfX00olY0?oooo]ZoookJP04oookJP03o`3ol?oo
nf[ooo]Z00Kooo]Z0ooob@000ooo00_ooo]ZoookJP02oookJP;oolT000?oocD0oookJ_oob@000ooo
nfX01Ol0oiOooo]ZoookJ_oonf[o0?oX00;ooo]Z00?o=_l0oookJ_oonfX03_oonfX00ol0hooooo]Z
oookJP03oookJP03ool0k?oonf[ooo]Z00oooo]Z00?o0?o]oookJ_oonfX04?oonfX00ooob@3ooo]Z
oad0o`08oookJP03ool0]?oonf[oojL000oooo]Z00?o0?l9oookJ_oonfX00_oonfX9ooo90003o`0;
oooo01Sooo]Z00Gooo]Z00Co/?l0oookJ_oonf[o0?_o1_oonfX00om>0?oooo]ZoookJP03oookJP03
o`000?oo01Coo`0D00;o00001?oonfX00oooa`3ooo]ZoookJP09oookJP03oonX0?oonf[ooo]Z00;o
oo]Z0_oo0:L6oookJP03ool0]?oo8@3oob40017ooo]Z0_l0oiL=oookJP;oS_l00ooonfX2ool0>@So
oo]Z1?l0ol03oookJPGoo`07LooonfX5ool01dSooo]Z00Coon<0oookJ_oonf[oo`d04ooonfX01?l0
odgooo]ZoookJ_oo0:X5oookJP03oeT0oooonf[ooo]Z00Wooo]Z00?o:@3ooookJ_oonfX01?oonfX0
0ol0oo3ooo]ZoookJP06oookJP04oooX0?oonf[ooo]Zool02`Oooo]Z00?oocD0oookJ_l0POl00_oo
nfX01Ol0oiOooo]ZoookJ_oonf[o0?oX00;ooo]Z00?o=_l0oookJ_oonfX03ooonfX00ol0hooooo]Z
oookJP03oookJP03ool0k?oonf[ooo]Z00oooo]Z00?o0?o]oookJ_oonfX04?oonfX00ooo6P3o7@3o
oookJP07oookJP03ool0]?oonf[oojL000oooo]Z00?o0?l9oookJ_oonfX01_oonfX01oml0?oo=?l0
o`0]oooonf[oo`1?o`0;oooo01P01_oonfX01?n`o`3ooo]ZoookJ_l0nol6oookJP;oCP3o1?oonfX2
o`0000;oo`0D00?o0000oookJ_oonfX00_oonfX2ooo700[ooo]Z00?oojP0oookJ_oonfX00_oonfX2
ool0Y`Kooo]Z00?oo`2doolQ0?oo8@004OoonfX2o`3oU`gooo]Z0_n>o`03oookJP?oo`0i1ooonfX4
o`3o`0?ooo]Z1Ooo00MdoookJPGoo`078_oonfX002Wooo]Z00?oon<0oookJ_oo3@005?oonfX01Ooo
003ooo]ZoookJ_oonf[oo`2Z00Cooo]Z00?oF@3ooookJ_oonfX02_oonfX00olY0?oooo]ZoookJP03
oookJP03o`3ol?oonf[ooo]Z00Oooo]Z0ooob@05oookJP05ooo90?oonf[oocD0oookJ_oob@000ooo
nfX01ol0oiOooo]ZoookJ_oonf[o0?oXoookJ_lfo`004OoonfX00ol0hooooo]ZoookJP03oookJP03
ool0k?oonf[ooo]Z00oooo]Z00?o0?o]oookJ_oonfX04?oonfX00ooob@3o7@3oo`3olP08oookJP03
ool0]?oonf[oojL000oooo]Z00Co0?l9oookJ_oonf[ooo]Z2_oob@000ol02oooo`0HoookJP05oook
JP04ok3o0?oonf[ooo]Zo`3ko`Kooo]Z0_m>0?l3oookJP?o000000?oo`0DoookJ_oonfX01?oonfX0
0oooa`3ooo]ZoookJP09oookJP;oojP01?oonfX00ooo0:Oooo]ZoookJP04oookJP;oo`2d0_oo8@0A
oookJP;o0?nG3OoonfX3ohko00;ooo]Z0ooo03T9oookJP?o0?o01OoonfX5ool01fWooo]Z1Ooo00M=
oookJP04oooS0?oonf[ooo]Zool=01?ooo]Z00Go0?m=oookJ_oonf[ooo]Zool0ZP04oookJP03oeT0
oooonf[ooo]Z00[ooo]Z00?o:@3ooookJ_oonfX01?oonfX00ol0oo3ooo]ZoookJP06oookJP03oooX
0?oonf[oo`0;00Oooo]Z00CoocD0oookJ_oonf[o087o0_oonfX01ol0oiOooo]ZoookJ_oonf[o0?oX
oookJ_lfo`004_oonfX00ol0hooooo]ZoookJP02oookJP03ool0k?oonf[ooo]Z013ooo]Z00?o0?o]
oookJ_oonfX04?oonfX00olM0?oo0?oboookJP07oookJP03ool0]?oonf[oojL000oooo]Z00?o0?l9
oookJ_oonfX01_oonfX01oml0?oo=?l0o`0]oooonf[oo`1?o`0;oooo01P01_oonfX01?n`o`3ooo]Z
oookJ_l0nol7oookJP04odh0oooonf[ooo]ZoookJPCo000000?oo`0DoookJ_oonfX01?oonfX00ooo
a`3ooo]ZoookJP08oookJP;oojP01?oonfX00ooo0:Oooo]ZoookJP05oookJP03ool0]?oo8@3oob40
017ooo]Z0_l0oiL=oookJP?oS_l00ooonfX2ool0>@Wooo]Z0ol0ol05oookJPGoo`07J_oonfX5ool0
1bOooo]Z000ZoookJP03oooS0?oo3@3ooo]Z01?ooo]Z00Goo`00oookJ_oonf[ooo]Zool0ZP05oook
JP03oeT0oooonf[ooo]Z00Wooo]Z00?o:@3ooookJ_oonfX01?oonfX00ol0oo3ooo]ZoookJP06oook
JPCoolT01ooonfX00ooo=@3o=ol0ooo90002oookJP05o`3oUooonf[ooo]ZoookJ_l0onP00_oonfX0
0olfo`3ooo]ZoookJP0?oookJP03o`3Soooonf[ooo]Z00;ooo]Z00?oo`3/oookJ_oonfX04?oonfX0
0ol0ongooo]ZoookJP0@oookJP03ooo90?lM0?oo0?ob00Sooo]Z00?oo`2doookJ_ooY`003ooonfX0
1?l0o`Wooo]ZoookJ_oonfX8ooo90004oookJ_oo04oo00_oo`0;o`Kooo]Z00?o/?l0oookJ_oonfX0
0_l0nol6oookJP03odh0oooonf[ooo]Z00Co00000_oo01@5oookJP;oolL02ooonfX2oonX00?ooo]Z
0_oo0:L6oookJP;oo`2d00?oob40oookJ_oonfX04?oonfX2o`3oU`kooo]Z0_n>o`03oookJP;oo`0i
2_oonfX4o`3o`0Kooo]Z1?oo00MPoookJPGoo`07DooonfX00oooh`3ooo]Zool=000CoookJP05o`3o
COoonf[ooo]ZoookJ_oo0:X01OoonfX00omI0?oooo]ZoookJP09oookJP03obT0oooonf[ooo]Z00Co
oo]Z00?o0?o`oookJ_oonfX01ooonfX00oooj03ooo]Zool02`07oookJP03oole0?oonf[o087o00;o
oo]Z00?o0?nGoookJ_oonfX00_oonfX00ol0onSooo]ZocKo000BoookJP03o`3Soooonf[ooo]Z00;o
oo]Z00?oo`3/oookJ_oonfX04?oonfX00ol0ongooo]ZoookJP0@oookJP03oad0ool0oo;ooo]Z00Oo
oo]Z00?oo`2doookJ_ooY`003ooonfX00ol0o`Wooo]ZoookJP06oookJP03og`0ooldo`3o02go00;o
oo]Z0_l02ol6oookJP;o/?l000?ooo]Zo`3kool0nol01_oonfX00om>0?oooo]ZoookJP04o`000003
oookJ_oo01Coo`0D00Gooo]Z00?oolL0oookJ_oonfX02OoonfX2oonX00?ooo]Z0_oo0:L6oookJP;o
o`2d0_oo8@0AoookJP;o0?nG3_oonfX2ohko00?ooo]Z0ooo03T9oookJPCo0?o01_oonfX5ool01f3o
oo]Z1Ooo00L/oookJP009OoonfX00om/0?oooo]ZoookJP02oookJP03oooS0?oonf[oo`d001Cooo]Z
00Goo`00oookJ_oonf[ooo]Zool0ZP04oookJP03oeT0oooonf[ooo]Z00[ooo]Z00?o:@3ooookJ_oo
nfX01?oonfX00ol0oo3ooo]ZoookJP05oookJPGoolT01_oonfX00ooo=@3ooo]Zooo90003oookJP05
o`3oUooonf[ooo]ZoookJ_l0onP00_oonfX00olfo`3ooo]ZoookJP0?oookJP03o`3Soooonf[ooo]Z
00;ooo]Z00?oo`3/oookJ_oonfX04?oonfX00ol0ongooo]ZoookJP0@oookJP03ooo90?lM0?oo0?ob
00Sooo]Z00?oo`2doookJ_ooY`003ooonfX01?l0o`Wooo]ZoookJ_oonfX6ooo90003oookJ_l0;Ooo
oo]Z00;oo`1?00?o00_ooookJ_oonfX01?oonfX01On`o`3ooo]ZoookJ_oonf[o0?_o00Kooo]Z0_m>
0?l4o`0000;ooo]Z00?oo`0DoookJ_oonfX01?oonfX00oooa`3ooo]ZoookJP0:oookJP;oojP00ooo
nfX00ooo0:Oooo]ZoookJP05oookJP03ool0]?oo8@3oob4001;ooo]Z0_l0oiL>oookJP?oS_l00_oo
nfX3ool0>@_ooo]Z1?l0ol06oookJPGoo`07E_oonfX5ool01a3ooo]Z0_l0ol11oookJP03of`0oooo
nf[ooo]Z00;ooo]Z00Coon<0oookJ_oonf[oo`d04ooonfX01Ol0odgooo]ZoookJ_oonf[oo`2Z00Co
oo]Z00?oF@3ooookJ_oonfX02_oonfX00olY0?oooo]ZoookJP04oookJP03o`3ol?oonf[ooo]Z00Ko
oo]Z00CoonP0oookJ_oonf[oo`0;1ooonfX00ooo=@3ooo]Zo`21o`02oookJP05o`3oUooonf[ooo]Z
oookJ_l0onP00_oonfX00olfo`3ooo]ZoookJP0@oookJP03o`3Soooonf[ooo]Z00;ooo]Z00?oo`3/
oookJ_oonfX03ooonfX00ol0ongooo]ZoookJP0AoookJP03oad0ool0oo;ooo]Z00Oooo]Z00?oo`2d
oookJ_ooY`003ooonfX2o`3o2@Oooo]Z00?oO03oocCo0?l0;Ol00_oonfX00ooo04oo00_ooookJP06
oookJP04ok3o0?oonf[ooo]Zo`3ko`Kooo]Z0_m>0?l4o`0000?ooo]Z00?oo`0DoookJ_oonfX00ooo
nfX2ooo700_ooo]Z0_ooZ003oookJP03ool0Yooonf[ooo]Z00Gooo]Z00Coo`2doookJ_oo8@3oob40
4OoonfX2o`3oU`kooo]Z0on>o`03oookJP?oo`0i2_oonfX4o`3o`0Oooo]Z1Ooo00MFoookJPGoo`07
4?oonfX2o`3o`1oooo]Z000UoookJP03of`0oooonf[ooo]Z00?ooo]Z00?oon<0ool=0?oonfX04ooo
nfX01Ooo003ooo]ZoookJ_oonf[oo`2Z00Gooo]Z00?oF@3ooookJ_oonfX02OoonfX00olY0?oooo]Z
oookJP04oookJP03o`3ol?oonf[ooo]Z00Kooo]Z1Ooob@06oookJP03oole0?oonf[oolT000?ooo]Z
00Co0?nGoookJ_oonf[o0?oX0_oonfX00olfo`3ooo]ZoookJP0@oookJP03o`3Soooonf[ooo]Z00;o
oo]Z00?oo`3/oookJ_oonfX04?oonfX00ol0ongooo]ZoookJP0@oookJP03ooo90?lM0?oo0?ob00Oo
oo]Z00Coo`2doookJ_oonf[oojL03ooonfX00ol0o`Wooo]ZoookJP05ooo90004og`0oooob@3oolT0
o`0]o`;ooo]Z00?oo`1?o`0;oooonfX01OoonfX2ok3o00;ooo]Z00?o0?_ooookJ_oonfX01OoonfX0
1?m>0?oo0000o`000?l00003oookJP03ool05?oonf[ooo]Z00Cooo]Z00?oolL0oookJ_oonfX02ooo
nfX01?ooZ03ooo]ZoookJ_oonfX2ool0Y`Kooo]Z0_oo0;@2oolQ01;ooo]Z0_l0oiL?oookJP?oS_l0
0_oonfX2ool0>@gooo]Z1?l0ol07oookJPGoo`07COoonfX4ool01a;ooo]Z0ol0ol13oookJP03of`0
oooonf[ooo]Z00?ooo]Z00?oon<0oookJ_oo3@004ooonfX01Ol0odgooo]ZoookJ_oonf[oo`2Z00Go
oo]Z00?oF@3ooookJ_oonfX02OoonfX00olY0?oooo]ZoookJP04oookJP03o`3ol?oonf[ooo]Z00Oo
oo]Z00?oonP0oookJ_oo00/01ooonfX01?oo=@3ooo]ZocOo0?l0POl2oookJP07o`3oUooonf[ooo]Z
oookJ_l0onSooo]ZocKo000BoookJP03o`3Soooonf[ooo]Z00;ooo]Z00?oo`3/oookJ_oonfX04?oo
nfX00ol0ongooo]ZoookJP0AoookJP03oad0ool0oo;ooo]Z00Oooo]Z00?oo`2doookJ_ooY`004?oo
nfX00ol0o`Wooo]ZoookJP05oookJP03og`0ooldo`3o=?l000;ooo]Z00?oo`1?o`0;oooonfX01_oo
nfX00on`o`3ooo]ZoookJP02o`3ko`Kooo]Z00CoCP3oo`000?l0003o00001?oonfX00ooo01Cooo]Z
oookJP04oookJP03ooo70?oonf[ooo]Z00[ooo]Z0_ooZ002oookJP;oo`2W1_oonfX2ool0]003oook
J_oo8@3oob40017ooo]Z0_l0oiL?oookJP?oS_l00ooonfX2ool0>@cooo]Z1?l0ol08oookJPCoo`07
COoonfX5ool01a;ooo]Z0ol0ol0QoookJP009_oonfX00om/0?oooo]ZoookJP02oookJP03oooS0?oo
nf[oo`d001Cooo]Z00Goo`00oookJ_oonf[ooo]Zool0ZP04oookJP03oeT0oooonf[ooo]Z00[ooo]Z
00?o:@3ooookJ_oonfX01?oonfX00ol0oo3ooo]ZoookJP05oookJPKoolT01OoonfX01?oo=@3ooo]Z
ocOo0?oob@03oookJP04o`3oUooonf[ooo]Zo`3oj0;ooo]Z00?o=_l0oookJ_oonfX03ooonfX00ol0
hooooo]ZoookJP02oookJP03ool0k?oonf[ooo]Z017ooo]Z00?o0?o]oookJ_oonfX04?oonfX00ooo
b@3o7@3ooad0o`07oookJP03ool0]?oonf[ooo]Z00;oojL03_oonfX00ol0o`Wooo]ZoookJP03ooo9
00;ooo]Z00CoO03ooookJ_oob@3o02go0_oonfX00ooo04oo00_ooookJP06oookJP03ok3o0?oonf[o
oo]Z00;o0?_o1OoonfX01?l0003oCP3oo`000?l00004oookJP;oo`0D1OoonfX00oooa`3ooo]Zoook
JP0;oookJP;oojP00ooonfX00ooo0:Oooo]ZoookJP05oookJP04ool0]?oonf[oob40oolQ01;ooo]Z
0ol0oiL?oookJP;oS_l00_oonfX3ool0>@kooo]Z1?l0ol08oookJPCoo`07A?oonfX5ool01a?ooo]Z
0ol0ol17oookJP03of`0oooonf[ooo]Z00;ooo]Z00Coon<0oookJ_oonf[oo`d04ooonfX01Ol0odgo
oo]ZoookJ_oonf[oo`2Z00Cooo]Z00?oF@3ooookJ_oonfX02_oonfX00olY0?oooo]ZoookJP04oook
JP03o`3ol?oonf[ooo]Z00Oooo]Z00?oonP0oookJ_oo00/01ooonfX00ooo=@3ooo]Zo`21o`03oook
JP07o`3oUooonf[ooo]ZoookJ_l0onSooo]ZocKo000BoookJP03o`3Soooonf[ooo]Z00;ooo]Z00?o
o`3/oookJ_oonfX04?oonfX00ol0ongooo]ZoookJP0@oookJP03oolJ0?lM0?oo7@3o00Sooo]Z00Co
o`2doookJ_ooY`3oojL03ooonfX00ol0o`Wooo]ZoookJP05oookJP03og`0oooonf[o=?l000;ooo]Z
00?oo`1?o`0;oooonfX01_oonfX01On`o`3ooo]ZoookJ_oonf[o0?_o00Gooo]Z00Co0000odh0oom>
0?oo00001OoonfX2ool050Gooo]Z00?oolL0oookJ_oonfX02ooonfX2oonX00;ooo]Z00?oo`2Woook
J_oonfX01OoonfX01?oo0;Cooo]ZoookJ_oo8@0BoookJP?o0?nG3ooonfX2ohko00?ooo]Z0ooo03T=
oookJPCo0?o02?oonfX5ool01d?ooo]Z1Ooo00LDoookJP?o0?o09?oonfX002Kooo]Z00?oK03ooook
J_oonfX00ooonfX00oooh`3ooo]Zool=000CoookJP03ool00?oonf[ooo]Z00;ooo]Z00?oo`2Zoook
J_oonfX00_oonfX00omI0?oooo]ZoookJP09oookJP03obT0oooonf[ooo]Z00Cooo]Z00?o0?o`oook
J_oonfX01OoonfX7ooo900Gooo]Z00CoocD0oookJ_lgo`3oolT00_oonfX01Ol0oiOooo]ZoookJ_oo
nf[o0?oX00;ooo]Z00?o=_l0oookJ_oonfX03ooonfX00ol0hooooo]ZoookJP02oookJP03ool0k?oo
nf[ooo]Z017ooo]Z00?o0?o]oookJ_oonfX04?oonfX00ooob@3o0?oboad0o`07oookJP05ool0]?oo
nf[ooo]ZoookJ_ooY`003_oonfX01?l0o`Wooo]ZoookJ_oob@04oookJP04og`0oooonf[oolT0o`0]
o`;ooo]Z00?oo`1?o`0;oooonfX01_oonfX01On`o`3ooo]ZoookJ_oonf[o0?_o00Cooo]Z0_l00002
odh0o`Kooo]Z00?oo`0DoookJ_oonfX00ooonfX2ooo700gooo]Z0_ooZ002oookJP;oo`2W1_oonfX2
ool0]003oookJ_oo8@3oob4001?ooo]Z0ol0oiL>oookJP?oS_l00_oonfX3ool0>@oooo]Z0ol0ol09
oookJPGoo`07>_oonfX5ool01a?ooo]Z1OoUo`1:oookJP03of`0oooonf[ooo]Z00?ooo]Z00?oon<0
oookJ_oo3@004ooonfX00ol0odgooo]ZoookJP02oookJP03ool0Z_oonf[ooo]Z00;ooo]Z00?oF@3o
oookJ_oonfX02OoonfX00olY0?oooo]ZoookJP05oookJP03o`3ol?oonf[ooo]Z00Kooo]Z00?oonP0
oookJ_oo00/02?oonfX00ooo=@3ooo]Zo`21o`02oookJP05o`3oUooonf[ooo]ZoookJ_l0onP00_oo
nfX00olfo`3ooo]ZoookJP0@oookJP03o`3Soooonf[ooo]Z00;ooo]Z00?oo`3/oookJ_oonfX04?oo
nfX00ol0ongooo]ZoookJP0@oookJP03oolJ0?l0oo;o7@3o00Sooo]Z00Coo`2doookJ_oonf[oojL0
3ooonfX00ol0o`Wooo]ZoookJP05oookJP03og`0oooonf[o=?l000;ooo]Z00?oo`1?o`0;oooonfX0
1_oonfX01On`o`3ooo]ZoookJ_oonf[o0?_o00Cooo]Z0ol000000om>0?oooo]ZoookJP05oookJP03
ool05?oonf[ooo]Z00?ooo]Z0_ooa`0=oookJP03oonX0?oonf[ooo]Z00;oo`2W1_oonfX2ool0]003
oookJ_oo8@3oob4001?ooo]Z0ol0oiL>oookJP?oS_l00ooonfX3ool0>@kooo]Z0ol0ol0:oookJPGo
o`07>OoonfX5ool01a?ooo]Z1_l0ol0WoookJP009ooonfX00om/0?oooo]ZoookJP02oookJP03oooS
0?oonf[oo`d001Cooo]Z00Goo`00oookJ_oonf[ooo]Zool0ZP04oookJP03oeT0oooonf[ooo]Z00[o
oo]Z00?o:@3ooookJ_oonfX01?oonfX00ol0oo3ooo]ZoookJP05oookJPOoolT01OoonfX00ooo=@3o
=ol0ooo90003oookJP04o`3oUooonf[ooo]Zo`3oj0;ooo]Z00?o=_l0oookJ_oonfX04?oonfX00ol0
hooooo]ZoookJP02oookJP03ool0k?oonf[ooo]Z013ooo]Z00?o0?o]oookJ_oonfX04OoonfX00ooo
b@3o0?oboad0o`07oookJP05ool0]?oonf[ooo]ZoookJ_ooY`003_oonfX2o`3o2@Kooo]Z00CoO03o
oookJ_oob@3o02go0_oonfX00ooo04oo00_ooookJP06oookJP05ok3o0?oonf[ooo]ZoookJ_l0nol0
0ooonfX4o`000003odh0oooonf[ooo]Z00Cooo]Z0_oo01@5oookJP;oolL03OoonfX2oonX00;ooo]Z
0_oo0:L6oookJP?oo`2d0_oo8@0DoookJP?o0?nG3_oonfX3ohko00;ooo]Z1Ooo03T=oookJPCo0?o0
2_oonfX5ool01c3ooo]Z1Ooo00L@oookJPSoiOl0D?oonfX00om/0?oooo]ZoookJP02oookJP04oooS
0?oonf[ooo]Zool=01?ooo]Z00Go0?m=oookJ_oonf[ooo]Zool0ZP04oookJP03oeT0oooonf[ooo]Z
00[ooo]Z00?o:@3ooookJ_oonfX01?oonfX00ol0oo3ooo]ZoookJP07oookJP03oooX0?oonf[oo`0;
00Oooo]Z00CoocD0oookJ_lgo`3o087o0_oonfX01ol0oiOooo]ZoookJ_oonf[o0?oXoookJ_lfo`00
4ooonfX00ol0hooooo]ZoookJP02oookJP03ool0k?oonf[ooo]Z013ooo]Z00?o0?o]oookJ_oonfX0
4?oonfX00ooo6P3o0?oboad0o`08oookJP04ool0]?oonf[ooo]ZoonW00oooo]Z00?o0?l9oookJ_oo
nfX01OoonfX00oml0?oooo]ZocCo0003oookJP03o`0;oooonf[ooo]Z00Gooo]Z00Co/?l0oookJ_oo
nf[ooo]Z0_l0nol2oookJPCo00000_m>0?l6oookJP;oo`0D1OoonfX2ooo700cooo]Z0_ooZ002oook
JP;oo`2W1_oonfX3ool0]0;oob405?oonfX3o`3oU`kooo]Z0on>o`03oookJPGoo`0i3?oonfX4o`3o
`0_ooo]Z1Ooo00L_oookJPGoo`074?oonfX8o`3o`2gooo]Z000WoookJP03of`0oooonf[ooo]Z00?o
oo]Z00?oon<0oookJ_oo3@004ooonfX00ooo003ooo]ZoookJP02oookJP03ool0Z_oonf[ooo]Z00;o
oo]Z00?oF@3ooookJ_oonfX02_oonfX00olY0?oooo]ZoookJP03oookJP03o`3ol?oonf[ooo]Z00Go
oo]Z2?oob@04oookJP04oole0?oonf[o=ol0ooo900?ooo]Z00Co0?nGoookJ_oonf[o0?oX0_oonfX0
0olfo`3ooo]ZoookJP0@oookJP03o`3Soooonf[ooo]Z00;ooo]Z00?oo`3/oookJ_oonfX04?oonfX0
0ol0ongooo]ZoookJP0AoookJP03ooo90?l0oo;o7@3o00Oooo]Z00Goo`2doookJ_oonf[ooo]ZoonW
000?oookJP03o`3o2Ooonf[ooo]Z00Cooo]Z00CoO03ooookJ_oob@3o02go0_oonfX00ooo04oo00_o
oookJP06oookJP04ok3o0?oonf[ooo]ZoookJP;o0?_o00?ooo]Zo`000?l000000_l000000ooonf[o
CP3oodh0o`06oookJP03ool05?oonf[ooo]Z00Cooo]Z0_ooa`0=oookJP;oojP00_oonfX00ooo0:Oo
oo]ZoookJP06oookJP;oo`2d0_oo8@0EoookJP?o0?nG3_oonfX5ohko00;ooo]Z1Ooo03T<oookJPCo
0?o02ooonfX`ool01`;oiOl03?oonfX7onGo05Wooo]Z00?oK03ooookJ_oonfX00_oonfX01?ooh`3o
oo]ZoookJ_oo3@0BoookJP03o`3oCOoonf[ooo]Z00;ooo]Z00?oo`2ZoookJ_oonfX00_oonfX00omI
0?oooo]ZoookJP0:oookJP03obT0oooonf[ooo]Z00Cooo]Z00?o0?o`oookJ_oonfX01ooonfX00ooo
j03oo`0;oookJP07oookJP03oole0?oonf[o087o00?ooo]Z00Oo0?nGoookJ_oonf[ooo]Zo`3oj?oo
nf[o=_l001;ooo]Z00?o0>?ooookJ_oonfX00_oonfX00ooo0>cooo]ZoookJP0AoookJP03o`3okOoo
nf[ooo]Z013ooo]Z00?ooaX0o`3ol_lM0?l02?oonfX01?oo0;Cooo]ZoookJ_ooY`0?oookJP03o`3o
2Ooonf[ooo]Z00Gooo]Z00CoO03ooookJ_ldo`3o02go0_oonfX00ol02ooooo]ZoookJP05oookJP03
ok3o0?oonf[ooo]Z00;ooo]Z00?o0?_ooookJ_l000000ol00002oookJP03odh0oooonf[ooo]Z00Go
oo]Z00?oo`0DoookJ_oonfX01?oonfX00oooa`3ooo]ZoookJP0;oookJP;oojP00_oonfX00ooo0:Oo
oo]ZoookJP06oookJP;oo`2d0_oo8@0EoookJP?o0?nG3_oonfX5ohko00?ooo]Z1Ooo03T;oookJPCo
0?o03?oonfX_ool01`kooo]Z1ol0ol0eoookJP00:?oonfX00om/0?oooo]ZoookJP02oookJP03oooS
0?oonf[oo`d001?ooo]Z00?oo`00oookJ_oonfX00_oonfX00ooo0:[ooo]ZoookJP02oookJP03oeT0
oooonf[ooo]Z00[ooo]Z00?o:@3ooookJ_oonfX01?oonfX00ol0oo3ooo]ZoookJP04oookJPWoolT0
1?oonfX01?oo=@3o=ol0oookJ_oob@03oookJP04o`3oUooonf[ooo]Zo`3oj0;ooo]Z00?o=_l0oook
J_oonfX04?oonfX01Ol0hooooo]ZoookJ_oonf[oo`3/01?ooo]Z00?o0?o]oookJ_oonfX04OoonfX0
0ooob@3oobP0oad0o`07oookJP05ool0]?oonf[ooo]ZoookJ_ooY`003ooonfX00ol0o`Wooo]Zoook
JP04oookJP04og`0oooonf[oolT0o`0]o`;ooo]Z00?oo`1?o`0;ool02ol01_oonfX00on`o`3ooo]Z
oookJP02oookJP03o`3kool0003o000000;o00000ooonfX00om>0?oooo]ZoookJP04oookJP;oo`0D
1_oonfX00oooa`3ooo]ZoookJP0<oookJP;oojP000?ooo]Zool0Yooo0:L02?oonfX2ool0]003oolQ
0?oonf[ooo]Z01Gooo]Z0ol0oiL@oookJPCoS_l00ooonfX5ool0>@_ooo]Z2_l0ol0[oookJPSoiOl0
1?oonfX8onGo01Sooo]Z1?oo03U4oookJP03of`0oooonf[ooo]Z00;ooo]Z00Coon<0oookJ_oonf[o
o`d04ooonfX01Ol0odgooo]ZoookJ_oonf[oo`2Z00Cooo]Z00?oF@3ooookJ_oonfX02_oonfX00olY
0?oooo]ZoookJP04oookJP03o`3ol?oonf[ooo]Z00Oooo]Z00?oonP0oookJ_oo00/02?oonfX00ooo
=@3o=ol0o`21o`03oookJP04o`3oUooonf[ooo]Zo`3oj0;ooo]Z00?o=_l0oookJ_oonfX04?oonfX0
0ol0hooooo]ZoookJP02oookJP03ool0k?oonf[ooo]Z017ooo]Z00?o0?o]oookJ_oonfX04?oonfX0
0ooo6P3o0?oboad0o`08oookJP04ool0]?oonf[ooo]ZoonW00oooo]Z00?o0?l9oookJ_oonfX01Ooo
nfX01?ml0?oooo]ZocCo0?l0;Ol2oookJP;o00_o1_oonfX00on`o`3ooo]ZoookJP02oookJP03o`3k
ool0003o000000;o00000ooonfX2odh0o`Kooo]Z0_oo01@5oookJP;oolL03OoonfX2oonX0003oook
J_oo0:Ooo`2W00Sooo]Z0_oo0;@2oolQ01Kooo]Z0ol0oiL@oookJPCoS_l01?oonfX5ool0>@[ooo]Z
2_l0ol0goookJPSo0?o06OoonfX4ool0>Aoooo]Z000XoookJP03of`0oooonf[ooo]Z00?ooo]Z00?o
on<0oookJ_oo3@004ooonfX00ooo003ooo]ZoookJP02oookJP03ool0Z_oonf[ooo]Z00;ooo]Z00?o
F@3ooookJ_oonfX02_oonfX00olY0?oooo]ZoookJP04oookJP03o`3ol?oonf[ooo]Z00Cooo]Z2Ooo
b@04oookJP03oole0?lgo`3oolT000?ooo]Z00Co0?nGoookJ_oonf[o0?oX0_oonfX00olfo`3ooo]Z
oookJP0AoookJP05o`3Soooonf[ooo]ZoookJ_oo0>`04ooonfX00ol0ongooo]ZoookJP0@oookJP05
ooo90?oo:03oobP0oad0oooo:0001_oonfX01Ooo0;Cooo]ZoookJ_oonf[oojL000oooo]Z00?o0?l9
oookJ_oonfX01?oonfX01?ml0?oooo]Zooo90?oob@03oookJP03ool0Col02ooooo]Z00Gooo]Z00?o
/?l0oookJ_oonfX00_oonfX00ol0nooo0000o`000002o`0000?ooo]Z00?oCP3ooookJ_oonfX01Ooo
nfX00ooo01Cooo]ZoookJP04oookJP;oolL03_oonfX2oonX0003oookJ_oo0:Oooo]Z00Sooo]Z00?o
o`2doolQ0?oo8@006?oonfX3o`3oUa7ooo]Z1?n>o`04oookJPGoo`0i4?oonfX?o`3o`1Wooo]Z3ooU
o`0KoookJPGoo`0iBOoonfX00om/0?oooo]ZoookJP02oookJP04oooS0?oonf[ooo]Zool=01;ooo]Z
00?o0?m=oookJ_oonfX00_oonfX00ooo0:[ooo]ZoookJP02oookJP03oeT0oooonf[ooo]Z00[ooo]Z
00?o:@3ooookJ_oonfX01?oonfX00ol0oo3ooo]ZoookJP07oookJP03oooX0?oo00_ooo]Z00Oooo]Z
00CoocD0oookJ_lgo`3o087o0_oonfX01ol0oiOooo]ZoookJ_oonf[o0?oXoookJ_lfo`004ooonfX0
0ol0hooooo]ZoookJP02oookJP03ool0k?oonf[ooo]Z013ooo]Z00?o0?o]oookJ_oonfX04OoonfX0
0ooo6P3ooo]Zoad0o`08oookJP04ool0]?oonf[ooo]ZoonW00oooo]Z00?o0?l9oookJ_oonfX01Ooo
nfX01?ml0?oooo]ZocCo0?ldo`02oookJP03ool0Col02ooooo]Z00Gooo]Z00?o/?l0oookJ_oonfX0
0_oonfX2o`3ko`?o00001?oonfX00om>0?oooo]ZoookJP05oookJP03ool05?oonf[ooo]Z00Cooo]Z
0_ooa`0=oookJP;oojP000?ooo]Zool0YooonfX02?oonfX2ool0]003oolQ0?oonf[ooo]Z01Kooo]Z
0ol0oiLAoookJPCoS_l01OoonfX5ool0>@oooo]Z3ol0ol0PoookJPSo0?o07?oonfX5ool0>B?ooo]Z
000YoookJP03of`0oooonf[ooo]Z00;ooo]Z00Coon<0oookJ_oonf[oo`d04_oonfX00ooo003ooo]Z
oookJP02oookJP03ool0Z_oonf[ooo]Z00;ooo]Z00?oF@3ooookJ_oonfX02_oonfX00olY0?oooo]Z
oookJP04oookJP03o`3ol?oonf[ooo]Z00Cooo]Z1ooob@06oookJP04oole0?oonf[o=ol0ooo900?o
oo]Z00Co0?nGoookJ_oonf[o0?oX0_oonfX00olfo`3ooo]ZoookJP0@oookJP03o`3Soooonf[ooo]Z
00;ooo]Z00?oo`3/oookJ_oonfX04OoonfX00ol0ongooo]ZoookJP0@oookJP04ooo90?oo:03oobP0
oad0o`;oobP01OoonfX01Ooo0;Cooo]ZoookJ_oonf[oojL000oooo]Z00?o0?l9oookJ_oonfX01?oo
nfX01?ml0?oooo]ZoookJ_oob@03oookJP03ool0Col02oooo`0H00Gooo]Z00Ko/?l0oookJ_oonf[o
oo]Zo`000?l0nol2o`0000Gooo]Z0_m>0?l6oookJP03ool05?oonf[ooo]Z00Gooo]Z0_ooa`0>oook
JP04oonX0?oonf[oo`2Wool0Y`[ooo]Z0_oo8@0IoookJP?o0?nG4_oonfX5ohko00Cooo]Z1Ooo03TJ
oookJPoo0?o01ooonfX?onGo01Sooo]Z1_oo03U>oookJP03of`0oooonf[ooo]Z00;ooo]Z00Coon<0
oookJ_oonf[oo`d04ooonfX01Ol0odgooo]ZoookJ_oonf[oo`2Z00Cooo]Z00?oF@3ooookJ_oonfX0
2ooonfX00olY0?oooo]ZoookJP03oookJP03o`3ol?oonf[ooo]Z00Sooo]Z00?oonP0ool02ooonfX0
1ooonfX01?oo=@3ooo]ZocOo0?l0POl2oookJP07o`3oUooonf[ooo]ZoookJ_l0onSooo]ZocKo000C
oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`04ooonfX00ol0ongooo]ZoookJP0AoookJP03oolJ0?oo
nf[o7@3o00Sooo]Z00Coo`2doookJ_oonf[oojL03ooonfX00ol0o`Wooo]ZoookJP05oookJP04og`0
oooonf[ooo]ZocCo00;ooo]Z00?oo`1?o`0;oooo01P01OoonfX01?n`o`3ooo]ZoookJ_oonfX2o`00
0003o`3kool0003ooo]Z00Gooo]Z00?oCP3ooookJ_oonfX01OoonfX00ooo01Cooo]ZoookJP05oook
JP;oolL03OoonfX2oonX00;oo`2W2_oonfX2oolQ01Wooo]Z0ol0oiLBoookJPGoS_l01OoonfX5ool0
>AWooo]Z3ol0ol0:oookJPOo0?o07_oonfX6ool0>BSooo]Z000YoookJP03of`0oooonf[ooo]Z00?o
oo]Z00?oon<0oookJ_oo3@004ooonfX00ooo003ooo]ZoookJP02oookJP03ool0Z_oonf[ooo]Z00;o
oo]Z00?oF@3ooookJ_oonfX02_oonfX00olY0?oooo]ZoookJP04oookJP03o`3ol?oonf[ooo]Z00?o
oo]Z1_oob@000ooo00_ooo]ZoookJP05oookJP04oole0?oonf[o=ol0ooo900?ooo]Z00Co0?nGoook
J_oonf[o0?oX0_oonfX00olfo`3ooo]ZoookJP0@oookJP05o`3Soooonf[ooo]ZoookJ_oo0>`05?oo
nfX00ol0ongooo]ZoookJP0@oookJP04ooo90?oo:03oobP0oad0o`?oobP01?oonfX01Ooo0;Cooo]Z
oookJ_oonf[oojL000oooo]Z00?o0?l9oookJ_oonfX01?oonfX01?ml0?oooo]ZoookJ_oob@03oook
JP03ool0Col02oooo`0H00Gooo]Z00?o/?l0oookJ_oonfX00_l00002o`3ko`Oooo]Z00?oCP3ooook
J_oonfX01?oonfX2ool050Oooo]Z0_ooa`0=oookJP;oojP000?ooo]Zool0Yooo0:L02_oonfX2oolQ
01[ooo]Z0_l0oiLEoookJPCoS_l01OoonfX5ool0>BCooo]Z1_l0ol0@onGo01?ooo]Z1Ooo03T;oook
JPCoS_l0A_oonfX00om/0?oooo]ZoookJP02oookJP04oooS0?oonf[ooo]Zool=01;ooo]Z00?o0?m=
oookJ_oonfX00_oonfX00ooo0:[ooo]ZoookJP02oookJP03oeT0oooonf[ooo]Z00[ooo]Z00?o:@3o
oookJ_oonfX01?oonfX00ol0oo3ooo]ZoookJP08oookJP03oooX0?oo00_ooo]Z00Oooo]Z00?oocD0
ocOo0?l0POl00ooonfX01ol0oiOooo]ZoookJ_oonf[o0?oXoookJ_lfo`004ooonfX01Ol0hooooo]Z
oookJ_oonf[oo`3/01?ooo]Z00?o0?o]oookJ_oonfX04OoonfX00ooo6P3ooo]Zoad0o`08oookJP04
ool0]?oonf[ooo]ZoonW00oooo]Z0_l0o`T6oookJP04og`0oooonf[ooo]ZocCo00?ooo]Z00?o00_o
ool06?oonfX01?oonfX00on`o`3ooo]ZoookJP03o`000003o`3koooonf[ooo]Z00Gooo]Z0_m>0?l6
oookJP;oo`0D1ooonfX00oooa`3ooo]ZoookJP0<oookJP;oojP00_oo0:L:oookJP;oob406_oonfX3
o`3oUaCooo]Z1?n>o`06oookJPGoo`0i8ooonfX:o`3o`1oooo]Z1_oo03T;oookJPCoS_l07ooonfX0
02[ooo]Z00?oK03ooookJ_oonfX00_oonfX01?ooh`3ooo]ZoookJ_oo3@0BoookJP03ool00?oonf[o
oo]Z00;ooo]Z00?oo`2ZoookJ_oonfX00ooonfX00omI0?oooo]ZoookJP0:oookJP03obT0oooonf[o
oo]Z00?ooo]Z00?o0?o`oookJ_oonfX01?oonfX3ooo90004oookJ_oob@3ooo]Zool02`Oooo]Z00?o
ocD0ocOo0?oob@001?oonfX00ol0oiOooo]Zo`3oj002oookJP03ocKo0?oonf[ooo]Z017ooo]Z00Go
0>?ooookJ_oonf[ooo]Zool0k00DoookJP03o`3okOoonf[ooo]Z013ooo]Z00CoolT0oolX0?oo:03o
7@3o1?oo:003oookJP05ool0]?oonf[ooo]ZoookJ_ooY`003ooonfX00ol0o`Wooo]ZoookJP04oook
JP04og`0oooonf[ooo]Zooo900?ooo]Z00?oo`1?o`0;oooo01P01OoonfX2ok3o00Co000000?o0?_o
oookJ_oonfX01OoonfX2odh0o`Kooo]Z00?oo`0DoookJ_oonfX01_oonfX2ooo700gooo]Z0_ooZ000
1?oonf[oo`2Wool0Yooo0:L9oookJP;oob4000?oo`2doookJ_oonfX05ooonfX3o`3oUaKooo]Z1On>
o`05oookJPGoo`0i:_oonfX;onGo00kooo]Z1Ooo03T:oookJPKoS_l0B_oonfX00om/0?oooo]Zoook
JP02oookJP04oooS0?oonf[ooo]Zool=01;ooo]Z00?o0?m=oookJ_oonfX00_oonfX00ooo0:[ooo]Z
oookJP03oookJP03oeT0oooonf[ooo]Z00[ooo]Z00?o:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]Z
oookJP08oookJP03oooX0?oonf[oo`0;00Oooo]Z00CoocD0oookJ_lgo`3o087o0ooonfX01_l0oiOo
oo]ZoookJ_l0onSooo]ZocKo01?ooo]Z00?o0>?ooookJ_oonfX00_oonfX00ooo0>cooo]ZoookJP0A
oookJP03o`3okOoonf[ooo]Z017ooo]Z00?ooaX0oookJ_lM0?l02?oonfX00ooo0;Cooo]ZoookJP02
oonW00oooo]Z00?o0?l9oookJ_oonfX01?oonfX01?ml0?oooo]ZoookJ_ldo`03oookJP03o`0;oooo
01Sooo]Z00Cooo]Z0_n`o`04o`0000;o0?_o1ooonfX00om>0?oooo]ZoookJP05oookJP03ool05?oo
nf[ooo]Z00Gooo]Z0_ooa`0>oookJP;oojP00ooo0:L9oookJP;oob4000?oo`2doookJ_oonfX06?oo
nfX3o`3oUaGooo]Z1On>o`06oookJPGoo`0i@_oonfX5ool0>@_ooo]Z1_n>o`0SoookJP00:_oonfX0
0om/0?oooo]ZoookJP03oookJP03oooS0?oonf[oo`d001?ooo]Z00?oo`00oookJ_oonfX00_oonfX0
0ooo0:[ooo]ZoookJP02oookJP03oeT0oooonf[ooo]Z00[ooo]Z00?o:@3ooookJ_oonfX01?oonfX0
0ol0oo3ooo]ZoookJP03oookJP03ooo90?oonf[ooo]Z00;ooo]Z00?oolT0ool02ooonfX01_oonfX0
1?oo=@3ooo]ZocOo0?oob@03oookJP04o`3oUooonf[ooo]Zo`3oj0;ooo]Z00?o=_l0oookJ_oonfX0
4OoonfX01Ol0hooooo]ZoookJ_oonf[oo`3/01?ooo]Z00?o0?o]oookJ_oonfX04OoonfX01?oob@3o
obP0oolX0?lM0?l5oolX00;ooo]Z00Goo`2doookJ_oonf[ooo]ZoonW000?oookJP03o`3o2Ooonf[o
oo]Z00Cooo]Z00CoO03ooookJ_oonf[oolT00ooonfX01?oo04oo00_oool06?oo01P5oookJP06ok3o
0?l0003o0000o`000?oonf[o0?_o2?oonfX00om>0?oooo]ZoookJP04oookJP;oo`0D2?oonfX00ooo
a`3ooo]ZoookJP0<oookJP;oojP00_oonfX2ool0Y`Wooo]Z0ooo8@0JoookJP?o0?nG6?oonfX4ohko
00Kooo]Z1Ooo03T<oookJP?oolT07OoonfX4onGo00Sooo]Z1_oo03T9oookJPKoS_l0DOoonfX00om/
0?oooo]ZoookJP02oookJP04oooS0?oonf[ooo]Zool=01;ooo]Z00?o0?m=oookJ_oonfX00_oonfX0
0ooo0:[ooo]ZoookJP02oookJP03oeT0oooonf[ooo]Z00_ooo]Z00?o:@3ooookJ_oonfX00ooonfX0
0ol0oo3ooo]ZoookJP08oookJP03oooX0?oo00_ooo]Z00Oooo]Z00CoocD0oookJ_lgo`3o087o0_oo
nfX01ol0oiOooo]ZoookJ_oonf[o0?oXoookJ_lfo`004ooonfX00ol0hooooo]ZoookJP02oookJP03
ool0k?oonf[ooo]Z017ooo]Z00?o0?o]oookJ_oonfX04OoonfX00ooo6P3ooo]Zoad0o`08oookJP05
ool0]?oonf[ooo]ZoookJ_ooY`003ooonfX00ol0o`Wooo]ZoookJP04oookJP04og`0oooonf[ooo]Z
ocCo00?ooo]Z00?o00_oool06?oo01P01OoonfX01?n`o`3o0000o`000?l00002oookJP03o`3koooo
nf[ooo]Z00Gooo]Z0_m>0?l6oookJP;oo`0D1ooonfX2ooo700kooo]Z0_ooZ0000ooonf[oo`2Wool0
Y`09oookJP?oob406ooonfX3o`3oUaOooo]Z1?n>o`07oookJPGoo`0i=ooonfX6ool0>@[ooo]Z1_n>
o`0YoookJP00:ooonfX00om/0?oooo]ZoookJP02oookJP04oooS0?oonf[ooo]Zool=01;ooo]Z00?o
o`00oookJ_oonfX00_oonfX00ooo0:[ooo]ZoookJP03oookJP03oeT0oooonf[ooo]Z00[ooo]Z00?o
:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP09oookJP03ooo90?oo00_ooo]Z00Kooo]Z00Co
ocD0oookJ_lgo`3oolT00ooonfX01?l0oiOooo]ZoookJ_l0onP2oookJP03ocKo0?oonf[ooo]Z017o
oo]Z00Co0>?ooookJ_oonf[oo`3/5?oonfX00ol0ongooo]ZoookJP0@oookJP05oolX0?oob@3oobP0
oolX0?lM0?l01_oo:0000ooonf[oo`2doookJP02oookJP03oonW0?oonf[ooo]Z00gooo]Z00?o0?l9
oookJ_oonfX01?oonfX00oml0?oooo]ZoookJP02ooo900;ooo]Z00Coo`1?o`0;ool02oooo`0H1?oo
nfX01?l0003o/?l0ok3o0?l00002oookJP;o0?_o1ooonfX00om>0?oooo]ZoookJP05oookJP03ool0
5?oonf[ooo]Z00Kooo]Z0_ooa`0>oookJP;oojP00_oonfX2ool0Y`[ooo]Z0ooo8@0JoookJP?o0?nG
6OoonfX4ohko00Oooo]Z1ooo03T8ooo900_oo`0i6OoonfX5ool0>@Wooo]Z1_n>o`1GoookJP03of`0
oooonf[ooo]Z00;ooo]Z00Coon<0oookJ_oonf[oo`d04_oonfX00ol0odgooo]ZoookJP02oookJP03
ool0Z_oonf[ooo]Z00?ooo]Z00?oF@3ooookJ_oonfX02ooonfX00olY0?oooo]ZoookJP02oookJP03
o`3ol?oonf[ooo]Z00Wooo]Z00?oonP0ool02ooonfX01ooonfX00ooo=@3ooo]Zo`21o`03oookJP07
o`3oUooonf[ooo]ZoookJ_l0onSooo]ZocKo000CoookJP05o`3Soooonf[ooo]ZoookJ_oo0>`05?oo
nfX00ol0ongooo]ZoookJP0AoookJP04oolJ0?oonf[o7@3oo`3olPOooo]Z00Goo`2doookJ_oonf[o
oo]ZoonW000?oookJP03o`3o2Ooonf[ooo]Z00Cooo]Z00?oO03ooookJ_oonfX00_ldo`02oookJP;o
00_o00?oo`0HoookJ_oonfX00_oonfX01?l0003o/?l0ok3o0?l00003oookJP;o0?_o1ooonfX00om>
0?oooo]ZoookJP05oookJP03ool05?oonf[ooo]Z00Kooo]Z00?oolL0oookJ_oonfX03OoonfX2oonX
0003oookJ_oo0:Ooo`2W00[ooo]Z0ooo8@0KoookJP?o0?nG6?oonfX4ohko00Sooo]Z6Ooo03TIoook
JPGoo`0i2_oonfX6ohko02oooo]Z000[oookJP03of`0oooonf[ooo]Z00;ooo]Z00Goon<0oookJ_oo
nf[ooo]Zool=000BoookJP03ool00?oonf[ooo]Z00;ooo]Z00?oo`2ZoookJ_oonfX00_oonfX00omI
0?oooo]ZoookJP0;oookJP03obT0oooonf[ooo]Z00?ooo]Z00?o0?o`oookJ_oonfX02?oonfX00ooo
b@3ooo]Zool02`06oookJP04oole0?oonf[ooo]Zooo900Cooo]Z00?o0?nGoookJ_l0onP00_oonfX0
0olfo`3ooo]ZoookJP0AoookJP05o`3Soooonf[ooo]ZoookJ_oo0>`05?oonfX00ol0ongooo]Zoook
JP0@oookJP05oolX0?oob@3oobP0oolX0?lM0?l01_oo:0000ooonf[oo`2doookJP02oookJP03oonW
0?oonf[ooo]Z00gooo]Z00?o0?l9oookJ_oonfX01?oonfX2og`0o`03oookJ_l0;OooolT000?ooo]Z
00Coo`1?o`0;oooo01Soo`0H0_oonfX3o`0000;o/?l00ooonfX00ol0nooooo]ZoookJP05oookJP;o
CP3o1_oonfX2ool050Sooo]Z0_ooa`0>oookJP;oojP00_oonfX3ool0Y`Wooo]Z00?oo`2doolQ0?oo
8@006ooonfX3o`3oUa[ooo]Z1On>o`04oookJPgoolT02ooonfXIool0>@Wooo]Z1On>o`1NoookJP05
of`0oooonf[ooo]ZoookJ_ooh`000ooonfX00ooo3@3ooo]ZoookJP0@oookJP03o`3oCOoonf[ooo]Z
00;ooo]Z00?oo`2ZoookJ_oonfX00_oonfX00omI0?oooo]ZoookJP0;oookJP03obT0oooonf[ooo]Z
00?ooo]Z00?o0?o`oookJ_oonfX02?oonfX00oooj03ooo]Zool02`07oookJP04oole0?oonf[o=ol0
o`21o`?ooo]Z00Ko0?nGoookJ_oonf[o0?oXoookJ_lfo`0DoookJP05o`3Soooonf[ooo]ZoookJ_oo
0>`04ooonfX00ol0ongooo]ZoookJP0BoookJP04oolJ0?oonf[o7@3oo`3olPOooo]Z00Goo`2doook
J_oonf[ooo]ZoonW000?oookJP03o`3o2Ooonf[ooo]Z00Cooo]Z0_ml0?l00ooonf[o02goocCo0002
oookJP04ool0Col02oooo`0Hool060;ooo]Z0ol00002ok3o00Cooo]Z00?o0?_ooookJ_oonfX01Ooo
nfX2odh0o`Kooo]Z0_oo01@7oookJP;oolL03ooonfX00oooZ03ooo]ZoookJP03ool0Y`Wooo]Z00?o
o`2doolQ0?oo8@007?oonfX3o`3oUaWooo]Z1On>o`0LoookJQWoo`0i2_oonfX5ohko03Gooo]Z000/
oookJP03of`0oooonf[ooo]Z00;ooo]Z00Coon<0oookJ_oonf[oo`d06?oonfX00ooo0:[ooo]Zoook
JP02oookJP03oeT0oooonf[ooo]Z00[ooo]Z00?o:@3ooookJ_oonfX00ooonfX00ol0oo3ooo]Zoook
JP09oookJP03ooo90?oonf[oo`0;00Kooo]Z00CoocD0oookJ_oonf[oolT01?oonfX00ol0oiOooo]Z
o`3oj002oookJP03ocKo0?oonf[ooo]Z017ooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00DoookJP03
o`3okOoonf[ooo]Z013ooo]Z00GoobP0ooo90?oo:03oobP0oad0o`04oolX00?ooo]Z00Goo`2doook
J_oonf[ooo]ZoonW000?oookJP03o`3o2Ooonf[ooo]Z00Gooo]Z00CoO03oo`00Ool0;OooolT00ooo
nfX01Ooo04oo00_ooookJ_oo01Sooo]Z00Co000000?ooo]Zok3o0?oonfX00_oonfX00ol0nooooo]Z
oookJP06oookJP03odh0oooonf[ooo]Z00Gooo]Z00?oo`0DoookJ_oonfX01ooonfX2ooo700kooo]Z
0_ooZ003oookJP;oo`2W2_oonfX3oolQ01_ooo]Z0ol0oiLLoookJP03ohko0?oob@3oolT000koolT0
9ooonfX6ohko06Cooo]Z00GoK03ooookJ_oonf[ooo]ZoooS0003oookJP03ool=0?oonf[ooo]Z01Go
oo]Z00?oo`2ZoookJ_oonfX00_oonfX00omI0?oooo]ZoookJP0;oookJP03obT0oooonf[ooo]Z00?o
oo]Z00?o0?o`oookJ_oonfX02?oonfX00oooj03ooo]Zool02`07oookJP04oole0?oonf[o=ol0o`21
o`?ooo]Z00Ko0?nGoookJ_oonf[o0?oXoookJ_lfo`0CoookJP03o`3Soooonf[ooo]Z00;ooo]Z00?o
o`3/oookJ_oonfX04OoonfX00ol0ongooo]ZoookJP0BoookJP04oolJ0?oonf[o7@3oo`3olPOooo]Z
00Goo`2doookJ_oonf[ooo]ZoonW000?oookJP03o`3o2Ooonf[ooo]Z00Gooo]Z00CoO03oo`00Ool0
;Ooo=?l00ooonfX01?l02ooooo]Zool06?oonfX4o`000003oookJ_n`o`3ooo]Z00?ooo]Z00?o0?_o
oookJ_oonfX01_oonfX00om>0?oooo]ZoookJP05oookJP03ool05?oonf[ooo]Z00Kooo]Z0_ooa`0>
oookJP;oojP00ooonfX2ool0Y`[ooo]Z0ooo8@0LoookJP?o0?nG6ooonfX>ohko02_ooo]Z1_n>o`0j
oookJP00;?oonfX00om/0?oooo]ZoookJP02oookJP05oooS0?oonf[ooo]ZoookJ_oo3@005ooonfX0
0ooo0:[ooo]ZoookJP02oookJP03oeT0oooonf[ooo]Z00_ooo]Z00?o:@3ooookJ_oonfX00ooonfX0
0ol0oo3ooo]ZoookJP09oookJP03ooo90?oo00_ooo]Z00Kooo]Z00CoocD0oookJ_lgo`3oolT00ooo
nfX01?l0oiOooo]ZoookJ_l0onP2oookJP03ocKo0?oonf[ooo]Z017ooo]Z00Go0>?ooookJ_oonf[o
oo]Zool0k00DoookJP03o`3okOoonf[ooo]Z00oooo]Z0_oo:0001?oob@3oobP0oolX0?lM0?l2oolX
00Gooo]Z00Goo`2doookJ_oonf[ooo]ZoonW000?oookJP03o`3o2Ooonf[ooo]Z00Gooo]Z0_ml0?l0
0ol0;OooolT0oookJP02oookJP04ool0Col02ooooo]Zool060Co00000_oonfX2ok3o00;ooo]Z0_l0
nol7oookJP;oCP3o1_oonfX00ooo01Cooo]ZoookJP08oookJP;oolL03_oonfX00oooZ03ooo]Zoook
JP02oookJP;oo`2W2_oonfX00ooo0;Coob40oolQ000LoookJP?o0?nG7OoonfXQooo900gooo]Z1_n>
o`1ZoookJP05of`0oooonf[ooo]ZoookJ_ooh`000ooonfX00ooo3@3ooo]ZoookJP0EoookJP03ool0
Z_oonf[ooo]Z00;ooo]Z00?oF@3ooookJ_oonfX03?oonfX00olY0?oooo]ZoookJP02oookJP03o`3o
l?oonf[ooo]Z00Wooo]Z00?oonP0ool02ooonfX01ooonfX01?oo=@3ooo]ZocOo0?l0POl2oookJP07
o`3oUooonf[ooo]ZoookJ_l0onSooo]ZocKo000CoookJP05o`3Soooonf[ooo]ZoookJ_oo0>`05?oo
nfX00ol0ongooo]ZoookJP0BoookJP04oolJ0?oonf[o7@3oo`3olPOooo]Z00Goo`2doookJ_oonf[o
oo]ZoonW000?oookJP03o`3o2Ooonf[ooo]Z00Cooo]Z00Go001oog`0ooml0?oo02goocCo0003oook
JP03o`0;oooonf[oo`0H00Co00000_oonfX2ok3o00?ooo]Z0_l0nol7oookJP03odh0oooonf[ooo]Z
00Gooo]Z00?oo`0DoookJ_oonfX01ooonfX2ooo700kooo]Z0_ooZ003oookJP;oo`2W2_oonfX00ooo
0;Coob40oolQ000MoookJP?o0?nG9_oonfXGohko00kooo]Z1_n>o`10oookJP00;OoonfX00om/0?oo
oo]ZoookJP02oookJP04oooS0?oonf[ooo]Zool=01Sooo]Z00?oo`2ZoookJ_oonfX00_oonfX00omI
0?oooo]ZoookJP0:oookJP03obT0oooonf[ooo]Z00Cooo]Z00?o0?o`oookJ_oonfX02?oonfX00ooo
b@3ooo]Zool02`06oookJP04oole0?oonf[ooo]Zooo900Cooo]Z00?o0?nGoookJ_l0onP00_oonfX0
0olfo`3ooo]ZoookJP0BoookJP04o`3Soooonf[ooo]Zool0k1Gooo]Z00?o0?o]oookJ_oonfX03ooo
nfX2oolX0004ooo90?oo:03oobP0oad0o`Oooo]Z00Goo`2doookJ_oonf[ooo]ZoonW000?oookJP03
o`3o2Ooonf[ooo]Z00Cooo]Z0_l007l2og`0o`07ooo90?oonf[ooo]ZoookJ_oo04oo00_ooookJP02
ool060;o00001?oonfX2ok3o00;ooo]Z00?o0?_ooookJ_oonfX01_oonfX00om>0?oooo]ZoookJP04
oookJP;oo`0D2_oonfX00oooa`3ooo]ZoookJP0<oookJP;oojP01?oonfX3ool0Y`Wooo]Z00Coo`2d
oolQ0?oo8@3oob407?oonfX4o`3oUagooo]Z2Ooob@0DoookJP_oolT00_n>o`1aoookJP05of`0oooo
nf[ooo]ZoookJ_ooh`000ooonfX00ooo3@3ooo]ZoookJP0EoookJP03ool0Z_oonf[ooo]Z00;ooo]Z
00?oF@3ooookJ_oonfX02ooonfX00olY0?oooo]ZoookJP03oookJP03o`3ol?oonf[ooo]Z00Sooo]Z
00?oonP0oookJ_oo00/01ooonfX01?oo=@3ooo]ZocOo0?l0POl3oookJP06o`3oUooonf[ooo]Zo`3o
j?oonf[o=_l05?oonfX01Ol0hooooo]ZoookJ_oonf[oo`3/01Cooo]Z00?o0?o]oookJ_oonfX04_oo
nfX01?oo6P3ooo]Zoad0ool0oo87oookJP05ool0]?oonf[ooo]ZoookJ_ooY`003ooonfX00ol0o`Wo
oo]ZoookJP03oookJP?o001o00?oO03oo`0]ooldo`000ooonfX01?l02ooooo]Zool06?oo01P2o`00
00Cooo]Z0_n`o`03oookJP03o`3koooonf[ooo]Z00Gooo]Z0_m>0?l6oookJP;oo`0D2OoonfX00ooo
a`3ooo]ZoookJP0=oookJP;oojP00ooonfX3ool0Y`Wooo]Z00Coo`2doolQ0?oo8@3oob407OoonfX4
o`3oUcWooo]Z3_n>o`16oookJP00;OoonfX00om/0?oooo]ZoookJP02oookJP05oooS0?oonf[ooo]Z
oookJ_oo3@005ooonfX00ooo0:[ooo]ZoookJP02oookJP03oeT0oooonf[ooo]Z00_ooo]Z00?o:@3o
oookJ_oonfX00ooonfX00ol0oo3ooo]ZoookJP09oookJP03ooo90?oonf[oo`0;00Kooo]Z00CoocD0
oookJ_oonf[oolT01?oonfX00ol0oiOooo]Zo`3oj002oookJP03ocKo0?oonf[ooo]Z01;ooo]Z00Co
0>?ooookJ_oonf[oo`3/5OoonfX00ol0ongooo]ZoookJP0>oookJP?oobP000CoolT0oolX0?oonf[o
7@3o1ooonfX01Ooo0;Cooo]ZoookJ_oonf[oojL000oooo]Z00?o0?l9oookJ_oonfX00ooonfX3o`00
O`04oookJ_ml0?ooolT0o`0]o`;ooo]Z00Koo`1?o`0;ool0003o0000ool06?l00006oookJP04ok3o
0?oonf[ooo]Zo`3ko`Sooo]Z00?oCP3ooookJ_oonfX01OoonfX00ooo01Cooo]ZoookJP08oookJP;o
olL03_oonfX2oonX00Gooo]Z0_oo0:L:oookJP04ool0]?oo8@3oob40oolQ01gooo]Z1_l0oiLJoook
JPKoolT0T_oonfX01Om/0?oooo]ZoookJ_oonf[oon<000?ooo]Z00?oo`d0oookJ_oonfX05OoonfX0
0ooo0:[ooo]ZoookJP02oookJP03oeT0oooonf[ooo]Z00cooo]Z00?o:@3ooookJ_oonfX00_oonfX0
0ol0oo3ooo]ZoookJP09oookJP03oooX0?oonf[oo`0;00Oooo]Z00CoocD0oookJ_lgo`3o087o0ooo
nfX01_l0oiOooo]ZoookJ_l0onSooo]ZocKo01Cooo]Z00Go0>?ooookJ_oonf[ooo]Zool0k00Doook
JP03o`3okOoonf[ooo]Z01;ooo]Z00CooaX0oookJ_lM0?oo0?ob1ooonfX01Ooo0;Cooo]ZoookJ_oo
nf[oojL000oooo]Z00?o0?l9oookJ_oonfX00_oonfX3o`00O`04oookJ_ml0?oo02goocCo00?ooo]Z
00Go00_oo`000?l0003oo`0Ho`000006oookJP05ok3o0?oonf[ooo]ZoookJ_l0nol02?oonfX00om>
0?oooo]ZoookJP05oookJP03ool05?oonf[ooo]Z00Oooo]Z0_ooa`0?oookJP;oojP01?oonfX2ool0
Y`[ooo]Z00Coo`2doolQ0?oo8@3oob407_oonfX5o`3oUhSooo]Z000^oookJP03of`0oooonf[ooo]Z
00;ooo]Z00Goon<0oookJ_oonf[ooo]Zool=000GoookJP03ool0Z_oonf[ooo]Z00;ooo]Z00?oF@3o
oookJ_oonfX02ooonfX00olY0?oooo]ZoookJP03oookJP03o`3ol?oonf[ooo]Z00Wooo]Z00?oolT0
oookJ_oo00/01_oonfX01?oo=@3ooo]ZoookJ_oob@04oookJP03o`3oUooonf[o0?oX00;ooo]Z00?o
=_l0oookJ_oonfX04_oonfX01?l0hooooo]ZoookJ_oo0>`EoookJP03o`3okOoonf[ooo]Z00kooo]Z
0ooo:0001?oob@3ooo]ZoookJ_lM0?l7oookJP05ool0]?oonf[ooo]ZoookJ_ooY`003ooonfX00ol0
o`Wooo]ZoookJP02oookJP?o001o0_oonfX00oml0?ooolT0o`0]o`02oookJP05ool0Col02ooo0000
o`000?oo01P00_l00005oookJP04ok3o0?oonf[ooo]Zo`3ko`Sooo]Z00?oCP3ooookJ_oonfX01Ooo
nfX00ooo01Cooo]ZoookJP09oookJP03ooo70?oonf[ooo]Z00gooo]Z00?oojP0oookJ_oonfX01?oo
nfX00ooo0:Oooo]ZoookJP09oookJP03ool0]?oonf[oob4002;ooo]Z0ol0oiLKoookJP;oolT0A_oo
nfX2o`3oUd_ooo]Z00GoK03ooookJ_oonf[ooo]ZoooS0003oookJP03ool=0?oonf[ooo]Z01Gooo]Z
00?oo`2ZoookJ_oonfX00_oonfX00omI0?oooo]ZoookJP0<oookJP03obT0oooonf[ooo]Z00;ooo]Z
00?o0?o`oookJ_oonfX02OoonfX00oooj03ooo]Zool02`07oookJP04oole0?oonf[o=ol0o`21o`?o
oo]Z00Ko0?nGoookJ_oonf[o0?oXoookJ_lfo`0DoookJP05o`3Soooonf[ooo]ZoookJ_oo0>`05?oo
nfX00ol0ongooo]ZoookJP0BoookJP04oolJ0?oonf[o7@3oo`3olPOooo]Z00Goo`2doookJ_oonf[o
oo]ZoonW000?oookJP04o`3o2Ooonf[ooo]ZoookJP?o001o0_oonfX00oml0?oooo]ZocCo0003oook
JP04o`0;ool0003o0000ool060;o00001OoonfX01On`o`3ooo]ZoookJ_oonf[o0?_o00Sooo]Z00?o
CP3ooookJ_oonfX01OoonfX00ooo01Cooo]ZoookJP08oookJP03ooo70?oonf[ooo]Z00kooo]Z00?o
ojP0oookJ_oonfX00ooonfX00ooo0:Oooo]ZoookJP09oookJP03ool0]?oonf[oob4002;ooo]Z0ol0
oiMSoookJP?o0?nG7ooonfX00?3ooo]Z0ol007l8oookJPCo0000oooonf[ToookJP?o001o2?oonfX4
o`000?Oooo]Z003`oookJP?o001o2?oonfX4o`000?oooo]Zi?oonfX3o`00O`Sooo]Z1?l0003goook
JP00l?oonfX3o`00Oooooo]Zl?oonfX3o`00Oooooo]Z1?oonfX00?3ooo]Z0ol007oooookJ_3ooo]Z
0ol007oooookJPCooo]Z003]oookJPKo001ooooonf[]oookJPKo001ooooonfX4oookJP00kOoonfX6
o`00Oooooo]ZkOoonfX6o`00Oooooo]Z1?oonfX00>oooo]Z1?l007oooookJ^oooo]Z1?l007oooook
JPCooo]Z003`oookJP?o001ooooonf[`oookJP?o001ooooonfX4oookJP00oooonf[ooookJ_oooo]Z
jooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooook
J_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooo
nf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oook
JP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooo
nf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oo
oo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003o
oookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_o
oo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[o
oookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Z
oooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX0
0?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]Z
jooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooook
J_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooo
nf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oook
JP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooo
nf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oo
oo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003o
oookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_o
oo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[o
oookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Z
oooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX0
0>Kooo]Z0ol007l5oookJPGo001ooooonf[VoookJP?o001o1OoonfX5o`00Oooooo]Z1?oonfX00>Ko
oo]Z0ol007l4oookJPOo001ooooonf[UoookJP?o001o1?oonfX7o`00Oooooo]Z0ooonfX00>Kooo]Z
0ol007l3oookJPCo001o00Cooo]Zo`00Ool007oo001ooooonf[UoookJP?o001o0ooonfX4o`00O`04
oookJ_l007oo001oo`00Oooooo]Z0ooonfX00=Kooo]Z2_l007l6oookJP?o001o0ooonfX3o`00O`?o
oo]Z0ol007l6oookJPCo0000oooonf[:oookJP[o001o1_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o
001o1_oonfX4o`000?Oooo]Z003FoookJP[o001o1_oonfX3o`00O`Wooo]Z0ol007l6oookJPKo0000
oooonf[8oookJP[o001o1_oonfX3o`00O`Wooo]Z0ol007l6oookJPKo0000mOoonfX00>Kooo]Z0ol0
07l9oookJP?o001o1_oonfX4o`000?oooo]Zf_oonfX3o`00O`Wooo]Z0ol007l6oookJPCo0000mooo
nfX00>Kooo]Z0ol007l4oookJP;o001o0_oonfX4o`00O`Kooo]Z1?l0003ooookJ][ooo]Z0ol007l4
oookJP;o001o0_oonfX4o`00O`Kooo]Z1?l0003goookJP00i_oonfX3o`00O`Cooo]Z1ol007l7oook
JPCo0000oooonf[JoookJP?o001o1?oonfX7o`00O`Oooo]Z1?l0003goookJP00i_oonfX3o`00O`Co
oo]Z1_l007l8oookJPCo0000oooonf[JoookJP?o001o1?oonfX6o`00O`Sooo]Z1?l0003goookJP00
hooonfX6o`00O`Cooo]Z0_l007l<oookJPCo0000oooonf[GoookJPKo001o1?oonfX2o`00O`cooo]Z
1?l0003goookJP00hooonfX6o`00O`Cooo]Z0_l007l<oookJPCo0000oooonf[GoookJPKo001o1?oo
nfX2o`00O`cooo]Z1?l0003goookJP00iOoonfX4o`00O`Gooo]Z1ol007l6oookJPCo0000oooonf[I
oookJPCo001o1OoonfX7o`00O`Kooo]Z1?l0003goookJP00i_oonfX3o`00O`Gooo]Z1ol007l6oook
JPCo0000oooonf[JoookJP?o001o1OoonfX7o`00O`Kooo]Z1?l0003goookJP00nooonfX4o`000?oo
oo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0
003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koook
JPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1Ol0003ooookJ^kooo]Z1Ol0003foookJP00
nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooo
nfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`00
0?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z
1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_
oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oo
oo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0
003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koook
JPGo0000oooonf[^oookJPGo0000m_oonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00
nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooo
nfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`00
0?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z
1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_
oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oo
oo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0
003ooookJ^oooo]Z1?l0003goookJP00nooonfX5o`000?oooo]Zk_oonfX5o`000?Kooo]Z003koook
JPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00
nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooo
nfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`00
0?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z
1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_
oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oo
oo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1Ol0
003ooookJ^kooo]Z1Ol0003foookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koook
JPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00
nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooo
nfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`00
0?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z
1?l0003goookJP00i_oonfX3o`00O`Gooo]Z1Ol007l8oookJPCo0000oooonf[JoookJP?o001o1Ooo
nfX5o`00O`Sooo]Z1?l0003goookJP00i_oonfX3o`00O`Cooo]Z1ol007l7oookJPCo0000oooonf[J
oookJP?o001o1?oonfX7o`00O`Oooo]Z1?l0003goookJP00i_oonfX3o`00O`Cooo]Z0ol007l01?oo
nf[o001oo`00Ool007l7oookJPCo0000oooonf[JoookJP?o001o1?oonfX3o`00O`04oookJ_l007oo
001oo`00O`Oooo]Z1?l0003goookJP00e_oonfX:o`00O`Kooo]Z0ol007l3oookJP?o001o0ooonfX3
o`00O`Kooo]Z1?l0003ooookJ/[ooo]Z2_l007l6oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6
oookJPCo0000mooonfX00=Kooo]Z2_l007l6oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oook
JPKo0000oooonf[8oookJP[o001o1_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX6o`00
0?Gooo]Z003VoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000oooonf[JoookJP?o
001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000mooonfX00>Kooo]Z0ol007l3oookJP?o001o
0ooonfX3o`00O`Kooo]Z1?l0003ooookJ][ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z
1?l0003goookJP00_OoonfX2ool000oooo]Z0_oo000FoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol0
07l6oookJPCo0000oooonfZaoookJP;o:@3o3ooonfX2oeT0oaKooo]Z0ol007l3oookJP?o001o0ooo
nfX3o`00O`Kooo]Z1?l0003goookJP00_ooonfX3ool000kooo]Z0_oo000DoookJP?o001o0ooonfX3
o`00O`?ooo]Z0ol007l6oookJPCo0000oooonfZcoookJP?o:@3o3_oonfX2oeT0oaCooo]Z0ol007l3
oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0003goookJP00`_oonfX3ool000Oooo]Z0_oo0004oook
JP;oo`003ooonfX6o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX4o`000?oooo]Z]_oonfX3obT0
o`gooo]Z0_mI0?l?oookJPKo001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000mooonfX00<Go
oo]Z0_oo0005oookJP?oo`001OoonfX2ool000gooo]Z1_l007l4oookJP?o001o00Cooo]Zo`00Ool0
07oo001o1ooonfX4o`000?oooo]Z^OoonfX3obT0o`cooo]Z0_mI0?l=oookJPKo001o1?oonfX3o`00
O`04oookJ_l007oo001oo`00O`Oooo]Z1?l0003goookJP00aooonfX3ool00003oookJ_oo003oo`00
00Coo`001OoonfX2ool000Gooo]Z0_oo0006oookJPCo001o1?oonfX7o`00O`Oooo]Z1?l0003ooook
J[cooo]Z0olY0?l;oookJP;oF@3o3OoonfX4o`00O`Cooo]Z1ol007l7oookJPCo0000mooonfX00<[o
oo]Z2?oo0006oookJP;oo`000ooonfX3ool000Kooo]Z0ol007l5oookJPGo001o2?oonfX4o`000?oo
oo]Z_ooonfX2obT0o`_ooo]Z0_mI0?l<oookJP?o001o1OoonfX5o`00O`Sooo]Z1?l0003goookJP00
b_oonfX:ool000Kooo]Z1ooo000JoookJPCo0000oooonf[1oookJP?o:@3o2_oonfX3oeT0oakooo]Z
1?l0003goookJP00b_oonfX;ool000Oooo]Z1ooo000HoookJPCo0000oooonf[4oookJP?o:@3o2_oo
nfX2oeT0oacooo]Z1?l0003goookJP00b_oonfX=ool000Cooo]Z2Ooo000GoookJPCo0000oooonf[7
oookJP?o:@3o2OoonfX2oeT0oa[ooo]Z1?l0003goookJP00TOoonfX5ool003?ooo]Z3ooo0003oook
JP[oo`005_oonfX4o`0001kooo]Z0_oo003ooookJZ[ooo]Z0olY0?l8oookJP;oF@3o6?oonfX4o`00
01kooo]Z00?oo`3fo`03oooonfX0e_oonfX0097ooo]Z3?oo000eoookJPOoo`0000?o:@3oool00?oo
00002ooo000DoookJPCo00007_oonfX2ool005gooo]Z00?oo`00oookJ_oonfX0oooonfY=oookJP;o
:@3o2?oonfX2oeT0oaKooo]Z1?l0000NoookJP03ool0m_l00ooooo]Z05cooo]Z00?oo`2eoookJ_oo
nfX0MooonfX0097ooo]Z4?oo0005o`3oUcCooo]Z0_lY0?l2oookJP[oo`004ooonfX5o`0001kooo]Z
0_oo001LoookJP03ool00?oonf[ooo]Z0?oooo]Z3ooonfX;o`3oUcGooo]Z0_lY0?l8oookJP;oF@3o
5?oonfX5o`0001kooo]Z00?oo`3fo`03oooonfX0FooonfX00ooo0;Gooo]ZoookJP1goookJP00TOoo
nfX>ool000Oooo]Z2Ol0oiL]oookJP03obT0oooonf[ooo]Z00Cooo]Z1_oo000BoookJPCo00008?oo
nfX2ool003;ooo]Z00?oo`00oookJ_oonfX09ooonfX00ooo003ooo]ZoookJP3ooookJPGooo]Z2Ol0
oiL;oookJPWo0?nG;_oonfX00olY0?oooo]ZoookJP07oookJP;oF@3o4_oonfX4o`00023ooo]Z00?o
o`3fo`03oooonfX0<_oonfX00ol09Ooooo]ZoookJP0VoookJP03ool0]Ooonf[ooo]Z07Kooo]Z0029
oookJQ?oo`004ooonfX9o`3oUbGooo]Z0_lY0?l9oookJP;oo`0000?oF@3ooookJ_oonfX03_oonfX4
o`00027ooo]Z0_oo000aoookJP03ool00?oonf[ooo]Z02Oooo]Z00?oo`00oookJ_oonfX0nooonfX9
o`3oUagooo]Z2Ol0oiLVoookJP;o:@3o2OoonfX2oeT0oa3ooo]Z1?l0000QoookJP03ool0m_l00ooo
oo]Z037ooo]Z00?o02GooookJ_oonfX09_oonfX00ooo0;Gooo]ZoookJP1foookJP00Q?oonfX5ool0
00Sooo]Z2?oo000OoookJP?o0?nG0ooo:009oookJP;oobP05_oonfX2obT0o`[ooo]Z00?oF@3ooook
J_oonfX03OoonfX4o`0002;ooo]Z0_oo000aoookJP03ool00?oonf[ooo]Z02Kooo]Z00?oo`00oook
J_oonfX0m_oonfX5o`3oUboooo]Z1_l0oiLRoookJP;o:@3o2OoonfX00omI0?oooo]ZoookJP0=oook
JPCo00008_oonfX00ooo0?Ko00?ooookJP0aoookJP03o`0Uoooonf[ooo]Z02Gooo]Z00?oo`2eoook
J_oonfX0M_oonfX0097ooo]Z1Ooo000XoookJP?oobP01_oonfX3oolX01Oooo]Z0_lY0?l9oookJP;o
F@3o3OoonfX4o`0000;ooo]Z0_oo000OoookJP03ool00?oonf[ooo]Z02oooo]Z00?oo`00oookJ_oo
nfX09ooonfX00ooo003ooo]ZoookJP3ooookJS3ooo]Z0ol0oiLQoookJP;o:@3o2?oonfX2oeT0o`go
oo]Z1?l00002oookJP;oK03o7ooonfX00ooo0?Ko00?ooookJP0`oookJP03oe@0oooonf[ooo]Z02Ko
oo]Z00?oo`2eoookJ_oonfX0MOoonfX0097ooo]Z0_oo000^oookJP?oobP00ooonfX5oolX01Oooo]Z
0_lY0?l9oookJP03oeT0oooonf[ooo]Z00[ooo]Z1?l00004oookJP03ool00?oonf[ooo]Z01gooo]Z
00?oo`00oookJ_oonfX0;_oonfX2ool002Sooo]Z00?oo`00oookJ_oonfX0oooonfXcoookJP?o0?nG
8?oonfX2obT0o`Sooo]Z00?oF@3ooookJ_oonfX02_oonfX4o`0000Cooo]Z00?oK03ooookJ_oonfX0
7OoonfX00ooo0?Ko00?ooookJP0_oookJP03oe@0ool09Ooooo]Z02Kooo]Z00?oo`2eoookJ_oonfX0
MOoonfX00<Cooo]Z2_oo:00GoookJP03obT0oooonf[ooo]Z00Oooo]Z00?oF@3ooookJ_oonfX02Ooo
nfX4o`0000Gooo]Z00?oo`00oookJ_oonfX07?oonfX2ool0033ooo]Z00?oo`00oookJ_oonfX09ooo
nfX00ooo003ooo]ZoookJP3ooookJSGooo]Z0ol0oiLOoookJP03obT0oooonf[ooo]Z00Kooo]Z0_mI
0?l:oookJPCo00001OoonfX00om/0?oooo]ZoookJP0LoookJP03ool0m_l00ooooo]Z033ooo]Z00?o
E03ooookJ_oonfX09_oonfX00ooo0;Gooo]ZoookJP1doookJP00a_oonfX9oolX01Oooo]Z0_lY0?l8
oookJP;oF@3o2OoonfX4o`0000Kooo]Z00?oo`00oookJ_oonfX07?oonfX2ool002oooo]Z0_oo000X
oookJP03ool00?oonf[ooo]Z0?oooo]Z>?oonfX4o`3oUacooo]Z0_lY0?l8oookJP03oeT0oooonf[o
oo]Z00Oooo]Z1?l00006oookJP03of`0oooonf[ooo]Z01cooo]Z00?oo`3fo`03oooonfX0;ooonfX0
0omD0?oo02GooookJP0VoookJP03ool0]Ooonf[ooo]Z07Cooo]Z0036oookJP_oobP05ooonfX2obT0
o`Sooo]Z00?oF@3ooookJ_oonfX01_oonfX4o`0000Oooo]Z00?oo`00oookJ_oonfX07?oonfX2ool0
02oooo]Z00?oo`00oookJ_oonfX09ooonfX00ooo003ooo]ZoookJP3ooookJS_ooo]Z0ol0oiLKoook
JP;o:@3o1ooonfX2oeT0o`Oooo]Z1?l00007oookJP03of`0oooonf[ooo]Z01cooo]Z00?oo`3fo`03
oooonfX0;ooonfX00omD0?oooo]ZoookJP0VoookJP03ool0]Ooonf[ooo]Z07?ooo]Z0035oookJPko
obP05ooonfX2obT0o`Oooo]Z0_mI0?l6oookJPCo00002?oonfX00ooo003ooo]ZoookJP0LoookJP;o
o`00;_oonfX2ool002Sooo]Z00?oo`00oookJ_oonfX0oooonfXnoookJP?o0?nG6_oonfX2obT0o`Oo
oo]Z00?oF@3ooookJ_oonfX01?oonfX4o`0000Sooo]Z00?oK03ooookJ_oonfX07?oonfX00ooo0?Ko
00?ooookJP0^oookJP03oe@0ool09Ooooo]Z02Kooo]Z00?oo`2eoookJ_oonfX0LooonfX00<Gooo]Z
3ooo:00DoookJP;oo`000_oonfX2obT0o`Oooo]Z00?oF@3ooookJ_oonfX00ooonfX4o`0000Wooo]Z
00?oo`00oookJ_oonfX07?oonfX00ooo003ooo]ZoookJP0]oookJP03ool00?oonf[ooo]Z02Kooo]Z
00?oo`00oookJ_oonfX0oooonfY1oookJP?o0?nG5OoonfX2o`3ol0;ooo]Z0_lY0?l6oookJP;oF@3o
1?oonfX4o`0000Wooo]Z00?oK03ooookJ_oonfX07?oonfX00ooo0?Ko00?ooookJP0^oookJP03oe@0
oooonf[ooo]Z02Gooo]Z00?oo`2eoookJ_oonfX0LooonfX00<kooo]Z1ooo:0000ol0oiOooo]Zoook
JP0BoookJP05ool00?oonf[ooo]ZoookJ_lY0?l01ooonfX2oeT0o`?ooo]Z1?l0000:oookJP03ool0
0?oonf[ooo]Z00;ooo]Z00?oo`00oookJ_oonfX05ooonfX00ooo003ooo]ZoookJP03ool002Wooo]Z
0_oo000XoookJP03ool00?oonf[ooo]Z0?oooo]Z@ooonfX3o`3oUaCooo]Z00Go0?o`oookJ_oonf[o
oo]ZobT0o`07oookJP04oeT0oooonf[ooo]ZoookJPCo00002_oonfX00om/0?oooo]ZoookJP0Loook
JP03ool0m_l00ooooo]Z02gooo]Z00?oE03oo`0UoooonfX09_oonfX00ooo0;Gooo]ZoookJP1boook
JP00a?oonfX2ool0013ooo]Z0_l0oiLCoookJP;oo`000_oonfX2obT0o`Oooo]Z00?oF@3ooookJ_oo
nfX01?l0000;oookJP05ool00?oonf[ooo]ZoookJ_oo00006OoonfX6ool002[ooo]Z0_oo000Woook
JP03ool00?oonf[ooo]Z0?oooo]ZA_oonfX2o`3oUa?ooo]Z0_l0oo02oookJP;o:@3o1_oonfX2oeT0
o`03oookJ_l0003o000000;o00002ooonfX00om/0?oooo]ZoookJP0KoookJP03ool0m_oonf[o00?o
02kooo]Z00?oE03oo`0UoooonfX09OoonfX00ooo0;Gooo]ZoookJP1boookJP00^_oonfX3ool000Oo
oo]Z1?oo000@oookJP;o0?nG4ooonfX01?oo003ooo]ZoookJ_oonfX2oolX0003oookJ_oo003ooo]Z
00?ooo]Z0_mI0?l4o`0000cooo]Z00?oo`00oookJ_oo00000_oo000HoookJPOoo`001_oonfX00ooo
003ooo]ZoookJP0PoookJP;oo`00:?oonfX00ooo003ooo]ZoookJP3ooookJRSooo]Z0ol0holLoook
JP;o0?nG4ooonfX01?l0oo3ooo]ZoookJ_oonfX2obT0o`Kooo]Z00?oF@3oo`000?l000000_l0000<
oookJP03of`0oooonf[ooo]Z01_ooo]Z00?oo`3fo`03oooonfX02OoonfX00ol0ogOooo]ZoookJP0Q
oookJP03oe@0ool09Ooooo]Z02Kooo]Z00?oo`2eoookJ_oonfX0LOoonfX00;gooo]Z1?oo0003oook
JPKoo`004?oonfX2o`3oUa;ooo]Z0_oo0003oookJP03oolX0?oo003ooo]Z00Gooo]Z00CoF@3oo`00
0?l0003o00003OoonfX5ool001Kooo]Z2?oo0006oookJP03ool00?oonf[ooo]Z027ooo]Z0_oo000W
oookJP03ool00?oonf[ooo]Z0?oooo]Z:ooonfX4o`3Soa[ooo]Z0_l0oiLBoookJP;o0?o`0ooonfX0
0olY0?oooo]ZoookJP04oookJP;oF@3o0_l0000=oookJP;oK03o7?oonfX00ooo0?Ko00?ooookJP08
oookJP03o`3oMooonf[ooo]Z02;ooo]Z00?oE03oo`0UoooonfX09OoonfX00ooo0;Gooo]ZoookJP1a
oookJP00`OoonfX;ool0013ooo]Z00?o0?nGool00?oo00004OoonfX00ooo003ooo]ZoookJP03ool0
00Gooo]Z00Co0000oeT0ool0003o00000_oo000:oookJPKoo`005OoonfX:ool000Kooo]Z00?oo`00
oookJ_oonfX08OoonfX00ooo003ooo]ZoookJP0UoookJP03ool00?oonf[ooo]Z0?oooo]Z;ooonfX4
o`3SoaSooo]Z0_l0onPBoookJP05o`3ol?oonf[ooo]ZoookJ_lY0?l01OoonfX2o`000003oeT0ool0
003o000000;oo`2Z3?oonfX00om/0?oooo]ZoookJP0JoookJP03ool0m_l00ooooo]Z00Sooo]Z00?o
0?mgoookJ_oonfX08OoonfX00omD0?oo02GooookJP0UoookJP03ool0]Ooonf[ooo]Z077ooo]Z0033
oookJP_oo`004?oonfX00ol0oiOoo`00ool0000@oookJPKoo`001?oonfX2o`0000;oF@3o0_oonfX0
0ooo003ooo]ZoookJP06oookJPSoo`005_oonfX8ool000Oooo]Z00?oo`00oookJ_oonfX08?oonfX2
ool002Oooo]Z00?oo`00oookJ_oonfX0oooonfXboookJPCo0>?o5_oonfX2o`3oj003o`3oUooonf[o
oo]Z00kooo]Z0_l0oo02oookJP;o:@3o0ooonfX3o`0000;oF@3o0_oonfX00ooo0:[ooo]ZoookJP0:
oookJP03of`0oooonf[ooo]Z01[ooo]Z00?oo`3fo`03oooonfX02?oonfX00ol0ogOooo]ZoookJP0Q
oookJP03oe@0ool09Ooooo]Z02Gooo]Z00?oo`2eoookJ_oonfX0L?oonfX00<?ooo]Z3Ooo000Aoook
JP;oo`001?oonfX2ool000?ooo]Z0_oo0004oookJPKoo`000ooonfX2o`000003oolX0?l0003oF@3o
00;ooo]Z00?oo`00oookJ_oonfX01?oonfX:ool001Kooo]Z2?oo0006oookJP03ool00?oonf[ooo]Z
027ooo]Z00?oo`00oookJ_oonfX09OoonfX00ooo003ooo]ZoookJP3ooookJSKooo]Z1?l0holDoook
JP;o0?oX00?o0?nGoookJ_oonfX01_oonfX2ool02`Kooo]Z00Go0?o`oookJ_oonf[ooo]ZobT0o`02
oookJPCo000000Gooo]ZoeT0oooonf[ooo]Zool0ZP0<oookJP03of`0oooonf[ooo]Z01[ooo]Z00?o
o`3fo`03oooonfX01ooonfX00ol0ogOooo]ZoookJP0QoookJP03oe@0ool09Ooooo]Z02Gooo]Z00?o
o`2eoookJ_oonfX0L?oonfX00<;ooo]Z4?oo000AoookJP04ool00?l0oiOooo]ZoookJP?oo`001?oo
nfX00ooo003ooo]ZoookJP08ool00007oolX0?oonf[o0000o`000?oo:03o0000oookJP02oolX0003
oookJ_oo003ooo]Z00Kooo]Z2Ooo000GoookJPKoo`001ooonfX00ooo003ooo]ZoookJP0HoookJP03
ool00?oonf[ooo]Z00Gooo]Z0_oo000WoookJP03ool00?oonf[ooo]Z0?oooo]Z>OoonfX4o`3Soa;o
oo]Z00?o0?oXo`3oUol0oiL02?oonfX00ooo00_ooo]ZoookJP04oookJP06o`3ol?oonf[ooo]Zoook
J_lY0?oooo]Z1?l00002oookJP;oF@3o00?ooo]Zool0Z_oonfX02ooonfX00om/0?oooo]ZoookJP0J
oookJP03ool0m_l00ooooo]Z00Oooo]Z00?o0?mgoookJ_oonfX06?oonfX00ooo0?;ooo]ZoookJP06
oookJP03oe@0ool09Ooooo]Z02Gooo]Z00?oo`2eoookJ_oonfX0KooonfX00:cooo]Z0ooo000Coook
JQ7oo`0000?o0>?ooookJ_oonfX03_oonfX7ool000Cooo]Z2ooo00000ooo:03o0000oolX0002oolX
00?ooo]Z00?oobP0oookJ_oo00002?oonfX7ool001Sooo]Z1_oo0007oookJP03ool00?oonf[ooo]Z
01Oooo]Z00?oo`00oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP0UoookJP03ool00?oonf[ooo]Z
0?oooo]Z?OoonfX3o`3Soa3ooo]Z0_l0onP2o`3oU`Oooo]Z0_oo00/5oookJP;o0?o`0_oonfX2obT0
o`?o00001?oonfX00omI0?oooo]Zool0ZP0<oookJP03of`0oooonf[ooo]Z01Wooo]Z00?oo`3fo`03
oooonfX02?oonfX00ol0ogOooo]ZoookJP0GoookJP03ool0l_oonf[ooo]Z00Kooo]Z00?oE03oo`0U
oooonfX09OoonfX00ooo0;Gooo]ZoookJP1_oookJP00[?oonfX7ool0027ooo]Z0ol0hol?oookJPKo
o`001?oonfX;ool000GoobP00ooonfX00ooo:03ooo]Zool00009oookJPKoo`006OoonfX4ool000Oo
oo]Z00?oo`00oookJ_oonfX06?oonfX00ooo003ooo]ZoookJP05oookJP;oo`009ooonfX00ooo003o
oo]ZoookJP3ooookJSoooo]Z0ol0hol?oookJP;o0?oX0_l0oiL7oookJP03ool02ooonf[ooo]Z00Co
oo]Z00Go0?o`oookJ_oonf[o0000obT0o`02o`0000Gooo]Z00?oF@3ooookJ_oo0:X03?oonfX00om/
0?oooo]ZoookJP0IoookJP03ool0m_l00ooooo]Z00Oooo]Z00?o0?mgoookJ_oonfX06?oonfX00ooo
0?;ooo]ZoookJP06oookJP03oe@0ool09Ooooo]Z02Gooo]Z00?oo`2eoookJ_oonfX0K_oonfX00:co
oo]Z2_oo000QoookJP;o0>?o3?oonfX8ool000Gooo]Z2_oo0005oolX00?ooo]Z00CoobP0oookJ_oo
003oo`000ooonfX00ooo003ooo]ZoookJP03oookJPGoo`006OoonfX4ool000Oooo]Z00?oo`00oook
J_oonfX05ooonfX00ooo003ooo]ZoookJP06oookJP03ool00?oonf[ooo]Z02Gooo]Z00?oo`00oook
J_oonfX0oooonfY2oookJP;o0>?o3ooonfX2o`3oj0;o0?nG1_oonfX2ool02`Gooo]Z0_l0oo02o`00
0003obT0ool0003ooo]Z00Gooo]Z00?oF@3ooookJ_oo0:X03?oonfX00om/0?oooo]ZoookJP0Ioook
JP03ool0m_l00ooooo]Z00Oooo]Z00?o0?mgoookJ_oonfX05ooonfX00ooo0?;ooo]ZoookJP06oook
JP03oe@0ool09Ooooo]Z02Gooo]Z00?oo`2eoookJ_oonfX0K_oonfX00:cooo]Z3_oo000OoookJP;o
0>?o2_oonfX:ool000Gooo]Z2Ooo0005oolX00?ooo]Z00GoobP0oookJ_oonf[oo`00oookJP02ool0
00Oooo]Z0ooo000JoookJP?oo`001ooonfX00ooo003ooo]ZoookJP0HoookJP03ool00?oonf[ooo]Z
00Gooo]Z0_oo0003oookJP;oo`008OoonfX00ooo003ooo]ZoookJP3ooookJTCooo]Z0ol0hol>oook
JP;o0?oX0_l0oiL6oookJP03ool02ooonf[ooo]Z00Cooo]Z00Co0?o`o`000?l0003o:@3o1ooonfX0
0omI0?oooo]Zool0ZP0<oookJP03of`0oooonf[ooo]Z01Wooo]Z00?oo`3fo`03oooonfX01ooonfX0
0ol0ogOooo]ZoookJP0GoookJP03ool0l_oonf[ooo]Z00Kooo]Z00?oE03oo`0UoooonfX09?oonfX0
0ooo0;Gooo]ZoookJP1^oookJP00YOoonfXGool000?o0?o]7?oonfX3o`3So`Kooo]Z3?oo0004oook
JPCoo`0000?oobP0ool00?oo00000ooo0005oolX00?ooo]Z00?oobP0oookJ_oonfX01?oo0008oook
JP;oo`006ooonfX2ool000Oooo]Z00?oo`00oookJ_oonfX05ooonfX00ooo003ooo]ZoookJP06oook
JPKoo`008_oonfX00ooo003ooo]ZoookJP3ooookJPoooo]Z6ol0ondLoookJP;o0>?o3_oonfX2o`3o
j003o`3oUooonf[ooo]Z00Cooo]Z0_oo00/4oookJP04o`000?l0oo3o0?o`o`0000;o:@3o1_oonfX0
0omI0?oooo]Zool0ZP0<oookJP03of`0oooonf[ooo]Z01Wooo]Z00?oo`3fo`03oooonfX01_oonfX0
0ol0ogOooo]ZoookJP0GoookJP03ool0l_oonf[ooo]Z00Kooo]Z00?oE03oo`0UoooonfX09OoonfX0
0ooo0;Gooo]ZoookJP1]oookJP00[?oonfX=ool000Kooo]Z1Ol0ondJoookJP;o0>?o1ooonfX:ool0
00;ooo]Z1ooo0002oolX00?oo`001?oo:004oookJP03oolX0?oo003oo`0000Coo`002OoonfX00ooo
003ooo]ZoookJP0IoookJP03ool00?oonf[ooo]Z00Kooo]Z00?oo`00oookJ_oonfX05ooonfX00ooo
003ooo]ZoookJP04oookJPOoo`008_oonfX00ooo003ooo]ZoookJP3ooookJR[ooo]Z1Ol0ondIoook
JP;o0>?o3_oonfX00ol0onSo0?nGo`3oU`06oookJP04ool02ooonf[ooo]ZoookJP?o000000Co0?o`
oookJ_oonf[o:@3o1_oonfX01?mI0?oooo]Zool0Z_oo0:X;oookJP03of`0oooonf[ooo]Z01Wooo]Z
00?oo`3fo`03oooonfX01_oonfX00ol0ogOooo]ZoookJP0GoookJP03ool0l_oonf[ooo]Z00Kooo]Z
00?oE03oo`0UoooonfX09?oonfX00ooo0;Gooo]ZoookJP1]oookJP00[?oonfX8ool0013ooo]Z1_l0
ondFoookJP;o0>?o2OoonfXAool00005o`000?oo:03oobP0ool00?l0oo000ooo:003oookJPSoo`00
2?oonfX00om/0?oooo]ZoookJP0IoookJP03ool0m_oo003ooo]Z00Kooo]Z00?oo`00oookJ_oonfX0
5ooonfX00ooo003ooo]ZoookJP03oookJPWoo`008_oonfX00ooo003ooo]ZoookJP3ooookJRkooo]Z
1_l0ondEoookJP?o0>?o3?oonfX2o`3oj003o`3oUooonf[ooo]Z00Cooo]Z0_oo00/00ooonf[o0000
o`000002o`0000;o0?o`00?ooo]ZobT0oooonfX01OoonfX01?mI0?oooo]ZoookJ_oo0:X:oookJP03
of`0oooonf[ooo]Z01Wooo]Z00?oo`3foookJ_l00ol01ooonfX00ol0ogOooo]ZoookJP0FoookJP03
ool0l_oonf[ooo]Z00Kooo]Z00?oE03oo`0UoooonfX09OoonfX00ooo0;Gooo]ZoookJP1/oookJP00
[?oonfX3ool001_ooo]Z1Ol0ond:oookJP;oobP01ooonfX3o`3So`Wooo]Z1Ooo00000ooonf[oo`00
ool00007ool000;o00000_oo:0001Ol0oo3oobP0oolX0?oo:03ooo]Z00Woo`002OoonfX00om/0?oo
oo]ZoookJP0IoookJP03o`03oooonf[ooo]Z00Kooo]Z00?oo`00oookJ_oonfX05ooonfX00ooo003o
oo]ZoookJP02oookJPWoo`008_oonfX00ooo003ooo]ZoookJP3ooookJSCooo]Z1Ol0ondCoookJP;o
0>?o3?oonfX2o`3oj003o`3oUooonf[ooo]Z00Cooo]Z00?oo`0;o`000?l000000_l00002oookJP04
o`3ol?oonf[o:@3oobT0o`Gooo]Z00CoF@3ooookJ_oonf[oo`2Z2_oonfX00om/0?oooo]ZoookJP0I
oookJP03ool0m_l00ooooo]Z00Kooo]Z00?o0?mgoookJ_oonfX05ooonfX00ooo0?;ooo]ZoookJP06
oookJP03oe@0ool09Ooooo]Z02Cooo]Z00?oo`2eoookJ_oonfX0K?oonfX00<oooo]Z0_l0ond2oolX
00Kooo]Z0ooo:009oookJP;o0>?o2ooonfX2ool00003o`3oj?oonf[ooo]Z00Ooo`0000Go0000oook
J_oonf[ooo]Zo`3ol003oolX00;ooo]Z2?oo0009oookJP03of`0oooonf[ooo]Z01Wooo]Z00?o00?o
oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP02ool001Cooo]Z00?oo`00oookJ_oonfX00ooonfX8
ool002?ooo]Z00?oo`00oookJ_oonfX00_oo003ooookJSKooo]Z1?l0ondAoookJP?o0>?o2ooonfX2
o`3oj0Kooo]Z0_oo00/2o`0000?ooo]Z00Co0?o`oookJ_oonf[o:@3o1OoonfX01?mI0?oooo]Zoook
J_oo0:X:oookJP03of`0oooonf[ooo]Z01Wooo]Z00?oo`3fo`03oooonfX01_oonfX00ol0ogOooo]Z
oookJP0FoookJP03ool0l_oonf[ooo]Z00Kooo]Z00?oE03oo`0UoooonfX09OoonfX00ooo0;Gooo]Z
oookJP1[oookJP00dooonfX3oolX00;ooo]Z1Ooo:00:oookJP;oobP02ooonfX00ol0oiOo0?oXoook
JP02oookJPKoo`001?oonfX00ol0oo3oobP0oolX0004oolX00Ooo`002OoonfX00om/0?oooo]Zoook
JP0HoookJP03ool0m_l00ooooo]Z00Kooo]Z00?oo`00oookJ_oo00000_oo000EoookJP03ool00?oo
nf[ooo]Z00;ooo]Z2?oo000SoookJPGoo`00oooonfXjoookJP?o0?o]4OoonfX2o`3So`_ooo]Z00?o
0?oXo`3oUooonfX00ooonfX2o`000003ool02ol0003ooo]Z00?ooo]Z00Co0?o`oookJ_oonf[o:@3o
1OoonfX01?mI0?oooo]ZoookJ_oo0:X:oookJP03of`0oooonf[ooo]Z01Sooo]Z00?oo`3foookJ_l0
0ol01ooonfX00ol0ogOooo]ZoookJP0FoookJP03ool0l_oonf[ooo]Z00Kooo]Z00?oE03oo`0Uoooo
nfX09?oonfX00ooo0;Gooo]ZoookJP1[oookJP00e_oonfX9oolX00[ooo]Z00?oobP0oookJ_oonfX0
0ooonfX00ooo:03ooo]ZoookJP04oookJP03o`3oj?l0oiOooo]Z00;ooo]Z00?o0000ool00?oo0000
0_oo0004oookJP03o`3ol?oonf[oobP000GoobP01_oo0009oookJP03of`0oooonf[ooo]Z01Sooo]Z
00?o00?ooookJ_oonfX01OoonfX6ool001Cooo]Z00?oo`00oookJ_oonfX00_oonfX8ool0027ooo]Z
1ooo003ooookJSgooo]Z0_l0ondAoookJP03o`3Soooonf[ooo]Z00Wooo]Z00?o0?oXo`3oUol0oiL0
0_oonfX3o`0000;oo`0;1?oonfX00ol0oo3ooo]ZoookJP02obT0o`Cooo]Z00CoF@3ooookJ_oonf[o
o`2Z2_oonfX00om/0?oooo]ZoookJP0HoookJP03ool0m_l00ooooo]Z00Oooo]Z00?o0?mgoookJ_oo
nfX05OoonfX00ooo0?;ooo]ZoookJP06oookJP03oe@0oooonf[o02Go02Cooo]Z00?oo`2eoookJ_oo
nfX0JooonfX00=Oooo]Z2Ooo:00:oookJP;oobP00ooonfX2oolX00Kooo]Z0_l0onP2oookJP?o0000
0ooo0004oookJP04o`3ol?oonf[ooo]ZobT0o`GoobP01?oo000:oookJP03of`0oooonf[ooo]Z01Oo
oo]Z00?oo`3fo`03oooonfX01?oonfX7ool001Gooo]Z00?oo`00oookJ_oonfX00_oonfX8ool001oo
oo]Z2?oo003ooookJSoooo]Z0ol0ond?oookJP;o0>?o2_oonfX2o`3oj003o`3oUooonf[o000000?o
000000?ooo]Zool02ooonfX00ooonfX2o`3ol0;ooo]Z00?o:@3ooookJ_oonfX00_oonfX01?mI0?oo
oo]ZoookJ_oo0:X:oookJP03of`0oooonf[ooo]Z01Sooo]Z00?oo`3fo`03oooonfX01_oonfX00ol0
ogOooo]ZoookJP0FoookJP03ool0l_oonf[ooo]Z00Cooo]Z00Coo`2PoookJ_mD0?oo02Go9OoonfX0
0ooo0;Gooo]ZoookJP1ZoookJP00eooonfX:oolX00_ooo]Z1_oo:007oookJP03o`3oj?l0oiOo0000
00?o00000_oonfX00ooo003oo`0;oookJP02oookJP04o`3ol?oonf[ooo]ZobT0o`KoobP00ooo000:
oookJP03of`0oooonf[ooo]Z01Oooo]Z00?o00?ooookJ_oonfX00_oonfX8ool00003oookJ_oo003o
oo]Z01;ooo]Z00?oo`00oookJ_oonfX00ooonfX7ool001oooo]Z2?oo003ooookJT;ooo]Z0_l0ond?
oookJP;o0>?o2_oonfX00ol0onSo0?nGo`3oU`03o`0000;ooo]Z0_oo00/4oookJP04o`3ol?oonf[o
oo]ZobT0o`Cooo]Z00CoF@3ooookJ_oonf[oo`2Z2_oonfX00om/0?oooo]ZoookJP0GoookJP03ool0
m_l00ooooo]Z00Oooo]Z00Go0?mgoookJ_oonf[ooo]ZoiOo000CoookJP03ool0l_oonf[ooo]Z00Co
oo]Z00Goo`2PoookJ_mD0?oooo]Zo`0Uo`0ToookJP03ool0]Ooonf[ooo]Z06[ooo]Z002foookJP?o
obP07_oonfX<oolX00_ooo]Z1Ooo:007oookJP03o`3oj?l0oiOo000000;o00001?oonfX01Ooo00_o
oo]ZoookJ_oonf[o0?o`00;ooo]Z00?o:@3ooookJ_oo:0001Ooo:002ool000Wooo]Z00?oK03ooook
J_oonfX06?oonfX00ol00ooooo]ZoookJP03oookJPSoo`005?oonfX00ooo003ooo]ZoookJP03oook
JPKoo`008?oonfX8ool00?oooo]Z@ooonfX3o`3ok@kooo]Z00?o0>?ooookJ_oonfX02?oonfX00ol0
onSo0000o`3oU`02o`0000Cooo]Z00?oo`0;oookJ_oonfX00_oonfX01?l0oo3ooo]ZoookJ_lY0?l4
oookJP04oeT0oooonf[ooo]Zool0ZPWooo]Z00?oK03ooookJ_oonfX06?oonfX00ooo0?Ko00?ooook
JP07oookJP04o`3oMooonf[ooo]ZoiOo01Cooo]Z00?oo`3boookJ_oonfX01?oonfX01?oo0:3ooo]Z
oe@0ool09OlUoookJP03ool0]Ooonf[ooo]Z06Wooo]Z002foookJPOoobP06OoonfX>oolX00Wooo]Z
1ooo:007oookJP;o0?oX00?o0?nGo`000?oonfX01?oonfX2ool000;ooo]Z0_l0oo001?oonf[o:@3o
oookJ_oonfX5oolX0003oookJ_oo003ooo]Z00Sooo]Z00?oK03ooookJ_oonfX05ooonfX00ooo0?Ko
00?ooookJP04oookJPKoo`0000?ooo]Zool00?oonfX04_oonfX00ooo003ooo]ZoookJP04oookJPGo
o`008OoonfX7ool00?oooo]ZA_oonfX2o`3ok@gooo]Z0_l0hol9oookJP;o0?oX0_l0oiL5oookJP;o
onP00ooonfX01?l0oo3ooo]ZoookJ_lY0?l4oookJP04oeT0oooonf[ooo]Zool0ZPWooo]Z00?oK03o
oookJ_oonfX06?oonfX00ooo0?Ko00?ooookJP06oookJP05o`3oMooonf[ooo]ZoookJ_nGo`004ooo
nfX00ooo0?;ooo]ZoookJP04oookJP05ool0X?oonf[oE03ooookJ_l09Ol09?oonfX00ooo0;Gooo]Z
oookJP1YoookJP00]_oonfX:oolX01_ooo]Z2_oo:008oookJPSoobP01_oonfX2o`000003o`3oj?l0
oiOooo]Z00Gooo]Z00?oo`0;ool00?oonfX00_oonfX00ol0oo3ooo]ZobT0o`03oookJP?oobP000?o
oo]Zool0Z_oonfX02OoonfX00om/0?oooo]ZoookJP0GoookJP03o`03oooonf[ooo]Z00Cooo]Z1Ooo
00000ooonf[oo`00oookJP0CoookJP03ool00?oonf[ooo]Z00?ooo]Z1Ooo000RoookJPKoo`00oooo
nfY8oookJP?o0?o]3?oonfX00ol0hooooo]ZoookJP06oookJP;o000000?o0?oXo`000?l0oiL01Ooo
nfX00ooo00_oonP0oookJP02oookJP04o`3ol?oonf[ooo]ZobT0o`Cooo]Z00?oF@3ooookJ_oo0:X0
2_oonfX00om/0?oooo]ZoookJP0GoookJP03ool0m_l00ooooo]Z00Oooo]Z00Co0?mgoookJ_oonf[o
Uol05?oonfX00ooo0?;ooo]ZoookJP03oookJP05ool0X?oonf[ooo]Zoe@0ool09Ol09?oonfX00ooo
0;Gooo]ZoookJP1YoookJP00]_oonfX>oolX01kooo]Z1?oo:0000ol0ongooo]ZoookJP03oookJP[o
obP01OoonfX3o`0000;o0?oX00?o0?nGoookJ_oonfX00ooonfX00ooo00_oo`00oookJP02oookJP03
o`3ol?oonf[o:@3o00Cooo]Z0_oo:0000ooonf[oo`2ZoookJP09oookJP03of`0oooonf[ooo]Z01Ko
oo]Z00?oo`3fo`03oooonfX01OoonfX5ool00003oookJ_oo003ooo]Z01;ooo]Z00?oo`00oookJ_oo
nfX01?oonfX5ool0027ooo]Z1_oo003ooookJT_ooo]Z0_l0ond;oookJP;o0>?o1_oonfX3o`0000;o
0?oX0_l0oiL4oookJP03ool02oooj03ooo]Z00;ooo]Z00Co0?o`oookJ_oonf[o:@3o1?oonfX00omI
0?oooo]Zool0ZP0:oookJP03of`0oooonf[ooo]Z01Oooo]Z00?oo`3fo`03oooonfX01ooonfX01?l0
ogOooo]ZoookJ_nGo`0CoookJP03ool0l_oonf[ooo]Z00Cooo]Z00Goo`2PoookJ_mD0?oooo]Zo`0U
o`0ToookJP03ool0]Ooonf[ooo]Z06Sooo]Z002^oookJP?oojL05Ooo:002oonW01oooo]Z0_l0ond5
oookJPWoobP01?oonfX4o`000003oookJ_l0onSo0?nG00Gooo]Z00?oo`0;ool00?oonfX00_oonfX0
0ol0oo3oo`00obT0o`05oookJP03oolX0?oonf[oo`2Z00[ooo]Z00?oK03ooookJ_oonfX05_oonfX0
0ol00ooooo]ZoookJP05oookJPCoo`0000?ooo]Zool00?oonfX04_oonfX01?oo003ooo]ZoookJ_oo
nfX2ool00003oookJ_oo003oo`0000?oo`008_oonfX5ool00?oooo]Z4ooonfXJoonW023ooo]Z0_l0
ond;oookJP03o`3Soooonf[ooo]Z00?ooo]Z1?l000001?oonf[o0?oXoookJ_l0oiL4oookJP03ool0
2oooj03ooo]Z00;ooo]Z0_l0oo000ooonf[o:@3ooookJP03oookJP03oeT0oooonf[oo`2Z00[ooo]Z
00?oK03ooookJ_oonfX05ooonfX00ol00ooooo]ZoookJP06oookJP04o`3oMooonf[ooo]ZoiOo01?o
oo]Z00?oo`3boookJ_oonfX01?oonfX01Ooo0:3ooo]ZoookJ_mD0?oo02Go02Cooo]Z00?oo`2eoook
J_oonfX0J?oonfX00:Oooo]Z1oooY`08oookJPgoobP01OoonfX5oonW01cooo]Z0_l0ond6oookJPOo
obP00ooonfX4o`0000;ooo]Z00?o0?oXo`3oUooonfX01?oonfX02?oo00_oo`00oookJ_oonf[oo`00
o`3ol?oonf[o:@3o1?oonfX01?mI0?oooo]ZoookJ_oo0:X:oookJP03of`0oooonf[ooo]Z01Kooo]Z
00?o00?ooookJ_oonfX01OoonfX3ool000;ooo]Z00?oo`00oookJ_oonfX04OoonfX5ool00003oook
J_oo003ooo]Z00?oo`008ooonfX4ool00?oooo]Z3?oonfX7oonW01[ooo]Z1OooY`0MoookJP;o0?o]
2_oonfX2o`3So`?ooo]Z1?l00002oookJP03o`3oj?oonf[o0?nG00Cooo]Z00?oo`0;oooX0?oonfX0
0ooonfX00ol0oo3ooo]ZobT0o`03oookJP04oeT0oooonf[ooo]Zool0ZP[ooo]Z00?oK03ooookJ_oo
nfX05_oonfX00ooo0?Ko00?ooookJP07oookJP04o`3oMooonf[ooo]ZoiOo01?ooo]Z00?oo`3boook
J_oonfX00ooonfX01_oo0:3ooo]ZoookJ_mD0?oooo]Zo`0UobCooo]Z00?oo`2eoookJ_oonfX0Iooo
nfX00:3ooo]Z1oooY`0?oookJPWoobP03_oonfX5oonW01Wooo]Z00?o0?o]oookJ_oonfX01_oonfX5
oolX00;ooo]Z1?l00003oookJP;o0?oX00?ooo]Zool00?oonfX00_oonfX00ooo00_oo`00ool00002
ool00003o`3ol?oonf[o:@3o00Cooo]Z00CoF@3ooookJ_oonf[oo`2Z2_oonfX00om/0?oooo]Zoook
JP0EoookJP03ool0m_l00ooooo]Z00Kooo]Z0ooo00000ooonf[oo`00oookJP0@oookJPOoo`000_oo
nfX01?oo003ooo]Zool00?oo000ToookJP?oo`00oooonfX5oookJPOoojL09_oonfX5oonW01[ooo]Z
00?o0?o]oookJ_oonfX02OoonfX2o`3So`03oookJ_l0003o000000;o00000ooonfX2o`3oj003o`3o
Uooonf[o087o00;ooo]Z00?oo`0;oooX0?oonfX00ooonfX00ol0oo3ooo]ZobT0o`03oookJP04oeT0
oooonf[ooo]Zool0ZP[ooo]Z00?oK03ooookJ_oonfX05_oonfX00ooo0?Ko00?ooookJP07oookJP03
o`3oMooonf[oUol001?ooo]Z00?oo`3boookJ_oonfX01?oonfX01Ooo0:3ooo]ZoookJ_mD0?oo02Go
02Cooo]Z00?oo`2eoookJ_oonfX0IooonfX009_ooo]Z0ooo0002oonW01Kooo]Z1_oo:00@oookJP;o
ogT01?oonfX5oonW01Gooo]Z0_l0ond9oookJP?oobP000?ooo]Zo`000?l000000_l00005oookJP03
o`3oj?oonf[oo`0000?ooo]Z1Ooo00000ol0oo3ooo]ZobT0o`04oookJP04oeT0oooonf[ooo]Zool0
ZPWooo]Z00?oK03ooookJ_oonfX05_oonfX00ol00ooooo]ZoookJP06oookJP;oo`000_oonfX00ooo
003ooo]ZoookJP0=oookJPWoo`0000Cooo]Zool00?oonf[ooo]Z0_oo000SoookJPCoo`00oooonfX4
oonW03;ooo]Z1OooY`0FoookJP;o0?o]2ooonfX00ol0hooo0000o`000002o`0000Gooo]Z00?o0?oX
o`3oUol0POl00ooonfX00ooo00_oonP0oookJP03oookJP03o`3ol?oonf[o:@3o00?ooo]Z00CoF@3o
oookJ_oonf[oo`2Z2OoonfX00om/0?oooo]ZoookJP0FoookJP03ool0m_l00ooooo]Z00Oooo]Z00Co
0?mgoookJ_oonf[oUol04ooonfX00ooo0?;ooo]ZoookJP03oookJP06ool0X?oonf[ooo]Zoe@0oooo
nf[o02Go9?oonfX00ooo0;Gooo]ZoookJP1VoookJP00U_oonfX6ool001[ooo]Z0_oo:00DoookJPGo
ogT01_oonfX3oonW01Cooo]Z0_l0ond:oookJP03oolX0?l0hooo000000;o00001_oonfX01?l0onSo
oo]Zool00?oonfX7ool00003o`3ol?oonf[o:@3o00Cooo]Z00?oF@3ooookJ_oo0:X02_oonfX00om/
0?oooo]ZoookJP0FoookJP03o`03oooonf[ooo]Z00Kooo]Z00Coo`00oookJ_oonf[oo`003ooonfX9
ool000;ooo]Z00Coo`00oookJ_oonf[oo`002ooonfX00ooo003ooo]ZoookJP0FoookJP?oo`00oOoo
nfX2oonW03_ooo]Z0oooY`0EoookJP;o0?o]2_oonfX2o`3So`;o00001_oonfX00ol0onSo0?nGo`21
o`03oookJP03ool02oooj03ooo]Z00?ooo]Z00?o0?o`oookJ_lY0?l00ooonfX00omI0?oooo]Zool0
ZP0:oookJP03of`0oooonf[ooo]Z01Kooo]Z00?oo`3fo`03oooonfX01ooonfX01?l0ogOooo]Zoook
J_nGo`0BoookJP03ool0l_oonf[ooo]Z00Cooo]Z00Goo`2PoookJ_oonf[oE03oo`0Uo`0:oookJP03
og_o0?oonf[ooo]Z01Oooo]Z00?oo`2eoookJ_oonfX0I_oonfX0097ooo]Z2_oo000HoookJQGo0?l9
0oooN@000ooonf[oogT0oomi0005oomi00Oooo]Z0oooY`0CoookJP;o0?o]2OoonfX01?l0003o0>?o
o`000?l00007oookJP03oolX0?oonf[oo`0000Soo`0000?oobP0oookJ_lY0?l01?oonfX00omI0?oo
oo]Zool0ZP0:oookJP03of`0oooonf[ooo]Z01Gooo]Z00?oo`3fo`03oooonfX01ooonfX01?oo003o
oo]ZoookJ_oo000?oookJPSoo`000_oonfX01?oo003ooo]ZoookJ_mD0?l;oookJP03ool00?oonf[o
oo]Z01Oooo]Z0_oo003koookJP;oojL06OoonfXHo`3o2@oooo]Z0oooY`0DoookJP;o0?o]2?oonfX2
o`000003o`3Sool0003ooo]Z00Kooo]Z00?o0?oXo`3oUol0POl00ooonfX00ooo00_oonP0oookJP03
oookJP03o`3ol?oonf[o:@3o00?ooo]Z00?oF@3ooookJ_oo0:X02_oonfX00om/0?oooo]ZoookJP0F
oookJP03ool0m_l00ooooo]Z00Oooo]Z00?o0?mgoookJ_nGo`004ooonfX00ooo0?;ooo]ZoookJP03
oookJP05ool0X?oonf[ooo]Zoe@0ool09Ol02_oonfX00omko`3ooo]ZoookJP0GoookJP03ool0]Ooo
nf[ooo]Z06Kooo]Z002>oookJPcoo`004_oonfX5oolX00;o0?l96?oonfX2ool000SoogT02?oonfX2
oonW01?ooo]Z0_l0ond7oookJP;o000000?o0>?oo`000?oonfX01ooonfX00ooo:03o0?nGool00007
ool00004oolX0?oonf[ooo]ZobT0o`Cooo]Z00?oF@3ooookJ_oo0:X02_oonfX00om/0?oooo]Zoook
JP0EoookJP03o`03oooonf[ooo]Z00Kooo]Z00Co0?mgoookJ_oonf[oo`004?oonfX7ool000;ooo]Z
00Goo`00oookJ_oonf[ooo]Zoe@0o`0:oookJP03ool00?oonf[ooo]Z01Sooo]Z00?oo`00oookJ_oo
nfX0mooonfX2oonW01Kooo]Z1Ol0o`THoookJPGo0?l93OoonfX2oonW01Cooo]Z0_l0ond6oookJP?o
000000?o0>?ooookJ_oonfX01_oonfX00ol0onSo0?nGo`21o`03oookJP03ool02oooj03ooo]Z00;o
oo]Z00Co0?o`oookJ_oonf[o:@3o0ooonfX00omI0?oooo]Zool0ZP0:oookJP03of`0oooonf[ooo]Z
01Gooo]Z00?oo`3fo`03oooonfX01ooonfX01?l0ogOooo]ZoookJ_nGo`0BoookJP03ool0l_oonf[o
oo]Z00?ooo]Z00Koo`2PoookJ_oonf[ooo]Zoe@0ool09Ol9oookJP03og_o0?oonf[ooo]Z01Sooo]Z
00?oo`2eoookJ_oonfX0IOoonfX008kooo]Z2ooo000@oookJP?o0?l93Ooo:008oookJP?oo`001ooo
nfX4ool000WoogT01ooonfX3oonW01;ooo]Z00?o0?o]oookJ_oonfX01?oonfX3o`000003o`3Sool0
003ooo]Z00Oooo]Z00?oobP0o`3oUooo00000_oo00000ooo:03oo`00ool00002ool00004oolX0?oo
nf[ooo]ZobT0o`?ooo]Z00CoF@3ooookJ_oonf[oo`2Z2_oonfX00om/0?oooo]ZoookJP0DoookJP03
ool0m_l00ooooo]Z00Oooo]Z00Co0?mgoookJ_oonf[oo`004?oonfX6ool000?ooo]Z00Coo`00oook
J_oonf[oE03o2ooonfX00ooo003ooo]ZoookJP0GoookJP03ool0]Ooonf[ooo]Z0?Cooo]Z0oooY`0C
oookJPGo0?l98_oonfX4o`3o2@_ooo]Z0oooY`0CoookJP03o`3okOoonf[ooo]Z00?ooo]Z1?l00000
0ol0hooooo]ZoookJP06oookJP03o`3oj?oonf[o087o00?ooo]Z00?oo`0;oooX0?oonfX00_oonfX0
1?l0oo3ooo]ZoookJ_lY0?l2oookJP04oeT0oooonf[ooo]Zool0ZP[ooo]Z00?oK03ooookJ_oonfX0
5OoonfX00ooo0?Ko00?ooookJP07oookJP03o`3oMooonf[oUol001?ooo]Z00?oo`3boookJ_oonfX0
0ooonfX01Ooo0:3ooo]ZoookJ_mD0?oo02Go00[ooo]Z00?oNol0oookJ_oonfX05ooonfX00ooo0;Go
oo]ZoookJP1UoookJP00SooonfX9ool000cooo]Z1Ol0o`T3oookJQ7oobP02Oml0?l00ooo003ooo]Z
oookJP02oookJPKoo`002OooN@08oookJP?oojL04?oonfX2o`3ok@Cooo]Z1?l00002o`3So`Sooo]Z
00?oobP0ool00?oo00000_oo:005ool00005oolX0?oonf[ooo]ZobT0oooonfX00_oo:0001?mI0?oo
oo]ZoookJ_oo0:X:oookJP03of`0oooonf[ooo]Z01Cooo]Z00?o00?ooookJ_oonfX01_oonfX01?l0
ogOooo]ZoookJ_oo0003oookJP;oo`003?oonfX6ool000;ooo]Z00Coo`00oookJ_oonf[oE03o2ooo
nfX00ooo003ooo]ZoookJP0GoookJP03ool0]Ooonf[ooo]Z0?;ooo]Z0_ooY`0AoookJPGo0?l93ooo
nfX>og`0o`kooo]Z1Ol0o`T9oookJP?oojL04OoonfX2o`3ok@?ooo]Z1?l000000ooonf[o0>?oo`3S
o`07oookJP03o`3oj?oonf[o087o00?ooo]Z00?oo`0;oooX0?oonfX00_oonfX01?l0oo3ooo]Zoook
J_lY0?l2oookJP04oeT0oooonf[ooo]Zool0ZP[ooo]Z00?oK03ooookJ_oonfX05OoonfX00ol00ooo
oo]ZoookJP06oookJP04o`3oMooonf[ooo]ZoiOo01;ooo]Z00?oo`3boookJ_oonfX00ooonfX01Ooo
0:3ooo]ZoookJ_mD0?oo02Go00[ooo]Z00?oNol0oookJ_oonfX05ooonfX00ooo0;Gooo]ZoookJP1U
oookJP00SooonfX7ool000_ooo]Z0ol0o`T8oookJPooobP01_oonfX5ool000_oO03o0_oo0008oomi
0003o`3o2Ooonf[ooo]Z00Oooo]Z0_ooY`0@oookJP;o0?o]0_oonfX4o`0000;ooo]Z00?o0>?ooook
J_oonfX01OoonfX00ooo003oobP0oolX0003oolX00Coo`0000Cooo]ZoolX0?oonf[ooo]Z0ooo:000
1Ooonf[oF@3ooookJ_oonf[oo`2Z00[ooo]Z00?oobP0oookJ_oonfX05?oonfX00ol00ooooo]Zoook
JP06oookJP03o`3oMooonf[ooo]Z00Goo`003OoonfX5ool000?ooo]Z00Coo`00oookJ_oonf[oE03o
2_oonfX00ooo003ooo]ZoookJP0HoookJP03ool0]Ooonf[ooo]Z0>oooo]Z0_ooY`0@oookJP?o0?l9
2ooonfX9og`0o`kooo]Z2oml0?l8oookJP?o0?l92OoonfX2oonW017ooo]Z0_l0ond00ooonf[o0000
o`000002o`0000?ooo]Z00?o0>?ooookJ_oonfX01OoonfX00ol0onSooo]Zo`21o`03oookJP03ool0
2oooj03ooo]Z00;ooo]Z00Co0?o`oookJ_oonf[o:@3o0_oonfX01?mI0?oooo]ZoookJ_oo0:X:oook
JP03of`0oooonf[ooo]Z01Cooo]Z00?oo`3fo`03oooonfX01ooonfX00ol0ogOooo]ZoiOo000Coook
JP03ool0l_oonf[ooo]Z00?ooo]Z00Goo`2PoookJ_oonf[oE03oo`0Uo`09oookJP03og_o0?oonf[o
oo]Z01Sooo]Z00?oo`2eoookJ_oonfX0I?oonfX008cooo]Z0ooo00000ooonf[oo`00ool00003ool0
00[ooo]Z0_l0o`T7oookJP03og`0oooo:03oobP000WoobP06?l02ol5ool000CoO03o1ooonfX2oomi
00Wooo]Z0oooY`0?oookJP03o`3okOoonf[o000000?o00000ooonfX00ol0hooooo]ZoookJP03oook
JP;oo`001_oo:004ool00003oookJ_oo:03oobP000CoobP000Gooo]ZoeT0oooonf[ooo]Zool0ZP09
oookJP03oolX0?oonf[ooo]Z01Cooo]Z00?oo`3fo`03oooonfX01_oonfX00ol0ogOoo`00ool00005
ool000gooo]Z1Ooo0003oookJP04ool00?oonf[ooo]Zoe@0o`_ooo]Z00?oo`00oookJ_oonfX05ooo
nfX00ooo0;Gooo]ZoookJP3]oookJP;oojL04?oonfX2o`3o2@Sooo]Z1_ml0?l5oookJQSo00_o1Ooo
nfX4og`0o`Oooo]Z0ol0o`T8oookJP?oojL04?oonfX00ol0ongo0000o`000002o`0000Cooo]Z00?o
0>?ooookJ_oonfX01OoonfX00ol0onSooo]Zo`21o`03oookJP03ool02oooj03ooo]Z00;ooo]Z00Co
0?o`oookJ_oonf[o:@3o0_oonfX01?mI0?oooo]ZoookJ_oo0:X9oookJP03of`0oooonf[ooo]Z01Go
oo]Z00?oo`3fo`03oooonfX01_oonfX01?l0ogOooo]ZoookJ_nGo`0BoookJP03ool0l_oonf[ooo]Z
00?ooo]Z00Goo`2PoookJ_oonf[oE03oo`0Uo`0:oookJP03og_o0?oonf[ooo]Z01Oooo]Z00?oo`2e
oookJ_oonfX0I?oonfX008[ooo]Z0_oo0004oookJPCoo`002?oonfX3o`3o2@Kooo]Z0oml0?l5oook
JP;oobP01Ol02ol2oolX00[ooo]Z3?oo0006o`0;o`?oo`001Oml0?l2oookJP?oogT00_l0o`T9oook
JP;oojL03_oonfX00ol0ongo0000o`000002o`0000Cooo]Z00?o0>?ooookJ_oonfX00ooonfX7oolX
00Coo`0000?ooo]ZoolX0?oo:0001?oo:002oookJP03oeT0oooonf[oo`2Z00[ooo]Z00?oobP0oook
J_oonfX05?oonfX00ol00ooooo]ZoookJP05oookJP03ool00?l0ogOoo`0000Koo`003OoonfX4ool0
00?ooo]Z00Coo`00oookJ_oonf[oE03o2ooonfX00ooo003ooo]ZoookJP0GoookJP03ool0]Ooonf[o
oo]Z0>_ooo]Z0_ooY`0?oookJP?o0?l91ooonfX3og`0o`Kooo]Z1Ol02olDoookJPCoo`0H1_l02ol0
0ooo01Sooo]ZoookJP05og`0o`Gooo]Z0_l0o`T9oookJP;oojL03ooonfX01?l0ongo0000o`000?l0
0005oookJP03o`3Soooonf[ooo]Z00Gooo]Z00?o0?oXoookJ_l0POl00ooonfX00ooo00_oonP0oook
JP02oookJP03o`3ol?oonf[o:@3o00?ooo]Z00?oF@3ooookJ_oo0:X02_oonfX00om/0?oooo]Zoook
JP0EoookJP03o`03oooonf[ooo]Z00Gooo]Z00Co0?mgoookJ_oonf[oUol04ooonfX00ooo0?;ooo]Z
oookJP02oookJP05ool0X?oonf[ooo]Zoe@0ool09Ol02_oonfX00omko`3ooo]ZoookJP0GoookJP03
ool0]Ooonf[ooo]Z06Cooo]Z0029oookJP03ool00?oonf[ooo]Z00Cooo]Z0ooo0007oookJP;o0?l9
1ooonfX2og`0o`Kooo]Z1?l02ol4oolX00gooo]Z4_oo0005o`0;o`;oo`0000?ooo]Zog`0ooooN@00
1OooN@02o`3o2@Wooo]Z0_ooY`0;oookJP03ool00?oonf[o0?o]00?o00001OoonfX01?l0hooooo]Z
oookJ_oonfX9oolX0003ool00?oo:03ooo]Z00SoobP00_oonfX00omI0?oooo]Zool0ZP0:oookJP03
oolX0?oonf[ooo]Z01?ooo]Z00?oo`3fo`03oooonfX01OoonfX00ooo003o0?mgool00006ool000ko
oo]Z0ooo0004oookJP03ool00?oonf[ooo]Z00;oo`002OoonfX00ooo003ooo]ZoookJP0GoookJP03
ool0]Ooonf[ooo]Z0>[ooo]Z00?oojL0oookJ_oonfX03OoonfX2o`3o2@Sooo]Z0_ml0?l5oookJPCo
00_o8ooonfX5o`0;o`?ooo]Z1?ml0?l3oookJP?o0?l92?oonfX2oonW00gooo]Z00Co0000o`3okOl0
003o00001_oonfX00ol0hooooo]ZoookJP05oookJP03o`3oj?oonf[o087o00;ooo]Z00?oo`0;oook
J_ooj0000_oonfX01?l0oo3ooo]ZoookJ_lY0?l3oookJP03oeT0oooonf[oo`2Z00[ooo]Z00?oK03o
oookJ_oonfX05?oonfX00ooo0?Ko00?ooookJP06oookJP04o`3oMooonf[ooo]ZoiOo01;ooo]Z00?o
o`3boookJ_oonfX00ooonfX01Ooo0:3ooo]ZoookJ_mD0?oo02Go00Wooo]Z00?oNol0oookJ_oonfX0
5ooonfX00ooo0;Gooo]ZoookJP1ToookJP00TOoonfX00ooo003ooo]ZoookJP04oookJP;o0?l91_oo
nfX3og`0o`?ooo]Z1Ol02ol2oookJPCoobP01ooonfX7ok3o00Wo0?_o00?o/?l0ool00?oo00003?oo
0002o`0;o`WoogT000?ooo]Zo`3o2Ol0o`T02OoonfX00oooY`3ooo]ZoookJP03oookJP;oo`000ooo
nfX00ooo003ooo]Zo`000002o`3ok@03o`000?oonf[ooo]Z00Cooo]Z0_l0hol3oookJPOoobP00_oo
0009oolX00?ooo]Z00?oF@3ooookJ_oo0:X02OoonfX00ooo:03ooo]ZoookJP0DoookJP03o`03oooo
nf[ooo]Z00Gooo]Z00?oo`00o`3oMooo00001Ooo000?oookJP?oo`000ooonfX5ool000[ooo]Z00?o
o`00oookJ_oonfX05_oonfX00ooo0;Gooo]ZoookJP3hoookJP;o0?l91ooonfX3og`0o`;ooo]Z1Ol0
2ol=oookJPOo/?l02Ol0nol8ok3o00Kooo]Z00?oo`0Ho`0;ool02ol00_l02ol3oookJP?oO03o0ooo
nfX2o`3o2@Sooo]Z00?oojL0oookJ_oonfX01?oonfX2oolJ00Cooo]Z0_l00002o`3ok@Oooo]Z0_l0
hol6oookJP03o`3oj?oonf[o087o00;ooo]Z00?oo`0;oookJ_ooj0000_oonfX01?l0oo3ooo]Zoook
J_lY0?l3oookJP03oeT0oooonf[oo`2Z00Wooo]Z00?oK03ooookJ_oonfX05OoonfX00ol00ooooo]Z
oookJP05oookJP04o`3oMooonf[ooo]ZoiOo01?ooo]Z00?oo`3boookJ_oonfX00_oonfX01Ooo0:3o
oo]ZoookJ_mD0?oo02Go00[ooo]Z00?oNol0oookJ_oonfX05ooonfX00ooo0;Gooo]ZoookJP1Soook
JP00U_oonfX2o`3o2@Gooo]Z0oml0?l3oookJP?o00_o1ooonfX00ooo:03ooo]ZoookJP02oookJPCo
/?l02Ol0nol01?oonf[oo`00ool00?oo0005oookJP03o`3koooo003oo`0000Koo`004oooN@001?oo
:03o0?l9o`3o2Ol0o`T7oookJP;oojL01OoonfX00ooo003ooo]Zool00002ool000?o000000?o0?o]
oookJ_oonfX01_oonfX01?l0hooooo]ZoookJ_oonfX7oolX0003ool00?oonf[oobP000SoobP00_oo
nfX01?mI0?oooo]ZoookJ_oo0:X9oookJP03oolX0?oonf[ooo]Z01Cooo]Z00?o00?ooookJ_oonfX0
1OoonfX00ol0ogOoo`00ool00004ool0013ooo]Z0_oo00000ooonf[oo`00ool00005ool000[ooo]Z
00?oo`00oookJ_oonfX05ooonfX00ooo0;Gooo]ZoookJP3eoookJP;o0?l91_oonfX3og`0o`;ooo]Z
0ol02ol<oookJPCo/?l02Ol0nol9oookJPWo0?_o1On`o`03oookJP;oo`0H0ol02ol3oookJP;oO03o
0ooonfX2o`3o2@Oooo]Z0_ooY`06oookJP04oolJ0?oonf[ooo]ZoookJPCo000000?o0?o]oookJ_oo
nfX01_oonfX00ol0hooooo]ZoookJP04oookJP03o`3oj?oonf[o087o00;ooo]Z00?oo`0;oooX0?oo
nfX00_oonfX01?l0oo3ooo]ZoookJ_lY0?l2oookJP04oeT0oooonf[ooo]Zool0ZPWooo]Z00?oK03o
oookJ_oonfX05OoonfX00ol00ooooo]ZoookJP05oookJP04o`3oMooonf[ooo]ZoiOo01;ooo]Z00?o
o`3boookJ_oonfX00_oonfX01_oo0:3ooo]ZoookJ_mD0?oooo]Zo`0Uo`Wooo]Z00?oNol0oookJ_oo
nfX05ooonfX00ooo0;Gooo]ZoookJP1SoookJP00TooonfX3o`3o2@Gooo]Z0_ml0?l4oookJP;o00_o
2OoonfX5ok3o00Go0?_o5ooonfX4oomi00;o0?_o0_ooN@02o`3ko`koogT00_oo:0001?oonf[o0?l9
o`3o2OoonfX2ool000Cooo]Z0_ooY`04oookJPGoo`000ol000000ol0ongooo]ZoookJP06oookJP03
o`3Soooonf[ooo]Z00;ooo]Z1_oo:0000ooo003ooo]ZoolX0007oolX00?ooo]Z00CoF@3ooookJ_oo
nf[oo`2Z2?oonfX01?oo:03ooo]ZoookJ_oonfX2oolX017ooo]Z0_oo:007oookJP03o`3oMooo003o
o`0000?oo`004OoonfX9ool000[ooo]Z00?oo`00oookJ_oonfX05ooonfX00ooo0;Gooo]ZoookJP3b
oookJP?o0?l91_oonfX2og`0o`?ooo]Z0_l02ol:oookJPCo/?l01Ol0nolKoookJPKo0?_o1?n`o`00
0ooonf[oo`0Hool06003o`0;o`;ooo]Z0_ml0?l3oookJP?o0?l91_oonfX2oonW00Gooo]Z00?ooaX0
oookJ_oonfX01?l000000ooonf[o0?o]oookJP07oookJP03o`3Soooonf[ooo]Z00Cooo]Z00?o0?oX
o`3oUol0POl00_oonfX00ooo00_oonP0oookJP02oookJP03o`3ol?oonf[o:@3o00?ooo]Z00CoF@3o
oookJ_oonf[oo`2Z2?oonfX00om/0?oooo]ZoookJP0EoookJP03ool0m_l00ooooo]Z00Gooo]Z00Co
0?mgoookJ_oonf[oUol04ooonfX00ooo0?;ooo]ZoookJP02oookJP05ool0X?oonf[ooo]Zoe@0ool0
9Ol02OoonfX00omko`3ooo]ZoookJP0GoookJP03ool0]Ooonf[ooo]Z06?ooo]Z002AoookJP;o0?l9
1OoonfX3og`0o`Cooo]Z0_l02ol7oookJPCo/?l00_oonfX3o`3ko`cooo]Z3Om>0?l2ool00003oook
J_ooN@3oogT000SoogT00ol0nol<oomi00;oO03o00?oobP0oookJ_l0o`T00ooo0005oookJP03oonW
0?oonf[ooo]Z00Ooo`000_l000000ooonf[o0?o]oookJP07oookJP03o`3Soooonf[ooo]Z00?ooo]Z
1?oo:002ool000;oobP000?oonP0oolX0?oo:0001?oo:003oookJP04oeT0oooonf[ooo]ZoolX00So
oo]Z00?oobP0oookJ_oo:0000_oo:00BoookJP03oolX0?oonf[ooo]Z00Gooo]Z00?o0?mgool00?oo
00001?oo000@oookJP03ool0l_oo003oo`0000Koo`002ooonfX00ooo003ooo]ZoookJP0FoookJP03
ool0]Ooonf[ooo]Z0?3ooo]Z0_l0o`T6oookJP?oO03o0ooonfX2o`0;o`Sooo]Z1?n`o`001?oonf[o
0?_oo`3kool0nol<oookJPgoCP3o3OoonfX4o`3ko`Co/?l00_oo01P2o`0;o`;ooo]Z0oml0?l3oook
JP;o0?l91_oonfX00oooY`3ooo]ZoookJP03oookJP03oolJ0?oonf[o000000?o00000_oonfX00ol0
ongooo]ZoookJP06oookJP03o`3Soooonf[ooo]Z00Cooo]Z00?o0?oXo`3oUol0POl00_oonfX00ooo
00_oonP0oookJP02oookJP03o`3ol?oonf[o:@3o00?ooo]Z00CoF@3ooookJ_oonf[oo`2Z2?oonfX0
0om/0?oooo]ZoookJP0EoookJP03o`03oooonf[ooo]Z00Gooo]Z00Co0?mgoookJ_oonf[oUol04_oo
nfX00ooo0?;ooo]ZoookJP02oookJP05ool0X?oonf[ooo]Zoe@0ool09Ol02_oonfX00omko`3ooo]Z
oookJP0FoookJP03ool0]Ooonf[ooo]Z06?ooo]Z002?oookJP;o0?l91OoonfX2ool000Gooo]Z0_l0
2ol7oookJP;o/?l00ooonfX3o`3ko`Kooo]Z2Om>0?l=oookJPGoo`006OooN@02og`0o`Goo`001?l0
07l00ooonf[oojL0oonW0008ool00003o`000?oonf[ooo]Z00;o0?o]1ooonfX00ol0hooooo]Zoook
JP03oookJPCoobP000Goo`00oolX0?oo:03oobP0oooX0005oolX00Cooo]Z00?oF@3ooookJ_oo:000
2?oonfX6oolX017ooo]Z0_oo:007oookJP03o`3oMooo003oo`0000?oo`004?oonfX00ooo0?;ooo]Z
ool00007ool000[ooo]Z00?oo`00oookJ_oonfX05_oonfX00ooo0;Gooo]ZoookJP3^oookJP;o0?l9
1_oonfX2og`0o`Cooo]Z0_l02ol8oookJP;o/?l00_oonfX3o`3ko`Kooo]Z2Om>0?l=oookJP_oCP3o
1_oonfX4o`3ko`?o/?l000Coo`0Ho`0;ool02ooo00_o0_oonfX2og`0o`?ooo]Z0_l0o`T4o`00O`03
oookJ_ooY`3oojL000Cooo]Z0_oo6P03o`0000?ooo]Z0_l0ond7oookJP03o`3Soooonf[ooo]Z00Co
oo]Z00?o0?oXo`3oUol0POl00_oonfX01Ooo00_oonP0oookJ_oonf[o0?o`00;ooo]Z00Oo:@3ooook
J_oonf[ooo]ZoeT0oooonf[oo`2Z00Wooo]Z00?oK03ooookJ_oonfX05?oonfX00ooo0?Ko00?ooook
JP05oookJP05o`3oMooonf[ooo]ZoookJ_nGo`004OoonfX00ooo0?;ooo]ZoookJP03oookJP05ool0
X?oonf[ooo]Zoe@0ool09Ol02OoonfX00omko`3ooo]ZoookJP0GoookJP03ool0]Ooonf[ooo]Z06;o
oo]Z002>oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z1Ooo0003oookJP;o00_o1ooonfX2ok3o00;ooo]Z
0ol0nol4oookJPGoCP3o2_oonfX=ool050Koo`000_oonfX8oomi00?ooo]Z2oooN@07ool000Co001o
0_oo0002oonW00Ooo`001?oonfX00ol0ongooo]ZoookJP04oookJP03o`3Soooonf[ooo]Z00Gooo]Z
0ooo:0001?oo003oobP0oolX0?ooj006oolX00Cooo]Z00?oF@3ooookJ_oo:0001_oonfX7oolX01;o
oo]Z00?oobP0oookJ_oonfX01OoonfX00ol0ogOoo`00ool00003ool0017ooo]Z00?oo`3boookJ_oo
00001_oo000:oookJP03ool00?oonf[ooo]Z01Oooo]Z00?oo`2eoookJ_oonfX0k?oonfX00ol0o`Wo
oo]ZoookJP05oookJP03og`0oooonf[ooo]Z00;ooo]Z0_l02ol8oookJP;o/?l000Cooo]Zo`3kool0
nooo0?_o1?oonfX5odh0o`[ooo]Z3Ooo01@:oookJPGoCP3o1OoonfX4o`3ko`03ok3o0?oonf[oo`0H
00?o00_o0_ldo`001Oml0?oooo]Zo`00Ool007oo0?l900Co001o0_oonfX2oonW00?ooo]Z00Co0000
oolJ0?l0003o00001OoonfX00ol0ongooo]ZoookJP04oookJP03o`3Soooonf[ooo]Z00Gooo]Z00?o
0?oXo`3oUol0POl00_oonfX01ooo00_oonP0oookJ_oonf[o0?o`oookJ_lY0?l01?oonfX00omI0?oo
oo]Zool0ZP08oookJP03of`0oooonf[ooo]Z01Cooo]Z00?oo`3fo`03oooonfX01_oonfX01?l0ogOo
oo]ZoookJ_nGo`0BoookJP03ool0l_oonf[ooo]Z00;ooo]Z00Goo`2PoookJ_oonf[oE03oo`0Uo`09
oookJP03og_o0?oonf[ooo]Z01Oooo]Z00?oo`2eoookJ_oonfX0H_oonfX008gooo]Z00Co0?l9oook
J_oonf[ooo]Z1_oo0003oookJP03o`0;oooonf[ooo]Z00Gooo]Z0_n`o`001?oonf[o0?_oo`3kool0
nol5oookJP;oCP3o1ooonfX8ool050_ooo]Z0_ooN@07ool050_oogT00_m>0?l2oookJP03oolX0?l0
noooogT000KoogT000?o00_oool00?oo00001?oo00000ol0o`Wo001oo`00O`02oookJP;oo`0000?o
ojL0ool00?oo00001?oo0005oookJP03o`3okOoonf[ooo]Z00Cooo]Z00?o0>?ooookJ_oonfX01_oo
nfX00ooo:03o087ooolX0002oolX0003oooX0?oo:03oobP000?oobP000?o:@3ooookJ_oonfX00_oo
nfX00omI0?oooo]ZoolX0004oookJPSoobP04_oonfX2oolX00Oooo]Z00?o0?mgool00?oo00000_oo
000AoookJP03ool0l_oonf[oo`0000Koo`002ooonfX00ooo003ooo]ZoookJP0FoookJP03ool0]Ooo
nf[ooo]Z0>_ooo]Z00?o0?l9oookJ_oonfX01?oonfX2og`0o`Cooo]Z00?o00_ooookJ_oonfX01_oo
nfX2ok3o00?o0?_o1OoonfX2odh0o`Oooo]Z2?oo01@=oookJP_oo`0D1?oonfX5odh0o`Cooo]Z0ol0
nol00on`o`3oo`0Hool06002o`0;o`;o=?l000?oO03oo`00Ool007l00_l0o`T2o`00O`Cooo]Z00?o
ojL0oookJ_oonfX00_l000000ooo6P3o0000oookJP05oookJP03o`3okOoonf[ooo]Z00Cooo]Z00?o
0>?ooookJ_oonfX01OoonfX00ol0onSo087ooookJP02oookJP07ool02oooj03ooo]ZoookJ_l0oo3o
oo]ZobT0o`04oookJP03oeT0oooonf[oo`2Z00Sooo]Z00?oK03ooookJ_oonfX05?oonfX00ooo0?Ko
00?ooookJP05oookJP05o`3oMooonf[ooo]ZoookJ_nGo`004OoonfX00ooo0?;ooo]ZoookJP02oook
JP05ool0X?oonf[ooo]Zoe@0ool09Ol02_oonfX00omko`3ooo]ZoookJP0FoookJP03ool0]Ooonf[o
oo]Z06;ooo]Z002;oookJP;o0?l90_oonfX7ool000;ooo]Z0_l02ol6oookJP;o/?l00ol0nol5oook
JP?oCP3o1?oonfX5ool051?ooo]Z1_ooN@03ool000googT000CoCP3ooolX0?oo:03oobP01_ooN@02
ool000;o00_o1_oo0002o`00O`Cooo]Z0_ooY`05ool000Gooo]Z00?o0?o]oookJ_oonfX01?oonfX0
0ol0hooooo]ZoookJP05oookJP03o`3oUooo:03o087o00?oobP000?oonP0oolX0?oo:0000ooo:004
oookJP03oeT0oooonf[oobP000?ooo]Z2_oo:00AoookJP;oobP01ooonfX00ol0ogOooo]Zool00002
ool0017ooo]Z00?oo`3boookJ_oonfX01_oo00000ol09Ooooo]ZoookJP08oookJP03ool00?oonf[o
oo]Z01Kooo]Z00?oo`2eoookJ_oonfX0j_oonfX00ol0o`Wooo]ZoookJP04oookJP03og`0oooonf[o
oo]Z00;ooo]Z0_l02ol6oookJP;o/?l00ol0nol5oookJP?oCP3o1?oonfX5ool051Cooo]Z1Oooa`07
oookJPGoo`0D1?oonfX4odh0o`?o001o0_l0nol00on`o`3o001oool06002o`0;o`;o=?l000?oO03o
oookJ_oonfX00_l0o`T00ol007oooo]ZoookJP02oookJP;oojL00ol00002oolJ00Kooo]Z00?o0?o]
oookJ_oonfX01?oonfX00ol0hooooo]ZoookJP05oookJP06o`3oj?l0POoooo]ZoookJ_oo00_oonP0
0ooonfX00ol0oo3ooo]ZobT0o`03oookJP03oeT0oooonf[oo`2Z00Wooo]Z00?oK03ooookJ_oonfX0
4ooonfX00ooo0?Ko00?ooookJP05oookJP05o`3oMooonf[ooo]ZogT0oonGo`004OoonfX00ooo0?;o
oo]ZoookJP03oookJP05ool0X?oonf[ooo]Zoe@0ool09Ol02OoonfX00omko`3ooo]ZoookJP0Foook
JP03ool0]Ooonf[ooo]Z06;ooo]Z002:oookJP03o`3o2Ooonf[oo`0000Soo`0000?ooo]Zo`0;ool0
2ol01_oonfX2ok3o00;o0?_o1_oonfX2odh0o`Gooo]Z0_oo01@HoookJQooogT01Ooo0002o`0;o`Go
o`0000?o0?l9oookJ_oonfX01?oonfX00oooY`3oo`00ool00003ool000Gooo]Z00?o0?o]oookJ_oo
nfX01?oonfX00ol0hooooo]ZoookJP05oookJP03o`3oj?oonf[o087o00?oobP000KoonP0oolX0?oo
:03ooo]ZoolX0?lY0?l4oookJP03oeT0oooonf[oobP000CoobP000?ooo]ZoolX0?oo:0001Ooo:00B
oookJP03oolX0?oonf[ooo]Z00Gooo]Z00?o0?mgoookJ_oonfX00ooo0007oookJP03ool00?oonf[o
oo]Z00Oooo]Z00?oo`3boookJ_oonfX01Ooo00000omD0?oooo]ZoookJP08oookJP03ool00?oonf[o
oo]Z01Kooo]Z00?oo`2eoookJ_oonfX0j?oonfX2o`3o2@Kooo]Z00CoO03ooookJ_oonf[ooo]Z0_l0
2ol6oookJP;o/?l00_l0nol6oookJP;oCP3o1OoonfX2ool051kooo]Z1oooa`05oookJPGoo`0D0ol0
07l3odh0o`;o001o0_l0nol2ok3o0003ool06?l02ooo00_o00;o=?l000?oO03oo`00Ool007l00_l0
o`T5oookJP03oonW0?l0003o000000;o000000?ooaX0oookJ_oonfX01?oonfX00ol0ongooo]Zoook
JP04oookJP03o`3Soooonf[ooo]Z00Cooo]Z00?o0?oXo`3oUol0POl00_oonfX00ooo00_oonP0oook
JP02oookJP03o`3ol?oonf[o:@3o00?ooo]Z00?oF@3ooookJ_oo0:X02?oonfX00om/0?oooo]Zoook
JP0DoookJP03o`03oooonf[ooo]Z00Gooo]Z00Go0?mgoookJ_mi0?oooo]ZoiOo0007oookJP03oono
0?oonf[ooo]Z00Oooo]Z00?oo`3boookJ_oonfX00_oonfX01Ooo0:3ooo]ZoookJ_mD0?oo02Go00Wo
oo]Z00?oNol0oookJ_oonfX05ooonfX00ooo0;Gooo]ZoookJP1QoookJP00ROoonfX00ol0o`Woo`00
ool00008ool000;o00_o1_oonfX2ok3o0003oookJ_l0nooooo]Z00Gooo]Z0_m>0?l4oookJP?oo`0D
6_oonfXIoomi0003ool05?ooN@3oogT000?oogT00ooo:004ool000;o00_o1?oo0002o`3o2@Cooo]Z
00?o0000oonW0?l000001?oo0005oookJP03o`3okOoonf[ooo]Z00Cooo]Z00?o0>?ooookJ_oonfX0
1OoonfX00ol0onSooo]Zo`21o`03oolX0006oooX0?oo:03ooo]ZoookJ_oo:03o:@3o1?oonfX00omI
0?ooobP0oolX0004oolX0003oookJ_oo:03oobP000CoobP04_oonfX2oolX00Oooo]Z00?o0?mgoook
J_oonfX00_oo0007oookJP03ool00?oonf[ooo]Z00Oooo]Z00Coo`3boookJ_oonf[ooo]Z1?oo0000
0omD0?oooo]ZoookJP09oookJP03ool00?oonf[ooo]Z01Gooo]Z00?oo`2eoookJ_oonfX0iooonfX0
0ol0o`Wooo]ZoookJP04oookJP;oO03o0_oonfX2o`0;o`Kooo]Z0_n`o`000ooonf[o0?_ooookJP05
oookJP;oCP3o1OoonfX2ool052Oooo]Z1_ooa`04oookJP?oo`0D0ooonfX2odh0o`;ooo]Z0_l0nol2
ok3o0003oookJ_l02ooo00_o00;o=?l00_l007l00ooonf[o0?l9oookJP03oookJP04o`000?ooY`3o
0000o`0000;ooo]Z00?ooaX0oookJ_oonfX00ooonfX00ol0ongooo]ZoookJP05oookJP03o`3Soooo
nf[ooo]Z00Cooo]Z00?o0?oXo`3oUol0POl00_oonfX00ooo00_oonP0oookJP02oookJP03o`3ol?lY
0?oooo]Z00?ooo]Z00?oF@3oool0Z_oonfX02?oonfX00om/0?oooo]ZoookJP0CoookJP03ool0m_l0
0ooooo]Z00Gooo]Z00Go0?mgoookJ_oonf[oN@3ooiOo0007oookJP03oono0?oonf[ooo]Z00Oooo]Z
00?oo`3boookJ_oonfX00ooonfX01?oo0:3ooo]Zoe@0ool09Ol:oookJP03og_o0?oonf[ooo]Z01Ko
oo]Z00?oo`2eoookJ_oonfX0HOoonfX008Oooo]Z0_l0o`T9ool000;o00_o1_oonfX2ok3o0003oook
J_l0nooo0?_o00Cooo]Z0om>0?l4oookJP;oo`0D5ooonfX2oomi00CoojP03oooN@04oookJP?oolL0
00Cooo]Zoomi0?ooN@3oogT00ooo01@5oomi00CoobP00_oo0002o`0;o`?oo`0000?ooo]Zo`3o2Ol0
o`T00_oonfX2o`000003oonW0?l0003ooo]Z00?oo`001OoonfX00ol0ongooo]ZoookJP04oookJP03
o`3Soooonf[ooo]Z00Gooo]Z00Ko0?oXo`21oooonf[ooo]ZoolX0?ooj002oolX0004oookJ_l0oo3o
oo]ZobT0o`;ooo]Z2?oo:002oookJPKoobP04_oonfX00ooo:03ooo]ZoookJP05oookJP03o`3oMooo
nf[ooo]Z00;oo`001ooonfX00ooo003ooo]ZoookJP07oookJP04ool0l_oonf[ooo]ZoookJPCoo`00
00?oE03oo`0UoooonfX02OoonfX00ooo003ooo]ZoookJP0FoookJP03ool0]Ooonf[ooo]Z0>Gooo]Z
00?o0?l9oookJ_oonfX01?oonfX00oml0?oooo]ZoookJP02o`0;o`Kooo]Z0_n`o`000ooonf[o0?_o
o`3ko`04oookJP?oCP3o1?oonfX3ool051Wooo]Z3?ooZ00:oookJP?oolL01?oonfX3ool050;ooo]Z
0_m>0?l2oookJP;o0?_o00?o/?l0oookJ_oonfX00_l02ol2ocCo00;ooo]Z0_l0o`T2oookJP;o0000
00?oojL0o`000?oonfX00_oonfX00ooo6P3ooo]ZoookJP03oookJP03o`3okOoonf[ooo]Z00Gooo]Z
00?o0>?ooookJ_oonfX01?oonfX00ol0onSo0?nGo`21o`02oookJP07ool02oooj03ooo]ZoookJ_l0
oo3ooo]ZobT0o`03oookJP03oeT0oooonf[oo`2Z00Sooo]Z00?oK03ooookJ_oonfX04ooonfX00ooo
0?Ko00?ooookJP06oookJP05o`3oMooonf[oN@3ooookJ_nGo`001_oonfX00ooo_`3ooo]ZoookJP07
oookJP03ool0l_oonf[ooo]Z00?ooo]Z00Goo`2PoookJ_oonf[oE03oo`0Uo`09oookJP03og_o0?oo
nf[ooo]Z01Kooo]Z00?oo`2eoookJ_oonfX0HOoonfX008Kooo]Z00?o0?l9oookJ_oonfX02?oo0000
0ol02oooo`00oookJP04oookJP;o/?l000?ooo]Zo`3kool0nol01?oonfX2odh0o`Gooo]Z0_oo01@D
oookJPOoojP05?ooN@02oonX00Cooo]Z1?ooa`03oomi00;oo`0D1oooN@03oolX0003ool00?l02ooo
00_o00;oo`000_oonfX2o`3o2@?o000000?oojL0oookJ_oonfX00_oonfX00ooo003ooo]ZoookJP03
oookJP03o`3okOoonf[ooo]Z00Cooo]Z00?o0>?ooookJ_oonfX01OoonfX01ol0onSo087ooookJ_oo
nf[oobP0oooX0?oo:0000_oonfX00ol0oo3ooo]ZobT0o`09oolX00?ooo]Z1Ooo:00BoookJP;oobP0
00?ooo]ZoolX0?oo:0001?oonfX01?l0ogOooo]Zool00?nGo`08oookJP03ool00?oonf[ooo]Z00Ko
oo]Z00?oo`3boookJ_oonfX00_oonfX3ool00003oookJ_mD0?oooo]Z00Wooo]Z00?oo`00oookJ_oo
00000_oo000DoookJP03ool0]Ooonf[ooo]Z0>Cooo]Z00?o0?l9oookJ_oonfX00ooonfX2og`0o`;o
oo]Z00?o00_ooookJ_oonfX01?oonfX2ok3o00;ooo]Z00?o0?_ooookJ_oonfX00_oonfX2odh0o`Go
oo]Z0_oo01@EoookJPOoojP03?oonfX9oonX00Cooo]Z1?ooa`03oookJP;oo`0D0_oonfX3odh0o`06
o`00Ool0nooo0?_ook3o0?l007ooo`0H0_l02ol2ocCo00;ooo]Z0_l0o`T3o`000003oonW0?oonf[o
oo]Z00;ooo]Z00?ooaX0oookJ_oonfX00ooonfX00ol0ongooo]ZoookJP05oookJP03o`3Soooonf[o
oo]Z00Cooo]Z00?o0?oXo`21oooonfX00_oonfX01ooo00_oonP0oookJ_oonf[o0?o`oookJ_lY0?l0
0ooonfX00omI0?oooo]Zool0ZP08oookJP03of`0oooonf[ooo]Z01?ooo]Z00?oo`3fo`03oooonfX0
1OoonfX01Ol0ogOooo]ZogT0oooonf[oUol000Oooo]Z00?ookl0oookJ_oonfX01ooonfX00ooo0?;o
oo]ZoookJP02oookJP05ool0X?oonf[ooo]Zoe@0ool09Ol02OoonfX00omko`3ooo]ZoookJP0Foook
JP03ool0]Ooonf[ooo]Z067ooo]Z0025oookJP03o`3o2Ooonf[ooo]Z00;ooo]Z1_oo00000ol02ooo
o`00oookJP04oookJP04ok3o0?oonf[ooo]Zo`3ko`Cooo]Z0_m>0?l4oookJP?oo`0D4OoonfX5oonX
00Gooo]Z5?ooN@04oookJP?oojP01OoonfX3ooo70005oomi0?oo:03oo`0Dool05?oo:0001oooN@03
oolX00;o00_o00Koo`00ocCo0?oonf[ooo]Zo`3o2Ooo0002o`0000;oojL00ooonfX00ooo6P3ooo]Z
oookJP03oookJP03o`3okOoonf[ooo]Z00Cooo]Z00?o0>?ooookJ_oonfX01?oonfX00ol0onSo0?nG
o`21o`02oookJP03oolX0?ooj03oobP000;ooo]Z00Co0?o`obT0oooonf[ooo]Z2?oo:003oookJPCo
obP04ooonfX6oolX00;ooo]Z00Go0?mgoookJ_oonf[oo`00oiOo0007oookJP03ool00?oonf[ooo]Z
00Oooo]Z00?oo`3boookJ_oonfX00_oonfX3ool00003oe@0ool09Ooooo]Z00Oooo]Z1_oo000Doook
JP03ool0]Ooonf[ooo]Z0>?ooo]Z00?o0?l9oookJ_oonfX00ooonfX01Oml0?oooo]ZoookJ_oonf[o
00_o00Kooo]Z00?o/?l0oookJ_oonfX00_l0nol3oookJP;oCP3o1OoonfX2ool051;ooo]Z1OooZ00L
oookJP?oojP01OoonfX3ooo700;ooo]Z0_oo01@3oookJP;oCP3o00Ko001oo`3kool0nooo/?l0oook
J_oo01P2o`0;o`;o=?l00_oonfX01?l0o`Wo0000o`000?l00002oonW00?ooo]Z00?ooaX0oookJ_oo
nfX00ooonfX00ol0ongooo]ZoookJP05oookJP03o`3Soooonf[ooo]Z00?ooo]Z00?o0?oXoookJ_l0
POl00ooonfX01_ooj03ooo]ZoookJ_oonf[o0?o`obT0o`Cooo]Z00?oF@3oool0Z_oonfX02?oonfX0
0om/0?oooo]ZoookJP0BoookJP03ool0m_l00ooooo]Z00Kooo]Z00Co0?mgoookJ_mi0?ooUol01ooo
nfX00ooo_`3ooo]ZoookJP07oookJP03ool0l_oonf[ooo]Z00?ooo]Z00Goo`2PoookJ_mD0?oooo]Z
o`0Uo`08oookJP03og_o0?oonf[ooo]Z01Oooo]Z00?oo`2eoookJ_oonfX0H?oonfX008Cooo]Z00?o
0?l9oookJ_oonfX00ooonfX5ool00003o`0;oooo003ooo]Z00Cooo]Z00Co/?l0oookJ_l0nooo0?_o
1?oonfX00om>0?oooo]ZoookJP02oookJP;oo`0D4OoonfX3oonX00Wooo]Z00?oo`2doomi0?ooN@00
1?oo8@0Aoomi00Cooo]Z1?ooZ004oookJPCoobP00ooo01@00ooo:03oogT0oomi0003oomi0004o`3k
oooonf[oo`0HoolX00;o00_o00Co=?l0oookJ_l0003oo`000_l00002oookJP05oonW0?oonf[ooo]Z
oookJ_oo6P001OoonfX00ol0ongooo]ZoookJP04oookJP03o`3Soooonf[ooo]Z00Cooo]Z00?o0?oX
oookJ_l0POl00ooonfX01_ooj03ooo]ZoookJ_l0oo3ooo]ZobT0o`;ooo]Z1ooo:004oookJPCoobP0
4?oonfX8oolX00?ooo]Z00Co0?mgoookJ_oo003oUol01ooonfX00ooo003ooo]ZoookJP07oookJP03
ool0l_oonf[ooo]Z00;ooo]Z0ooo00000omD0?oo02GooookJP05oookJPSoo`005?oonfX00ooo0;Go
oo]ZoookJP3QoookJP;o0?l91OoonfX01Oml0?oooo]ZoookJ_oonf[o00_o00Kooo]Z00Co/?l0oook
J_oonf[o0?_o1?oonfX00om>0?oooo]ZoookJP03oookJP;oo`0D4OoonfX3oonX00Sooo]Z1?oo0;@?
oolQ00;oo`2d1ooonfX4oonX00Cooo]Z0oooa`001?oonf[oo`0Dool05?oo01@2o`00O`;oCP3o00Co
oo]Zo`3kool0nooooo]Z0_oo01P2o`0;o`04ocCo0?oonf[o0000o`3o2@;o00000_oonfX01OooY`3o
oo]ZoookJ_oonf[ooaX000Gooo]Z00?o0?o]oookJ_oonfX01OoonfX00ol0hooooo]ZoookJP03oook
JP03o`3oj?l0oiOo087o00?ooo]Z00KoonP0oookJ_oonf[o0?o`oookJ_lY0?l3oookJP03oeT0oooo
nf[oo`2Z00Sooo]Z00?oK03ooookJ_oonfX04ooonfX00ooo0?Ko00?ooookJP05oookJP05o`3oMooo
nf[oN@3ooookJ_nGo`001_oonfX00ooo_`3ooo]ZoookJP07oookJP03ool0l_oonf[ooo]Z00?ooo]Z
00Goo`2PoookJ_oonf[oE03oo`0Uo`09oookJP03og_o0?oonf[ooo]Z01Kooo]Z00?oo`2eoookJ_oo
nfX0H?oonfX008;ooo]Z0_l0o`T5oookJP03ool00?oonf[oo`0000;oo`0000?o00_oool00?oonfX0
1?oonfX00on`o`3ooo]Zo`3ko`05oookJP04odh0oooonf[ooo]ZoookJP;oo`0D4?oonfX3oonX00Oo
oo]Z2?oo8@0Foomi00;oob4000?oo`2doookJ_oonfX00_oonfX3oonX0003oookJ_oo:03oobP000Go
obP00_oo01@00ooo:03ooo]Zodh0o`02oookJP08o`3koon`o`3ooo]Zool06?oonf[o00_oocCo0?ml
0?l2ool00005o`000?oonf[ooo]ZoookJ_ooY`000ooonfX00ooo6P3ooo]ZoookJP03oookJP03o`3o
kOoonf[ooo]Z00Cooo]Z00?o0>?ooookJ_oonfX01?oonfX00ol0onSo087ooookJP02oookJP07oooX
0?oo:03ooo]ZoookJ_l0oo3ooo]ZobT0o`02oookJPKoobP01?oonfX01?oo003oobP0oolX0?oo:00?
oookJPWoobP00ooonfX01?l0ogOooo]Zool00?nGo`08oookJP03ool00?oonf[ooo]Z00Kooo]Z00?o
o`3boookJ_oonfX00ooonfX2ool00003oookJ_mD0?oooo]Z00Gooo]Z2?oo000EoookJP03ool0]Ooo
nf[ooo]Z0=oooo]Z00?o0?l9oookJ_oonfX00ooonfX2og`0o`?ooo]Z00?o00_ooookJ_oonfX01?oo
nfX01?n`o`3ooo]Zo`3kool0nol4oookJP03odh0oooonf[ooo]Z00;ooo]Z0_oo01@@oookJP?oojP0
1_oonfX9oolQ00oooo]Z2Ooo8@04oookJP?oojP01?oonfX2ooo700;ooo]Z0_oo01@2oookJP06odh0
oooonf[ooo]Zo`3koon`o`3ooo]Z0_oo01P01?l02ooo=?l0og`0ool00002o`3o2@?ooo]Z00GoojL0
oookJ_oonf[ooo]ZoolJ0005oookJP03o`3okOoonf[ooo]Z00Gooo]Z00?o0>?ooookJ_oonfX00ooo
nfX00ol0onSo0?nGo`21o`03oookJP06oooX0?oonf[ooo]Zo`3ol?oonf[o:@3o0ooonfX00omI0?oo
oo]Zool0ZP06oookJP03ool=0?oonf[oK03o01Cooo]Z00?oo`3fo`03oooonfX01_oonfX01?l0ogOo
N@3ooookJ_nGo`07oookJP03oono0?oonf[ooo]Z00Oooo]Z00?oo`3boookJ_oonfX00_oonfX01Ooo
0:3ooo]ZoookJ_mD0?oo02Go00Wooo]Z00?oNol0oookJ_oonfX05_oonfX00ooo0;Gooo]ZoookJP1P
oookJP00POoonfX00ol0o`Wooo]ZoookJP04oookJP07ool00?oonf[ooo]ZoookJ_oo003o00_oool0
0004oookJP;o/?l00_l0nol4oookJP;oCP3o0ooonfX00ooo01Cooo]ZoookJP0=oookJP?oojP01ooo
nfX3oolQ0003ool0]?oonf[ooo]Z00?ooo]Z5OooN@05oookJP?oob400_oo0;@3oookJP?oojP01ooo
:002ool05004o`00Oom>0?ooCP3oo`00O`;o0?_o00Gooo]Zool06?oonf[o00_oocCo0002og`0o`03
ool00?oonf[ooo]Z00;ooo]Z00GoojL0oookJ_oonf[ooo]ZoolJ0005oookJP03o`3okOoonf[ooo]Z
00Cooo]Z00?o0>?ooookJ_oonfX01?oonfX00ol0onSo087ooookJP02oookJP04oooX0?oonf[ooo]Z
o`3ol0;ooo]Z00?o:@3ooookJ_oonfX01_oo:003oookJP04ool00?oonf[oobP0oolX00oooo]Z2Ooo
:004oookJP04o`3oMooonf[oo`00oiOo00Oooo]Z00?oo`00oookJ_oonfX01ooonfX00ooo0?;ooo]Z
oookJP03oookJP04ool00?oonf[oE03oo`0Uo`Kooo]Z1ooo000EoookJP03ool0]Ooonf[ooo]Z0=ko
oo]Z00?o0?l9oookJ_oonfX00ooonfX00oml0?oooo]ZoookJP02oookJP03o`0;oooonf[ooo]Z00?o
oo]Z0_n`o`000ooonf[o0?_ooookJP03oookJP;oCP3o1?oonfX00ooo01Cooo]ZoookJP0=oookJP?o
ojP01_oonfX3oolQ00;oo`2d7ooonfX3oolQ0004ool0]?oonf[ooo]ZoookJP?oojP00ooonfX2ooo7
0005oookJ_l007ooo`0Dool05?l007l00_m>0?l02?l007oo0?_oo`3koon`o`3ooo]Zool06?l02ooo
=?l00_ml0?l00ol0003o0?l9oookJP02oookJP05oonW0?oonf[ooo]ZoookJ_oo6P001OoonfX00ol0
ongooo]ZoookJP05oookJP03o`3Soooonf[ooo]Z00?ooo]Z00?o0?oXo`3oUol0POl00_oonfX01ooo
00_oonP0oookJ_oonf[o0?o`oookJ_lY0?l00ooonfX00omI0?ooo`2ZoookJP05oookJP03ool=0?oo
nf[oK03o01Cooo]Z00?oo`3foookJ_l00ol01_oonfX01?l0ogOooo]ZogT0oonGo`07oookJP03oono
0?oonf[ooo]Z00Oooo]Z00?oo`3boookJ_oonfX00ooonfX01Ooo0:3ooo]ZoookJ_mD0?oo02Go00So
oo]Z00?oNol0oookJ_oonfX05_oonfX00ooo0;Gooo]ZoookJP1PoookJP00P?oonfX00ol0o`Wooo]Z
oookJP04oookJP04ool00?oonf[ooo]ZoookJP;o00_o00?oo`00oookJ_oonfX00_oonfX00on`o`3o
0?_oo`3ko`05oookJP03odh0oooonf[ooo]Z00;ooo]Z00?oo`0DoookJ_oonfX02ooonfX3oonX00Oo
oo]Z0ooo8@000ooo0;Cooo]ZoookJP06oookJPKoogT00_oonfX8oomi00CoobP02OoonfX4oolQ0004
ool0]?oo:03oobP0oolX00;oojP01ooo:002ool05006o`00Oom>0?oooo]ZoookJ_l0nooo/?l00_oo
0002o`0;o`04ool00?ml0?ooo`00o`3o2@?ooo]Z00GoojL0oookJ_oonf[ooo]ZoolJ0005oookJP03
o`3okOoonf[ooo]Z00Cooo]Z00?o0>?ooookJ_oonfX00ooonfX00ol0onSo0?nGo`21o`03oookJP06
oooX0?oonf[ooo]Zo`3ol?oonf[o:@3o0ooonfX5oolX00Cooo]Z00Coo`00oookJ_oo:03oobP03ooo
nfX8oolX00Cooo]Z00Co0?mgoookJ_oo003oUol01ooonfX00ooo003ooo]ZoookJP07oookJP03ool0
l_oonf[ooo]Z00?ooo]Z00Coo`2PoookJ_mD0?oo02Go1ooonfX6ool001Gooo]Z00?oo`2eoookJ_oo
nfX0gOoonfX00ol0o`Wooo]ZoookJP03oookJP04og`0oooonf[ooo]ZoookJP;o00_o1OoonfX01?n`
o`3ooo]Zo`3kool0nol4oookJP03odh0oooonf[ooo]Z00?ooo]Z00?oo`0DoookJ_oonfX02ooonfX3
oonX00Kooo]Z0ooo8@000ooo0;Cooo]ZoookJP0ToookJP?oob4000Coo`2doookJ_oonf[ooo]Z0_oo
Z003oookJP?oolL000Go001oool05?oo01Co001oodh0o`02oookJP04o`3koon`o`3ooo]Zool060;o
00_o00Co0000og`0oooonf[o0?l90ooonfX01OooY`3ooo]ZoookJ_oonf[ooaX000Gooo]Z00?o0?o]
oookJ_oonfX01OoonfX00ol0hooooo]ZoookJP02oookJP04o`3oj?oonf[o0?nGo`21o`;ooo]Z00Ko
o`0;oooX0?oonf[o0?o`oookJ_lY0?l3oookJP03oeT0oooonf[oo`2Z00Kooo]Z00?oo`d0oookJ_m/
0?l05?oonfX00ooo0?Ko00?ooookJP05oookJP05o`3oMooonf[oN@3ooookJ_nGo`001_oonfX00ooo
_`3ooo]ZoookJP07oookJP03ool0l_oonf[ooo]Z00?ooo]Z00Goo`2PoookJ_oonf[oE03oo`0Uo`09
oookJP03og_o0?oonf[ooo]Z01Kooo]Z00?oo`2eoookJ_oonfX0GooonfX007oooo]Z00?o0?l9oook
J_oonfX02?oonfX00ol02ooooo]ZoookJP04oookJP03ok3o0?l0nooooo]Z00Cooo]Z0_m>0?l4oook
JP03ool05?oonf[ooo]Z00[ooo]Z0_ooZ007oookJP?oob403?oonfX2oomi00Kooo]Z0oooN@04oook
JPOoobP02ooonfX3oolQ00;ooo]Z00?oobP0oonX0?ooZ0001ooo:0001Ooo01Cooo]Zodh0oom>0?oo
oo]Z00;o0?_o0ooo00001Ol02ooo=?l0og`0oooonf[o0?l900?ooo]Z00GoojL0oookJ_oonf[ooo]Z
oolJ0005oookJP03o`3okOoonf[ooo]Z00Cooo]Z00?o0>?ooookJ_oonfX00ooonfX00ol0onSo0?nG
o`21o`03oookJP06oolX0?oonf[ooo]Zo`3ol?oonf[o:@3o0_oonfX00omI0?ooobP0oolX0002oolX
00Cooo]Z00Coo`00oookJ_oonf[oobP04?oonfX8oolX00Cooo]Z00?o0?mgool00?nGo`002?oonfX0
0ooo003ooo]ZoookJP06oookJP03ool0l_oonf[ooo]Z00?ooo]Z00Coo`2PoookJ_oonf[oE03o1ooo
nfX6ool001Gooo]Z00?oo`2eoookJ_oonfX0g?oonfX00ol0o`Wooo]ZoookJP07oookJP03o`0;oooo
nf[ooo]Z00Cooo]Z00?o/?l0oookJ_l0nol01?oonfX2odh0o`Cooo]Z0_oo01@;oookJP?oojP01_oo
nfX3oolQ0003ool0]?oonf[ooo]Z02[ooo]Z0ooo8@000ooo0;Cooo]ZoookJP02oonX00Cooo]Z0_oo
a`000ooonf[oo`0DoookJP02odh0o`0;oookJ_l0nooo0?_ook3o0?l0003oo`0Ho`0;ooldo`3oO03o
oookJ_l0o`T00ooonfX01OooY`3ooo]ZoookJ_oonf[ooaX000Gooo]Z00?o0?o]oookJ_oonfX01Ooo
nfX00ol0hooooo]ZoookJP02oookJP03o`3oj?oonf[o087o00?ooo]Z00Koo`0;oooX0?oonf[o0?o`
oookJ_lY0?l3oookJP03oeT0oooonf[oo`2Z00Gooo]Z00Coo`d0oookJ_oonf[oK03o4ooonfX00ooo
0?Ko00?ooookJP06oookJP04o`3oMooonf[oN@3ooiOo00Oooo]Z00?ookl0oookJ_oonfX01ooonfX0
0ooo0?;ooo]ZoookJP02oookJP05ool0X?oonf[ooo]Zoe@0ool09Ol02OoonfX00omko`3ooo]Zoook
JP0FoookJP03ool0]Ooonf[ooo]Z05oooo]Z001ooookJP03o`3o2Ooonf[ooo]Z00Oooo]Z00?o00_o
oookJ_oonfX01?oonfX00on`o`3o0?_ooookJP04oookJP03odh0oooonf[ooo]Z00;ooo]Z0_oo01@<
oookJP03oonX0?oonf[ooo]Z00Cooo]Z0ooo8@0DoookJPCoogT01_oonfX9oolX00cooo]Z0ooo8@02
oookJP;oojP01_oo:002ool05005oookJ_oo003oo`00ool00?l0nol00ooo00001Ol02ooo=?l0og`0
oooonf[o0?l900;ooo]Z00?oobP0oonW0?oonfX00_oonfX00ooo6P3ooo]ZoookJP03oookJP03o`3o
kOoonf[ooo]Z00Cooo]Z00?o0>?ooookJ_oonfX00ooonfX00ol0onSo087ooookJP02oookJP06oolX
0?oonf[ooo]Zo`3ol?oo:03o:@3o0ooonfX00omI0?ooobP0oolX0002oolX00Cooo]Z00?oo`00oook
J_m/0?l04OoonfX7oolX00Cooo]Z00Go0?mgoookJ_oo003oUol0oookJP02ool000Cooo]Z00?oo`00
oookJ_oonfX01ooonfX00ooo0?;ooo]ZoookJP03oookJP04ool0X?oonf[oE03oo`0Uo`Oooo]Z1Ooo
000FoookJP03ool0]Ooonf[ooo]Z0=_ooo]Z00?o0?l9oookJ_oonfX01_oonfX00ol02ooooo]Zoook
JP04oookJP03ok3o0?oonf[o0?_o00Cooo]Z00?oCP3ooookJ_oonfX00ooonfX00ooo01Cooo]Zoook
JP0:oookJP03oonX0?oonf[ooo]Z00Cooo]Z0ooo8@000ooo0;Cooo]ZoookJP0`oookJP?oob400_oo
nfX3oonX00?ooo]Z0_ooa`02ool0500<oookJ_m>0?oooo]ZoookJ_l0nooo/?l0o`000?oo01So00_o
ocCo0?ml0?oooo]Z0_l0o`T2oookJP05oonW0?oonf[ooo]ZoookJ_oo6P001OoonfX00ol0ongooo]Z
oookJP05oookJP03o`3Soooonf[ooo]Z00;ooo]Z00?o0?oXo`3oUol0POl00_oonfX01_oo00_oonP0
oookJ_oonf[o0?o`obT0o`Cooo]Z00?oF@3oool0Z_oonfX01OoonfX00ooo3@3ooo]Zof`0o`0Doook
JP03ool0m_l00ooooo]Z00Gooo]Z00Co0?mgoookJ_mi0?ooUol01ooonfX00ooo_`3ooo]ZoookJP07
oookJP03ool0l_oonf[ooo]Z00?ooo]Z00Goo`2PoookJ_oonf[oE03oo`0Uo`08oookJP03og_o0?oo
nf[ooo]Z01Kooo]Z00?oo`2eoookJ_oonfX0GooonfX007kooo]Z00?o0?l9oookJ_oonfX01ooonfX0
0ol02ooooo]ZoookJP03oookJP;o/?l000?ooo]Zo`3koooonfX00ooonfX00om>0?oooo]ZoookJP02
oookJP03ool05?oonf[ooo]Z00[ooo]Z0_ooZ005oookJP;oob4000?oo`2doookJ_oonfX05?oonfX5
oomi00CoS_l03Ooo:00;oookJP03ool0]?oo8@3oob4000;ooo]Z0_ooZ003oookJP;oobP000CoolL0
ool05?oo01CoCP3o0_oo0002o`3ko`;oo`000_l02ol01oml0?oooo]Zo`3o2Ooonf[oobP0oookJ_oo
Y`000ooonfX00ooo6P3ooo]ZoookJP03oookJP03o`3okOoonf[ooo]Z00?ooo]Z00?o0>?ooookJ_oo
nfX01?oonfX00ol0onSo087ooookJP02oookJP06oolX0?oonf[oobP0o`3ol?oo:03o:@3o0ooonfX0
1?mI0?ooobP0oolX0?oo:004oookJP07ool00?oonf[ooo]Zof`0oooo003ooo]Zool0000=oookJPOo
obP01OoonfX00ooo:03oo`00ool00003ool000Cooo]Z00?oo`00oookJ_oonfX01ooonfX00ooo0?;o
oo]ZoookJP03oookJP04ool0X?oonf[oE03oo`0Uo`Oooo]Z1_oo000EoookJP03ool0]Ooonf[ooo]Z
0=[ooo]Z00?o0?l9oookJ_oonfX01_oonfX00ol02ooooo]ZoookJP03oookJP;o/?l00_oonfX01Ol0
nooooo]ZoookJ_oonf[oCP3o00Cooo]Z0_oo01@;oookJP;oojP01OoonfX2oolQ00;oo`2d6ooonfX:
ohko01;ooo]Z0_oo8@000ooo0;Cooo]ZoookJP02oonX00?ooo]Z0_ooa`02ool050;oCP3o00?ooo]Z
o`3kool0nol00_l00002o`0;o`04og`0oooonf[ooo]Zo`3o2@;ooo]Z00GoojL0oookJ_oonf[ooo]Z
oolJ0005oookJP03o`3okOoonf[ooo]Z00Cooo]Z00?o0>?ooookJ_oonfX00ooonfX00ol0onSo0?nG
o`21o`02oookJP06ool02oooj03ooo]Zo`3ol?oonf[o:@3o0ooonfX00omI0?oooo]Zool0ZP05oook
JP04ool=0?oonf[ooo]Zof`0o`;ooo]Z00?oH_l0oookJ_oonfX03_oonfX00ooo0?Ko00?ooookJP06
oookJP04o`3oMomi0?oooo]ZoiOo00Kooo]Z00?ookl0oookJ_oonfX01ooonfX00ooo0?;ooo]Zoook
JP03oookJP05ool0X?oonf[ooo]Zoe@0ool09Ol02OoonfX00omko`3ooo]ZoookJP0EoookJP03ool0
]Ooonf[ooo]Z05oooo]Z001moookJP03o`3o2Ooonf[ooo]Z00Oooo]Z00?o00_ooookJ_oonfX00ooo
nfX01?n`o`3ooo]ZoookJ_l0nol3oookJP;oCP3o1?oonfX00ooo01Cooo]ZoookJP0:oookJP03oonX
0?oonf[ooo]Z00Cooo]Z00?oob40ool0]?oonfX01_oonfX@ool000KoS_l01?ooN@0?oolX00cooo]Z
0_oo8@02oookJP;oojP01?oonfX02?ooa`3ooo]Zool05?oonf[oCP3oo`000?oo003o0?_o0ooo0000
0ol02oooO03ooookJP03oolX0003oookJ_ooY`3ooo]Z00;ooo]Z00?ooaX0oookJ_oonfX00ooonfX0
0ol0ongooo]ZoookJP03oookJP03o`3Soooonf[ooo]Z00?ooo]Z00?o0?oXo`3oUol0POl00_oonfX3
oolX0004o`3ol?oo:03oobP0obT0o`;ooo]Z00CoF@3ooookJ_oo:03oobP01?oonfX3ool00004of`0
oooo003ooo]Zool000kooo]Z1_oo:004oookJPOoo`001OoonfX00ooo003ooo]ZoookJP02ool000Co
oo]Z00?oo`3boookJ_oonfX00ooonfX01?oo0:3ooo]ZoookJ_mD0?l8oookJPGoo`005OoonfX00ooo
0;Gooo]ZoookJP3IoookJP03o`3o2Ooonf[ooo]Z00Kooo]Z00?o00_ooookJ_oonfX00ooonfX01On`
o`3ooo]ZoookJ_oonf[o0?_o00;ooo]Z0_m>0?l4oookJP03ool05?oonf[ooo]Z00[ooo]Z00?oojP0
oookJ_oonfX01?oonfX00ooo8@3oo`2dool0]00DoookJPWoS_l02_oonfX6ohko00kooo]Z0_oo8@00
0ooo0;Cooo]ZoookJP02oonX00?ooo]Z00GoolL0oookJ_oo01Cooo]Zodh0o`02o`000005o`3kool0
003ooo]Zool06?l02ol00_ml0?l01Ooonf[o0?l9oookJ_oonf[oojL000?ooo]Z00?ooaX0oookJ_oo
nfX00ooonfX00ol0ongooo]ZoookJP04oookJP03o`3Soooonf[ooo]Z00;ooo]Z00Oo0?oXoookJ_l0
oiOo087ooookJ_oo00_oonP000;ooo]Z00?o0?o`oookJ_lY0?l00ooonfX00omI0?ooo`2ZoookJP05
oookJP03ool=0?oonf[oK03o00;ooo]Z00?oH_l0oookJ_oonfX03_oonfX00ooo0?Kooo]Zo`03o`06
oookJP04o`3oMooonf[oN@3ooiOo00Oooo]Z00?ookl0oookJ_oonfX01ooonfX00ooo0?;ooo]Zoook
JP02oookJP05ool0X?oonf[ooo]Zoe@0ool09Ol02OoonfX00omko`3ooo]ZoookJP0FoookJP03ool0
]Ooonf[ooo]Z05kooo]Z001loookJP03o`3o2Ooonf[ooo]Z00Oooo]Z00?o00_ooookJ_oonfX00ooo
nfX01?n`o`3ooo]ZoookJ_l0nol3oookJP03odh0oooonf[ooo]Z00;ooo]Z0_oo01@;oookJP;oojP0
1OoonfX2oolQ00Wooo]Z3_oo0003oookJPWoogT04?oo:002ohko00_ooo]Z00Coob40ool0]?oonf[o
oo]Z0_ooZ003oookJP04ooo70?oonf[oo`0Dool050;oCP3o00?o0000o`3kool0nol00_oo00000ol0
2oooobP0oolX0002oolX00;ooo]Z00GoojL0oookJ_oonf[ooo]ZoolJ0003oookJP;oobP000?o0?o]
oookJ_oonfX00ooonfX00ol0hooooo]ZoookJP03oookJP03o`3oj?oonf[oobP000GoobP000?o0?o`
oolX0?lY0?l00ooonfX01OmI0?oooo]ZoolX0?oo:03ooo]Z00Koo`0000CoK03ooookJ_oonf[oo`00
3_oonfX5oolX00?ooo]Z2?oo0005oookJPGoo`001?oonfX00ooo0?;ooo]ZoookJP03oookJP05ool0
X?oonf[ooo]Zoe@0oooo:0002?oonfX4ool001Gooo]Z00?oo`2eoookJ_oonfX0f?oonfX00ol0o`Wo
oo]ZoookJP06oookJP03o`0;oooonf[ooo]Z00?ooo]Z00Go/?l0oookJ_oonf[ooo]Zo`3ko`02oook
JP03odh0oooonf[ooo]Z00?ooo]Z00?oo`0DoookJ_oonfX02OoonfX2oonX00Gooo]Z0_oo8@000ooo
0;Cooo]ZoookJP0?oookJPGoS_l01?oonfXBo`3o`0?ooo]Z1On>o`0;oookJP;oob4000?oo`2doook
J_oonfX00_ooZ002oookJP04ooo70?oonf[oo`0Dool050;oCP3o00[o0000o`3kool0nooooo]Zool0
6?l02ooo02goog`0oooonf[o0?l90_oonfX01OooY`3ooo]ZoookJ_oonf[ooaX000Gooo]Z00?o0?o]
oookJ_oonfX01?oonfX00ol0hooooo]ZoookJP02oookJP07o`3oj?l0oiOooo]Zo`21oooonf[oo`0;
oooX0002oookJP03o`3ol?lY0?oooo]Z00?ooo]Z00?oF@3oool0Z_oonfX01?oonfX01?oo3@3ooo]Z
oookJ_m/0?l2oookJP03of;o0?oonf[ooo]Z00kooo]Z00?oo`3fo`03oooonfX01OoonfX01?l0ogOo
oo]ZogT0oonGo`07oookJP03oono0?oonf[ooo]Z00Oooo]Z00?oo`3boookJ_oonfX00_oonfX01_oo
0:3ooo]ZoookJ_oonf[oE03oo`0Uo`Sooo]Z00?oNol0oookJ_oonfX05_oonfX00ooo0;Gooo]Zoook
JP1NoookJP00O?oonfX00ol0o`Wooo]ZoookJP06oookJP03o`0;oooonf[ooo]Z00?ooo]Z00Co/?l0
oookJ_oonf[o0?_o0ooonfX00om>0?oooo]ZoookJP02oookJP03ool05?oonf[ooo]Z00Wooo]Z0_oo
Z006oookJP03oolQ0?oo0;Cooo]Z00Wooo]Z3?oo00000ooonf[o0?o0o`3o`002o`3o`0KoogT03Ooo
00L6o`3o`0;ooo]Z1?n>o`02oookJP;oogT01?oonfX2oolQ0004ool0]?oonf[ooo]ZoonX00?ooo]Z
0_ooa`001?oonf[oo`0Dool05?m>0?l2o`000004o`3koooo003oobP0o`0;o`CoobP00_oonfX01_oo
Y`3ooo]ZoookJ_oonf[ooaX0oookJP?oobP000?o0?o]oookJ_oonfX01?oonfX00ol0hooooo]Zoook
JP03oookJP03o`3oj?oo:03oobP000GoobP000?o0?o`oookJ_lY0?l00_oonfX01?mI0?oooo]Zoook
J_oo:007ool00004of`0oooo003ooo]Zool000oooo]Z1?oo:003oookJPSoo`000ooonfX7ool000Go
oo]Z00?oo`3boookJ_oonfX00ooonfX01?oo0:3ooo]Zoe@0oooo:008oookJPCoo`005OoonfX00ooo
0;Gooo]ZoookJP3HoookJP03o`3o2Ooonf[ooo]Z00Gooo]Z00?o00_ooookJ_oonfX00ooonfX01On`
o`3ooo]ZoookJ_oonf[o0?_o00;ooo]Z00?oCP3ooookJ_oonfX00_oonfX2ool050[ooo]Z0_ooZ006
oookJP03oolQ0?oo0;Cooo]Z00kooo]Z1?n>o`04oookJPGo0?o01OoonfX=ool01`Ko0?o00_oonfX4
ohko00Wooo]Z0_oo8@001?oo0;Cooo]ZoookJ_ooZ002oookJP;oolL000Cooo]Zool05?oo01CoCP3o
0_l000002?l0nooooo]Zool06?l02ooo02goog`0oooonf[o0?l90_oonfX01OooY`3ooo]ZoookJ_oo
nf[ooaX000Cooo]Z00?o0?o]oookJ_oonfX01?oonfX00ol0hooooo]ZoookJP03oookJP03o`3oj?l0
oiOo087o00;ooo]Z00Koo`0;oooX0?oonf[o0?o`oookJ_lY0?l3oookJP03oeT0oooonf[oo`2Z00Go
oo]Z00?oo`d0oookJ_m/0?l00_oonfX00omRo`3ooo]ZoookJP0>oookJP03ool0m_oonf[o00?o00Ko
oo]Z00?o0?mgogT0oonGo`001ooonfX00ooo_`3ooo]ZoookJP07oookJP03ool0l_oonf[ooo]Z00?o
oo]Z00Goo`2PoookJ_oonf[oE03oo`0Uo`09oookJP03og_o0?oonf[ooo]Z01Gooo]Z00?oo`2eoook
J_oonfX0G_oonfX007_ooo]Z00?o0?l9oookJ_oonfX01_oonfX00ol02ooooo]ZoookJP03oookJP04
ok3o0?oonf[ooo]Zo`3ko`?ooo]Z00?oCP3ooookJ_oonfX00_oonfX00ooo01Cooo]ZoookJP09oook
JP03oonX0?oonf[ooo]Z00Cooo]Z0_oo8@0=oookJPWoo`000ol0ol02oookJPSoo`070oooN@0:oook
JPSoo`070_l0ol02oookJP;oS_l00oooN@05oookJP;oob4000Coo`2doookJ_ooZ03oojP00ooonfX0
1Oooa`3o0000o`000?oo01CoCP3o00;ooo]Z0ooo:0000ol02oooobP0oolX0002oolX00;ooo]Z00?o
ojL0oookJ_oonfX01_oo:0000ol0ongooo]ZoookJP03oookJP03o`3Soooonf[ooo]Z00Cooo]Z00?o
0?oXoolX0?oo:0001?oo:0000ol0oo3oobP0obT0o`03oookJP03oeT0oooonf[oo`2Z00Ooo`0000Co
K03oool00?oonf[oo`003ooonfX4oolX00Cooo]Z1ooo0002oookJPSoo`001OoonfX00ooo0?;ooo]Z
oookJP03oookJP04ool0X?oonf[ooo]Zoe@0o`Wooo]Z0ooo000FoookJP03ool0]Ooonf[ooo]Z0=Ko
oo]Z00?o0?l9oookJ_oonfX01OoonfX00ol02ooooo]ZoookJP03oookJP05ok3o0?oonf[ooo]Zoook
J_l0nol00_oonfX00om>0?oooo]ZoookJP02oookJP03ool05?oonf[ooo]Z00Wooo]Z00?oojP0oook
J_oonfX01?oonfX2oolQ00oooo]Z0_n>o`04oookJPCo0?o00ooonfX7ool01`gooo]Z2?oo00L3o`3o
`003oookJ_n>o`3oS_l000;oS_l01ooonfX2oolQ00;ooo]Z0_ooZ002oookJP05ooo70?l0003o0000
ool05?m>0?l00_oonfX02?l0nooooo]ZoookJ_l02ooo02goog`0oooonf[o0?l90_oonfX01OooY`3o
oo]ZoookJ_oonf[ooaX000Cooo]Z00?o0?o]oookJ_oonfX01?oonfX00ol0hooooo]ZoookJP03oook
JP06o`3oj?l0oiOo087ooookJ_oo00_oonP00_oonfX00ol0oo3o:@3ooookJP03oookJP03oeT0oooo
0:[ooo]Z00Cooo]Z00?oo`d0oookJ_m/0?l00_oonfX00omRo`3ooo]ZoookJP0?oookJP03ool0m_l0
0ooooo]Z00Gooo]Z00Co0?mgoookJ_mi0?ooUol01ooonfX00ooo_`3ooo]ZoookJP07oookJP03ool0
l_oonf[ooo]Z00;ooo]Z00Goo`2PoookJ_oonf[oE03oo`0Uo`09oookJP03og_o0?oonf[ooo]Z01Go
oo]Z00?oo`2eoookJ_oonfX0G_oonfX007[ooo]Z00?o0?l9oookJ_oonfX01ooonfX00ol02ooooo]Z
oookJP03oookJP03ok3o0?oonf[o0?_o00Cooo]Z00GoCP3ooookJ_oonf[ooo]Zool0500:oookJP;o
ojP01OoonfX00ooo0;Coob40oookJP0>oookJPOoo`0000Co0?o0oookJ_oonf[ooo]Z0ooo00L2oook
JPKoogT05OoonfX4ool01`03o`3o`?ooN@3oogT000?oogT000?oS_l0oookJ_oonfX00ooonfX2oolQ
0004ool0]?oonf[oojP0oonX00;ooo]Z0_ooa`000ol0003oo`0Dodh0o`05oolX0004o`0;oooo:03o
obP0oolX00?ooo]Z00?oojL0oolX0?oo:0001Ooo:0000ooonf[o0?o]oookJP04oookJP03o`3Soooo
nf[ooo]Z00?ooo]Z00?o0?oXoolX0?oo:0001Ooo:0000ol0oo3ooo]ZobT0o`03oookJP03oeT0oooo
nf[oo`2Z00Ooo`0000CoK03ooookJ_oonf[oo`000_oonfX2ool000_ooo]Z1?oo:004oookJPKoo`00
0_oonfX8ool000Gooo]Z00?oo`3boookJ_oonfX00ooonfX00ooo0:3ooo]ZoookJP02oolX00Sooo]Z
0ooo000FoookJP03ool0]Ooonf[ooo]Z0=Gooo]Z00?o0?l9oookJ_oonfX01_oonfX00ol02ooooo]Z
oookJP03oookJP04ok3o0?oonf[ooo]Zo`3ko`?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool0500:oook
JP;oojP01OoonfX00ooo0;Coob40oookJP0CoookJP?o0?o01?oonfX3ool01acooo]Z1?oo00L2o`3o
`0;ooo]Z0on>o`06oookJP;oob400_oonfX00oooZ03ooo]ZoookJP02ooo70006o`000?oo01CoCP3o
odh0oooonf[o0?_o0_oonfX01Ol02ooo02goog`0oooonf[o0?l900;ooo]Z00CoojL0oookJ_oonf[o
oaX01OoonfX00ol0ongooo]ZoookJP04oookJP03o`3Soooonf[ooo]Z00;ooo]Z00Oo0?oXo`3oUooo
nf[o087ooookJ_oo00_oonP000;ooo]Z00?o0?o`obT0oooonfX00ooonfX00omI0?ooo`2ZoookJP04
oookJP03ool=0?oonf[oK03o00;ooo]Z00?oH_l0oookJ_oonfX03_oonfX00ooo0?Ko00?ooookJP05
oookJP04o`3oMooonf[oN@3ooiOo00Oooo]Z00?ookl0oookJ_oonfX01ooonfX00ooo0?;ooo]Zoook
JP02oookJP05ool0X?oonf[ooo]ZoookJ_mD0?l02OoonfX00omko`3ooo]ZoookJP0FoookJP03ool0
]Ooonf[ooo]Z05gooo]Z001ioookJP03o`3o2Ooonf[ooo]Z00Oooo]Z00?o00_ooookJ_oonfX00ooo
nfX00on`o`3ooo]Zo`3ko`04oookJP05odh0oooonf[ooo]ZoookJ_oo01@02_oonfX00oooZ03ooo]Z
oookJP04oookJP03ool0]?oo8@3ooo]Z00oooo]Z1_oo0002oookJP?oo`071OoonfX2oomi01gooo]Z
00?oo`07oomi0?ooN@001OooN@000on>o`3ooo]ZoookJP03oookJP;oob4000Coo`2doookJ_ooZ03o
oo]Z0_l000001Oooa`3o0000ool05?oonf[oCP3o00CoobP000Co00_ooolX0?oo:03oobP00_oonfX0
0ooo:03oojL0oolX0006oolX0003o`3okOoonf[ooo]Z00Cooo]Z00Co0>?ooookJ_oonf[ooo]Z0_oo
:0000ol0onSoobP0oolX0004oolX0004o`3ol?oonf[ooo]ZobT0o`;ooo]Z00CoF@3ooookJ_oo0:[o
oo]Z1_oo00000om/0?oooo]ZoookJP05ool000cooo]Z0ooo:004oookJPKoo`000ooonfX7ool000Ko
oo]Z00?oo`3boookJ_oonfX00_oonfX00ooo0:3ooo]ZoookJP02oolX00Wooo]Z0_oo000FoookJP03
ool0]Ooonf[ooo]Z0=Cooo]Z00?o0?l9oookJ_oonfX01_oonfX00ol02ooooo]ZoookJP03oookJP04
ok3o0?oonf[ooo]Zo`3ko`?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool0500:oookJP03oonX0?oonf[o
oo]Z00Cooo]Z00?oo`2doolQ0?oonfX04_oonfX2o`3o`0Cooo]Z0ooo00LSoookJPCoo`0700?o0?o0
oookJ_oonfX00_n>o`06oookJP;oob4000?ooo]ZoonX0?oonfX00_l000001_ooa`3o0000ool05?oo
nf[oCP3ooookJP;o0?_o00Kooo]Zo`0;oooonf[oO03ooookJ_l0o`T2oookJP04oonW0?oonf[ooo]Z
oolJ00Gooo]Z00?o0?o]oookJ_oonfX00ooonfX00ol0hooooo]ZoookJP03oookJP03o`3oj?l0oiOo
087o00;ooo]Z00KoonP0oookJ_oonf[o0?o`oookJ_lY0?l3oookJP03oeT0oooo0:[ooo]Z00Cooo]Z
00?oo`d0oookJ_m/0?l00_oonfX00omRo`3ooo]ZoookJP0>oookJP03ool0m_oonf[o00?o00Kooo]Z
00?o0?mgogT0oonGo`001ooonfX00ooo_`3ooo]ZoookJP07oookJP03ool0l_oonf[ooo]Z00;ooo]Z
00Koo`2PoookJ_oonf[ooo]Zoe@0ool09Ol9oookJP03og_o0?oonf[ooo]Z01Gooo]Z00?oo`2eoook
J_oonfX0GOoonfX007Wooo]Z00?o0?l9oookJ_oonfX01_oonfX00ol02ooooo]ZoookJP03oookJP03
ok3o0?oonf[o0?_o00Cooo]Z00?oCP3ooookJ_oonfX00_oonfX00ooo01Cooo]ZoookJP07oookJP03
oonX0?oonf[ooo]Z00Cooo]Z0_oo8@0BoookJP?oo`0000Cooo]Zool01ooo00Ooo`079ooonfX9oomi
0003ohko0?oonf[ooo]Z00Cooo]Z0_oo8@000ooo0;CoojP0oonX0002o`000005ooo70?oonf[oo`0D
oookJ_m>0?l01?oo:0001?l02oooobP0oolX0?l0o`T3oookJP03oonW0?oo:03oobP000CoobP000?o
oo]Zo`3okOoonfX01?oonfX01?l0hooooo]ZoookJ_oonfX2oolX0003o`3oj?oo:03oobP000GoobP0
00?o0?o`oookJ_lY0?l00ooonfX01?mI0?oooo]Zool0Z_oonfX6ool00003of`0oooo003oo`0000Co
o`003OoonfX2oolX00Gooo]Z1Ooo0004oookJPKoo`001_oonfX00ooo0?;ooo]ZoookJP02oookJP03
ool0X?oonf[ooo]Z00;oobP02_oonfX00ooo003ooo]ZoookJP0DoookJP03ool0]Ooonf[ooo]Z0=Co
oo]Z00?o0?l9oookJ_oonfX01OoonfX00ol02ooooo]ZoookJP03oookJP04ok3o0?oonf[ooo]Zo`3k
o`?ooo]Z00?oCP3ooookJ_oonfX00_oonfX00ooo01Cooo]ZoookJP07oookJP03oonX0?oonf[ooo]Z
00Cooo]Z0_oo8@0CoookJP04o`3o`?oonf[ooo]ZoookJP?oo`07:_oonfX3ool01`04o`3o`?oonf[o
S_l0ohko00Kooo]Z00Coob40ool0]?ooZ03oojP00_l000001?ooa`3ooo]Zool05?oo01@2odh0o`05
ok3o0?l0nooooo]Zo`0;ooml0?l00_oonfX01?l0o`Wooo]ZoookJ_ooY`02oookJP03oolJ0?oonf[o
oo]Z00;ooo]Z00?o0?o]oookJ_oonfX01?oonfX00ol0hooooo]ZoookJP03oookJP06o`3oj?l0oiOo
087ooookJ_oo00_oonP00_oonfX00ol0oo3o:@3ooookJP03oookJP03oeT0oooo0:[ooo]Z00Cooo]Z
00?oo`d0oookJ_m/0?l00_oonfX00omRo`3ooo]ZoookJP0>oookJP03ool0m_l00ooooo]Z00Gooo]Z
00Co0?mgoookJ_mi0?ooUol01ooonfX00ooo_`3ooo]ZoookJP07oookJP05ool0l_oonf[ooo]Zoook
J_oo0:000ooonfX00omD0?oo02GooookJP08oookJP03og_o0?oonf[ooo]Z01Gooo]Z00?oo`2eoook
J_oonfX0GOoonfX007Sooo]Z00?o0?l9oookJ_oonfX01ooonfX00ol02ooooo]ZoookJP02oookJP04
ok3o0?oonf[ooo]Zo`3ko`?ooo]Z00?oCP3ooookJ_oonfX00_oonfX00ooo01Cooo]ZoookJP08oook
JP03oonX0?oonf[ooo]Z00?ooo]Z00?oob40oookJ_oonfX04OoonfX00ol0ol3oo`00ool01`02ool0
1b[ooo]Z2_ooN@02ohko00Kooo]Z00Coob40ool0]?l0003oojP00_l00002ooo70004ool05?oonf[o
oo]Zodh0o`?oobP000Co00_ooolX0?oo:03o0?l90ooonfX00oooY`3oobP0oolX0003oolX00;ooo]Z
00?o0?o]oookJ_oonfX00ooonfX01?l0hooooo]ZoookJ_oonfX2oolX0003o`3oj?oo:03oobP000Go
obP000?o0?o`oookJ_lY0?l00_oonfX00omI0?oooo]Zool0ZP02oookJPGoo`0000?oK03oool00?oo
00001?oo000=oookJP03ool0m_oo:03ooo]Z00Cooo]Z1_oo0003oookJPKoo`001_oonfX00ooo0?;o
oo]ZoookJP03oookJP04ool0X?oonf[oobP0oolX00[ooo]Z00?oNol0oookJ_oonfX05OoonfX00ooo
0;Gooo]ZoookJP3BoookJP03o`3o2Ooonf[ooo]Z00Kooo]Z00?o00_ooookJ_oonfX00ooonfX00on`
o`3ooo]Zo`3ko`03oookJP03odh0oooonf[ooo]Z00;ooo]Z00?oo`0DoookJ_oonfX02?oonfX00ooo
Z03ooo]ZoookJP03oookJP03oolQ0?oonf[ooo]Z017ooo]Z0_l0ol001?oonf[oo`07ool01ooo00L`
oookJP;oo`0700?o0?o0oookJ_n>o`001_oonfX2oolQ0004o`000?ooZ03o0000o`0000;oolL000Wo
oo]Zool05?oonf[oCP3ooookJ_l0nooooo]Zo`0;ooml0?l00_oonfX01?l0o`Wooo]ZoookJ_ooY`02
oookJP03oolJ0?oonf[ooo]Z00;ooo]Z00?o0?o]oookJ_oonfX00ooonfX00ol0hooooo]ZoookJP03
oookJP03o`3oj?l0oiOo087o00;ooo]Z00KoonP0oookJ_oonf[ooo]Zo`3ol?lY0?l3oookJP03oeT0
oooo0:[ooo]Z00Cooo]Z00?oo`d0oookJ_m/0?l00_oonfX00omRo`3ooo]ZoookJP0>oookJP03ool0
m_oonf[o00?o00Gooo]Z00Co0?mgoookJ_mi0?ooUol01ooonfX00ooo_`3ooo]ZoookJP07oookJP03
ool0l_oonf[ooo]Z00;ooo]Z00Goo`2PoookJ_oonf[oE03oo`0Uo`09oookJP03og_o0?oonf[ooo]Z
01Gooo]Z00?oo`2eoookJ_oonfX0GOoonfX007Oooo]Z00?o0?l9oookJ_oonfX01ooonfX00ol02ooo
oo]ZoookJP03oookJP03ok3o0?oonf[o0?_o00Cooo]Z00GoCP3ooookJ_oonf[ooo]Zool0500:oook
JP03oonX0?oonf[ooo]Z00?ooo]Z00?oob40oookJ_oonfX04?oonfX2o`3o`003oookJ_oo00Oooo]Z
02_ooo]Z3OooN@02ohko00Gooo]Z0_oo8@000ooo003oojP0oonX0002oookJP06ooo70?oo01Cooo]Z
oookJ_m>0?oo0?_o0_oo:0001?l02oooobP0oookJ_l0o`T3oookJP03oonW0?oo:03oobP000?oobP0
0_oonfX00ol0ongooo]ZoookJP03oookJP06o`3Soooonf[ooo]ZoookJ_oo:03o0?oX1ooo:0000ol0
oo3ooo]ZobT0o`03oookJP03oeT0oooo0:[ooo]Z00;ooo]Z1Ooo00000om/0?ooo`00ool00003ool0
00gooo]Z00?oo`3fo`03oooonfX01OoonfX5ool000Cooo]Z1Ooo0006oookJP03ool0l_oonf[ooo]Z
00?ooo]Z00Coo`2PoookJ_oonf[oobP02_oonfX00omko`3ooo]ZoookJP0EoookJP03ool0]Ooonf[o
oo]Z0=7ooo]Z00?o0?l9oookJ_oonfX01_oonfX00ol02ooooo]ZoookJP03oookJP03ok3o0?oonf[o
0?_o00Cooo]Z00GoCP3ooookJ_oonf[ooo]Zool0500:oookJP03oonX0?oonf[ooo]Z00?ooo]Z00?o
ob40oookJ_oonfX04?oonfX2o`3o`003oookJ_oo00Ooo`0703Gooo]Z0_oo00L00ol0ol3oS_l0ohko
0006oookJP;oob400_ooZ002oookJP0:ooo70?oonf[oo`0DoookJ_m>0?oooo]Zo`3koooo01So00_o
og`0o`;ooo]Z00Co0?l9oookJ_oonf[oojL00_oonfX00ooo6P3ooo]ZoookJP02oookJP03o`3okOoo
nf[ooo]Z00?ooo]Z00?o0>?ooookJ_oonfX00ooonfX01_l0onSo0?nGo`21oooonf[oo`0;oooX00;o
oo]Z00?o0?o`obT0oooonfX00_oonfX00omI0?ooo`2ZoookJP05oookJP05ool=0?oonf[oK03ooook
J_mRo`004?oonfX00ooo0?Kooo]Zo`03o`05oookJP04o`3oMooonf[ooo]ZogT0o`Oooo]Z00?ookl0
oookJ_oonfX01ooonfX00ooo0?;ooo]ZoookJP02oookJP05ool0X?oonf[ooo]ZoookJ_mD0?l02Ooo
nfX00omko`3ooo]ZoookJP0FoookJP03ool0]Ooonf[ooo]Z05cooo]Z001goookJP03o`3o2Ooonf[o
oo]Z00Kooo]Z00?o00_ooookJ_oonfX00ooonfX00on`o`3ooo]Zo`3ko`04oookJP05odh0oooonf[o
oo]ZoookJ_oo01@02_oonfX00oooZ03ooo]ZoookJP02oookJP;oo`2d00?oob40oookJ_oonfX03ooo
nfX01?l0ol3ooo]Zool01ooo00LaoookJP[oogT000?ooo]Zohko0?oonfX00ooonfX2ool000;oob40
00Ko0000oonX0?oonf[ooo]Zooo70?oo01@2oookJP08odh0ool0noooobP0oolX0?l02oooobP0oook
J_l0o`T3oookJP03oonW0?oo:03oobP000;oobP00_oonfX00ol0ongooo]ZoookJP04oookJP06o`3S
oooonf[ooo]ZoookJ_oo:03o0?oX1ooo:0000ol0oo3ooo]ZobT0o`02oookJP03oeT0oooonf[oo`2Z
00;ooo]Z1Ooo00000om/0?ooo`00ool00004ool000gooo]Z00?o00?ooookJ_oonfX01OoonfX4ool0
00Cooo]Z1_oo0006oookJP03ool0l_oonf[ooo]Z00;ooo]Z00?oo`2PoookJ_oonfX00_oo:009oook
JP03og_o0?oonf[ooo]Z01Gooo]Z00?oo`2eoookJ_oonfX0dOoonfX00ol0o`Wooo]ZoookJP06oook
JP03o`0;oooonf[ooo]Z00;ooo]Z00?o/?l0oookJ_l0nol01?oonfX01Om>0?oooo]ZoookJ_oonf[o
o`0D00[ooo]Z00?oojP0oookJ_oonfX00ooonfX00ooo0;Coob40oookJP0@oookJP04o`3o`?oonf[o
oo]Zool01cWooo]Z0_oo00L00ol0ol3oS_l0ohko0004oookJP;o000000?oob40o`000?ooZ0000_oo
nfX02_ooa`3ooo]Zool05?oonf[oCP3ooookJ_l0noooo`0Ho`0;ooml0?l2oookJP04o`3o2Ooonf[o
oo]ZoonW00;ooo]Z00?ooaX0oookJ_oonfX00_oonfX00ol0ongooo]ZoookJP03oookJP03o`3Soooo
nf[ooo]Z00;ooo]Z00Ko0?oXoookJ_l0oiOo087ooookJ_ooj003oookJP03o`3ol?lY0?oooo]Z00;o
oo]Z00?oF@3oool0Z_oonfX01?oonfX00ooo3@3ooo]Zof`0o`02oookJP03of;o0?oonf[ooo]Z00ko
oo]Z00?oo`3fo`03oooonfX01OoonfX00ol0ogOooo]ZogT0o`08oookJP03oono0?oonf[ooo]Z00Oo
oo]Z00Goo`3boookJ_oonf[ooo]Zool0X003oookJP03oe@0oooonf[ooo]Z00Oooo]Z00?oNol0oook
J_oonfX05_oonfX00ooo0;Gooo]ZoookJP1LoookJP00M_oonfX00ol0o`Wooo]ZoookJP07oookJP03
o`0;oooonf[ooo]Z00;ooo]Z00?o/?l0oookJ_l0nol01?oonfX01Om>0?oooo]ZoookJ_oonf[oo`0D
00[ooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo0;Cooo]ZoolQ000@oookJP;o0?o00_oo00Lhoook
JPKoogT000Co0?o0ohko0?n>o`3ooo]Z1Ooo00000ooo8@3ooo]ZoonX0002oookJP0?ooo70?oo01Co
oo]Zodh0oooonf[o0?_oool06?oo:03o00_ooolX0?oonf[o0?l9oookJ_oo:03oojL000GoobP00_oo
nfX00ol0ongooo]ZoookJP03oookJP03o`3Soooonf[ooo]Z00;ooo]Z00?o0?oXoolX0?oo:0001Ooo
:0002?l0oo3ooo]ZoookJ_lY0?oooo]ZoeT0oooonf[oo`2Z0ooonfX5ool00003of`0oooo003oo`00
00?oo`003OoonfX00ooo0?Ko00?ooookJP03oookJP;oobP01?oo0005oookJPGoo`001_oonfX00ooo
0?;ooo]ZoookJP02oookJP03ool0X?oonf[ooo]Z00;oobP02OoonfX00omko`3ooo]ZoookJP0Eoook
JP03ool0]Ooonf[ooo]Z0=3ooo]Z00?o0?l9oookJ_oonfX01_oonfX00ol02ooooo]ZoookJP03oook
JP03ok3o0?l0nooooo]Z00?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool0500:oookJP03oonX0?oonf[o
oo]Z00?ooo]Z00?oo`2doolQ0?oonfX03ooonfX2o`3o`003oookJ_oo00Ooo`0703cooo]Z0_oo00L0
0ol0ol3oS_l0ohko0002oookJP?o00000_oo8@001oooZ03ooo]ZoookJ_ooa`3ooo]Zool05?m>0?l0
0_oonfX01?l0noooo`0Ho`0;ooml0?l2oookJP03o`3o2Ooonf[oojL000;ooo]Z00?ooaX0oookJ_oo
nfX00ooonfX00ol0ongooo]ZoookJP02oookJP03o`3Soooonf[ooo]Z00?ooo]Z00?o0?oXo`3oUol0
POl00_oonfX01_ooj03ooo]ZoookJ_l0oo3ooo]ZobT0o`;ooo]Z00?oF@3oool0Z_oonfX01OoonfX0
1Ooo3@3ooo]Zof`0oooonf[oH_l0013ooo]Z00?oo`3foookJ_l00ol01OoonfX01?l0ogOooo]ZogT0
oonGo`07oookJP03oono0?oonf[ooo]Z00Oooo]Z00Goo`3boookJ_oonf[ooo]Zool0X003oookJP03
oe@0oooonf[ooo]Z00Oooo]Z00?oNol0oookJ_oonfX05_oonfX00ooo0;Gooo]ZoookJP1LoookJP00
MOoonfX00ol0o`Wooo]ZoookJP07oookJP03o`0;oooonf[ooo]Z00?ooo]Z00?o/?l0o`3koooonfX0
0ooonfX00om>0?oooo]ZoookJP02oookJP03ool05?oonf[ooo]Z00Oooo]Z00?oojP0oookJ_oonfX0
0_oonfX00ooo0;Cooo]ZoolQ000?oookJP;o0?o000?ooo]Zool01ooonfX0;_oonfX2oomi00kooo]Z
0_ooN@000ooo00Oo0?o0ohko0006ool00003oolQ0?oonf[oojP000;ooo]Z00[oolL0ool05?oonf[o
CP3oo`3koon`o`3oo`0HoookJ_l02ooooo]Z1?oo:0000oooY`3ooo]ZoolX0002oolX00?ooo]Z00?o
0?o]oookJ_oonfX00ooonfX00ol0hooooo]ZoookJP02oookJP03o`3oj?oo:03oobP000CoobP000Co
oo]Zo`3ol?oonf[o:@3o0_oonfX00omI0?oooo]Zool0ZP03oookJP?oo`0000?ooo]Zof`0oooo0000
1?oo000=oookJP04ool0m_l00ooooo]ZoookJPGoobP00ooo0006oookJPCoo`000ooonfX01?oo003o
oo]ZoookJ_oo0?85oookJP04ool0X?oonf[oobP0oolX00Wooo]Z00?oNol0oookJ_oonfX05OoonfX0
0ooo0;Gooo]ZoookJP3?oookJP03o`3o2Ooonf[ooo]Z00Kooo]Z00?o00_ooookJ_oonfX00ooonfX0
0on`o`3o0?_ooookJP03oookJP03odh0oooonf[ooo]Z00;ooo]Z00?oo`0DoookJ_oonfX01ooonfX0
0oooZ03ooo]ZoookJP03oookJP03ool0]?oo8@3ooo]Z00kooo]Z0_l0ol000ooonf[oo`07ool01`10
oookJP;oo`0700?o0?o0ohko0?oonfX01?l000000ooo0;Coob40oonX0002oookJP;oolL000Soo`0D
odh0oooonf[o0?_ook3o0?oo01So00_oog`0o`;ooo]Z00?o0?l9oookJ_ooY`000_oonfX00ooo6P3o
oo]ZoookJP02oookJP03o`3okOoonf[ooo]Z00?ooo]Z00?o0>?ooookJ_oonfX00ooonfX01_l0onSo
0?nGo`21oooonf[oo`0;oooX00;ooo]Z00?o0?o`obT0oooonfX00_oonfX00omI0?ooo`2ZoookJP04
oookJP03ool=0?oonf[oK03o00;ooo]Z00?oH_l0oookJ_oonfX03OoonfX00ooo0?Kooo]Zo`03o`05
oookJP04o`3oMooonf[ooo]ZogT0o`Oooo]Z00?ookl0oookJ_oonfX00ooonfX01Ol0ob7ooo]Zoook
J_oonf[oo`3b00Cooo]Z00Goo`2PoookJ_oonf[oE03oo`0Uo`09oookJP03og_o0?oonf[ooo]Z01Go
oo]Z00?oo`2eoookJ_oonfX0G?oonfX007Cooo]Z00?o0?l9oookJ_oonfX01ooonfX00ol02ooooo]Z
oookJP03oookJP03ok3o0?l0nooooo]Z00Cooo]Z00GoCP3ooookJ_oonf[ooo]Zool05009oookJP03
oonX0?oonf[ooo]Z00;ooo]Z00?oo`2doookJ_oo8@003ooonfX01?l0ol3ooo]Zool01ooo00L`oook
JP?oogT04?oonfX01?oo00Oo0?o0ohko0?n>o`05ool00003oolQ0?oonf[oojP000;ooo]Z00WoolL0
ool05?oonf[oCP3oo`3koon`o`3oo`0HoookJ_l02ol01Ooo:0000oooY`3ooo]ZoolX0002oolX00;o
oo]Z00?o0?o]oookJ_oonfX01?oonfX00ol0hooooo]ZoookJP02oookJP05o`3oj?oo:03oobP0oolX
0?oonfX00_oo:0002?l0oo3ooo]ZoookJ_lY0?oooo]ZoeT0oooonf[oo`2Z1?oonfX4ool00003of`0
oooo003oo`0000;oo`003OoonfX01?oo0?Ko00?ooookJ_oonfX5oolX00?oo`001_oonfX4ool000?o
oo]Z00Goo`00oookJ_oonf[ooo]Zool0lP04oookJP04ool0X?oonf[oobP0oolX00[ooo]Z00?oNol0
oookJ_oonfX05OoonfX00ooo0;Gooo]ZoookJP3=oookJP03o`3o2Ooonf[ooo]Z00Oooo]Z00?o00_o
oookJ_oonfX00_oonfX00on`o`3o0?_ooookJP04oookJP05odh0oooonf[ooo]ZoookJ_oo01@02_oo
nfX00oooZ03ooo]ZoookJP02oookJP03ool0]?oo8@3ooo]Z00kooo]Z00Co0?o0oookJ_oonf[oo`07
A?oonfX01Ooo00Oo0?o0ohko0?n>o`3o000000;o0?nG0_oonfX00ooo8@3oojP0oonX0002oookJP0;
ool05?oonf[oCP3ooookJ_l0nooo/?l0ool06?l02oooO03ooookJ_l0o`T00_oonfX01?ooY`3ooo]Z
oookJ_oo6P04oookJP03o`3okOoonf[ooo]Z00?ooo]Z00?o0>?ooookJ_oonfX00_oonfX00ol0onSo
oo]Zo`21o`02oookJP06oooX0?oonf[ooo]Zo`3ol?oonf[o:@3o0_oonfX00omI0?ooo`2ZoookJP05
oookJP05ool=0?oonf[oK03ooookJ_mRo`003ooonfX00ooo0?Kooo]Zo`03o`06oookJP03o`3oMooo
nf[oN@3o00Sooo]Z00?ookl0oookJ_oonfX00_oonfX00ol0ob7ooo]ZoookJP02oookJP05ool0l_oo
nf[ooo]ZoookJ_oo0:000_oonfX00omD0?oo02GooookJP08oookJP03og_o0?oonf[ooo]Z01Kooo]Z
00?oo`2eoookJ_oonfX0FooonfX007Cooo]Z00?o0?l9oookJ_oonfX01_oonfX00ol02ooooo]Zoook
JP03oookJP03ok3o0?l0nooooo]Z00Cooo]Z00GoCP3ooookJ_oonf[ooo]Zool05009oookJP03oonX
0?oonf[ooo]Z00;ooo]Z00?oo`2doookJ_oo8@003ooonfX00ol0ol3ooo]Zool01`0VoookJP03oomi
0?mi0?ooN@3o00KoN@3o0ooonfX5oomi00oooo]Z0_oo00L00ol0ol3oS_l0ool00004ool00003oolQ
0?oonf[oojP000;ooo]Z00GoolL0ool05?oonf[oCP3oo`3ko`02oolX0003o`0;ooml0?ooobP000?o
obP000?ooo]ZoonW0?oonfX00_oo:003oookJP03o`3okOoonf[ooo]Z00?ooo]Z00?o0>?ooookJ_oo
nfX00_oonfX02ol0onSoobP0oolX0?oo:03ooo]Zool02ooo:03ooo]Zo`3ol?oonf[o:@3o00;ooo]Z
00?oF@3ooookJ_oo0:X01?oonfX2ool00003oookJ_m/0?ooo`0000?oo`003_oonfX01?l00ooooo]Z
oookJ_oonfX5oolX00;oo`0000?oUol0oookJ_oonfX01?oonfX3ool000?ooo]Z00Goo`00oookJ_oo
nf[ooo]ZoolX0004oookJP04ool0X?oonf[oobP0oolX00[ooo]Z00?oNol0oookJ_oonfX05OoonfX0
0ooo:03ooo]ZoookJP3=oookJP03o`3o2Ooonf[ooo]Z00Kooo]Z00?o00_ooookJ_oonfX00ooonfX0
0ol0nooooo]ZoookJP03oookJP05odh0oooonf[ooo]ZoookJ_oo01@02_oonfX00oooZ03ooo]Zoook
JP02oookJP03ool0]?oo8@3ooo]Z00kooo]Z00Co0?o0oookJ_oo00Ooo`079_oonfX9ogT0oaOooo]Z
0_oo00L01Ol0ol3oS_l0o`000?l0003o0?nG00;ooo]Z00?oob40oookJ_ooZ0000_oonfX02ooo01Co
oo]Zodh0oooonf[o0?_ook3o0?l02ooo02goog`0oooonf[o0?l900;ooo]Z00CoojL0oookJ_oonf[o
oaX01?oonfX00ol0ongooo]ZoookJP02oookJP03o`3Soooonf[ooo]Z00?ooo]Z00[o0?oXo`3oUol0
POoooo]Zool02oooj03ooo]Zo`3ol?oonf[o:@3o0_oonfX00omI0?oooo]Zool0ZP05oookJP05ool=
0?oonf[oK03ooookJ_mRo`004?oonfX00ooo0?Ko00?ooookJP05oookJP04o`3oMooonf[oN@3ooiOo
00Oooo]Z00?ookl0oookJ_oonfX00_oonfX00ol0ob7ooo]ZoookJP02oookJP05ool0l_oonf[ooo]Z
oookJ_oo0:000_oonfX00omD0?oo02GooookJP08oookJP03og_o0?oonf[ooo]Z01Kooo]Z00?oo`2e
oookJ_oonfX0FooonfX007?ooo]Z00?o0?l9oookJ_oonfX01ooonfX00ol02ooooo]ZoookJP02oook
JP03ok3o0?oonf[o0?_o00Cooo]Z00GoCP3ooookJ_oonf[ooo]Zool0500:oookJP07oonX0?oonf[o
oo]ZoookJ_oo0;Cooo]ZoolQ000?oookJP03o`3o`?oonf[oo`07027ooo]Z1omi0?l5oomi00?ooo]Z
1Omi0?l5oomi00oooo]Z00Coo`07o`3o`?n>o`3oS_l01?oo00000ooo8@3ooo]ZoonX0002oookJP05
ooo70?oo01Cooo]ZoolX0?l0nol00_oo:0000ol02oooO03ooolX0002oolX0005oookJ_ooY`3ooo]Z
oookJ_oo:0001?oonfX00ol0ongooo]ZoookJP03oookJP03o`3Soooonf[ooo]Z00;ooo]Z00?o0?oX
oolX0?oo:0000_oonfX00oooj03ooo]Zo`3ol002oookJP05obT0oooonf[oF@3ooookJ_oo0:X01Ooo
nfX00ooo003ooo]Zof`0o`04ool000kooo]Z00?oo`3fo`03oooonfX00_oonfX5oolX0003ool00?nG
o`3ooo]Z00Gooo]Z0ooo0003oookJP05ool00?oonf[ooo]ZoookJ_oo:0001?oonfX00ooo0:3ooo]Z
oookJP02oolX00Wooo]Z00?oNol0oookJ_oonfX05OoonfX00ooo:03ooo]ZoookJP3<oookJP03o`3o
2Ooonf[ooo]Z00Kooo]Z00?o00_ooookJ_oonfX00ooonfX00on`o`3o0?_ooookJP03oookJP05odh0
oooonf[ooo]ZoookJ_oo01@02_oonfX00oooZ03ooo]ZoookJP02oookJP03ool0]?oo8@3ooo]Z00ko
oo]Z00?o0?o0oookJ_oo00L08OoonfX7ogT0o`Wooo]Z1Omi0?lDoookJP06ool01ol0ol3oS_l0ohko
0?oonf[o0?nG0_oonfX00ooo8@3ooo]ZoonX0002oookJP0=ool05?oonf[oCP3ooookJ_l0nooo/?l0
o`0;ool0;OooO03ooookJ_l0o`Wooo]ZoonW0003oookJP03oolJ0?oonf[ooo]Z00;ooo]Z00?o0?o]
oookJ_oonfX00_oonfX00ol0hooooo]ZoookJP02oookJP06o`3oj?oonf[o0?nGo`21oooonf[oonP0
0_oonfX00ol0oo3ooo]ZobT0o`02oookJP03oeT0oooo0:[ooo]Z00Gooo]Z00Goo`d0of`0oooonf[o
oo]Zof;o000?oookJP03ool0m_l00ooooo]Z00Gooo]Z00Co0?mgoookJ_oonf[oN@3o1ooonfX00ooo
_`3ooo]ZoookJP02oookJP03o`3o8Ooonf[ooo]Z00;ooo]Z00Goo`3boookJ_oonf[ooo]Zool0X003
oookJP03oe@0oooonf[ooo]Z00Oooo]Z00?oNol0oookJ_oonfX05_oonfX00ooo0;Gooo]ZoookJP1K
oookJP00L_oonfX00ol0o`Wooo]ZoookJP07oookJP03o`0;oooonf[ooo]Z00?ooo]Z00?o/?l0o`3k
oooonfX00ooonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00[ooo]Z00OoojP0oookJ_oonf[ooo]Zool0
]?oonf[oob4000kooo]Z0_l0ol000ooonf[oo`07oookJP0HoookJPWoobP00_oonfX?okSo00?oogT0
1?mi0?l2oomi00kooo]Z00Goo`00ool01ooo00Oo0?o0ohko0004ool00003oolQ0?oonf[oojP000;o
oo]Z00GoolL0ool05?m>0?oooo]Zo`3ko`02oolX0003o`0;ooml0?ooobP000;oobP000Gooo]ZoonW
0?oonf[ooo]ZoolX0003oookJP03o`3okOoonf[ooo]Z00?ooo]Z00?o0>?ooookJ_oonfX00_oonfX0
2ol0onSo0?nGoolX0?oo:03ooo]Zool02oooj03ooo]Zo`3ol?oonf[o:@3o00;ooo]Z00?oF@3ooook
J_oo0:X01?oonfX01?oo3@3ooo]ZoookJ_m/0?l3ool000kooo]Z00?oo`3fo`03oooonfX00_oonfX5
oolX0003ogT0oonGo`3ooo]Z00Kooo]Z0_oo0004oookJP04ool00?oonf[ooo]ZoolX00Gooo]Z00Co
o`2PoookJ_oo:03oobP02OoonfX00omko`3ooo]ZoookJP0EoookJP03oolX0?oonf[ooo]Z0<_ooo]Z
00?o0?l9oookJ_oonfX01ooonfX00ol02ooooo]ZoookJP02oookJP03ok3o0?l0nooooo]Z00?ooo]Z
00GoCP3ooookJ_oonf[ooo]Zool0500:oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oo`2doolQ0?oo
nfX03_oonfX00ol0ol3ooo]Zool01`0OoookJP?oN@3o0ooonfXAokSo0004oookJ_mi0?ooN@3oogT0
oa7ooo]Z00Oo0000ool01ooo00Oo0000ohko0?oonf[o0?nG00;ooo]Z00?oob40oookJ_ooZ0000_oo
nfX02_oo01CoCP3ooookJ_oonf[o0?_ook3o0?l02ooooo]Zog`0ool0o`T2oookJP05oonW0?oonf[o
oo]ZoookJ_oo6P000ooonfX00ol0ongooo]ZoookJP02oookJP03o`3Soooonf[ooo]Z00?ooo]Z00[o
0?oXo`3oUol0POoooo]Zool02oooj03ooo]Zo`3ol?oonf[o:@3o0_oonfX00omI0?oooo]Zool0ZP05
oookJP05ool=0?oonf[oK03ooookJ_mRo`003ooonfX00ooo0?Kooo]Zo`03o`05oookJP04o`3oMooo
nf[ooo]ZogT0o`Sooo]Z00?ookl0oookJ_oonfX00_oonfX01Ol0ob7ooo]ZoookJ_oonf[oo`3b00Co
oo]Z00Coo`2PoookJ_oonf[oE03o2OoonfX00omko`3ooo]ZoookJP0FoookJP03ool0]Ooonf[ooo]Z
05_ooo]Z001aoookJP03o`3o2Ooonf[ooo]Z00Oooo]Z00?o00_ooookJ_oonfX00ooonfX00on`o`3o
oo]Zo`3ko`04oookJP05odh0oooonf[ooo]ZoookJ_oo01@02OoonfX00oooZ03ooo]ZoookJP02oook
JP03ool0]?oo8@3ooo]Z00gooo]Z00Co0?o0oookJ_oonf[oo`076_oonfXAoolX00_oo`2l1OooN@03
ogT0o`03oomi0?oonf[ooo]Z00Wooo]Z1?oo00001?oo00Oo0?o0ohko0?n>o`02ool0000:oookJ_oo
8@3ooo]ZoonX0?oonf[oolL0oookJ_oo01CoCP3oo`3ko`;oobP000?o00_oocCo0?oo:0000_oo:002
oookJP03oonW0?oonf[ooaX000Cooo]Z00?o0?o]oookJ_oonfX00ooonfX00ol0hooooo]ZoookJP02
oookJP0:o`3oj?l0oiOoobP0oookJ_oo00_oonP0oookJ_l0oo3ooo]ZobT0o`;ooo]Z00?oF@3ooook
J_oo0:X01OoonfX00ooo3@3ooo]Zof`0o`04ool000gooo]Z00?oo`3fo`03oooonfX00ooonfX4oolX
0003ogT0oooonf[oUol000Oooo]Z00?oo`00oookJ_oonfX00_oonfX01?oo003ooo]ZoookJ_oo:005
oookJP03ool0X?oonf[oobP000GoobP01OoonfX00omko`3ooo]ZoookJP0EoookJP03oolX0?oonf[o
oo]Z0<[ooo]Z00?o0?l9oookJ_oonfX01ooonfX00ol02ooooo]ZoookJP03oookJP03ok3o0?l0nooo
oo]Z00?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool0500:oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?o
ob40oookJ_oonfX03OoonfX00ol0ol3ooo]Zool01`0MoookJP?oN@3o00?ooo]ZokSo0?nho`000onh
o`02oookJPkoo`2l00?ooo]ZokSo0?nho`000_nho`03ogT0o`kooo]Z0ol000001Ooo00Ooo`0iohko
0?oonf[o0?nG00;ooo]Z00ooob40oookJ_ooZ03ooo]Zooo70?oo01CoCP3ooookJ_l0nooo/?l0oook
J_l02oooO03ooookJ_l0o`T00_oonfX01?ooY`3ooo]ZoookJ_oo6P04oookJP03o`3okOoonf[ooo]Z
00;ooo]Z00?o0>?ooookJ_oonfX00ooonfX01Ol0onSooo]Zo`21oooo00_oonP000;ooo]Z00Oo0?o`
obT0oooonf[ooo]ZoeT0oooonf[oo`2Z00Gooo]Z00?oo`d0oookJ_m/0?l00_oonfX00omRo`3ooo]Z
oookJP0<oookJP03ool0m_oonf[o00?o00Kooo]Z00Co0?mgoookJ_mi0?ooUol01ooonfX00ooo_`3o
oo]ZoookJP02oookJP05o`3o8Ooonf[ooo]ZoookJ_oo0?801?oonfX01?oo0:3ooo]ZoookJ_mD0?l9
oookJP03og_o0?oonf[ooo]Z01Kooo]Z00?oo`2eoookJ_oonfX0FooonfX0077ooo]Z00?o0?l9oook
J_oonfX01ooonfX00ol02ooooo]ZoookJP02oookJP03ok3o0?oonf[o0?_o00Cooo]Z00GoCP3ooook
J_oonf[ooo]Zool05009oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oo`2doolQ0?oonfX03OoonfX0
1?l0ol3ooo]ZoookJ_oo00LJoookJQ3oobP03OooN@05ool0_0?oogT00omi0?l;oookJP?oo`000_oo
00L03_oo003oS_l0ool00?oo003ooo]ZoolQ0?oonf[oojP0oookJ_ooa`3ooo]Zool05?m>0?oo0?_o
0_oo:0001?l02ooo=?l0oolX0?oo:002oookJP04oonW0?oonf[ooo]ZoolJ00?ooo]Z00?o0?o]oook
J_oonfX00ooonfX00ol0hooooo]ZoookJP02oookJP03o`3oj?l0oiOo087o00;ooo]Z00KoonP0oook
J_oonf[o0?o`oookJ_lY0?l2oookJP03oeT0oooo0:[ooo]Z00Cooo]Z00Coo`d0oookJ_oonf[oK03o
0ooo000>oookJP03o`03oooonf[ooo]Z00;ooo]Z1?oo:0000omi0?ooobP0oolX0007oookJP03oono
0?oonf[ooo]Z00;ooo]Z00Goo`00oookJ_oonf[ooo]ZoolX0003oookJP03oolX0?oo0:3oobP000Ko
obP01OoonfX00omko`3ooo]ZoookJP0EoookJP03oolX0?oonf[ooo]Z0<[ooo]Z00?o0?l9oookJ_oo
nfX01_oonfX00ol02ooooo]ZoookJP03oookJP03ok3o0?l0nooooo]Z00?ooo]Z00GoCP3ooookJ_oo
nf[ooo]Zool0500:oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oob40oookJ_oonfX03OoonfX00ol0
ol3ooo]Zool01`0KoookJP?oN@3o1?nho`02oookJPGoo`2l0ooonfX:of`0o`03oookJ_oo0;coo`2l
00?oo`2l0_oonfX01?nho`3oN@3oogT0oomi0?l;oookJPCo000000Goo`07oookJ_n>o`3ooo]Zo`3o
U`02oookJP0AoolQ0?ooZ03ooo]ZoookJ_ooa`3oo`0Dodh0oooonf[o0?_ook3o0?oonf[o00_oog`0
oooonf[o0?l9oookJ_ooY`000ooonfX01Ooo6P3ooo]ZoookJ_oonf[o0?o]00Cooo]Z00?o0>?ooook
J_oonfX00ooonfX01Ol0onSo0?nGo`21oooonf[oonP000;ooo]Z00?o0?o`oookJ_lY0?l00_oonfX0
0omI0?ooo`2ZoookJP05oookJP05ool=0?oonf[oK03ooookJ_mRo`003ooonfX00ooo0?Ko00?ooook
JP05oookJP04o`3oMooonf[oN@3ooiOo00Oooo]Z00?ookl0oookJ_oonfX00_oonfX01Ol0ob7ooo]Z
oookJ_oonf[oo`3b00Cooo]Z00Goo`2PoookJ_oonf[oE03oo`0Uo`08oookJP03og_o0?oonf[ooo]Z
01Kooo]Z00?oo`2eoookJ_oonfX0FooonfX0073ooo]Z00?o0?l9oookJ_oonfX01ooonfX00ol02ooo
oo]ZoookJP03oookJP03ok3o0?oonf[o0?_o00?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05009oook
JP03oonX0?oonf[ooo]Z00;ooo]Z00?oo`2doolQ0?oonfX03OoonfX01?l0ol3ooo]ZoookJ_oo00LG
oookJPGoobP000?ooo]ZoolX0?oo:0002Ooo:002of`0oa?oogT00ooo0;`3oomi00;oN@3o2OoonfX2
o`0000?oo`0000?oo`07ool00?n>o`000_oo00002_oonf[oob40oookJ_ooZ03ooo]Zooo70?oonf[o
o`0Dodh0ool0nol2oolX0004o`0;ooml0?ooobP0oolX00;ooo]Z00CoojL0oookJ_oonf[ooaX00ooo
nfX00ol0ongooo]ZoookJP03oookJP0?o`3Soooo003oo`00ool00?oonf[o0?oXo`3oUol0POoooo]Z
ool02oooj03ooo]Zo`3ol?oonf[o:@3o00;ooo]Z00?oF@3ooookJ_oo0:X01?oonfX01Ooo3@3ooo]Z
oookJ_m/0?oooo]Z00;oo`003_oonfX00ooo0?Ko00?ooookJP03oookJPCoobP000?oN@3ooolX0?oo
nfX01_oonfX00ooo_`3ooo]ZoookJP02oookJP05ool00?oonf[ooo]ZoookJ_oo:0000ooonfX00ooo
:03oo`2PoolX0006oolX00Gooo]Z00?oNol0oookJ_oonfX05OoonfX00ooo:03ooo]ZoookJP39oook
JP03o`3o2Ooonf[ooo]Z00Oooo]Z00?o00_ooookJ_oonfX00_oonfX00on`o`3ooo]Zo`3ko`03oook
JP05odh0oooonf[ooo]ZoookJ_oo01@02_oonfX00oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[o
oo]Z00gooo]Z00?o0?o0oookJ_oo00L06_oonfX2ogT0o`03oookJ_nho`3o^?l000?ooo]Z0ooo0;`2
oookJPKoK03o2_oonfX6of`0o`Coo`2l00Cooo]ZokSo0?mi0?ooN@3o2OoonfX4o`000006oookJ_oo
00Oooo]Zohko0?oonf[o0?nG0_oonfX03_oo8@3oojP0oookJ_oonf[oolL0ool05?m>0?oooo]Zo`3k
oon`o`3o00_oo`0]ooml0?oo0?l90_oonfX01?ooY`3ooo]ZoookJ_oo6P04oookJP03o`3okOoonf[o
oo]Z00;ooo]Z00?o0>?ooookJ_oonfX00ooonfX01Ol0onSooo]Zo`21oooo00_oonP000;ooo]Z00Oo
0?o`obT0oooonf[ooo]ZoeT0oooonf[oo`2Z00Gooo]Z00Goo`d0oookJ_m/0?oooo]Zof;o000?oook
JP03ool0m_l00ooooo]Z00Gooo]Z00Co0?mgoookJ_oonf[oN@3o1ooonfX00ooo_`3ooo]ZoookJP02
oookJP03o`3o8Ooonf[ooo]Z00;ooo]Z00Goo`3boookJ_oonf[ooo]Zool0X002oookJP03oe@0ool0
9Ooooo]Z00Oooo]Z00?oNol0oookJ_oonfX05_oonfX00ooo0;Gooo]ZoookJP1KoookJP00L?oonfX0
0ol0o`Wooo]ZoookJP06oookJP03o`0;oooonf[ooo]Z00?ooo]Z00?o/?l0oookJ_l0nol00ooonfX0
1Om>0?oooo]ZoookJ_oonf[oo`0D00Wooo]Z00?oojP0oookJ_oonfX00ooonfX00ooo8@3ooo]Zoook
JP0<oookJP04o`3o`?oonf[ooo]Zool01aGooo]Z1ooo:002okSo00WoobP000?oK03ooookJ_ooN@00
3_ooN@06oookJP03of`0ooooN@3oogT000;oo`2l0oooN@02ogT0o`Oooo]Z1?l00002ool0000?ool0
1ooo003oS_l0oookJ_oo003oob40ool0]?oonf[oojP0oookJ_ooa`3ooo]Zool05?m>0?oo0?_o00;o
obP000?o00_ooolX0?oo:0000ooonfX00oooY`3ooo]ZoolJ0004oookJP03o`3okOoonf[ooo]Z00Ko
o`0000Cooo]Zo`3oj?l0oiOo087o0_oonfX01Oooj03ooo]ZoookJ_l0oo3o:@3o00;ooo]Z00?oF@3o
oookJ_oo0:X01OoonfX00ooo3@3ooo]Zof`0o`02oookJP03ool00?oonf[ooo]Z00cooo]Z00?oo`3f
o`03oooonfX01?oonfX3oolX0003ogT0oooo:03ooo]Z00Kooo]Z00?ookl0oookJ_oonfX00_oonfX0
1Ooo003ooo]ZoookJ_oonf[oobP000Cooo]Z00?oo`2PoolX0?oo:0001Ooo:005oookJP03og_o0?oo
nf[ooo]Z01Gooo]Z00?oobP0oookJ_oonfX0bOoonfX00ol0o`Wooo]ZoookJP06oookJP03o`0;oooo
nf[ooo]Z00?ooo]Z00?o/?l0o`3koooonfX00_oonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00[ooo]Z
00?oojP0oookJ_oonfX00_oonfX00ooo8@3oo`2doookJP0=oookJP03o`3o`?oonf[oo`0701Wooo]Z
0_mi0?l00ooonf[o^?l0okSo0003oookJP;oo`2l0ooonfX2of`0oaKooo]Z1?m/0?l3ool0_003oook
J_mi0?ooN@3o00Oooo]Z1?l00002oookJP09ool01ooonf[oS_l0oookJ_l0oiOooo]ZoolQ0?oo0;Co
ojP000;ooo]Z00[oolL0ool05?m>0?oooo]Zo`3koooonf[o00_oog`0oooonf[o0?l90_oonfX01?oo
Y`3ooo]ZoookJ_oo6P03oookJP03o`3okOoonf[ooo]Z00;ooo]Z00?o0>?ooookJ_oonfX00ooonfX0
1Ol0onSo0?nGo`21oooonf[oonP000;ooo]Z00?o0?o`obT0oooonfX00_oonfX00omI0?ooo`2Zoook
JP04oookJP03ool=0?oonf[oK03o00;ooo]Z00?oH_l0oookJ_oonfX03?oonfX00ooo0?Kooo]Zo`03
o`05oookJP05o`3oMooonf[ooo]ZogT0oooo9`001_oonfX00ooo_`3ooo]ZoookJP02oookJP03o`3o
8Ooonf[ooo]Z00;ooo]Z00Goo`3boookJ_oonf[ooo]Zool0X002oookJP03oe@0ool09Ooooo]Z00So
oo]Z00?oNol0oookJ_oonfX05OoonfX00ooo0;Gooo]ZoookJP1KoookJP00L?oonfX00ol0o`Wooo]Z
oookJP06oookJP03o`0;oooonf[ooo]Z00;ooo]Z00Co/?l0oookJ_oonf[o0?_o0ooonfX01?m>0?oo
oo]ZoookJ_oo01@9oookJP03oonX0?oonf[ooo]Z00?ooo]Z00?oob40oookJ_oonfX03?oonfX01?l0
ol3ooo]ZoookJ_oo00LBoookJP[oobP000?o^?l0oookJ_oo0;`01ooo:0001?m/0?oooo]ZoookJ_oo
nfX:oomi00oooo]Z1?ooN@001?oo0;co^?l0ogT0oomi0?l5oookJPCo00000_oonfX05Ooo003oo`07
ool00?n>o`3o0?nGoookJ_oo8@3oo`2doookJ_ooZ03oobP0ooo70?oonf[oo`0DoookJ_l0nooooo]Z
o`0;ooldo`3oobP0o`3o2@02oookJP04oomi0?ooY`3ooo]ZoolJ00?ooo]Z00?o0?o]ool00?oo0000
1_oo0002oookJP05o`3oj?l0POoooo]ZoookJ_ooj0000_oonfX00ol0oo3ooo]ZobT0o`02oookJP03
oeT0oooonf[oo`2Z00Cooo]Z00Koo`d0oookJ_oonf[oK03ooookJ_mRo`0?oookJP03o`03oooonf[o
oo]Z00?ooo]Z0ooo:0000omi0?ooobP0oookJP06oookJP03oono0?oonf[ooo]Z00;ooo]Z00Goo`00
oookJ_oonf[ooo]ZoolX0003oookJP;oobP000?oo`2PoolX0?oo:0001?oo:005oookJP03og_o0?oo
nf[ooo]Z01Gooo]Z00?oobP0oookJ_oonfX0bOoonfX00ol0o`Wooo]ZoookJP06oookJP03o`0;oooo
nf[ooo]Z00;ooo]Z00?o/?l0oookJ_l0nol00ooonfX01?m>0?oooo]ZoookJ_oo01@:oookJP03oonX
0?oonf[ooo]Z00;ooo]Z00?oob40ool0]?oonfX03OoonfX00ol0ol3ooo]Zool01`0IoookJP04ogT0
oooonf[ooo]ZokSo00;ooo]Z0ooo0;`2oookJP?oK03o7?oonfX3of`0o`?oo`2l0_mi0?l5oookJPCo
00000ooonfX01?oo00Oooo]Zohko0?l0oiL2oookJP03oolQ0?oo0;CoojP000;ooo]Z00WoolL0ool0
5?oonf[ooo]Zo`3koooonf[o00_oog`0ool0o`T00ooonfX00oooY`3ooo]ZoolJ0004oookJP06o`3o
kOoonf[ooo]ZoookJ_oo0>co0>?o1OoonfX01?l0onSo087ooookJ_ooj002oookJP03o`3ol?oonf[o
:@3o00;ooo]Z00?oF@3ooookJ_oo0:X01OoonfX01Ooo3@3ooo]Zof`0oooonf[oH_l000oooo]Z00?o
o`3fo`03oooonfX01OoonfX01?l0ogOooo]ZogT0oooo9`06oookJP03oono0?oonf[ooo]Z00;ooo]Z
00?o0?lQoookJ_oonfX00_oonfX00ooo0?;ooo]ZoookJP02oookJP04ool0X?oonf[ooo]Zoe@0o`Wo
oo]Z00?oNol0oookJ_oonfX05OoonfX00ooo0;Gooo]ZoookJP1KoookJP00KooonfX00ol0o`Wooo]Z
oookJP06oookJP03o`0;oooonf[ooo]Z00;ooo]Z00Co/?l0oookJ_oonf[o0?_o0ooonfX01Om>0?oo
oo]ZoookJ_oonf[oo`0D00Wooo]Z00?oojP0oookJ_oonfX00ooonfX00ooo8@3ooo]ZoookJP0<oook
JP03o`3o`?oonf[oo`07017ooo]Z2ooo:0000onho`3oo`2lool0_002oookJP?oobP000?oK03ooook
J_oonfX01?oonfX6oomi00gok@3o1?oonfX2ooo900GoogT00_oo0;`00onho`3oN@3oogT0o`03oook
JPCo00000ooonfX05?oo003oo`07ool00?n>o`3o0?nGoookJ_oo8@3oo`2doolX0?ooZ03oolL0oook
J_oo01CoCP3oo`3koon`o`3oo`0Ho`0;ooldo`3oobP00oooN@001?ooY`3ooo]ZoookJ_oo6P03oook
JPSoo`000_oonfX00ol0onSo0?nGo`21o`02oookJP05oooX0?oonf[ooo]Zo`3ol?lY0?l00_oonfX0
0omI0?oooo]Zool0ZP04oookJP06ool=0?oonf[ooo]Zof`0oooonf[oH_l03ooonfX00ooo0?Ko00?o
oookJP04oookJP;oobP000?oN@3oool00?oo:0001ooonfX01Ooo_`3ooo]ZoookJ_oonf[oo`0000?o
oo]Z00CoobP0oookJ_oonf[ooo]Z0_oo:0000ooo0:3oobP0oolX0004oolX00Gooo]Z00?oNol0oook
J_oonfX05OoonfX00ooo:03ooo]ZoookJP38oookJP03o`3o2Ooonf[ooo]Z00Kooo]Z00?o00_ooook
J_oonfX00_oonfX00on`o`3ooo]Zo`3ko`03oookJP05odh0oooonf[ooo]ZoookJ_oo01@02_oonfX0
0oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00gooo]Z00?o0?o0ool01ooonfX05ooonfX2
ogT0o`04oookJ_nho`3o^?l0oookJP;oo`2l0ooonfX2of`0o`cooo]Z3Oo]0?l9oookJP;oK03o00?o
oo]Zool0_?oo0;`00_mi0?l3oookJPCo00001?oonfX01?oo00Oooo]Zohko0?l0oiL2oookJP0>oolQ
0?oo0;CoojP0oookJ_ooa`3oo`0Dodh0oooonf[o0?_ook3o0?oo01So00_oog`0ool0o`T2oookJP04
oonW0?oonf[ooo]ZoolJ00?ooo]Z00Ko0?o]oookJ_oonf[ooo]Zool0k?l0hol5oookJP05o`3oj?oo
nf[o087ooookJ_ooj0000_oonfX01ol0oo3o:@3ooookJ_oonf[oF@3ooookJ_oo0:X01OoonfX01Ooo
3@3ooo]Zof`0oooonf[oH_l000oooo]Z00?oo`3fo`03oooonfX01OoonfX01?l0ogOooo]ZogT0oonG
o`07oookJP05oono0?oonf[ooo]ZoookJ_l0ob401?oonfX00ooo0?;ooo]ZoookJP02oookJP04ool0
X?oonf[ooo]Zoe@0o`Wooo]Z00?oNol0oookJ_oonfX05OoonfX00ooo0;Gooo]ZoookJP1KoookJP00
KooonfX00ol0o`Wooo]ZoookJP05oookJP03o`0;oooonf[ooo]Z00?ooo]Z00Co/?l0oookJ_oonf[o
0?_o0ooonfX01?m>0?oooo]ZoookJ_oo01@9oookJP03oonX0?oonf[ooo]Z00?ooo]Z00?oob40oook
J_oonfX03?oonfX00ol0ol3ooo]Zool01`0BoookJP[oobP00_oo0004oookJP03oolX0?m/0?oooo]Z
00Oooo]Z00?oogT0ond0ooo]0?l00oo]0?l:oomi00?oWOl00_o]0?l2ool00003ooo90?ooN@3oogT0
00GoogT000Cooo]Zool0_?oo0;co^?l00_mi0?l00ooonf[o0000o`000002o`0000Gooo]Z00?oo`07
ool00?n>o`000_oo:0003Ooo8@3oobP0oolX0?ooZ03oolL0oookJ_oo01Coo`00o`3koon`o`3oo`0H
o`0;ooldo`001?ooN@000oooY`3ooo]ZoolJ0003oookJP03o`3okOoo003oo`0000Goo`000ooonfX0
1Ol0onSo087ooookJ_oonf[oonP000;ooo]Z00?o0?o`obT0oooonfX00_oonfX00omI0?ooo`2Zoook
JP04oookJP03ool=0?oonf[oK03o00;ooo]Z00?oH_l0oookJ_oonfX03?oonfX00ooo0?Ko00?ooook
JP04oookJP;oobP000?oN@3oool00?oo:0001ooonfX00ooo_`3ooo]ZoookJP02oookJP04ool00?oo
nf[ooo]ZoolX00Cooo]Z00?oobP0ool0X?oo:0001Ooo:005oookJP03og_o0?oonf[ooo]Z01Gooo]Z
00?oobP0oookJ_oonfX0b?oonfX00ol0o`Wooo]ZoookJP05oookJP03o`0;oooonf[ooo]Z00?ooo]Z
00?o/?l0oookJ_l0nol00ooonfX01?m>0?oooo]ZoookJ_oo01@:oookJP03oonX0?oonf[ooo]Z00;o
oo]Z00?oob40ool0]?oonfX03OoonfX00ol0ol3oo`07oookJP0GoookJP05ogT0oooonf[ooo]ZokSo
0?oonfX00_oo0;`3oookJP;oK03o2_oonfX4ond0o`goWOl01?o]0?l7oookJP;oK03o00?ooo]Zool0
_?oo0;`00_mi0?l00ooonf[o0000o`000002o`0000Gooo]Z00Coo`07oookJ_n>o`3o0?nG0_oonfX0
3_oo8@3ooo]ZoonX0?oonf[oolL0ool05?m>0?oooo]Zo`3koon`o`3oo`0Ho`0;oooonf[o0?l90_oo
nfX01?ooY`3ooo]ZoookJ_oo6P03oookJP06o`3okOoonf[ooo]ZoookJ_oo0>co0>?o1?oonfX01Ol0
onSo0?nGo`21oooonf[oonP000;ooo]Z00?o0?o`obT0oooonfX00_oonfX00omI0?ooo`2ZoookJP04
oookJP03ool=0?oonf[oK03o00;ooo]Z00?oH_l0oookJ_oonfX03?oonfX00ooo0?Ko00?ooookJP05
oookJP04o`3oMooonf[oN@3ooiOo00Oooo]Z00?ookl0oookJ_oonfX00_oonfX01Ol0ob7ooo]Zoook
J_oonf[oo`3b00Cooo]Z00Coo`2PoookJ_oonf[oE03o2OoonfX00omko`3ooo]ZoookJP0EoookJP03
ool0]Ooonf[ooo]Z05_ooo]Z001_oookJP03o`3o2Ooonf[ooo]Z00Gooo]Z00?o00_ooookJ_oonfX0
0_oonfX01?n`o`3ooo]ZoookJ_l0nol3oookJP05odh0oooonf[ooo]ZoookJ_oo01@02OoonfX00ooo
Z03ooo]ZoookJP02oookJP03ool0]?oo8@3ooo]Z00cooo]Z00?o0?o0oookJ_oo00L05?oonfX7oolX
00Coo`000ooonfX00om/0?oooo]ZoookJP06oookJP?ok@3o1_ooN@02ool0g0OoE`3o1Ooo0=`3ool0
00GoogT000SoolT0oomi0?ooN@3oK03ooookJ_oo0;cooo]ZokSo00;oN@3o0ol00003oookJP06oomi
0?oonf[ooo]Zool01ooo003oS_l00_oo:0003?oo8@3oobP0oolX0?ooZ03oolL0ool00?oo01Coo`00
o`3kooooN@3o00_oocCo00CoogT000CoojL0oookJ_oonf[ooaX00ooonfX00ol0ongoo`00ool00005
ool000;ooo]Z00Ko0?oXo`3oUol0POoooo]Zool02oooj002oookJP07o`3ol?lY0?oooo]ZoookJ_mI
0?oooo]Zool0ZP04oookJP03ool=0?oonf[oK03o00;ooo]Z00?oH_l0oookJ_oonfX03?oonfX00ooo
0?Ko00?ooookJP05oookJP04oolX0?mi0?ooo`00oolX00Oooo]Z00?ookl0oookJ_oonfX00_oonfX4
ool000Cooo]Z00?oobP0ool0X?oo:0001Ooo:006oookJP03og_o0?oonf[ooo]Z01Gooo]Z00?oobP0
oookJ_oonfX0a_oonfX00ol0o`Wooo]ZoookJP06oookJP03o`0;oooonf[ooo]Z00;ooo]Z00?o/?l0
oookJ_l0nol00ooonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00[ooo]Z00?oojP0oookJ_oonfX00_oo
nfX00ooo8@3ooo]ZoookJP0<oookJP03o`3o`?oo00Oooo]Z01Oooo]Z00KoN@3ooookJ_oonf[o^?l0
oookJ_oo0;`4oookJP03of`0oooonf[ooo]Z00Oooo]Z0oo]0?l4oigo0003oookJ_oo0=coo`3L00Oo
E`3o1_oo0=`00onMo`3ok@3oond0o`02ond0o`Gooo]Z0_m/0?l00ooonf[oo`2lokSo0002ogT0o`?o
00001_oonfX01?oo00Oooo]Zohko0?l0oiL2oookJP0=oolQ0?oonf[oojP0oookJ_ooa`3oo`0Dodh0
oooonf[o0?_oool06?l02oooO03oo`3o2@02oookJP04oonW0?oonf[ooo]ZoolJ00?ooo]Z00Ko0?o]
oookJ_oonf[ooo]Zool0k?l0hol5oookJP05o`3oj?l0POoooo]Zool02oooj0000_oonfX01ol0oo3o
:@3ooookJ_oonf[oF@3ooookJ_oo0:X01?oonfX01_oo3@3ooo]ZoookJ_m/0?oooo]Zof;o00kooo]Z
00?oo`3fo`03oooonfX01_oonfX00ol0ogOoN@3ooiOo0007oookJP03oono0?oonf[ooo]Z00;ooo]Z
00Go0?lQoookJ_oonf[ooo]Zool0lP04oookJP05ool0X?oonf[ooo]Zoe@0ool09Ol02?oonfX00omk
o`3ooo]ZoookJP0EoookJP03ool0]Ooonf[ooo]Z05_ooo]Z001^oookJP03o`3o2Ooonf[ooo]Z00Go
oo]Z00?o00_ooookJ_oonfX00ooonfX01?n`o`3ooo]ZoookJ_l0nol3oookJP04odh0oooonf[ooo]Z
ool050Wooo]Z00?oojP0oookJ_oonfX00ooonfX00ooo8@3ooo]ZoookJP0<oookJP03o`3o`?oo00Oo
oo]Z01Gooo]Z1?oo:005ool000;ooo]Z0_m/0?l7oookJP;ok@3o0onMo`001?ooN@3oo`3Lool0g?oo
0=`4oeL0o`03oong0?oonf[ooo]Z00Cooo]Z1?mG0?l5ool000CoogT00_oob@02oomi00;oK03o0_oo
0;`00ooonf[o^?l0ogT0o`02o`0000;ooo]Z0_ooN@02oookJP03oolX0?oo00OoS_l000?oobP000Oo
ob40oolX0?oo003oojP0ooo70?oo01Coo`0000?oogT000?o00_oocCo0?ooN@000oooN@000oooY`3o
oo]ZoolJ0004oookJPOoo`000_oonfX00ol0onSo0?nGo`21o`02oookJP05oooX0?oonf[ooo]Zo`3o
l?lY0?l00_oonfX00omI0?oooo]Zool0ZP04oookJP03ool=0?oonf[oK03o00;ooo]Z00?oH_l0oook
J_oonfX03OoonfX00ol00ooooo]ZoookJP05oookJP03oolX0?mi0?ooobP000Oooo]Z00?ookl0ool0
0?oo00001_oo00000ooo:03ooo]ZoookJP02oookJP03oolX0?oo0:3oobP000?oobP01ooonfX00omk
o`3ooo]ZoookJP0EoookJP03oolX0?oonf[ooo]Z0<Kooo]Z00?o0?l9oookJ_oonfX01OoonfX00ol0
2ooooo]ZoookJP03oookJP03ok3o0?oonf[o0?_o00?ooo]Z00CoCP3ooookJ_oonf[oo`0D2_oonfX0
0oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00gooo]Z00?oo`07oookJ_oonfX05_oonfX0
1_mi0?oooo]ZoookJ_nho`3ooo]Zool0_0?ooo]Z0_m/0?l8oookJP;ok@3o0onMo`03ool0g0CoE`3o
00?ookL0oookJ_oonfX01?oonfX8oeL0o`03ool0g?oonf[ooo]Z00?ok@3o1?oonfX2of`0o`;oo`2l
00Co^?l0ogT0ool0003o00001ooonfX01?oo00OoS_l0oookJ_l0oiL2oookJP0=oolQ0?oonf[oojP0
oookJ_oo01Cooo]Zodh0ool0nooo/?l0ool06?l02ooo02goo`3o2@02oookJP04oonW0?oonf[ooo]Z
oolJ00?ooo]Z00Ko0?o]oookJ_oonf[ooo]Zool0k?l0hol4oookJP05o`3oj?l0oiOo087ooookJ_oo
j0000_oonfX01ol0oo3o:@3ooookJ_oonf[oF@3ooookJ_oo0:X01OoonfX01Ooo3@3ooo]Zof`0oooo
nf[oH_l000oooo]Z00?oo`3fo`03oooonfX01OoonfX01?l0ogOooo]ZogT0oooo9`06oookJP03oono
0?oonf[ooo]Z00;ooo]Z00Go0?lQoookJ_oonf[ooo]Zool0lP05oookJP04ool0X?oonf[oE03oo`0U
o`Sooo]Z00?oNol0oookJ_oonfX05OoonfX00ooo0;Gooo]ZoookJP1KoookJP00K_oonfX00ol0o`Wo
oo]ZoookJP05oookJP03o`0;oooonf[ooo]Z00?ooo]Z00?o/?l0oookJ_l0nol01?oonfX01?m>0?oo
oo]ZoookJ_oo01@9oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oo`2doolQ0?oonfX03?oonfX00ol0
ol3ooo]Zool01`0FoookJP;oobP01_oo00000ooonf[oK03oof`0o`07oookJP03oomi0?o]0?ooogT0
00;oogT00ooo0=`3oeL0o`;oogT00_oonfX;oi<0o`Ooo`0000?oogT0ooo90?oob@000_oob@02oomi
0003oookJ_m/0?ooK03o00;oo`2l00Co^?l0ogT0oomi0?oooo]Z1?ooN@02oookJP03ool01ol0ol3o
S_l000?oobP000Koob40oolX0?ooZ03oolL0ool00?oo01@4oomi0003o`0;ooooN@3oogT000;oogT0
00CoojL0oookJ_oonf[ooaX00ooonfX00ol0ongoo`00ool00004ool000?ooo]Z00Go0?oXo`21oooo
nf[ooo]ZoooX0002oookJP03o`3ol?lY0?oooo]Z00;ooo]Z00?oF@3oool0Z_oonfX01?oonfX01Ooo
3@3ooo]Zof`0oooonf[oH_l000[ooo]Z00?oo`00oookJ_oonfX00_oonfX00ooo0?Ko00?ooookJP05
oookJP03o`3oMomi0?ooobP000CoobP00ooonfX00ooo_`3oo`00ool00006ool000_oobP01ooonfX0
0omko`3ooo]ZoookJP0EoookJP03oolX0?oonf[ooo]Z0<Gooo]Z00?o0?l9oookJ_oonfX01_oonfX0
0ol02ooooo]ZoookJP03oookJP03ok3o0?l0nooooo]Z00?ooo]Z00CoCP3ooookJ_oonf[oo`0D2_oo
nfX00oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00cooo]Z00?o0?o0ool01ooonfX05_oo
nfX01_mi0?oooo]ZoookJ_nho`3ooo]Zool0_0;ooo]Z0_m/0?l8oookJP;ok@3o0_nMo`03ool0g0?o
E`3o1?oonfX?oi<0o`CoE`3o00?oo`3LoookJ_o]0?l00_o]0?l3oookJP04of`0oooonf[oo`2lool0
_0;oN@3o1ooonfX01Ooo00Oo0?o0ohko0?oonf[o0?nG00;ooo]Z00coob40oonX0?oonf[oolL0ool0
5?m>0?oooo]Zo`3koon`o`3o00_oocCo0?l0o`T2oookJP04oonW0?oonf[ooo]ZoolJ00?ooo]Z00Ko
0?o]oookJ_oonf[ooo]Zool0k?l0hol4oookJP05o`3oj?l0oiOo087ooookJ_ooj0000_oonfX00ol0
oo3o:@3ooookJP02oookJP03oeT0oooo0:[ooo]Z00Cooo]Z00Goo`d0oookJ_m/0?oooo]Zof;o000:
oookJP03on;o0?oonf[ooo]Z00;ooo]Z00?oo`3fo`03oooonfX01OoonfX01?l0ogOooo]ZogT0oooo
9`06oookJP03oono0?oonf[ooo]Z00;ooo]Z00Go0?lQoookJ_oonf[ooo]Zool0lP05oookJP04ool0
X?oonf[oE03oo`0Uo`Sooo]Z00?oNol0oookJ_oonfX05OoonfX00ooo0;Gooo]ZoookJP1KoookJP00
KOoonfX00ol0o`Wooo]ZoookJP06oookJP03o`0;oooonf[ooo]Z00;ooo]Z00Co/?l0oookJ_oonf[o
0?_o0ooonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Sooo]Z00?oojP0oookJ_oonfX00ooonfX00ooo
8@3ooo]ZoookJP0<oookJP03o`3o`?oo00Oooo]Z01Kooo]Z1ooo00000ooonf[oK03ooookJP04oook
JP?oogT00_o]0?l01?ooN@3oo`3Lool0g?oo0=`3oeL0o`;oogT01OnC0?l3oomi00ooo`001_oob@00
2OooN@3oobP0oookJ_oonf[oK03oo`000?oo0;co0000okSo0005oomi00?ooo]Z00?oo`07o`3o`?n>
o`000ooo:0001_oo8@3oo`00oonX0?ooa`3oo`00ool050?oogT000?o00_oocCo0?ooN@000_ooN@00
1Ooonf[oojL0oookJ_oonf[ooaX000;oogT000?ooo]Zo`3okOoo00001?oo0003oookJP03o`3oj?l0
oiOo087o00;ooo]Z00GoonP0oookJ_oonf[o0?o`obT0o`02oookJP03oeT0oooo0:[ooo]Z00Cooo]Z
00Goo`d0oookJ_m/0?oooo]Zof;o000:oookJP03ool00?oonf[ooo]Z00;ooo]Z00?oo`3fo`03oooo
nfX01?oonfX00ooo:03o0?mgogT0o`05oolX00?ooo]Z00?ookl0oookJ_oo00001_oo000;oolX00Oo
oo]Z00?oNol0oookJ_oonfX05OoonfX00ooo:03ooo]ZoookJP35oookJP03o`3o2Ooonf[ooo]Z00Ko
oo]Z00?o00_ooookJ_oonfX00_oonfX00on`o`3ooo]Zo`3ko`03oookJP05odh0oooonf[ooo]Zoook
J_oo01@02OoonfX00oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00cooo]Z00?o0?o0ool0
1ooonfX05_oonfX01_mi0?oooo]ZoookJ_nho`3ooo]Zool0_0;ooo]Z00?oK03ooookJ_oonfX01_oo
nfX2ond0o`;oWOl00_oo0=`3oeL0o`;ooo]Z1OnC0?l3onco00goo`000onC0?l3oeL0o`04ool0g?oo
nf[ok@3oond0o`;ooo]Z0_m/0?l01?l0003oo`2lokSo0?mi0?l7oookJP0Cool01ol0ol3oS_l0oook
J_l0oiOooo]Zool0]?oo8@3oojP0oookJ_ooa`3oo`0Dodh0oooonf[o0?_oool06?l02oooO03oo`3o
2@02oookJP04oonW0?oonf[ooo]ZoolJ00?ooo]Z00Ko0?o]oookJ_oonf[ooo]Zool0k?l0hol4oook
JP05o`3oj?l0POoooo]ZoookJ_ooj0000_oonfX01_l0oo3o:@3ooookJ_oonf[oF@3oool0ZPGooo]Z
00Goo`d0oookJ_m/0?oooo]Zof;o000:oookJP03on;o0?oonf[ooo]Z00;ooo]Z00?oo`3fo`03oooo
nfX01OoonfX01?l0ogOooo]ZogT0oooo9`06oookJP03oono0?oonf[ooo]Z00;ooo]Z00Go0?lQoook
J_oonf[ooo]Zool0lP05oookJP04ool0X?oonf[ooo]Zoe@0o`Sooo]Z00?oNol0oookJ_oonfX05Ooo
nfX00ooo0;Gooo]ZoookJP1KoookJP00KOoonfX00ol0o`Wooo]ZoookJP05oookJP03o`0;oooonf[o
oo]Z00?ooo]Z00?o/?l0oookJ_l0nol01?oonfX01?m>0?oooo]ZoookJ_oo01@9oookJP03oonX0?oo
nf[ooo]Z00;ooo]Z00?oo`2doolQ0?oonfX03?oonfX00ol0ol3ooo]Zool01`0EoookJPWoo`0000?o
K03ooookJ_oonfX01?oonfX00oooN@3ok@3oond0o`02oomi0004ool0g?ooN@3oE`3ooeL0o`;oogT0
0onC0?l2oomi00Koo`001ol[0?l8ool000OoolT000CoobP0oomi0?oonf[ooo]Z0_m/0?l2ool0_0Ko
ogT000Kooo]ZoolX0?oo:03oo`07oolX0?n>o`02oolX0007oolQ0?oo0;CoojP0ool00?ooa`3oo`0D
oookJP03oomi0004o`0;ooooN@3oogT0oomi00;ooo]Z1OooN@000ooonf[o0?o]oookJP04ool000Co
oo]Z00Go0?oXo`21oooonf[ooo]ZoooX0002oookJP07o`3ol?lY0?oooo]ZoookJ_mI0?oooo]Zool0
ZP04oookJP03ool=0?oonf[oK03o00;ooo]Z00?oH_l0oookJ_oonfX01ooonfX00ooo003ooo]Zoook
JP02oookJP03ool0m_l00ooooo]Z00Cooo]Z00?oobP0o`3oMomi0?l01Ooo:003oookJP03oono0?oo
nf[oo`0000Koo`001Ooo:0000ooonf[oobP0oolX0003oolX00Oooo]Z00?oNol0oookJ_oonfX01Ooo
nfX00ooo003ooo]ZoookJP0=oookJP03oolX0?oonf[ooo]Z0<Gooo]Z00?o0?l9oookJ_oonfX01Ooo
nfX00ol02ooooo]ZoookJP03oookJP03ok3o0?l0nooooo]Z00?ooo]Z00CoCP3ooookJ_oonf[oo`0D
2_oonfX01_ooZ03ooo]ZoookJ_oonf[oo`2doolQ00gooo]Z00?o0?o0oookJ_oo00L05_oonfX01_mi
0?oooo]ZoookJ_nho`3ooo]Zool0_0;ooo]Z00?oK03ooookJ_oonfX01OoonfX2ond0o`;oWOl00_oo
0=`2oeL0o`03oong0?oonf[oT`3o00;oT`3o00?oo`2Yonco0?oo00001Ooo000=ob/0o`?oo`0000?o
k?l0oi<0oonC0?l00_mG0?l2ool0g009ond0oooonf[ooo]Zo`000?m/0?oo0000ool0_?nho`3oN@3o
00Oooo]Z01;oo`07oookJ_n>o`3ooo]Zo`3oUooonf[oob40oonX0?oonf[oolL0ool05?oonf[oCP3o
o`3koon`o`3o00_oocCo0?l0o`T3oookJP03oonW0?oonf[ooaX000?ooo]Z00Ko0?o]oookJ_oonf[o
oo]Zool0k?l0hol4oookJP05o`3oj?l0oiOo087ooookJ_ooj0000_oonfX01ol0oo3o:@3ooookJ_oo
nf[oF@3ooookJ_oo0:X01?oonfX01_oo3@3ooo]ZoookJ_m/0?oooo]Zof;o00Wooo]Z00?oh_l0oook
J_oonfX00_oonfX00ooo0?Ko00?ooookJP05oookJP04o`3oMooonf[oN@3ooiOo00Kooo]Z00?ookl0
oookJ_oonfX00_oonfX00ol0ob7ooo]ZoookJP02oookJP03ool0l_oonf[ooo]Z00;ooo]Z00Coo`2P
oookJ_oonf[oE03o2OoonfX00omko`3ooo]ZoookJP05oookJP03o`3o>?oonf[ooo]Z00cooo]Z00?o
o`2eoookJ_oonfX0FooonfX006gooo]Z00?o0?l9oookJ_oonfX01OoonfX00ol02ooooo]ZoookJP03
oookJP03ok3o0?oonf[o0?_o00?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05008oookJP03oonX0?oo
nf[ooo]Z00;ooo]Z00?oo`2doolQ0?oonfX03?oonfX00ol0ol3ooo]Zool01`0DoookJP[oo`0000?o
oo]Zof`0oooonfX01OoonfX01Oo]0?ooogT0oomi0?ooN@3oo`3L00;oE`3o0_ooN@02oi<0o`03oomi
0?o/o`3oo`0000;oo`0000?oolT0ob/0ool[0?l00ol[0?l7oomi00Ooo`002Ooob@000ooo:03oogT0
oookJP02o`0000;oogT000?oo`2loomi0?ooN@000oooN@03oookJP03oolX0?oo00OoS_l000?oobP0
00Ooob40ool0]?ooZ03oolL0ool00?oo01Cooo]Z00;oogT000?o00_oocCo0?ooN@002?ooN@02oook
JP03o`3okOoo003oo`0000;oo`001?oonfX01Ol0onSo0?nGo`21oooonf[oonP000;ooo]Z00Oo0?o`
obT0oooonf[ooo]ZoeT0oooonf[oo`2Z00Gooo]Z00Goo`d0of`0oooonf[ooo]Zof;o0009oookJP03
ool00?oonf[ooo]Z00?ooo]Z00?o00?ooookJ_oonfX00ooonfX00ooo003o0?mgogT0o`05oolX00?o
oo]Z00?ookl0oookJ_oonfX01_oo0005oolX0003oookJ_oo:03oobP000?oobP01ooonfX00omko`3o
oo]ZoookJP05oookJP03ool00?oonf[ooo]Z00gooo]Z00?oobP0oookJ_oonfX0a?oonfX00ol0o`Wo
oo]ZoookJP06oookJP03o`0;oooonf[ooo]Z00;ooo]Z00?o/?l0oookJ_l0nol00ooonfX01Om>0?oo
oo]ZoookJ_oonf[oo`0D00Wooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo8@3ooo]ZoookJP0<oook
JP03o`3o`?oo00Oooo]Z01Gooo]Z00KoN@3ooookJ_oonf[o^?l0oookJ_oo0;`3oookJP03of`0oooo
nf[ooo]Z00Cooo]Z00Gok@3ooookJ_nMo`3ooo]Zool0g002oeL0o`04oong0?oonf[oT`3ooi<0o`;o
oo]Z0ooo00000ooonf[o:`3oob/0o`03ob/0o`god_l00ol[0?l3ool000;oT`3o0_mG0?l00ooo0=co
k@3oond0o`02o`0000;oK03o00?oo`2lokSo0?mi0?l01ooonfX01?oo00OoS_l0ool0>Ol0oiL2oook
JP0<oolQ0?ooZ03ooo]Zooo70?oo01Cooo]Zodh0ool0noooo`0Ho`0;ooml0?oo0?l90_oonfX01?oo
Y`3ooo]ZoookJ_oo6P03oookJP05o`3okOoonf[ooo]Zool0k?l0hol01?oonfX01Ol0onSo0?nGo`21
oooonf[oonP000;ooo]Z00Oo0?o`obT0oooonf[ooo]ZoeT0oooonf[oo`2Z00Gooo]Z00Goo`d0oook
J_m/0?oooo]Zof;o0009oookJP03on;o0?oonf[ooo]Z00?ooo]Z00?o00?ooookJ_oonfX01?oonfX0
1?l0ogOooo]ZogT0oonGo`06oookJP03oono0?oonf[ooo]Z00;ooo]Z00?o0?lQoookJ_oonfX00_oo
nfX00ooo0?;ooo]ZoookJP02oookJP04ool0X?oonf[ooo]Zoe@0o`Wooo]Z00?oNol0oookJ_oonfX0
1OoonfX00ol0ocSooo]ZoookJP0<oookJP03ool0]Ooonf[ooo]Z05_ooo]Z001/oookJP03o`3o2Ooo
nf[ooo]Z00Kooo]Z00?o00_ooookJ_oonfX00_oonfX00on`o`3ooo]Zo`3ko`04oookJP04odh0oooo
nf[ooo]Zool050Wooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo8@3ooo]ZoookJP0<oookJP03o`3o
`?oonf[oo`0701?ooo]Z2_oo00000ooonf[oK03ooookJP05oookJP06ond0oonMo`3oogT0oomi0?oo
0=coE`3o0_ooN@02oi<0o`05oomi0?oo003oo`00ool00?ooN@000ol[0?l8ooo900;oogT000?ooo]Z
ool00?oo00001Ooo000;ooo90003oolX0?ooN@3ok@3o00?o000000?oogT0ool0_?ooN@001?ooN@03
oookJP03oolX0?oo00OoS_l000?oobP000Ooob40ool0]?ooZ03oolL0ool00?oo01CoolT000;oogT0
00?o00_ooomi0?ooN@001oooN@02oookJP03o`3okOoonf[oo`0000;oo`0000?o0>?ooookJ_oonfX0
0_oonfX02Ol0onSo087ooookJ_oonf[oonP0oookJ_l0oo3ooo]ZobT0o`02oookJP03oeT0oooo0:[o
oo]Z00Cooo]Z00Goo`d0oookJ_m/0?oooo]Zof;o0009oookJP03ool00?oonf[ooo]Z00?ooo]Z00?o
o`3fo`03oooonfX00ooonfX00ooo003o0?mgogT0o`05oolX00Cooo]Z00?ookl0oookJ_oo00001Ooo
0005oolX0003oookJ_oo:03oobP000?oobP01ooonfX00omko`3ooo]ZoookJP05oookJP03ool00?oo
nf[ooo]Z00gooo]Z00?oobP0oookJ_oonfX0a?oonfX00ol0o`Wooo]ZoookJP06oookJP03o`0;oooo
nf[ooo]Z00;ooo]Z00?o/?l0o`3koooonfX00ooonfX01?m>0?oooo]ZoookJ_oo01@9oookJP03oonX
0?oonf[ooo]Z00;ooo]Z00?oob40oookJ_oonfX03?oonfX00ol0ol3ooo]Zool01`0EoookJP06ogT0
oooonf[ooo]ZokSo0?oonf[oo`2l0ooonfX00om/0?oooo]ZoookJP04oookJP06ond0oooonf[oWOl0
oookJ_oo0=coE`3o0_oo]`000ooonf[oT`3ooookJP03ool00004oookJ_l[0?oo:`3oob/0o`?od_l0
4_oonfX3omgo00;oo`000_nC0?l2oeL0o`03ool0g?o]0?ook@3o00;o000000CoK03oool0_?nho`3o
N@3o1ooonfX01?oo00OoS_l0ool0>Ol0oiL2oookJP0<oolQ0?ooZ03ooo]Zooo70?oo01CoCP3ooook
J_l0nooo00_oocCo0?oonf[o0?l90_oonfX00oooY`3ooo]ZoolJ0003oookJP06o`3okOoonf[ooo]Z
oookJ_oo0>co0>?o1?oonfX02Ol0onSo087ooookJ_oonf[oonP0oookJ_l0oo3ooo]ZobT0o`02oook
JP03oeT0oooo0:[ooo]Z00Cooo]Z00Goo`d0oookJ_m/0?oooo]Zof;o000:oookJP03on;o0?oonf[o
oo]Z00;ooo]Z00?oo`3fo`03oooonfX01?oonfX01?l0ogOooo]ZogT0oonGo`07oookJP03oono0?oo
nf[ooo]Z00;ooo]Z00Go0?lQoookJ_oonf[ooo]Zool0lP04oookJP05ool0X?oonf[ooo]Zoe@0ool0
9Ol02?oonfX00omko`3ooo]ZoookJP05oookJP03o`3o>?oonf[ooo]Z00cooo]Z00?oo`2eoookJ_oo
nfX0FooonfX006cooo]Z00?o0?l9oookJ_oonfX01OoonfX00ol02ooooo]ZoookJP03oookJP03ok3o
0?oonf[o0?_o00?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05009oookJP06oonX0?oonf[ooo]Zoook
J_oo0;Coob403OoonfX00ol0ol3ooo]Zool01`0EoookJPSoo`0000?ooo]Zof`0oooonfX01OoonfX0
1_o]0?ooWOl0oomi0?ooN@3oo`3LoeL0o`;oogT000CoT`3ooomi0?ooN@3oo`000_ooN@02ob/0o`;o
ogT02_oob@07oolL00Goo`002Ooob@001?oo:03oogT0ond0oooob@02o`000003oomi0?oo0;coogT0
00?oogT00_oonfX2oomi0003oolX0?oo00OoS_l000;oobP000Soo`00oolQ0?ooZ03oolT0ooo70?oo
01CoolT0odh0o`;oogT000?o00_ooomi0?ooN@001_ooN@02oookJP03o`3okOoonf[ooo]Z00?oo`00
1?oonfX00ol0onSo087ooookJP04ool00006o`3ol?lY0?oooo]ZoookJ_mI0?ooo`2Z1OoonfX01Ooo
3@3ooo]Zof`0oooonf[oH_l000Wooo]Z1Ooo00000ooonf[oo`3fo`03o`05oookJP03o`3oMooo:03o
N@3o00CoobP01?oonfX00ooo_`3ooo]Zool00005ool000CoobP00_oonfX5oolX00Oooo]Z00?oNol0
oookJ_oonfX01OoonfX00ooo003ooo]ZoookJP0=oookJP03oolX0?oonf[ooo]Z0<?ooo]Z00?o0?l9
oookJ_oonfX01_oonfX00ol02ooooo]ZoookJP03oookJP03ok3o0?l0nooooo]Z00;ooo]Z00GoCP3o
oookJ_oonf[ooo]Zool05009oookJP06oonX0?oonf[ooo]ZoookJ_oo0;Coob403OoonfX00ol0ol3o
oo]Zool01`0EoookJP04ogT0oooonf[ooo]ZokSo00Gooo]Z00?oK03ooookJ_oonfX01?oonfX01oo]
0?oooo]Zoigo0?oonf[oo`3LoeL0oooo]`000_oonfX01OnC0?oooo]Zool00?o/o`3ooo]Z00;o:`3o
0ooBo`04oookJPKo^?l01ooo7004okSo00?ooo]Z0_oMo`02ool000;oT`3o0_mG0?l02?nMo`3ok@3o
o`000?l0003oK03oool0_?nho`3oN@3o1ooonfX04Ooo00OoS_l0ool0>Ol0oiOooo]ZoolQ0?ooZ03o
oo]Zooo70?oo01Cooo]Zodh0ool0nooo/?l0o`0;ooldo`3o0?l900;ooo]Z00?oojL0oookJ_oo6P00
0ooonfX01_l0ongooo]ZoookJ_oonf[oo`3/o`3So`Cooo]Z00Go0?oXo`3oUol0POoooo]ZoooX0002
oookJP06o`3ol?lY0?oooo]ZoookJ_mI0?ooo`2Z1OoonfX01Ooo3@3ooo]Zof`0oooonf[oH_l000[o
oo]Z00?oh_l0oookJ_oonfX00_oonfX00ooo0?Ko00?ooookJP04oookJP04o`3oMooonf[ooo]ZogT0
o`Oooo]Z00?ookl0oookJ_oonfX00_oonfX01Ol0ob7ooo]ZoookJ_oonf[oo`3b00Cooo]Z00Goo`2P
oookJ_oonf[oE03oo`0Uo`08oookJP03og_o0?oonf[ooo]Z00Gooo]Z00?o0?lhoookJ_oonfX03?oo
nfX00ooo0;Gooo]ZoookJP1KoookJP00K?oonfX00ol0o`Wooo]ZoookJP05oookJP03o`0;oooonf[o
oo]Z00?ooo]Z00?o/?l0o`3koooonfX00ooonfX01?m>0?oooo]ZoookJ_oo01@9oookJP03oonX0?oo
nf[ooo]Z00;ooo]Z00?oob40oookJ_oonfX03?oonfX00ol0ol3ooo]Zool01`0DoookJPWoo`0000?o
K03ooookJ_oonfX01?oonfX01_o]0?ooWOl0oookJ_ooN@3oo`3LoeL0o`;oogT000GoT`3ooomi0?oo
003oo`00oomi0002ob/0o`04om;o0?ooN@3oogT0oomi00KoolT01?oo7006ooo90004o`3oU_oo703o
oa`0oolL00?oolT00_oo:007ooo90004oomi0?mG0?ook@3oond0o`;oolT000?oogT0ool0_?ooN@00
1_ooN@02ool0000;ool01on>o`3oobP0ooo90?oo8@3oolT0oonX0?ooa`3oolT0ool05?m>0?l00_oo
N@000ol02oooogT0oomi0006oomi00?ooo]Z00?o0?o]oookJ_oo00000_oo0003oookJP03ool00?l0
onSoo`0000Goo`0000Ko0?o`obT0oooonf[ooo]ZoeT0oooo0:X6oookJP04ool=0?m/0?oooo]Zof;o
00Kooo]Z2?oo00000ooonf[oo`3fo`03o`05oookJP03ool00?l0ogOoN@3o00CoobP01?oonfX00ooo
_`3ooo]ZoookJP04ool000GoobP00_oonfX00ooo:03ooo]ZoolX0002oolX00Oooo]Z00?oNol0oook
J_oonfX01OoonfX00ooo003ooo]ZoookJP0=oookJP03oolX0?oonf[ooo]Z0<?ooo]Z00?o0?l9oook
J_oonfX01_oonfX00ol02ooooo]ZoookJP02oookJP03ok3o0?l0nooooo]Z00?ooo]Z00CoCP3ooook
J_oonf[oo`0D2OoonfX00oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00cooo]Z00?o0?o0
oookJ_oo00L05OoonfX01?mi0?oooo]ZoookJ_nho`04oookJP03of`0oooonf[ooo]Z00Cooo]Z00Oo
k@3ooookJ_nMo`3ooo]Zool0g?mG0?oookL000;ooo]Z00CoT`3ooookJ_oo003oo`2Y0_l[0?l00ooo
nf[od_l0oookJP04oookJP;o^?l00_oonfX4oolL00;ooo]Z1Ol0oiH6oolL0005okSo0?oonf[ooo]Z
om;o0?oMo`000_oo0002oi<0o`;oE`3o00Ook@3ooookJ_oonf[oK03oool0_?nho`3oN@3o00Oooo]Z
017oo`07ohko0?oonf[o0?nGoookJ_oo8@3oojP0oookJ_ooa`3oo`0Dodh0oooonf[o0?_oo`0;oold
o`3ooo]Zo`3o2@02oookJP03oonW0?oonf[ooaX000?ooo]Z00Go0?o]oookJ_oonf[ooo]Zool0k004
oookJP05o`3oj?l0oiOo087ooookJ_ooj0000_oonfX01_l0oo3o:@3ooookJ_oonf[oF@3oool0ZPKo
oo]Z00Coo`d0oookJ_m/0?ooH_l02_oonfX00ooRo`3ooo]ZoookJP02oookJP03ool0m_l00ooooo]Z
00Gooo]Z00Co0?mgoookJ_mi0?ooobL01_oonfX00ooo_`3ooo]ZoookJP02oookJP05o`3o8Ooonf[o
oo]ZoookJ_oo0?801?oonfX01Ooo0:3ooo]ZoookJ_mD0?oo02Go00Sooo]Z00?oNol0oookJ_oonfX0
1OoonfX00ol0ocSooo]ZoookJP0=oookJP03ool0]Ooonf[ooo]Z05[ooo]Z001[oookJP03o`3o2Ooo
nf[ooo]Z00Kooo]Z00?o00_ooookJ_oonfX00_oonfX00on`o`3ooo]Zo`3ko`03oookJP05odh0oooo
nf[ooo]ZoookJ_oo01@02OoonfX01_ooZ03ooo]ZoookJ_oonf[oo`2doolQ00gooo]Z00?o0?o0oook
J_oo00L05?oonfX2ool00003oookJ_nho`3oo`0000Coo`0000?oK03ooookJ_oonfX01?oonfX01_o]
0?ooWOl0oookJ_oonf[oo`3LoeL0o`;oogT000?oT`3ooomi0?oo00000_ooN@001?l[0?oooo]Zom;o
0?oonfX3oomi00?oolT00ooo7004ooo900Woo`1?1_oob@03oolX00GoolT000CoT`3ooeL0oooo0=co
k@3o0_oob@000om/0?ooo`2loomi0005oomi00;oo`0000?oo`07ohko0?oob@000_oob@001ooo8@3o
ojP0ooo90?ooa`3oo`0DoookJ_m>0?l00_ooN@000ol02oooogT0oomi0005oomi00?ooo]Z00?o0?o]
oookJ_oonfX00_oo00000ol0hooooo]ZoookJP02ool00003o`3oj?oo003oo`0000?oo`0000Oo0?o`
oookJ_lY0?oooo]ZoeT0oooonf[oo`2Z00Gooo]Z00GoobP0of`0oooonf[ooo]Zof;o0005oookJPSo
o`0000?ooo]Zool0m_l00ol01OoonfX00ooo003o0?mgogT0o`04oolX00Cooo]Z00?ookl0oookJ_oo
nfX01?oo0005oolX00;ooo]Z00GoobP0oookJ_oo:03oobP0o`0Uo`07oookJP03og_o0?oonf[ooo]Z
00Gooo]Z00?oo`00oookJ_oonfX03OoonfX00ooo:03ooo]ZoookJP33oookJP03o`3o2Ooonf[ooo]Z
00Gooo]Z00?o00_ooookJ_oonfX00ooonfX00on`o`3o0?_ooookJP02oookJP05odh0oooonf[ooo]Z
oookJ_oo01@02OoonfX01_ooZ03ooo]ZoookJ_oonf[oo`2doolQ00gooo]Z00?o0?o0oookJ_oo00L0
5OoonfX01?mi0?oooo]ZoookJ_nho`04oookJP03of`0oooonf[ooo]Z00Cooo]Z00Ook@3ooookJ_nM
o`3ooo]Zool0g?mG0?oookL000;ooo]Z00KoT`3oonco0?oo003ooo]Zob/0oooonfX2om;o00Cooo]Z
0_nho`001?oonf[ooa`0oolL0?oo7003o`3oUPgoo`1?00Co0?nFoolL0?oo703ooa`00_oonfX01?oB
o`3ogOl0ool00?oo0002oi<0o`08oeL0ooo]0?oooo]ZoookJ_m/0?ooo`2lokSo0?mi0?l6oookJP0A
ool01on>o`3oo`0io`3oUooonf[oob40oonX0?oonf[oolL0ool05?oonf[oCP3oo`3koon`o`3o00_o
ocCo0?l0o`T00_oonfX00oooY`3ooo]ZoolJ0003oookJP06o`3okOoonf[ooo]ZoookJ_oo0>co0>?o
1?oonfX03Ol0onSo087ooole0?oo00_oonP0oookJ_l0oo3ooo]ZobT0oooonf[oF@3ooookJ_oo0:X0
1OoonfX01Ooo3@3ooo]Zof`0oooonf[oH_l000Wooo]Z00?oh_l0oookJ_oonfX00_oonfX00ooo0?Ko
00?ooookJP05oookJP04o`3oMooonf[oN@3ooiOo00Kooo]Z00?ookl0oookJ_oonfX00_oonfX01Ol0
ob7ooo]ZoookJ_oonf[oo`3b00Cooo]Z00Goo`2PoookJ_oonf[ooo]Zoe@0o`08oookJP03og_o0?oo
nf[ooo]Z00Gooo]Z00?o0?lhoookJ_oonfX03OoonfX00ooo0;Gooo]ZoookJP1JoookJP00JooonfX0
0ol0o`Wooo]ZoookJP05oookJP03o`0;oooonf[ooo]Z00?ooo]Z00?o/?l0oolX0?oonfX00ooonfX0
1?m>0?oooo]ZoookJ_oo01@9oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oob40oookJ_oonfX02ooo
nfX00ol0ol3ooo]Zool01`0DoookJP?oo`0000?o^?l0oookJ_oonfX00ooo00000om/0?oooo]Zoook
JP04oookJP06ond0oonMo`3ooo]ZoookJ_oo0=coE`3o0_ooN@001?nC0?ooogT0ool00?ooN@02ob/0
o`;od_l00_oonfX3oomi00?ooa`00ooob@04ool0C`04ooo90?oUo`3oogT0oomi00Gooo]Z2?oob@04
oolX00?oolT000CoT`3ooeL0oooo0=cok@3o0_oob@08oomi0004ool00?oob@3oo`07ohko00?oolT0
00Goob40oonX0?oob@3oolL0ool05002ooo90003oomi0?l02oooogT000KoogT00ooonfX01_l0ongo
oo]ZoookJ_oonf[oo`00o`3So`?ooo]Z00?oo`00o`3oj?oo00001?oo00000ooonf[o0?o`obT0o`02
oookJP03oeT0oooo0:[ooo]Z00Cooo]Z00GoobP0of`0oooo:03oobP0of;o0006oookJPOoo`0000?o
oo]Zool0m_l00ol01_oonfX00ol0ogOoN@3ooolX0002oolX00Gooo]Z00Cookl0oookJ_oonf[ooo]Z
0ooo0005oolX00;ooo]Z00GoobP0oookJ_oo:03oobP0o`0Uo`07oookJP03og_o0?oonf[ooo]Z00Go
oo]Z00?oo`00oookJ_oonfX02OoonfX9oolX0<3ooo]Z00?o0?l9oookJ_oonfX01_oonfX00ol02ooo
oo]ZoookJP02oookJP03ok3o0?l0nooooo]Z00?ooo]Z00CoCP3ooookJ_oonf[oo`0D2OoonfX00ooo
Z03ooo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00_ooo]Z00?o0?o0oookJ_oo00L05_oonfX00omi
0?oooo]ZokSo0004oookJP03of`0oooonf[ooo]Z00Cooo]Z00Ook@3ooookJ_nMo`3ooo]Zool0g?mG
0?oookL000;ooo]Z00?oT`3oonco0?oo00000_l[0?l00ooonf[od_l0oookJP03oookJP;o^?l00ooo
7002o`3oUPCoo`1?3OoonfX3ool0C`0;o`3oU_oo703ooa`0okSo0?oonf[od_l0omgo0?oo003ok?l0
oi<0oomG0?l00_o]0?l01?oonf[oK03oool0_?mi0?l7oookJP0Cool01on>o`3ooo]Zo`3oUooonf[o
ob40oonX0?oonf[oolL0ool05?m>0?oo0?_ook3o0?l02ooo=?l0oookJ_l0o`Wooo]ZoonW0002oook
JP04oolJ0?oonf[ooo]Zo`3ok@Cooo]Z00?oo`3/oookJ_oonfX00_oonfX01Ol0onSo087ooole0?oo
nf[oonP000;ooo]Z00Ko0?o`obT0oooonf[ooo]ZoeT0oooo0:X5oookJP05ool=0?oonf[oK03ooook
J_mRo`002OoonfX00ooRo`3ooo]ZoookJP02oookJP03ool0m_l00ooooo]Z00Gooo]Z00Co0?mgoook
J_mi0?ooUol01_oonfX00ooo_`3ooo]ZoookJP02oookJP05o`3o8Ooonf[ooo]ZoookJ_oo0?801?oo
nfX01Ooo0:3ooo]ZoookJ_oonf[oE03o00Sooo]Z00?oNol0oookJ_oonfX01OoonfX00ol0ocSooo]Z
oookJP0=oookJP03ool0]Ooonf[ooo]Z05[ooo]Z001ZoookJP03o`3o2Ooonf[ooo]Z00Kooo]Z00?o
00_ooookJ_oonfX00_oonfX00on`o`3ooo]ZoolX0003oookJP05odh0oooonf[ooo]ZoookJ_oo01@0
2OoonfX00oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00_ooo]Z00?o0?o0oookJ_oo00L0
4ooonfX4ool00006okSo0?oonf[ooo]ZoookJ_oo003oK03o1ooonfX01Oo]0?oooo]ZoookJ_oonf[o
E`3o00;ooo]Z00OoT`3ooomi0?oo003oogT0ob/0oooonf[od_l000?ooo]Z0_ooN@02oolL0003oomi
0?oob@3oolT000?oo`1?1ooob@02onGo00;oogT000?ooo]Zooo90?oob@002Ooob@05oolX0005ooo9
0?nC0?ooE`3oool0g?o]0?l02OooN@02ool00003ool01on>o`3oolT000KoolT000Koo`0Dooo90?oo
b@3o0?_oo`0;ooldo`06oomi0005oolJ0?oonf[ooo]ZoookJ_l0ond00_oonfX00ooo0>co0>?ooook
JP02oookJP03ool00?l0onSoo`0000Coo`0000?ooo]Zo`3ol?lY0?l00_oonfX00omI0?ooo`2Zoook
JP06oolX0003of`0oooo:03oH_l000Kooo]Z1ooo00000ooonf[oo`3fo`03o`06oookJP03o`3oMomi
0?ooobP000;oobP01OoonfX01?oo_`3ooo]ZoookJ_oonfX3ool000GoobP00_oonfX01Ooo:03ooo]Z
oookJ_oo:03o02Go00Sooo]Z00?oNol0oookJ_oonfX01?oonfX00ooo003ooo]ZoookJP09oookJPWo
obP0`?oonfX00ol0o`Wooo]ZoookJP06oookJP03o`0;oooonf[ooo]Z00;ooo]Z00?o/?l0o`3koooo
nfX00_oonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Wooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo
8@3ooo]ZoookJP0;oookJP03o`3o`?oonf[oo`0701Gooo]Z00CoN@3ooookJ_oonf[o^?l00ooonfX0
0om/0?oooo]ZoookJP05oookJP06ond0oonMo`3ooo]ZoookJ_mG0?oookL00_oonfX01?nC0?ook?l0
ool00?l[0?l2oookJP04om;o0?oonf[ooo]ZoookJP;o^?l00_oo7002o`3oUP?oo`1?5?oonfX3ool0
C`05oolL0?nho`3o^?l0o`000?oMo`000_oo00002?nC0?ooE`3ooigo0?o]0?ooK03ooookJ_oo0;co
N@3o1_oonfX04Ooo00Oo0?o0ohko0?oonf[o0?nGool0]?ooZ03ooo]Zooo70?oonf[oo`0DoookJ_l0
nooo/?l0o`0;ooldo`3o0?l900;ooo]Z00?oojL0oookJ_oo6P000ooonfX01Ol0ongooo]ZoookJ_oo
nf[oo`3/00Cooo]Z00Go0?oXo`3oUooo=@3ooo]ZoooX0002oookJP06o`3ol?lY0?oooo]ZoookJ_mI
0?ooo`2Z1OoonfX01Ooo3@3ooo]ZoookJ_m/0?ooH_l000Wooo]Z00?oh_l0oookJ_oonfX00_oonfX0
0ooo0?Ko00?ooookJP05oookJP04o`3oMooonf[oN@3ooiOo00Kooo]Z00?ookl0oookJ_oonfX00_oo
nfX01Ol0ob7ooo]ZoookJ_oonf[oo`3b00Cooo]Z00Goo`2PoookJ_oonf[ooo]Zoe@0o`08oookJP03
og_o0?oonf[ooo]Z00Gooo]Z00?o0?lhoookJ_oonfX03OoonfX00ooo0;Gooo]ZoookJP1JoookJP00
J_oonfX00ol0o`Wooo]ZoookJP06oookJP03o`0;oooonf[ooo]Z00;ooo]Z00?o/?l0oolX0?oo:000
0ooonfX01?m>0?oooo]ZoookJ_oo01@9oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oob40oookJ_oo
nfX02ooonfX00ol0ol3ooo]Zool01`0CoookJPCoo`0000?o^?l0oookJ_oonfX00_oonfX00om/0?oo
oo]ZoookJP05oookJP0<ond0oonMo`3ooo]ZoookJ_oo0=coE`3ooookJ_nC0?ooogT0onco0?oo003o
:`3o0_oonfX00ooBo`3oogT0oomi0002oomi0003oolL0?ooN@3o0?nF00?oo`1?2ooob@02onGo0003
ooo90?l0oh_o0?n;00;o0?n;2_oob@04oolX0005ool00?nC0?ooE`3oool0g?o]0?l02?ooN@02ool0
0003ooo90?oo00OoS_l000KoolT000Koo`0Dooo90?oob@3o0?_oool06?l02ol7oomi00?ooo]Z00Ko
0?o]oookJ_oonf[oo`3/oookJ_l0hol3oookJP03o`3oj?oo003oo`0000?oo`0000?ooo]Zo`3ol?lY
0?l00_oonfX00omI0?ooo`2ZoookJP06oolX0003of`0oooo:03oH_l000Kooo]Z1_oo0003oookJP03
o`03oooonf[ooo]Z00Cooo]Z00?o0?mgogT0oooo:0000_oo:005oookJP03oono0?oonf[ooo]Z00;o
oo]Z0_oo00000ooonf[oobP0oolX0002oolX00;ooo]Z00GoobP0oookJ_oonf[oE03oo`0Uo`08oook
JP03og_o0?oonf[ooo]Z00Cooo]Z00?oo`00oookJ_oonfX02_oonfX8oolX0;oooo]Z00?o0?l9oook
J_oonfX01_oonfX00ol02ooooo]ZoookJP02oookJP03ok3o0?oonf[o0?_o00?ooo]Z00CoCP3ooook
J_oonf[oo`0D2OoonfX00oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00_ooo]Z00?o0?o0
oookJ_oo00L05_oonfX00omi0?oooo]ZokSo0003oookJP03of`0oooonf[ooo]Z00Gooo]Z00Kok@3o
oookJ_nMo`3ooo]Zool0g?mG0?l2oookJP04oi<0ooo/o`3oo`00ob/0o`;ooo]Z00God_l0oookJ_oo
nf[ooo]ZokSo0002oolL00;o0?nF0_oo04l7oookJPoo0?n;1?oonfX2ool0C`0>oolL0?nho`3o0000
omgo0?l[0?ooo`00oi<0oomG0?ooWOl0ond0oom/0?oooo]Zool0_?mi0?l6oookJP0Cool01ol0ol3o
S_l0o`3oUooonf[oob40oonX0?oonf[oolL0ool05?m>0?oo0?_ook3o0?l02ooo=?l0oookJ_l0o`Wo
oo]ZoonW0002oookJP04oolJ0?oonf[ooo]Zo`3ok@?ooo]Z00?oo`3/o`3SoooonfX00ooonfX01?l0
onSo087ooole0?ooj002oookJP06o`3ol?lY0?oooo]ZoookJ_mI0?ooo`2Z1OoonfX01Ooo3@3ooo]Z
oookJ_m/0?ooH_l000Wooo]Z00?oh_l0oookJ_oonfX00ooonfX00ol00ooooo]ZoookJP04oookJP04
o`3oMooonf[oN@3ooiOo00Kooo]Z00?ookl0oookJ_oonfX00_oonfX01Ol0ob7ooo]ZoookJ_oonf[o
o`3b00Cooo]Z00Goo`2PoookJ_oonf[ooo]Zoe@0o`09oookJP03og_o0?oonf[ooo]Z00Cooo]Z00?o
0?lhoookJ_oonfX03OoonfX00ooo0;Gooo]ZoookJP1JoookJP00J_oonfX00ol0o`Wooo]ZoookJP05
oookJP03o`0;oooonf[ooo]Z00?ooo]Z00?o/?l0oolX0?oo:0000ooonfX01?m>0?oooo]ZoookJ_oo
01@9oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oob40oookJ_oonfX02ooonfX00ol0ol3ooo]Zool0
1`0BoookJPGoo`0000?o^?l0oookJ_oonfX00_oonfX00om/0?oooo]ZoookJP04oookJP06ond0oonM
o`3ooo]ZoookJ_oo0=coE`3o0_oonfX01onC0?ook?l0ool00?ooN@3o:`3ooomi0?oBo`001_ooN@00
0ol0oiKoo`1?oookJP0=ooo900_oiOl02?oob@03oolX0005ool00?nC0?ooE`3oool0g?o]0?l01ooo
N@02ool000;oolT000?oo`07ooo90?oob@001Ooob@001ooo01CoolT0oolX0?l0nooo00_oocCo0?l0
o`T01OooN@03oookJP06o`3okOoonf[ooo]ZoookJ_oo0>co0>?o0ooonfX00ooo003o0?oXool00003
ool00003oookJ_l0oo3o:@3o00;ooo]Z00CoF@3ooookJ_oo0:[ooo]Z1Ooo:0000om/0?ooobP0of;o
0007oookJPGoo`000ooonfX00ol00ooooo]ZoookJP04oookJP03o`3oMooo003oN@3o00;oobP01Ooo
nfX00ooo_`3ooo]ZoookJP02oookJP;oo`0000?ooo]ZoolX0?oo:0000_oo:002oookJP05oolX0?oo
nf[ooo]Zoe@0ool09Ol02?oonfX00omko`3ooo]ZoookJP04oookJP03ool00?oonf[ooo]Z00[ooo]Z
1ooo:030oookJP03o`3o2Ooonf[ooo]Z00Kooo]Z00?o00_ooookJ_oonfX00_oonfX00on`o`3o0?_o
oookJP03oookJP04odh0oooonf[ooo]Zool050Wooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo8@3o
oo]ZoookJP0;oookJP03o`3o`?oonf[oo`0701Gooo]Z00?oN@3ooookJ_nho`001?oonfX00om/0?oo
oo]ZoookJP04oookJP06ond0oooonf[oWOl0oookJ_oo0=coE`3o0ooonfX01_nC0?ooo`00oookJ_l[
0?oooo]Zom;o00?ooo]Z00Ko^?l0oolL0?oonf[o0?nFoookJ_oo04l6oookJP?o0?n;3ol0okD3o`3o
R`?ooo]Z0_oo04l03Ooo703o0000omgo0?l[0?ooo`00oi<0oomG0?ooWOl0ond0oom/0?ooo`2lokSo
0?mi0?l01_oonfX04_oo00OoS_l0oookJ_l0oiOoo`2doonX0?oonf[oolL0oookJ_oo01Cooo]Zo`3k
ool02ooo=?l0og`0ool0o`Wooo]ZoonW00;ooo]Z00CooaX0oookJ_oonf[o0?o]0ooonfX00ooo0>co
0>?ooookJP03oookJP08o`3oj?l0POooocD0oooX0?oo00_ooo]Zo`3ol?lY0?l2oookJP03oeT0oooo
nf[oo`2Z00Cooo]Z00Goo`d0oookJ_oonf[oK03oof;o000:oookJP03on;o0?oonf[ooo]Z00;ooo]Z
00?oo`3fo`03oooonfX01?oonfX01?l0ogOooo]ZoookJ_mi0?l6oookJP03oono0?oonf[ooo]Z00?o
oo]Z00Go0?lQoookJ_oonf[ooo]Zool0lP03oookJP05ool0X?oonf[ooo]ZoookJ_mD0?l02OoonfX0
0omko`3ooo]ZoookJP04oookJP03o`3o>?oonf[ooo]Z00gooo]Z00?oo`2eoookJ_oonfX0F_oonfX0
06Wooo]Z00?o0?l9oookJ_oonfX01_oonfX00ol02ooooo]ZoookJP02oookJP04ok3o0?oo:03oobP0
oolX00;ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05008oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?o
ob40ool0]?oonfX03?oonfX00ol0ol3oo`07oookJP0AoookJPKoo`001?oonfX00om/0?oooo]Zoook
JP05oookJP05ond0oonMo`3ooo]Zool0g?mG0?l00_oonfX01onC0?ook?l0ool00?ooN@3o:`3ooomi
0?oBo`001_ooN@001?l0oiKoo`1?oookJ_oonfX;ooo900ooiOl02?oob@02oolX0005ool00?nC0?oo
iOl0onGo0?o]0?l01_ooN@04ooo90003ool01oooN@3oolT000GoolT000Koo`0Dooo90?oob@3o0?_o
o`0;ooldo`02ooo900CoogT000GooaX0oookJ_oonf[ooo]Zo`3ok@02oookJP03ool0k?l0hooooo]Z
00;ooo]Z00?oo`00o`3oj?oo00000ooo0002oookJP07o`3ol?lY0?oooo]ZoookJ_mI0?ooo`2Zoook
JP05oolX0004of`0oooo:03ooo]Zof;o00Kooo]Z1Ooo0003oookJP03o`03oooonf[ooo]Z00Cooo]Z
00?o0?mgool00?mi0?l00_oo:005oookJP03oono0?oonf[ooo]Z00;ooo]Z0_oo0002oookJP[oobP0
2?oonfX00omko`3ooo]ZoookJP04oookJP03ool00?oonf[ooo]Z00[ooo]Z1ooo:02ooookJP03o`3o
2Ooonf[ooo]Z00Oooo]Z00?o00_ooookJ_oonfX00_oonfX00on`o`3o0?_ooookJP02oookJP05odh0
oooonf[ooo]ZoookJ_oo01@02?oonfX00oooZ03ooo]ZoookJP02oookJP03oolQ0?oo0;Cooo]Z00co
oo]Z00?o0?o0ool01ooonfX05?oonfX00omi0?oooo]ZokSo0004oookJP03of`0oooonf[ooo]Z00Go
oo]Z00Gok@3ooigo0?oonf[oo`3LoeL0o`03oookJP06oi<0oooo003ooo]Zob/0oooonf[od_l01?oo
nfX01Onho`3ooa`0oookJ_l0oiKoo`1?00Gooo]Z0_l0oh/3o`3o]@oooo]Z0ol0okD3o`3oR`0@oook
J_l0003oo`1?oolL0?nho`3ogOl0ob/0oooo003ookL0oeL0oonMo`3ok@3oof`0oooo0;co^?l0ogT0
o`Gooo]Z013oo`07o`3o`?n>o`3o0?nGoookJ_oo8@3oojP0oookJ_ooa`3oo`0Dodh0ool0nooo/?l0
o`0;ooldo`3o0?l90_oonfX00oooY`3ooo]ZoolJ0003oookJP05o`3okOoonf[ooo]ZoookJ_oo0>`0
1?oonfX01Ol0onSo087ooole0?oonf[oonP000;ooo]Z00Ko0?o`obT0oooonf[ooo]ZoeT0oooo0:X5
oookJP05ool=0?oonf[oK03ooookJ_mRo`002OoonfX00ooRo`3ooo]ZoookJP02oookJP03ool0m_l0
0ooooo]Z00Cooo]Z00Co0?mgoookJ_oonf[oN@3o1_oonfX00ooo_`3ooo]ZoookJP03oookJP05o`3o
8Ooonf[ooo]ZoookJ_oo0?800ooonfX01Ooo0:3ooo]ZoookJ_oonf[oE03o00Wooo]Z00?oNol0oook
J_oonfX01?oonfX00ol0ocSooo]ZoookJP0=oookJP03ool0]Ooonf[ooo]Z05[ooo]Z001YoookJP03
o`3o2Ooonf[ooo]Z00Kooo]Z00?o00_ooookJ_oonfX00_oonfX4oolX00;ooo]Z00CoCP3ooookJ_oo
nf[oo`0D2OoonfX00oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00_ooo]Z00?o0?o0oook
J_oo00L04OoonfX6ool000Gooo]Z00?oK03ooookJ_oonfX01?oonfX01Oo]0?ooWOl0oookJ_oo0=co
E`3o00;ooo]Z00OoT`3oonco0?oo003oogT0ob/0ooooN@3od_l000KoogT000?o0?nFool0CooonfX0
0_oonfX8ooo901?oiOl00_oob@02o`3oR`;oolT000Goo`1?ooo90?oob@3oobP0ool00002onGo0003
ond0ooooN@3oogT000GoogT00ooob@000oooN@3oo`07ooo90006ooo90003ool05?oob@3oolT000Co
olT01?ooN@001Ooo6P3ooo]ZoookJ_oonf[o0?o]00;ooo]Z00?oo`3/oookJ_l0hol00oooN@002Ol0
onSoo`00ool00?oo003oonP0oomi0?oonf[o0?o`obT0o`02oookJP03oeT0oooo0:[ooo]Z00GoobP0
00CoK03ooolX0?oonf[oobP01_oonfX5ool000?ooo]Z00?o00?ooookJ_oonfX01?oonfX00ol0ogOo
o`00oolX0002oolX00Kooo]Z00?ookl0oookJ_oonfX00_oonfX00ooo003ooo]ZoookJP0:oolX00So
oo]Z00GoobP0oookJ_oonf[ooo]Zool00002oookJP03ool00?oonf[ooo]Z00_ooo]Z1_oo:02ooook
JP03o`3o2Ooonf[ooo]Z00Kooo]Z00?o00_ooookJ_oonfX00_oonfX00on`o`3ooo]Zo`3ko`03oook
JP04odh0oooonf[ooo]Zool050Wooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo8@3ooo]ZoookJP0;
oookJP03o`3o`?oonf[oo`0701Gooo]Z00?oN@3ooookJ_nho`001?oonfX00om/0?oooo]ZoookJP04
oookJP05ond0oooonf[oWOl0ool0g?mG0?l00ooonfX01_nC0?ooo`00oookJ_l[0?oooo]Zom;o00Co
oo]Z00Go^?l0oolL0?oonf[o0?nFool0C`04oookJP;o0?n;00?ooo]Zo`3o]OoonfX01OoonfX>ool0
]@05oookJ_l0okGo0?neoookJ_l0oh/00_l000003Ooo04oooa`0oolL0?oMo`3o:`3oool00?oo]`3o
E`3oond0oooonf[oK03oool0_?mi0?l01_oonfX04_oo00Oo0?o0ohko0?l0oiOoob40oonX0?oonf[o
olL0oookJ_oo01Co0?_ook3o0?l02ooo=?l0oookJ_l0o`Wooo]ZoonW00;ooo]Z00CooaX0oookJ_oo
nf[o0?o]0ooonfX00ooo0>co0>?ooookJP02oookJP05o`3oj?l0POooocD0oookJ_ooj0000_oonfX0
1_l0oo3o:@3ooookJ_oonf[oF@3oool0ZPGooo]Z00Goo`d0oookJ_m/0?oooo]Zof;o0009oookJP03
on;o0?oonf[ooo]Z00;ooo]Z00?oo`3fo`03oooonfX01?oonfX01Ol0ogOooo]ZoookJ_mi0?ooUol0
00Kooo]Z00?ookl0oookJ_oonfX00_oonfX01Ol0ob7ooo]ZoookJ_oonf[oo`3b00?ooo]Z00Goo`2P
oookJ_oonf[ooo]Zoe@0o`09oookJP04og_o0?oonf[ooo]Zoom100?ooo]Z00?o0?lhoookJ_oonfX0
3OoonfX00ooo0;Gooo]ZoookJP1JoookJP00:_oonfX3o`00O`Gooo]Z1Ol007lboookJP03o`3o2Ooo
nf[ooo]Z00Gooo]Z00?o00_oo`00Ool007l00ooonfX4oolX0003o`00Oooo:03o001o00;ooo]Z00?o
o`0DoookJ_oonfX01ooonfX00oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00_ooo]Z00?o
0?o0oolX0?oonfX04?oonfX7ool000?ooo]Z00?o001oof`0ool007l00_l007l3oookJP0>ond0oonM
o`3ooo]Zool0g?oo]`3oE`3ooookJ_nC0?ook?l0ool00?ooN@3o:`3ooomi0?oBo`07oomi0003ool0
Cooonf[ooo]Z00;ooo]Z1Ooob@000oooN@3ooo]ZonGo000DonGo000>ool0]OoUo`3oiOl0o`3oRooU
o`3oolT0ool0Cooob@3oiOl0omgo0?oo003oiOl0oeL0ooo]0?l6oomi00CoolT000?oo`07oomi0?oo
b@003Ooob@03oomi0005oolJ0?oonf[ooo]ZoookJ_l0ond00_oonfX00ooo0>cooo]Zo`3So`03oomi
0009o`3oj?oo003oo`00ool00?ooj03oogT0oookJ_l0oo3o:@3o00;ooo]Z00CoF@3oool0Z_oonf[o
oo]Z1?oo:0000om/0?ooobP0oookJP05oolX00?ooo]Z1?oo0003oookJP03o`03oooonf[ooo]Z00Co
oo]Z00?o0?mgoookJ_oo:0000_oo:006oookJP03oono0?oonf[ooo]Z00;ooo]Z00?o0?lQoookJ_oo
nfX02_oo:008oookJP08oolX0?oonf[ooo]Zo`00Oooo003o001ooookJ_oo0003oookJPGo001o1Ooo
nfX6oolX02kooo]Z0ol007l5oookJPGo001oA_oonfX3o`00O`Gooo]Z1Ol007laoookJP03o`3o2Ooo
nf[ooo]Z00Gooo]Z00?o001oo`0;ool007l00ooonfX00on`o`3ooo]Zo`3ko`02o`00O`05odh0ool0
07oooo]ZoookJ_oo01@02OoonfX00oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00_ooo]Z
00?o0?o0ool01ooonfX05?oonfX00omi0?oooo]ZokSo0003oookJP03o`00Oom/0?oo001o00;o001o
0ooonfX01_o]0?oooo]Zoigo0?oo0=cooo]ZoeL0o`;ooo]Z00KoT`3oool00?oonf[o:`3ooookJ_oB
o`04oookJP05okSo0?oo703ooo]Zo`3oU_oo04l01?oonfX01?l0oh_ooo]ZoookJ_l0okD4oookJP?o
o`2e0ooo8009oookJP;oob000ooo0;D2o`3o]@0@o`3oRol0003o0000ool0Col0oiKooa`0omgo0?oo
003oT`3ooong0?mG0?ook@3oof`0oooonf[oo`2logT0o`Gooo]Z01;oo`07o`3o`?n>o`3o0?nGoook
J_oo8@3oojP0oookJ_ooa`3oo`0Dodh0ool0nooo/?l0o`0;ooml0?oo0?l9oookJ_ooY`02oookJP04
oolJ0?oonf[ooo]Zo`3ok@?ooo]Z00?oo`3/o`3SoooonfX00ooonfX01?l0onSo087ooole0?ooj002
oookJP06o`3ol?lY0?oooo]ZoookJ_mI0?ooo`2Z1?oonfX01_l007ooo`d0o`00Oom/0?oo001oof;o
00Wooo]Z00?oh_l0oookJ_oonfX00_oonfX00ooo0?Ko00?ooookJP04oookJP05o`3oMooonf[ooo]Z
ogT0oonGo`001_oonfX00ooo_`3ooo]ZoookJP02oookJP05o`3o8Ooonf[ooo]ZoookJ_oo0?801?oo
nfX01?oo0:3ooo]ZoookJ_mD0?l9oookJP05og_o0?oonf[o001ooom10?l007l00_oonfX00ol0ocSo
oo]ZoookJP05o`00O`Sooo]Z00?oo`2eoookJ_oonfX0;ooonfX3o`00O`Gooo]Z1Ol007lNoookJP00
:_oonfX3o`00O`Cooo]Z1ol007l`oookJP03o`3o2Ooonf[ooo]Z00Kooo]Z00?o00_oo`00Ool007l0
0_oonfX5oolX0005o`00Oooo:03o001oo`00Oooo01@02OoonfX00oooZ03ooo]ZoookJP02oookJP03
oolQ0?oonf[ooo]Z00cooo]Z00?o0?o0oolX0?oonfX03ooonfX8ool000;ooo]Z0_l007l00om/0?oo
001oo`00O`02o`00O`;ooo]Z00Gok@3ooigo0?oo:03ookL0oeL0o`02oookJP06oi<0ooooN@3ooo]Z
oookJ_l[0?ood_l01oooN@000ooonf[oo`1?oookJP02oookJP03oomi0?oob@3oolT000?oogT00_oo
b@0EonGo00;oU?l01?oUo`001_nDo`3oo`1?ooo90?oUo`3ogOl0ool000;oiOl000?ok@3ooomi0?oo
N@000oooN@02ooo90005oookJ_oob@3oogT0ool01oooN@003Ooob@03oomi0005oolJ0?oonf[ooo]Z
oookJ_l0ond00ooonfX00ooo0>coobP0oolX0002oolX0009o`3oj?oo003oo`00ool00?ooj03oogT0
oookJ_l0oo3o:@3o00;ooo]Z00CoF@3oool0Z_oonf[ooo]Z1?oo:0000om/0?ooobP0oolX0005oolX
00?ooo]Z1?oo0003oookJP03o`03oooonf[ooo]Z00Cooo]Z00Go0?mgoookJ_oo:03oo`00oolX0006
oookJP03oono0?oonf[ooo]Z00;ooo]Z00Co0?lQoookJ_oonf[ooo]Z2?oo:0000ol09Ooooo]Zoook
JP06oookJP08oolX0?oonf[ooo]Zo`00Oooo003o001ooookJ_oo0002oookJPOo001o1?oonfX6oolX
02kooo]Z0ol007l4oookJPOo001oAOoonfX3o`00O`Cooo]Z1ol007l_oookJP03o`3o2Ooonf[ooo]Z
00Kooo]Z00?o00_oo`00Ool007l00_oonfX00on`o`3ooo]Zo`3ko`03o`00O`04odh0ool007oo001o
ool050Wooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo8@3ooo]ZoookJP0<oookJP03o`3o`?oo00Oo
oo]Z01Cooo]Z00?oN@3ookSo0?oonfX00_oonfX2o`00O`03of`0ool007oo001o00;o001o0_oonfX0
1Oo]0?ooWOl0ool0g?oonf[oE`3o00;ooo]Z00KoT`3oool00?oonf[ooo]Zob/0oooBo`04oookJP05
okSo0?oo703ooo]Zo`3oU_oo04l01?oonfX01?l0oh_ooo]ZoookJ_l0okD3oookJP;oo`2e0ooo8000
0ooonf[o203oo`P0o`09o`3o>0;ood4000?ooo]ZoolP0?oo80000_oo0;D04Ol0okGo0?n;o`000?l0
003oo`1?o`3oU_oo703ogOl0ool00?nC0?ooE`3ooigo0?o]0?ooK03ooookJ_oo0;coN@3o00Gooo]Z
017oo`07ohko0?oonf[o0?nGoolQ0?ooZ03ooo]Zooo70?oo01CoCP3oo`3koon`o`3o00_oocCo0?l0
o`Wooo]ZoonW0002oookJP04oolJ0?oonf[ooo]Zo`3ok@?ooo]Z00?oo`3/o`3SoooonfX00ooonfX0
2?l0onSo087ooole0?ooj03oo`0;oookJ_l0oo3o:@3o0_oonfX00omI0?ooo`2ZoookJP02oookJP;o
001o00Goo`d0o`00Oom/0?oo001oof;o0009oookJP03on;o0?oonf[ooo]Z00;ooo]Z00?oo`3fo`03
oooonfX01?oonfX01Ol0ogOooo]ZoookJ_mi0?ooUol000Kooo]Z00?ookl0oookJ_oonfX00_oonfX0
1Ol0ob7ooo]ZoookJ_oonf[oo`3b00Cooo]Z00Coo`2PoookJ_oonf[oE03o2OoonfX01Omko`3ooo]Z
o`00Oooo@@3o001o00;ooo]Z00?o0?lhoookJ_l007l01_l007l7oookJP03ool0]Ooonf[ooo]Z02oo
oo]Z0ol007l4oookJPOo001o7OoonfX002[ooo]Z0ol007l3oookJPCo001o00Cooo]Zo`00Ool007oo
001o<?oonfX00ol0o`Wooo]ZoookJP06oookJP03o`0;ool007oo001o00;ooo]Z1ooo:002o`00O`03
ool05?oonf[ooo]Z00Oooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo8@3ooo]ZoookJP0;oookJP03
o`3o`?oo:03oobP000oooo]Z2?oo0002oookJP;o001o00?oK03oo`00OooonfX00ol007l01?oonf[o
k@3ooigo0?oonfX2oolX00;ooo]Z00OoT`3oonco0?ooN@3ooo]Zob/0oooonf[od_l000KoogT000Co
oo]Zool0Cooonf[ooo]Z0oooN@001?l0oh_oogT0oomi0?ooN@02ooo90003ool0]Ooo803oob0000oo
iOl000CoU?l0onGo0?oUo`3oiOl00_nDo`000ooUo`3oU?l0oiCo0003oiCo0008ool0Cooob@3oU?l0
omgo0?oo003oE`3oonGo0?o]0?l4oomi00;oolT00ooo:0000ooo00OoobP0ooo9000:ooo90003ocCo
0?oob@3oolT000;oogT000Gooo]ZoolJ0?oonf[ooo]Zo`3ok@08oolX0005o`3oj?oo003oo`00ool0
0?ooj0000_oonfX02?l0oo3o:@3ooookJ_oonf[oF@3oool0Z_oonf[o001o1?oo:0000om/0?ooobP0
oolX0005oolX00?ooo]Z1?oo0003oookJP03ool0m_l00ooooo]Z00Cooo]Z00Go0?mgoookJ_oo:03o
o`00oiOo0006oookJP03oolX0?oonf[ooo]Z00;ooo]Z00Go0?lQoookJ_oonf[ooo]Zool0lP07oolX
0003o`0Uoooonf[ooo]Z00Kooo]Z00SoobP0oookJ_oonf[o001oool00?l007oooo]Zool000;ooo]Z
0ol007l01?oonf[o001oo`00Ool007l5oookJPCoobP0;ooonfX3o`00O`?ooo]Z1?l007l01?oonf[o
001oo`00Ool007m5oookJP?o001o0ooonfX4o`00O`04oookJ_l007oo001oo`00Oboooo]Z00?o0?l9
oookJ_oonfX01_oonfX00ol02ooo001oo`00O`02oookJP03ok3o0?oonf[o0?_o00;o001o00Gooo]Z
odh0ool007oo001oool05009oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oob40oookJ_oonfX02ooo
nfX00ol0ol3ooo]Zool01`0DoookJP03ogT0oooonf[o^?l000;ooo]Z0_l007l00om/0?oo001ooook
JP03o`00O`0?oookJ_o]0?oooo]Zoigo0?oo0=coE`3ooong0?oonf[oT`3oonco0?oo003ooo]Zob/0
oooonf[od_l000?ooo]Z00Go^?l0oolL0?oonf[o0?nFool0C`05oookJP03o`3oRooonf[o0?ne00?o
oo]Z00?oo`2eoolP0?oo80000_oonfX00ol80?oo0?lho`3o>00<og_o00;o0?lh00?ood40oolP0?oo
80000_oo0;D2o`3oR`0>oookJ_oo04oo0?nFoolL0?oMo`3oo`00onco0?mG0?ook@3ooookJ_m/0?oo
o`2logT0oooo03P4oookJP0Bool01ol0ol3oS_l0o`3oUooo8@3ooo]ZoonX0?oonf[oolL0ool05?l0
nooo/?l0o`0;ooldo`3ooo]Zo`3o2Ooonf[oojL00_oonfX00ooo6P3ooo]Zo`3ok@03oookJP03ool0
k?l0hooooo]Z00?ooo]Z00So0?oXo`21oooo=@3oonP0ool02ooonf[o0?o`obT0o`;ooo]Z00CoF@3o
ool0Z_oonf[ooo]Z0ol007l01Ooo3@3ooo]Zof`0ool007ooH_l000Wooo]Z00?oh_l0oookJ_oonfX0
0_oonfX00ooo0?Ko00?ooookJP04oookJP05o`3oMooonf[ooo]ZogT0oonGo`001_oonfX00ooo_`3o
oo]ZoookJP02oookJP05o`3o8Ooonf[ooo]ZoookJ_oo0?801?oonfX01?oo0:3ooo]ZoookJ_mD0?l9
oookJP05og_o0?oonf[o001ooom10?l007l00_oonfX00ol0ocSooo]Zo`00O`02o`00O`04oookJ_l0
07oo001oo`00O`Oooo]Z00?oo`2eoookJ_oonfX0;ooonfX3o`00O`?ooo]Z1?l007l01?oonf[o001o
o`00Ool007lMoookJP006_oonfX:o`00O`Kooo]Z0ol007l3oookJP?o001o0ooonfX3o`00ObSooo]Z
1ol007l00ol0o`Wo001oo`00O`05oookJP05o`0;ool007oo001oo`00OooonfX02?oo:002o`00O`03
ool05?oonf[ooo]Z00Oooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo8@3ooo]ZoookJP0;oookJP03
o`3o`?oo:03oobP000gooo]Z1?l007l6ool000;ooo]Z0_l007l01?m/0?oooo]ZoookJ_oonfX2o`00
O`03oolX0?oonf[oWOl000?oobP000?ooo]Zoomi0?oonfX00_ooN@000ol[0?oooo]Zom;o0007oomi
0003ool0CoooN@3oogT000?oogT000Co0?n;oomi0?ooN@3oogT00_oob@001?oo0;Goob00ooo90?oo
b@0?onGo0003oiCo0?oUo`3oiOl000;oA?l000?oU?l0odCo0?m4o`000ol0o``2oiCo0008ool0ConD
o`3oU?l0omgo0?oo003oU?l0ool0g?o]0?l3oomi00;oolT01?oo:0000ooo00OoogT0ooo90009ooo9
0007ocCo0?oob@3oolT0ooo90?ooN@3ooo]ZoolJ0003oookJPSoobP000?o0?oXool00?oo00000_oo
00002Oooj03ooo]Zo`3ol?oonf[o:@3ooookJ_mI0?ooo`2ZoookJP02o`00O`?oobP000?oK03ooolX
0?oo:0001?oo:005oookJP;oo`001?oonfX00ooo0?Ko00?ooookJP05oookJP04o`3oMooo:03oo`00
oiOo00Kooo]Z00?oobP0oookJ_oonfX00_oonfX01_l0ob7ooo]ZoookJ_oonf[oo`3boookJPKoobP0
00?o02GooookJ_oonfX01_oonfX00ooo:03ooo]ZoookJP09ool000?ooo]Z0ol007l4oookJPCoobP0
;ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o=?oonfX:o`00O`Kooo]Z0ol007l3oookJP?o001o
0ooonfX3o`00ObOooo]Z1ol007l00ol0o`Wo001oo`00O`06oookJP03o`0;ool007oo001o00;ooo]Z
00Co/?l0o`00Ool0nooo001o0_oonfX01?m>0?oo001oo`00Oooo01@9oookJP03oonX0?oonf[ooo]Z
00;ooo]Z00?oob40oookJ_oonfX02ooonfX00ol0ol3oo`07oookJP0=oookJPWo001o00?o^?l0oook
J_oonfX00_l007l01?m/0?oooo]ZoookJ_oonfX2o`00O`0>ond0oooonf[oWOl0ool0g?oonf[oE`3o
oookJ_nC0?oooo]Zool00?oonf[o:`3ooookJ_oBo`03oookJP05okSo0?oo703ooo]ZoookJ_oo04l0
1OoonfX00ol0oh_ooo]Zo`3o]@03oookJP05ool0]Ooo803ooo]ZoookJ_l80?l00_l0ocP00ooo@@3o
Nol0o`1<o`04obX0o`;o04co1?oo0:000olZ0?ooNol0og_o0002og_o0005o`3o>?oo803o0000ool0
]Ol0okD00_l0oh/03?oo04oooa`0om;o0?oMo`3oo`00oong0?mG0?ook@3ooookJ_m/0?ooo`2logT0
o`Gooo]Z017oo`07ohko0?oonf[o0?nGoolQ0?ooZ03ooo]Zooo70?oo01CoCP3oo`3koon`o`3o00_o
o`0]ool0o`Wooo]ZoonW0002oookJP04oolJ0?oonf[ooo]Zo`3ok@;ooo]Z00?oo`3/o`3SoooonfX0
0ooonfX03_l0onSo087ooole0?oonf[oonP0oookJ_l0oo3ooo]ZobT0oooonf[oF@3ooookJ_oo0:[o
oo]Z0ol007l01_oo3@3ooo]Zof`0ool007ooH_l0o`00O`Sooo]Z00?oh_l0oookJ_oonfX00_oonfX0
0ooo0?Ko00?ooookJP05oookJP04o`3oMooonf[oN@3ooiOo00Kooo]Z00?ookl0oookJ_oonfX00_oo
nfX01Ol0ob7ooo]ZoookJ_oonf[oo`3b00Cooo]Z00Coo`2PoookJ_oonf[oE03o2OoonfX01Omko`3o
oo]Zo`00Oooo@@3o001o00;ooo]Z00Co0?lho`00Ool007oo001o0ooonfX3o`00O`Kooo]Z00?oo`2e
oookJ_oonfX0;ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o7?oonfX001[ooo]Z2_l007l6oook
JP?o001o2OoonfX3o`00ObSooo]Z1ol007l00ol0o`Wo001oo`00O`05oookJP05o`0;ool007oo001o
o`00OooonfX02?oo:0000ol007ooo`0Do`00O`09oookJP06oonX0?oonf[ooo]ZoookJ_oo0;Coob40
3OoonfX3oolX00gooo]Z1Ol007l5ool000Cooo]Z00CoK03ooookJ_oonf[ooo]Z0_l007l00ooo:03o
WOl0oolX0003oolX0003oookJ_ooN@3oogT000;oogT000?o:`3ooomi0?ooN@001_ooN@000ooo04oo
ogT0oomi0003oomi0004o`3oRoooN@3oogT0oomi00;oolT000?oo`2eoolP0?oob@000_oob@000ooU
o`3oNol0og_o000;onGo00?oU?l00ooUo`09o`2`o`08o`3oGOnDo`3oU?l0ool00?nDo`3oo`3Lond0
oooob@03oomi00GoolT000?oo`07ooo90?oob@003ooob@001?oo6P3ooo]ZoookJ_oonfX8oolX0003
ool00?l0onSoo`0000;oo`0000SoonP0oookJ_l0oo3ooo]ZobT0oooonf[oF@3oool0ZP?ooo]Z0ooo
:0000om/0?ooobP0oolX0004oolX00Gooo]Z0_oo0004oookJP03ool0m_l00ooooo]Z00Gooo]Z00Co
0?mgoolX0?oo9`3oUol01_oonfX00ooo:03ooo]ZoookJP02oookJP06o`3o8Ooonf[ooo]ZoookJ_oo
0?;ooo]Z1_oo:0001Ol09Ooooo]ZoookJ_oonf[oo`0000Cooo]Z00?oobP0oookJ_oonfX02Ooo0003
oookJP?o001o1?oonfX4oolX02oooo]Z0ol007l9oookJP?o001o=?oonfX:o`00O`Kooo]Z0ol007l9
oookJP?o001o9ooonfX7o`00O`03o`3o2Ol007oo001o00Gooo]Z00go00_oo`00Ool007oo001ooook
J_n`o`3ooo]Zo`00Ool0nooo001ooookJ_m>0?oooo]Z00;o001o00?oo`0DoookJ_oonfX01ooonfX0
1_ooZ03ooo]ZoookJ_oonf[oo`2doolQ00gooo]Z00?o0?o0ool01ooonfX03OoonfX8o`00O`03okSo
0?l007oooo]Z00?ooo]Z00CoK03ooookJ_oonf[ooo]Z0_l007l01Oo]0?ooWOl0oookJ_oo0=coE`3o
00;ooo]Z00OoT`3oonco0?oo003ooo]Zob/0oooonf[od_l000?ooo]Z00Co^?l0oolL0?oonf[oo`1?
1OoonfX00ol0oh_ooo]Zo`3o]@04oookJP06ool0]Ooonf[ooo]Zo`P0ool0ocSood400_mko`02obX0
o`03ool:0?mD0?ooo`2P00?oo`2P1?oo0?84ool0X003obX0oomko`3oNol000;oob0000_oo`2eo`3o
]Ooonf[o0?n;ool0Cooo703od_l0ool00?nC0?ooE`3oond0o`02oookJP03of`0oooo0;coN@3o00Co
oo]Z017oo`07ohko0?oonf[o0?nGoolQ0?ooZ03ooo]Zooo70?oo01CoCP3oo`3koon`o`3o00_oo`0]
ool0o`Wooo]ZoonW0002oookJP04oolJ0?oonf[ooo]Zo`3ok@?ooo]Z00?oo`3/o`3SoooonfX00_oo
nfX03Ol0onSo087ooole0?oonf[oonP0oookJ_l0oo3ooo]ZobT0oooonf[oF@3ooookJ_oo0:X01?oo
nfX01_oo3@3ooo]Zof`0ool007ooH_l0o`00O`Wooo]Z00Koh_l0oookJ_oonf[ooo]Zool0m_l00ol6
oookJP04o`3oMooonf[oN@3ooiOo00Kooo]Z00?ookl0oookJ_oonfX00_oonfX01Ol0ob7ooo]Zoook
J_oonf[oo`3b00Cooo]Z00Coo`2PoookJ_oonf[oE03o0ooonfX00olZ0?oooo]ZoookJP03oookJP08
og_o0?oonf[o001ooom10?l007oooo]Zo`3o>?oonfX3o`00O`?ooo]Z0ol007l6oookJP03ool0]Ooo
nf[ooo]Z02oooo]Z0ol007l9oookJP?o001o7?oonfX002[ooo]Z0ol007l9oookJP?o001o;_oonfX0
0ol0o`Wooo]ZoookJP06oookJP04o`0;ool007oo001oo`00O`WoobP000?o001oool05?l007l02Ooo
nfX01OooZ03ooo]ZoookJ_oonf[oob4000gooo]Z00Co0?o0oolX0?oo:03oobP05?oonfX2ool000Co
oo]Z00?oK03ooookJ_oonfX00_oonfX01?l007ooobP0oolX0?nMo`04oolX00CoogT000?o:`3ooomi
0?ooN@003?ooN@001?l0oh_oogT0oomi0?ooN@02ooo90003ool0]Ooo803oolT000;oolT000?oiOl0
og_o0?oUo`002ooUo`05oiCo0003onGo0?l0o`co0;3o00So0;3o00Go0?mMoiCo0?m4o`3oA?l0ool0
0002oiCo0004ond0oooUo`3oogT0oomi00;oiOl01?oob@000ooo00OoogT0ooo9000>ooo90003oolJ
0?ooN@3oogT000;oogT01ooo:0000ooo003o0?oXool00002ool00008oooX0?oonf[o0?o`oookJ_lY
0?oooo]ZoeT0oooo0:X3oookJPCoobP000?oK03ooolX0?oo:0000ooo:005oookJP;oo`001?oonfX0
0ooo0?Ko00?ooookJP02oookJPWoobP01?oonfX00ooo:03ooo]ZoookJP02oookJP06o`3o8Ooonf[o
oo]ZoookJ_oo0?;ooo]Z1_oo:0001Ol09Ooooo]ZoookJ_oonf[oo`0000Cooo]Z00?oobP0oookJ_oo
nfX02Ooo0003oookJP?o001o1OoonfX3oolX02oooo]Z0ol007l9oookJP?o001oA?oonfX3o`00O`Wo
oo]Z0ol007l^oookJP03o`3o2Ooonf[ooo]Z00Gooo]Z00So00_oo`00Ool007oo001ooookJ_n`o`3o
oo]Zo`3ko`;o001o00Kooo]Zodh0oooonf[o001oool05?l007l9oookJP05oonX0?oonf[ooo]Zoook
J_oo8@003OoonfX00ol0ol3ooo]Zool01`0FoookJP03okSo0?oonf[ooo]Z00;ooo]Z00?oK03ooook
J_oonfX00_oonfX2o`00O`0=ond0oonMo`3ooo]Zool0g?mG0?oooo]Zoi<0oooonf[oo`00oookJ_l[
0?oooo]Zom;o0003oookJP04okSo0?oo703ooo]Zool0C`Gooo]Z00?o0?n;oookJ_l0okD01?oonfX0
1Ooo0;Gooo]ZoookJ_l80?oo0?lh00;oNol000?oo`X0obX0oomD0?l00ooo0:0=o`3o8@;oo`2P01?o
Nol0o`3o>?oo803oo`2eo`3o]Ol0oh_ooo]Zool0Conho`3od_l0ool00?nC0?ooE`3oond0oooonf[o
K03oool0_?mi0?ooo`0h00Cooo]Z013oo`07ohko0?l0oiOoob40oookJ_ooZ03ooo]Zool05?m>0?oo
0?_ook3o0?l02ooo=?l0o`3o2Ooonf[oojL00_oonfX01?oo6P3ooo]ZoookJ_l0ond3oookJP03ool0
k?l0hooooo]Z00?ooo]Z00co0?oXo`21oooo=@3oonP0oookJ_l0oo3ooo]ZobT0oooonf[oF@3ooook
J_oo0:X4oookJP06ool=0?oonf[ooo]Zof`0oomRo`3o001o2OoonfX01_oRo`3ooo]ZoookJ_oonf[o
o`3fo`03o`Kooo]Z00Co0?mgoookJ_mi0?ooUol01_oonfX00ooo_`3ooo]ZoookJP02oookJP05o`3o
8Ooonf[ooo]ZoookJ_oo0?801?oonfX01?oo0:3ooo]ZoookJ_mD0?l3oookJP03obX0oooonf[ooo]Z
00?ooo]Z00SoNol0oookJ_l007oood40o`00Oooonf[o0?lhoookJP?o001o0ooonfX3o`00O`Kooo]Z
00?oo`2eoookJ_oonfX0;ooonfX3o`00O`Wooo]Z0ol007lLoookJP00:_oonfX3o`00O`Cooo]Z0_l0
07l2oookJPCo001o;_oonfX00ol0o`Wooo]ZoookJP05oookJP04o`0;oooonf[o001oo`00O`[oobP0
00?o001oool05?l007l02?oonfX00oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00_ooo]Z
1?oo:00EoookJP03ool00?oonf[ooo]Z00;ooo]Z00GoK03oo`00Oooonf[ooo]Zo`00O`08oolX01;o
ogT000?o0?n;oomi0?ooN@000_ooN@001?oob@3oo`2eooo90?oo8002ooo90004o`3o>?mko`3oiOl0
obX0o`CoiOl00_l0ob44onGo00CoU?l000Co0?n]oiCo0?nDo`3o0?l<2Ol0/?l01Ol0oegoU?l0odCo
0?m4o`3oo`0000;oU?l00_oUo`03ooo90003onGo0?oob@3oolT001?oolT000?ooaX0oomi0?ooN@00
0_ooN@07oolX0003ool00?l0onSoo`0000;oo`0000[oonP0oookJ_l0oo3ooo]ZobT0oooonf[oF@3o
oookJ_oo0:[ooo]Z0_l007l3oolX0003of`0oooo:03oobP000?oobP01_oonfX00ooo003ooo]Zoook
JP02oookJP03ool0m_l00ooooo]Z00;ooo]Z2Ooo:004oookJP05oolX0?oonf[ooo]ZoookJ_l0ob40
1?oonfX00ooo0?;ooo]ZoookJP04oolX0003oe@0oooonf[ooo]Z00;ooo]Z00?oo`00oookJ_oonfX0
0_oonfX01?oo:03ooo]ZoookJ_l007l7ool00004o`00Oooonf[ooo]ZoookJP?o001o1OoonfX3oolX
02oooo]Z0ol007l4oookJP;o001o0_oonfX4o`00OdCooo]Z0ol007l4oookJP;o001o0_oonfX4o`00
Obgooo]Z00?o0?l9oookJ_oonfX01_oonfX02?l02ooo001oo`00Ool007oooo]Zok3o0?oonf[o0?_o
0_l007l01_oonf[oCP3ooookJ_l007ooo`0Do`00O`Sooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo
8@3ooo]ZoookJP0;oookJP03o`3o`?oonf[oo`0701Kooo]Z00?o^?l0oookJ_oonfX00_oonfX01?m/
0?oo001ooookJ_oonfX2o`00O`0=ond0ool007ooWOl0ool0g?oo]`3oE`3ooookJ_nC0?ooo`2Yool0
0?oonf[o:`3oom;o0004oookJP04okSo0?oo703ooo]Zool0C`Cooo]Z00?o0?n;oookJ_l0okD01?oo
nfX02Ooo0;Goob00oookJ_l80?oo0?lhog_o0?oonf[oo`X0obX0o`02ool0X0;oo`3b00?o0?lQo`3o
X_l0oj800_oo_`07ogT0o`0Goono0?l0oj;o0?lQo`3o8Ooo0:3oNol0o`3o>?oo803oo`2eo`3o]Ol0
oh_oo`1?oolL0?nho`3od_l0ool00?mG0?oookL0ond0oooonf[oK03oool0_?mi0?l01?oonfX04ooo
00OoS_l0oookJ_l0oiOoob40oonX0?oonf[oolL0ool05?l0nooo/?l0o`0;ooldo`3ooo]Zo`3o2Ooo
nf[oojL0oookJ_oo6P000_oonfX01_l0ongooo]ZoookJ_oonf[oo`3/o`3So`Cooo]Z00co0?oXo`21
oooo=@3oonP0oookJ_l0oo3ooo]ZobT0oooonf[oF@3ooookJ_oo0:X2oookJP;o001o00Koo`d0oook
J_l007ooK03oof;o0?l007l9oookJP06on;o0?oonf[ooo]ZoookJ_oo0?Ko00?o1_oonfX01?l0ogOo
oo]ZogT0oonGo`06oookJP03oono0?oonf[ooo]Z00;ooo]Z00Go0?lQoookJ_oonf[ooo]Zool0lP04
oookJP04ool0X?oonf[ooo]Zoe@0o`?ooo]Z00?o:P3ooookJ_oonfX00ooonfX02?mko`3ooo]Zo`00
Oooo@@3o001ooookJ_l0ocSooo]Z0ol007l3oookJP?o001o1_oonfX00ooo0;Gooo]ZoookJP0_oook
JP?o001o1?oonfX2o`00O`;ooo]Z1?l007lLoookJP00:_oonfX3o`00O`Cooo]Z1ol007l_oookJP03
o`3o2Ooonf[ooo]Z00Gooo]Z00CoobP0oookJ_l007oo001o2_oo:0000ol007ooo`0Do`00O`08oook
JP06oonX0?oonf[ooo]ZoookJ_oo0;Coob403?oonfX5oolX01Cooo]Z00?o^?l0oookJ_oonfX00_oo
nfX00om/0?oo001oo`00O`03o`00O`OoobP01OooN@000ooonf[oogT0oomi000;oomi0008o`3oRooo
N@3oogT0oomi0?oob@3oo`2eooo90?oo8002ooo90006o`3o>?oob@3oNol0obX0oooUo`3oo`2P0_oU
o`000ol0ob7oiOl0onGo0003onGo00CoU?l00_l0ojd2oiCo00;o0?l<1ol0/?l00ol0oegoU?l0oiCo
0003odCo0003ool00?m4o`3oiOl000CoiOl05Ooob@000oooN@3ooo]ZoolJ0003oomi00OoobP000Ko
o`00o`3oj?oo003oocD0ool00?ooj002oookJP07o`3ol?lY0?oooo]ZoookJ_mI0?ooo`2ZoookJP02
o`00O`?oobP000?oK03ooolX0?oo:0000_oo:007oookJP03on;o0?oonf[ooo]Z00?ooo]Z00Co00?o
oookJ_oonf[ooo]Z2Ooo:004oookJP05oolX0?oonf[ooo]ZoookJ_l0ob401?oonfX00ooo0?;ooo]Z
oookJP04oolX0003oe@0oooonf[ooo]Z00;ooo]Z00Goo`00oookJ_oonf[ooo]ZoolX0003oookJPSo
o`0000Co001ooookJ_oonf[ooo]Z0ol007l5oookJP;oobP0<?oonfX3o`00O`Cooo]Z1ol007m5oook
JP?o001o1?oonfX7o`00Obkooo]Z00?o0?l9oookJ_oonfX01OoonfX00ol02ooooo]Zo`00O`02o`00
O`04oookJ_n`o`3ooo]Zo`3ko`;o001o00Kooo]Zodh0oooonf[o001oool05?l007l8oookJP06oonX
0?oonf[ooo]ZoookJ_oo0;Coob403OoonfX00ol0ol3oo`07oookJP0EoookJP03okSo0?oonf[ooo]Z
00;ooo]Z00?oK03oo`00Ool007l01?l007l03Oo]0?ooWOl0oookJ_oo0=coE`3ooookJ_nC0?oooo]Z
onco0?oo003o:`3ooookJ_oBo`000ooonfX01?nho`3ooa`0oookJ_oo04l5oookJP03o`3oRol0okGo
oo]Z00?ooo]Z00coo`2eoolP0?oonf[ooo]Zo`3o>?ooW03oNol0ool:0?lZ0?ooo`2PoookJ_oo0?82
o`3o8@;ookl00omi0?l7o`3oM`;oN@3o01Ko0?mgo`3oX_l0ob7oo`2Pog_o0?l0ocSooo]Zool0]Ol0
okGo0?n;ool0Cooo703o^?l0omgo0?oo003oE`3ooigo0?o]0?ooK03oool0_?mi0?ooo`0h0ooonfX0
4Ooo00OoS_l0oookJ_l0oiOoob40oonX0?oonf[oolL0ool05?m>0?oo0?_oo`0;ooldo`3ooo]Zo`3o
2Ooonf[oojL000;ooo]Z00?ooaX0oookJ_l0ond00ooonfX00ooo0>co0>?ooookJP02oookJP05ocKo
0?l0onSo087ooole0?ooj0000_oonfX01_l0oo3o:@3ooookJ_oonf[oF@3oool0ZP;ooo]Z0ol007l0
1?oo3@3o001oof`0oomRo`0:oookJP03on;o0?oonf[ooo]Z00;ooo]Z00?oo`3fo`03oooonfX01?oo
nfX01?l0ogOooo]ZogT0oonGo`06oookJP03oono0?oonf[ooo]Z00;ooo]Z00Go0?lQoookJ_oonf[o
oo]Zool0lP04oookJP04ool0X?oonf[ooo]Zoe@0o`?ooo]Z00?o:P3ooookJ_oonfX00_oonfX01?mk
o`3ooo]ZoookJ_oo@@02o`00O`03oookJ_l0ocSooo]Z00?o001o0ooonfX3o`00O`Kooo]Z00?oo`2e
oookJ_oonfX0;ooonfX3o`00O`Cooo]Z1ol007lMoookJP00:_oonfX3o`00O`Cooo]Z1_l007l`oook
JP03o`3o2Ooonf[ooo]Z00Gooo]Z00?oobP0oookJ_l007l02ooo:0000ol007ooo`0Do`00O`08oook
JP06oonX0?oonf[ooo]ZoookJ_oo0;Coob403?oonfX5oolX01Cooo]Z00?o^?l0oookJ_oonfX00_oo
nfX00om/0?oo001oo`00O`02o`00O`SoobP01OooN@000ooBo`3ooo]Zoomi0007oomi0004oookJ_oo
N@3oogT0o`3oR`?oogT000Cooo]Zooo90?oo0;Goob000ooob@001Ol0ocSoNol0onGo0?lZ0?ooo`2P
00;oiOl000?o0?lQonGo0?oUo`000ooUo`02odCo00;oU?l01?l0ojd2oiCo0003o`3o3?l0/?oo0;3o
00Go0;3o00?o0?mMoiCo0?m4o`000om4o`000ooo003oA?l0odCo0007onGo01;oolT000?oojL0oook
J_oo6P000oooN@06oolX00;oo`0000Go0?oXool00?oo=@3oo`00oooX0002oookJP07o`3ol?lY0?oo
oo]ZoookJ_mI0?ooo`2ZoookJP02o`00O`;oobP000?o001oof`0oooo:0000ooo:007oookJP03on;o
0?oonf[ooo]Z00?ooo]Z00?o00?ooookJ_oonfX00_oonfX7oolX00Cooo]Z00?oobP0oookJ_oonfX0
0_oonfX01Ol0ob7ooo]ZoookJ_oonf[oo`3b00?ooo]Z1?oo:0000omD0?oooo]ZoookJP02oookJP05
ool00?oonf[ooo]ZoookJ_oo:0000ooonfX8ool00004o`00Oooonf[ooo]ZoookJP?o001o1_oonfX0
0ooo:03ooo]ZoookJP0^oookJP?o001o1?oonfX6o`00OdKooo]Z0ol007l4oookJPKo001o;ooonfX0
0ol0o`Wooo]ZoookJP05oookJP03o`0;oooonf[o001o00;o001o00Co/?l0oookJ_oonf[o0?_o0_l0
07l01_oonf[oCP3ooookJ_l007ooo`0Do`00O`Sooo]Z00KoojP0oookJ_oonf[ooo]Zool0]?oo8@0<
oookJP03o`3o`?oonf[oo`0701Kooo]Z00?o^?l0oookJ_oonfX00_oonfX00om/0?oo001oo`00O`04
o`00O`0<ond0oonMo`3oo`3Loong0?mG0?oooo]Zoi<0oooonf[oo`00oookJ_l[0?ood_l00ooonfX0
1Onho`3ooa`0oookJ_l0oiKoo`1?00Cooo]Z00?o0?n;oookJ_l0okD01?oonfX03_oo0;Gooo]Zoook
J_l80?oo0?lhog_o0?oo2P3o:P3oool0X?oonf[oo`3bo`3o8Ol0oj;o0:;o0_mi0?l2o`3oM`03o`3o
B?mJo`3oF_l000KoF_l001Oo0?nnogT0oomi0?oo0?nRo`3o8Ooo0:3oNol0o`3o>?oonf[oo`2eo`3o
Rooonf[oo`1?oolL0?nho`3oo`00oeL0oooo]`3ok@3oof`0oooo0;coN@3oool0>004oookJP0@ool0
1on>o`3o0?nGoolQ0?oo0:OoojP0ooo70?oo01CoCP3oo`3koooo01So00_ooookJ_l0o`Wooo]ZoonW
00;ooo]Z00CooaX0oookJ_oonf[o0?o]0_oonfX00ooo0>co0>?ooookJP02oookJP05ocKo0?l0onSo
087ooole0?ooj0000_oonfX01_l0oo3o:@3ooookJ_oonf[oF@3oool0ZP;ooo]Z0ol007l01Ooo3@3o
001oof`0oooonf[oH_l000Wooo]Z00?oh_l0oookJ_oonfX00_oonfX00ooo0?Ko00?ooookJP04oook
JP04o`3oMooonf[oN@3ooiOo00Kooo]Z00?ookl0oookJ_oonfX00_oonfX01Ol0ob7ooo]ZoookJ_oo
nf[oo`3b00Cooo]Z00Coo`2PoookJ_oonf[oE03o0ooonfX00olZ0?oooo]ZoookJP02oookJP04og_o
0?oonf[ooo]Zoom100;o001o00?ooo]Zo`3o>?oonfX00ol007l3oookJP?o001o1_oonfX00ooo0;Go
oo]ZoookJP0_oookJP?o001o1?oonfX6o`00Oakooo]Z000WoookJPKo001o1?oonfX2o`00OcCooo]Z
00?o0?l9oookJ_oonfX01?oonfX2oolX00Co001o00?o/?l0oookJ_oonfX01_oo:0000ooo01Co001o
o`00O`08oookJP05oonX0?oonf[ooo]ZoookJ_oo8@003?oonfX6oolX01Cooo]Z00?o^?l0oookJ_oo
nfX00_oonfX01?m/0?oo001oo`00OooonfX8oolX00GoogT000Co:`3oom;o0?oonf[ooo]Z1_ooN@02
oookJP;oogT000?o0?n;oomi0?ooN@000_oonfX02_oo0;Goob00ooo90?oob@3o203oo`3o>?mko`3o
obP0obX0oooo0:02onGo0005o`3o8OoUo`3oiOl0ogT0oooob@001Om4o`06o`3o[@;oU?l01ol0/?l0
0ol0oegoU?l0odCo0004odCo0003ool00?m4o`3oA?l000OoiOl04Ooob@000oooY`3ooo]ZoolJ0004
oomi00GoobP00_oo00001Ol0onSoo`00oole0?oo003oonP000;ooo]Z00Oo0?o`obT0oooonf[ooo]Z
oeT0oooo0:[ooo]Z00;o001o00Cooo]ZoolX0?oonf[oK03o1?oo:007oookJP03on;o0?oonf[ooo]Z
00?ooo]Z00?o00?ooookJ_oonfX00_oonfX7oolX0003oookJ_oo:03oobP000KoobP000Go0?lQoook
J_oonf[ooo]Zool0lP04oookJP?oobP000Go02GooookJ_oonf[ooo]Zool00004oookJP04oolX0?l0
07oo001oo`00O`Soo`0000Co001ooookJ_oonf[ooo]Z0ol007l6oookJP03oolX0?oonf[ooo]Z02_o
oo]Z1_l007l4oookJP;o001oAooonfX6o`00O`Cooo]Z0_l007lcoookJP03o`3o2Ooonf[ooo]Z00Co
oo]Z00?o001oo`0;ool007l00ol007l01?n`o`3ooo]ZoookJ_l0nol2o`00O`06odh0oooonf[ooo]Z
o`00Oooo01Co001o2?oonfX01OooZ03ooo]ZoookJ_oonf[oob4000gooo]Z00?o0?o0oookJ_oo00L0
5_oonfX00onho`3ooo]ZoookJP02oookJP03of`0ool007oo001o00?ooo]Z00Gok@3ooookJ_nMo`3o
o`3LoeL0o`02oookJP06oi<0ooo/o`3oo`00oookJ_l[0?ood_l00ooonfX01Onho`3ooa`0oookJ_l0
oiKoo`1?00Cooo]Z00?o0?n;o`3o]OoonfX00ooonfX05?oo0;Gooo]ZoookJ_l80?oo0?lhog_o0?oo
2P3o:P3oool0X?mD0?ooo`3bo`3o8Ol0oj;ooo]ZogT0oooo9`3o0?mgo`3oB?oo0?KoF_l00_oRo`03
oookJP?oH_l00omJo`02ogT0o`0Bo`3o8Ooo0:3oNol0o`3o>?oo803oo`2eo`3oRooonf[oo`1?oolL
0?oMo`3oo`00oeL0ooo]0?oooo]Zof`0oooo0;coN@3o1?oonfX04?oo00OoS_l0oookJ_l0oiOoob40
oonX0?oonf[oo`0Dodh0ool0nooo/?l0o`0;ool0;Ooo0?l9oookJ_ooY`02oookJP04oolJ0?oonf[o
oo]Zo`3ok@;ooo]Z00?oo`3/o`3SoooonfX00_oonfX01Olfo`3o0?oXo`21oooo=@3oonP000;ooo]Z
00Ko0?o`obT0oooonf[ooo]ZoeT0oooo0:X2oookJP;o001o00Kooo]Zool=0?oonf[oK03ooookJ_mR
o`09oookJP03on;o0?oonf[ooo]Z00;ooo]Z00?oo`3fo`03oooonfX01?oonfX01?l0ogOooo]ZogT0
oonGo`06oookJP03oono0?oonf[ooo]Z00;ooo]Z00Go0?lQoookJ_oonf[ooo]Zool0lP04oookJP04
ool0X?oonf[oE03oo`0Uo`;ooo]Z00?o:P3ooookJ_oonfX00ooonfX01?mko`3o001oo`00Oooo@@02
o`00O`03oookJ_l0ocSooo]Z00?o001o0ooonfX3o`00O`Kooo]Z00?oo`2eoookJ_oonfX0;?oonfX6
o`00O`Cooo]Z0_l007lRoookJP009ooonfX6o`00O`Cooo]Z0_l007ldoookJP03o`3o2Ooonf[ooo]Z
00Cooo]Z0_oo:004o`00O`03ok3o0?oonf[oobP000KoobP000?oo`0Do`00OooonfX01ooonfX01_oo
Z03ooo]ZoookJ_oonf[oo`2doolQ00cooo]Z1_oo:00CoookJP03okSo0?oonf[ooo]Z00;ooo]Z00Co
K03ooookJ_l007oo001o2?oo:006oomi0005oookJ_oBo`3ooo]ZoookJ_nho`001OooN@03oookJP03
o`3oRoooN@3oogT000?ooo]Z00Koo`2eoolP0?oob@3o203oo`3o>?mko`03ooo90003ool0X?oUo`3o
0?lQ00;oiOl000?oN@3oonGo0?oob@001om4o`04o`3o[@;oU?l01ol0/?l00ol0oegoU?l0odCo0004
odCo0003ool00?m4o`3oA?l000OoiOl04Ooob@000oooY`3ooo]ZoolJ0004oomi00GoobP00_oo0000
1Ol0onSoo`00oole0?oo003oonP000;oo`0000Oo0?o`obT0oooonf[ooo]ZoeT0oooo0:[ooo]Z00;o
001o00Cooo]ZoolX0?oonf[oK03o0ooo:008oookJP03on;o0?oonf[ooo]Z00?ooo]Z00?o00?ooook
J_oonfX00_oonfX7oolX0003oookJ_oo:03oobP000KoobP000Go0?lQoookJ_oonf[ooo]Zool0lP04
oookJP?oobP000Go02GooookJ_oonf[ooo]Zool00004oookJP06oolX0?l007oo001oo`00Oooo003o
001o1Ooo0003o`00O`04oookJ_l007oo001oo`00O`Oooo]Z00?oo`2eoookJ_oonfX0:ooonfX6o`00
O`Cooo]Z0_l007m7oookJPKo001o1?oonfX2o`00Oc?ooo]Z00?o0?l9oookJ_oonfX01?oonfX00ol0
07oo00_oo`00O`03o`00O`04ok3o0?oonf[o0?_ooookJP;o001o00GoCP3ooookJ_l007oo001oool0
5008oookJP06oonX0?oonf[ooo]ZoookJ_oo0;Coob403OoonfX00ol0ol3ooo]Zool01`0EoookJP03
okSo0?oonf[ooo]Z00;ooo]Z00CoK03ooookJ_l007oo001o0ooonfX03Oo]0?ooWOl0oookJ_oo0=co
E`3ooookJ_nC0?oooo]Zool00?oonf[o:`3ooookJ_oBo`000_oonfX01Onho`3ooa`0oookJ_l0oiKo
o`1?00Cooo]Z00?o0?n;oookJ_l0okD00ooonfX03ooo0;Goob00oookJ_l80?oo0?lhog_o0?oonf[o
:P3oo`1<oooo0:3oo`3boookJ_l0ob7ookl0ogT0o`02o`3oM`06o`3oB?mJo`3oF_l0on;o0?mRo`3o
on<01om/0?l05oooh`3oH_l0o`3o__l0ogOoN@3oo`3o8Ooo0:3oNol0o`3o>?oo0;Go0?neo`3oRooo
04oooa`0om;o0?oo003oE`3ooong0?o]0?ooK03oool0_?mi0?ooo`0h00?ooo]Z013oo`07ohko0?oo
nf[o0?nGoolQ0?ooZ03ooo]Zool05?m>0?oo0?_ook3o0?l02ooo=?l0o`3o2Ooonf[oojL00_oonfX0
1?oo6P3ooo]ZoookJ_l0ond2oookJP03ool0k?oonf[o0>?o00;ooo]Z00Go=_l0o`3oj?l0POooocD0
oooX0002oookJP08o`3ol?lY0?oooo]ZoookJ_mI0?oooo]Zool0Z_oonfX2o`00O`06oookJ_oo3@3o
oo]Zof`0oooonf[oH_l02OoonfX00ooRo`3ooo]ZoookJP02oookJP03ool0m_l00ooooo]Z00Cooo]Z
00Co0?mgogT0oooo9`3oUol01_oonfX00ooo_`3ooo]ZoookJP02oookJP05o`3o8Ooonf[ooo]Zoook
J_oo0?801?oonfX01?oo0:3ooo]Zoe@0ool09Ol2oookJP03obX0oooonf[ooo]Z00?ooo]Z00CoNol0
o`00Ool007oood400_l007l01?oonf[o0?lhoookJ_oonfX3o`00O`04oookJ_l007oo001oo`00O`Oo
oo]Z00?oo`2eoookJ_oonfX0;?oonfX6o`00O`Cooo]Z0_l007lRoookJP00:OoonfX4o`00O`Gooo]Z
1ol007l]oookJP03o`3o2Ooonf[ooo]Z00Gooo]Z0_oo:004o`00O`03ok3o0?oonf[oobP000KoobP0
00?oo`0Do`00OooonfX01ooonfX01_ooZ03ooo]ZoookJ_oonf[oo`2doolQ00_ooo]Z1ooo:00Coook
JP03okSo0?oonf[ooo]Z00;ooo]Z00CoK03ooookJ_oonf[o001o1ooo:007oomi0006om;o0?oonf[o
oo]ZoookJ_nho`3ooa`01?ooN@03oookJP03o`3oRoooN@3ooo]Z00?ooo]Z013oo`2eooo90?oob@3o
olT0oomi0?mko`3oobP0ooo90?oo0:3oiOl0o`3o8Ooob@3oiOl0ooo90?mi0?ooogT02_m4o`03o`3o
[@03oiCo0?l0o`co0;3o00Co0;3o00?o0?mMoiCo0?nDo`001_m4o`000ooo003oiOl0onGo0006onGo
0003oomi0?oob@3oolT000GoolT000?oogT0ooo90?oob@001Ooob@001?ooN@3oojL0oomi0?oo6P04
oomi00GoobP00_oo00001Ol0onSoo`00oole0?oo003oonP000;oo`0000Ko0?o`obT0oooonf[ooo]Z
oeT0oooo0:X2oookJP;o001o00?oo`d0o`00Oom/0?l00ooo:008oookJP03on;o0?oonf[ooo]Z00?o
oo]Z00?o00?ooookJ_oonfX00_oonfX7oolX0003oookJ_oo:03oobP000GoobP000?ooo]Zo`3o8Ooo
nfX00_oonfX00ooo0?;ooo]ZoookJP02oookJP;oobP000?oE03oo`0UoooonfX00_oonfX00ooo003o
oo]ZoolX0004oolX0004oookJ_l007ooo`00o`00O`Goo`001ol007l7oookJP03ool0]Ooonf[ooo]Z
02gooo]Z1?l007l5oookJPOo001o@ooonfX4o`00O`Gooo]Z1ol007l]oookJP03o`3o2Ooonf[ooo]Z
00Gooo]Z00?o00_oo`00Ool007l00_l007l01?n`o`3ooo]Zo`3koooonfX2o`00O`05odh0ool007oo
001oool05?l007l02?oonfX01_ooZ03ooo]ZoookJ_oonf[oo`2doolQ00cooo]Z00Co0?o0oookJ_oo
nf[oo`075OoonfX00onho`3ooo]ZoookJP02oookJP03of`0oooonf[ooo]Z00Co001o00cok@3ooigo
0?oo0=cooo]ZoeL0oooonf[oT`3ooookJ_oo003ooo]Zob/0oooBo`03oookJP05okSo0?oo703ooo]Z
o`3oU_oo04l01?oonfX00ol0oh_o0?neoookJP03oookJP0Eool0]Ooonf[ooo]Zo`3o>?ooW03oNol0
ool:0?lZ0?ooo`2Pool0l_oonf[o0?lQo`3oX_oonf[oN@3ooolW0?l0odSoF_l0o`3o__oonf[oH_l0
00;oK03o0ol0odd01?lY0?oo0?o`o`3ol?lY0?l3of`0o`0Doe[o0?l0okkoN@3oo`3o8Ooo0:3oNol0
o`3o>?oo0;Go0?n;oookJ_oo04oooa`0omgo0?oo003oo`3Lond0oom/0?ooo`2logT0oooo03P4oook
JP0Bool01on>o`3o0?nGoolQ0?ooZ03ooo]Zooo70?oo01Co0?_ook3o0?l02ooo=?l0oookJ_l0o`Wo
oo]ZoonW0?oonf[ooaX00_oonfX01_l0ongooo]ZoookJ_oo0>cooo]Zo`3So`;ooo]Z00Wo=_l0o`3o
j?l0POooocD0ool02oooj03ooo]Zo`3ol?lY0?l00_oonfX00omI0?oooo]Zool0ZP02oookJP;o001o
00Goo`d0o`00Oom/0?oo001oof;o0008oookJP03on;o0?oonf[ooo]Z00?ooo]Z00?oo`3fo`03oooo
nfX01?oonfX01?l0ogOoN@3ooolW0?nGo`06oookJP05oono0?oonf[ooo]ZoookJ_l0ob401?oonfX0
0ooo0?;ooo]ZoookJP02oookJP04ool0X?oonf[oE03oo`0Uo`;ooo]Z00?o:P3ooookJ_oonfX00ooo
nfX01?mko`3ooo]Zo`00Oooo@@02o`00O`04oookJ_l0ocSooo]ZoookJPOo001o1ooonfX00ooo0;Go
oo]ZoookJP0^oookJPCo001o1OoonfX7o`00Oacooo]Z000ZoookJP?o001o1OoonfX7o`00Obgooo]Z
00?o0?l9oookJ_oonfX01?oonfX4oolX00?o001o00?o/?l0oookJ_oo:0001_oo:0000ooo01Cooo]Z
oookJP07oookJP06oonX0?oonf[ooo]ZoookJ_oo0;Coob402ooonfX7oolX01?ooo]Z00?o^?l0oook
J_oonfX00_oonfX00om/0?oooo]ZoookJP07oolX00SoogT000God_l0oookJ_oonf[ooo]ZokSo0005
oomi00;ooo]Z00?o0?n;oookJ_l0okD00ooonfX01ooo0;Goob00oookJ_l80?ooolT0og_o0?oo:000
0_oob@000ooo0:3o0?lQooo90002ooo90003ogT0ooooN@3oogT000_oA?l00_l0ojd2oiCo00Go0;3o
0_l0oed7odCo0003ool00?oUo`3oiOl000GoiOl00_ooN@06ooo90003oonX0?ooN@3oolT000KoolT0
00GoogT0oonW0?ooN@3ooaX0oookJP04oomi00?oobP000cooo]Zool00?oo003o0?oXool00?oo=@3o
o`00oooX0?oo003ooo]Zo`3ol?lY0?l2oookJP04oeT0oooo0:[ooo]ZoookJP;o001o00?oo`d0o`00
Oom/0?l00ooo:008oookJP03on;o0?oonf[ooo]Z00?ooo]Z00?o00?ooookJ_oonfX00ooonfX5oolX
00;ooo]Z1ooo:0000ooonf[o0?lQoookJP02oookJP03ool0l_oonf[ooo]Z00?ooo]Z00?oobP0oe@0
ool09Ol00ooonfX00ooo003ooo]ZoolX0007oolX00Koo`0000?ooo]Zo`00Ool007l00ol007l8oook
JP03ool0]Ooonf[ooo]Z02kooo]Z0ol007l5oookJPOo001oA?oonfX3o`00O`Gooo]Z1ol007l]oook
JP03o`3o2Ooonf[ooo]Z00Gooo]Z00?o00_ooookJ_l007l00_l007l00on`o`3ooo]Zo`3ko`02oook
JP05o`00Oom>0?oo001oo`00Oooo01@02OoonfX01_ooZ03ooo]ZoookJ_oonf[oo`2doolQ00cooo]Z
00?o0?o0oookJ_oo00L05_oonfX00onho`3ooo]ZoookJP02oookJP03of`0oooonf[ooo]Z00Co001o
00cok@3ooigo0?oo0=coE`3ooookJ_nC0?oooo]Zonco0?oo003o:`3ooookJ_oBo`03oookJP05okSo
0?oo703ooo]Zo`3oU_oo04l00ooonfX00ol0oh_ooo]Zo`3o]@03oookJP0Iool0]Ooo803ooo]Zo`P0
ool0ocSoNol0oookJ_lZ0?ooE03oool0X?oo0?;o0?lQo`3oX_oonf[oN@3ooolW0?l0odSooo]Zoe[o
0?oRo`3ooo]Zof`0ooooh`3o0?m=ool0ZP03o`3ol0?o0?oX0_l0oo005OlY0?ooK03oof`0ool0ogOo
N@3oo`3o8Ooo0:3oNol0ool0]Ol0okGo0?n;ool0Cooo703ogOl0ool00?mG0?ook@3ooookJ_oo0;co
^?l0ogT0o`04oookJP0Bool01on>o`3o0?nGoolQ0?ooZ03ooo]Zooo70?oo01Co0?_ook3o0?l02ooo
=?l0oookJ_l0o`Wooo]ZoonW0?oonf[ooaX00_oonfX01_l0ongooo]ZoookJ_oonf[oo`3/o`3So`;o
oo]Z00Wo=_l0o`3oj?l0POooocD0ool02oooj03ooo]Zo`3ol?lY0?l00_oonfX00omI0?oooo]Zool0
ZP02oookJP;o001o00Goo`d0o`00Oom/0?oo001oof;o0008oookJP03on;o0?oonf[ooo]Z00?ooo]Z
00?oo`3fo`03oooonfX01?oonfX00ol0ogOoN@3ooiOo0007oookJP05oono0?oonf[ooo]ZoookJ_l0
ob401?oonfX00ooo0?;ooo]ZoookJP02oookJP04ool0X?oonf[oE03oo`0Uo`;ooo]Z00?o:P3ooook
J_oonfX00ooonfX01?mko`3ooo]ZoookJ_oo@@02o`00O`03oookJ_l0ocSooo]Z00;ooo]Z1Ol007l8
oookJP03ool0]Ooonf[ooo]Z02oooo]Z0ol007l5oookJPOo001o7?oonfX006Kooo]Z00?o0?l9oook
J_oonfX01?oonfX4oolX00?ooo]Z00?o/?l0oookJ_oo:0001_oo:0000ooo01Cooo]ZoookJP07oook
JP06oonX0?oonf[ooo]ZoookJ_oo0;Coob402_oonfX8oolX01;ooo]Z00?o^?l0oookJ_oonfX00ooo
nfX00om/0?oooo]ZoolX0006oolX00WoogT000Cod_l0oookJ_oonf[o^?l01_ooN@02oookJP03o`3o
Rooonf[o0?ne00?ooo]Z00?oo`2eoolP0?oonfX00_oob@002omko`3oolT0ooo90?oo0:3oolT0o`3o
8Ooob@3ookl0ogT0ool0ogOoolT000koA?l000?o0?n]o`3oj?l0/?l01?l0/?l00ol0oego0?lQodCo
0005odCo0003onGo0?oMo`3oo`0000KoiOl00_ooN@06ooo90003oomi0?ooZ03oolT000KoolT000Go
ogT0oonW0?oonf[ooaX0oookJP04oomi00?oobP00_oonfX00ooo003o0?oXoolX0003oolX0004ool0
0?oonf[o0?o`obT0o`;ooo]Z00?oF@3oool0Z_oonfX00ooonfX00ooo3@3ooo]Zof`0o`03oolX00So
oo]Z00?oh_l0oookJ_oonfX00ooonfX00ol00ooooo]ZoookJP03oookJPGoobP00_oonfX6oolX0003
ool00?oonf[o0?lQ00?ooo]Z00?oo`3boookJ_oonfX00ooonfX00ooo:03oE03oo`0Uo`03oookJP03
ool00?oonf[oobP000OoobP01Ooo000>oookJP03ool0]Ooonf[ooo]Z0;gooo]Z00?o0?l9oookJ_oo
nfX01OoonfX00ol02ooooo]ZoookJP03oookJP03ok3o0?oonf[o0?_o00?ooo]Z00CoCP3ooookJ_oo
nf[oo`0D2OoonfX01_ooZ03ooo]ZoookJ_oonf[oo`2doolQ00cooo]Z00?o0?o0oookJ_oo00L05Ooo
nfX00onho`3ooo]ZoookJP03oookJP03of`0oooonf[ooo]Z00?ooo]Z00gok@3ooookJ_nMo`3oo`3L
oeL0oooonf[oT`3ooookJ_oo003ooi/0ob/0oooonf[od_l000;ooo]Z00Go^?l0oolL0?oonf[o0?nF
ool0C`04oookJP03o`3oRooonf[o0?ne00?ooo]Z01Woo`2eoolP0?oonf[o0?lhoonL0?mko`3oo`X0
obX0oooo0:3oo`3boookJ_l0ob7o0?nRogT0ool0ogOooo]Zo`3oB?mJo`3oh_l0oookJ_mRo`3oK03o
o`3oCOlY0?oo0?o`00?o0?oX0ooo0>`3o`3oj00Do`3ol?ooh`3oK03oogT0ool0oj;o0?lQog_o0?l0
ocSoob00o`3oRooo04oooa`0om;o0?oMo`3oo`00ond0oooonf[oo`2loookJ_mi0?l4oookJP0Bool0
1on>o`3o0?nGoolQ0?oo0;CoojP0ooo70?oo01CoCP3oo`3kool02ooo=?l0oookJ_l0o`Wooo]ZoonW
0?oonf[ooaX00_oonfX01_l0ongooo]ZoookJ_oonf[oo`3/o`3So`;ooo]Z00Wo=_l0o`3oj?l0POoo
ocD0ool02oooj03ooo]Zo`3ol?lY0?l00_oonfX00omI0?oooo]Zool0ZP04oookJP05ool=0?oonf[o
K03ooookJ_mRo`002?oonfX00ooRo`3ooo]ZoookJP03oookJP03ool0m_l00ooooo]Z00Cooo]Z00?o
0?mgogT0oonGo`001ooonfX01Ooo_`3ooo]Zo`3oX_oonf[o0?lQ00Cooo]Z00?oo`3boookJ_oonfX0
0_oonfX01?oo0:3ooo]Zoe@0ool09Ol2oookJP03obX0oooonf[ooo]Z00?ooo]Z00CoNol0oookJ_oo
nf[ood400ooonfX00ol0ocSooo]ZoookJP0=oookJP03ool0]Ooonf[ooo]Z05_ooo]Z001VoookJP03
o`3o2Ooonf[ooo]Z00Cooo]Z1?oo:003oookJP03ok3o0?oo:03oobP000GoobP000?oo`0DoookJ_oo
nfX01ooonfX00oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00_ooo]Z00?o0?o0oolX0?oo
:0000ooo:00BoookJP03oolX0?oonf[ooo]Z00;ooo]Z00?oK03ooookJ_oonfX02Ooo:006oomi0004
om;o0?oonf[ooo]ZoookJPKoogT00ooonfX00ol0oh_o0?neoookJP02oookJP03ool0]Ooo803ooo]Z
00?oolT000?oNol0ooo90?oob@000_oob@001?l0ob7oolT0ooo90?mi0?l3oiCo013oA?l00ol0/?l2
o`3oG@03o`3o8Om4o`3oA?l000?oA?l000Co0?l<onGo0?oUo`3oo`001OoUo`03oomi00GoolT000Ko
ob40oomi0?ooZ03oogT0ooo90?ooN@03ooo900;oogT000CoojL0oookJ_oo6P3ooo]Z1?ooN@03oolX
00;ooo]Z00?oo`00o`3oj?oo:0001Ooo:0001_l0oo3o:@3ooookJ_oonf[oF@3oool0ZPCooo]Z00Go
o`d0oookJ_m/0?oooo]ZoolX0009oookJP03on;o0?oonf[ooo]Z00?ooo]Z00?o00?ooookJ_oonfX0
0ooonfX5oolX00?ooo]Z1Ooo:0000ooo003ooo]Zo`3o8@03oookJP03ool0l_oonf[ooo]Z00?ooo]Z
00?oo`2Poe@0oooo00001?oo00000ooonf[oobP0oolX0005oolX00Koo`003_oonfX00ooo0;Gooo]Z
oookJP2moookJP03o`3o2Ooonf[ooo]Z00Gooo]Z00?o00_ooookJ_oonfX00ooonfX00on`o`3o0?_o
oookJP02oookJP05odh0oooonf[ooo]ZoookJ_oo01@02?oonfX00oooZ03ooo]ZoookJP02oookJP03
oolQ0?oonf[ooo]Z00_ooo]Z00?o0?o0oookJ_oo00L05OoonfX00onho`3ooo]ZoookJP02oookJP03
of`0oooonf[ooo]Z00Cooo]Z00gok@3ooigo0?oonf[oo`3LoeL0oooonf[oT`3ooookJ_oo003ooo]Z
ob/0oooonf[od_l000;ooo]Z00Go^?l0oolL0?oonf[o0?nFool0C`04oookJP03o`3oRol0okGooo]Z
00;ooo]Z01koo`2eoolP0?oonf[ooo]Zo`3o>?ooW03oNol0obX0oomD0?ooo`2Pool0l_l0ob7o0?nR
oookJ_mi0?oo0?mgo`3oB?mJo`3o0?nnoookJ_mRo`3oK03oo`3oCOlY0?oo0?o`oole0?l0onSoo`3/
o`3okOoo6P04oonW000Eool0k?l0onSo0?oXof`0oomJo`3oN@3oo`3o8Ooo0:3oNol0ool0]Ol0oh_o
oo]Zool0Cooo703ogOl0ool00?o]0?ooWOl0of`0oooo0;coN@3o00Cooo]Z01;oo`07ohko0?l0oiOo
oo]ZoolQ0?ooZ03oolL0ool05?m>0?oo0?_oo`0;ooldo`3ooo]Zo`3o2Ooonf[oojL0oookJ_oo6P02
oookJP06o`3okOoonf[ooo]ZoookJ_oo0>co0>?o0_oonfX02Olfo`3o0?oXo`21oooo=@3oo`0;oooX
0?oonf[o0?o`obT0o`02oookJP03oeT0oooonf[oo`2Z00Cooo]Z00Goo`d0oookJ_m/0?oooo]Zof;o
0008oookJP03on;o0?oonf[ooo]Z00?ooo]Z00?oo`3fo`03oooonfX00ooonfX01?l0ogOooo]ZogT0
oonGo`06oookJP06oono0?oonf[ooo]Zo`3oX_oonf[o0?lQ0ooonfX00ooo0?;ooo]ZoookJP03oook
JP04ool0X?oonf[oE03oo`0Uo`;ooo]Z00?o:P3ooookJ_oonfX00ooonfX01?mko`3ooo]ZoookJ_oo
@@03oookJP03o`3o>?oonf[ooo]Z00gooo]Z00?oo`2eoookJ_oonfX0FooonfX006Kooo]Z00?o0?l9
oookJ_oonfX00ooonfX5oolX00;ooo]Z00?o/?l0oookJ_oo:0000_oonfX4oolX0003ool05?oonf[o
oo]Z00Oooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo8@3ooo]ZoookJP0;oookJP04o`3o`?oo:03o
oo]ZoookJP;oobP04_oonfX00ooo:03ooo]ZoookJP02oookJP03of`0oooonf[oobP000_oobP01?oo
N@001?oBo`3ooo]ZoookJ_oonfX6oomi00;ooo]Z00?o0?n;oookJ_l0okD00ooonfX00ooo0;Goob00
oomi0002ooo90003og_o0?oob@3oolT000;oolT000Go0?lQooo90?oob@3oiOl0ogT0o`02oiCo017o
A?l00ol0/?l2o`3oG@GoA?l000?o0?l<onGo0?oUo`001ooUo`02oomi0003oookJ_oob@3oolT000?o
olT000Koob40oomi0?ooZ03oogT0ool05?ooN@03ooo900;oogT000?oojL0oookJ_oo6P000_oonfX3
oomi00?oobP00_ooN@000ooo003o0?oXoolX0005oolX0006o`3ol?lY0?oooo]ZoookJ_mI0?ooo`2Z
1?oonfX01Ooo3@3ooo]Zof`0oooonf[oobP000Sooo]Z00?oh_l0oookJ_oonfX00ooonfX00ooo0?Ko
00?ooookJP04oookJP04o`3oMooo:03oobP0oolX00Cooo]Z1Ooo:0000ooo003ooo]Zo`3o8@03oook
JP03ool0l_oonf[ooo]Z00?ooo]Z00?oo`2Poe@0oooo00001Ooo0007oolX00Koo`003_oonfX00ooo
0;Gooo]ZoookJP2moookJP03o`3o2Ooonf[ooo]Z00Gooo]Z00?o00_ooookJ_oonfX00_oonfX00on`
o`3ooo]Zo`3ko`03oookJP05odh0oooonf[ooo]ZoookJ_oo01@02?oonfX00oooZ03ooo]ZoookJP02
oookJP03oolQ0?oonf[ooo]Z00_ooo]Z00?o0?o0oookJ_oo00L05OoonfX00onho`3ooo]ZoookJP02
oookJP03of`0oooonf[ooo]Z00Cooo]Z00gok@3ooigo0?oo0=cooo]ZoeL0oooonf[oT`3ooookJ_oo
003ooo]Zob/0oooonf[od_l000;ooo]Z00Go^?l0oolL0?oonf[o0?nFool0C`04oookJP03o`3oRol0
okGooo]Z00;ooo]Z01goo`2eoolP0?oonf[o203oo`3o>?mko`3ooo]ZobX0oomD0?ooo`2Pool0l_l0
ob7o0?nRoookJ_mi0?oo0?m8ool0m_mJo`3oh_l0of;o0?m/0?oo0?m=ool0Z_l0oo3oocD0o`3oj?oo
0>co0?o]ool0]002o`0;o`Coo`0D01GoojL0ool0k?l0onSoK03oo`3oMomi0?oo0?lQog_o0?l0ocSo
oo]Zo`3oRooo04oooa`0omgo0?oo003oE`3oond0oom/0?ooo`2logT0oooo03P00ooonfX04_oo00Oo
S_l0o`3oUooonf[oob40oonX0?ooa`3oo`0Dodh0ool0nooo00_oocCo0?oonf[o0?l9oookJ_ooY`3o
oo]ZoolJ00;ooo]Z00Ko0?o]oookJ_oonf[ooo]Zool0k?l0hol2oookJP09ocKo0?l0onSo087ooole
0?oo00_oonP0oookJ_l0oo3o:@3o00;ooo]Z00?oF@3ooookJ_oo0:X01?oonfX01Ooo3@3ooo]Zof`0
oooonf[oH_l000Sooo]Z00?oh_l0oookJ_oonfX00ooonfX00ol00ooooo]ZoookJP03oookJP04o`3o
Mooonf[oN@3ooiOo00Kooo]Z00Kookl0oookJ_oonf[o0?nRoookJ_l0ob43oookJP03ool0l_oonf[o
oo]Z00?ooo]Z00Coo`2PoookJ_mD0?oo02Go0_oonfX00olZ0?oooo]ZoookJP03oookJP04og_o0?oo
nf[ooo]Zoom100?ooo]Z00?o0?lhoookJ_oonfX03OoonfX00ooo0;Gooo]ZoookJP1KoookJP00I_oo
nfX00ol0o`Wooo]ZoookJP03oookJPGoobP00_oonfX00on`o`3ooo]ZoolX0003oookJP04oolX0?oo
nf[oobP0ool050Wooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo8@3ooo]ZoookJP0;oookJP03oolX
0?oonf[ooo]Z01Cooo]Z0_oo:004oookJP03of`0oooo:03oobP000_oobP000GoogT0ool00?ooN@3o
ogT0om;o0002oookJPOoogT00_oonfX00ol0oh_ooo]Zo`3o]@03oookJP03ool0]Ooo803oolT000;o
olT000?oNol0ooo90?oob@001Ooob@001?mi0?ooiOl0oiCo0?nDo`0AodCo00?o0;3o0_l0oed4odCo
0003o`3o3?l03oooiOl000;oiOl00ol0ojd2onGo00;oogT000?oiOl0oookJ_oob@001?oob@001_oo
8@3oogT0oonX0?ooN@3oo`0Doomi00?oolT00_ooN@000oooY`3ooo]ZoolJ0002oookJPCoogT000?o
obP0oomi0?ooN@000_ooN@000ol0onSoobP0oolX0004oolX0006o`3ol?lY0?oooo]ZoookJ_mI0?oo
o`2Z0_oonfX3ool00004oookJ_m/0?oooo]Zof;o00Sooo]Z00?oh_l0oookJ_oonfX00ooonfX00ol0
0ooooo]ZoookJP04oookJP04o`3oMooo:03oobP0oolX00Cooo]Z1Ooo:0000ooo003ooo]Zo`3o8@03
oookJP03ool0l_oonf[ooo]Z00?ooo]Z00?oo`2Poe@0oooo00001_oo0006oolX00Koo`003_oonfX0
0ooo0;Gooo]ZoookJP2moookJP03o`3o2Ooonf[ooo]Z00Gooo]Z00?o00_ooookJ_oonfX00_oonfX0
0on`o`3ooo]Zo`3ko`03oookJP05odh0oooonf[ooo]ZoookJ_oo01@02?oonfX00oooZ03ooo]Zoook
JP02oookJP03oolQ0?oonf[ooo]Z00_ooo]Z00?o0?o0ool01ooonfX05OoonfX00onho`3ooo]Zoook
JP02oookJP03of`0oooonf[ooo]Z00Cooo]Z00cok@3ooigo0?oo0=coE`3ooong0?oonf[oT`3ooook
J_oo003ooo]Zob/0oooBo`03oookJP05okSo0?oo703o0?nFoookJ_oo04l01?oonfX00ol0oh_o0?ne
oookJP02oookJP0Pool0]Ooo803ooo]Zo`3o>?ooW03oNol0oookJ_lZ0?ooo`2Pool0l_l0ob7o0?nR
o`2Roomi0?oo0?mgo`3oB?mJo`3oh_l0oookJ_m/0?ooon<0o`3oCOlY0?oo0?o`o`3oj?l0hoooo`3/
ool0]?ooY`3o00_oool05?ooZ003ool01`0Eool05?l02ooo0?oXo`3ol?ooh`3oN@3oo`3o8Omko`3o
0?lhool0]Ol0oh_oo`1?oolL0?oMo`3oo`00oeL0ooo]0?oooo]Zool0_?mi0?ooo`0h00?ooo]Z01;o
o`07ohko0?l0oiOooo]ZoolQ0?ooZ03oolL0ool05?m>0?oo0?_oo`0;ooldo`3ooo]Zo`3o2Ooonf[o
ojL0oookJ_oo6P02oookJP06o`3okOoonf[ooo]ZoookJ_oo0>co0>?o0_oonfX02Olfo`3o0?oXo`21
oooo=@3oo`0;oooX0?oonf[o0?o`obT0o`02oookJP03oeT0oooonf[oo`2Z00Cooo]Z00Goo`d0oook
J_m/0?oooo]Zof;o0008oookJP03on;o0?oonf[ooo]Z00;ooo]Z00?oo`3fo`03oooonfX01?oonfX0
1?l0ogOooo]ZogT0oonGo`06oookJP06oono0?oonf[ooo]Zo`3oX_oonf[o0?lQ0ooonfX00ooo0?;o
oo]ZoookJP03oookJP04ool0X?oonf[oE03oo`0Uo`;ooo]Z00?o:P3ooookJ_oonfX00ooonfX01?mk
o`3ooo]ZoookJ_oo@@03oookJP03o`3o>?oonf[ooo]Z00gooo]Z00?oo`2eoookJ_oonfX0FooonfX0
06Gooo]Z00?o0?l9oookJ_oonfX01?oonfX5oolX00;ooo]Z00?o/?l0oookJ_oo:0000ooonfX01?oo
:03ooo]ZoookJ_oo01@9oookJP06oonX0?oonf[ooo]ZoookJ_oo0;Coob403OoonfX00ooo:03ooo]Z
oookJP0DoookJP;oobP01?oonfX01?m/0?oooo]ZoookJ_oonfX6oolX0006oeL0oooo:03oobP0oolX
0?ooN@3oo`000_ooN@02oookJPSoogT00_oonfX00ol0oh_ooo]Zo`3o]@02oookJP03ool0]OooN@3o
olT000?oolT000?oNol0ooo90?oob@001?oob@000ooUo`3oN@3oonGo0002oiCo00GoA?l00_oUo`06
o`3o30;oo`070_l0o``3o`2`o`;o0?mM0om4o`000onDo`3o0?ono`3o[@06o`3o[@04onGo0?ooN@3o
ogT0ogT0o`;oiOl01?oob@001ol0oiOoob40oomi0?ooZ03oogT0ool05?ooN@000ooob@02oomi0003
oonW0?oonf[ooaX000;ooo]Z1?ooN@000ooo:03oogT0oomi0002oomi0003o`3oj?oo:03oobP000?o
obP000Oo0?o`oookJ_lY0?oooo]ZoeT0oooonf[oo`2Z00;ooo]Z1?oo00000om/0?ooo`00of;o0008
oookJP03on;o0?oonf[ooo]Z00?ooo]Z00?o00?ooookJ_oonfX01?oonfX01?l0ogOoobP0oolX0?oo
:004oookJPCoobP000?oo`00oookJ_l0ob401?oonfX00ooo0?;ooo]ZoookJP02oookJP03ool0X?oo
nf[oE03o00Ooo`001Ooo:004ool00003oookJ_oo003ooo]Z00kooo]Z00?oo`2eoookJ_oonfX0_Ooo
nfX00ol0o`Wooo]ZoookJP05oookJP03o`0;oooonf[ooo]Z00;ooo]Z00?o/?l0oookJ_l0nol00ooo
nfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Sooo]Z00KoojP0oookJ_oonf[ooo]Zool0]?oo8@0=oook
JP03o`3o`?oo00Oooo]Z01Gooo]Z00?o^?l0oookJ_oonfX00_oonfX00om/0?oooo]ZoookJP04oook
JP0<ond0oonMo`3oo`3LoeL0oooo]`3ooo]Zoi<0ooo/o`3oo`00oookJ_l[0?ood_l00ooonfX01Onh
o`3ooa`0o`3oU_oonf[oo`1?00?ooo]Z00?o0?n;oookJ_l0okD00_oonfX09?oo0;Gooo]ZoolP0?oo
nf[o0?lhoom10?mko`3oo`X0obX0oooo0:3oo`3bo`3o8Ol0oj;ooo]ZogT0ool0ogOo0?m8oe[o0?oo
nf[oH_l0of`0ool0odgoo`2Zo`3ol?oo=@3o0?oXool0k?oo6P3oojL0o`0;oooo01Coob40ool01ooo
0;cok@3oool000;oo`0701?o00_oo`3oj?m/0?ooF_l0o`3o8Omko`3o0?lhool0]Ol0oh_oo`1?oolL
0?oMo`3oo`00oeL0ooo]0?oooo]Zool0_?mi0?ooo`0h00?ooo]Z00ooo`07ohko0?l0oiOooo]ZoolQ
0?ooZ03oolL0ool05?m>0?oo0?_oo`0;ooldo`3o0?l9oookJ_ooY`000_oonfX01?oo6P3ooo]Zoook
J_l0ond3oookJP0=ool0k?l0hooooo]ZoookJ_lfo`3o0?oXo`21oooo=@3oo`0;oooX0?oonf[o0?o`
obT0o`02oookJP03oeT0oooo0:[ooo]Z00Cooo]Z00Goo`d0of`0oooonf[ooo]Zof;o0008oookJP03
on;o0?oonf[ooo]Z00;ooo]Z00?oo`3fo`03oooonfX01?oonfX01?l0ogOooo]ZogT0oonGo`06oook
JP03oono0?oonf[o0?nR00;ooo]Z00Go0?lQoookJ_oonf[ooo]Zool0lP04oookJP07ool0X?oonf[o
oo]Zoe@0ool09Ooooo]ZobX0o`06oookJP04og_o0?oonf[ooo]Zoom100?ooo]Z00?o0?lhoookJ_oo
nfX03OoonfX00ooo0;Gooo]ZoookJP1KoookJP00:?oonfXmo`000003o`3o2Ol0003o000000?o0000
1_oo:002o`000003ok3o0?oo:03o000000?o000000CoobP0o`000?l0003oo`0D2Ol000001OooZ03o
0000o`000?l0003oob4000go000000?o0?o0ool01ol000005Ol00002oolX00Co000000?oK03oo`00
0?l000000ol000002Oo]0?ooWOl0oolX0?oo:03oE`3ooomi0?nC0?ooobP0ool00003oomi0003o`00
0?ooN@3oogT000OoogT00_l000000ol0oh_o0?neo`000002o`000003ool0]Ooob@3oolT000[oolT0
00?oiOl0ogT0oooUo`000_nDo`03odCo0003o`2`oooUo`3oiOl000;oiOl00ol0/?l01?oo01Co0;3o
ool01ol0/?l3o`3o3004o`2`ool0o`co0?mMo`3oj0;oA?l02_l0ojd01?oUo`3oogT0ool0_?mi0?l2
onGo00CoolT000Go0?nGoolQ0?ooN@3oojP0ool05002ooo90008oomi0?oob@3o=?l0oomi0?l0003o
ojL0o`000?oo6P02o`0000CoogT000?oo`3/oomi0?ooN@000_ooN@000ol0onSoobP0oolX0003oolX
0007o`3ol?l0003o:@3oo`000?mI0?oo0000ool0ZP02o`0000Coo`0000CoK03oool00?oo003oo`00
1ol000000ooRo`3o0000o`000003o`000003o`03ool0003o000000Co000000Co0?mgoolX0?oo:03o
obP01?l00004oolX0003ool00?l0003o0?lQ00Co000000?oo`3bo`000?l000000_l000000ooo0:3o
0000oe@0o`07ool000GoobP01?oo00000ol0003oo`00o`00000>o`000003ool0]Ol0003o000003Oo
0000B?oonfXno`000003o`3o2Ol0003o000000Go000000?o00_oo`000?l000000_l000000on`o`3o
0?_oo`000003o`000004odh0ool0003o0000ool050Wo000000GoojP0o`000?l0003o0000oolQ000=
o`000003o`3o`?l0003oo`0701Ko000000?o^?l0o`000?l000000_l000000om/0?oo0000o`000003
o`000005ond0ool0003oWOl0ool0g?mG0?l00_l000001_nC0?ooo`00oonK0?l[0?oo0000om;o00;o
000000Go^?l0oolL0?l0003o0?nFool0C`04o`000003o`3oRol0okGo000000;o000002Goo`2eo`00
0?oo803o0000o`3o>?oo@@3oNol0obX0oomD0?ooo`2Pool0l_l0ob7ookl0o`000?mi0?oo0?mgo`3o
__mJo`3o0000of;o0?m/0?oo0?m=ool0Z_l0oo3o0?oXo`3Soooo0>co7@3ooonW0?oo01CoojP0ool0
1omi0?ook@3oool00?oMo`3oo`0000;oo`0701;o0?oXo`3ol?mJo`3oN@3oo`3o8Omko`3oo`2eo`3o
Rooo04oooa`0omgo0?oo003oE`3oond0ool0003oo`2logT0oooo03P3o`00000?ool01on>o`3o0?nG
o`000?oo8@3oojP0ooo70?oo01CoCP3oo`3kool02ooo=?l0o`3o2Ol0003oojL000;o000000CooaX0
o`000?l0003o0?o]0ol000003Ooo0>co0000o`000?l0003o=_l0o`3oj?l0POooocD0ool02oooj03o
0000o`3ol?lY0?l00_l000000omI0?ooo`2Zo`000003o`000005ool=0?l0003oK03oo`000?mRo`00
2Ol000000ooRo`3o0000o`000002o`000003ool0m_l00ooo000000Co000000Co0?mgo`000?mi0?oo
Uol01_l000000ooo_`3o0000o`3oXP02o`000005o`3o8Ol0003o0000o`000?oo0?801?l000001ooo
0:3o0000o`000?mD0?oo02Goo`000?lZ0?l01_l000001?mko`3o0000o`000?oo@@03o`000003o`3o
>?l0003o000000go000000?oo`2eo`000?l00000>?l0000SoookJP00:?oonfXmo`000003o`3o2Ol0
003o000000?o00001_oo:002o`000003ok3o0?oo:03o000000;o000000CoobP0o`000?l0003oo`0D
2Ol000000oooZ03o0000o`000002o`000003oolQ0?l0003o000000_o000000?o0?o0ool01ol00000
5?l00004oolX00;o000000?oK03oo`000?l000001?l000002Oo]0?ooWOl0o`000?oo0=coE`3ooomi
0?nC0?ooogT0ool00003oomi00?o00001_ooN@02o`000003o`3oRol0003o0?ne00?o000000?oo`2e
ooo90?oob@002_oob@001?oUo`3oN@3oonGo0?oUo`04oiCo00GoiOl00ol0/?l01Ooo01CoU?l0o`2`
ool0/?ooA?l000;o0?mM00?o00ooo`3o3?l0ojd03Ol0ojd01OooN@3oolT0ool0_?mi0?ooiOl000Go
olT000Go0000oolQ0?ooZ03oogT0ool05002ooo90008oomi0?oob@3o=?l0oomi0?l0003oojL0o`00
0?oo6P03o`000004oomi0?l0003oogT0ool0k0CoogT000?o0?oXoolX0?oo:0000ooo:0001ol0oo3o
0000obT0ool0003oF@3oo`000?oo0:X00_l00004ool00004of`0oooo003oo`00ool000Oo000000?o
h_l0o`000?l000000ol000000ol00ooo0000o`000004o`000004o`3oMol0003oobP0oiOo00Co0000
1Ooo00000ol0003o0?lQo`000003o`000003ool0l_l0003o000000;o000000Coo`2Po`000?mD0?oo
02Go1_oo0005oolX00Coo`0000?o0000o`3o>?l000003Ol000000ooo0;Go0000o`00000ho`0004So
oo]Z?_l000000ol0o`Wo0000o`000005o`000003o`0;ool0003o000000;o000000?o/?l0o`3kool0
00000_l000001Om>0?oo0000o`000?l0003oo`0D00So000000?oojP0o`000?l000000_l000000ooo
8@3o0000o`00000;o`000003o`3o`?l0003oo`0701Ko000000Go^?l0o`000?l0003o0000of`0o`06
o`00000=ond0oonMo`3o0000ool0g?mG0?oo0000oi<0ool0003oo`00o`000?l[0?oo0000om;o0002
o`000005okSo0?oo703o0000o`3oU_oo04l01?l000000ol0oh_o0?neo`000002o`00000Tool0]Ooo
803o0000o`P0ool0ocSoNol0o`000?lZ0?ooE03oool0X?l0ob7o0?nRo`2Roooo9`3oN@3oo`3oB?l0
okkoF_l0o`000?mRo`3oK03oo`3oCOmI0?oo0?o`o`3oj?oo0>co0?o]ool0]?l02oooo`0DoonX0?oo
00Ooo`2lool00?oo04oo0?lQ0ooo00L04_l0onSo0?o`oe[o0?l0ob7oo`2Pog_o0?oo0;Go0?n;ool0
Cooo703ogOl0ool00?mG0?ook@3oo`000?oo0;coN@3oool0>0?o000000ooo`07ohko0?l0oiOo0000
oonX0?l0003oolL0ool05?m>0?oo0?_oo`0;ooldo`3o0?l9o`000?ooY`000_l000001?oo6P3o0000
o`000?l0ond3o`00000=ool0k?l0003o0000o`000?lfo`3o0?oXo`21oooo=@3oo`0;oooX0?l0003o
0?o`obT0o`02o`000003oeT0oooo0:[o000000?o000000Goo`d0oooS0?m/0?oo0000of;o0009o`00
0003on;o0?l0003o000000;o000000?oo`3fo`03ool000001?l000001?l0ogOo0000ogT0oonGo`06
o`000003oono0?l0003o0?nR00;o000000Go0?lQo`000?l0003o0000ool0lP04o`000007ool0X?l0
003o0000oe@0ool09Ooo0000obX0o`06o`000004og_o0?l0003o0000oom100?o000000?o0?lho`00
0?l000003?l000000ooo0;Go0000o`00000io`0002?ooo]Z000XoookJSgo000000?o0?l9o`000?l0
00000ol00007oolX0003o`000?n`o`3o0?_o00?o000000CoobP0o`000?l0003oo`0D2Ol000000ooo
Z03o0000o`000002o`000003oolQ0?l0003o000000_o000000?o0?o0ool01ol000005?l00004oolX
00;o000000?oK03oo`000?l000001?l000002Oo]0?ooWOl0o`000?oo0=coE`3ooomi0?nC0?ooogT0
ool00004oomi00;o000000?o^?l0oolL0?l000000oooN@02o`000003o`3oRol0003o0?ne00?o0000
3?oob@000ooUo`3oN@3oonGo0002onGo00;oU?l01_oUo`04o`2`o`05ool05?nDo`3o0;3oonGo0?m4
o`000_l0oed01?l0ojgo0?mMo`3oGOl0oed<o`3o[@04o`3oGOm4o`3oo`2logT0o`KoolT000Go0000
oolQ0?ooZ03oogT0ool05002ooo90008oomi0?l02oooogT0o`3o2Ol0003oojL0o`000?oo6P03o`00
0004oomi0?l0003oogT0ool0k0CoogT000?o0?oXoolX0?oo:0000_oo:0001ol0003o0?o`o`000?lY
0?oo0000oeT0oooo0:X00ol00004ool00003of`0oooo003oo`0000So000000?oh_l0o`000?l00000
0_l000000ooo0?Ko00?oo`000005o`000004o`3oMol0003oobP0oiOo00Co00001_oo00001Ol0ob7o
o`00ool00?l0003oo`3b00Go000000Coo`2Po`000?mD0?oo02Go1Ooo00000ol0003oobP0oolX0002
oolX00Coo`000_l000000ol0ocSo0000o`00000<o`000003ool0]Ol0003o000003So0000B?oonfXn
o`000003o`3o2Ol0003o000000Go000000?o00_oo`000?l000000_l000000on`o`3o0?_oo`000002
o`000005odh0ool0003o0000o`000?oo01@02?l000000oooZ03o0000o`000002o`000003oolQ0?l0
003o000000_o000000?o0?o0o`000?oo00L05_l000001Onho`3o0000o`000?l0003oK03o00Ko0000
00gok@3ooigo0?l0003oo`3LoeL0ool0003oT`3oo`000?oo003o0000ob/0ool0003od_l000;o0000
00Go^?l0oolL0?l0003o0?nFool0C`04o`000003o`3oRol0okGo000000;o000002Coo`2eoolP0?l0
003o203oo`3o>?mko`3o0000obX0oomD0?ooo`2Po`3o8Ol0oj;o0:;oogT0ool0ogOo0?m8oe[o0?oR
o`3o0000of;o0?m/0?oo0?m=obT0ool0oo3o0?oXool0k?l0ongoojL0o`0;oooo01CoojP0ool01ooo
0;coo`00ool0Col0ob43ool01`0Ao`3oj?m/0?oo0?mgo`3o8Ooo0:3oNol0ool0]Ol0oh_oo`1?oolL
0?oMo`3oo`00oeL0ooo]0?ooK03oool0_?mi0?l00ol000004?oo00Oo0?o0ohko0?l0oiOoob40oonX
0?ooa`3o0000ool05?l0nooo/?l0o`0;ooldo`3o0?l9o`000?ooY`02o`000004oolJ0?l0003o0000
o`3ok@;o000000?oo`3/o`3Sool000000_l000003Olfo`3o0?oXo`21oooo=@3oonP0o`000?l0oo3o
0000obT0ool0003oF@3oo`000?oo0:X01?l000001Ooo3@3oon<0of`0ool0003oH_l000So000000?o
h_l0o`000?l000000ol000000ooo0?Ko00?oo`000004o`000004o`3oMol0003oN@3ooiOo00Ko0000
00?ookl0o`000?l0oj800_l000001Ol0ob7o0000o`000?l0003oo`3b00Co000000Ooo`2Po`000?l0
003oE03oo`0Uool0003o:P3o00Go000000GoNol0o`000?l0003o0000oom10003o`000003o`3o>?l0
003o000000co000000?oo`2eo`000?l00000>Ol0000SoookJP00:?oonfXmo`000003o`3o2Ol0003o
000000;o00002?oo:0000ol0003o/?l0o`3ko`03o`000004oolX0?l0003o0000ool050Wo000000?o
ojP0o`000?l000000_l000000ooo8@3o0000o`00000;o`000003o`3o`?oo00Oo000001Co00001?oo
:002o`000003of`0ool0003o000000?o000000[ok@3oo`000?nMo`3oo`3Loong0?mG0?ooogT0oi<0
ooooN@3oo`001?ooN@02o`000006okSo0?oo703o0000ool0Col0003oogT00_l000000ol0oh_o0000
o`3o]@02o`0000goolT000?oogT0ogT0oooUo`002_oUo`04o`2`o`;oU?l000Oo0?mModCo0?m4o`3o
0?mMo`3o3?l0ojgo0?oX00Oo0?mM1ol0ojd00ol0oegoA?l0ool0_008ooo90004oolQ0?ooZ03oogT0
ool050;oolT000SoogT0o`0;ooooN@3oogT0o`000?ooY`3o0000oolJ00?o000000Co0?o]o`000?oo
N@3oo`3/0oooN@000ol0onSoobP0oolX0003oolX0007o`000?l0oo3o0000obT0ool0003oF@3oool0
ZP03o`0000?oo`0000CoK03oool00?oo003oo`002?l000000ooRo`3o0000o`000002o`000003ool0
m_l00ooo000000Go000000Co0?mgo`000?mi0?ooUol01?l00006ool00005o`3o8Ooo003oo`00o`00
0?oo0?801Ol000001?oo0:3o0000oe@0ool09Ol5ool00003o`000?oo:03oobP000;oobP01?oo0000
0ol0003o0?lho`00000>o`000003ool0]Ol0003o000003So0000B?oonfXmo`000003o`3o2Ol0003o
000000Ko000000?o00_oo`000?l000000_l000000on`o`3o0?_oo`000002o`000005odh0ool0003o
0000o`000?oo01@02?l000000oooZ03o0000o`000002o`000003oolQ0?l0003o000000_o000000?o
0?o0o`000?oo00L05_l000001Onho`3o0000o`000?l0003oK03o00Ko000000gok@3ooigo0?oo0=co
0000oeL0ool0003oT`3oo`000?oo003o0000ob/0ool0003od_l000;o000000Go^?l0oolL0?l0003o
0?nFool0C`04o`000003o`3oRol0okGo000000;o000002Goo`2eoolP0?l0003o203oo`3o>?mko`3o
0000obX0oomD0?ooo`2Po`3o8Ol0oj;o0:;oogT0ool0ogOo0?m8oe[o0?oRo`3o0000of;o0?m/0?oo
0?m=obT0ool0oo3o0?oXool0k?l0ongoojL0o`0;oooo01CoojP0ool01ooo0;coo`00omgo0?l0oj;o
0?lQ00;o0?oX017o0?o`of`0oomi0?oo0?lQog_o0?l0ocSoo`2eo`3oRooo04oooa`0omgo0?oo003o
k@3oo`000?m/0?ooo`2logT0o`03o`00000Bool01on>o`3o0000o`3oUooo8@3oojP0ooo70?l0003o
o`0Do`3koon`o`3o00_oocCo0?l0o`Wo0000oonW0?l0003ooaX00ol000001Ol0ongo0000o`000?oo
0>co0>?o00;o000000ko=_l0o`3oj?l0POooocD0ool02oooj03o0000o`3ol?l0003o:@3oo`000?mI
0?oo0000ool0ZPCo000000Goo`d0oooS0?m/0?oo0000of;o0008o`000003on;o0?l0003o000000?o
000000?o00?oo`000?l000001?l000001?l0ogOo0000ogT0oonGo`06o`000003oono0?l0003o0?nR
00;o000000Go0?lQo`000?l0003o0000ool0lP04o`000007ool0X?l0003o0000oe@0ool09Ooo0000
obX0o`05o`000004og_o0?l0003o0000oom100?o000000?o0?lho`000?l000003Ol000000ooo0;Go
0000o`00000io`0002?ooo]Z000ZoookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0?l9oookJ_oonfX0
0_oonfX8oolX0003ok3o0?oonf[o0?_o00?ooo]Z00CoobP0oookJ_oonf[oo`0D2OoonfX00oooZ03o
oo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00_ooo]Z00?o0?o0ool01ooonfX04ooonfX5oolX00;o
oo]Z00?oK03ooookJ_l000000ooonfX01oo]0?ooWOl0oookJ_oo0=coE`3ooomi0?nC0?l00_ooN@00
0ooo003oogT0oomi0002oomi00;ooo]Z00Co^?l0oolL0?oonf[oo`1?1?oonfX01?l0oh_ooo]Zo`3o
]OoonfX>ooo90003onGo0?oob@3oiOl000[oiOl00_l0/?l00oooY`3oU?l0oiCo0002oiCo00;oA?l0
00Go0?l<o`3o[Ol0ojgo0?n]odCo000;o`3oG@;o0?n]00?o0?mModCo0?m4o`002Ooob@001oooZ03o
ogT0ool05?m>0?ooolT0oomi0?l02ol00oooN@000oooY`3ooaX0oookJP03oookJP03o`3okOoonf[o
o`3/00CoogT000?o0?oXoolX0?oo:0000_oo:002oookJP06o`3ol?lY0?oooo]ZoookJ_mI0?ooo`2Z
0ooonfX3ool00003of`0oooo003oo`0000Gooo]Z0ooo:0000ooonf[oh_l0oookJP03oookJP03ool0
m_l00ooooo]Z00Gooo]Z00Co0?mgoookJ_mi0?ooUol01?oonfX6ool00005oolX0?oo003ooo]Zoook
J_oo0?801OoonfX01?oo0:3ooo]Zoe@0oooonfX5ool00003oookJ_oo:03oobP000;oobP01?oo0000
1Ooonf[o0?lhoookJ_oonf[o000000cooo]Z00?oo`2eoookJ_oonfX0=_oonfX00ol0003ooo]Zoook
JP19oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0?l9oookJ_oonfX01OoonfX02?l02ooooo]Zoook
J_oonf[o0000ok3o0?oonf[o0?_o0ooonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Sooo]Z00?oojP0
oookJ_oonfX00_oonfX00ooo8@3ooo]ZoookJP0;oookJP03o`3o`?oonf[oo`0701Kooo]Z00Oo^?l0
oookJ_oonf[ooo]Zof`0oooonf[o000000Cooo]Z00gok@3ooigo0?oo0=coE`3ooong0?oonf[oT`3o
oookJ_oo003ooo]Zob/0oooonf[od_l000;ooo]Z00Go^?l0oolL0?oonf[o0?nFool0C`04oookJP03
o`3oRol0okGooo]Z00;ooo]Z02Coo`2eoolP0?oonf[o203oo`3o>?mko`3ooo]ZobX0oooo0:3oo`3b
o`3o8Ol0oj;o0:;oogT0ool0ogOo0?m8oe[o0?oRo`3ooo]Zof;o0?m/0?oo0?m=obT0ool0oo3o0?oX
ool0k?l0ongoojL0ocCo0?oo01CoojP0ool01ooo03Sok@3oool00?oo04l2o`3o8@;oN@3o0_l0ob40
3_oo0:3oNol0ool0]Ol0okGo0?n;ool0Cooonf[oo`00oeL0ooo]0?oooo]Zool0_?nho`3oN@3o0ooo
nfX04_oo00OoS_l0oookJ_l0oiOoob40oonX0?ooa`3ooo]Zool05?l0nooo/?l0o`0;ooldo`3o0?l9
oookJ_ooY`3ooo]ZoolJ00?ooo]Z00Go0?o]oookJ_oonf[oo`3/o`3So`02oookJP09ocKo0?l0onSo
087ooole0?oo00_oonP0oookJ_l0oo3o:@3o00;ooo]Z00?oF@3ooookJ_oo0:X01?oonfX01Oooh`3o
oo]Zof`0oooonf[oH_l000Sooo]Z00?oh_l0oookJ_oonfX00ooonfX00ol00ooooo]ZoookJP04oook
JP04o`3oMooonf[oN@3ooiOo00Kooo]Z00?ookl0oookJ_l0oj800_oonfX01Ol0ob7ooo]ZoookJ_oo
nf[oo`3b00Cooo]Z00Coo`2PoookJ_oonf[oE03o0_oonfX00olZ0?oooo]ZoookJP03oookJP04og_o
0?oonf[ooo]Zoom100?ooo]Z00Co0?lhoookJ_oonf[o00003?oonfX00ooo0;Gooo]ZoookJP0goook
JP03o`000?oonf[ooo]Z02;ooo]Z001ToookJP03o`3o2Ooonf[ooo]Z00Kooo]Z00?oobP0oookJ_oo
:0000_oo:0000on`o`3ooo]Zo`3ko`03oookJP04oolX0?oonf[ooo]Zool050Wooo]Z00?oojP0oook
J_oonfX00_oonfX00ooo8@3ooo]ZoookJP0;oookJP03o`3o`?oo00Oooo]Z01?ooo]Z1Ooo:002oook
JP03of`0oooonf[ooo]Z00?ooo]Z00Ook@3ooigo0?oonf[oo`00oeL0oooonf[oT`3o00;oogT000?o
o`00oomi0?ooN@000_ooN@02oookJP04okSo0?oo703o0?nFool0C`Cooo]Z00Co0?n;oookJ_l0okGo
oo]Z4?oob@0:onGo0005o`3oj?oUo`3oiOl0oonW0?l0oed00onDo`02odCo0004ool00?l0ojgo0?n]
o`3o[@;oA?l03Ol0oed2odCo00CoolT000_oo`07ooo90?oob@3oo`2doonX0?ooN@3oolL0ool05?m>
0?oo0?_oo`0;o`03oomi0003oonW0?ooN@3ooaX000?ooo]Z00Co0?o]oookJ_ooN@3oo`3/1?ooN@00
0ol0onSoobP0oolX0002oolX0004oomi0?l0oo3ooo]ZobT0o`;ooo]Z00?oF@3oool0Z_oonfX00_oo
nfX3ool00003of`0oooo003oo`0000Gooo]Z1ooo:002oookJP03ool0m_l00ooooo]Z00Cooo]Z00Go
0?mgoookJ_mi0?ooobL0oiOo0004oookJPKoo`0000GoobP0ool00?oonf[ooo]Zool0lP04oookJP05
ool0X?oonf[ooo]Zoe@0oooonfX01?oo0003oookJP;oobP000Cooo]Zool00?oo003oo`000_oonfX0
0ol0ocSooo]ZoookJP0=oookJP03ool0]Ooonf[ooo]Z0;gooo]Z00?o0?l9oookJ_oonfX01OoonfX0
0ol02ooooo]ZoookJP02oookJP03ok3o0?oonf[o0?_o00?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool0
5008oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oob40oookJ_oonfX02ooonfX00ol0ol3ooo]Zool0
1`0EoookJP03okSo0?oonf[ooo]Z00;ooo]Z00?oK03ooookJ_oonfX01?oonfX03Oo]0?ooWOl0ool0
g?mG0?oookL0oookJ_nC0?ooo`2Yool00?oonf[o:`3ooookJ_oBo`000_oonfX01Onho`3ooa`0o`3o
U_oonf[oo`1?00Cooo]Z00?o0?n;o`3o]OoonfX00_oonfX09_oo0;Goob00oookJ_l80?oo0?lhog_o
0?oo2P3o:P3oool0X?oo0?;o0?lQo`3oX_l0X_ooN@3oo`3oMol0odSoF_l0on;o0?oonf[oH_l0of`0
ool0odgo:@3oo`3ol?l0onSo0>?oool0k?ooY`3o=?l0o`0;oooo01CoS_l0ool01ooo0;coo`00omgo
0?l0oh_oNol00ol0ob42og_o000=ool0]Ooonf[o0?n;ool0Cooo703od_l0ool00?mG0?ook@3oof`0
oooo0;co^?l0ogT0o`03oookJP0Bool01on>o`3o0?nGoookJ_oo8@3oojP0ooo70?oo01CoCP3oo`3k
ool02ooo=?l0oookJ_l0o`Wooo]ZoonW0?oonf[ooaX00_oonfX01_l0ongooo]ZoookJ_oonf[oo`3/
o`3So`;ooo]Z00Wo=_l0o`3oj?l0POooocD0ool02oooj03ooo]Zo`3ol?lY0?l00_oonfX00omI0?oo
o`2ZoookJP04oookJP04oooS0?oonf[oK03oof;o00Wooo]Z00?oh_l0oookJ_oonfX00ooonfX00ol0
0ooooo]ZoookJP03oookJP05o`3oMooonf[oN@3ooolW0?nGo`001_oonfX00ooo_`3ooo]Zo`3oXP02
oookJP05o`3o8Ooonf[ooo]ZoookJ_oo0?800ooonfX01Ooo0:3ooo]ZoookJ_oonf[oE03o00;ooo]Z
00?o:P3ooookJ_oonfX00ooonfX01?mko`3ooo]ZoookJ_oo@@03oookJP03o`3o>?oonf[ooo]Z00go
oo]Z00?oo`2eoookJ_oonfX0G?oonfX006Cooo]Z00?o0?l9oookJ_oonfX01_oonfX00ooo:03ooo]Z
oookJP02oookJP03ok3o0?oonf[o0?_o00;ooo]Z00CoobP0oookJ_oonf[oo`0D2_oonfX00oooZ03o
oo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00_ooo]Z00?o0?o0ool01ooonfX04ooonfX5oolX00;o
oo]Z00?oK03ooookJ_oonfX00ooonfX00oo]0?ooWOl0oookJP02ool00005oookJ_nC0?ooogT0oomi
0?oo00001?ooN@02oookJP04okSo0?oo703o0?nFool0C`Cooo]Z00?o0?n;oookJ_l0okD04_oob@09
onGo0003o`3oj?oUo`3o0?mM00;o0?mM0onDo`02odCo0004o`3o3?l0ojgo0?n]o`3o[@;o0?l<00?o
A?l0o`3oGOl0oed02Ol0oed2odCo00CoolT000coo`07ooo90?oob@3oogT0oolQ0?ooZ03oolL0ool0
5?m>0?oo0?_ooomi0?l02ol3oomi0003oonW0?ooN@3oogT000?ooo]Z00Co0?o]oookJ_ooN@3oo`3/
0oooN@000ooo:03o0?oXoolX0002oolX0003oooX0?ooN@3o0?o`00?oogT000?oF@3ooookJ_oo0:X0
0ooonfX3ool00003of`0oooo003oH_l000Gooo]Z2Ooo:0000ooo0?Ko00?ooookJP04oookJP05o`3o
Mooonf[oN@3ooolX0?nGo`001?oonfX6ool00005oolX0?oonf[ooo]ZoookJ_oo0?801?oonfX01Ooo
0:3ooo]Zoe@0ool09Ooooo]Z00Coo`000ooonfX2oolX0004oookJ_oo003oo`00ool000;ooo]Z00?o
0?lhoookJ_oonfX03OoonfX00ooo0;Gooo]ZoookJP2moookJP03o`3o2Ooonf[ooo]Z00Gooo]Z00?o
00_ooookJ_oonfX00_oonfX00on`o`3ooo]Zo`3ko`02oookJP05odh0oooonf[ooo]ZoookJ_oo01@0
2OoonfX00oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00_ooo]Z00?o0?o0oookJ_oo00L0
5OoonfX00onho`3ooo]ZoookJP02oookJP03of`0oooonf[ooo]Z00Cooo]Z00cok@3ooigo0?oo0=co
E`3ooong0?oonf[oT`3oool0ZOoo003ooo]Zob/0oooBo`03oookJP05okSo0?oo703o0?nFoookJ_oo
04l01?oonfX00ol0oh_o0?neoookJP02oookJP0Sool0]Ooo803ooo]Zo`P0ool0ocSoNol0ool:0?lZ
0?ooo`2Pool0l_l0ob7o0?nRoono0?mi0?oo0?mgo`3oB?l0okkoF_l0oookJ_mRo`3oK03oo`3oCOmI
0?oo0?o`o`3oj?oonf[oo`3/oad0ooooY`3o00_oool05?ooZ03oo`07ogT0ooo]0?l00_oo00001Ooo
04oo0?n;ool0]Ol0ocSoo`2e00;o0?n;0_oo04l02Ooo703ogOl0ool00?mG0?ook@3ooookJ_m/0?oo
o`2logT0o`03oookJP0Bool01ol0ol3oS_l0o`3oUooo8@3oojP0oookJ_ooa`3oo`0Do`3koon`o`3o
00_oocCo0?l0o`Wooo]ZoonW0?oonf[ooaX00ooonfX01_l0ongooo]ZoookJ_oonf[oo`3/o`3So`;o
oo]Z00Wo=_l0o`3oj?l0POooocD0ool02oooj03ooo]Zo`3ol?lY0?l00_oonfX00omI0?ooo`2Zoook
JP04oookJP04oooS0?m/0?oooo]Zof;o00Wooo]Z00?oh_l0oookJ_oonfX00ooonfX00ol00ooooo]Z
oookJP03oookJP05o`3oMooonf[oN@3ooolW0?nGo`001_oonfX00ooo_`3o0?nRoookJP02oookJP05
o`3o8Ooonf[ooo]ZoookJ_oo0?800ooonfX01Ooo0:3ooo]ZoookJ_mD0?oo02Go00;ooo]Z00?o:P3o
oookJ_oonfX00ooonfX01?mko`3ooo]ZoookJ_oo@@03oookJP03o`3o>?oonf[ooo]Z00gooo]Z00?o
o`2eoookJ_oonfX0G?oonfX006Cooo]Z00?o0?l9oookJ_oonfX01_oonfX00ooo:03ooo]ZoookJP02
oookJP03ok3o0?oonf[o0?_o00;ooo]Z00CoobP0oookJ_oonf[oo`0D2_oonfX00oooZ03ooo]Zoook
JP02oookJP03oolQ0?oonf[ooo]Z00_ooo]Z00?o0?o0ool01ooonfX04_oonfX6oolX00;ooo]Z00?o
K03ooookJ_oonfX00ooonfX00oo]0?ooWOl0oookJP02ool00005oookJ_nC0?ooogT0oomi0?oo0000
1?ooN@02oookJP04oolL0?oonf[o0?nFool0C`Cooo]Z00?o0?n;oookJ_l0okD00_oonfX?ooo900[o
iOl01Ol0oed3oiCo0003ool01om4o`3o0?l<00?o0?n]0_nDo`02o`3o30Wo0?mM00?o0?l<odCo0?m4
o`001?oob@003?oo00OoolT0ooo90?ooN@3oob40oonX0?ooa`3oo`0Dodh0ool0noooogT0o`0;o`?o
ogT000CoojL0oomi0?ooN@3oogT00_oonfX01?l0ongooo]Zoomi0?oo0>`2oomi00;oobP000?o0?oX
oolX0?oo:0000_oo:0000oooN@3o0?o`oomi0004oomi0004ool0Z_oonf[ooo]ZoookJP?oo`0000?o
K03oool00?mRo`001OoonfX9oolX0003o`03oooonf[ooo]Z00;ooo]Z0_oo:0001?l0ogOooo]ZogT0
oonGo`05oookJPGoo`0000?oobP0ool00?oonfX00_oonfX00ooo0?;ooo]ZoookJP02oookJP05ool0
X?oonf[oE03oo`0UoooonfX01?oo0003oookJP;oobP00_oonfX2ool00003oookJ_l0ocSooo]Z00ko
oo]Z00?oo`2eoookJ_oonfX0__oonfX00ol0o`Wooo]ZoookJP05oookJP03o`0;oooonf[ooo]Z00;o
oo]Z00?o/?l0oookJ_l0nol00_oonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Wooo]Z00?oojP0oook
J_oonfX00_oonfX00ooo8@3ooo]ZoookJP0;oookJP03o`3o`?oonf[oo`0701Gooo]Z00?o^?l0oook
J_oonfX00_oonfX00om/0?oooo]ZoookJP03oookJP0=ond0oooonf[oWOl0ool0g?mG0?oookL0oook
J_nC0?ooo`2Yool00?oonf[o:`3oom;o0003oookJP05okSo0?oo703o0?nFoookJ_oo04l00ooonfX0
0ol0oh_ooo]Zo`3o]@03oookJP0Bool0]Ooo803ooo]Zo`P0ool0ocSood40og_o0?lZ0?ooo`2Po`3o
E_oo0?;o0?lQoono0?nGo`3oN@3oo`3oB?l0okkoF_l00_oonfX04om/0?oo0?m=ool0Z_l0oo3o0?oX
oookJ_oo0>co7@3ooonW0?l02oooo`0DoonX0?oo00Oooo]ZogT0ooo]0?ooE`3oool00?oMo`001Ooo
04l2oolL0008omgo0?oo003ookL0oeL0ooo]0?ooK03oool0_?mi0?l4oookJP0Bool01on>o`3o0?nG
oookJ_oo8@3oojP0ooo70?oonf[oo`0Do`3koon`o`3o00_oocCo0?l0o`Wooo]ZoonW0?oonf[ooaX0
0ooonfX01Ol0ongooo]ZoookJ_oo0>co0>?o00?ooo]Z00Go=_l0o`3oj?l0POooocD0oooX0002oook
JP06o`3ol?lY0?oooo]ZoookJ_mI0?ooo`2Z1OoonfX01?ooh`3oK03ooookJ_mRo`09oookJP03on;o
0?oonf[ooo]Z00;ooo]Z00?oo`3fo`03oooonfX01?oonfX01?l0ogOooo]ZogT0oonGo`07oookJP05
oono0?l0oj;ooo]ZoookJ_l0ob401?oonfX01Ooo0?;ooo]ZoookJ_oonf[oo`2P00;ooo]Z00GoE03o
oookJ_oonf[ooo]ZobX0o`05oookJP04og_o0?oonf[ooo]Zoom100;ooo]Z00?o0?lhoookJ_oonfX0
3OoonfX00ooo0;Gooo]ZoookJP1MoookJP00I?oonfX00ol0o`Wooo]ZoookJP06oookJP03oolX0?oo
nf[ooo]Z00;ooo]Z00?o/?l0oookJ_l0nol00_oonfX01?oo:03ooo]ZoookJ_oo:00:oookJP03oonX
0?oonf[ooo]Z00;ooo]Z00?oob40oookJ_oonfX02ooonfX00ol0ol3oo`07oookJP0BoookJPOoobP0
00?ooo]Zof`0oooonfX01?oonfX00oo]0?ooWOl0ool00003ool000?oogT000?oo`00oomi0?ooN@00
0_ooN@001_oonf[o^?l0oolL0?oonf[o0?nFool0C`Cooo]Z00?o0?n;oookJ_l0okD00_oonfX00ooo
b@3oobP0oolX000>ooo900OoiOl01_l0oed4oiCo0003odCo0?l0ojgo0?n]00;o0?n]00?o0?onoiCo
0?nDo`000onDo`07o`3oG@;oA?l01Ooob@002?oo00OoolT0ooo90?oo8@3oojP0oomi0?ooa`3oo`0D
0oooN@001?l02oooogT0oomi0?ooY`02oomi0004oolJ0?oonf[ooo]Zo`3ok@;ooo]Z00KoogT0ool0
k?ooN@3oogT0oolX0?l0onP3oolX0004oooX0?ooN@3oogT0o`3ol0KoogT00ooonfX3ool00003of`0
oomRo`3ooo]Z00Gooo]Z2?oo:0000ooo0?Ko00?ooookJP03oookJP;oobP000Go0?mgoolX0?mi0?oo
Uol0oolX0004oookJP06ool00?oo:03oobP0oolX0?oo003oobP01?oonfX00ooo0?;ooo]ZoookJP02
oookJP04ool0X?oonf[oE03oo`0Uo`;ooo]Z0_oo0004oookJP05oolX0?oonf[ooo]ZoookJ_oo0000
0_oonfX00ol0ocSooo]ZoookJP0=oookJP03ool0]Ooonf[ooo]Z0;kooo]Z00?o0?l9oookJ_oonfX0
1OoonfX00ol02ooooo]ZoookJP02oookJP03ok3o0?oonf[o0?_o00;ooo]Z00GoCP3ooookJ_oonf[o
oo]Zool05009oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oob40oookJ_oonfX02ooonfX00ol0ol3o
oo]Zool01`0EoookJP03okSo0?oonf[ooo]Z00;ooo]Z00?oK03ooookJ_oonfX00ooonfX03Oo]0?oo
WOl0oookJ_oo0=coE`3ooong0?oonf[oT`3oonco0?oo003ooo]Zob/0oooBo`000ooonfX01Onho`3o
oa`0o`3oU_oonf[oo`1?00?ooo]Z00?o0?n;oookJ_l0okD00ooonfX04_oo0;Goob00oookJ_oonf[o
0?lhoom10?mko`3o:P3oool0X?oonf[oo`3bo`3o8Ooo_`3oUol0ogT0ool0odSo0?nnoe[o00;ooo]Z
013oK03oo`3oCOoo0:[o0?o`oooX0?l0onSo0>?oool0k?oo0;CoojL0o`0;oooo01CoojP0ool01ol0
003oo`2l0_o]0?l2ool000;ogOl000?ooa`0omgo0?oo00000_oo00001omG0?ook@3oond0oom/0?oo
o`2lokSo0?mi0?l01?oonfX04_oo00OoS_l0o`3oUooo8@3oo`2doonX0?ooa`3oo`0Dodh0ool0nooo
/?l0o`0;ooldo`3o0?l9oookJ_ooY`3ooo]ZoolJ00;ooo]Z00Ko0?o]oookJ_oonf[ooo]Zool0k?l0
hol2oookJP06ocKo0?l0onSo087ooole0?oonf[oonP00_oonfX01_l0oo3o:@3ooookJ_oonf[oF@3o
ool0ZPCooo]Z00Goon<0oookJ_m/0?oooo]Zof;o0008oookJP03on;o0?oonf[ooo]Z00?ooo]Z00?o
o`3fo`03oooonfX01?oonfX01?l0ogOooo]ZogT0oonGo`06oookJP03oono0?oonf[o0?nR00;ooo]Z
00?o0?lQoookJ_oonfX00_oonfX01Ooo0?;ooo]ZoookJ_oonf[oo`2P00;ooo]Z00CoE03ooookJ_oo
nf[o:P3o1_oonfX01?mko`3ooo]ZoookJ_oo@@02oookJP03o`3o>?oonf[ooo]Z00gooo]Z00?oo`2e
oookJ_oonfX0GOoonfX006Cooo]Z00?o0?l9oookJ_oonfX01_oonfX00ooo:03ooo]ZoookJP02oook
JP03ok3o0?oonf[o0?_o00;ooo]Z00CoCP3ooookJ_oonf[oobP02_oonfX00oooZ03ooo]ZoookJP02
oookJP03oolQ0?oonf[ooo]Z00_ooo]Z00?o0?o0ool01ooonfX04_oonfX7oolX0003oookJ_m/0?oo
oo]Z00Cooo]Z00?oo`00oigo0?oo00000ooo00001OnC0?oooo]Zonco0?oo003o:`3o00?oogT000Ko
oo]ZokSo0?oo703ooo]Zo`3oU_oo04l4oookJP03o`3oRooonf[o0?ne00;ooo]Z00GoolT0oolX0?oo
:03oobP0o`3o>00>ooo900CoiOl01_l0oed5oiCo0003ool01ol0ojgo0?n]00?o0?n]1_nDo`05o`3o
G@03o`3o3?m4o`3oA?l000CoolT000?oo`07ooo90?oob@000_oob@001oooZ03oolL0oomi0?oo01Co
0?_ooomi0?l02ol00oooN@000oooY`3oogT0oolJ0003oookJP06o`3okOoonf[ooo]Zoomi0?oo0>co
ogT00_oo:0001ol0onSoobP0oolX0?oo:03oonP0oomi0?l0oo001oooN@03oookJP?oo`0000?oK03o
of;o0?oonfX01OoonfX8oolX0003ool0m_l00ooooo]Z00?ooo]Z0_oo:0001?l0ogOoN@3ooolX0?nG
o`03oolX00;ooo]Z00?ookl0oolX0?oo:0001Ooo:002oookJP03ool0l_oonf[ooo]Z00;ooo]Z00?o
o`2PoookJ_mD0?l00ooonfX2ool000Cooo]Z00GoNol0oookJ_oonf[ooo]Zool00002oookJP03o`3o
>?oonf[ooo]Z00gooo]Z00?oo`2eoookJ_oonfX0__oonfX00ol0o`Wooo]ZoookJP05oookJP03o`0;
oooonf[ooo]Z00;ooo]Z00?o/?l0oookJ_l0nol00_oonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Wo
oo]Z00?oojP0oookJ_oonfX00_oonfX00ooo8@3ooo]ZoookJP0;oookJP03o`3o`?oonf[oo`0701Go
oo]Z00?o^?l0oookJ_oonfX00_oonfX00om/0?oooo]ZoookJP03oookJP0=ond0oonMo`3ooo]Zool0
g?mG0?oookL0oookJ_nC0?ook?l0ool00?oonf[o:`3oom;o0003oookJP05okSo0?oo703o0?nFoook
J_oo04l00ooonfX00ol0oh_ooo]Zo`3o]@03oookJP0Bool0]Ooo803ooo]ZoookJ_l0ocSood40og_o
0?lZ0?ooo`2PoookJ_oo0?;o0?lQoono0?nGo`3oN@3ooookJ_l0odSoF_l00_oonfX04?m/0?ooo`d0
o`3oCOl0oo3o:@3oo`3oj?oonf[oo`3/oad0ooooY`3o00_oo`3koooo01CoS_l0ool01ol00002ool0
_0;ok@3o1?oo0002oeL0o`;ok@3o00?oK03oool0_?oo0;`00_mi0?l4oookJP0Bool01ol0ol3oS_l0
oookJ_oo8@3oo`2doonX0?ooa`3oo`0Do`3koon`o`3o00_oocCo0?oonf[o0?l9oookJ_ooY`3ooaX0
0ooonfX01_l0ongooo]ZoookJ_oonf[oo`3/o`3So`;ooo]Z00Wo=_l0o`3oj?l0POooocD0ool02ooo
j03ooo]Zo`3ol?lY0?l00ooonfX00ooo0:[ooo]ZoookJP03oookJP05oooS0?oonf[oK03ooookJ_mR
o`002?oonfX00ooRo`3ooo]ZoookJP03oookJP03o`03oooonf[ooo]Z00Cooo]Z00Co0?mgogT0oooo
9`3oUol01_oonfX00ooo_`3ooo]Zo`3oXP02oookJP03o`3o8Ooonf[ooo]Z00;ooo]Z00Soo`3boook
J_oonf[ooo]Zool0X?oonf[oE03oo`0Uo`;ooo]Z00?o:P3ooookJ_oonfX01?oonfX01?mko`3ooo]Z
oookJ_oo@@02oookJP03o`3o>?oonf[ooo]Z00gooo]Z00?oo`2eoookJ_oonfX0GOoonfX006Cooo]Z
00?o0?l9oookJ_oonfX01_oonfX00ooo:03ooo]ZoookJP02oookJP03ok3o0?oonf[o0?_o00;ooo]Z
00?oCP3ooookJ_oonfX00_oo:009oookJP06oonX0?oonf[ooo]ZoookJ_oo0;Coob403?oonfX00ol0
ol3ooo]Zool01`0BoookJPSoobP000?ooo]Zof`0oooonfX01?oonfX00ooo003oWOl0ool00003ool0
0007oi<0oooonf[ok?l0ool00?l[0?oooo]Zom;o0002oookJP05okSo0?oo703ooo]Zo`3oU_oo04l0
1?oonfX00ol0oh_ooo]Zo`3o]@02oookJP;oolT00_oo:0000ol80?ooolT0ooo9000:ooo90003onGo
0?oob@3oiOl000CoiOl01Ol0oed5oiCo0003odCo0?l0ojgo0?n]00?o0?n]00?oolT0oiCo0?nDo`00
1?nDo`04o`3oG@03oiCo0?m4o`3oU?l000?oolT000?oo`07ooo90?oob@000_oob@001?ooZ03oogT0
ooo70?oo01@2oomi0003o`0;ooooN@3oogT000;oogT000?oojL0oookJ_ooN@000ooonfX01?l0ongo
oo]ZoookJ_oo0>`4oomi0007o`3oj?oo:03oobP0oolX0?ooj03oogT0o`3ol006oomi00Cooo]Z0ooo
00000om/0?ooH_l0oookJP05oookJPOoobP000?ooo]Zool0m_l00ol01?oonfX2oolX0003o`3oMomi
0?ooUol000CoobP00_oonfX00ooo_`3oobP0oolX0007oolX00Cooo]Z00Coo`2PoookJ_oonf[oE03o
0ooonfX2ool000Cooo]Z00GoNol0oookJ_oonf[ooo]Zoom10002oookJP03o`3o>?oonf[ooo]Z00go
oo]Z00?oo`2eoookJ_oonfX0_OoonfX00ol0o`Wooo]ZoookJP06oookJP03o`0;oooonf[ooo]Z00;o
oo]Z00?o/?l0oookJ_l0nol00_oonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Wooo]Z00KoojP0oook
J_oonf[ooo]Zool0]?oo8@0<oookJP04o`3o`?oonf[ooo]Zool01aGooo]Z00?o^?l0oookJ_oonfX0
0_oonfX00om/0?oooo]ZoookJP03oookJP0=ond0oonMo`3ooo]Zool0g?mG0?oookL0oookJ_nC0?oo
k?l0ool00?oonf[o:`3oom;o0003oookJP05okSo0?oo703o0?nFoookJ_oo04l00ooonfX00ol0oh_o
oo]Zo`3o]@03oookJP0Vool0]Ooo803ooo]ZoookJ_l0ocSood40og_o0?lZ0?ooE03oool0X?oo0?;o
0?lQo`3oX_oonf[oN@3oo`3oMol0odSoF_l0on;o0?oonf[oK03ooooS0?l0odgoF@3oo`3ol?l0onSo
0?nGool0k?l0ongoojL0ool0]?l02oooo`0DoonX0?l0oiOoo`07o`3o`?oo03P3ool0_0Gok@3o00?o
K03oool0_?oo0;`00_mi0?l5oookJP0?ool01ooonf[oS_l0o`3oUooo8@3oo`2doonX0?oonf[oo`0D
odh0ool0nooooo]Zo`0;ooml0?oo0?l900;ooo]Z00?oojL0oolJ0?oonfX00_oonfX01_l0ongooo]Z
oookJ_oo0>cooo]Zo`3So`;ooo]Z00Wo=_l0o`3oj?l0POooocD0ool02oooj03ooo]Zo`3ol?lY0?l0
0_oonfX00omI0?ooo`2ZoookJP04oookJP04oooS0?oonf[oK03oof;o00Wooo]Z00?oh_l0oookJ_oo
nfX00ooonfX00ol00ooooo]ZoookJP04oookJP03o`3oMomi0?ooUol000Oooo]Z00?ookl0oookJ_l0
oj800_oonfX01Ol0ob7ooo]ZoookJ_oonf[oo`3b00?ooo]Z00Goo`2PoookJ_oonf[oE03oo`0Uo`02
oookJP03obX0oooonf[ooo]Z00Cooo]Z00CoNol0oookJ_oonf[ood400_oonfX00ol0ocSooo]Zoook
JP0=oookJP03ool0]Ooonf[ooo]Z05gooo]Z001SoookJP03o`3o2Ooonf[ooo]Z00Oooo]Z00GoobP0
oookJ_oonf[ooo]Zok3o0002oookJP05o`3koooonf[ooo]Zodh0oooonfX00ooo:009oookJP06oonX
0?oonf[ooo]ZoookJ_oo0;Coob403?oonfX00ol0ol3ooo]Zool01`0BoookJPSoobP000?ooo]Zof`0
oooonfX01?oonfX7ool00006oookJ_o/o`3oo`00oookJ_l[0?ood_l00_oonfX01Onho`3ooa`0oook
J_l0oiKoo`1?00Cooo]Z00?o0?n;oookJ_l0okD00_oonfX2ooo900;oobP03Ooob@08onGo00Co0?mM
1OnDo`06o`3o[@03o`3oo_oob@3oU?l000GoU?l00ol0oed3oiCo00;oiOl000?oo`07onGo0?oUo`00
0_oUo`001?oo8@3oojP0ooo70?oo01@3oomi0008o`0;ooooN@3oogT0oomi0?ooY`3ooo]ZoolJ0?oo
N@02oookJP07o`3okOoonf[ooo]ZoookJ_oo0>coogT0oolX0003oomi0006oolX0?oo=@3oonP0oolX
0?ooN@3o0?o`1OooN@001Ooo0:[ooo]ZoookJ_oonf[oo`d000;oo`0000?oK03ooookJ_mRo`001_oo
nfX6oolX00;ooo]Z00?oo`3fo`03oooonfX00ooonfX01Ooo:03o0?mgoolX0?mi0?ooUol000?oobP0
0ooonfX00ooo_`3oobP0oolX0007oolX00Cooo]Z00Coo`2PoookJ_mD0?oo02Go0ooonfX00ooo003o
oo]ZoookJP02oookJP05og_o0?oonf[ooo]ZoookJ_oo@@000ooonfX00ol0ocSooo]ZoookJP0=oook
JP03ool0]Ooonf[ooo]Z0;gooo]Z00?o0?l9oookJ_oonfX01_oonfX01Ol02ooooo]ZoookJ_oonf[o
/?l000;ooo]Z00Co0?_ooookJ_oonf[oCP3o0ooonfX00ooo01Cooo]ZoookJP07oookJP06oonX0?oo
nf[ooo]ZoookJ_oo0;Coob403?oonfX00ol0ol3ooo]Zool01`0FoookJP03okSo0?oonf[ooo]Z00;o
oo]Z00?oK03ooookJ_oonfX00ooonfX03Oo]0?ooWOl0oookJ_oo0=coE`3ooong0?oonf[oT`3oonco
0?oo003ooo]Zob/0oooBo`000ooonfX01Onho`3ooa`0o`3oU_oonf[oo`1?00?ooo]Z00?o0?n;oook
J_l0okD00ooonfX04ooo0;Goob00oookJ_oonf[o0?lhoom10?mko`3o:P3ooe@0oooo0:3oo`3bo`3o
8Ol0oj;ooo]ZogT0ool0ogOo0?m8o`3o__mJo`000_oonfX03?m/0?oooo]Zo`3oCOl0oo3oonP0o`3o
j?l0hoooo`3/oolJ0?ooY`3oO03oo`0;o`;oo`0D00Ooo`2dool01ol0ol3ooo]Zool0>?nho`3oN@3o
00Goo`2l0_mi0?l6oookJP0?ool01on>o`3oS_l0o`3oUooonf[oob40oonX0?oonf[oolL0ool05?oo
nf[o0?_oo`0]ool02ooo0?l900;ooo]Z00?oojL0oookJ_oo6P000_oonfX01_l0ongooo]ZoookJ_oo
nf[oo`3/o`3So`?ooo]Z00Wo=_l0o`3oj?l0POooocD0oooX0?oonf[o0?o`oookJ_lY0?l00_oonfX0
0omI0?ooo`2ZoookJP03oookJP05ool=0?ooh`3oK03ooookJ_mRo`002OoonfX00ooRo`3ooo]Zoook
JP03oookJP03o`03oooonf[ooo]Z00Cooo]Z00?o0?mgogT0oonGo`001_oonfX01_oo_`3ooo]Zoook
J_l0oj;ooo]Zo`3o8@Cooo]Z00Goo`3boookJ_oonf[ooo]Zool0X002oookJP05oe@0oooonf[ooo]Z
oookJ_lZ0?l01OoonfX01Omko`3ooo]ZoookJ_oonf[ood4000;ooo]Z00?o0?lhoookJ_oonfX03Ooo
nfX00ooo0;Gooo]ZoookJP1MoookJP00HooonfX00ol0o`Wooo]ZoookJP07oookJP05oolX0?oonf[o
oo]ZoookJ_n`o`000_oonfX01Ol0nooooo]ZoookJ_m>0?oooo]Z00?oobP02OoonfX01_ooZ03ooo]Z
oookJ_oonf[oo`2doolQ00cooo]Z00?o0?o0oookJ_oo00L05OoonfX00ooo:03ooo]ZoookJP03oook
JP03of`0oooonf[ooo]Z00;ooo]Z2?oo00001_oonf[ok?l0ool00?oonf[o:`3oom;o00;ooo]Z00Go
^?l0oolL0?oonf[o0?nFool0C`04oookJP03o`3oRooonf[o0?ne00;ooo]Z0ooob@000ooo:03oolT0
ooo9000<ooo90005oomi0?oUo`3oiOl0onGo0?m/0?l00_oUo`001?m4o`3o0?mMo`3oGOl0oed5oiCo
00Ko0?n]00?o0?onoiCo0?oob@001_nDo`000ol0oegoU?l0oiCo0002oiCo0003onGo0?oo00OoiOl0
00;oiOl00_oo8@000oooZ03oiOl0ool05003oomi0007o`0;ooooN@3oogT0oomi0?ooY`3oogT0oook
JP03oomi0007oookJ_l0ongooo]ZoookJ_oo0>coogT0oookJP05oomi0004oolX0?ooj03oobP0o`3o
l0GoogT000?oo`2ZoookJ_oonfX00_oonfX01_oo3@3oo`00ool00?m/0?oooo]Zof;o00Kooo]Z1_oo
:0001?oonf[oo`3foookJ_l00ol4oookJP05oolX0?l0ogOoobP0ogT0oonGo`000ooo:002oookJP03
oono0?oonf[oobP000OoobP000?oo`3boookJ_oonfX00_oonfX01?oo0:3ooo]Zoe@0ool09Ol3oook
JP03obX0oooonf[ooo]Z00;ooo]Z00GoNol0oookJ_oonf[ooo]Zoom10002oookJP03o`3o>?oonf[o
oo]Z00kooo]Z00?oo`2eoookJ_oonfX0_OoonfX00ol0o`Wooo]ZoookJP06oookJP05o`0;oooonf[o
oo]ZoookJ_n`o`000_oonfX01?l0nooooo]ZoookJ_m>0?l3oookJP03ool05?oonf[ooo]Z00Oooo]Z
00KoojP0oookJ_oonf[ooo]Zool0]?oo8@0<oookJP03o`3o`?oonf[oo`0701Kooo]Z00?o^?l0oook
J_oonfX00_oonfX00om/0?oooo]ZoookJP03oookJP0=ond0oonMo`3ooo]Zool0g?mG0?oookL0oook
J_nC0?ook?l0ool00?oonf[o:`3oom;o0003oookJP05okSo0?oo703o0?nFoookJ_oo04l00ooonfX0
0ol0oh_ooo]Zo`3o]@03oookJP0Cool0]Ooo803ooo]ZoookJ_l0ocSood40og_o0?lZ0?ooE03oool0
X?oo0?;o0?lQo`3oX_oo_`3oN@3oo`3oMol0odSo0?nnoe[o0002oookJP0@of`0oooo3@3o0?m=oeT0
ool0oo3o0?oXocKo0?oo0>co0?o]oad0ooooY`3oO03oo`0;oom>0?ooo`0DoonX00;oo`070_oonfX2
ool0>0?oN@3o00?oo`0hoookJ_oonfX01OoonfX01?oo00OoS_l0oookJ_l0oiL2oolQ000>oonX0?oo
nf[oolL0ool05?oonf[o0?_oool06?l02ooooo]Zo`3o2Ooonf[oojL0oookJ_oo6P03oookJP06o`3o
kOoonf[ooo]Zool0k?oonf[o0>?o0_oonfX02_lfo`3o0?oXo`21oooo=@3oo`0;oooX0?oonf[o0?o`
oookJ_lY0?l2oookJP03ool0Z_oonf[ooo]Z00?ooo]Z00Goo`d0oooS0?m/0?oooo]Zof;o0008oook
JP03on;o0?oonf[ooo]Z00?ooo]Z00?oo`3fo`03oooonfX01?oonfX01?l0ogOooo]ZogT0oonGo`06
oookJP06oono0?oonf[ooo]Zo`3oX_oonf[o0?lQ1?oonfX01Ooo0?;ooo]ZoookJ_oonf[oo`2P00;o
oo]Z00GoE03ooookJ_oonf[ooo]ZobX0o`05oookJP04og_o0?oonf[ooo]Zoom100;ooo]Z00?o0?lh
oookJ_oonfX03_oonfX00ooo0;Gooo]ZoookJP1MoookJP00HooonfX00ooo:03ooo]ZoookJP07oook
JP05oolX0?oonf[ooo]ZoookJ_n`o`000_oonfX01Ol0nooooo]ZoookJ_m>0?oooo]Z00CoobP02?oo
nfX01_ooZ03ooo]ZoookJ_oonf[oo`2doolQ00cooo]Z00?o0?o0oookJ_oo00L05OoonfX00onho`3o
oo]ZoookJP03oookJP03of`0oooonf[ooo]Z00;ooo]Z2?oo00001_oonf[ok?l0ool00?oonf[o:`3o
om;o00;ooo]Z00Go^?l0oolL0?oonf[o0?nFool0C`04oookJP03o`3oRooonf[o0?ne00;ooo]Z0ooo
b@000ooo:03oolT0ooo9000<ooo90007oomi0?mJo`3oolT0ooo90?oUo`3oK03oooo90002onGo0003
o`3oGOm4o`3oU?l000CoU?l01_l0ojd5onGo00SoU?l00_oo00L4onGo0009ooo90?oUo`3oiOl0ool0
5?oUo`3oCP3oo`3kooooN@3o00_o00?oogT000?oojL0oomi0?ooN@001?ooN@03oookJP03ool0k?l0
hooooo]Z00KoogT000?oonP0oomi0?l0oo001OooN@000ooo0:[ooo]ZoookJP02oookJP05ool=0?oo
003oK03ooookJ_mRo`001ooonfX5oolX00;ooo]Z00?oo`3fo`03oooonfX01?oonfX01?oo:03o0?mg
oolX0?mi0?l3oolX00?ooo]Z00?ookl0oookJ_oo:0001ooo:005oookJP03ool0X?oonf[oE03o00?o
oo]Z00?o:P3ooookJ_oonfX00ooonfX01Omko`3ooo]ZoookJ_oonf[ood4000;ooo]Z00?o0?lhoook
J_oonfX03OoonfX00ooo0;Gooo]ZoookJP2noookJP03o`3o2Ooonf[ooo]Z00Kooo]Z00Go00_ooook
J_oonf[ooo]Zok3o0002oookJP04o`3koooonf[ooo]Zodh0o`?ooo]Z00?oo`0DoookJ_oonfX01ooo
nfX01_ooZ03ooo]ZoookJ_oonf[oo`2doolQ00cooo]Z00?o0?o0oookJ_oo00L05_oonfX00onho`3o
oo]ZoookJP02oookJP03of`0oooonf[ooo]Z00?ooo]Z00gok@3ooigo0?oonf[ooo]ZoeL0oooo]`3o
oo]Zoi<0ooo/o`3oo`00oookJ_l[0?ood_l000?ooo]Z00Go^?l0oolL0?oonf[o0?nFool0C`03oook
JP03o`3oRooonf[o0?ne00Cooo]Z01;oo`2eoookJ_oonf[o0?lhoom10?mko`3o04coobX0oooo0:3o
0?mFool0l_l0ob7ookl0oookJ_mi0?oooo]Zo`3oB?mJo`02oookJP0Bof;o0?m/0?ooo`2Zo`3oCOl0
oo3oonP0o`3oj?l0hoooo`3/o`3okOlM0?ooojL0og`0ool02oooCP3oool05?ooZ03oob400ooo00L:
oookJP;oo`0700ooS_l0o`3oUol0oiOoob40ool0]?ooZ03ooo]Zooo70?oo01CoCP3oo`3koon`o`3o
00_oocCo0?l0o`T00_oonfX00oooY`3ooo]ZoolJ0002oookJP07o`3okOoonf[ooo]ZoookJ_oo0>co
oo]Zo`3So`02oookJP05ocKo0?l0onSo087ooole0?ooj0000_oonfX01_l0oo3o:@3ooookJ_oonf[o
F@3oool0ZPGooo]Z00Coon<0oookJ_m/0?ooH_l02OoonfX00ooRo`3ooo]ZoookJP03oookJP03o`03
oooonf[ooo]Z00Cooo]Z00?o0?mgoookJ_mi0?l01ooonfX00ooo_`3ooo]Zo`3oXP02oookJP05o`3o
8Ooonf[ooo]ZoookJ_oo0?801?oonfX01?oo0:3ooo]Zoe@0ool09Ol2oookJP03obX0oooonf[ooo]Z
00Cooo]Z00CoNol0oookJ_oonf[ood400_oonfX00ol0ocSooo]ZoookJP0=oookJP03ool0]Ooonf[o
oo]Z05kooo]Z001SoookJP03oolX0?oonf[ooo]Z00Kooo]Z00?oobP0oookJ_oonfX00_oonfX01?oo
:03ooo]ZoookJ_l0nol2oookJP03odh0oooonf[oobP000?oobP02?oonfX01OooZ03ooo]ZoookJ_oo
nf[oob4000gooo]Z00?o0?o0oookJ_oo00L05OoonfX00onho`3ooo]ZoookJP03oookJP03of`0oooo
nf[ooo]Z00;ooo]Z2Ooo00001Oo/o`3oo`00oookJ_l[0?ood_l000;ooo]Z00Go^?l0oolL0?oonf[o
0?nFool0C`05oookJP04o`3oRol0okGooo]ZoookJP?oolT000?oobP0ooo90?oob@003?oob@000ooo
N@3oolT0ooo90002ooo90005of`0oooob@3oiOl0o`3ol?oUo`001_nDo`07o`3o[@03o`3o3?oUo`3o
iOl000SoiOl000?oo`07onGo0?oUo`001_oUo`002_oo01CoiOl0onGo0?l0noooogT0o`0;ooooN@3o
olT0oomi0?ooY`07oomi00?ooo]Z00?oo`3/oookJ_ooN@002?ooN@000ol0oo3oogT0oomi0003oomi
000:ool0Z_ooN@3ooo]ZoookJ_oo3@3ooo]Zool00?m/0?oooo]Zof;o00Oooo]Z1Ooo:002oookJP03
ool0m_l00ooooo]Z00Cooo]Z00Co0?mgoolX0?mi0?ooUol00_oo:004oookJP03oono0?oonf[oobP0
00KoobP000?oo`3boookJ_oonfX00ooonfX00ooo0:3ooo]Zoe@0o`03oookJP03obX0oooonf[ooo]Z
00;ooo]Z00GoNol0oookJ_oonf[ooo]Zoom10003oookJP03o`3o>?oonf[ooo]Z00gooo]Z00?oo`2e
oookJ_oonfX0__oonfX00ol0o`Wooo]ZoookJP05oookJP03o`0;oooonf[ooo]Z00;ooo]Z00Co/?l0
oookJ_oonf[o0?_o0_oonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Wooo]Z00KoojP0oookJ_oonf[o
oo]Zool0]?oo8@0<oookJP03o`3o`?oonf[oo`0701Kooo]Z00?o^?l0oookJ_oonfX00_oonfX00om/
0?oooo]ZoookJP03oookJP0=ond0oonMo`3ooo]ZoookJ_oo0=coE`3ooookJ_nC0?ook?l0ool00?oo
nf[o:`3oom;o0003oookJP05okSo0?oo703ooo]Zo`3oU_oo04l01?oonfX00ol0oh_o0?neoookJP03
oookJP0Uool0]Ooo803ooo]Zo`3o>?oo@@3oNol0oookJ_lZ0?ooo`2PoookJ_oo0?;o0?lQo`3oX_oo
nf[oN@3oo`3oMol0odSoF_l0on;o0?oonf[oH_l0of`0oooo3@3o0?m=oeT0ool0oo3o0?oXocKo0?l0
hoooo`3/o`3okOoo0;CoojL0ocCo0?l02ooo0?_oool05002oonX0003ool0]?l0ol3oo`0700Woo`07
00?oS_l0oookJ_l0oiL00_oo8@002ooo0:OoojP0oookJ_ooa`3oo`0Dodh0ool0nooo/?l0o`0;oold
o`3o0?l900;ooo]Z00CoojL0oookJ_oonf[ooaX00_oonfX01_l0ongooo]ZoookJ_oonf[oo`3/o`3S
o`;ooo]Z00[o=_l0o`3oj?l0POooocD0ool02oooj03ooo]Zo`3ol?oonf[o:@3o0_oonfX00omI0?oo
o`2ZoookJP03oookJP05ool=0?ooh`3oK03ooookJ_mRo`002OoonfX00ooRo`3ooo]ZoookJP02oook
JP03ool0m_l00ooooo]Z00Gooo]Z00?o0?mgogT0oonGo`001_oonfX01?oo_`3ooo]ZoookJ_l0oj82
oookJP05o`3o8Ooonf[ooo]ZoookJ_oo0?801?oonfX01?oo0:3ooo]Zoe@0ool09Ol2oookJP03obX0
oooonf[ooo]Z00?ooo]Z00GoNol0oookJ_oonf[ooo]Zoom10002oookJP03o`3o>?oonf[ooo]Z00go
oo]Z00?oo`2eoookJ_oonfX0G_oonfX006?ooo]Z0_oo:007oookJP03oolX0?oonf[ooo]Z00;ooo]Z
00CoobP0oookJ_oonf[o0?_o0_oonfX00om>0?oooo]ZoolX0003oolX00Sooo]Z00GoojP0oookJ_oo
nf[ooo]ZoolQ000=oookJP03o`3o`?oonf[oo`0701Gooo]Z00?o^?l0oookJ_oonfX00ooonfX00om/
0?oooo]ZoookJP02oookJPWoo`0000cok?l0ool00?oonf[o:`3ooookJ_oBo`3ooo]ZokSo0?oonf[o
oa`0oookJ_oo04l5oookJP04o`3oRol0okGooo]ZoookJP?oolT000?oo`00ooo90?oob@001ooob@00
0ol0ob7oolT0ooo90007ooo90005oooS0?m/0?ooiOl0o`3ol?m4o`001OnDo`08o`3o[@03o`3oo_oo
Z03oiOl000ooiOl00_oo01@2onGo0003o`3koooob@3o00_o00?oolT000?oogT0oonW0?ooN@001ooo
N@001?oonf[oo`3/oookJ_oonfX>oomi0008ool0Z_ooN@3oogT0oomi0?oonf[oo`d0oookJ_m/0?l2
oookJP03of;o0?oonf[ooo]Z00Gooo]Z1?oo:002oookJP03ool0m_l00ooooo]Z00Gooo]Z00Co0?mg
oolX0?mi0?ooUol00_oo:004oookJP03oono0?oonf[oobP000GoobP000?ooo]Zool0l_oonfX01?oo
nfX00ooo0:3oE03oo`0Uo`03oookJP03obX0oooonf[ooo]Z00;ooo]Z00GoNol0oookJ_oonf[ooo]Z
oom10003oookJP03o`3o>?oonf[ooo]Z00gooo]Z00?oo`2eoookJ_oonfX0__oonfX00ol0o`Wooo]Z
oookJP05oookJP03o`0;oooonf[ooo]Z00;ooo]Z00Co/?l0oookJ_oonf[o0?_o0_oonfX01Om>0?oo
oo]ZoookJ_oonf[oo`0D00Wooo]Z00KoojP0oookJ_oonf[ooo]Zool0]?oo8@0<oookJP03o`3o`?oo
nf[oo`0701Kooo]Z00?o^?l0oookJ_oonfX00_oonfX00om/0?oooo]ZoookJP03oookJP0>ond0oooo
nf[oWOl0oookJ_oo0=coE`3ooookJ_nC0?ook?l0ool00?oonf[o:`3ooookJ_oBo`02oookJP05okSo
0?oonf[ooa`0o`3oU_oo04l01?oonfX00ol0oh_ooo]Zo`3o]@03oookJP0Cool0]Ooo803ooo]Zoook
J_l0ocSood40og_o0?lZ0?ooo`2PoookJ_oo0?;o0?lQo`3oX_oonf[oN@3oo`3oMol0odSo0?nnoe[o
0002oookJP0@oooS0?m/0?oooo]Zo`3oCOl0oo3oo`0;o`3oj?oonf[o0>?oool0k?l0ongoo`2doonW
0?ldo`3o00_oo`3ko`;oo`0D0_ooZ0000ooo8@3o0?nGo`3o`007ohko00;o0?nG00Goob40ool0]?oo
Z03oojP0oookJP02ool05006odh0ool0nooo/?l0o`0;ooldo`3o0?l90_oonfX01?ooY`3ooo]Zoook
J_oo6P03oookJP05o`3okOoonf[ooo]Zool0k?l0hol00ooonfX02Olfo`3o0?oXo`21oooo=@3oo`0;
oooX0?oonf[o0?o`obT0o`02oookJP03oeT0oooo0:[ooo]Z00Cooo]Z00Goo`d0oooS0?m/0?oooo]Z
of;o0008oookJP03on;o0?oonf[ooo]Z00?ooo]Z00?oo`3fo`03oooonfX01?oonfX01?l0ogOooo]Z
ogT0oonGo`06oookJP06oono0?oonf[ooo]Zo`3oX_oonf[o0?lQ1?oonfX00ooo0?;ooo]ZoookJP02
oookJP03ool0X?oonf[oE03o00?ooo]Z00?o:P3ooookJ_oonfX00ooonfX01?mko`3ooo]ZoookJ_oo
@@03oookJP03o`3o>?oonf[ooo]Z00gooo]Z00?oo`2eoookJ_oonfX0G_oonfX006;ooo]Z0ooo:007
oookJP03oolX0?oonf[ooo]Z00;ooo]Z00CoobP0oookJ_oonf[o0?_o0_oonfX00om>0?ooobP0oolX
0004oolX00Kooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo8@3ooo]ZoookJP0;oookJP03o`3o`?oo
nf[oo`0701Gooo]Z00?o^?l0oookJ_oonfX00ooonfX00om/0?oooo]ZoookJP02oookJPWoo`0000Ko
k?l0ool00?oonf[o:`3ooookJ_oBo`02oookJP04okSo0?oo703ooo]Zool0C`Gooo]Z00?o0?n;oook
J_l0okD03_oob@000ol0ob7oolT0ooo90003ooo900GoobP000?oK03oooo90?nDo`001_nDo`08o`3o
[@04o`3oo_l0o`coojP0oiCo017oiOl000?oolT0o`0;ool02ol01?oob@000oooY`3oogT0oomi0008
oomi0003ool0k?oonf[ooo]Z00OoogT000?ooo]Zo`3ol?ooN@001?ooN@000ooo0:[oogT0oomi0002
oomi0005ool=0?ooh`3oK03ooookJ_mRo`002?oonfX4oolX00;ooo]Z00?oo`3fo`03oooonfX01Ooo
nfX01Ol0ogOoobP0ogT0oonGo`3oobP000Cooo]Z00?ookl0oookJ_oonfX01_oo:0000ooo0?;ooo]Z
oookJP03oookJP04ool0X?oonf[oE03oo`0Uo`;ooo]Z00?o:P3ooookJ_oonfX00ooonfX01Omko`3o
oo]ZoookJ_oonf[ood4000;ooo]Z00?o0?lhoookJ_oonfX03_oonfX00ooo0;Gooo]ZoookJP2noook
JP03o`3o2Ooonf[ooo]Z00Gooo]Z00?o00_ooookJ_oonfX00_oonfX01?n`o`3ooo]ZoookJ_l0nol2
oookJP05odh0oooonf[ooo]ZoookJ_oo01@02OoonfX01_ooZ03ooo]ZoookJ_oonf[oo`2doolQ00co
oo]Z00?o0?o0oookJ_oo00L05_oonfX00onho`3ooo]ZoookJP02oookJP03of`0oooonf[ooo]Z00?o
oo]Z00kok@3ooookJ_nMo`3ooo]Zool0g?mG0?oooo]Zoi<0ooo/o`3oo`00oookJ_l[0?oooo]Zom;o
00;ooo]Z00Go^?l0oookJ_oo703o0?nFool0C`04oookJP03o`3oRooonf[o0?ne00?ooo]Z01?oo`2e
oolP0?oonf[ooo]Zo`3o>?oo@@3oNol0obX0oomD0?ooo`2Pool0l_l0ob7o0?nRoookJ_mi0?oo0?mg
oookJ_l0odSoF_l000?ooo]Z00koon<0of`0oooo0:[oF@3oo`3ol?oo=@3o0?oXoookJ_oo0>cooo]Z
o`3okOoo0;CoojL0ocCo00?o00_o00Coo`0Dooo70?ooZ03oojP02?oo8@04oonX0003ooo70?oo01Co
o`0D00;oCP3o00Go0?_oo`0;ool02ooo=?l0o`3o2@02oookJP04oonW0?oonf[ooo]ZoolJ00;ooo]Z
0_l0ond3oookJP0>ool0k?l0hooooo]ZoookJ_lfo`3o0?oXo`21oooo=@3oo`0;oooX0?oonf[o0?o`
oookJ_lY0?l2oookJP03oeT0oooo0:[ooo]Z00Cooo]Z00Coon<0oookJ_m/0?ooH_l02OoonfX00ooR
o`3ooo]ZoookJP03oookJP03o`03oooonf[ooo]Z00Cooo]Z00Co0?mgoookJ_mi0?ooUol01_oonfX0
1_oo_`3ooo]ZoookJ_l0oj;ooo]Zo`3o8@?ooo]Z00?oo`3boookJ_oonfX00_oonfX01?oo0:3ooo]Z
oookJ_mD0?l2oookJP03obX0oooonf[ooo]Z00Cooo]Z00CoNol0oookJ_oonf[ood400_oonfX00ol0
ocSooo]ZoookJP0>oookJP03ool0]Ooonf[ooo]Z05kooo]Z001RoookJP?oobP01ooonfX01?oo:03o
oo]ZoookJ_oonfX3oolX0005o`3koooonf[ooo]ZoookJ_m>0?l01_oo:006oookJP03oonX0?oonf[o
oo]Z00;ooo]Z00?oob40oookJ_oonfX02ooonfX00ol0ol3ooo]Zool01`0FoookJP03okSo0?oonf[o
oo]Z00;ooo]Z00CoK03ooookJ_oonf[ooo]Z3?oo00001?oonf[o:`3ooookJ_oBo`02oookJP05okSo
0?oo703ooo]Zo`3oU_oo04l01?oonfX00ol0oh_ooo]Zo`3o]@0>ooo90003o`3o8Ooob@3oolT000Co
olT01?oo:0000om/0?ooobP0oomi0003oiCo0003o`3oj?nDo`3oU?l000GoU?l00_oob@02o`0;o`?o
o`0D00?oU?l0onGo0?oUo`003_oUo`000ol02ooo=?l0ooo90003ooo90003oonW0?oob@3oogT000Oo
ogT000Cooo]Zool0k?oonf[ooo]Z2?ooN@000ooonf[o0?o`oomi0004oomi000:ool0Z_ooN@3oogT0
oookJ_oo3@3ooo]ZoooS0?m/0?oooo]Zof;o00Sooo]Z0ooo:003oookJP03ool0m_l00ooooo]Z00Co
oo]Z00Co0?mgoolX0?oo:03oN@3o0_oo:004oookJP03oono0?oonf[ooo]Z00GoobP000?ooo]Zool0
l_oonfX01?oonfX00ooo0:3ooo]Zoe@0o`03oookJP03obX0oooonf[ooo]Z00;ooo]Z00GoNol0oook
J_oonf[ooo]Zoom10003oookJP03o`3o>?oonf[ooo]Z00kooo]Z00?oo`2eoookJ_oonfX0__oonfX0
0ol0o`Wooo]ZoookJP05oookJP03o`0;oooonf[ooo]Z00;ooo]Z00?o/?l0oookJ_l0nol00ooonfX0
1Om>0?oooo]ZoookJ_oonf[oo`0D00Wooo]Z00KoojP0oookJ_oonf[ooo]Zool0]?oo8@0<oookJP03
o`3o`?oonf[oo`0701Oooo]Z00Go^?l0oookJ_oonf[ooo]Zof`0o`06oookJP0=ond0oonMo`3ooo]Z
ool0g?mG0?oooo]Zoi<0oooonf[oo`00oookJ_l[0?oooo]Zom;o0003oookJP04okSo0?oo703o0?nF
ool0C`Cooo]Z00?o0?n;oookJ_l0okD00ooonfX05?oo0;Gooo]ZoolP0?oonf[o0?lhoom10?mko`3o
:P3oo`0Uoooo0:3oo`3bo`3o8Ooonf[o0?nRoookJ_mi0?oo0?mgo`3oB?mJo`3oh_l00_oonfX03Ooo
h`3oK03oool=0?oo0:[o0?o`oooX0?oo=@3o0?oXoookJ_oo0>cooo]Zo`3okOlM0?l00_ooY`02ocCo
0004o`0;oooo01Coo`0Dool050SoojP000?oo`2Wooo70?oo01@00_oo01@02?oonf[oCP3oo`3kool0
nooo00_oocCo0?l0;Ooo0?l90_oonfX01?ooY`3ooo]ZoookJ_oo6P02oookJP03o`3okOoonf[ooo]Z
00;ooo]Z00?oo`3/o`3SoooonfX00_oonfX02_lfo`3o0?oXo`21oooo=@3oo`0;oooX0?oonf[o0?o`
oookJ_lY0?l2oookJP03oeT0oooo0:[ooo]Z00?ooo]Z00Goo`d0oooS0?m/0?oooo]Zof;o0009oook
JP03on;o0?oonf[ooo]Z00;ooo]Z00?oo`3fo`03oooonfX01OoonfX00ol0ogOooo]ZogT0o`06oook
JP07oono0?oonf[ooo]ZoookJ_l0oj;ooo]Zo`3o8@03oookJP03ool0l_oonf[ooo]Z00;ooo]Z00Co
o`2PoookJ_mD0?oo02Go0_oonfX00olZ0?oooo]ZoookJP03oookJP05og_o0?oonf[ooo]ZoookJ_oo
@@000_oonfX00ol0ocSooo]ZoookJP0>oookJP03ool0]Ooonf[ooo]Z05kooo]Z001RoookJPCoobP0
1_oonfX01?oo:03ooo]ZoookJ_oonfX3oolX0005o`3koooonf[ooo]ZoookJ_m>0?l01_oo:006oook
JP03oonX0?oonf[ooo]Z00;ooo]Z00?oob40oookJ_oonfX02ooonfX00ol0ol3ooo]Zool01`0Foook
JP03okSo0?oonf[ooo]Z00;ooo]Z00CoobP0oookJ_oonf[ooo]Z3?oo00001?ooV`3o:`3ooookJ_oB
o`02oookJP05okSo0?oo703ooo]Zo`3oU_oo04l01?oonfX00ol0oh_ooo]Zo`3o]@0?ooo90003o`3o
8Ooob@3oolT000?oolT01Ooo:002ooo900CoU?l000Co0?oXoiCo0?nDo`3oU?l00ooUo`02oonW00;o
olT00_l02ol01?oob@3oiOl0onGo0?oob@0>onGo0003ocCo0?oob@3oolT000GoolT01OooN@03oook
JP04ool0k?oonf[ooo]ZoookJPkoogT000?oo`2Zoomi0?ooN@000_oo:0001Ooo3@3oon<0of`0oooo
nf[oH_l000Wooo]Z0_oo:003oookJP03ool0m_l00ooooo]Z00Gooo]Z00Go0?mgoolX0?mi0?ooUol0
oolX0005oookJP03oono0?oonf[o0?nR00GoobP000?ooo]Zool0l_oonfX01?oonfX00ooo0:3ooo]Z
oe@0o`03oookJP03obX0oooonf[ooo]Z00;ooo]Z00GoNol0oookJ_oonf[ooo]Zoom10003oookJP03
o`3o>?oonf[ooo]Z00kooo]Z00?oo`2eoookJ_oonfX0__oonfX00ol0o`Wooo]ZoookJP05oookJP03
o`0;oooonf[ooo]Z00;ooo]Z00?o/?l0oookJ_l0nol00ooonfX01Om>0?oooo]ZoookJ_oonf[oo`0D
00Wooo]Z00KoojP0oookJ_oonf[ooo]Zool0]?oo8@0<oookJP03o`3o`?oonf[oo`0701Oooo]Z00Go
^?l0oookJ_oonf[ooo]Zof`0o`06oookJP0=ond0oonMo`3ooo]Zool0g?mG0?oooo]Zoi<0oooonf[o
k?l0ool00?l[0?oooo]Zom;o0003oookJP05okSo0?oo703ooo]Zo`3oU_oo04l00ooonfX01?l0oh_o
oo]ZoookJ_l0okD2oookJP0Dool0]Ooonf[oob00oookJ_l80?oo0?lhog_o0?oonf[o:P3oool0X?l0
oeKoo`3bo`3o8Ol0oj;ooo]ZogT0ool0ogOo0?m8o`03oomJo`03oookJP0@oooS0?m/0?ooo`2ZoeT0
ool0oo3oocD0o`21ool0onSooo]Zool0k?l0003o0?o]o`000?oo0;CoojL0o`3o2@;o=?l000?o00_o
o`3koooo01@02Ooo01@00ooonf[oCP3ook3o0002o`3ko`;o00_o00Co=?l0o`3o2Ooonf[ooo]Z0_oo
Y`000ooonf[ooaX0oolJ0002oookJP03o`3okOoonf[ooo]Z00;ooo]Z00?oo`3/o`3SoooonfX00_oo
nfX02_lfo`3o0?oXo`21oooo=@3oo`0;oooX0?oonf[o0?o`oookJ_lY0?l2oookJP03oeT0oooo0:[o
oo]Z00Cooo]Z00Coon<0oookJ_m/0?ooH_l02_oonfX00ooRo`3ooo]ZoookJP02oookJP03ool0m_l0
0ooooo]Z00Cooo]Z00Co0?mgoookJ_mi0?ooUol01_oonfX01?oo_`3ooo]ZoookJ_l0oj82oookJP05
o`3o8Ooonf[ooo]ZoookJ_oo0?801?oonfX00ooo0:3ooo]Zoe@0o`03oookJP03obX0oooonf[ooo]Z
00?ooo]Z00CoNol0oookJ_oonf[ood400ooonfX00ol0ocSooo]ZoookJP0>oookJP03ool0]Ooonf[o
oo]Z05kooo]Z001RoookJPCoobP01_oonfX01?l02ooooo]ZoookJ_oonfX3oolX0005o`3koooonf[o
oo]ZoookJ_m>0?l01ooo:005oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oob40oookJ_oonfX02ooo
nfX00ol0ol3ooo]Zool01`0FoookJP03okSo0?oonf[ooo]Z00;ooo]Z00CoobP0oookJ_oonf[ooo]Z
2ooo00001Oo/o`3oo`00ob/0oooonf[od_l000;ooo]Z00Go^?l0oolL0?oonf[o0?nFool0C`05oook
JP03o`3oRol0okGoolT000KoolT000?o0?lhooo90?mko`001Ooob@001Ol0ob7o0?nRooo90?oob@3o
N@3o00;oolT00oooN@04ooo90005ool00?lY0?ooU?l0oiCo0?l0onP01_oUo`000ooob@3oojL0oonW
0002ooo901;oiOl02Ooob@000oooN@3o0?o]oookJP03oookJP04ool0k?oonf[ooo]ZoookJPooogT0
00?oo`2Zoomi0?oonfX00ooo:0001?ooh`3oK03ooookJ_mRo`09oookJP;oobP00ooonfX00ooo0?Ko
00?ooookJP04oookJP06o`3oMooonf[oobP0ogT0oonGo`3oobP01OoonfX00ooo_`3ooo]Zo`3oXP04
oolX00;ooo]Z00?oo`3boookJ_oonfX00ooonfX00ooo0:3oE03oo`0Uo`02oookJP03obX0oooonf[o
oo]Z00?ooo]Z00GoNol0oookJ_oonf[ooo]Zoom10003oookJP03o`3o>?oonf[ooo]Z00gooo]Z00?o
o`2eoookJ_oonfX0_ooonfX00ol0o`Wooo]ZoookJP05oookJP03o`0;oooonf[ooo]Z00;ooo]Z00?o
/?l0oookJ_l0nol00ooonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Wooo]Z00KoojP0oookJ_oonf[o
oo]Zool0]?oo8@0=oookJP03o`3o`?oo00Oooo]Z01Kooo]Z00Go^?l0oookJ_oonf[ooo]Zof`0o`06
oookJP0=ond0oonMo`3ooo]Zool0g?mG0?oooo]Zoi<0oooonf[ok?l0ool00?l[0?oooo]Zom;o0003
oookJP05okSo0?oo703ooo]Zo`3oU_oo04l01?oonfX00ol0oh_ooo]Zo`3o]@02oookJP03ool0]Ooo
nf[oob0000;ooo]Z013o0?lhog_o0?oonf[o:P3ooe@0oooo0:3oo`3bo`3o8Ol0oj;ookl0oookJ_mi
0?oooo]Zo`3oB?mJo`3oh_l00_oonfX03?mRo`3oK03oool=0?oo0:[o:@3oo`3ol?oo=@3o087oo`3o
j?oonf[oo`3/o`0000;o0?o]00Go7@3ooonW0?ooY`3o0?l9og`0o`03o`0;o`[o0?_o0ol02ol2ocCo
0005o`3o2Ooonf[oojL0oonW0?oonfX00_oo6P03oookJP03o`3okOoonf[ooo]Z00?ooo]Z00coo`3/
oookJ_oonf[ooo]ZocKo0?l0oiOo0?oXoole0?oo00_ooo]ZoooX0?l0oo02oookJP05obT0oooonf[o
oo]ZoeT0oooo0:X01?oonfX01Ooo3@3oon<0oookJ_m/0?ooH_l000Wooo]Z00?oh_l0oookJ_oonfX0
0_oonfX00ooo0?Ko00?ooookJP05oookJP04o`3oMooonf[oN@3ooiOo00Kooo]Z00Kookl0oookJ_oo
nf[o0?nRoookJ_l0ob44oookJP03ool0l_oonf[ooo]Z00;ooo]Z00?oo`2PoookJ_mD0?l00_oonfX0
0olZ0?oooo]ZoookJP04oookJP04og_o0?oonf[ooo]Zoom100?ooo]Z00?o0?lhoookJ_oonfX03Ooo
nfX00ooo0;Gooo]ZoookJP1OoookJP00H_oonfX4oolX00Kooo]Z00Co00_ooookJ_oonf[ooo]Z0ooo
:0001Ol0nooooo]ZoookJ_oonf[oCP3o00OoobP01OoonfX00oooZ03ooo]ZoookJP02oookJP03oolQ
0?oonf[ooo]Z00_ooo]Z00?o0?o0oookJ_oo00L05_oonfX00onho`3ooo]ZoookJP02oookJP;oobP0
0_oonfX=ool00003oookJ_l[0?ood_l000?ooo]Z00Cooa`0oookJ_ooN@3oo`1?1OoonfX00ol0oh_o
0?neooo90006ooo90004o`P0oooob@3oolT0og_o00GoolT000Co0?lQo`3oX_oob@3oN@3o0ooob@02
oomi0003ooo90?oo003oolT000;oolT000Coo`00obT0oooUo`3oiOl00_oob@04onGo00?oolT00_oo
Y`02ooo9013oiOl02Ooob@000ol0ongooo]ZoookJP02oookJP03ool0k?oonf[ooo]Z00;ooo]Z3_oo
N@000ooo0:[oogT0oookJP04oolX0003of`0oooonf[oH_l000[ooo]Z00?oobP0oookJ_oonfX00_oo
nfX00ol00ooooo]ZoookJP04oookJP05o`3oMooonf[oobP0ogT0oooo:0001OoonfX01?oo_`3ooo]Z
oookJ_l0oj84oolX0003oookJ_oo0?;ooo]Z00Cooo]Z00Coo`2PoookJ_mD0?oo02Go0_oonfX00olZ
0?oooo]ZoookJP02oookJP05og_o0?oonf[ooo]ZoookJ_oo@@000ooonfX00ol0ocSooo]ZoookJP0>
oookJP03ool0]Ooonf[ooo]Z0;oooo]Z00?o0?l9oookJ_oonfX01OoonfX00ol02ooooo]ZoookJP02
oookJP03ok3o0?oonf[o0?_o00?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05009oookJP06oonX0?oo
nf[ooo]ZoookJ_oo0;Coob403OoonfX00ol0ol3oo`07oookJP0FoookJP05okSo0?oonf[ooo]Zoook
J_m/0?l01_oonfX03Oo]0?ooWOl0oookJ_oo0=coE`3ooong0?nC0?oooo]Zonco0?oo003ooo]Zob/0
oooBo`000ooonfX01Onho`3ooa`0oookJ_l0oiKoo`1?00Cooo]Z00?o0?n;oookJ_l0okD00ooonfX0
5Ooo0;Gooo]ZoolP0?oonf[o0?lhoom10?mko`3o:P3oo`0Uoooo0:3o0?mFool0l_l0ob7o0?nRoook
J_mi0?oo0?mgo`3oB?l00oooF_l0on;o0002oookJP08of;o0?m/0?oooo]Zool0Z_lY0?oo0?o`oole
0?l0POl2o`3oj006ool0k?l0hooo0000o`3okOl0oo;o7@3o0_ooY`02o`3o2@03og`0ool02ooo00_o
00So00_o0_ldo`03o`3o2@05oookJ_ooY`3ooo]ZoookJ_oo6P000ooonfX2o`3ok@Gooo]Z00ooo`3/
oookJ_oonf[ooo]ZocKo0?oonf[o0?oXoole0?oo00_ooo]ZoooX0?oonf[o0?o`oookJ_lY0?l00_oo
nfX00omI0?ooo`2ZoookJP03oookJP05ool=0?ooh`3ooo]Zof`0oomRo`002_oonfX00ooRo`3ooo]Z
oookJP02oookJP03ool0m_l00ooooo]Z00Gooo]Z00?o0?mgoookJ_mi0?l01_oonfX01?oo_`3ooo]Z
oookJ_l0oj82oookJP05o`3o8Ooonf[ooo]ZoookJ_oo0?801?oonfX01?oo0:3ooo]Zoe@0ool09Ol2
oookJP03obX0oooonf[ooo]Z00?ooo]Z00GoNol0oookJ_oonf[ooo]Zoom10002oookJP03o`3o>?oo
nf[ooo]Z00kooo]Z00?oo`2eoookJ_oonfX0GooonfX0067ooo]Z1_oo:005oookJP04o`0;oooonf[o
oo]ZoookJP?oobP000Co0?_ooookJ_oonf[ooo]Z2?oo:005oookJP03oonX0?oonf[ooo]Z00;ooo]Z
00?oob40oookJ_oonfX03?oonfX00ol0ol3oo`00oookJP0EoookJP03okSo0?oonf[ooo]Z00;ooo]Z
0_oo:002oookJPgoo`0000?ooo]Zob/0oooBo`000ooonfX01Ooo703ooo]Zoomi0?oonf[oo`1?00Co
oo]Z00?oogT0oookJ_oob@001_oob@001ol80?ooolT0ooo90?mko`3oolT0obX0oooo0:000_oob@00
1Ol0ob7o0?nRooo90?oob@3oN@3o00;oolT00oooN@000ooo003oolT0ooo90002ooo90003ool00?oU
o`3oiOl000CoolT000?oiOl0ooo90?oob@001?oob@03oonW0003ooo90?oUo`3oiOl000_oiOl01ooo
b@03ool000?ooo]Z0_oo0>`4oookJPkoogT000Coo`2Zoomi0?oonf[ooo]Z1?oo:0000om/0?ooobP0
of;o000:oookJP06on;o0?oonf[ooo]ZoookJ_oo0?Ko00?o1_oonfX01?l0ogOooo]ZogT0oonGo`06
oookJP04oono0?oonf[o0?nRoookJP?oobP00_oonfX00ooo0?;ooo]ZoookJP03oookJP04ool0X?oo
nf[oE03oo`0Uo`;ooo]Z00?o:P3ooookJ_oonfX00_oonfX01Omko`3ooo]ZoookJ_oonf[ood4000?o
oo]Z00?o0?lhoookJ_oonfX03_oonfX00ooo0;Gooo]ZoookJP2ooookJP03o`3o2Ooonf[ooo]Z00Go
oo]Z00?o00_ooookJ_oonfX00_oonfX00on`o`3ooo]Zo`3ko`03oookJP05odh0oooonf[ooo]Zoook
J_oo01@02OoonfX00oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00_ooo]Z00?o0?o0ool0
1ooonfX05_oonfX01Onho`3ooo]ZoookJ_oonf[oK03o00Kooo]Z00gok@3ooigo0?oonf[ooo]ZoeL0
oooo]`3oT`3ooookJ_o/o`3oo`00oookJ_l[0?ood_l000?ooo]Z00Go^?l0oolL0?oonf[o0?nFool0
C`04oookJP03o`3oRooonf[o0?ne00?ooo]Z01Goo`2eoookJ_oo803ooo]Zo`P0ool0ocSoNol0oook
J_lZ0?ooo`2PoookJ_oo0?;o0?lQo`3oX_oonf[oobL0ogT0oooonf[o0?m8o`3o__mJo`000ooonfX0
1_mRo`3oK03ooookJ_oo0:[o:@3oo`3ol0;oocD000Wo087oo`3oj?oo0>co0>?ooookJ_l0ongooo]Z
oad0oooo6P000oooY`03o`3o2@03og`0ooldo`3o=?l000;o=?l000GoO03oo`3o2Ol0o`Wo0?l9oook
JP03oonW0003oookJ_oo6P3ooaX000?ooo]Z00?o0?o]oookJ_oonfX00ooonfX2ool0k0?ooo]Z00Wo
=_l0oookJ_l0onSoocD0oookJ_oo00_oonP0oookJ_l0oo000_oonfX01?lY0?oooo]ZoeT0oooo0:X5
oookJP05ool=0?ooh`3ooo]Zof`0oomRo`002_oonfX01ooRo`3ooo]ZoookJ_oonf[oo`3foookJ_l0
0ol01OoonfX01?l0ogOooo]ZogT0oonGo`06oookJP04oono0?oonf[ooo]Zo`3oXP;ooo]Z00Go0?lQ
oookJ_oonf[ooo]Zool0lP04oookJP04ool0X?oonf[oE03oo`0Uo`;ooo]Z00?o:P3ooookJ_oonfX0
0ooonfX01?mko`3ooo]ZoookJ_oo@@03oookJP03o`3o>?oonf[ooo]Z00kooo]Z00?oo`2eoookJ_oo
nfX0GooonfX0067ooo]Z1_oo:005oookJP03o`0;oooonf[ooo]Z00CoobP000Co0?_ooookJ_oonf[o
oo]Z2Ooo:004oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oob40oookJ_oonfX03?oonfX00ol0ol3o
o`00oookJP0EoookJP03okSo0?oonf[ooo]Z00;ooo]Z0ooo:008ool0000:oong0?oonf[oT`3ooook
J_o/o`3oo`00oookJ_l[0?oooo]Zom;o00;ooo]Z00Go^?l0oolL0?ooN@3oogT0ool0C`04oookJP03
oomi0?oonf[oolT000OoolT000[o0?lhoomi0?mko`3oolT0obX0oooob@3oo`2Pooo90?l0ob7o0?nR
0_oob@001?mi0?ooolT0ooo90?oob@02oomi0003ool00?oob@3oolT000?oolT000?oiOl0ooo90?oo
b@003Ooob@03oonW00_oiOl02?oob@02ool00004oookJ_oo0>coo`3/o`3So`Cooo]Z0oooN@000ooo
=@3oogT0oomi0009oomi00?ooo]Z1?oo:0001?m/0?ooobP0oolX0?oo:009oookJP03on;o0?oonf[o
oo]Z00;ooo]Z00?o00?ooookJ_oonfX01?oonfX01Ol0ogOooo]ZoookJ_mi0?ooUol000Kooo]Z00Co
okl0oookJ_l0oj;ooo]Z0_oo:003oookJP03ool0l_oonf[ooo]Z00;ooo]Z00Coo`2PoookJ_oonf[o
E03o0_oonfX00olZ0?oooo]ZoookJP03oookJP05og_o0?oonf[ooo]ZoookJ_oo@@000ooonfX00ol0
ocSooo]ZoookJP0>oookJP03ool0]Ooonf[ooo]Z0;oooo]Z00?o0?l9oookJ_oonfX01OoonfX00ol0
2ooooo]ZoookJP02oookJP03ok3o0?oonf[o0?_o00?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05009
oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oob40oookJ_oonfX02ooonfX00ol0ol3oo`07oookJP0F
oookJP03okSo0?oonf[ooo]Z00;ooo]Z00?oK03ooookJ_oonfX00ooonfX00oo]0?oooo]Zoigo0002
oookJP09oong0?nC0?oooo]Zool0ZOoo003ooo]Zob/0oooonf[od_l000;ooo]Z00Go^?l0oookJ_oo
703o0?nFool0C`04oookJP04o`3oRooonf[ooo]Zo`3o]@;ooo]Z00?oo`2eoookJ_oo80000_oonfX0
4Ol0ocSood40og_o0?lZ0?oo02Goool0X?oo0?;o0?lQoookJ_l0oj;ooo]ZogT0ool0ogOo0?m8o`03
oomJo`3oh_l000;ooo]Z00SoH_l0of`0oooo3@3ooo]Zool0Z_lY0?oo0?o`oooX00;oocD000Co0?oX
ool0k?oo0>cooo]Z0_l0ond3oad0o`03ool0]?ooY`3oojL000?oojL00ol0o`T00ooonf[oojL0oonW
0002oonW0004ool0]?oo6P3ooaX0oolJ00Cooo]Z00?o0?o]oookJ_oonfX00_oonfX2ool0k00;o`3S
oooonf[ooo]ZoookJ_lfo`3ooo]Zo`3oj?oo=@3ooo]Zool02oooj0000_oonfX01ol0oo3ooo]ZobT0
oooonf[oF@3ooookJ_oo0:X01?oonfX01_oo3@3oon<0oookJ_m/0?oooo]Zof;o00Wooo]Z00?oh_l0
oookJ_oonfX00_oonfX00ooo0?Ko00?ooookJP05oookJP04o`3oMooonf[oN@3ooiOo00Kooo]Z00?o
okl0oookJ_l0oj800ooonfX01Ol0ob7ooo]ZoookJ_oonf[oo`3b00?ooo]Z00Coo`2PoookJ_oonf[o
E03o0_oonfX00olZ0?oooo]ZoookJP04oookJP04og_o0?oonf[ooo]Zoom100?ooo]Z00?o0?lhoook
J_oonfX03_oonfX00ooo0;Gooo]ZoookJP1OoookJP00HOoonfX6oolX00Gooo]Z00?o00_ooookJ_oo
nfX01?oo:0001?l0nooooo]ZoookJ_oonfX9oolX00Cooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo
8@3oo`2doookJP0<oookJP03o`3o`?oo003oo`0001Gooo]Z00?o^?l0oookJ_oonfX00_oonfX3oolX
00Woo`000_oonfX01onC0?ook?l0ool00?ooV`3o:`3ooookJ_oBo`000_oonfX01Onho`3ooa`0oomi
0?ooN@3oo`1?00Cooo]Z0_ooN@04ooo9000;oookJ_oo0;Goo`00oookJ_l80?oo0?lhoom10?mko`3o
:P3oooo90?oo0:000_oob@001Ol0ob7o0?nRooo90?oob@3oN@3o00;oolT00_ooN@02ool000OoolT0
00?oiOl0ooo90?oob@003ooob@09onGo00SoolT00_oo00000ooo0>co0>?oo`3So`03oookJP05ocKo
0?ooN@3oogT0oomi0?oo=@002oooN@001?oo0:[ooo]ZoookJ_oonfX3oolX0003of`0oooo:03oobP0
00?oobP01ooonfX00ooRo`3ooo]ZoookJP03oookJP03o`03oooonf[ooo]Z00Cooo]Z00Co0?mgoook
J_mi0?ooUol01_oonfX00ooo_`3ooo]Zo`3oXP02oookJP;oobP00_oonfX00ooo0?;ooo]ZoookJP03
oookJP04ool0X?oonf[ooo]Zoe@0o`;ooo]Z00?o:P3ooookJ_oonfX00ooonfX01?mko`3ooo]Zoook
J_oo@@04oookJP03o`3o>?oonf[ooo]Z00gooo]Z00?oo`2eoookJ_oonfX0`OoonfX00ol0o`Wooo]Z
oookJP04oookJP03o`0;oooonf[ooo]Z00?ooo]Z00?o/?l0o`3koooonfX00_oonfX00om>0?oooo]Z
oookJP02oookJP03ool05?oonf[ooo]Z00Kooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo8@3ooo]Z
oookJP0;oookJP03o`3o`?oo00Oooo]Z01Kooo]Z00?o^?l0oookJ_oonfX00_oonfX00om/0?oooo]Z
oookJP03oookJP03ond0oooonf[oWOl000;ooo]Z00WookL0oookJ_nC0?oooo]Zonco0?oo003o:`3o
oookJ_oBo`000ooonfX01?nho`3ooa`0oookJ_oo04l5oookJP03o`3oRooonf[o0?ne00?ooo]Z01Ko
o`2eoookJ_oo803ooo]Zo`P0ool0ocSoNol0obX0ool0C?ooE03oool0X?oo0?;o0?lQo`3oX_l0X_oo
oo]ZogT0ool0ogOo0?m8o`3o__mJo`3oh_l00_oonfX02_mRo`3oK03ooookJ_oonf[oo`2ZobT0ool0
oo3o0000oooX0?oo=@02o`3oj0?oo`3/0_l0ond00ooonf[ooaX0oad0o`02oad0o`;oo`2d1?ooY`02
ool0]0?ooaX01_oonfX00ol0ongooo]ZoookJP02oookJP03ool0k?l0hooo0>?o00;ooo]Z0_lfo`00
0ooonf[o0?oXoole0002ool02`06oookJ_ooj03ooo]Zo`3ol?oonf[o:@3o0_oonfX00omI0?ooo`2Z
oookJP04oookJP05ool=0?ooh`3oK03ooookJ_mRo`002OoonfX00ooRo`3ooo]ZoookJP03oookJP03
ool0m_l00ooooo]Z00Gooo]Z00?o0?mgogT0oonGo`001_oonfX01?oo_`3ooo]ZoookJ_l0oj82oook
JP05o`3o8Ooonf[ooo]ZoookJ_oo0?801?oonfX01?oo0:3ooo]ZoookJ_mD0?l2oookJP03obX0oooo
nf[ooo]Z00Cooo]Z00CoNol0oookJ_oonf[ood400ooonfX00ol0ocSooo]ZoookJP0=oookJP03ool0
]Ooonf[ooo]Z063ooo]Z001QoookJPOoobP01?oonfX00ol02ooooo]ZoookJP04oolX0003o`3koooo
:03ooo]Z00;ooo]Z00CoCP3ooookJ_oonf[oobP02?oonfX00oooZ03ooo]ZoookJP02oookJP03oolQ
0?oo0;Cooo]Z00cooo]Z00?o0?o0ool00?oo00005OoonfX00onho`3ooo]ZoookJP02oookJP?oobP0
1Ooo00003Ooonf[oWOl0oookJ_oonf[ookL0oookJ_nC0?ook?l0ool00?ooV`3o:`3ooookJ_oo:000
0ooonfX01?oo703oogT0oomi0?oo04l4oookJP?oogT01?oonfX03_oo0;Goo`00ool00?oonf[o0?lh
oom10?mko`3oolT0obX0oooob@3oo`2Pool0l_l0ob7o0?nR0_oob@001?mi0?ooolT0ooo90?oob@02
oomi0003ool00?oob@3oolT0017oolT00_oo:005ooo900KoiOl000?oolT0onGo0?oob@001ooob@02
ool00003o`3Soooonf[ooo]Z00;ooo]Z0_ooN@000ol0onSoogT0oole0002oomi0003oooX0?ooN@3o
ogT000KoogT000Coo`2ZoookJ_oonf[ooo]Z1?oo:0001?m/0?ooobP0oolX0?oo:009oookJP03on;o
0?oonf[ooo]Z00;ooo]Z00?oo`3fo`03oooonfX01OoonfX01?l0ogOoN@3ooookJ_nGo`06oookJP03
oono0?oonf[o0?nR00;ooo]Z00GoobP0oookJ_oonf[ooo]Zool0lP05oookJP04ool0X?oonf[oE03o
o`0Uo`;ooo]Z00?o:P3ooookJ_oonfX00_oonfX01Omko`3ooo]ZoookJ_oonf[ood4000Cooo]Z00?o
0?lhoookJ_oonfX03OoonfX00ooo0;Gooo]ZoookJP31oookJP03o`3o2Ooonf[ooo]Z00Cooo]Z00?o
00_ooookJ_oonfX00ooonfX00on`o`3o0?_ooookJP03oookJP05odh0oooonf[ooo]ZoookJ_oo01@0
2?oonfX00oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00_ooo]Z00?o0?o0ool01ooonfX0
5_oonfX00onho`3ooo]ZoookJP02oookJP03of`0oooonf[ooo]Z00?ooo]Z00?ok@3ooookJ_nMo`00
0_oonfX02Ooo]`3ooo]Zoi<0oooonf[ok?l0ool00?l[0?oooo]Zom;o0003oookJP05okSo0?oo703o
oo]Zo`3oU_oo04l01?oonfX00ol0oh_ooo]Zo`3o]@03oookJP03ool0]Ooonf[oob0000;ooo]Z017o
0?lhoonL0?mko`3o:P3oo`0Uoooo0:3oo`3bo`3o8Ooonf[o0?nRoookJ_nGo`3oN@3oo`3oB?l00ooo
0?nnoe[o0003oookJP06of;o0?m/0?ooo`d0oookJ_oo0:[ooo]Z0_l0oo001_ooj03oocD0oole0?l0
onSooo]Zo`3So`;oo`3/1?l0ond3oolJ00;o7@3o1?oo6P06oookJP?o0?o]0ooonfX2ool0k006o`3S
oooonf[ooo]ZoookJ_lfo`3ooo]Z0_l0onP01Ooo=@3oo`0;oookJ_oonf[oonP000;o0?o`00Oooo]Z
obT0oooonf[ooo]ZoeT0oooonf[oo`2Z00Cooo]Z00?oo`d0oooS0?m/0?l00_oonfX00omRo`3ooo]Z
oookJP07oookJP03on;o0?oonf[ooo]Z00;ooo]Z00?oo`3foookJ_l00ol01OoonfX01?l0ogOooo]Z
ogT0oonGo`06oookJP03oono0?oonf[o0?nR00?ooo]Z00Go0?lQoookJ_oonf[ooo]Zool0lP04oook
JP04ool0X?oonf[oE03oo`0Uo`;ooo]Z00?o:P3ooookJ_oonfX00ooonfX01Omko`3ooo]ZoookJ_oo
nf[ood4000?ooo]Z00?o0?lhoookJ_oonfX03OoonfX00ooo0;Gooo]ZoookJP1PoookJP00HOoonfX7
oolX00Gooo]Z00?o00_ooookJ_oo:0000ooo:0000ol0noooobP0oookJP02oookJP04odh0oooonf[o
oo]ZoolX00Sooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo8@3oo`2doookJP0<oookJP04o`3o`?oo
003oo`00ool001Cooo]Z00?o^?l0oookJ_oonfX00_oonfX4oolX00Gooo]Z00coobP0oookJ_oonf[o
okL0oookJ_nC0?oooo]Zool00?ooV`3ooo]Zob/0oooo:003oookJP05oolL0?ooN@3oogT0oomi0?oo
04l00ooonfX3oomi0005o`3o]Ooonf[ooo]ZoookJ_oo0;D00ooo00002_l80?oo0?lhog_o0?ooN@3o
:P3oooo90?oo0:3oolT0ool0l_l0ob43ooo90005ogT0oooob@3oolT0ooo90?ooN@000_oo000Aooo9
0003ool0k?oo:03oobP000;oobP01?oob@04onGo00CoobP00_oo00000ooonf[oolT0ooo90002ooo9
0003o`3Soooonf[ooo]Z00;ooo]Z00Go=_l0oomi0?ooN@3o0?oXoole000:oomi0003oookJ_ooN@3o
o`2Z00Cooo]Z0ooo:0001?m/0?ooobP0oolX0?oo:009oookJP03on;o0?oonf[ooo]Z00?ooo]Z00?o
00?ooookJ_oonfX01?oonfX01?l0ogOooo]ZogT0oonGo`07oookJP03oono0?l0oj;ooo]Z00;ooo]Z
00Go0?lQoookJ_oonf[ooo]Zool0lP04oookJP04ool0X?oonf[ooo]Zoe@0o`;ooo]Z00?o:P3ooook
J_oonfX00ooonfX01Omko`3ooo]ZoookJ_oonf[ood4000?ooo]Z00?o0?lhoookJ_oonfX03_oonfX0
0ooo0;Gooo]ZoookJP31oookJP03o`3o2Ooonf[ooo]Z00Gooo]Z00?o00_ooookJ_oonfX00_oonfX0
0on`o`3o0?_ooookJP03oookJP05odh0oooonf[ooo]ZoookJ_oo01@02?oonfX00oooZ03ooo]Zoook
JP02oookJP03oolQ0?oonf[ooo]Z00_ooo]Z00?o0?o0oookJ_oo00L05_oonfX00onho`3ooo]Zoook
JP02oookJP03of`0oooonf[ooo]Z00Gooo]Z00coWOl0oookJ_oonf[ookL0oookJ_nC0?oooo]Zonco
0?oo003ooo]Zob/0oooBo`03oookJP05okSo0?oo703ooo]Zo`3oU_oo04l01?oonfX01?l0oh_ooo]Z
oookJ_l0okD2oookJP03ool0]Ooonf[oob0000;ooo]Z01;o0?lhoom10?mko`3o:P3ooookJ_mD0?oo
o`2Pool0l_l0ob7o0?nRo`2Roooonf[oUol0ogT0ool0odSo00?ooe[o0?oRo`03oookJP07of;o0?m/
0?ooo`d0oookJ_oo0:[oF@3oo`000002o`3ol003oooX0?oo=@3o0?oX00;ooo]Z00Go0>?oool0k?oo
0>coo`3/oookJP05o`3ok@Gooo]Z1Ol0ond4oookJP;oo`3/00?o0>?ooookJ_oonfX00_oonfX01olf
o`3ooo]Zo`3oj?oo=@3o=ol0ool02ooonfX00_ooj0001?l0oo3ooo]ZoookJ_lY0?l2oookJP03oeT0
oooonf[oo`2Z00Cooo]Z00?oo`d0oookJ_m/0?l00_oonfX00omRo`3ooo]ZoookJP07oookJP03on;o
0?oonf[ooo]Z00?ooo]Z00?oo`3fo`03oooonfX01OoonfX00ol0ogOoN@3ooiOo0007oookJP03oono
0?oonf[o0?nR00?ooo]Z00Go0?lQoookJ_oonf[ooo]Zool0lP03oookJP04ool0X?oonf[ooo]Zoe@0
o`;ooo]Z00?o:P3ooookJ_oonfX01?oonfX01?mko`3ooo]ZoookJ_oo@@03oookJP03o`3o>?oonf[o
oo]Z00kooo]Z00?oo`2eoookJ_oonfX0H?oonfX0063ooo]Z2?oo:005oookJP03o`0;oooonf[oobP0
00?oobP000?o0?_ooolX0?oonfX00_oonfX01?m>0?oooo]ZoookJ_oo:008oookJP03oonX0?oonf[o
oo]Z00;ooo]Z00?oobP0ool0]?oonfX03?oonfX4ool001Gooo]Z00?o^?l0oookJ_oonfX01Ooo:005
oookJP0;oolX0?oonf[ooo]Zoong0?oonf[oT`3ooookJ_o/o`3oo`00oookJ_l[0?l00_oo:002oook
JP05okSo0?oo703oogT0oomi0?oo04l01?oonfX3oomi00Cooo]Z00koo`2eool00?oo003o203oo`3o
>?oo@@3oNol0oomi0?lZ0?ooE03oool0X?ooN@3oolT0o`3o8@?oolT000KoN@3oo`3oB?ooN@3oogT0
ool00?ooN@0Cooo900CoobP00ooob@001?oUo`3oobP0oolX0?oUo`03oolX00;oo`0000CoogT0oook
J_oo0>coo`3/0_l0hol4oookJP;oogT00_l0onP00ooo=@3oogT0oomi0006oomi0003obT0ooooN@3o
ogT000;oo`2Z1?oonfX3oolX0004of`0oooo:03oobP0of;o00Sooo]Z00?oo`00on;o0?oonfX01?oo
nfX00ooo0?Ko00?ooookJP05oookJP03o`3oMomi0?ooUol000Oooo]Z00?ookl0oookJ_l0oj800_oo
nfX01Ol0ob7ooo]ZoookJ_oonf[oo`3b00Gooo]Z00Coo`2PoookJ_oonf[oE03o0_oonfX00olZ0?oo
oo]ZoookJP03oookJP04og_o0?oonf[ooo]Zoom100Cooo]Z00?oobP0oookJ_oonfX03OoonfX00ooo
0;Gooo]ZoookJP32oookJP03o`3o2Ooonf[ooo]Z00Gooo]Z00?o00_ooookJ_oonfX00_oonfX00on`
o`3o0?_ooookJP03oookJP05odh0oooonf[ooo]ZoookJ_oo01@02?oonfX00oooZ03ooo]ZoookJP02
oookJP03oolQ0?oonf[ooo]Z00_ooo]Z00?o0?o0oookJ_oo00L05ooonfX01Onho`3ooo]ZoookJ_oo
nf[oK03o00Oooo]Z00goWOl0oookJ_oonf[ookL0oookJ_nC0?oooo]Zonco0?oo003ooo]Zob/0oooo
nf[od_l000;ooo]Z00Go^?l0oolL0?oonf[ooo]Zool0C`05oookJP03o`3oRooonf[o0?ne00?ooo]Z
00ooo`2eoookJ_oo803ooo]Zo`P0ool0ocSooo]Zog_o0?lZ0?oo02Goool0X?l0oeKoo`3bo`3o8Ol0
oj800_oonfX01_mi0?oooo]Zo`3oB?l00oooF_l0on;o00?ooo]Z00CoH_l0of`0ooooh`3ooo]Z0_oo
0:X01Ol0003o:@3oo`3ol?ooj03o0?nG00;o0?oX00Co=_l0o`3Sool0hooo0>?o0_oo0>`4oookJPGo
0?o]1ooonfX2ool0k003o`3Soooonf[ooo]Z00?ooo]Z00[o=_l0o`3oj?l0onSoocD0ocOo0?oo00_o
oo]ZoooX0?oonf[o0?o`0_oonfX01?lY0?oooo]ZoeT0oomI0?l2ool0ZPGooo]Z00Goo`d0oooS0?m/
0?oooo]Zof;o0009oookJP03on;o0?oonf[ooo]Z00?ooo]Z00?oo`3foookJ_l00ol01_oonfX00ol0
ogOoN@3ooookJP06oookJP04oono0?oonf[ooo]Zo`3oXP;ooo]Z00Go0?lQoookJ_oonf[ooo]Zool0
lP04oookJP04ool0X?oonf[ooo]Zoe@0o`;ooo]Z00?o:P3ooookJ_oonfX01?oonfX01?mko`3ooo]Z
oookJ_oo@@03oookJP03o`3o>?oonf[ooo]Z00gooo]Z00?oo`2eoookJ_oonfX0HOoonfX0063ooo]Z
2Ooo:004oookJP03o`0;oooo:03oobP000?oobP000?o0?_ooolX0?oo:0000_oonfX01?m>0?oooo]Z
oookJ_oo:008oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oobP0ool0]?oonfX03?oonfX4ool001Go
oo]Z00?o^?l0oookJ_oonfX01_oo:004oookJP;oobP000Wooo]Zoong0?oonf[ooo]Zoi<0ooo/o`3o
o`00oookJ_l[0?l00ooo:002oookJP05oolL0?ooN@3oogT0ool0CoooN@000ooonfX4oomi00?ooo]Z
01?oo`2eool00?oo003oo`00o`P0ool0ocSoNol0oomi0?lZ0?ooE03oool0X?ooN@3oolT0o`3o8Ooo
b@3ookl0oiOo0?mi0?oo0?mg00CoogT05?oob@04oolX0004ooo90?ooN@3oogT0oomi00GoobP00_oo
00001?ooN@3oo`3/o`3Sool0hol4oookJP06ocKo0?ooN@3oogT0o`3oj?ooN@3oocD02?ooN@000olY
0?ooogT0oomi0002oomi00Gooo]Z0ooo:0000om/0?ooobP0of;o0009oookJP;oo`001?oonfX00ooo
0?Ko00?ooookJP05oookJP04o`3oMooonf[oN@3ooiOo00Oooo]Z00?ookl0oookJ_l0oj800_oonfX0
1Ol0ob7ooo]ZoookJ_oonf[oo`3b00Cooo]Z00Coo`2PoookJ_oonf[oE03o0ooonfX00olZ0?oooo]Z
oookJP02oookJP05og_o0?oonf[ooo]ZoookJ_oo@@001?oonfX00ooo:03ooo]ZoookJP0=oookJP03
ool0]Ooonf[ooo]Z0<;ooo]Z00?o0?l9oookJ_oonfX01OoonfX00ol02ooooo]ZoookJP02oookJP03
ok3o0?l0nooooo]Z00?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05008oookJP03oonX0?oonf[ooo]Z
00;ooo]Z00?oob40oookJ_oonfX03?oonfX00ol0ol3oo`07oookJP0FoookJP05okSo0?oonf[ooo]Z
oookJ_m/0?l01ooonfX01?nMo`3ooo]ZoookJ_oo]`02oookJP07oi<0oooonf[oo`00oookJ_l[0?oo
oo]Zom;o0003oookJP04okSo0?oo703ooo]Zool0C`Gooo]Z00?o0?n;oookJ_l0okD00ooonfX00ooo
0;Gooo]ZoolP0002oookJP0Bo`3o>?oo@@3oNol0obX0oooonf[oE03oool0X?oo0?;o0?lQo`3oX_oo
_`3ooo]ZoiOo0?mi0?oo0?m8o`03oooonf[oF_l01?oonfX00omRo`3oK03ooooS0002o`000003ool0
Z_l0003ooo]Z00;o0?o`00Coo`0;oole0?l0onSo0?oX0_lfo`02o`3So`?oo`3/2OoonfX4ool0k003
o`3Soooonf[ooo]Z00?ooo]Z0_lfo`001Ol0onSo087ooole0?lgo`3oo`0;00;oonP000?ooo]Zo`3o
l?oonfX00_lY0?l01?oonf[oF@3ooookJ_oo0:X5oookJP;oo`d000Coon<0of`0oooonf[oH_l02_oo
nfX00ooRo`3ooo]ZoookJP02oookJP03ool0m_oonf[o00?o00Kooo]Z00?o0?mgogT0oonGo`001ooo
nfX00ooo_`3ooo]Zo`3oXP02oookJP03o`3o8Ooonf[ooo]Z00;ooo]Z00Goo`3boookJ_oonf[ooo]Z
ool0X002oookJP05oe@0oooonf[ooo]ZoookJ_lZ0?l01OoonfX01Omko`3ooo]ZoookJ_oonf[ood40
00?ooo]Z00?o0?lhoookJ_oonfX03OoonfX00ooo0;Gooo]ZoookJP1QoookJP00H?oonfX9oolX00Co
oo]Z00?o00_ooolX0?oo:0000ooo:0000ol0noooobP0oolX0002oookJP04odh0oooonf[ooo]ZoolX
00Sooo]Z00?oojP0oookJ_oonfX00_oonfX2oolX00gooo]Z1Ooo000DoookJP03okSo0?oonf[ooo]Z
00KoobP01?oonfX2oolX0009oookJ_oo]`3ooo]ZoookJ_nC0?ook?l0ool00?ooV`3o:`3o00?oobP0
0_oonfX01_oo703oogT0oomi0?ooN@3oo`1?oomi00;ooo]Z1OooN@02oookJP03ool0]Ooo003oo`00
00;oo`0000oo0?lhoom10?mko`3oogT0obX0oomD0?ooo`2Pooo90?oo0?;o0?lQoono0?ooN@3oUol0
ogT0ool0ogL01?ooN@0Booo90004o`3oj?ooN@3oogT0oomi00;oobP01OooN@03oolX00;oo`0000?o
ogT0oookJ_oonfX00ooonfX2ocKo00?o0?oX00?oogT0oole0?ooN@001_ooN@000olY0?ooogT0oomi
0004oomi00Cooo]Z0ooo:0000om/0?oooo]Zof;o0009oookJPCoo`000_oonfX00ooo0?Ko00?ooook
JP05oookJP04o`3oMooonf[oN@3ooiOo00Oooo]Z00?ookl0oookJ_l0oj800_oonfX00ol0ob7ooo]Z
oookJP02oookJP03ool0l_oonf[ooo]Z00;ooo]Z00Coo`2PoookJ_oonf[oE03o0_oonfX00olZ0?oo
oo]ZoookJP03oookJP05og_o0?oonf[ooo]ZoookJ_oo@@000ooonfX00ooo:03ooo]ZoookJP0=oook
JP03ool0]Ooonf[ooo]Z0<?ooo]Z00?o0?l9oookJ_oonfX01OoonfX00ol02ooooo]ZoookJP02oook
JP03ok3o0?l0nooooo]Z00?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05008oookJP03oonX0?oonf[o
oo]Z00;ooo]Z00?oob40oookJ_oonfX03?oonfX00ol0ol3oo`07oookJP0FoookJP03okSo0?oonf[o
oo]Z00;ooo]Z00?oK03ooookJ_oonfX01OoonfX03?nMo`3ooo]ZoookJ_oo]`3ooo]Zoi<0oooonf[o
k?l0ool00?l[0?oooo]Zom;o00?ooo]Z00Go^?l0oolL0?oonf[o0?nFool0C`05oookJP03o`3oRooo
nf[o0?ne00;ooo]Z01Soo`2eoookJ_oonf[oob00oookJ_l80?oo0?lhoookJ_mko`3o:P3oo`0UoomD
0?ooo`2Pool0l_l0ob7o0?nRo`2Roooonf[oUol0ogT0ool0odSo00?ooookJ_mJo`04oookJP06of;o
0?m/0?ooK03oool=0?l0003oo`2Z0_oonfX01OlY0?oo0?o`o`3ol?l0oiOoocD000;o0?oX0olfo`02
o`3So`Woo`3/0_l0hol5oookJP?o=_l00_l0onP01Ol0POooocD0ool02ooo00_oonP000;ooo]Z00?o
0?o`obT0oolY0?l00_oonfX00omI0?oooo]Zool0ZP05oookJP04ool=0?oonf[oon<0of`0o`;ooo]Z
00?oH_l0oookJ_oonfX01ooonfX00ooRo`3ooo]ZoookJP03oookJP03ool0m_l00ooooo]Z00Gooo]Z
00?o0?mgoookJ_mi0?l01ooonfX01?oo_`3ooo]ZoookJ_l0oj82oookJP03o`3o8Ooonf[ooo]Z00;o
oo]Z00Goo`3boookJ_oonf[ooo]Zool0X002oookJP04oe@0oooonf[ooo]ZobX0o`Kooo]Z00CoNol0
oookJ_oonf[ood400ooonfX00ol0ocSooo]ZoookJP0=oookJP03ool0]Ooonf[ooo]Z06;ooo]Z001T
oookJP03oolX0?oonf[ooo]Z00Kooo]Z00?o00_ooolX0?oo:0000ooo:0000ol0nooooo]ZoookJP02
oookJP04odh0oooonf[ooo]ZoolX00Sooo]Z00?oobP0oookJ_oonfX00_oonfX2oolX00gooo]Z1Ooo
000DoookJP03okSo0?oonf[ooo]Z00OoobP00ooonfX3oolX0008oookJ_oo]`3ooo]Zoi<0ooo/o`3o
o`00oonK0?l[0?l4oolX0003oookJ_nho`3ooa`000;oogT000Coo`1?oomi0?oonf[ooo]Z1OooN@03
oookJP03ool0]Ooo003oo`0000;oo`0000oo0?lhoom10?mko`3o04coobX0oooo0:3oogT0ool0l_l0
ob7o0?nRoono0?ooN@3oN@3ooomi0?l0ogL00oooN@0Cooo900Co0?oX2?ooN@000ooo:03oogT0ool0
0003ooo90003oookJ_lfo`3o0?oX00;o0?oX00CoogT0oole0?oo=@3oocD01?ooN@000ol0oo3oogT0
obT0o`09oomi00;ooo]Z00Koo`d0oolX0?m/0?ooK03ooookJ_mRo`09oookJPKoo`0000?ooo]Zool0
m_l00ol01_oonfX01?l0ogOooo]ZogT0oonGo`07oookJP03oono0?oonf[o0?nR00;ooo]Z00Go0?lQ
oookJ_oonf[ooo]Zool0lP04oookJP04ool0X?oonf[ooo]Zoe@0o`?ooo]Z00?o:P3ooookJ_oonfX0
0ooonfX01?mko`3ooo]ZoookJ_oo@@04oookJP03oolX0?oonf[ooo]Z00gooo]Z00?oo`2eoookJ_oo
nfX0`ooonfX00ol0o`Wooo]ZoookJP05oookJP03o`0;oooonf[ooo]Z00;ooo]Z00?o/?l0o`3koooo
nfX00ooonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Sooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo
8@3ooo]ZoookJP0<oookJP03o`3o`?oo00Oooo]Z01Kooo]Z00?o^?l0oookJ_oonfX00_oonfX00om/
0?oooo]ZoookJP05oookJP0:oigo0?oonf[ooo]Zoong0?oonf[oT`3ooookJ_o/o`3oo`00ob/0o`;o
oo]Z00God_l0oookJ_oonf[o^?l0oolL0002oookJP03ool0Cooonf[ooo]Z00?ooo]Z00?o0?n;oook
J_l0okD00ooonfX00ooo0;Gooo]ZoolP0002oookJP0Do`3o>?oo@@3oNol0o`1<oolZ0?ooE03oool0
X?oo0?;o0?lQoookJ_l0oj;o0:;ooookJ_mi0?oo0?mgo`3oB?l00ooooo]Zoe[o0?oRo`04oookJP0=
of;o0?m/0?ooo`d0o`000?oo0:[oF@3ooookJ_lY0?ooonP0o`3ol?ooj03oo`0;oole0004o`3oj0;o
=_l03OoonfX2ocKo00?o0?oX00Co087ooole0?oo=@3oo`0;0_ooj0001?oonf[o0?o`o`3ol?lY0?l3
oookJP03oeT0oooonf[oo`2Z00Gooo]Z00Coo`d0oookJ_m/0?ooK03o0_oonfX00omRo`3ooo]Zoook
JP08oookJP03on;o0?oonf[ooo]Z00;ooo]Z00?oo`3fo`03oooonfX01_oonfX00ol0ogOoN@3ooiOo
0007oookJP03oono0?oonf[o0?nR00;ooo]Z00?o0?lQoookJ_oonfX00_oonfX01Ooo0?;ooo]Zoook
J_oonf[oo`2P00;ooo]Z00GoE03ooookJ_oonf[ooo]ZobX0o`06oookJP04og_o0?oonf[ooo]Zoom1
00?ooo]Z00?o0?lhoookJ_oonfX03OoonfX00ooo0;Gooo]ZoookJP1RoookJP00I?oonfX00ooo:03o
oo]ZoookJP06oookJP03o`0;oooonf[ooo]Z00;ooo]Z00?oobP0o`3koooonfX00ooonfX01?m>0?oo
oo]ZoookJ_oo:008oookJP03oolX0?oonf[ooo]Z00;ooo]Z0ooo:00<oookJPKoo`004ooonfX00ooo
003ooo]ZoookJP07oolX00?ooo]Z0ooo:0002Ooonf[ookL0oookJ_oonf[oT`3oool00?ooV`3ooo]Z
ob/0o`03oolX00;ooo]Z00Cooa`0oomi0?ooN@3oo`1?0_ooN@000ooonf[oogT0oomi0004oomi00;o
oo]Z00?oo`2eool00?oo00000_oo00002ol0ocSood40og_o0?ooN@3o:P3ooe@0oooo0:3oogT0ool0
l_l0ob7o0?nR00;oogT000?oN@3oo`3oMoooN@000oooN@05ooo90003oomi0?oob@3oolT000OoolT0
0_l0oo05ooo900Ko0?oX1OooN@05o`3oj004oomi0?oo=@3oocD0oole00CoogT00ol0oo02obT0o`co
ogT000GoobP0of`0oooo:03ooo]Zof;o000:oookJPOoo`0000?o00?ooookJ_oonfX01?oonfX01?l0
ogOooo]ZogT0oonGo`07oookJP03oono0?oonf[o0?nR00;ooo]Z00Go0?lQoookJ_oonf[ooo]Zool0
lP05oookJP04ool0X?oonf[ooo]Zoe@0o`?ooo]Z00?o:P3ooookJ_oonfX00_oonfX01Omko`3ooo]Z
oookJ_oonf[ood4000?ooo]Z00?oobP0oookJ_oonfX03OoonfX00ooo0;Gooo]ZoookJP34oookJP03
o`3o2Ooonf[ooo]Z00Gooo]Z00?o00_ooookJ_oonfX00_oonfX00on`o`3o0?_ooookJP03oookJP05
odh0oooonf[ooo]ZoookJ_oo01@02?oonfX00oooZ03ooo]ZoookJP03oookJP03oolQ0?oonf[ooo]Z
00_ooo]Z00?o0?o0ool01ooonfX05_oonfX00onho`3ooo]ZoookJP02oookJP03of`0oooonf[ooo]Z
00Gooo]Z00CoWOl0oookJ_oonf[ookL00_oonfX01onC0?ook?l0ool00?oonf[o:`3ooookJ_oBo`00
0ooonfX01Onho`3ooa`0oookJ_l0oiKoo`1?00Gooo]Z00?o0?n;o`3o]OoonfX00ooonfX04?oo0;Go
ob00oookJ_oonf[o0?lhoom10?oonf[oNol0obX0oooonf[oE03oool0X?oo0?;o0?lQoono0?l0oj82
oookJP05ogT0ool0odSooo]Zo`03oooonfX00_mJo`03oookJP05o`000?mRo`3oK03ooooS0?oonfX0
0_oo0:X00omI0?oo:@3oobT0o`02o`3ol003oooX0?oo=@3oocD000;oocD01_l0onP5oookJP03ocKo
0?l0onSo0?oX00?o0?oX00Co087ooole0?oo=@3oocD00oooj003o`3ol0;o:@3o0ooonfX00omI0?oo
oo]Zool0ZP05oookJP03ool=0?oonf[oK03o00?ooo]Z00?oH_l0oookJ_oonfX02?oonfX00ooRo`3o
oo]Zoe[o0002oookJP03ool0m_oonf[o00?o00Kooo]Z00?o0?mgoookJ_mi0?l01ooonfX01?oo_`3o
oo]ZoookJ_l0oj82oookJP05o`3o8Ooonf[ooo]ZoookJ_oo0?801?oonfX01?oo0:3ooo]ZoookJ_mD
0?l3oookJP03obX0oooonf[ooo]Z00?ooo]Z00GoNol0oookJ_oonf[ooo]Zoom10002oookJP03o`3o
>?oonf[ooo]Z00gooo]Z00?oo`2eoookJ_oonfX0HooonfX006Cooo]Z00?oobP0oookJ_oonfX01_oo
nfX00ol02ooooo]ZoookJP02oookJP03oolX0?oo003ooo]Z00?ooo]Z00CoCP3ooookJ_oonf[oobP0
2?oonfX2oolX00?ooo]Z0ooo:00<oookJPKoo`004ooonfX00ooo003ooo]ZoookJP07oolX00?ooo]Z
1?oo:0002?oo]`3ooo]ZoookJ_nC0?ook?l0ool00?oonf[o:`3o1?oo:0000ooonf[oogT0oolL0002
oomi0003ool0CoooN@3ooo]Z00OoogT000?ooo]Zool00?oo0;D01?oo00002ol0ocSood40og_o0?oo
N@3o:P3ooe@0oooo0:3oogT0ool0l_l0ob7ookl000;oogT000?oN@3oo`3oMoooN@000_ooN@04ooo9
00?oogT02_oob@02o`3ol0CoolT01OooN@05o`3oj003ooo90?oo=@3oocD000?oocD01OooN@02o`3o
l003oomi0?lY0?oo:@3o00koogT000CoK03ooookJ_mRo`3oH_l02_oonfX9ool000Gooo]Z00Go0?mg
oookJ_mi0?ooobL0oiOo0004oookJP;oobP000Cooo]Zoono0?oonf[o0?nR0_oonfX01Ol0ob7ooo]Z
oookJ_oonf[oo`3b00Cooo]Z00Coo`2PoookJ_oonf[oE03o0ooonfX00olZ0?oooo]ZoookJP03oook
JP03og_o0?oonf[ooo]Z00;oobP00ooonfX00ooo:03ooo]ZoookJP0=oookJP03ool0]Ooonf[ooo]Z
0<Cooo]Z00?o0?l9oookJ_oonfX01OoonfX00ol02ooooo]ZoookJP02oookJP03ok3o0?l0nooooo]Z
00?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05008oookJP03oonX0?oonf[ooo]Z00?ooo]Z00?oob40
oookJ_oonfX02ooonfX00ol0ol3ooo]Zool01`0FoookJP03okSo0?oonf[ooo]Z00;ooo]Z00?oK03o
oookJ_oonfX01_oonfX00onMo`3ooo]Zoong0002oookJP07oi<0oooonf[ok?l0ool00?l[0?oooo]Z
om;o0003oookJP05okSo0?oo703ooo]Zo`3oU_oo04l01OoonfX00ol0oh_ooo]Zo`3o]@03oookJP03
ool0]Ooonf[oob0000;ooo]Z00co0?lhoom10?oonf[oNol0obX0ool09Oooo`2Po`3oE_oo0?;o0?lQ
o`3oX_l0X_l2oookJP07ogT0ool0odSooo]Zo`03oooonf[o0?nnoe[o0002oookJP;o000000?oH_l0
of`0ooooh`000_oonfX2ool0ZP03oeT0oolY0?oo:@3o00?o0?o`0_ooj006oole00Ko0?oX00?o0?nG
oole0?oo=@000ooo=@001?oo00_oonP0oooX0?oonfX2o`3ol003oookJ_lY0?oo:@3o00?ooo]Z0_mI
0?l00ooonf[oo`2ZoookJP04oookJP03ool=0?oonf[oK03o00;ooo]Z0_mRo`0:oookJP03on;o0?oo
nf[oF_l000?ooo]Z00?oo`3fo`03oooonfX01OoonfX01?l0ogOooo]ZogT0oonGo`07oookJP03oono
0?oonf[o0?nR00;ooo]Z00?o0?lQoookJ_oonfX00_oonfX01Ooo0?;ooo]ZoookJ_oonf[oo`2P00;o
oo]Z00GoE03ooookJ_oonf[ooo]ZobX0o`06oookJP04og_o0?oonf[ooo]Zoom100?ooo]Z00?o0?lh
oookJ_oonfX03OoonfX00ooo0;Gooo]ZoookJP1SoookJP00I?oonfX00ooo:03ooo]ZoookJP06oook
JP03o`0;oooonf[ooo]Z00;ooo]Z00?oobP0ool00?oonfX00ooonfX01?m>0?oooo]ZoookJ_oo:008
oookJP;oobP00ooonfX3oolX00cooo]Z1ooo000BoookJP;oo`0000?ooo]ZoolX0?oo:0001_oo:002
oookJPCoobP000SookL0oookJ_oonf[oT`3oonco0?oo003ooi/0ob/0o`GoobP000GoogT0oolL0?oo
N@3oogT0ool0C`09oomi0003oookJ_oo003oo`2e00Coo`00013o0?lhoomi0?oo@@3oNol0obX0oooo
N@3oo`2Poomi0?oo0?;o0?lQo`3oX_oo_`3o0:;ooomi0?mi0?oo0?mg0_oo:003ooo90004oe[o0?oo
nf[oogT0oomi00?oolT00_ooN@000ooob@3oogT0oomi0004ooo900;o0?o`0_oob@04oomi00;oolT0
1Ooo=@02ooo900?oonP00_ooN@03o`3ol0?o:@3o0_oonfX?oomi0003of;o0?oonf[ooo]Z00[ooo]Z
1ooo00000ol00ooooo]ZoookJP04oookJP04o`3oMooonf[oN@3ooiOo00Gooo]Z0ooo:002oookJP03
o`3oX_oonf[o0?lQ00?ooo]Z00?oo`3boookJ_oonfX00ooonfX01?oo0:3ooo]ZoookJ_mD0?l3oook
JP03oolX0?oonf[ooo]Z00?ooo]Z00?oNol0oookJ_oonfX01Ooo:00@oookJP03ool0]Ooonf[ooo]Z
0<Cooo]Z00?o0?l9oookJ_oonfX01OoonfX00ol02ooooo]ZoookJP02oookJP03ok3o0?l0nooooo]Z
00?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05008oookJP03oonX0?oonf[ooo]Z00?ooo]Z00?oob40
oookJ_oonfX02ooonfX00ol0ol3ooo]Zool01`0FoookJP03okSo0?oonf[ooo]Z00;ooo]Z00?oK03o
oookJ_oonfX01_oonfX00onMo`3ooo]Zoong0002oookJP05oi<0oooonf[ok?l0ool00?l[0?l00_oo
nfX01OoBo`3ooo]ZoookJ_nho`3ooa`000;ooo]Z00?o0?nFool0CooonfX00ooonfX00ol0oh_ooo]Z
o`3o]@04oookJP0Kool0]Ooonf[ooo]ZoookJ_l0ocSo203ooom10?mko`3o:P3oo`1<oomD0?ooo`2P
ool0l_l0ob7ooo]Zo`3oX_l0X_oooo]ZoolW0?mi0?oo0?mgoookJ_l00ooooo]Zo`3o__mJo`3ooo]Z
00?o000000CoH_l0of`0ooooh`3oon<00_oonfX2ool0ZP04oeT0oolY0?oo:@3ooookJP;o0?o`0ooo
j004ool02`KoocD000?ooo]Zool02oooj0000oooj003o`3ol0?o:@3o0ooonfX2oeT0o`03oookJ_oo
0:[oo`2Z00Gooo]Z00?oo`d0oooS0?m/0?l00_oonfX00omRo`3ooo]ZoookJP09oookJP03on;o0?oo
nf[oF_l000?ooo]Z00?oo`3fo`03oooonfX01_oonfX00ol0ogOooo]ZogT0o`07oookJP06oono0?oo
nf[ooo]Zo`3oX_oonf[o0?lQ1?oonfX00ooo0?;ooo]ZoookJP02oookJP04ool0X?oonf[ooo]Zoe@0
o`?ooo]Z00?o:P3ooookJ_oonfX01?oonfX01?mko`3ooo]ZoookJ_oo@@02oookJP03o`3o>?oonf[o
oo]Z00kooo]Z00?oo`2eoookJ_oonfX0HooonfX006Cooo]Z00?oobP0oookJ_oonfX01_oonfX00ol0
2ooooo]ZoookJP02oookJP03oolX0?oo003oo`0000?ooo]Z00CoCP3ooookJ_oonf[oobP02?oonfX3
oolX00;ooo]Z1?oo:00:oookJPSoo`004_oonfX3ool000CoobP01_oonfX5oolX0008oong0?oonf[o
T`3ooookJ_oo003ooi/0oookJ_l[0?l4oolX0003oomi0?oo703oogT000;oogT000?oo`1?oomi0?oo
N@001oooN@02ool00003ool0]Ooo003oo`0000;oo`0000co0?lhoom10?mko`3ooo]ZobX0ooooN@3o
o`2Poomi0?oo0?;o0?lQo`3oX_oo_`02oomi0009ogT0ool0ogOoobP0oolX0?oob@3o0?nnoolX0?mJ
o`3o000000;oogT000?oolT0of`0oom/0?l01OooN@05ooo900Go0?o`00?oogT0oooX0?ooj0001ooo
j0000ooonf[o0?o`o`3ol002o`3ol003oookJ_lY0?oo:@3o00Cooo]Z4?ooN@0<oookJPOoo`0000?o
00?ooookJ_oonfX01?oonfX01?l0ogOooo]ZogT0oonGo`05oookJPKoobP000?ooo]Zo`3o8OoonfX0
0ooonfX00ooo0?;ooo]ZoookJP03oookJP03ool0X?oonf[oE03o00Cooo]Z00?oobP0oookJ_oonfX0
0_oonfX01?mko`3ooo]ZoookJ_oonfX7oolX00gooo]Z00?oo`2eoookJ_oonfX0aOoonfX00ol0o`Wo
oo]ZoookJP05oookJP03o`0;oooonf[ooo]Z00;ooo]Z00?o/?l0o`3koooonfX00ooonfX01Om>0?oo
oo]ZoookJ_oonf[oo`0D00Wooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo8@3ooo]ZoookJP0;oook
JP03o`3o`?oonf[oo`0701Oooo]Z00Go^?l0oookJ_oonf[ooo]Zof`0o`08oookJP0=oigo0?oonf[o
oo]Zoong0?oonf[oT`3ooookJ_o/o`3oo`00oookJ_l[0?oooo]Zom;o0003oookJP05okSo0?oo703o
oo]Zo`3oU_oo04l01OoonfX00ol0oh_o0?neoookJP03oookJP03ool0]Ooonf[ooo]Z00;ooo]Z01Ko
0?lhoom10?oonf[oNol0obX0ool09OooE03oool0X?oo0?;o0?lQoookJ_l0oj;o0:;ooookJ_mi0?oo
Uol0o`3oMooonf[o00?ooookJ_l0okkoF_l01?l000001?mRo`3oK03oof`0ooooh`03oookJP;oo`2Z
00CoF@3oobT0oolY0?oo:@3o1Ol0oo0:oooX0005oookJ_l0oo3o0?o`o`3ol?oonfX00_lY0?l4oook
JP;oF@3o0ooo0:X5oookJP;oo`d000Goon<0of`0oooonf[ooo]Zof;o000;oookJP03on;o0?oonf[o
F_l000Cooo]Z00?oo`3fo`03oooonfX01OoonfX00ol0ogOooo]ZogT0o`07oookJP04oono0?oonf[o
oo]Zo`3oXP;ooo]Z00Go0?lQoookJ_oonf[ooo]Zool0lP05oookJP03ool0X?oonf[oE03o00Cooo]Z
00?o:P3ooookJ_oonfX00ooonfX01Omko`3ooo]ZoookJ_oonf[ood4000;ooo]Z00?o0?lhoookJ_oo
nfX03OoonfX00ooo0;Gooo]ZoookJP1ToookJP00I?oonfX00ooo:03ooo]ZoookJP06oookJP03o`0;
oooonf[ooo]Z00;ooo]Z00?oobP0ool00?oo00000ooonfX01?m>0?oooo]ZoookJ_oo:008oookJP?o
obP000?ooo]ZoolX0?oo:0000ooo:00:oookJPSoo`004_oonfX3ool000Cooo]Z00?oobP0oookJ_oo
nfX00ooonfX5oolX0008oong0?oonf[ooo]Zoi<0ooo/o`3oo`00oookJ_l[0?l4oolX00;oogT000Co
oa`0oomi0?ooN@3oo`1?0_oonfX8oomi0003ool00?oo0;Goo`0000;oo`000_ooN@003?l0ocSood40
og_o0?lZ0?ooogT0oe@0oooo0:3oogT0ool0l_l0ob7oogT0oono00;ooo]Z00?oN@3oo`3oMooo:000
0_oo:002o`3o_P03oe[o0?oRo`3oogT000?oogT00_m/0?l2oomi00OoolT00_ooN@02obT0o`_o0?o`
1OlY0?l4oookJP03oeT0ooooN@3oogT000GoogT00_oonfX9oomi00[ooo]Z1_oo00000ooo0?Kooo]Z
o`03o`05oookJP05o`3oMooonf[ooo]ZogT0oonGo`001OoonfX6oolX0003oookJ_l0ob7ooo]Z00;o
oo]Z00?oo`3boookJ_oonfX00ooonfX01?oo0:3ooo]ZoolX0?oo:003oookJP03oolX0?oonf[ooo]Z
00?ooo]Z00?oNol0oookJ_oonfX02Ooo:00<oookJP03ool0]Ooonf[ooo]Z0<Gooo]Z00?o0?l9oook
J_oonfX01OoonfX00ol02ooooo]ZoookJP02oookJP03ok3o0?l0nooooo]Z00?ooo]Z00GoCP3ooook
J_oonf[ooo]Zool05009oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oob40oookJ_oonfX02ooonfX0
0ol0ol3ooo]Zool01`0GoookJP03okSo0?oonf[ooo]Z00;ooo]Z00?oK03ooookJ_oonfX01_oonfX0
0onMo`3ooo]Zoong0002oookJP07oi<0oooonf[ok?l0ool00?l[0?oooo]Zom;o0003oookJP05okSo
0?oo703ooo]Zo`3oU_oo04l01OoonfX00ol0oh_ooo]Zo`3o]@04oookJP03ool0]Ooonf[ooo]Z00;o
oo]Z01Oo0?lhoom10?mko`3o:P3oo`1<oomD0?ooo`2Po`3oE_oo0?;o0?lQo`3oX_oo_`3o0:;ooook
J_mi0?ooUol0o`3oMooonf[o00?ooookJ_l0okkoF_l0on;o0002o`0000;ooo]Z00GoH_l0of`0oom/
0?ooon<0ool=0002oookJP?oo`2Z00?oF@3ooookJ_oonfX00olY0?l;o`3ol0Co:@3o1?oonfX01?mI
0?ooo`2Zool0Z_oo0:X7oookJP05ool=0?ooh`3oon<0of`0oooonfX00_mRo`0;oookJP03on;o0?oo
nf[oF_l000Cooo]Z00?oo`3fo`03oooonfX01OoonfX01?l0ogOooo]ZoookJ_mi0?l7oookJP06oono
0?oonf[ooo]Zo`3oX_oonf[o0?lQ1?oonfX00ooo0?;ooo]ZoookJP02oookJP04ool0X?oonf[oE03o
o`0Uo`?ooo]Z00?o:P3ooookJ_oonfX00ooonfX01Omko`3ooo]ZoookJ_oonf[ood4000;ooo]Z00?o
0?lhoookJ_oonfX03_oonfX00ooo0;Gooo]ZoookJP1ToookJP00I?oonfX00ooo:03ooo]ZoookJP06
oookJP03o`0;oooonf[ooo]Z00;ooo]Z00CoobP0ool00?oo003oo`000_oonfX01?m>0?oooo]Zoook
J_oo:008oookJP[oobP02OoonfX9ool0017ooo]Z1?oo0003oookJP03oolX0?oonf[ooo]Z00?ooo]Z
1Ooo:0002?oo]`3ooo]ZoookJ_nC0?ook?l0ool00?ooV`3o:`3o1?oo:002oomi0004oolL0?oonf[o
0?nFool0C`;ooo]Z1_ooN@02oookJP;oo`0000?oo`2eoomi0?oonfX00_ooN@001ol0ocSood40oomi
0?mko`3o:P3ooomi0?oo0:000_ooN@001?oo0?;o0?lQo`2<oooo_`02oookJP;oN@3o1?oo:0000ol0
okkoF_l0oomi0005oomi0004of`0oooob@3oon<0oooS00CoolT000?oo`2Zoomi0?ooN@000_ooN@00
0omI0?oooo]ZoookJP02oookJPKo:@3o1?oonfX3oeT0o`;oo`2Z0oooN@05oookJP03ool=0?ooN@3o
ogT000SoogT02OoonfX00ooRo`3oo`00ool00002ool000;oo`3f00?ooo]Zo`03oooonfX01OoonfX0
1?l0ogOooo]ZogT0oonGo`05oookJPOoobP000Go0?lQoookJ_oonf[ooo]Zool0lP06oookJP03ool0
X?oonf[oobP000;oobP000?ooo]ZoolX0?oonfX01?oonfX00omko`3ooo]ZoookJP0:oolX00_ooo]Z
00?oo`2eoookJ_oonfX0a_oonfX00ol0o`Wooo]ZoookJP05oookJP03o`0;oooonf[ooo]Z00;ooo]Z
00?o/?l0oookJ_l0nol00ooonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Wooo]Z00?oojP0oookJ_oo
nfX00_oonfX00ooo8@3ooo]ZoookJP0<oookJP03o`3o`?oo00Oooo]Z01Kooo]Z00?o^?l0oookJ_oo
nfX00_oonfX00om/0?oooo]ZoookJP06oookJP0=oigo0?oonf[ooo]Zoong0?oonf[oT`3ooookJ_o/
o`3oo`00oookJ_l[0?oooo]Zom;o0002oookJP06okSo0?oo703ooo]ZoookJ_l0oiKoo`1?1OoonfX0
0ol0oh_o0?neoookJP04oookJP0Cool0]Ooonf[ooo]ZoookJ_l0ocSood40oonL0?mko`3o:P3oo`1<
oomD0?ooo`2Po`3oE_oo0?;o0?lQo`3oX_oo_`3o0:;ooookJP02ogT0o`05o`3oMooonf[o00?oo`03
ool000000_mJo`001?l0003ooo]ZoookJ_oonfX2of;o0004of`0ooooh`3oon<0ool=00?ooo]Z0_oo
0:X4oeT0o`Cooo]Z1olY0?l3oookJP?oF@3o0ooo0:X8oookJP03ool=0?ooh`3oon<000;oK03o00?o
oo]Zof;o0?oonfX02ooonfX00ooRo`3ooo]Zoe[o0003oookJP;oo`3f00?o00?ooookJ_oonfX01Ooo
nfX00ol0ogOooo]ZogT0o`07oookJP04oono0?oonf[ooo]Zo`3oXP;ooo]Z00Go0?lQoookJ_oonf[o
oo]Zool0lP05oookJP03ool0X?oonf[oE03o00?ooo]Z00?o:P3ooookJ_oonfX01?oonfX01?mko`3o
oo]ZoookJ_oo@@03oookJP03o`3o>?oonf[ooo]Z00gooo]Z00?oo`2eoookJ_oonfX0IOoonfX006Co
oo]Z00?oobP0oookJ_oonfX01ooonfX01Ol02ooooo]ZoookJ_oonf[oobP000?oo`000_oonfX01?m>
0?oooo]ZoookJ_oo:008oookJP[oobP02OoonfX5ool001Gooo]Z1?oo0003oookJP03oolX0?oonf[o
oo]Z00?ooo]Z1_oo:0002?oo]`3ooo]Zoi<0oooonf[oo`00oonK0?oo:03o:`3o0ooo:0002?ooN@3o
obP0oolL0?oonf[o0?nFoookJ_oo04oooo]Z0oooN@002?l0oh_ooo]ZoookJ_l0okGooo]Zool00?oo
nf[oo`2e0_oonfX3oomi000=o`3o>?oo@@3oNol0oookJ_lZ0?ooE03oool0X?ooN@3oo`3boomi0?l0
ob7o08cooono0002oookJP03oiOo0?mi0?ooobP000?oobP00_l0okh5oomi0005of;o0?m/0?ooK03o
ooo90?ooh`000_oob@03oookJP?oogT00_oo0:X6oeT0o`03ooo90?mI0?ooF@3o00?oF@3o1?oo0:X9
oookJPgoogT01ooonfX00ooRo`3oo`00ool00002ool00004ool0m_oonf[o00?oo`03o`Kooo]Z00Co
0?mgoookJ_mi0?ooUol01_oonfX7oolX0005o`3o8Ooo:03ooo]ZoookJ_oo0?801OoonfX00ooo0:3o
oo]ZoolX0005oolX00Cooo]Z00CoNol0oolX0?oonf[ooo]Z2Ooo:00<oookJP03ool0]Ooonf[ooo]Z
0<Kooo]Z00?o0?l9oookJ_oonfX01_oonfX01ol02ooooo]ZoookJ_oonf[o/?l0oookJ_l0nol00ooo
nfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Wooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo8@3ooo]Z
oookJP0<oookJP03o`3o`?oo00Oooo]Z01Oooo]Z00Go^?l0oookJ_oonf[ooo]Zof`0o`08oookJP0=
oigo0?oonf[ooo]Zoong0?oonf[oT`3ooookJ_o/o`3oo`00oookJ_l[0?oooo]Zom;o0003oookJP05
okSo0?oo703ooo]Zo`3oU_oo04l01OoonfX00ol0oh_ooo]Zo`3o]@04oookJP03ool0]Ooonf[ooo]Z
00;ooo]Z00co0?lhoom10?mko`3ooo]ZobX0ool0C?ooo`2PoookJ_oo0?;ooo]Zo`3o8Ol0oj82oono
00;ooo]Z00WoN@3oo`3oMol0odSooo]Zo`03ool0003o0?nnoe[o0?oRo`001?oonfX00omRo`3oK03o
of`0o`02oooS0004ool=0?oonf[ooo]ZoookJPGoo`2Z3?mI0?l4ool0ZPWooo]Z0_oo3@000oooh`3o
K03oof`0o`02oookJP03of;o0?oonf[ooo]Z00[ooo]Z00?oh_l0oookJ_mJo`000ooonfX00ooo0?Ko
00?oo`03o`07oookJP04o`3oMooonf[oN@3ooiOo00Oooo]Z00?ookl0oookJ_l0oj800_oonfX01Ol0
ob7ooo]ZoookJ_oonf[oo`3b00Gooo]Z00Coo`2PoookJ_mD0?oo02Go0ooonfX00olZ0?oooo]Zoook
JP03oookJP05og_o0?oonf[ooo]ZoookJ_oo@@000_oonfX00ol0ocSooo]ZoookJP0>oookJP03ool0
]Ooonf[ooo]Z06Gooo]Z001ToookJP03oolX0?oonf[ooo]Z00Oooo]Z00Go00_ooookJ_oonf[ooo]Z
oolX0003ool000;ooo]Z00CoCP3ooookJ_oonf[oobP01ooonfX<oolX00[ooo]Z00Co0?o0oookJ_oo
nf[oo`005?oonfX5ool000;ooo]Z00?oK03ooookJ_oonfX00ooonfX6oolX0008oong0?oonf[ooo]Z
oi<0ooo/o`3oo`00oolX0?l[0?l6oolX0006oolL0?oonf[o0?nFool0Cooonf[oogT00ooonfX00ol0
oh_ooo]Zo`3o]@04oookJP03ool0]Ooonf[ooo]Z00?oogT0017o0?lhoomi0?mko`3o04coobX0oomD
0?ooo`2Poomi0?oo0?;oogT0o`3o8Ol0S?oookl0oookJ_oo:03oUol0ogT0o`05oolX0004o`3o__oo
N@3oogT0oomi00;ooo]Z00?oolT0of;o0?m/0?l00_m/0?l01_ooh`3oo`d0ool=0?oo3@3ooo]Zoomi
00?ooo]Z3?oo0:X;oookJP03ool=0?ooN@3oogT000WoogT01ooonfX2ool00008on;o0?oonf[oo`00
ool00?oonf[oo`3foookJ_l00ol6oookJP;o0?mg00?ooo]ZogT0oonGo`001OoonfX2ool000KoobP0
00Go0?lQoookJ_oonf[ooo]Zool0lP06oookJP03ool0X?oonf[oobP000KoobP00ooonfX01Omko`3o
obP0oolX0?oo:03ooo]Z00OoobP03OoonfX00ooo0;Gooo]ZoookJP36oookJP03o`3o2Ooonf[ooo]Z
00Kooo]Z00Oo00_ooookJ_oonf[ooo]Zok3o0?oonf[o0?_o00?ooo]Z00GoCP3ooookJ_oonf[ooo]Z
ool05009oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oo`2doolQ0?oonfX03?oonfX00ol0ol3ooo]Z
ool01`0GoookJP05okSo0?oonf[ooo]ZoookJ_m/0?l02?oonfX01?nMo`3ooo]ZoookJ_oo]`02oook
JP07oi<0oooonf[ok?l0ool00?l[0?oooo]Zom;o0003oookJP06okSo0?oo703ooo]ZoookJ_l0oiKo
o`1?1OoonfX00ol0oh_o0?neoookJP04oookJP03ool0]Ooonf[ooo]Z00;ooo]Z00ko0?lhoonL0?mk
o`3ooo]ZobX0oomD0?ooo`2PoookJ_oo0?;ooo]Zo`3o8Ol0oj;o08cooono00;ooo]Z00CoN@3oo`3o
Mol0odSo00000_l00ol00ol0003oF_l0on;o0004oookJP;oH_l00om/0?l00oooh`3oo`d0ool=0005
oookJPcoo`2Z3?oonfX01?oo3@3oK03oof`0oom/0?l2oookJP;oH_l03?oonfX00ooRo`3ooo]Zoe[o
0003oookJP03ool0m_l00ooooo]Z00Kooo]Z0_l0ogL00ooonf[oN@3ooiOo0007oookJP03oono0?oo
nf[o0?nR00;ooo]Z00?o0?lQoookJ_oonfX00_oonfX00ooo0?;ooo]ZoookJP03oookJP03ool0X?oo
nf[oE03o00?ooo]Z00?o:P3ooookJ_oonfX01?oonfX01?mko`3ooo]ZoookJ_oo@@03oookJP03o`3o
>?oonf[ooo]Z00kooo]Z00?oo`2eoookJ_oonfX0IOoonfX006Cooo]Z00?oobP0oookJ_oonfX01ooo
nfX01Ol02ooooo]ZoookJ_oonf[oobP000Coo`0000Gooo]Zool00?oonf[ooo]Zool05007oookJPco
obP02_oonfX01?oo:03ooo]ZoookJ_oo000DoookJPKoo`000_oonfX00om/0?oooo]ZoookJP02oook
JPKoobP000SookL0oookJ_oonf[oT`3ooookJ_oo003oobP0ob/0o`CoobP000Kooo]ZokSo0?oo703o
oo]Zo`3oU_oo04l6oookJP03o`3oRooonf[o0?ne00?ooo]Z00?oo`2eoookJ_oonfX00oooN@004ol0
ocSood40oomi0?mko`3o:P3ooomi0?mD0?ooo`2Po`3oE_oo0?;ooo]Zo`3o8Ol0S?oookl0oookJ_oo
:03oUol0ogT0ool0ogL01?oo:0000ol0okkoogT0on;o0005oookJP03of;o0?oob@3oK03o00?oK03o
0_oo3@08oookJPWoogT01_oonfX2ool=0003oooS0?ooN@3oogT000GoogT02ooonfX3ool00007oook
J_oo003ooo]ZoookJ_oo0?Kooo]Zo`03o`06oookJP05o`3oMooonf[ooo]ZogT0oonGo`001_oonfX0
0ooo003oobP0oolX0005oolX0005o`3o8Ooonf[ooo]ZoookJ_oo0?801OoonfX00ooo0:3ooo]Zoe@0
o`08oolX0003oookJ_mko`3oobP000[oobP03OoonfX00ooo0;Gooo]ZoookJP37oookJP03o`3o2Ooo
nf[ooo]Z00Kooo]Z00Oo00_ooookJ_oonf[ooo]Zok3o0?oonf[o0?_o00?ooo]Z00GoCP3ooookJ_oo
nf[ooo]Zool05009oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oo`2doolQ0?oonfX03?oonfX00ol0
ol3ooo]Zool01`0GoookJP03okSo0?oonf[ooo]Z00;ooo]Z00?oK03ooookJ_oonfX01_oonfX03OnM
o`3ooo]ZoookJ_oo]`3ooo]Zoi<0oooonf[ok?l0ool00?oonf[o:`3ooookJ_oBo`000_oonfX01_nh
o`3ooa`0oookJ_oonf[o0?nFool0C`Gooo]Z00?o0?n;oookJ_l0okD01?oonfX00ooo0;Gooo]Zoook
JP02oookJP0;o`3o>?oo@@3ooi`0og_o0?oonf[o:P3ooe@0oooo0:3ooo]Zool0l_oonfX00_l0ob40
1?l0S?oookl0oookJ_oonfX2ogT0o`07o`3oMol0odSo0000o`03oooo0?KoF_l0on;o0005oookJP?o
H_l00om/0?l00oooh`3oo`d0ool=000GoookJP04ool=0?ooh`3oK03oof`0o`?ooo]Z0_mRo`0=oook
JP03on;o0?oonf[oF_l000?ooo]Z00?oo`3fo`03oooonfX01_oonfX01Ol0ogOooo]ZoookJ_mi0?oo
Uol000Sooo]Z00?ookl0o`3oX_oonfX00_oonfX01Ol0ob7ooo]ZoookJ_oonf[oo`3b00Gooo]Z00Co
o`2PoookJ_mD0?oo02Go0_oonfX00olZ0?oooo]ZoookJP04oookJP05og_o0?oonf[ooo]ZoookJ_oo
@@000_oonfX00ol0ocSooo]ZoookJP0>oookJP03ool0]Ooonf[ooo]Z06Kooo]Z001ToookJP03oolX
0?oonf[ooo]Z00Oooo]Z00Co00_ooookJ_oonf[ooo]Z1Ooo00001Ooonf[oo`00oookJ_oonf[oo`0D
00Oooo]Z3?oo:00:oookJP04oolX0?oonf[ooo]Zool001Gooo]Z1Ooo0002oookJP03of`0oooonf[o
oo]Z00;ooo]Z1ooo:0002Ooo]`3ooo]Zoi<0oooonf[ok?l0ool00?oo:03o:`3ooolX0004oookJP05
okSo0?oo703ooo]Zo`3oU_oo04l01OoonfX01?l0oh_ooo]ZoookJ_l0okD3oookJP03ool0]Ooonf[o
ogT000?oogT000ko0?lhoom10?mko`3oogT0obX0ooooN@3oE03oool0X?l0oeKoo`3boookJ_l0ob7o
08cooono00;oobP000?oUol0ogT0ool0ogL00ooo:0000ol00ooo0?nnoe[o0003oomi00Gooo]Z0omR
o`04of`0o`ooogT00_oonfX3ool=0003oooS0?m/0?ooK03o00?oogT00_mRo`0=oookJP?oo`0000Oo
F_l0ool00?oonf[ooo]Zool0m_oonf[o00?o00Kooo]Z00Go0?mgoookJ_oonf[oN@3ooiOo0006oook
JP;oo`001_oo:0001Ol0ob7oo`00ool00?oonf[oo`3b00Gooo]Z00?oo`2PoookJ_oonfX02?oo:002
oookJP03og_o0?oo:03oobP000SoobP03_oonfX00ooo0;Gooo]ZoookJP37oookJP03o`3o2Ooonf[o
oo]Z00Kooo]Z00?o00_ooookJ_oonfX00_oonfX00on`o`3o0?_ooookJP02oookJP05odh0oooonf[o
oo]ZoookJ_oo01@02_oonfX00oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00_ooo]Z00?o
0?o0oookJ_oo00L06?oonfX01Onho`3ooo]ZoookJ_oonf[oK03o00Sooo]Z00goWOl0oookJ_oonf[o
okL0oookJ_nC0?oooo]Zonco0?ooV`3oo`00ob/0oooonf[od_l000?ooo]Z00Ko^?l0oolL0?oonf[o
oo]Zo`3oU_oo04l5oookJP03o`3oRooonf[o0?ne00Cooo]Z00?oo`2eoookJ_oonfX00_oonfX00ol0
ocSood40og_o0002oookJP05obX0oomD0?ooo`2PoookJ_oo0?800_oonfX02?l0ob7o08cooono0?l0
X_oooo]ZoiOo0?mi0?oo0?mg0_l0odP01Ol00oooo`3foe[o0?l0okkoh_l000Kooo]Z0omRo`04of`0
o`04oooS0?oo3@3oo`d0ool=00gooo]Z0ooo3@001?ooh`3oK03oof`0oom/0?l2oookJP?oH_l03Ooo
nfX2on;o00;oF_l00_oonfX2ool0mP03o`03oooonf[ooo]Z00Gooo]Z00Go0?mgoookJ_oonf[oN@3o
oiOo0007oookJP;ookl000Go0?nRo`2<oooonf[ooo]Zo`3o8@03oookJP03ool0l_oonf[ooo]Z00?o
oo]Z00Coo`2PoookJ_oonf[oE03o0ooonfX00olZ0?oooo]ZoookJP03oookJP05og_o0?oonf[ooo]Z
oookJ_oo@@000ooonfX00ol0ocSooo]ZoookJP0>oookJP03ool0]Ooonf[ooo]Z06Kooo]Z001Uoook
JP03oolX0?oonf[ooo]Z00Kooo]Z00Co00_ooookJ_oonf[ooo]Z2?oo0002oookJP03ool05?oonf[o
oo]Z00Cooo]Z3Ooo:009oookJP;oobP000?ooo]Zool00?oonfX05?oonfX6ool00003oookJ_m/0?oo
oo]Z00?ooo]Z1Ooo:002oookJP09oong0?oonf[ooo]Zoi<0ooo/o`3oo`00oonK0?l[0?ood_l000Co
oo]Z00Go^?l0oolL0?oonf[ooo]Zool0C`06oookJP03o`3oRooonf[o0?ne00Cooo]Z00?oo`2eoook
J_ooN@000oooN@003_l0ocSood40og_o0?ooN@3o:P3ooookJ_mD0?ooo`2Po`3oE_oo0?;ooo]Zo`3o
8Ol0S?oookl00_oo:0001_nGo`3oN@3oo`3oMooo:03o0000o`3oB0;o00?o00?oF_l0o`3o__ooN@00
1?ooN@04oookJPCoogT01?m/0?l3oooS00OoogT00_ooh`05of`0o`;ooo]Z0_mRo`0<oookJP;oobP0
00?ooo]Zool00?oo00000_mJo`02ool00004oookJ_oo0?Ko00?oo`03o`Kooo]Z00Go0?mgoookJ_oo
nf[ooo]ZogT0o`06oookJP;oo`001Ooo:0000ooonf[o0?lQoookJP02ool00003ool0l_oonf[oo`00
00?ooo]Z00Coo`2PoookJ_oonf[oE03o1ooo:002oookJP03og_o0?oo:03oobP000SoobP03_oonfX0
0ooo0;Gooo]ZoookJP39oookJP03o`3o2Ooonf[ooo]Z00Gooo]Z00?o00_ooookJ_oonfX00_oonfX0
0on`o`3ooo]Zo`3ko`02oookJP03odh0oooonf[ooo]Z00;ooo]Z00?oo`0DoookJ_oonfX01ooonfX0
0oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00_ooo]Z00?o0?o0oookJ_oo00L06?oonfX0
1Onho`3ooo]ZoookJ_oonf[oK03o00Sooo]Z00goWOl0oookJ_oonf[ooo]Zoong0?oonf[oT`3ooook
J_o/o`3oo`00oookJ_l[0?ood_l000?ooo]Z00Ko^?l0oolL0?oonf[ooo]Zo`3oU_oo04l5oookJP03
o`3oRooonf[o0?ne00Gooo]Z00Soo`2eoookJ_oonf[ooo]Zo`P0ool0ocSood40og_o00;ooo]Z00Go
:P3ooe@0oooo0:3ooo]Zool0lP02oookJP0:o`3o8Ol0S?oookl0o`2Roooonf[oUol0ogT0ool0ogOo
0000o`3oB0;o00?o00CoF_l0o`3o__oRo`3oh_l01ooonfX3of;o0003oookJ_m/0?ooK03o00?oK03o
0_ooh`08ool=0003oooS0?m/0?ooK03o00?oK03o0ooonfX2of;o00kooo]Z0_oRo`000ooonf[oF_l0
oookJP02oookJP03ool0m_l00ooo00?o00Oooo]Z00Go0?mgoookJ_oonf[oN@3ooiOo0007oookJP04
oono0?oonf[ooo]Zo`3oXP?ooo]Z00Oo0?lQoookJ_oonf[ooo]Zool0l_oonf[o0?mF00;ooo]Z00Go
o`2PoookJ_oonf[oE03oo`0Uo`02oookJP03obX0oooonf[ooo]Z00Cooo]Z00CoNol0oookJ_oonf[o
od400ooonfX00ol0ocSooo]ZoookJP0>oookJP03ool0]Ooonf[ooo]Z06Oooo]Z001UoookJP03oolX
0?oonf[ooo]Z00Kooo]Z00Co00_ooookJ_oonf[ooo]Z2?oo0002oookJP03ool05?oonf[ooo]Z00Co
oo]Z2_oo:00<oookJP;oobP000?ooo]Zool00?oonfX05?oonfX6ool000;ooo]Z00CoK03ooookJ_oo
nf[ooo]Z0_oo:003oookJP0<oolX0?oonf[ooo]Zoong0?oonf[oT`3ooookJ_oo003ooi/0oookJ_l[
0?ood_l01?oonfX01Onho`3ooa`0oookJ_l0oiKoo`1?00Gooo]Z00Co0?n;oookJ_oonf[o0?ne1?oo
nfX00ooo0;GoogT0oomi0002oomi000?o`3o>?ooN@3ood40og_o0?oonf[o:P3oo`0UoomD0?ooo`2P
o`3oE_oo0?;ooo]Zo`3o8OooN@3ookl000;oobP000GoUol0ogT0oomi0?oo0?mgoookJP02ool00004
o`03oomJo`3oF_l0o`3o_PKoogT00ooonfX6oomi00coK03o1?oonfX3of;o00gooo]Z0ooo:002ool0
0003oe[o0?oo003oo`0000?oo`0000?o00?ooookJ_oonfX01OoonfX01Ol0ogOooo]ZoookJ_oonf[o
N@3o00?ooo]Z00Koo`00oookJ_oonf[ooo]Zool00?oo_`04oolX0003ool00?l0ob7ooo]Z00?oo`00
00?oo`3bool00?oo00000_oonfX01Ooo0:3ooo]ZoookJ_oonf[oE03o00KoobP00ooonfX00omko`3o
obP0oolX0008oolX00kooo]Z00?oo`2eoookJ_oonfX0bOoonfX00ol0o`Wooo]ZoookJP05oookJP03
o`0;oooonf[ooo]Z00;ooo]Z00?o/?l0oookJ_l0nol00ooonfX01Om>0?oooo]ZoookJ_oonf[oo`0D
00Wooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo8@3ooo]ZoookJP0<oookJP03o`3o`?oo00Oooo]Z
01Oooo]Z00?o^?l0oookJ_oonfX00_oonfX00om/0?oooo]ZoookJP06oookJP0=oigo0?oonf[ooo]Z
oong0?oonf[oT`3ooookJ_o/o`3oo`00oookJ_l[0?oooo]Zom;o0003oookJP06okSo0?oo703ooo]Z
o`3oU_oonf[oo`1?1OoonfX00ol0oh_ooo]Zo`3o]@04oookJP03ool0]Ooonf[ooo]Z00;ooo]Z00Co
0?lhoookJ_oo@@3oNol00_oonfX01OlZ0?ooE03oool0X?oonf[oo`3b00;ooo]Z00Ko0?lQo`3oX_oo
_`3o0:;oo`000?nGo`02ogT0o`04o`3oMol0odSo0?m8o`03o`;oF_l000Co0?nnon;o0?oRo`3oh_l0
1ooonfX5of;o0003oookJ_m/0?ooK03o00WoK03o1OoonfX3of;o00oooo]Z00Coh_l0oookJ_mJo`3o
F_l00ooonfX00ooo0?Ko00?ooookJP07oookJP05o`3oMooonf[ooo]ZogT0oonGo`001ooonfX01?oo
_`3ooo]ZoookJ_l0oj83oookJP07o`3o8Ooonf[ooo]ZoookJ_oo0?;ooo]Zo`3oEP02oookJP05ool0
X?oonf[ooo]ZoookJ_mD0?l00_oonfX00olZ0?oooo]ZoookJP04oookJP05og_o0?oonf[ooo]Zoook
J_oo@@000ooonfX00ol0ocSooo]ZoookJP0>oookJP03ool0]Ooonf[ooo]Z06Oooo]Z001UoookJP03
oolX0?oonf[ooo]Z00Kooo]Z00Co00_ooookJ_oonf[ooo]Z2Ooo00000ooonf[oo`0DoookJP05oook
JPSoobP000?oo`2doolX0?oonfX02ooonfX3oolX0003ool00?oonf[ooo]Z01?ooo]Z1ooo00000ooo
nf[oK03ooookJP07oookJP04oolX0?oonf[ooo]Zoong00;ooo]Z00KoT`3oonco0?oo003ooi/0ob/0
oooBo`04oookJP05okSo0?oonf[ooa`0oookJ_oo04l01_oonfX00ol0oh_ooo]Zo`3o]@04oookJP03
ool0]OooN@3oogT000?oogT000go0?lhoom10?oonf[oNol0oookJ_lZ0?oo02Gooe@0oooo0:3ooo]Z
ool0l_ooN@3o0?lQ00?oogT000KoobP0o`000?nGo`3oN@3oo`3oMooonfX4ool000;oF_l02OooN@00
0ooonf[oogT0oomi000<oomi0003oookJ_mRo`3oH_l000?oH_l03_oonfX5oolX00;oF_l01_oo0007
oookJP05o`3oMooonf[ooo]ZoookJ_mi0?l01?oonfX01Ooo003ooo]ZoookJ_oo003ookl000CoobP0
00?oo`00o`3o8Ooo00000ooo00001?oo0?;oo`00ool00?oo0002oookJP04ool0X?oonf[ooo]Zoe@0
o`KoobP00ooonfX00omko`3oobP0oolX0008oolX00kooo]Z00?oo`2eoookJ_oonfX0b_oonfX00ol0
o`Wooo]ZoookJP05oookJP03o`0;oooonf[ooo]Z00;ooo]Z00?o/?l0oookJ_l0nol00ooonfX01Om>
0?oooo]ZoookJ_oonf[oo`0D00Wooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo8@3ooo]ZoookJP0<
oookJP03o`3o`?oo00Oooo]Z01Oooo]Z00?o^?l0oookJ_oonfX00_oonfX00om/0?oooo]ZoookJP06
oookJP0=oigo0?oonf[ooo]ZoookJ_oo]`3ooo]Zoi<0ooo/o`3oo`2Yool00?oonf[o:`3oom;o0003
oookJP06okSo0?oonf[ooa`0oookJ_l0oiKoo`1?1OoonfX00ol0oh_ooo]Zo`3o]@05oookJP03ool0
]Ooonf[ooo]Z00;ooo]Z00_o0?lhoom10?ooW03oNol0oookJ_l0C?oo:P3ooe@0oooo0:3ooo]Zool0
lP02oookJP04o`3o8Ol0oj;ookl0o`2Ro`;o000000OoUol0ogT0ool0ogOooo]Zo`3oB?oonf[o00?o
00;oF_l000Co0?nnoookJ_oRo`3oh_l02_oonfX7of;o00Gooo]Z1OmRo`0@oookJP;oh_l000Cooo]Z
oe[o0?l0okko0?nn0_oonfX00ooo0?Ko00?ooookJP07oookJP05o`3oMooonf[ooo]ZogT0oonGo`00
1ooonfX01?oo_`3ooo]ZoookJ_l0oj83oookJP07o`3o8Ooonf[ooo]ZoookJ_oo0?;ooo]Zo`3oEP03
oookJP05ool0X?oonf[ooo]Zoe@0ool09Ol00_oonfX00olZ0?oooo]ZoookJP04oookJP04og_o0?oo
nf[ooo]Zoom100?ooo]Z00?o0?lhoookJ_oonfX03_oonfX00ooo0;Gooo]ZoookJP1XoookJP00IOoo
nfX00ooo:03ooo]ZoookJP06oookJP04o`0;oooonf[ooo]ZoookJPWoo`0000?ooo]Zool05?oonfX0
1OoonfX:oolX00cooo]Z1?oo:0000ooo003ooo]ZoookJP0BoookJPSoo`0000?oK03ooookJ_oonfX0
1_oonfX01?nMo`3ooo]ZoookJ_oo]`02oookJP07oi<0ooo/o`3oo`00oonK0?l[0?oooo]Zom;o0004
oookJP05okSo0?oo703ooo]Zo`3oU_oo04l01_oonfX00ol0oh_ooo]Zo`3o]@04oookJP03ool0]Ooo
N@3oogT000;ooo]Z00Co203oo`3o>?oo@@3oNol00_oonfX02?lZ0?oo02Gooe@0oooo0:3ooo]Zool0
l_ooN@3o0?lQ1?ooN@001Ol0003oUol0ogT0oomi0?oooo]Z00Goo`000omJo`08oomi0003oookJ_oo
N@3oogT000SoogT00omRo`0AoookJPSoobP01ooo0006oookJP05o`3oMooonf[ooo]ZoookJ_mi0?l0
1?oonfX3ool00003oookJ_oo_`3oo`0000;oobP00_oo00000ol0ob7oo`00oookJP02ool00003ool0
l_oo003oo`0000?oo`0000Goo`2PoookJ_oonf[oE03oo`0Uo`05oolX00Cooo]Z00?oNol0oolX0?oo
:0000ooo:0001?oonf[oobP0oolX0?oo:00?oookJP03ool0]Ooonf[ooo]Z0<[ooo]Z00?o0?l9oook
J_oonfX01OoonfX00ol02ooooo]ZoookJP02oookJP03ok3o0?oonf[o0?_o00?ooo]Z00GoCP3ooook
J_oonf[ooo]Zool05009oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oob40oookJ_oonfX03?oonfX0
0ol0ol3ooo]Zool01`0HoookJP03okSo0?oonf[ooo]Z00;ooo]Z00?oK03ooookJ_oonfX01OoonfX0
3_nMo`3ooo]ZoookJ_oonf[ookL0oookJ_nC0?oooo]Zonco0?oo003ooo]Zob/0oooonf[od_l00ooo
nfX01_nho`3ooa`0oookJ_l0oiKooo]Zool0C`Gooo]Z00?o0?n;oookJ_l0okD01OoonfX00ooo0;Go
oo]ZoookJP02oookJP03o`3o>?oo@@3oNol000;ooo]Z00Ko04coobX0oomD0?ooo`2PoookJ_oo0?82
oookJP04o`3o8Ol0oj;ookl0oono00;o000000CoUol0ogT0ool0ogOooo]Z0_l0odP00ooonf[o00?o
oe[o0002oe[o0004oookJ_oRo`3oh_l0on;o00kooo]Z1OmRo`0CoookJP;oh_l000Cooo]Zoe[o0?mJ
o`3o0?nn0_oonfX2ool0mP03o`03oooonf[ooo]Z00Kooo]Z00Go0?mgoookJ_oonf[oN@3ooiOo0007
oookJP04oono0?oonf[ooo]Zo`3oXP?ooo]Z00?o0?lQoookJ_oonfX00_oonfX00ooo0?;o0?mFoook
JP02oookJP05ool0X?oonf[ooo]ZoookJ_mD0?l00_oonfX00olZ0?oooo]ZoookJP04oookJP05og_o
0?oonf[ooo]ZoookJ_oo@@000ooonfX00ol0ocSooo]ZoookJP0>oookJP03ool0]Ooonf[ooo]Z06So
oo]Z001UoookJP03oolX0?oonf[ooo]Z00Kooo]Z00Co00_ooookJ_oonf[ooo]Z2_oo00000ooonf[o
o`0DoookJP04oookJPGoobP00ooonfX2oolX00cooo]Z1?oo:0000ooo003ooo]ZoookJP0BoookJPKo
o`000ooonfX00om/0?oooo]ZoookJP06oookJP04oigo0?oonf[ooo]Zoong00;ooo]Z00KoT`3oool0
0?ooV`3ooo]Zob/0oooBo`04oookJP06okSo0?oonf[ooa`0oookJ_l0oiKoo`1?1OoonfX01?l0oh_o
oo]ZoookJ_l0okD4oookJP03ool0]Ooonf[ooo]Z00;ooo]Z00Co203oo`3o>?oo@@3oNol00_oonfX0
2?lZ0?oo02Goo`0Uoooo0:3ooo]Zool0l_ooN@3o0?lQ1OooN@001?oonf[oUol0ogT0ool0ogL6ool0
0003o`3o__mJo`3oF_l000KoogT00ooonfX9oomi01;ooo]Z2Ooo:008ool000Cooo]Z00?o0?mgoook
J_oonfX00_mi0?l4oookJPCoo`0000Cookl0ool00?oo003oobP00_oo00001_l0ob7ooo]ZoookJ_oo
nf[oo`00ool0lPGoo`0000Koo`2Pool00?oonf[oE03oo`0UoooonfX4oolX00Cooo]Z00?oNol0oolX
0?oo:0000ooo:0001?oonf[oobP0oolX0?oo:00@oookJP03ool0]Ooonf[ooo]Z0<[ooo]Z00?o0?l9
oookJ_oonfX01OoonfX00ol02ooooo]ZoookJP02oookJP03ok3o0?oonf[o0?_o00?ooo]Z00GoCP3o
oookJ_oonf[ooo]Zool05009oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oo`2doolQ0?oonfX03?oo
nfX00ol0ol3ooo]Zool01`0HoookJP03okSo0?oonf[ooo]Z00;ooo]Z00?oK03ooookJ_oonfX01_oo
nfX01?nMo`3ooo]ZoookJ_oo]`02oookJP07oi<0ooo/o`3oo`00oookJ_l[0?oooo]Zom;o0003oook
JP07okSo0?oonf[ooa`0oookJ_l0oiKooo]Zool0C`04oookJP04o`3oRooonf[ooo]Zo`3o]@Cooo]Z
00?oo`2eoookJ_oonfX00ooonfX00ol0ocSood40og_o0002oookJP06o`1<oolZ0?oo02Goool0X?oo
nf[oo`3b0_oonfX01ol0ob7o0?nRo`2<oooo_`3o0000oookJ_nGo`000_mi0?l01?l0ogOooo]Zo`3o
B?oonfX2o`03o`03o`3o__mJo`3oF_l000;ooo]Z0ooRo`0RoookJP05on;o0?oonf[ooo]Zoe[o0?l0
okh00_oonfX2ool0mP;o00?o2?oonfX01Ol0ogOooo]ZogT0oomi0?ooUol000Oooo]Z00Cookl0oook
J_oonf[o0?nR0ooonfX00ol0ob7ooo]ZoookJP02oookJP03ool0l_l0oeKooo]Z00;ooo]Z00Goo`2P
oookJ_oonf[ooo]Zoe@0o`03oookJP03obX0oooonf[ooo]Z00?ooo]Z00GoNol0oookJ_oonf[ooo]Z
oom10003oookJP03o`3o>?oonf[ooo]Z00oooo]Z00?oo`2eoookJ_oonfX0J?oonfX006Gooo]Z00?o
obP0oookJ_oonfX01_oonfX01?l02ooooo]ZoookJ_oonfX;ool00003ool05?oonf[ooo]Z00Oooo]Z
00CoobP0oookJ_oonf[ooo]Z0_oo:00<oookJPCoobP000?oo`00oookJ_oonfX04_oonfX4ool000Go
oo]Z00?oK03ooookJ_oonfX01_oonfX01?nMo`3ooo]ZoookJ_oo]`02oookJP07oi<0ooo/o`3oo`00
oonK0?l[0?oooo]Zom;o0004oookJP05okSo0?oo703ooo]Zo`3oU_oo04l01_oonfX00ol0oh_ooo]Z
o`3o]@04oookJP03ool0]Ooonf[ooo]Z00?ooo]Z00Co203oo`3o>?oo@@3oNol00_oonfX00olZ0?oo
obP0o`0Uo`02ool0X003ool0l_ooN@3o0?lQ00OoogT00_mi0?l00ol0ogOoo`00ool00005ool000?o
F_l00_ooN@02on;o00Cooo]Z1OooN@000ooonf[oogT0oookJP0:oookJP?oobP00_oonfX;oolX00Go
o`001_oonfX01Ol0ogOooo]ZoookJ_mi0?ooUol000Cooo]Z1?oo00001?oo_`3oo`00o`3oX_oo:002
ool00006o`3o8Ooonf[ooo]ZoookJ_oo003oo`3b1Ooo00001_oo0:3ooo]ZoookJ_mD0?oo02Gooook
JPCoobP01?oonfX00omko`3ooo]ZoolX0003oolX00;ooo]Z0_oo:00@oookJP03ool0]Ooonf[ooo]Z
0<_ooo]Z00?o0?l9oookJ_oonfX01OoonfX00ol02ooooo]ZoookJP02oookJP03ok3o0?oonf[o0?_o
00?ooo]Z00?oCP3ooookJ_oonfX00_oonfX00ooo01Cooo]ZoookJP07oookJP06oonX0?oonf[ooo]Z
oookJ_oo0;Coob403_oonfX00ol0ol3oo`07oookJP0GoookJP03okSo0?oonf[ooo]Z00;ooo]Z00?o
K03ooookJ_oonfX01_oonfX03_nMo`3ooo]ZoookJ_oonf[ookL0oookJ_nC0?ook?l0oookJ_oo003o
oo]Zob/0oooonf[od_l00ooonfX01_nho`3ooa`0oookJ_l0oiKooo]Zool0C`Gooo]Z00?o0?n;oook
J_l0okD01OoonfX00ooo0;Gooo]ZoookJP03oookJP08o`3o>?oo@@3oNol0og_o0?oonf[o04coobX0
oooonfX2ool0X007ool0l_oonf[ooo]Zo`3o8Ol0oj;o08cooono0003oookJP04oiOo0?mi0?oo0?mg
o`3oM`;o0?m800Cooo]Zo`03ool00ooooo]Z0omJo`02oookJP?oh_l07?oonfX3on;o00?oF_l00_oo
nfX2ool0mP;o00?o2OoonfX00ol0ogOooo]ZogT0o`02oiOo00Oooo]Z00Cookl0o`2Rool0oj;o0?nR
0ooonfX00ol0ob7ooo]ZoookJP02oookJP03ool0l_l0oeKooo]Z00;ooo]Z00Goo`2PoookJ_oonf[o
oo]Zoe@0o`03oookJP03obX0oooonf[ooo]Z00Cooo]Z00CoNol0oookJ_oonf[ood401?oonfX00ol0
ocSooo]ZoookJP0>oookJP03ool0]Ooonf[ooo]Z06Wooo]Z001UoookJP03oolX0?oonf[ooo]Z00Ko
oo]Z00Co00_ooookJ_oonf[ooo]Z2ooo00000ooo01Cooo]ZoookJP07oookJP04oolX0?oonf[ooo]Z
oookJP?oobP02ooonfX5oolX01Cooo]Z00Goo`00oookJ_oonf[ooo]Zool00004oookJP03of`0oooo
nf[ooo]Z00Kooo]Z00CoWOl0oookJ_oonf[ookL00_oonfX01onC0?oooo]Zool00?ooV`3o:`3ooook
J_oBo`001?oonfX01_nho`3ooo]ZoolL0?oonf[o0?nFool0C`Gooo]Z00?o0?n;oookJ_oonfX00_oo
:003oookJP03ool0]Ooonf[ooo]Z00?ooo]Z00Oo0?lhoookJ_oo@@3oNol0oookJ_oo:03o:P3o00;o
obP000CoE03oool0X?oo0?;oogT00_l0ob47oomi0003ogT0ool0ogOo0?mg00Soo`000omJo`000ooo
nf[oh_l0on;o0003on;o0004oookJ_ooN@3oogT0oomi00Wooo]Z5Ooo:008oookJP;o0?mg00Cooo]Z
ogT0oomi0?ooobL01?oonfX4ool00003oono0?oo003o0?nR00?oo`0000Ko0?lQoookJ_oonf[ooo]Z
ool00?oo0?86ool00004ool0X?oonf[oE03oo`0Uo`;ooo]Z0ooo:005oookJP03og_o0?oonf[oobP0
00;oobP00ooonfX00ooo:03ooo]ZoookJP0?oookJP03ool0]Ooonf[ooo]Z0<_ooo]Z00?o0?l9oook
J_oonfX01OoonfX00ol02ooooo]ZoookJP02oookJP04ok3o0?oonf[ooo]Zo`3ko`?ooo]Z00GoCP3o
oookJ_oonf[ooo]Zool05009oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oob40oookJ_oonfX03?oo
nfX00ol0ol3ooo]ZoookJP0HoookJP03okSo0?oonf[ooo]Z00;ooo]Z00?oK03ooookJ_oonfX01_oo
nfX03OnMo`3ooo]ZoookJ_oo]`3ooo]Zoi<0oooonf[ok?l0ool00?oonf[o:`3ooookJ_oBo`000ooo
nfX01onho`3ooo]ZoolL0?oonf[o0?nFoookJ_oo04l01?oonfX01?l0oh_ooo]ZoookJ_l0okD4oook
JP03ool0]Ooonf[ooo]Z00Cooo]Z00Co0?lhoom10?ooW03oNol00_oonfX01olZ0?oooo]Zoe@0oooo
0:3oo`3boookJ_l000000_l0ob400ol0S?oookl0oono0002oookJP03oiOo0?mi0?oooo]Z00;o0?mg
00?o0?m8oookJ_oonfX00_l00ol00ooo0?Kooo]Zoe[o0002oe[o00;ooo]Z1?oRo`0CoookJPCoh_l0
1?mJo`000ol0okkooo]ZoookJP02ool0mP;o00?o2OoonfX2o`3oM`;oN@3o00?oUol0oookJ_oonfX0
1_oonfX01?oo_`3ooo]Zo`3oX_l0S?l3oookJP03o`3o8Ooonf[ooo]Z00;ooo]Z00?oo`3bo`3oE_oo
nfX00ooonfX01?oo0:3ooo]ZoookJ_mD0?l3oookJP03obX0oooonf[ooo]Z00Cooo]Z00GoNol0oook
J_oonf[ooo]Zoom10003oookJP03o`3o>?oonf[ooo]Z00oooo]Z00?oo`2eoookJ_oonfX0JOoonfX0
06Gooo]Z00?oobP0oookJ_oonfX01ooonfX01Ol02ooooo]ZoookJ_oonf[o/?l000;ooo]Z1ooo0000
0ooo01Cooo]ZoookJP08oookJP03oolX0?oonf[ooo]Z00?oobP03?oonfX5oolX01Oooo]Z00?oo`00
oookJ_oonfX00ooonfX00om/0?oooo]ZoookJP06oookJP04oigo0?oonf[ooo]ZoolX00;ooo]Z00Oo
T`3oonco0?oo003ooi/0ob/0oooonf[od_l000Cooo]Z00Go^?l0oolL0?oonf[o0?nFool0C`06oook
JP03o`3oRooonf[oobP000;oobP00ooonfX00ooo0;Gooo]ZoookJP03oookJP07o`3o>?oonf[ood40
og_o0?oonf[oobP0obX0o`03oolX0004ool0X?oo0?;oogT0oomi00;o0?lQ1_ooN@02ogT0o`;o0?mg
1_oo00000oooN@3ooo]ZoookJP03oe[o0003o`3o__oonf[ooo]Z00?oh_l000?oogT0on;o0?oonfX0
1?oonfXHoolX00Kooo]Z0_l0ogL01?oonf[oN@3oogT0oonGo`05oookJPCoo`0000?ookl0ool00?l0
oj800ooo00000ol0ob7ooo]ZoookJP02oookJP03ool0l_oo003oo`0000?oo`0000Gooo]Zool0X?oo
nf[oE03oo`0Uo`03oookJP;oobP01OoonfX00omko`3ooo]ZoolX0002oolX00Cooo]Z00?o0?lhoook
J_oonfX03_oonfX00ooo0;Gooo]ZoookJP3<oookJP03o`3o2Ooonf[ooo]Z00Kooo]Z00Go00_ooook
J_oonf[ooo]Zok3o0002oookJP05o`3koooonf[ooo]ZoookJ_m>0?l00ooonfX00ooo01Cooo]Zoook
JP07oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oob40oookJ_oonfX03?oonfX00ol0ol3ooo]Zoook
JP0HoookJP03okSo0?oonf[ooo]Z00;ooo]Z00?oK03ooookJ_oonfX01_oonfX03_nMo`3ooo]Zoook
J_oonf[ookL0oookJ_nC0?ook?l0oookJ_oo003ooo]Zob/0oooonf[od_l00ooonfX01_nho`3ooa`0
oookJ_l0oiKooo]Zool0C`Gooo]Z00?o0?n;oookJ_l0okD01OoonfX00ooo0;Gooo]ZoookJP04oook
JP04o`3o>?oo@@3ooi`0og_o00;ooo]Z00Co:P3ooookJ_mD0?ooo`2P0_oo0?82o`000007o`3o8Ol0
S?oo08cooono0?l0X_oooo]ZoiOo0002ogT0o`03oookJ_l0ogOo0?m800?ooo]Z0ol00ol2oookJP?o
F_l000?o0?nnoookJ_oonfX01OoRo`06oookJPSoh_l000Cooo]Zoe[o0?mJo`3oF_l00ol0okh2oook
JP;oo`3f0_l00ol9oookJP;o0?mg0_mi0?l00onGo`3ooo]ZoookJP06oookJP05o`2Roooo_`3ooo]Z
o`3oX_l0S?l00ooonfX00ol0ob7ooo]ZoookJP02oookJP03ool0l_l0oeKooo]Z00?ooo]Z00Coo`2P
oookJ_oonf[oE03o1?oonfX00olZ0?oooo]ZoookJP04oookJP04og_o0?oonf[ooo]Zoom100Cooo]Z
00?o0?lhoookJ_oonfX03_oonfX00ooo0;Gooo]ZoookJP1ZoookJP00IOoonfX00ooo:03ooo]Zoook
JP07oookJP05o`0;oooonf[ooo]ZoookJ_n`o`000_oonfX8ool00003ool05?oonf[ooo]Z00Oooo]Z
00?oobP0oookJ_oonfX01?oo:00;oookJPGoobP05ooonfX00ooo003ooo]ZoookJP03oookJP03of`0
oooonf[ooo]Z00Kooo]Z00CoWOl0oookJ_oonf[oobP00_oonfX01onC0?oooo]Zool00?ooV`3o:`3o
oookJ_oBo`001OoonfX01Onho`3ooa`0oookJ_l0oiKoo`1?00Kooo]Z00?o0?n;oookJ_oo:0000_oo
:003oookJP03ool0]Ooonf[ooo]Z00?ooo]Z00Oo0?lhoookJ_oo@@3oNol0oookJ_oo:03o:P3o00?o
obP000?oo`2Poomi0?ooN@000_ooN@000ol0ob7oogT0oomi0003oomi0004oookJ_nGo`3oN@3oogT0
o`;o0?mg0ooo0002oomi00;o00?o0ooonfX6oe[o00;ooo]Z00?oh_l0oolX0?oo:0001Ooo:005oe[o
00SoobP01OooN@07oookJP;o0?mg0_oonfX00omi0?ooUol0oookJP06oookJP?oo`0000?ookl0o`3o
X_l0oj800_oo00000ooonf[o0?lQoookJP03oookJP03ool0l_oo003oo`0000;oo`000_oonfX01?oo
0:3ooo]Zoe@0ool09Ol3oookJP;oobP01_oonfX01?mko`3ooo]ZoolX0?oo:004oookJP03o`3o>?oo
nf[ooo]Z00kooo]Z00?oo`2eoookJ_oonfX0cOoonfX00ol0o`Wooo]ZoookJP06oookJP05o`0;oooo
nf[ooo]ZoookJ_n`o`000_oonfX01Ol0nooooo]ZoookJ_oonf[oCP3o00?ooo]Z00?oo`0DoookJ_oo
nfX01ooonfX00oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00cooo]Z00?o0?o0oookJ_oo
nfX06?oonfX00onho`3ooo]ZoookJP03oookJP03of`0oooonf[ooo]Z00Kooo]Z00goWOl0oookJ_oo
nf[ookL0oookJ_nC0?oooo]Zonco0?oo003ooo]Zob/0oooonf[od_l000Cooo]Z00Ko^?l0oolL0?oo
nf[o0?nFoookJ_oo04l5oookJP03o`3oRooonf[o0?ne00Gooo]Z00?oo`2eoookJ_oonfX01?oonfX0
1?l0ocSood40oookJ_mko`02oookJP06obX0oooonf[oE03oool0X?l0oeKoo`3b0_l00002o`3o8@03
o`2<oooo_`3o0:;o00;ooo]Z00?oUol0ogT0oomi0?l00_l0ogL5oookJP;o00?o00?oo`3foookJ_oo
nfX01omJo`000ooonf[oh_l0on;o0004on;o00;ooo]Z1omJo`03o`3o_P;ooo]Z0ooo0?H2o`03o`Wo
oo]Z0_l0ogL01?oonf[oN@3ooiOo0?nGo`08oookJP05o`2Roooo_`3ooo]Zo`3oX_l0S?l00ooonfX0
0ol0ob7ooo]ZoookJP02oookJP03ool0l_l0oeKooo]Z00?ooo]Z00Coo`2PoookJ_oonf[oE03o1?oo
nfX00olZ0?oooo]ZoookJP04oookJP05og_o0?oonf[ooo]ZoookJ_oo@@000ooonfX00ol0ocSooo]Z
oookJP0>oookJP03ool0]Ooonf[ooo]Z06_ooo]Z001UoookJP03o`3o2Ooonf[ooo]Z00Oooo]Z00?o
00_ooookJ_oonfX00_oonfX00on`o`3ooo]Zool00007ool00003ool05?oonf[ooo]Z00Oooo]Z00?o
obP0oookJ_oonfX01?oo:00;oookJPKoobP05ooonfX00ooo003ooo]ZoookJP02oookJP03of`0oooo
nf[ooo]Z00Oooo]Z00CoWOl0oookJ_oo:03oobP00_oonfX01onC0?ook?l0ool00?ooV`3o:`3ooook
J_oBo`001?oonfX01Onho`3ooo]ZoolL0?oonf[oo`1?00Oooo]Z00?o0?n;oolX0?oo:0000ooo:000
0ooonf[oo`2eoookJP05oookJP04o`3o>?oonf[ood40og_o00;oobP000Go:P3ooolX0?oo:03oobP0
ool0X004oomi00;o0?lQ0_ooN@001Ol0X_oooo]ZoookJ_ooN@3oUol000;oN@3o0_l0ogL01Ooo003o
ogT0oomi0?ooN@3ooo]Z00Co00?o1OoonfX:oe[o00OoobP02oooN@06oookJP03o`3oMooonf[ooo]Z
00;oN@3o2?oonfX2ool000;ookl000?o0?nRool00?oo00000_oonfX00ol0ob7ooo]ZoookJP02oook
JP03ool0l_oo003oo`0000;oo`000_oonfX01Ooo0:3ooo]Zoe@0oooonf[o02Go00;ooo]Z00?o:P3o
oolX0?oonfX01?oonfX2og_o00;ooo]Z00?oobP0oookJ_oonfX00_oonfX00ol0ocSooo]ZoookJP0>
oookJP03ool0]Ooonf[ooo]Z0<kooo]Z00?o0?l9oookJ_oonfX01_oonfX00ol02ooooo]ZoookJP02
oookJP03ok3o0?oonf[o0?_o00?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05009oookJP03oonX0?oo
nf[ooo]Z00;ooo]Z00?oob40oookJ_oonfX03OoonfX00ol0ol3ooo]ZoookJP0HoookJP03okSo0?oo
nf[ooo]Z00;ooo]Z00?oK03ooookJ_oonfX01_oonfX03_nMo`3ooo]ZoookJ_oonf[ookL0oookJ_nC
0?ook?l0oookJ_oo003ooo]Zob/0oooonf[od_l00ooonfX01_nho`3ooo]ZoolL0?oonf[o0?nFool0
C`Kooo]Z00?o0?n;oookJ_l0okD01?oonfX00ooo0;Gooo]ZoookJP05oookJP04o`3o>?oo@@3ooo]Z
og_o00;ooo]Z00Go:P3ooookJ_mD0?ooo`2Po`3oEP02ool0lP;ooo]Z00?o0?lQo`3oX_oo_`000_l0
X_l2oookJP03oiOo0?mi0?ooN@3o00;o0?mg1OoonfX4o`03o`03ool0m_oonf[ooo]Z00;ooo]Z00?o
0?nnoe[o0?mJo`001omJo`05o`3o_P?ooo]Z0ooo0?H4o`03o`Wooo]Z0_l0ogL01?oonf[oN@3oogT0
oonGo`08oookJP03o`2Roooo_`3ookl000;o0?nR00Go08cooookJ_oonf[ooo]Zo`3o8@04oookJP03
ool0l_l0oeKooo]Z00?ooo]Z00Goo`2PoookJ_oonf[oE03oo`0Uo`02oookJP;o:P3o1_oonfX01Omk
o`3ooo]ZoookJ_oonf[ood4000?ooo]Z00?o0?lhoookJ_oonfX03_oonfX00ooo0;Gooo]ZoookJP1/
oookJP00IOoonfX00ol0o`Wooo]ZoookJP07oookJP03o`0;oooonf[ooo]Z00;ooo]Z00?o/?l0oook
J_oo00001ooo00000ooo01Cooo]ZoookJP07oookJP03oolX0?oonf[ooo]Z00GoobP02_oonfX7oolX
01Kooo]Z00?oo`00oookJ_oonfX00ooonfX00om/0?oooo]ZoookJP06oookJP03oigo0?oonf[ooo]Z
00;oobP000Sooo]Zoi<0oooonf[ok?l0ool00?oonf[o:`3oom;o00Gooo]Z00Go^?l0oolL0?oonf[o
0?nFool0C`06oookJP03o`3oRooonf[oobP000CoobP000?ooo]Zool0]OoonfX01OoonfX2o`3o>004
oom10?mko`3oobP0oolX00;oogT00_oo:0000ooo0:3oogT0oomi0003oomi00;o0?lQ0_oo_`001Ol0
X_oooo]Zoomi0?oo003oUol000;oN@3o0ol0ogL3oomi00?ooo]Z1Ol00ol4oookJPgoobP03?ooN@03
oookJP;o0?mg0_oonfX00omi0?ooUol0oookJP07oookJP06ool00?oo_`3ookl0ool00?l0oj;oo`00
0ooonfX00ol0ob7ooo]ZoookJP02oookJP04ool0l_oo003oo`00ool000;ooo]Z0_oo0:001?oonf[o
E03ooookJ_l09Ol2oookJP03obX0oooonf[ooo]Z00Cooo]Z00GoNol0oookJ_oonf[ooo]ZoolX0004
oookJP03o`3o>?oo003ooo]Z00oooo]Z00?oo`2eoookJ_oonfX0c_oonfX00ol0o`Wooo]ZoookJP06
oookJP03o`0;oooonf[ooo]Z00;ooo]Z00?o/?l0oookJ_l0nol00ooonfX00om>0?oooo]ZoookJP02
oookJP03ool05?oonf[ooo]Z00Kooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo8@3oo`2doookJP0=
oookJP03o`3o`?oonf[ooo]Z01Sooo]Z00?o^?l0oookJ_oonfX00_oonfX00om/0?oooo]ZoookJP07
oookJP0=oigo0?oonf[ooo]Zoong0?oonf[oT`3ooookJ_o/o`3oo`00oookJ_l[0?oooo]Zom;o0004
oookJP06okSo0?oo703ooo]Zo`3oU_oonf[oo`1?1_oonfX00ol0oh_ooo]Zo`3o]@04oookJP03ool0
]Ooonf[ooo]Z00Gooo]Z0_l0ocP01?oonf[oNol0oookJ_oonfX2obX0o`05oe@0oooo0:3o0000o`3o
E_oo0?800_oonfX2o`3o8@;ookl00_l0X_l2oookJP03oiOo0?mi0?ooN@3o00?o0?mg1_oonfX5o`03
o`03ool0m_oonf[ooo]Z00cooo]Z00?oo`3fo`03ool00ol00ol00ol;oookJP;o0?mg0_oonfX00omi
0?ooUol0oookJP08oookJP;ookl000Cooo]Zo`3oX_l0S?oo08co0ooonfX00ol0ob7ooo]ZoookJP02
oookJP03ool0l_l0oeKooo]Z00;ooo]Z0_oo0:02oookJP05oe@0ool09Ooooo]ZoookJ_lZ0?l01ooo
nfX01Omko`3ooo]ZoookJ_oonf[ood4000?ooo]Z00?o0?lhoookJ_l80?l03ooonfX00ooo0;Gooo]Z
oookJP1/oookJP00I_oonfX00ol0o`Wooo]ZoookJP06oookJP03o`0;oooonf[ooo]Z00;ooo]Z00?o
/?l0oookJ_oo00001ooo00000ooo01Coo`00oookJP07oookJP04oolX0?oonf[ooo]ZoookJPGoobP0
2OoonfX7oolX01cooo]Z00?oK03ooookJ_oonfX01ooonfX00onMo`3ooo]ZoolX0002oolX0008oi<0
oooonf[ok?l0ool00?ooV`3o:`3ooookJ_oBo`04oookJP06okSo0?oonf[ooa`0oookJ_l0oiKoo`1?
1_oonfX00ol0oh_oobP0oolX0004oolX0003oookJ_oo0;Gooo]Z00Gooo]Z00Go203oo`3o>?oo@@3o
Nol0oolX0005oomi0003ool0X?ooN@3oogT000?oogT000?ooo]Zo`3o8Ol0oj800_oo_`001Ooonf[o
ogT0ool00?oo003oUol000;oN@3o00CoogT0o`3oMol0ogOoogT02?oonfX8o`03o`WoobP03?ooN@00
0ooonf[o0?mgo`3oM`02oookJP;oN@3o2OoonfX00ooo003ookl0ool00002o`3oXP?ooo]Z0_l0ob44
oookJP03ool0l_oonf[oo`0000?ooo]Z00Koo`2PoookJ_oonf[oE03ooookJ_l09Ol2oookJP03obX0
oooonf[ooo]Z00Cooo]Z00KoNol0oookJ_oonf[ooo]Zoom10?oo0003oookJP03o`3o>?oo003ooo]Z
00oooo]Z00?oo`2eoookJ_oonfX0d?oonfX00ol0o`Wooo]ZoookJP05oookJP03o`0;oooonf[ooo]Z
00;ooo]Z00?o/?l0oookJ_l0nol01?oonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Wooo]Z00?oojP0
oookJ_oonfX00_oonfX00ooo8@3ooo]ZoookJP0<oookJP03o`3o`?oonf[ooo]Z01kooo]Z00?oK03o
oookJ_oonfX01_oonfX03_nMo`3ooo]ZoookJ_oonf[ookL0oi<0oooonf[ok?l0oookJ_oo003ooo]Z
ob/0oooonf[od_l00ooonfX01onho`3ooo]ZoolL0?oonf[o0?nFoookJ_oo04l01_oonfX00ol0oh_o
oo]Zo`3o]@04oookJP03ool0]Ooonf[ooo]Z00Gooo]Z00Co203oo`3o>?oonf[oNol00_oonfX01ol0
C?oo:P3ooe@0oooo0:3o0000o`3oE_oo0?800ooonfX01Ol0ob7o0?nRoono0?oo_`3o0:;o00?ooo]Z
00CoUol0ogT0oomi0?oooo]Z0_l0ogL9oookJQ3o00?o3_oonfX2o`3oM`;ooo]Z0_mi0?l00onGo`3o
oo]ZoookJP06oookJP06o`2Roooo_`3ooo]ZoookJ_l0oj;o08co0ooonfX2o`3o8@Cooo]Z00?oo`3b
o`3oE_oonfX00_oonfX01_oo0:3ooo]ZoookJ_oonf[oE03oo`0Uo`;ooo]Z00?o:P3ooookJ_oonfX0
1OoonfX01Omko`3ooo]ZoookJ_oonf[ood4000?ooo]Z00?o0?lhoookJ_l80?l03ooonfX00ooo0;Go
oo]ZoookJP1]oookJP00I_oonfX00ol0o`Wooo]ZoookJP06oookJP03ool00?oonf[ooo]Z00;ooo]Z
00?o/?l0oookJ_oonfX01_oo0002oookJP03ool05?oonf[ooo]Z00Oooo]Z00?oobP0oookJ_oonfX0
1Ooo:009oookJPSoobP06ooonfX00om/0?oooo]ZoookJP07oookJP03oigo0?oonf[oobP000?oobP0
00OoT`3ooookJ_o/o`3oo`00oookJ_l[0?ood_l000Gooo]Z00Go^?l0oolL0?oonf[ooo]Zool0C`07
oookJP03o`3oRooo:03oobP000GoobP000?oo`2eoookJ_oonfX01?oonfX01Ol80?oo0?lhoom10?mk
o`3oobP000GoogT000Goo`2Poomi0?ooN@3oogT0ool0lP02oookJP?oogT00_oo_`001Ooonf[oo`00
oomi0?ooN@3oUol0013oogT01ooonfX3oolX00googT00ol0ogL01Ooonf[oN@3oogT0oomi0?ooUol0
00Wooo]Z0_oo_`000ooonf[o0?nRoookJP02oookJP;o0?lQ1OoonfX00ooo0?;o0?mFool00003oook
JP06ool0X?oonf[ooo]Zoe@0oooonf[o02Go0_oonfX00olZ0?oooo]ZoookJP04oookJP06og_o0?oo
nf[ooo]ZoookJ_oo@@3ooo]Z0_oo00000ooonf[o0?lhool0000@oookJP03ool0]Ooonf[ooo]Z0=7o
oo]Z00?o0?l9oookJ_oonfX01OoonfX00ol02ooooo]ZoookJP02oookJP04ok3o0?oonf[ooo]Zo`3k
o`?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05009oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oob40
oookJ_oonfX03OoonfX00ol0ol3ooo]ZoookJP0MoookJP03of`0oooonf[ooo]Z00Oooo]Z00WoWOl0
oookJ_oonf[ookL0oookJ_nC0?oooo]Zonco0?oo00000_oonfX00ol[0?ood_l0oookJP03oookJP06
okSo0?oo703ooo]ZoookJ_l0oiKoo`1?1_oonfX01?l0oh_ooo]ZoookJ_l0okD4oookJP03ool0]Ooo
nf[ooo]Z00Gooo]Z00Co203oo`3o>?oonf[oNol00_oonfX01?l0C?oo:P3oo`0Uoooo0:02oookJP;o
o`3b0_oonfX2o`3o8@04o`3oX_oo_`3ookl0oono00?ooo]Z00CoUol0ogT0oomi0?ooN@3o0ol0ogLQ
oookJP?o0?mg00Gooo]ZogT0oomi0?ooN@3ooiOo0009oookJP;ookl000?ooo]Zo`2<ool0oj800ooo
nfX2o`3o8@Gooo]Z00?oo`3bo`3oE_oonfX00_oonfX01_oo0:3ooo]ZoookJ_oonf[oE03oo`0Uo`;o
oo]Z00?o:P3ooookJ_oonfX01OoonfX01Omko`3ooo]ZoookJ_oonf[ood4000?ooo]Z00?o0?lhoook
J_l80?l03ooonfX00ooo0;Gooo]ZoookJP1^oookJP00I_oonfX00ol0o`Wooo]ZoookJP06oookJP03
ool00?oonf[ooo]Z00?ooo]Z00Co/?l0oookJ_oo003oo`000_oonfX01Ooo003ooo]ZoookJ_oonf[o
o`0D00Wooo]Z00?oobP0oookJ_oonfX01_oo:008oookJPGoobP07ooonfX00om/0?oooo]ZoookJP06
oookJP03oigo0?oonf[oobP000?oobP000SoT`3ooookJ_oonf[oo`00oonK0?l[0?oooo]Zom;o00Co
oo]Z00Ko^?l0oookJ_oo703ooo]Zo`3oU_oo04l7oookJP03o`3oRooo:03oobP000GoobP000?oo`2e
oookJ_oonfX01?oonfX01Ol80?oo0?lhoom10?mko`3oobP000GoogT000Goo`2Poomi0?oo:03o0?mF
ool0lP03oookJQSoogT01OoonfX<oomi00;ooo]Z1?l0ogL01?oonf[oN@3oogT0oomi0?l2oiOo00Go
oo]Z0_oo:002oookJP;ookl000?ooo]Zo`2<ool0oj800ooonfX00ol0ob7ooo]ZoookJP04oookJP03
ool0l_l0oeKooo]Z00;ooo]Z0_oo0:02oookJP03oe@0oooonf[o02Go00;ooo]Z00?o:P3ooookJ_oo
nfX01?oonfX01_mko`3ooo]ZoookJ_oonf[ood40oookJP?oo`0000?o0?lhool00?oonfX03ooonfX0
0ooo0;Gooo]ZoookJP3BoookJP03o`3o2Ooonf[ooo]Z00Gooo]Z00?o00_ooookJ_oonfX00ooonfX0
0on`o`3ooo]Zo`3ko`03oookJP05odh0oooonf[ooo]ZoookJ_oo01@02OoonfX00oooZ03ooo]Zoook
JP02oookJP03oolQ0?oo0;Cooo]Z00gooo]Z00?o0?o0oookJ_oonfX07_oonfX00om/0?oooo]Zoook
JP06oookJP06oigo0?oonf[ooo]ZoookJ_oo]`3oT`3o0_oonfX01_o/o`3oo`00oookJ_l[0?oooo]Z
om;o00?ooo]Z00Oo^?l0oookJ_oo703ooo]Zo`3oU_oonf[oo`1?00Kooo]Z00?o0?n;oookJ_l0okD0
1OoonfX00ooo0;Gooo]ZoookJP05oookJP09o`P0ool0ocSooo]Zog_o0?oonf[o0000o`1<oolZ0?oo
000000;oo`2P0_oonfX01?oo0?;ooo]ZoookJ_oonfX2o`3o8@;o08co0_oo_`04oookJP03oiOo0?mi
0?ooN@3o00;oN@3o0ol0ogLIoookJPCo0?mg00Cooo]ZogT0oomi0?ooN@3o0_nGo`09oookJP;ookl0
00Cooo]Zo`2<ool0S?oo0?nR0_oonfX2o`3o8@Kooo]Z00Coo`3boookJ_oonf[ooo]Z0_oo0:03oook
JP05oe@0ool09Ooooo]ZoookJ_lZ0?l01ooonfX01Omko`3ooo]ZoookJ_oonf[ood4000?ooo]Z00?o
0?lhoookJ_l80?l03ooonfX00ooo0;Gooo]ZoookJP1_oookJP00I_oonfX00ol0o`Wooo]ZoookJP06
oookJP;oo`001?oonfX00on`o`3ooo]Zool00003oookJP05ool00?oonf[ooo]ZoookJ_oo01@02Ooo
nfX00ooo:03ooo]ZoookJP06oolX00Sooo]Z0_oo:002oookJP03oolX0?oonf[ooo]Z01gooo]Z00?o
K03ooookJ_oonfX01ooonfX00onMo`3ooo]ZoolX0003oolX0007oi<0oooonf[ok?l0ool00?ooV`3o
:`3oom;o0005oookJP;oobP000?ooa`0oookJ_oo04l01ooonfX00ol0oh_oobP0oolX0006oolX0003
ool0]Ooonf[ooo]Z00Cooo]Z00?o203oo`3o>?l0ocP00_mko`06oomi00;oo`2P00?oogT0ool0l_oo
0?800_oonfX9oomi00;ooo]Z7OooN@02o`3oM`;ooo]Z0omi0?l2oiOo00;oobP01OoonfX2oolX00;o
0:;o00?ookl0oookJ_l0S?l00_l0oj82oookJP;o0?lQ1OoonfX2ool0lP05o`3oE_oonf[ooo]Zoook
J_oo0:000ooonfX00omD0?oooo]Zo`0Uo`02oookJP03obX0oooonf[ooo]Z00Cooo]Z00KoNol0oook
J_oonf[ooo]Zoom10?oonfX3ool00003o`3o>?oo003oo`00013ooo]Z00?oo`2eoookJ_oonfX0d_oo
nfX00ol0o`Wooo]ZoookJP05oookJP03o`0;oooonf[ooo]Z00?ooo]Z00?o/?l0oookJ_l0nol00ooo
nfX00om>0?oooo]ZoookJP02oookJP03ool05?oonf[ooo]Z00Kooo]Z00?oojP0oookJ_oonfX00_oo
nfX00ooo8@3oo`2doookJP0=oookJP03o`3o`?oonf[ooo]Z01kooo]Z00?oK03ooookJ_oonfX01_oo
nfX03_nMo`3ooo]ZoookJ_oonf[ookL0oookJ_nC0?oooo]Zonco0?oo0:Woo`00oookJ_l[0?ood_l0
1?oonfX01_nho`3ooo]ZoolL0?oonf[o0?nFool0C`Oooo]Z00?o0?n;oookJ_l0okD01OoonfX00ooo
0;Gooo]ZoookJP05oookJP03o`P0ool0ocSooo]Z00;oNol000Go0000o`1<oolZ0?oo:P3oo`0Uo`02
ool0X003oookJ_oo0?;oo`3b00?ooo]Z0_l0ob401Ol0oj;o08cooono0?oo_`3o0:;o00Gooo]Z00Co
Uol0ogT0oomi0?ooN@3o1_l0ogL@oookJP?o0?mg0_oonfX3ogT0o`;oUol02OoonfX2o`2Ro`04oono
0?oonf[ooo]Zo`2<o`;o0?nR00?ooo]Zo`3o8Ol0ob401_oonfX2ool0lP?ooo]Z00?oo`2PoookJ_oo
nfX00_oonfX01OmD0?oo02GooookJ_oonf[o:P3o00Oooo]Z00GoNol0oookJ_oonf[ooo]Zoom10003
oookJP03o`3o>?oonf[o203o013ooo]Z00?oo`2eoookJ_oonfX0KooonfX006Oooo]Z00?o0?l9oook
J_oonfX01OoonfX2ool000Cooo]Z00?o/?l0oookJ_oo00000ooonfX01Ooo003ooo]ZoookJ_oonf[o
o`0D00Wooo]Z00?oobP0oookJ_oonfX00_oo:0000ooo8@3oobP0oolX0002oolX00_ooo]Z00?oobP0
oookJ_oonfX07OoonfX00om/0?oooo]ZoookJP07oookJP03oigo0?oonf[oobP000CoobP000KoT`3o
oolX0?o/o`3oo`00oolX0?l[0?l2ool000?ooo]Z0_oo:0001?oo703ooo]ZoookJ_oo04l7oookJP03
o`3oRooo:03oobP000KoobP000?oo`2eoookJ_oonfX01?oonfX01Ol80?oooo]Zo`3o>?oo:03oNol0
00OoogT00_oo0:001?ooN@3oo`3bool0l_oonfXEoomi00?oN@3o2oooN@08ogT0o`;oUol01Ooo:003
oookJP04oolX0?l0X_oo0:;oo`2Ro`;ookl000?ooo]Zo`3oX_l0oj800_oonfX2o`3o8@Gooo]Z0_oo
0?800ol0oeKooo]ZoookJP02oookJP03ool0X?oonf[ooo]Z00;oE03o0_l09Ol2oookJP03obX0oooo
nf[ooo]Z00Cooo]Z00GoNol0oookJ_oonf[ooo]Zoom10002oookJP;oo`0000?o0?lhool00?oo0000
0_oo000>oookJP03ool0]Ooonf[ooo]Z0=?ooo]Z00?o0?l9oookJ_oonfX01_oonfX00ol02ooooo]Z
oookJP02oookJP03ok3o0?oonf[o0?_o00?ooo]Z00?oCP3ooookJ_oonfX00_oonfX00ooo01Cooo]Z
oookJP06oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oob40ool0]?oonfX03OoonfX00ol0ol3ooo]Z
oookJP0NoookJP03of`0oooonf[ooo]Z00Oooo]Z00koWOl0oookJ_oonf[ooo]Zoong0?oonf[oT`3o
oookJ_o/o`3oo`00oookJ_l[0?oooo]Zom;o00?ooo]Z00Oo^?l0oookJ_oonf[ooa`0oookJ_l0oiKo
o`1?00Oooo]Z00?o0?n;oookJ_l0okD01OoonfX00ooo0;Gooo]ZoookJP05oookJP05o`P0ool0ocSo
od40oonL0?mko`000_l000001?l0C?oo:P3ooookJ_l09Ol2ool0X003oookJ_oo0?;oo`3b00?ooo]Z
00Co0?lQo`3oX_l0oj;o0?nR0_oo_`000ol0X_oooo]ZoookJP04oookJP03oiOo0?mi0?ooN@3o00Ko
N@3o2ol0ogL8ogT0o`;oUol02_oonfX2o`2Ro`;ookl000Cooo]Zo`2<ool0oj;o0?nR0_oonfX00ol0
ob7ooo]ZoookJP04oookJP;oo`3b1?oonfX01?oo0:3ooo]ZoookJ_oonfX2oe@0o`04o`0Uoooonf[o
oo]ZobX0o`Oooo]Z00GoNol0oookJ_oonf[ooo]Zoom10004oookJP03o`3o>?l80?oooo]Z00oooo]Z
00?oo`2eoookJ_oonfX0L?oonfX006Oooo]Z00?o0?l9oookJ_oonfX01OoonfX3ool000?ooo]Z00?o
/?l0oookJ_oo00001?oonfX01?oo003ooo]ZoookJ_oo01@9oookJP03oolX0?oonf[ooo]Z00?oobP0
00?oob40oolX0?oo:0000_oo:00:oookJP03oolX0?oonf[ooo]Z01kooo]Z00?oo`00oookJ_oonfX0
1ooonfX00onMo`3oobP0oolX0003oolX0006oi<0oooo:03ok?l0ool00?ooV`3o:`3o0ooo0003oook
JP;oobP000Cooa`0oookJ_l0oiKoo`1?1_oonfX00ooo:03o0?n;oolX0004oolX00?ooo]Z00?oo`2e
oookJ_oonfX01?oonfX01?l80?ooogT0o`3o>?oo:002og_o00OoogT000?oo`2Poomi0?l0oeH00_oo
0?8Goomi00_oN@3o1?ooN@03oiOo0003oookJ_oo:03oobP000GoobP000Cooo]ZoolX0?l0X_oo0:;o
0ooo_`000ooo:03o0?nRo`3oXP03oookJP03o`3o8Ooonf[ooo]Z00?ooo]Z0_oo0?800ol0oeKooo]Z
oookJP03oookJP06ool0X?oonf[ooo]Zoe@0oooonf[o02Go0ooonfX00olZ0?oooo]ZoookJP04oook
JP05og_o0?oonf[ooo]ZoookJ_oo@@000_oonfX2ool00003o`3o>?oo003oo`0000Coo`003?oonfX0
0ooo0;Gooo]ZoookJP3EoookJP03o`3o2Ooonf[ooo]Z00Gooo]Z00?o00_ooookJ_oonfX00_oonfX0
0on`o`3ooo]Zo`3ko`04oookJP05odh0oooonf[ooo]ZoookJ_oo01@02?oonfX00oooZ03ooo]Zoook
JP03oookJP03oolQ0?oonf[ooo]Z00gooo]Z00?o0?o0oookJ_oonfX07_oonfX00om/0?oooo]Zoook
JP06oookJP0>oigo0?oonf[ooo]ZoookJ_oo]`3ooo]Zoi<0oooonf[ok?l0oookJ_oo003ooo]Zob/0
oooBo`04oookJP07okSo0?oonf[ooa`0oookJ_l0oiKooo]Zool0C`07oookJP03o`3oRooonf[o0?ne
00Gooo]Z00?oo`2eoookJ_oonfX01OoonfX02Ol80?oo0?lhoom10?ooW03oNol0o`000?oonf[o04co
obX0o`02oookJP04oe@0oooo0:3oo`2Po`3oEP;oo`3b0_oonfX2o`3o8@04oookJ_l0oj;o0?nRo`3o
XP;ookl02OoonfX4oiOo00_oN@3o1onGo`0;oookJP06o`2Roooo_`3ookl0oono0?oonf[o08co0_l0
oj82oookJP;o0?lQ1OoonfX2ool0lPGooo]Z00Koo`2PoookJ_oonf[ooo]Zoe@0ool09Ol3oookJP03
obX0oooonf[ooo]Z00Gooo]Z00GoNol0oookJ_oonf[ooo]Zoom10004oookJP03o`3o>?l80?oooo]Z
00oooo]Z00?oo`2eoookJ_oonfX0LOoonfX006Oooo]Z00?o0?l9oookJ_oonfX01OoonfX3ool000Co
oo]Z00?o/?l0oookJ_oo00000ooonfX01Ooo003ooo]ZoookJ_oonf[oo`0D00Wooo]Z00?oobP0oook
J_oo:0000_oo:0000ooo8@3oobP0oookJP0<oookJP03oolX0?oonf[ooo]Z01kooo]Z0_oo0008oook
JP03oigo0?oonf[oobP000CoobP000KoT`3ooolX0?o/o`3oo`00oolX0?l[0?l3ool000;ooo]Z0ooo
:0001?oo703ooo]Zo`3oU_oo04l6oookJP03oolX0?l0oh_oobP000;oobP01OoonfX00ooo0;Gooo]Z
oookJP04oookJP06o`P0ooooN@3o0?lhoolX0?ooN@3oNol01oooN@02ool0X0;o0?mF00?oo`3boomi
0?ooN@008oooN@02oookJP[oobP00ooo_`001Ooo:03o0?nRo`3oX_l0oj;oobP000;ooo]Z0_l0ob42
oolX00;ooo]Z0_oo0?82o`3oEPCooo]Z0_oo0:000ooonf[oE03ooe@0o`02o`0Uo`?ooo]Z00?o:P3o
oookJ_oonfX01?oonfX01Omko`3ooo]ZoookJ_oonf[ood4000?ooo]Z00?oo`00o`3o>?oo00001?oo
000>oookJP03ool0]Ooonf[ooo]Z0=Gooo]Z00?o0?l9oookJ_oonfX01OoonfX00ol02ooooo]Zoook
JP03oookJP03ok3o0?oonf[o0?_o00?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05009oookJP03oonX
0?oonf[ooo]Z00;ooo]Z00?oob40ool0]?oonfX03OoonfX00ol0ol3ooo]ZoookJP0NoookJP03of`0
oooonf[ooo]Z00Oooo]Z00koWOl0oookJ_oonf[ooo]Zoong0?oonf[oT`3ooookJ_o/o`3oo`00oook
J_l[0?oooo]Zom;o00Cooo]Z00Oo^?l0oookJ_oo703ooo]Zo`3oU_oonf[oo`1?00Oooo]Z00Co0?n;
oookJ_l0okGo0?ne1?oonfX00ooo0;Gooo]ZoookJP05oookJP04o`P0ool0ocSood40oom100;oNol0
0_oonfX01OlZ0?oo04cooookJ_l09OooE03o00;oo`2P00?o0?mFool0l_oo0?800_oonfX2o`3o8@;o
oo]Z0ol0oj82oono00cooo]Z2?nGo`0@oookJP06o`2Roooo_`3ookl0oono0?oonf[o08co0ol0oj82
oookJP;o0?lQ1OoonfX2ool0lP03o`3oE_oonf[ooo]Z00;ooo]Z0_oo0:02oookJP;oE03o00Go02Go
oookJ_oonf[ooo]ZobX0o`07oookJP05og_o0?oonf[ooo]ZoookJ_oo@@001?oonfX00ol0ocSo203o
oookJP0@oookJP03ool0]Ooonf[ooo]Z077ooo]Z001WoookJP03o`3o2Ooonf[ooo]Z00Gooo]Z1?oo
0003oookJP03ok3o0?oonf[oo`0000?ooo]Z00Goo`00oookJ_oonf[ooo]Zool05009oookJP06oolX
0?oonf[oobP0oolX0?oonf[oob403ooonfX00ooo:03ooo]ZoookJP0MoookJP?oo`002?oonfX00onM
o`3oobP0oolX0004oolX0006oi<0oooo:03oo`00oonK0?oo:03o:`3o0ooo0002oookJP;oobP000Go
oa`0oolX0?oonf[o0?nFool0C`05oookJP;oobP000Co0?n;oolX0?oonf[o0?ne1OoonfX00ooo0;Go
oo]ZoookJP04oookJP03o`P0ooooN@3o0?lh00;oogT00_mko`05oomi0005oookJ_mD0?ooo`2Pool0
X?oonfX00_oo0?87oomi00?o0?nR1oooN@02oookJPSoogT01_oonfX2oomi00WoobP00ooo_`02oolX
00;o0?nR0ooo:003o`3o8@06oookJ_oo:03oobP0oolX0?oonf[oo`3b0_l0oeH5oookJP06ool0X?oo
nf[ooo]Zoe@0oooonf[o02Go1?oonfX00olZ0?oooo]ZoookJP04oookJP05og_o0?oonf[ooo]Zoook
J_oo@@000ooonfX00ooo003o0?lhool00004ool000kooo]Z00?oo`2eoookJ_oonfX0e_oonfX00ol0
o`Wooo]ZoookJP06oookJP03o`0;oooonf[ooo]Z00;ooo]Z00?o/?l0oookJ_l0nol00ooonfX01Om>
0?oooo]ZoookJ_oonf[oo`0D00Wooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo8@3oo`2doookJP0=
oookJP03o`3o`?oonf[ooo]Z01oooo]Z00?oK03ooookJ_oonfX01_oonfX01OnMo`3ooo]ZoookJ_oo
nf[ookL000;ooo]Z00SoT`3oonco0?oonf[oo`00oookJ_l[0?oooo]Zom;o00Cooo]Z00Oo^?l0oook
J_oo703ooo]Zo`3oU_oonf[oo`1?00Oooo]Z00Co0?n;oookJ_oonf[o0?ne1?oonfX00ooo0;Gooo]Z
oookJP05oookJP06o`P0ool0ocSo0000oom10?ooW03oNol00_oonfX2obX0o`;ooo]Z0_mD0?l2ool0
X003oookJ_oo0?;oo`3b00;ooo]Z0ol0ob42oookJP?o0?nR0_oo_`000ol0X_oooo]ZoookJP0Joook
JP;o0:;o0ooo_`000ooonf[o08coo`2<o`02o`3oXP;ooo]Z0ol0ob45oookJP;oo`3b00?o0?mFoook
J_oonfX00ooonfX01_oo0:3ooo]ZoookJ_oonf[oE03oo`0Uo`Cooo]Z00?o:P3ooookJ_oonfX01Ooo
nfX01Omko`3ooo]ZoookJ_oonf[ood4000Cooo]Z00?o0?lho`P0oooonfX04?oonfX00ooo0;Gooo]Z
oookJP1boookJP00J?oonfX00ol0o`Wooo]ZoookJP04oookJPCoo`000ooonfX00on`o`3ooo]Zool0
0003oookJP05ool00?oonf[ooo]ZoookJ_oo01@02OoonfX00ooo:03ooo]ZoookJP03oookJP03oolQ
0?oonf[ooo]Z00cooo]Z00?oobP0oookJ_oonfX07_oonfX3ool000Oooo]Z00?oWOl0oolX0?oo:000
1?oo:0001_nC0?ooobP0oolX0?oo003oobP0ob/0o`Coo`0000Sooo]ZoolX0?oo:03oobP0oolL0?oo
:03o0?nFool0C`Gooo]Z0ooo:0001?l0oh_ooo]ZoookJ_l0okD5oookJP;oo`2e1OoonfX00ol0003o
ogT0oomi0003oomi0004og_o0?ooN@3oogT0oomi00;o:P3o00?ooo]Zo`0UoomD0?l00_oo0:000ooo
nf[oo`3boomi0005oomi00;o0?lQ00?oogT0o`3oX_l0oj800ol0oj82oomi00Cooo]Z1_ooN@05oook
JPWoobP00ooo_`03oolX00;o0?nR0_oo:003o`3o8@03oolX0?oonf[oobP000?oobP00_oo0?800ol0
oeKooo]ZoookJP04oookJP04ool0X?oonf[oE03ooe@0o`;o02Go1?oonfX00olZ0?oooo]ZoookJP04
oookJP05og_o0?oonf[ooo]ZoookJ_oo@@000ooonfX00ooo003o0?lhool00003ool000oooo]Z00?o
o`2eoookJ_oonfX0eooonfX00ol0o`Wooo]ZoookJP06oookJP03o`0;oooonf[ooo]Z00;ooo]Z00?o
/?l0oookJ_l0nol00ooonfX00om>0?oooo]ZoookJP02oookJP03ool05?oonf[ooo]Z00Kooo]Z00?o
ojP0oookJ_oonfX00ooonfX00ooo8@3ooo]ZoookJP0<oookJP03o`3o`?oonf[ooo]Z01oooo]Z00?o
K03ooookJ_oonfX01ooonfX03_nMo`3ooo]ZoookJ_oonf[ookL0oookJ_nC0?oooo]Zonco0?oo003o
oo]Zob/0oooonf[od_l01?oonfX01onho`3ooo]ZoookJ_oo703o0?nFoookJ_oo04l02?oonfX01?l0
oh_ooo]ZoookJ_l0okD4oookJP;oo`2e1OoonfX2o`0000;o0?lh0_oo@@02og_o00;ooo]Z0_lZ0?l0
1?oonf[o02Gooe@0oomD0?l2ool0X003oookJ_oo0?;oo`3b00?ooo]Z0ol0ob42oookJPCo0?nR0_oo
_`000ol0X_oooo]ZoookJP0?oookJPKo0:;o0ooo_`001?oonf[o08coo`2<ool0S?l2o`3oXP04oook
J_l0ob7o0?lQo`3o8@Kooo]Z0_oo0?800ol0oeKooo]ZoookJP04oookJP03ool0X?oonf[ooo]Z00;o
E03o00?o02GooookJ_oonfX00_oonfX00olZ0?oooo]ZoookJP05oookJP05og_o0?oonf[ooo]Zoook
J_oo@@001?oonfX00ol0ocSo203ooookJP0@oookJP03ool0]Ooonf[ooo]Z07?ooo]Z001XoookJP03
o`3o2Ooonf[ooo]Z00Cooo]Z1Ooo0002oookJP03ok3o0?oonf[oo`0000?ooo]Z00Goo`00oookJ_oo
nf[ooo]Zool05009oookJP03oonX0?oonf[ooo]Z00?ooo]Z00?oob40oookJ_oonfX03?oonfX00ooo
:03ooo]ZoookJP0NoookJPCoo`001_oonfX00onMo`3oobP0oolX0005oolX0006oi<0ooo/o`3oobP0
ool00?oo:03o:`3o1Ooo0003oolX0004oolL0?oo:03o0?nFool0C`Gooo]Z00CoobP0oookJ_oonf[o
0?n;0_oonfX00ol0okGooo]ZoookJP04oookJP03ool0]Ooonf[ooo]Z00;ooo]Z0_l00005oomi00;o
Nol00_ooN@001_l0C?oo:P3ooookJ_oonf[o02Gooe@0o`;oo`2P00?ooo]Zoomi0?ooN@000_ooN@03
oookJP?o0?lQ0oooN@04o`3oXPGookl00oooN@04o`2Ro`;oobP02?oo_`02oolX00Co0?nR1?l0ob47
oolX00;oo`3b0_oo:005oookJP;oo`2P00Cooo]Zoe@0ool09Ooo02Go1OoonfX00olZ0?oooo]Zoook
JP03oookJP03ool00?mko`3ooo]Z00;ooo]Z00?ood40oookJ_oonfX00_oonfX01?l0ocSoo`00ool0
0?oo000@oookJP03ool0]Ooonf[ooo]Z0=Wooo]Z00?o0?l9oookJ_oonfX01OoonfX00ol02ooooo]Z
oookJP02oookJP03ok3o0?oonf[o0?_o00?ooo]Z00?oCP3ooookJ_oonfX00_oonfX00ooo01Cooo]Z
oookJP06oookJP03oonX0?oonf[ooo]Z00?ooo]Z00?oob40oookJ_oonfX03OoonfX00ol0ol3ooo]Z
oookJP0OoookJP03of`0oooonf[ooo]Z00Kooo]Z00GoWOl0oookJ_oonf[ooo]Zoong0002oookJP08
oi<0ooo/o`3ooo]Zool00?oonf[o:`3ooookJ_oBo`04oookJP07okSo0?oonf[ooa`0oookJ_l0oiKo
oo]Zool0C`08oookJP04o`3oRooonf[ooo]Zo`3o]@Gooo]Z00?oo`2eoookJ_oonfX00_oonfX3o`00
0006o`P0ool0ocSooo]Zoom10?ooW03oNol00ooonfX01?lZ0?oooo]ZoookJ_l09Ol2oe@0o`;oo`2P
00Cooo]Zool0l_oo0?;oo`3b0ooonfX3o`3o8@;ooo]Z00?o08coo`3oX_l0oj800_l0oj85oono00Wo
0:;o2?oo_`000ooonf[o08coo`2<o`04o`3oXP?o0?lQ1ooonfX2ool0lP;o0?mF1OoonfX2ool0X004
oookJ_mD0?ooE03oo`0Uo`Gooo]Z00?o:P3ooookJ_oonfX01OoonfX01Omko`3ooo]ZoookJ_oonf[o
od4000Cooo]Z00?o0?lho`P0oooonfX04?oonfX00ooo0;Gooo]ZoookJP1doookJP00J?oonfX00ol0
o`Wooo]ZoookJP04oookJPGoo`000ooonfX00on`o`3oo`00oookJP03oookJP05ool00?oonf[ooo]Z
oookJ_oo01@02OoonfX00oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00gooo]Z00?oobP0
oookJ_oonfX07OoonfX5ool000Kooo]Z00goo`00oolX0?oo:03oobP0oookJ_oo:03ooo]ZoolX0?nC
0?ook?l0ool00?oo:03o:`3o00Koo`000_oo:0001Ooo703oobP0oolX0?l0oiKoo`1?00Sooo]Z00Co
0?n;oookJ_oonf[o0?ne1_oonfX01?oo0;Gooo]ZoookJ_oonfX3o`0000KoogT000CoNol0oomi0?oo
N@3oogT00_lZ0?l2ool00004o`0UoomD0?ooo`2Pool0X0?oogT00_oo0?83oookJP05oomi0?l0ob7o
0?lQo`3o8OooN@000_oonfX00ol0S?oo0?nRo`3oXP07o`3oXPGookl00ol0S?l7o`3oXP04oolX0?l0
ob7o0?lQo`3o8@SoobP00ooo0?84oolX00;ooo]Z0ooo0:02oookJP03oe@0ool09Ooooo]Z00Cooo]Z
0_lZ0?l5oookJP06ool00?mko`3ooo]ZoookJ_oo003ood400ooonfX2o`3o>0?oo`004OoonfX00ooo
0;Gooo]ZoookJP3IoookJP03o`3o2Ooonf[ooo]Z00Gooo]Z00?o00_ooookJ_oonfX00ooonfX00on`
o`3o0?_ooookJP03oookJP05odh0oooonf[ooo]ZoookJ_oo01@02OoonfX00oooZ03ooo]ZoookJP02
oookJP03oolQ0?oo0;Cooo]Z00gooo]Z00?o0?o0oookJ_oonfX07ooonfX00om/0?oooo]ZoookJP07
oookJP05oigo0?oonf[ooo]ZoookJ_oo]`000_oonfX02?nC0?ook?l0ool00?oo0:Wooo]Zob/0oooo
nf[od_l01?oonfX01onho`3ooo]ZoolL0?oonf[o0?nFoookJ_oo04l02?oonfX01?l0oh_ooo]Zoook
J_l0okD5oookJP04ool0]Ooonf[ooo]ZoookJPCo000000?ooo]Zo`3o>?l0ocP00_oo@@001?mko`3o
oo]ZoookJ_oonfX2obX0o`;ooo]Z00?o02Gooe@0oomD0?l00_oo0:02oookJP?oo`3b0ooonfX3o`3o
8@?ooo]Z00?o08coo`3oX_l0oj801ol0oj85oono0004oookJ_l0S?oo08coo`2<o`Oo0?nR00Cooo]Z
o`3o8Ol0ob7o0?lQ1ooonfX3ool0lP;o0?mF1?oonfX3ool0X0;ooo]Z00?oE03ooookJ_l09Ol01?oo
nfX2obX0o`Oooo]Z00GoNol0oookJ_oonf[ooi`0oom10003oookJP;o0?lh00?o203ooookJ_oonfX0
4?oonfX00ooo0;Gooo]ZoookJP1doookJP00J?oonfX00ol0o`Wooo]ZoookJP04oookJPKoo`000_oo
nfX00on`o`3oo`00oookJP03oookJP05ool00?oonf[ooo]ZoookJ_oo01@02OoonfX00oooZ03ooo]Z
oookJP03oookJP03oolQ0?oonf[ooo]Z00cooo]Z00?oobP0oookJ_oonfX07OoonfX6ool000Gooo]Z
00?oo`00oolX0?oo00000_oonfX02Ooo:03ooo]ZoookJ_nC0?ook?l0oolX0?oo003oobP0ob/0o`06
ool000;oobP000Gooa`0oolX0?l0oiKoobP0ool0C`08oookJP04o`3oRooonf[ooo]Zo`3o]@Kooo]Z
00?oo`2eoookJ_oonfX01?l00006oomi00;oNol000?oogT0oookJ_oonfX00_lZ0?l4ool00003ool0
X?ooN@3oo`2P00;ooo]Z0ooo0?82oookJP;oogT02?l0ob400ooonf[o08coo`2<o`02oomi00So0?nR
2?l0ob44oolX00?ooo]Z00CoobP0ool0l_oo0?;oo`3b1ooo:002ool0X0?ooo]Z0_mD0?l00ol09Ooo
oo]ZoookJP02oookJP;o:P3o1_oonfX2og_o00?oo`0000Kood40oookJ_oonf[ooo]Zo`3o>?oonfX2
ool001;ooo]Z00?oo`2eoookJ_oonfX0f_oonfX00ol0o`Wooo]ZoookJP06oookJP03o`0;oooonf[o
oo]Z00;ooo]Z00?o/?l0o`3koooonfX00ooonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Wooo]Z00?o
ojP0oookJ_oonfX00ooonfX00ooo8@3ooo]ZoookJP0<oookJP03o`3o`?oonf[ooo]Z023ooo]Z00?o
K03ooookJ_oonfX01_oonfX01OnMo`3ooo]ZoookJ_oonf[ookL000;ooo]Z00SoT`3oonco0?oonf[o
o`00oookJ_l[0?oooo]Zom;o00Gooo]Z00Co^?l0oookJ_oo703o0?nF0_oonfX00ooo04oooo]Zoook
JP06oookJP04o`3oRooonf[ooo]Zo`3o]@Gooo]Z0_oo0;D00ooonf[o0000o`000002o`0000;ooo]Z
00Co203oo`3o>?l0ocSood400_mko`03oookJP;o:P3o0_oonfX00ol09OooE03ooe@0o`02ool0X0?o
oo]Z0ooo0?83oookJPWo0?lQ00Cooo]Zo`2<ool0S?oo08co2?l0oj89o`3o8@Oooo]Z0ooo0?82o`3o
EPGooo]Z0_oo0:03oookJP;oE03o0_l09Ol3oookJP;o:P3o1ooonfX2og_o00;ooo]Z00?ooi`0oom1
0?oonfX00_oonfX00ol0ocSooo]Zo`P0o`0BoookJP03ool0]Ooonf[ooo]Z07Gooo]Z001YoookJP03
o`3o2Ooonf[ooo]Z00?ooo]Z1_oo0002oookJP03ok3o0?oonf[oo`0000?ooo]Z00Goo`00oookJ_oo
nf[ooo]Zool05009oookJP03oonX0?oonf[ooo]Z00?ooo]Z00?oob40oookJ_oonfX03?oonfX00ooo
:03ooo]ZoookJP0NoookJPKoo`001OoonfX3ool000;ooo]Z00WoobP0oookJ_oo:03oT`3oonco0?oo
003oobP0ool00?l[0?l01_oo0002oolX0004oolL0?oo:03o0?nFool0C`Wooo]Z00Co0?n;oookJ_oo
nf[o0?ne1_oonfX00ooo0;Gooo]Zo`000003o`000003oookJ_ooN@3oogT000GoogT00_mko`02oomi
0003ool00?lZ0?ooo`0000Goo`000_oo0:000ooo003ooo]ZoookJP03ool0lP03oomi0?oonf[ooo]Z
00;ooo]Z1?ooN@0=o`3o8@cooo]Z1?oo0?87oolX00?oo`2P00KoobP0oookJ_oonf[ooo]Zoe@0ool0
9Ol4oookJP;o:P3o1_oonfX2og_o00Coo`0000Oood40oookJ_oonf[ooo]Zo`3o>?oonf[oo`0001?o
oo]Z00?oo`2eoookJ_oonfX0fooonfX00ol0o`Wooo]ZoookJP06oookJP03o`0;oooonf[ooo]Z00;o
oo]Z00?o/?l0oookJ_l0nol00ooonfX01Om>0?oooo]ZoookJ_oonf[oo`0D00Wooo]Z00?oojP0oook
J_oonfX00ooonfX00ooo8@3ooo]ZoookJP0<oookJP03o`3o`?oonf[ooo]Z023ooo]Z00?oK03ooook
J_oonfX01ooonfX01OnMo`3ooo]ZoookJ_oonf[ookL000;ooo]Z00SoT`3oonco0?oo003oo`2Yoook
J_l[0?oooo]Zom;o00Cooo]Z00Oo^?l0oookJ_oo703ooo]Zo`3oU_oonf[oo`1?00Wooo]Z00Co0?n;
oookJ_oonf[o0?ne1_oonfX00ooo0;Go0000o`000002o`0000Cooo]Z00Co203oo`3o>?oo@@3ood40
0_mko`03oookJP03obX0ool0C?oooo]Z00;ooo]Z0_mD0?l2ool0X0Cooo]Z0ooo0?89oookJPco0?lQ
3?oonfX4ool0lP;o0?mF1_oonfX2ool0X0Cooo]Z00?oE03ooookJ_l09Ol00ooonfX2obX0o`Oooo]Z
0_mko`02oookJP;ooi`000?ood40oookJ_oonfX00_l0ocP00ooonf[o203ooookJP0AoookJP03ool0
]Ooonf[ooo]Z07Kooo]Z001YoookJP03o`3o2Ooonf[ooo]Z00?ooo]Z1ooo00001?oonf[o/?l0oook
J_oo0003oookJP05ool00?oonf[ooo]ZoookJ_oo01@02_oonfX00oooZ03ooo]ZoookJP02oookJP03
oolQ0?oonf[ooo]Z00gooo]Z00?oobP0oookJ_oonfX07OoonfX7ool000Cooo]Z1?oo00002_oonf[o
obP0oookJ_oo:03oT`3ooolX0?o/o`3oo`00oookJ_l[0?l7ool00006oolX0?oo703oobP0oolX0?l0
oiKoo`1?2OoonfX01?l0oh_ooo]ZoookJ_l0okD6oookJP;oo`2e0ol00002oookJPSoogT00_mko`00
1?ooN@3oo`00obX0oolZ0?l6ool000;oo`2P00Goo`00oookJ_oonf[ooo]Zool0lP0@oomi00kooo]Z
0ooo0?89oolX00;oo`2P1?oo:0001?oonf[oE03ooe@0ool09Ol2oookJP?o:P3o1_oonfX2og_o00Co
o`000_oo@@001_oo003ooo]Zo`3o>?l0ocSo203oool001;ooo]Z0_oo0;GNoookJP03o`3o2Ooonf[o
oo]Z00Kooo]Z00?o00_ooookJ_oonfX00_oonfX00on`o`3ooo]Zo`3ko`03oookJP03odh0oooonf[o
oo]Z00;ooo]Z00?oo`0DoookJ_oonfX01ooonfX00oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[o
oo]Z00gooo]Z00?o0?o0oookJ_oonfX08?oonfX00om/0?oooo]ZoookJP07oookJP04oigo0?oonf[o
oo]Zoong00;ooo]Z00KoT`3ooookJ_o/o`3oo`00oookJ_l[0?l2oookJP03om;o0?oonf[ooo]Z00;o
oo]Z00Oo^?l0oookJ_oo703ooo]Zo`3oU_oonf[oo`1?00Wooo]Z00Co0?n;oookJ_oonf[o0?ne1_oo
nfX01?oo0;Go0000o`000?l00005oookJP03o`P0ool0ocSo0?lh00;ood400_mko`02oookJP;o:P3o
0_l0C?l2oookJP;oE03o0_oo0:05oookJPGoo`3b6OoonfX3ool0lP?o0?mF1_oonfX3ool0X0Cooo]Z
0_mD0?l2o`0Uo`04oookJ_lZ0?oo:P3oobX0o`Oooo]Z0_mko`02oookJP;ooi`00_oo@@02oookJP04
o`3o>?oonf[o203oo`P0oa7ooo]Z0_oo0;EioookJP00JOoonfX00ol0o`Wooo]ZoookJP03oookJPOo
o`000_oonfX00on`o`3oo`00oookJP02oookJP03ool00?oonf[ooo]Z00;ooo]Z00?oo`0DoookJ_oo
nfX01ooonfX00oooZ03ooo]ZoookJP02oookJP03oolX0?oo8@3ooo]Z00gooo]Z00?oobP0oookJ_oo
nfX07OoonfX8ool000?ooo]Z1Ooo00001ooonf[oobP0oookJ_oo:03oT`3ooookJ_o/o`000_oo0000
0ol[0?ooo`00ool00005ool00006oolX0?oo703oobP0oookJ_l0oiKoo`1?2OoonfX01?l0oh_ooo]Z
oookJ_l0okD6oookJP04o`000?oo0;Go0000o`0000?ooo]Z2OooN@03og_o0004ool00?lZ0?oo:P3o
obX0o`Goo`005OooN@05oookJPWoo`3b0_l0oeH7oolX00?oo`2P1?oonfX3oe@0o`03o`0Uoooonf[o
oo]Z00;o:P3o1ooonfX2og_o0004oookJ_oo003oo`00ool000;ood400ooo00000ol0ocSooo]Zo`P0
o`0CoookJP03ool0]Ooonf[ooo]Z0=oooo]Z00?o0?l9oookJ_oonfX01_oonfX00ol02ooooo]Zoook
JP02oookJP03ok3o0?l0nooooo]Z00;ooo]Z00?oCP3ooookJ_oonfX00_oonfX00ooo01Cooo]Zoook
JP07oookJP03oonX0?oonf[ooo]Z00?ooo]Z00?oob40oookJ_oonfX03?oonfX00ol0ol3ooo]Zoook
JP0PoookJP03of`0oooonf[ooo]Z00Oooo]Z00GoWOl0oookJ_oonf[ooo]Zoong0002oookJP06oi<0
oooonf[ok?l0ool00?oonf[o:`3o0_oonfX00ooBo`3ooo]ZoookJP02oookJP07okSo0?oonf[ooa`0
oookJ_l0oiKooo]Zool0C`09oookJP04o`3oRooonf[ooo]Zo`3o]@Gooo]Z00Co0000ool0]Ol0003o
00001ooonfX00ol80?oo0?lho`3o>002oom100?oNol000Gooo]ZobX0oolZ0?oo:P3oo`1<o`02oook
JP03o`0UoomD0?ooo`2P00;oo`2P1OoonfX2o`3oEPOoo`3b2OoonfX9ool0lP?o0?mF1ooonfX2ool0
X0Cooo]Z0omD0?l2o`0Uo`03oookJ_lZ0?oo:P3o00Sooo]Z0_mko`03oookJP03oonL0?oo@@3ood40
00;ooo]Z0_l0ocP2o`P0oa;ooo]Z00?oo`2eoookJ_oonfX0NOoonfX006Wooo]Z00?o0?l9oookJ_oo
nfX00ooonfX8ool00003oookJ_n`o`3ooo]Z00Cooo]Z00Goo`00oookJ_oonf[ooo]Zool05009oook
JP03oonX0?oonf[ooo]Z00?ooo]Z00?oob40oookJ_oonfX03?oonfX00ol0ol3ooo]ZoookJP0Noook
JPSoo`000ooonfX5ool00007oong0?oonf[oobP0oookJ_nC0?ook?l0oolX0002ool00003ob/0oooo
003oo`0000;oo`001_oo:0000ooonf[o0?nFool0C`09oookJP04o`3oRooonf[ooo]Zo`3o]@Gooo]Z
0_l000000ooo0;Go0000oookJP03oookJPSoogT00_oo@@000ooonf[oNol0og_o0002ool000?o:P3o
0_oo0002o`0Uoa?oogT01Ooo0?87o`3oEPSooo]Z0ooo0:04oookJP?oE03o00Co02GooookJ_oonf[o
oo]Z0_lZ0?l8oookJP03og_o0?oonf[ooo]Z00;oo`000_oo@@03ool000;o0?lh0_l80?lCoookJP03
ool0]Ooonf[ooo]Z0>3ooo]Z00?o0?l9oookJ_oonfX01_oonfX00ol02ooooo]ZoookJP02oookJP03
ok3o0?oonf[ooo]Z00?ooo]Z00GoCP3ooookJ_oonf[ooo]Zool05009oookJP03oonX0?oonf[ooo]Z
00?ooo]Z00?oob40oookJ_oonfX03?oonfX00ol0ol3ooo]ZoookJP0QoookJP03of`0oooonf[ooo]Z
00Oooo]Z00CoWOl0oookJ_oonf[ookL00ooonfX02?nC0?ook?l0oookJ_oo003ooo]Zob/0oooonf[o
d_l01?oonfX02?nho`3ooo]ZoookJ_oo703ooo]Zo`3oU_oonf[oo`1?2OoonfX01?l0oh_ooo]Zoook
J_l0okD4oookJP;o00000_oo0;D8oookJP;o203o00Go0?lhoookJ_oo@@3ood40oonL0002og_o00;o
oo]Z0olZ0?l3oookJP03o`0UoomD0?ooo`2P00Coo`2P1_oonfX3o`3oEPWoo`3b00?ooo]Zo`3oE_l0
oeH01Ol0oeH8oookJP?oo`2P0ooonfX3oe@0o`;o02Go0_oonfX2obX0o`Sooo]Z0_mko`03oookJP03
oonL0?oo@@3ood4000?ooo]Z00?o0?lhoookJ_l80?l04ooonfX00ooo0;Gooo]ZoookJP1joookJP00
J_oonfX00ol0o`Wooo]ZoookJP02oookJPGoo`001?oonfX00on`o`3ooo]ZoookJP03oookJP05ool0
0?oonf[ooo]ZoookJ_oo01@02_oonfX00oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00go
oo]Z00?o0?o0oookJ_oonfX07OoonfX9ool000;ooo]Z1_oo00001_oo]`3ooo]ZoookJ_nC0?oooo]Z
onco00?oo`0000?o:`3oool00?oo00000ooo:0000ooonf[oobP0oolX0002oolX0004oookJ_l0oiKo
o`1?ool0C`Sooo]Z00Co0?n;oookJ_oonf[o0?ne1?oonfX3o`000003ool0]Ooonf[ooo]Z00?ooo]Z
1_ooN@001_l0ocSooo]ZoookJ_oo@@3ooi`0oookJP;oNol00ooo0004obX0o`03oookJ_l09OooogT0
01KoogT02OoonfX5ool0X0Cooo]Z0omD0?l00ol09Ooooo]ZoookJP02oookJP;o:P3o2?oonfX2og_o
00;ooo]Z00?oo`00oom10?oo@@001?oo00000ol0ocSo203oo`P0o`0CoookJP;oo`2ehooonfX00ol0
o`Wooo]ZoookJP06oookJP03o`0;oooonf[ooo]Z00;ooo]Z00?o/?l0oookJ_oonfX00ooonfX01Om>
0?oooo]ZoookJ_oonf[oo`0D00[ooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo8@3ooo]ZoookJP0=
oookJP03o`3o`?oonf[ooo]Z027ooo]Z00?oK03ooookJ_oonfX01_oonfX01OnMo`3ooo]ZoookJ_oo
nf[ookL000;ooo]Z00CoT`3ooookJ_o/o`3oo`000_oonfX00ol[0?oooo]Zom;o0004oookJP07okSo
0?oonf[ooo]ZoolL0?oonf[o0?nFoookJP02ool0C`Sooo]Z00Co0?n;oookJ_oonf[o0?ne0ooonfX4
o`000003ool0]Ooonf[ooo]Z00Oooo]Z00Co203oo`3o>?l0ocSooo]Z0_oo@@000oooW03oNol0og_o
0003oookJPCo:P3o0_oonfX2o`0Uo`;oE03o1Ooo0:08oookJPKo0?mF2_oonfX5ool0X0?ooo]Z0omD
0?l2o`0Uo`?ooo]Z0_lZ0?l8oookJP;oNol01?oonfX2oom100Cooo]Z00?o0?lho`P0ool80?l04_oo
nfX2ool0]Ggooo]Z001ZoookJP03o`3o2Ooonf[ooo]Z00;ooo]Z0_oo0002oookJP03ool00?oonf[o
oo]Z00;ooo]Z00?o/?l0oookJ_oonfX00ooonfX01Ooo003ooo]ZoookJ_oonf[oo`0D00[ooo]Z00?o
ojP0oookJ_oonfX00_oonfX00ooo:03oob40oookJP0=oookJP03o`3o`?oonf[ooo]Z01gooo]Z1ooo
0004oookJPOoo`0000KookL0oookJ_oonf[oT`3ooookJ_o/o`03ool00004ob/0oooo003ooo]ZoolX
00?ooo]Z1Ooo:0000ol0oiKooo]Zool0C`02oookJPGo001o00Gooo]Zo`3oRooonf[ooo]Zo`3o]@03
oookJPCo000000?oo`2eoookJ_oonfX00ooonfX5oomi0004oookJ_l0ocSo0?lhoookJP;ood4000?o
oi`0ool00?ooN@002?ooN@000olZ0?oooo]Zoomi0009oomi00Koo`2P1OooN@04oookJPGoo`2P1_oo
nfX3oe@0o`03o`0Uoooonf[ooo]Z00;ooo]Z0olZ0?l8oookJP;oNol00ooonfX00ooo003ood40ool0
0004ool00003o`3o>?l80?oooo]Z01?ooo]Z00?oo`2eoookJ_oonfX0hooonfX00ol0o`Wooo]Zoook
JP06oookJP03o`0;oooonf[ooo]Z00;ooo]Z00?o/?l0oookJ_oonfX00ooonfX01Om>0?oooo]Zoook
J_oonf[oo`0D00[ooo]Z00?oojP0oookJ_oonfX00ooonfX00ooo8@3ooo]ZoookJP0<oookJP03o`3o
`?oonf[ooo]Z027ooo]Z00?oK03ooookJ_oonfX01ooonfX01OnMo`3ooo]ZoookJ_oonf[ookL000;o
oo]Z00CoT`3ooookJ_o/o`3oo`000_oonfX00ol[0?oooo]Zom;o0004oookJP06okSo0?oonf[ooo]Z
oolL0?oonf[o0?nF0_oonfX00ooo04oooo]Zo`00O`04o`00O`;ooo]Z00Co0?n;oookJ_oonf[o0?ne
0_oonfX4o`000003oookJ_oo0;Gooo]Z00Wooo]Z00Co203oo`3o>?l0ocSooo]Z0_oo@@001?oonf[o
Nol0og_o0?mko`04oookJP?o:P3o0ooonfX00ol09OooE03ooe@0o`02oe@0o`[oo`2P2OoonfX5ool0
X0Gooo]Z0omD0?l2o`0Uo`?ooo]Z0olZ0?l8oookJP;oNol01?oonfX2oom100Cooo]Z0_l0ocP00ol8
0?oooo]ZoookJP0AoookJP03ool0]Ooonf[ooo]Z07gooo]Z001ZoookJP03o`3o2Ooonf[ooo]Z00Ko
oo]Z00?oo`00oookJ_oonfX00ooonfX00on`o`3ooo]ZoookJP02oookJP03ool00?oonf[ooo]Z00;o
oo]Z00?oo`0DoookJ_oonfX01ooonfX00oooZ03ooo]ZoookJP03oookJP03oolQ0?oonf[ooo]Z00go
oo]Z00?o0?o0oookJ_oonfX07?oonfX5ool000Oooo]Z1ooo00002ooo]`3ooo]ZoookJ_nC0?oooo]Z
onco0?oo003ooo]Zob/0oooonf[oo`0000Gooo]Z1_oo:0000ooonf[oo`1?o`00O`06o`00O`04oook
J_l0oh_o0?n;oookJP;oo`0000?ooo]Zo`000?l000000_l000000ooonf[oo`2eool0]@04oookJP?o
ogT01?oonfX2o`3o>003oookJ_oo@@3ood4000;oo`006OooN@09ool0X0;ooo]Z2OmD0?l01?l09Ooo
oo]ZoookJ_oonfX4obX0o`Wooo]Z0_mko`04oookJP;ood401?oo0002o`3o>003o`P0oooonf[ooo]Z
01;ooo]Z00?oo`2eoookJ_oonfX0iOoonfX00ol0o`Wooo]ZoookJP06oookJP03o`0;oooonf[ooo]Z
00;ooo]Z00?o/?l0oookJ_oonfX00_oonfX00om>0?oooo]ZoookJP02oookJP03ool05?oonf[ooo]Z
00Oooo]Z00?oojP0oookJ_oonfX00ooonfX00ooo8@3ooo]ZoookJP0=oookJP03o`3o`?oonf[ooo]Z
027ooo]Z00?oK03ooookJ_oonfX01ooonfX01OnMo`3ooo]ZoookJ_oonf[ookL000;ooo]Z00SoT`3o
oookJ_o/o`3oo`00oookJ_l[0?oooo]Zom;o00Gooo]Z0_nho`001?oonf[ooa`0oookJ_l0oiH2oook
JP03ool0Col007oo001o00Co001o0_oonfX2o`3oR`03oookJ_l0okGo0?ne00Co00000_oonfX2ool0
]@[ooo]Z00Co203oo`3o>?l0ocSooo]Z0_oo@@02oookJP?oNol01?oonfX5obX0o`03oookJ_l09Ooo
02Go00;o02Go1omD0?l00ooonf[oo`2Pool0X007ool0X003oookJ_mD0?ooE03o00OoE03o0_l09Ol2
oookJPCo:P3o2OoonfX2og_o00Cooo]Z0_oo@@05oookJP03o`3o>?l80?oooo]Z01?ooo]Z00?oo`2e
oookJ_oonfX0O_oonfX006[ooo]Z00?o0?l9oookJ_oonfX01ooonfX00ooo003ooo]ZoookJP02oook
JP03ok3o0?oonf[ooo]Z00;ooo]Z00?oo`00oookJ_oonfX00_oonfX00ooo003ooo]ZoookJP08oook
JP03oonX0?oonf[ooo]Z00;ooo]Z00?oob40oookJ_oonfX03OoonfX00ol0ol3ooo]ZoookJP0Moook
JP?oo`0000?ooo]Zool00?oonfX01OoonfX7ool00004oong0?oo003ooo]Zoi<0o`;ooo]Z00Kok?l0
ool00?oonf[o:`3ooookJ_oo0005oookJPKoobP000Go001oool0Col007oo001ooookJP03o`00O`?o
oo]Z00?o0?n;ool00?oo00000ooo0002o`0000?ooo]Z0_oo0;D3oookJP03oomi0?oonf[ooo]Z00Go
oo]Z0ol0ocP00ooo@@3oo`00ool0000Loomi00OoE03o00?o02GooookJ_oonfX01_oonfX4obX0o`[o
oo]Z0omko`04oookJP;ood400ooo0002oookJP03o`3o>?l80?oooo]Z01?ooo]Z0_oo0;GXoookJP03
o`3o2Ooonf[ooo]Z00Kooo]Z00?o00_ooookJ_oonfX00_oonfX00on`o`3ooo]ZoookJP02oookJP03
odh0oooonf[ooo]Z00;ooo]Z00?oo`0DoookJ_oonfX02?oonfX00oooZ03ooo]ZoookJP02oookJP03
oolQ0?oonf[ooo]Z00gooo]Z00?o0?o0oookJ_oonfX08OoonfX00om/0?oooo]ZoookJP07oookJP05
oigo0?oonf[ooo]ZoookJ_oo]`000_oonfX02OnC0?oooo]ZoookJ_o/o`3oo`00oookJ_l[0?oooo]Z
om;o0006oookJP05okSo0?oonf[ooa`0oookJ_l0oiH00_l007l00ooo04oo001ooookJP03o`00O`Co
oo]Z00Co0?n;oookJ_oonf[o0?ne0ol00004oookJP;oo`2e2_oonfX01?l80?oo0?lho`3o>?oonfX3
oom100;ooo]Z0omko`06oookJPGo:P3o1OoonfX2o`0Uo`_oE03o00?o02GooookJ_oonfX01ooonfX3
obX0o`[ooo]Z0omko`04oookJP;ood401OoonfX2o`3o>003o`P0oooonf[ooo]Z017ooo]Z0_oo0;F1
oookJP00JooonfX00ol0o`Wooo]ZoookJP06oookJP03ool00?oonf[ooo]Z00;ooo]Z00?o/?l0oook
J_oonfX00ooonfX01Ooo003ooo]ZoookJ_oonf[oo`0000[ooo]Z00?oojP0oookJ_oonfX00_oonfX0
0ooo:03oob40oookJP0=oookJP03o`3o`?oonf[ooo]Z01gooo]Z00Goo`00oookJ_oonf[ooo]Zool0
0006oookJPSoo`0000cookL0ool00?oonf[oT`3ooookJ_o/o`3oo`2Yool00?oonf[o:`3ooookJ_oo
0005oookJPOoobP000Coo`1?oookJ_oonf[ooo]Z0ol007l3oookJP03o`3oRooo003oo`0000Coo`00
1OoonfX2ool0]@_ooo]Z00Co203oo`3o>?l0ocSoo`000_oo@@0;oomi0004oookJ_ooN@3oogT0oomi
00Go:P3o1oooN@0;oookJPCo:P3o2ooonfX3og_o00Cooo]Z00?oobP0oom10?oo@@000_oo0004oook
JP03o`3o>?l80?oooo]Z01?ooo]Z00?oo`2eoookJ_oonfX0j?oonfX00ol0o`Wooo]ZoookJP06oook
JP03o`0;oooonf[ooo]Z00;ooo]Z00?o/?l0oookJ_oonfX00ooonfX01Om>0?oooo]ZoookJ_oonf[o
o`0D00[ooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo0;Coob40oookJP0>oookJP03o`3o`?oonf[o
oo]Z027ooo]Z00?oK03ooookJ_oonfX01ooonfX01OnMo`3ooo]ZoookJ_oonf[ookL000;ooo]Z00Wo
T`3ooookJ_o/o`3oo`2Yool00?oonf[o:`3ooookJ_oBo`001_oonfX01Onho`3ooo]ZoolL0?oonf[o
0?nF00;o001o00?oo`1?oookJ_oonfX00ol007l4oookJP03o`3oRooonf[o000000;o0?ne00?o0000
oookJ_oonfX01?oonfX00ooo0;Gooo]ZoookJP09oookJP05o`P0ool0ocSo0?lhoookJ_ooW0000ooo
@@02oookJP?oNol02?oonfX5obX0oa?ooo]Z1?lZ0?l:oookJP?oNol01OoonfX2oom10003oonL0?oo
nf[ooo]Z00?ooo]Z00?o0?lho`P0oooonfX04ooonfX00ooo0;Gooo]ZoookJP21oookJP00JooonfX0
0ol0o`Wooo]ZoookJP06oookJP03ool00?oonf[ooo]Z00;ooo]Z00?o/?l0oookJ_oonfX00ooonfX0
1?oo003ooo]ZoookJ_oonfX2ool000[ooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo8@3ooo]Zoook
JP0=oookJP03o`3o`?oonf[ooo]Z027ooo]Z00?oo`00oookJ_oonfX01?oonfX7ool00008oookJ_oo
]`3ooo]ZoookJ_nC0?oooo]Zonco0?oo0002oookJP03ob/0oooonf[ooo]Z00Cooo]Z2?oo:0000ooo
04oooo]ZoookJP03o`00O`Cooo]Z00?o0?n;ool00?oo00001_oo0004oookJP;oo`2e2ooonfX00ol8
0?oo0?lho`3o>002oookJPWoogT01?oonfX00oooN@3ooo]ZoookJP02oookJP03oomi0?lZ0?oo:P3o
013o:P3o1OoonfX2oolX00Gooo]Z0omko`05oookJP?ood4000?oobP0oookJ_oonfX00ooonfX2o`3o
>1Gooo]Z00?oo`2eoookJ_oonfX0jOoonfX00ol0o`Wooo]ZoookJP07oookJP05o`0;oooonf[ooo]Z
oookJ_n`o`001OoonfX00om>0?oooo]ZoookJP02oookJP03ool05?oonf[ooo]Z00Sooo]Z00?oojP0
oookJ_oonfX00_oonfX00ooo8@3ooo]ZoookJP0=oookJP03o`3o`?oonf[ooo]Z027ooo]Z00?oK03o
oookJ_oonfX02?oonfX01OnMo`3ooo]ZoookJ_oonf[ookL000;ooo]Z00CoT`3ooookJ_o/o`3oo`00
0_oonfX00ol[0?oooo]ZoookJP06oookJP05okSo0?oonf[ooa`0oookJ_l0oiH00_oonfX00ooo04oo
oo]Zo`00O`02o`00O`Gooo]Z00Go0?n;o`000?l0003o0000o`3o]@02o`0000Gooo]Z0_oo0;D;oook
JP03o`P0ool0ocSo0?lh00;ooo]Z00Cooi`0oom10?oo@@3ood400_oonfX3og_o00[ooo]Z4olZ0?l;
oookJP?oNol01OoonfX3oom100Kooo]Z0_l0ocPEoookJP03ool0]Ooonf[ooo]Z08;ooo]Z001[oook
JP03o`3o2Ooonf[ooo]Z00Kooo]Z00?oo`00oookJ_oonfX00ooonfX00on`o`3ooo]ZoookJP06oook
JP?oo`002OoonfX00oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00gooo]Z00?o0?o0oook
J_oonfX08OoonfX00ooo003ooo]ZoookJP04oookJPGoo`001?oonfX01ooo]`3ooo]ZoookJ_nC0?oo
oo]Zonco0?oo00000_oonfX00ol[0?oooo]ZoookJP04oookJPSoobP00_oo04l3o`00O`Gooo]Z0_l0
oh/8ool000Cooo]Z00?oo`2eoookJ_oonfX02_oonfX00ol80?oo0?lho`3o>002oookJPSoogT00omk
o`08oookJPGoogT03OoonfX5oolX00;ooo]Z0omko`04oookJP04oonL0?oo@@3ood40oom100CoobP0
0_oonfX3o`3o>1Kooo]Z00?oo`2eoookJ_oonfX0jooonfX00ol0o`Wooo]ZoookJP06oookJP03o`0;
oooonf[ooo]Z00;ooo]Z00?o/?l0oookJ_oonfX01ooonfX00ooo01Cooo]ZoookJP08oookJP03oonX
0?oonf[ooo]Z00;ooo]Z00?oob40oookJ_oonfX03_oonfX00ol0ol3ooo]ZoookJP0QoookJP03of`0
oooonf[ooo]Z00Oooo]Z00?oWOl0oookJ_oonfX00_oonfX01ooo]`3ooo]ZoookJ_nC0?oooo]Zonco
0?oo00000_oonfX00ol[0?oooo]ZoookJP06oookJP05okSo0?oonf[ooa`0oookJ_l0oiH00_oonfX0
1?oo04oo001oo`00Ool007l6oookJP;o0?n;0_l000000ol0okGooo]ZoookJP06oookJP;oo`2e2ooo
nfX00ol80?oo0?lho`3o>003oookJP04oonL0?oo@@3ood40oom100;ooo]Z1?mko`0QoookJP?oNol0
1OoonfX3oom100Kooo]Z0ol0ocP00ol80?oooo]ZoookJP0CoookJP03ool0]Ooonf[ooo]Z08?ooo]Z
001[oookJP03o`3o2Ooonf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX00_oonfX00on`o`3ooo]Zoook
JP06oookJP?oo`002OoonfX00oooZ03ooo]ZoookJP02oookJP03ool0]?oo8@3ooo]Z00kooo]Z00?o
0?o0oookJ_oonfX08OoonfX00ooo003ooo]ZoookJP03oookJPCoo`0000?ooo]Zool00?oonfX00_oo
nfX02?oo]`3ooo]ZoookJ_oonf[oT`3ooookJ_o/o`3oo`000_oonfX00ol[0?oooo]ZoookJP04oook
JPWoobP000?oo`1?o`00Ool007l01_oonfX00ol0003o0?n;ool00009ool000;ooo]Z0_oo0;D=oook
JP?o0?lh1_ooN@04oookJPGoNol01OoonfX00oooN@3ooo]Zoomi000:oookJPOoobP00omko`04oook
JPCood401_oo:003o`3o>0;oobP05OoonfX2ool0]Nkooo]Z00?o0?l9oookJ_oonfX01_oonfX00ol0
2ooooo]ZoookJP02oookJP03ok3o0?oonf[ooo]Z00Oooo]Z00?oo`0DoookJ_oonfX02?oonfX00ooo
Z03ooo]ZoookJP02oookJP03ool0]?oo8@3ooo]Z00kooo]Z00?o0?o0oookJ_oonfX08OoonfX00om/
0?oooo]ZoookJP08oookJP05oigo0?oonf[ooo]ZoookJ_oo]`000ooonfX01?nC0?oooo]Zonco0?oo
0002oookJP03ob/0oooonf[ooo]Z00Kooo]Z00So^?l0oookJ_oo703o001oo`3oU_oonf[o001oool0
C`;o001o1_oonfX2o`000003o`3oRol0003ooo]Z00;o0?ne2?oonfX2ool0]@cooo]Z0ol0ocP3oook
JP04oonL0?oo@@3ood40oom100?ooo]Z1Omko`0IoookJP?oNol01?oonfX4oom100Kooo]Z0ol0ocP2
o`P0oaGooo]Z0_oo0;F6oookJP00K?oonfX00ol0o`Wooo]ZoookJP06oookJP03ool00?oonf[ooo]Z
00;ooo]Z00?o/?l0oookJ_oonfX01ooonfX3ool000Wooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo
8@3ooo]ZoookJP0=oookJP03o`3o`?oonf[ooo]Z02;ooo]Z00?oo`00oookJ_oonfX00ooonfX01Ooo
003ooo]ZoookJ_oonf[oo`0000Cooo]Z00[ookL0oookJ_oonf[oT`3ooookJ_o/o`3oo`2Yool00?oo
nf[o:`3o1_oonfX8oolX00;o001o00?oo`1?oookJ_oonfX01OoonfX2o`000003o`3oRooo003oo`00
00Soo`000ooonfX2ool0]@kooo]Z00?o0?lhoomi0?ooN@000oooN@05oom100Cooo]Z1Omko`0:oook
JP[oNol000CoobP0oookJ_oonf[ooo]Z0ooo@@03oookJPCoobP00ol0ocP2oolX01Oooo]Z00?oo`2e
oookJ_oonfX0k_oonfX00ol0o`Wooo]ZoookJP07oookJP05o`0;oooonf[ooo]ZoookJ_n`o`002_oo
nfX00ooo01Cooo]ZoookJP08oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oob40oookJ_oonfX03_oo
nfX00ol0ol3ooo]ZoookJP0QoookJP03of`0oooonf[ooo]Z00Sooo]Z00GoWOl0oookJ_oonf[ooo]Z
oong0003oookJP06oi<0ooo/o`3ooo]Zool00?oonf[o:`3o2OoonfX01?nho`3o001ooolL0?l007l2
o`3oUP03o`00Oooo04oooo]Z00Kooo]Z0ol000001Ol0oh_ooo]ZoookJ_oonf[o0?ne00Wooo]Z00?o
o`2eoookJ_oonfX03?oonfX4o`3o>0;ooo]Z00?ooi`0oom10?oo@@000ooo@@03oookJPGoNol02_oo
nfX:og_o00Cooo]Z0ooo@@000oooW03ooo]ZoookJP04oookJP?o0?lh0_l80?lGoookJP03ool0]Ooo
nf[ooo]Z08Kooo]Z001/oookJP03o`3o2Ooonf[ooo]Z00Kooo]Z00?oo`00oookJ_oonfX00_oonfX0
0on`o`3ooo]ZoookJP07oookJPCoo`002?oonfX00oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[o
oo]Z00kooo]Z00?o0?o0oookJ_oonfX08OoonfX00ooo003ooo]ZoookJP08oookJP03ool00?oonf[o
oo]Z00;ooo]Z00OookL0oookJ_oonf[oT`3ooookJ_o/o`3oo`0000;ooo]Z00?o:`3ooookJ_oonfX0
1?oonfX6oolX0005o`00Ool0oiKo001ooookJ_oo04l01_oonfX2o`000003ool00?l0oh_oo`0000So
o`001OoonfX2ool0]@oooo]Z0_ooN@03o`3o>003oookJ_ooW03ooi`000Sood4000?ooo]Zog_o0?mk
o`002?mko`0;oolX00?ood401?oonfX3oolX00?o0?lh1Ooo:00FoookJP03ool0]Ooonf[ooo]Z0>oo
oo]Z00?o0?l9oookJ_oonfX01ooonfX01Ol02ooooo]ZoookJ_oonf[o/?l000[ooo]Z00?oo`0Doook
J_oonfX02?oonfX00oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00kooo]Z00?o0?o0oook
J_oonfX08OoonfX00om/0?oooo]ZoookJP08oookJP03oigo0?oonf[ooo]Z00;ooo]Z00[ookL0oook
J_oonf[oT`3ooookJ_o/o`3oo`00ool0ZOoonf[o:`3o2OoonfX00onho`3o001ooolL0002o`00O`03
o`3oU_oonf[oo`1?00Kooo]Z1?l000001?l0oh_ooo]ZoookJ_oonfX2o`3o]@Sooo]Z0_oo0;D?oook
JP03o`P0ool0ocSo0?lh00;o0?lh00Cooo]ZoonL0?ooW03ooi`02?oo@@0:og_o00Gooo]Z1_ooW003
oom10003oonL0?oonf[ooo]Z00Cooo]Z0ol0ocP2o`P0oaWooo]Z00?oo`2eoookJ_oonfX0QooonfX0
06cooo]Z00?o0?l9oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP03oookJP03ok3o0?oonf[ooo]Z
00Kooo]Z1Ooo0007oookJP03oonX0?oonf[ooo]Z00?ooo]Z00?oob40oookJ_oonfX03OoonfX00ol0
ol3ooo]ZoookJP0RoookJP03ool00?oonf[ooo]Z00Sooo]Z00Goo`00oookJ_oonf[ooo]Zoong0003
oookJP04oi<0oooonf[ok?l0ool000;ooo]Z00?o:`3ooookJ_oonfX00ooonfX6oolX00;ooo]Z00Co
0?nFoookJ_oonf[oo`1?1OoonfX3o`000003ool00?l0oh_o0?n;00Koo`002?oonfX2ool0]@kooo]Z
00CoogT0oookJ_l80?oo203o1?l0ocP7oookJQKood4000?oobP0oookJ_oonfX00_oonfX2oolX00?o
0?lh2Ooo:00CoookJP;oo`2el_oonfX00ol0o`Wooo]ZoookJP07oookJP03o`0;oooonf[ooo]Z00;o
oo]Z00?o/?l0oookJ_oonfX02?oonfX00ooo01Cooo]ZoookJP07oookJP03oonX0?oonf[ooo]Z00?o
oo]Z00?oob40oookJ_oonfX03_oonfX00ol0ol3ooo]ZoookJP0QoookJP03of`0oooonf[ooo]Z00So
oo]Z00GoWOl0oookJ_oonf[ooo]Zoong0003oookJP07oi<0oooonf[ok?l0ool00?oo0:Wooo]Zob/0
o`08oookJP04o`00Oonho`3ooo]ZoolL00;ooo]Z00?o0?nFoookJ_oo04l01OoonfX4o`000003oook
J_l0oh_o0?n;00?ooo]Z00?o0?neoookJ_oonfX01ooonfX2ool0]A3ooo]Z0_l80?l4o`3o>0Oooo]Z
00?ooi`0oom10?oo@@004ooo@@07oookJP?o0?lh00?o203ooookJ_oonfX06OoonfX2ool0]H[ooo]Z
001/oookJP03o`3o2Ooonf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX00_oonfX00on`o`3ooo]Zoook
JP06oookJPGoo`002?oonfX00oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[ooo]Z00kooo]Z00?o
0?o0oookJ_oonfX0;?oonfX00ooo003ooo]ZoookJP02oookJP08oong0?oonf[ooo]ZoookJ_nC0?oo
oo]Zonco0?oo0002oookJP03ob/0oooonf[ooo]Z00?ooo]Z0ooo:0000ol007oo^?l0oolX0002oook
JP04o`3oU_oonf[ooo]Zool0C`Cooo]Z1?l00002ool00003o`3oRooo003oo`0000?oo`002_oonfX3
ool0]A3ooo]Z0ol80?l6o`3o>0cooo]Z3?oo:0000ooonf[o0?lho`3o>003o`3o>0coobP04?oonfX3
ool0]OGooo]Z00?o0?l9oookJ_oonfX01_oonfX00ol02ooooo]ZoookJP02oookJP03ok3o0?oonf[o
oo]Z00Sooo]Z00?oo`0DoookJ_oonfX02?oonfX00oooZ03ooo]ZoookJP02oookJP03oolQ0?oonf[o
oo]Z00kooo]Z00?o0?o0oookJ_oonfX0;?oonfX00onMo`3ooo]ZoookJP02oookJP08oong0?oonf[o
oo]ZoookJ_nC0?oooo]Zonco0?oo0002oookJP03ob/0oooonf[ooo]Z00Gooo]Z0_l007l00onho`3o
oo]ZoolL0002oookJP03o`3oU_oonf[oo`1?00Cooo]Z1?l00003oookJP05o`3oRooonf[ooo]Zoook
J_l0okD02_oonfX3ool0]A3ooo]Z0ol80?l6o`3o>1Wooo]Z1Ol0ocP00ol80?oooo]ZoookJP0Ioook
JP?oo`2eS?oonfX006gooo]Z00?o0?l9oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP02oookJP03
ok3o0?oonf[ooo]Z00Kooo]Z1_oo0007oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oob40ool0]?oo
nfX03_oonfX00ol0ol3ooo]ZoookJP0]oookJP03ool00?oonf[ooo]Z00;ooo]Z00SookL0oookJ_oo
nf[oT`3ooookJ_o/o`3ooo]Zool000;ooo]Z0_l[0?l4oookJP06oolX0?oonf[o001oo`00Oonho`3o
obP00_l007l2o`3oUP03oookJ_oo04oooo]Z00;ooo]Z1?l000001?oonf[oo`00ool00?l0oh/2ool0
00;ooo]Z00?oo`00oookJ_oonfX02_oonfX2ool0]ACooo]Z0ol80?l8o`3o>0Sooo]Z2Ol0ocP00ol8
0?ooobP0oolX0006oolX01Kooo]Z0_oo0;GhoookJP03o`3o2Ooonf[ooo]Z00Oooo]Z00Go00_ooook
J_oonf[ooo]Zok3o000:oookJP03ool05?oonf[ooo]Z00Sooo]Z00?oojP0oookJ_oonfX00_oonfX0
0ooo8@3oo`2doookJP0?oookJP03o`3o`?oonf[ooo]Z02cooo]Z00?oWOl0oookJ_oonfX00_oonfX0
1ooo]`3ooo]ZoookJ_oonf[oT`3ooookJ_o/o`000_oo00000ooonf[o:`3oob/0o`06oookJP;o001o
00?o^?l0o`00Oooo70000_l007l2o`3oUP04ool0Cooonf[ooo]ZoookJPCo00001?oonfX01Ol0oh_o
oo]ZoookJ_oonf[o0?ne00cooo]Z0_oo0;DDoookJP?o203o2Ol0ocP7oookJPWo0?lh0ol80?lLoook
JP;oo`2eSooonfX006gooo]Z00?o0?l9oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP02oookJP03
ok3o0?oonf[ooo]Z00Kooo]Z1ooo0006oookJP03oonX0?oonf[ooo]Z00?ooo]Z00?oob40oookJ_oo
nfX03_oonfX00ol0ol3ooo]ZoookJP0]oookJP03ool00?oonf[ooo]Z00;ooo]Z00SookL0oookJ_oo
nf[oT`3ooookJ_o/o`3oo`2Yool000?ooo]Z00?o:`3ooookJ_oonfX00ooonfX3o`00O`07okSo0?oo
:03ooa`0o`00Oooonf[o0?nFoookJP02oolX0003oookJ_l0003o000000;o00000_oonfX2ool00003
o`3oRooonf[ooo]Z013ooo]Z0ooo0;DIoookJP?o203o2?l0ocP00ol80?oooo]ZoookJP03oookJP;o
obP07_oonfX2ool0]O[ooo]Z00?o0?l9oookJ_oonfX01ooonfX01Ol02ooooo]ZoookJ_oonf[o/?l0
00_ooo]Z00?oo`0DoookJ_oonfX01ooonfX00oooZ03ooo]ZoookJP03oookJP03oolQ0?oonf[ooo]Z
00kooo]Z00?o0?o0oookJ_oonfX0;OoonfX00onMo`3ooo]ZoookJP02oookJP09oong0?oonf[ooo]Z
oookJ_nC0?oooo]Zonco0?ooV`3oo`0000;ooo]Z00?o:`3ooookJ_oonfX00ooonfX3o`00O`04okSo
0?l007oooa`0oolL00;ooo]Z00Co0?nFool0Cooo04oooo]Z1?l00005oookJP03o`3oRooonf[ooo]Z
00oooo]Z0ooo0;DJoookJP?o203o1ol0ocP2o`P0obCooo]Z0_oo0;FAoookJP00KOoonfX00ol0o`Wo
oo]ZoookJP07oookJP03ool00?oonf[ooo]Z00;ooo]Z00?o/?l0oookJ_oonfX01OoonfX7ool000Oo
oo]Z00?oojP0oookJ_oonfX00_oonfX00ooo8@3ooo]ZoookJP0>oookJP03o`3o`?oonf[ooo]Z03;o
oo]Z00WookL0oookJ_oonf[ooo]Zoi<0oooonf[ok?l0ool0ZOoo00000ooonfX00ol[0?oooo]Zoook
JP06oookJP03okSo0?oonf[ooa`000;ooo]Z00?o0?nFoolX0?oo:0000ooo:002o`0000?ooo]Z00Co
o`00oookJ_l0oh_o0?n;4ooonfX2ool0]DGooo]Z0ooo0;GloookJP03o`3o2Ooonf[ooo]Z00Oooo]Z
00?o00_ooookJ_oonfX00_oonfX00on`o`3ooo]ZoookJP08oookJP03ool05?oonf[ooo]Z00Sooo]Z
00?oojP0oookJ_oonfX00_oonfX00ooo8@3ooo]ZoookJP0>oookJP03o`3o`?oonf[ooo]Z03;ooo]Z
00?ookL0oookJ_oonfX00_oonfX01OnC0?oooo]Zonco0?ooV`3oo`0000;ooo]Z00?o:`3ooookJ_oo
nfX01_oonfX01?nho`3ooo]ZoookJ_oo7002oookJP03o`3oU_oonf[oo`1?00Co00001_oonfX2o`3o
Ra;ooo]Z0_oo0;E5oookJP?oo`2eTooonfX006gooo]Z00?o0?l9oookJ_oonfX01ooonfX00ooo003o
oo]ZoookJP02oookJP03ool00?oonf[ooo]Z00Kooo]Z1ooo0006oookJP03oonX0?oonf[ooo]Z00;o
oo]Z00?oob40ool0]?oonfX03_oonfX00ol0ol3ooo]ZoookJP0coookJP09oong0?oonf[ooo]Zoook
J_nC0?oooo]Zonco0?oo0:Woo`0000?ooo]Z00?o:`3ooookJ_oonfX01_oonfX00onho`3ooo]ZoolL
0002oookJP03o`3oU_oo:03oobP000CoobP01ooonfX2o`3oRa?ooo]Z0_oo0;E1oookJP;oo`2eoooo
nfX1oookJP03o`3o2Ooonf[ooo]Z00Oooo]Z00Go00_ooookJ_oonf[ooo]Zok3o000:oookJP03ool0
5?oonf[ooo]Z00Sooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo8@3oo`2doookJP0?oookJP03o`3o
`?oonf[ooo]Z03;ooo]Z00GookL0oookJ_oonf[ooo]Zoi<0o`02oookJP03onco0?ooV`3oo`0000;o
oo]Z00?o:`3ooookJ_oonfX01_oonfX01?nho`3ooo]ZoookJ_oo7002oookJP04o`3oU_oonf[oo`1?
ool0C`;o00002?oonfX2o`3oRa;ooo]Z0_oo0;E1oookJP;oo`2eU_oonfX006kooo]Z00?o0?l9oook
J_oonfX01_oonfX00ooo003ooo]ZoookJP02oookJP03ool00?oonf[ooo]Z00Kooo]Z2?oo0006oook
JP03oonX0?oonf[ooo]Z00;ooo]Z00?oob40oookJ_oonfX03_oonfX00ol0ol3ooo]ZoookJP0coook
JP09oong0?oonf[ooo]ZoookJ_nC0?oooo]Zonco0?oo0:Woo`0000?ooo]Z00?o:`3ooookJ_oonfX0
1_oonfX2ool00004oolL0?oonf[ooo]Zo`3oUPOoobP01ooonfX2o`3oRa?ooo]Z0ooo0;DloookJP;o
o`2eoooonfX3oookJP03o`3o2Ooonf[ooo]Z00Oooo]Z00Go00_ooookJ_oonf[ooo]Zok3o000;oook
JP03ool05?oonf[ooo]Z00Sooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo8@3ooo]ZoookJP0>oook
JP03o`3o`?oonf[ooo]Z03?ooo]Z00GookL0oookJ_oonf[ooo]Zoi<0o`02oookJP03onco0?ooV`3o
o`0000;ooo]Z00?o:`3ooookJ_oonfX01_oonfX2okSo0005oookJ_oo703ooo]ZoookJ_l0oiH00_l0
00000ooo04oo0000oookJP09oookJP;o0?n;4_oonfX3ool0]Ccooo]Z0_oo0;FHoookJP00K_oonfX0
0ol0o`Wooo]ZoookJP06oookJP03ool00?oonf[ooo]Z00;ooo]Z0_oo0007oookJPGoo`002OoonfX0
0oooZ03ooo]ZoookJP02oookJP03oolQ0?oo0;Cooo]Z00kooo]Z00?o0?o0oookJ_oonfX0=?oonfX2
ool00007oookJ_nC0?oooo]ZoookJ_o/o`3oo`2Yool00003oookJP03ob/0oooonf[ooo]Z00Gooo]Z
0ooo00001?oo703ooo]ZoookJ_l0oiH9oolX00Kooo]Z0_l0oh/DoookJQ3oogT0:OoonfX3ool0]Ooo
oo]Z1OoonfX00ol0o`Wooo]ZoookJP07oookJP03o`0;oooonf[ooo]Z00;ooo]Z00?o/?l0oookJ_oo
nfX02?oonfX00ooo01Cooo]ZoookJP08oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oob40ool0]?oo
nfX03ooonfX00ol0ol3ooo]ZoookJP0coookJP05oong0?oonf[ooo]ZoookJ_nC0?l00_oonfX00oo/
o`3ooi/0ool00002oookJP03ob/0oooonf[ooo]Z00Oooo]Z00?o^?l0oookJ_oo70000_oonfX2o`3o
UP03o`000?oo04oooo]Z00_ooo]Z0_l0oh/CoookJP?oo`2e=_oonfX3ool0]I[ooo]Z001^oookJP03
o`3o2Ooonf[ooo]Z00Oooo]Z00Coo`00oookJ_oonf[ooo]Z0ooo0006oookJP;oo`000_oonfX00ooo
003ooo]ZoookJP07oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oob40ool0]?oonfX03ooonfX00ol0
ol3ooo]ZoookJP0coookJP?oo`0000Gooo]Zoi<0oooonf[ooo]Zonco0002ool000?ooo]Z00?o:`3o
oookJ_oonfX01OoonfX3ool000;ooa`000?ooo]Zo`000?oo:0002Ooo:006oookJP;o0?n;5?oonfX>
oomi02Kooo]Z0ooo0;GooookJPSooo]Z00?o0?l9oookJ_oonfX01ooonfX00ol02ooooo]ZoookJP02
oookJP03ok3o0?oonf[ooo]Z00Wooo]Z00?oo`0DoookJ_oonfX01ooonfX00oooZ03ooo]ZoookJP02
oookJP03oolQ0?oo0;Cooo]Z00oooo]Z00?o0?o0oookJ_oonfX0=?oonfX01Ooo]`3ooo]ZoookJ_oo
nf[oT`3o00;ooo]Z00?ok?l0oonK0?oo00000_oonfX00ol[0?oooo]ZoookJP07oookJP04okSo0?oo
nf[ooa`0oolL00;o000000Co0?nFo`000?oo04ooo`1?3?oonfX2o`3oRaCooo]Z1Ooo0;D^oookJP?o
o`2eWOoonfX006kooo]Z00?o0?l9oookJ_oonfX01ooonfX01?oo003ooo]ZoookJ_oonfX4ool000Wo
oo]Z00?oo`00oookJ_oonfX02?oonfX00oooZ03ooo]ZoookJP02oookJP03ool00?oo0;Cooo]Z00ko
oo]Z00?o0?o0oookJ_oonfX0=?oonfX4ool00004oi<0oooonf[ooo]Zonco00?oo`000_oonfX00ol[
0?oooo]ZoookJP05oookJPCoo`0000?ooa`0ool00?l000002_oo:007oookJP03o`3oRooonf[ooo]Z
01?ooo]Z3?ooN@0QoookJPGoo`2e7ooonfX2ool000Oooo]Z0_oo003PoookJP03o`3o2Ooonf[ooo]Z
00Sooo]Z00?o00_ooookJ_oonfX00_oonfX00on`o`3ooo]ZoookJP08oookJP03ool05?oonf[ooo]Z
00Sooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo8@3oo`2doookJP0?oookJP03o`3o`?oonf[ooo]Z
03Cooo]Z00GookL0oookJ_oonf[ooo]Zoi<0o`02oookJP03onco0?ooV`3oo`0000;ooo]Z00?o:`3o
oookJ_oonfX01ooonfX2okSo0008oookJ_oo703o0000o`000?l0oiKo0000oookJ_oo04l=oookJP03
o`3oRooonf[ooo]Z01Kooo]Z1?oo0;DUoookJPGoo`2e:?oonfX2o`3oRgKooo]Z001_oookJP03o`3o
2Ooonf[ooo]Z00Kooo]Z00?oo`00oookJ_oonfX00_oonfX3ool000Wooo]Z00?oo`00oookJ_oonfX0
2?oonfX00oooZ03ooo]ZoookJP02oookJP03ool00?oo0;Cooo]Z00oooo]Z00?o0?o0oookJ_oonfX0
=?oonfX4ool000;oT`3o00?ooo]Zonco0?oo00000_oo0002oookJP03ob/0oooonf[ooo]Z00Gooo]Z
1?oo00000ooo703oo`00oolX0009oolX00Sooo]Z0_l0oh/EoookJP_oogT06ooonfX5ool0]B?ooo]Z
0ooo0005oookJP;oo`00hooonfX00ol0o`Wooo]ZoookJP07oookJP03o`0;oooonf[ooo]Z00;ooo]Z
00?o/?l0oookJ_oonfX02?oonfX00ooo01Cooo]ZoookJP08oookJP03oonX0?oonf[ooo]Z00;ooo]Z
00?oob40ool0]?oonfX03ooonfX00ol0ol3ooo]ZoookJP0eoookJP04oong0?oonf[ooo]ZoookJP;o
T`3o00Cooo]Zonco0?ooV`3oo`000_oonfX00ol[0?oooo]ZoookJP08oookJP03okSo0?l0003ooa`0
00;o000000?o0?nFoookJ_oonfX00_oo04l<oookJP;o0?n;6_oonfX5ool0]A_ooo]Z1Ooo0;D[oook
JP;o0?n;N?oonfX006oooo]Z00?oo`00oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP02oookJPCo
o`002OoonfX00ooo003ooo]ZoookJP07oookJP03oonX0?oonf[ooo]Z00;ooo]Z0_oo00000ooo0;Co
oo]ZoookJP0=oookJP03o`3o`?oonf[ooo]Z03Cooo]Z1_oo00000onC0?oooo]Zonco0004ool00003
oookJ_l[0?oooo]Z00Gooo]Z1Ooo00000ooo703oo`00oolX0007oolX00_ooo]Z0_l0oh/EoookJPOo
ogT00_oonfX2oomi00[oo`2e2_oonfX5ool0]BOooo]Z1Ooo0002oookJP;oo`00iOoonfX00ol0o`Wo
oo]ZoookJP07oookJP03o`0;oooonf[ooo]Z00;ooo]Z00?o/?l0oookJ_oonfX02OoonfX00ooo01Co
oo]ZoookJP07oookJP03oonX0?oonf[ooo]Z00?ooo]Z00?oob40ool0]?oonfX03ooonfX00ol0ol3o
oo]ZoookJP0eoookJP03oong0?oonf[ooo]Z00;ooo]Z00GoT`3ooookJ_o/o`3ooi/0ool00002oook
JP03ob/0oooonf[ooo]Z00Sooo]Z00Go^?l0o`000?oo703o0000oookJP02o`3oUP;ooo]Z00?oo`1?
oookJ_oonfX02ooonfX2o`3oRagooo]Z3?oo0;D:oookJPGoo`2e;_oonfX2o`3oRg[ooo]Z001_oook
JP03ool00?oonf[ooo]Z00Oooo]Z00Coo`00oookJ_oonf[ooo]Z1Ooo0008oookJP03ool00?oonf[o
oo]Z00Sooo]Z00?oojP0oookJ_oonfX00_oonfX2ool0013ooo]Z00?o0?o0oookJ_oonfX0=?oonfX6
ool00003oi<0oooo003ok?l000Goo`0000?o:`3ooookJ_oonfX01?oonfX5ool000;ooa`01ooo:00=
oookJP;o0?n;5?oonfX6oomi00kooo]Z2_oo0;D[oookJPSoo`00iooonfX00ol0o`Wooo]ZoookJP08
oookJP03o`0;oooonf[ooo]Z00;ooo]Z00?o/?l0oookJ_oonfX02?oonfX00ooo01Cooo]ZoookJP08
oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oob40ool0]?oonfX03ooonfX00ol0ol3ooo]ZoookJP0f
oookJP03oong0?oonf[ooo]Z00;ooo]Z00GoT`3ooookJ_o/o`3ooi/0ool00002oookJP03ob/0oooo
nf[ooo]Z00Oooo]Z00?o0000okSo0?l000000_oo7002oookJP;o0?nF00?ooo]Zool0CooonfX03Ooo
nfX2o`3oRbOooo]Z2_oo0;DaoookJP;o0?n;O?oonfX006oooo]Z0_oo0008oookJP04ool00?oonf[o
oo]ZoookJPKoo`002?oonfX00ooo003ooo]ZoookJP07oookJP03oonX0?oonf[ooo]Z00;ooo]Z0ooo
000?oookJP03o`3o`?oonf[ooo]Z03Cooo]Z1ooo00000onC0?ooo`00onco0005ool00003ob/0oooo
nf[ooo]Z00Cooo]Z1_oo00000ooo703oobP0oolX0003oolX0003oookJ_oo:03oobP000gooo]Z0_l0
oh/DoookJP?oogT0@ooonfX8ool00>Wooo]Z00?o0?l9oookJ_oonfX01ooonfX00ol02ooooo]Zoook
JP02oookJP03ok3o0?oonf[ooo]Z00Wooo]Z00?oo`0DoookJ_oonfX01ooonfX00oooZ03ooo]Zoook
JP03oookJP03oolQ0?oo0;Cooo]Z00oooo]Z00?o0?o0oookJ_oonfX0=_oonfX00ooo]`3ooo]Zoook
JP02oookJP05oi<0oooonf[ok?l0oonK0?oo00000_oonfX00ol[0?oooo]ZoookJP06oookJP;o0000
0_nho`000ooonf[ooa`0oookJP02oookJP04o`3oU_oonf[oo`1?ool0C`kooo]Z0_l0oh]NoookJP;o
0?n;O_oonfX006oooo]Z0ooo000;oookJPKoo`002?oonfX00ooo003ooo]ZoookJP07oookJP03oonX
0?oonf[ooo]Z00;ooo]Z1?oo000>oookJP03o`3o`?oonf[ooo]Z03Gooo]Z1ooo00000onC0?ooo`00
onco0005ool00003ob/0oooonf[ooo]Z00Cooo]Z1_oo00001?oo703oobP0oolX0?oo:002o`3oUP;o
oo]Z00?oobP0oookJ_oonfX03?oonfX3o`3oRa?ooo]Z00?oogT0oookJ_oonfX0?ooonfX:ool00>Wo
oo]Z00?o0?l9oookJ_oonfX03OoonfX00on`o`3ooo]ZoookJP08oookJP03ool05?oonf[ooo]Z00Oo
oo]Z00?oojP0oookJ_oonfX00ooonfX00ooo8@3oo`2doookJP0?oookJP03o`3o`?oonf[ooo]Z03Oo
oo]Z00?ookL0oookJ_oonfX00_oonfX01OnC0?oooo]Zonco0?ooV`3oo`0000;ooo]Z00?o:`3ooook
J_oonfX01OoonfX4o`000003okSo0?oonf[ooa`000?ooo]Z0_l0oiH00ooonf[oo`1?oookJP0>oook
JP?o0?n;F?oonfX3o`3oRh3ooo]Z001_oookJPCoo`002_oonfX7ool000Oooo]Z00?oo`00oookJ_oo
nfX02?oonfX01?oo003ooo]ZoookJ_oonfX5ool000kooo]Z00?o0?o0oookJ_oonfX0=OoonfX7ool0
00;oT`3o00?ok?l0ool00?oo00000ooo00000ol[0?ooo`00oookJP03oookJPOoo`0000?ooa`0oolX
0?oonfX00_oonfX2o`3oUP03oookJ_oo:03oo`1?00oooo]Z0ol0oh]AoookJP_oo`00jOoonfX00ol0
o`Wooo]ZoookJP0=oookJP03ok3o0?oonf[ooo]Z00Sooo]Z00?oo`0DoookJ_oonfX02?oonfX00ooo
Z03ooo]ZoookJP03oookJP03oolQ0?oonf[ooo]Z00oooo]Z00?o0?o0oookJ_oonfX0=ooonfX00ooo
]`3ooo]ZoookJP02oookJP05oi<0oooonf[ok?l0oonK0?oo00000_oonfX00ol[0?oooo]ZoookJP04
oookJPCo000000Cooo]ZokSo0?oonf[ooa`01?oonfX2o`3oUP;oo`1?4?oonfX3o`3oRe?ooo]Z0_l0
oh^3oookJP00L?oonfX3ool000[ooo]Z2?oo0007oookJP03ool00?oonf[ooo]Z00Oooo]Z00?oo`00
oookJ_oonfX00_oonfX5ool000gooo]Z00?o0?o0oookJ_oonfX0=OoonfX9ool00003oi<0ooo/o`3o
o`0000Coo`0000?o:`3oool00?oonfX00ooonfX5ool00003oookJ_oo003ooa`000Gooo]Z0_l0oiH0
0ooonf[oo`1?ool0C`0@oookJP?o0?n;COoonfX=ool00>Wooo]Z00?o0?l9oookJ_oonfX03OoonfX0
0on`o`3ooo]ZoookJP08oookJP03ool05?oonf[ooo]Z00Oooo]Z00?oojP0oookJ_oonfX01?oonfX0
0ooo8@3ooo]ZoookJP0>oookJP03o`3o`?oonf[ooo]Z03Sooo]Z00?ookL0oookJ_oonfX00_oonfX0
1OnC0?oooo]Zonco0?ooV`3oo`0000;ooo]Z00?o:`3ooookJ_oonfX00ooonfX4o`0000;ooo]Z0_nh
o`000ooo703ooo]ZoookJP03oookJP;o0?nF0_oo04lAoookJP?o0?n;C_oonfX2o`3oRhGooo]Z001`
oookJPCoo`002_oonfX8ool000Kooo]Z00?oo`00oookJ_oonfX01ooonfX2ool000?ooo]Z1_oo000=
oookJP;oo`00=_oonfX6ool000;ooo]Z00?oo`00oi<0ooo/o`001Ooo00000ol[0?oooo]ZoookJP02
oookJP04o`000?oo003oo`00ool000?ooo]Z1?oo0004oookJP03o`3oU_oonf[ooo]Z00;oo`1?4Ooo
nfX3o`3oRdWooo]Z2ooo003/oookJP03o`3o2Ooonf[ooo]Z00gooo]Z00?o/?l0oookJ_oonfX02?oo
nfX00ooo01Cooo]ZoookJP08oookJP03oonX0?oonf[ooo]Z00?ooo]Z00?oob40oookJ_oonfX03ooo
nfX00ol0ol3ooo]ZoookJP0hoookJP03oong0?oonf[ooo]Z00;ooo]Z00GoT`3ooookJ_o/o`3ooi/0
ool00002oookJP03ob/0oooonf[ooo]Z00;ooo]Z1?l00004oookJP03okSo0?oo703ooa`000Gooo]Z
00Co0?nFoookJ_oo04ooo`1?4_oonfX2o`3oRd[ooo]Z0_l0oh^7oookJP00L?oonfX5ool000Wooo]Z
1_oo0009oookJP03ool00?oonf[ooo]Z00Oooo]Z0_oo0002oookJPOoo`003?oonfX3ool003Gooo]Z
1_oo0003oookJP04ool00?nC0?ook?l0onco00;oobP00_oonfX2ob/0o`;ooo]Z0_l000000ooo003o
0000oookJP03oookJP03ool00?oonf[oo`0000Coo`0000?ooo]Zo`3oU_l0oiH00_oonfX2ool0Ca;o
oo]Z0ol0oh]5oookJPOoo`00l_oonfX00ol0o`Wooo]ZoookJP0<oookJP03ok3o0?oonf[ooo]Z00Wo
oo]Z00?oo`0DoookJ_oonfX01ooonfX00oooZ03ooo]ZoookJP04oookJP03oolQ0?oonf[ooo]Z00ko
oo]Z00?o0?o0oookJ_oonfX0>OoonfX00ooo]`3ooo]ZoookJP02oookJP;oT`3o0_o/o`02ool00003
oookJ_l[0?oo:`3o00;ooo]Z1?l00005oookJP04okSo0?oonf[ooa`0oolL00Cooo]Z0_l0oiH00ooo
nf[oo`1?ool0C`0BoookJP?o0?n;AOoonfX2o`3oRhWooo]Z001`oookJPKoo`002?oonfX3ool00003
oookJ_oo003ooo]Z00Wooo]Z00?oo`00oookJ_oonfX01ooonfX3ool000;ooo]Z1ooo000<oookJP?o
o`00=OoonfX3ool000;ooo]Z00?oo`00oookJ_oonfX00_oo00000onC0?ooo`00oolX0004oolX0003
oookJ_l[0?oooo]Z00Co00001OoonfX00ooo003ooo]Zool00006ool000;o0?nF0_oonfX2ool0Ca?o
oo]Z0ol0oh/ooookJP;o0?n;0ooo003goookJP03o`3o2Ooonf[ooo]Z00gooo]Z00?o/?l0oookJ_oo
nfX02?oonfX00ooo01Cooo]ZoookJP08oookJP03oonX0?oonf[ooo]Z00?ooo]Z00?oob40oookJ_oo
nfX03ooonfX00ol0ol3ooo]ZoookJP0ioookJP03oong0?oonf[ooo]Z00?ooo]Z00GoT`3ooookJ_o/
o`3ooi/0ool00002oookJP03ob/0oooonf[o000000?o00001_oonfX00onho`3ooo]ZoookJP02oolL
00Cooo]Z0_l0oiH00ooonf[oo`1?ool0C`0CoookJP?o0?n;?ooonfX3o`3oRh_ooo]Z001`oookJPKo
o`002?oonfX01Ooo003ooo]ZoookJ_oonf[oo`0000[ooo]Z00?oo`00oookJ_oonfX01ooonfX4ool0
0003oookJ_oo003oo`0000Koo`002ooonfX4ool003Gooo]Z00?oo`00oookJ_oonfX00_oonfX00ooo
003ooo]ZoookJP02ool00003oi<0oooonf[oobP000GoobP000?o:`3oo`000?l000000_l00006oook
JP03ool00?oonf[oo`0000Woo`000_oonfX00ooo04oooo]ZoookJP0CoookJPCo0?n;7_oonfX3oolX
01Gooo]Z1Ol0oh_moookJP03o`3o2Ooonf[ooo]Z00cooo]Z00?o/?l0oookJ_oonfX02?oonfX00ooo
01Cooo]ZoookJP08oookJP03oonX0?oonf[ooo]Z00Cooo]Z00?oob40oookJ_oonfX03ooonfX00ol0
ol3ooo]ZoookJP0ioookJP03oong0?oonf[ooo]Z00?ooo]Z00GoT`3ooookJ_o/o`3ooi/0ool00002
oookJP;o:`3o0ol00007oookJP05okSo0?oonf[ooo]ZoookJ_oo70001OoonfX00ol0oiKooo]Zoook
JP02ool0CaCooo]Z1?l0oh/foookJPGo0?n;S_oonfX0073ooo]Z1ooo000<oookJP03ool00?oonf[o
oo]Z00Sooo]Z00?oo`00oookJ_oonfX01_oonfX;ool000gooo]Z1Ooo000joookJP05ool00?oonf[o
oo]Zool00?oonfX00_nC0?l8oolX00;o00002OoonfX;ool00003oookJ_oo04ooo`1?01Oooo]Z1Ol0
oh/EoookJPOoobP04OoonfX4o`3oRooooo]Z0ooonfX00ol0o`Wooo]ZoookJP0=oookJP03ok3o0?oo
nf[ooo]Z00Sooo]Z00?oo`0DoookJ_oonfX02?oonfX00oooZ03ooo]ZoookJP03oookJP03oolQ0?oo
nf[ooo]Z00oooo]Z00?o0?o0oookJ_oonfX0>_oonfX00ooo]`3ooo]ZoookJP03oookJP05oi<0oooo
nf[ok?l0onco0?oo00000_oonfX01?l0003o:`3oo`000?l0000<oookJP;ooa`01?oonfX2o`3oUP;o
oo]Z0_oo04lFoookJPGo0?n;;OoonfX4o`3oRi?ooo]Z001`oookJPSoo`002ooonfX00ooo003ooo]Z
oookJP08oookJP03ool00?oonf[ooo]Z00Oooo]Z2Ooo000?oookJPKoo`00>OoonfX00ooo003ooo]Z
oookJP03oookJP03oi<0oooo:03oobP000OoobP02_oonfX:ool00003o`3oU_oonf[ooo]Z00;oo`1?
6_oonfX5o`3oR`gooo]Z2_oo:00=oookJPCo0?n;oooonfX7oookJP03o`3o2Ooonf[ooo]Z00gooo]Z
00?o/?l0oookJ_oonfX02?oonfX00ooo01Cooo]ZoookJP09oookJP03oonX0?oonf[ooo]Z00?ooo]Z
00?oob40oookJ_oonfX03ooonfX00ol0ol3ooo]ZoookJP0joookJP03oong0?oonf[ooo]Z00?ooo]Z
00CoT`3ooookJ_oonf[ok?l00_oo0002o`000003ob/0ool0003ooo]Z00gooo]Z0_oo7004oookJP;o
0?nF0_oonfX2ool0CaWooo]Z1Ol0oh/ToookJPCo0?n;UooonfX0077ooo]Z2?oo000;oookJP03ool0
0?oonf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX01ooonfX7ool00003oookJ_oo003ooo]Z00kooo]Z
1ooo000ioookJP03ool00?oonf[ooo]Z00?ooo]Z00?oT`3ooolX0?oo:0002Ooo:008oookJPSoo`00
0_oonfX3o`3oUP03oookJ_oo04ooo`1?01gooo]Z1Ol0oh/4oookJPkoobP02?oonfX5o`3oRooooo]Z
3?oonfX00ol0o`Wooo]ZoookJP0=oookJP03ok3o0?oonf[ooo]Z00Oooo]Z00?oo`0DoookJ_oonfX0
2OoonfX00oooZ03ooo]ZoookJP03oookJP03oolQ0?oonf[ooo]Z00oooo]Z00?o0?o0oookJ_oonfX0
>ooonfX00ooo]`3ooo]ZoookJP03oookJP06oi<0oooonf[ooo]Zonco0?ooV`3oo`000_l00002ob/0
o`oooo]Z0_oo7004oookJP?o0?nF00?ooo]Zool0Cooo04l07?oonfX5o`3oRa[ooo]Z1Ol0oh^Koook
JP00LOoonfX6ool000gooo]Z00?oo`00oookJ_oonfX02?oonfX00ooo003ooo]ZoookJP06oookJPOo
o`000_oonfX00ooo003ooo]ZoookJP0<oookJPSoo`00>OoonfX00ooo003ooo]ZoookJP03oookJP03
oi<0oooo:03oobP000WoobP02?oonfX7ool000Gooo]Z0_l0oiH00ooonf[oo`1?ool0C`0PoookJP;o
0?n;5ooo:0000ol0oh_ooo]ZoookJP3ooookJPoooo]Z00?o0?l9oookJ_oonfX03OoonfX00on`o`3o
oo]ZoookJP08oookJP03ool05?oonf[ooo]Z00Wooo]Z00?oojP0oookJ_oonfX00ooonfX00ooo8@3o
oo]ZoookJP0?oookJP03o`3o`?oonf[ooo]Z03_ooo]Z00?ookL0oookJ_oonfX00ooonfX00onC0?oo
oo]ZoookJP02onco0005ool00?l0003o0000oookJ_l[0?l04?oonfX2oolL00Gooo]Z0_l0oiH00ooo
nf[oo`1?ool0C`0OoookJQ[o0?n;X?oonfX0077ooo]Z0ooo00000ooonf[oo`00oookJP0>oookJP03
ool00?oonf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX01ooonfX7ool00003oookJ_oo003ooo]Z00ko
oo]Z2?oo000ioookJP03ool00?oonf[ooo]Z00?ooo]Z2ooo:009oookJPGoo`0000?ooo]Zool00?oo
00001OoonfX3o`3oUPWoo`007?oonfX=oolX03[ooo]Z0_oo003MoookJP03o`3o2Ooonf[ooo]Z00go
oo]Z00?o/?l0oookJ_oonfX01ooonfX00ooo01Cooo]ZoookJP09oookJP03oonX0?oonf[ooo]Z00?o
oo]Z00?oob40oookJ_oonfX04?oonfX00ol0ol3ooo]ZoookJP0koookJP03oong0?oonf[ooo]Z00?o
oo]Z00OoT`3ooookJ_oonf[oo`2Yonco0?oo003o000000;ooo]Z0_l[0?l@oookJP03oolL0?oonf[o
oo]Z00Cooo]Z0_l0oiH00ooonf[oo`1?ool0C`1ZoookJP;o0?nFJooonfX0077ooo]Z00Goo`00oook
J_oonf[ooo]Zool0000?oookJP03ool00?oonf[ooo]Z00Sooo]Z00?oo`00oookJ_oonfX01_oonfX8
ool00003ool0]?oo003ooo]Z00gooo]Z2Ooo000ooookJPWoobP000?o:`3ooookJ_oonfX02?oonfX4
ool000?ooo]Z0_oo0006oookJP;o0?nF3ooo000HoookJPWoobP0;ooonfX2ool000Kooo]Z0ooo003O
oookJP03o`3o2Ooonf[ooo]Z00gooo]Z00?o/?l0oookJ_oonfX02?oonfX00ooo01Cooo]ZoookJP09
oookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oo`2doolQ0?oonfX04?oonfX00ol0ol3ooo]ZoookJP12
oookJP;oT`3o0_l000000oo/o`3oo`00ool00003oookJP03ob/0oooonf[ooo]Z00kooo]Z0_oo7006
oookJP?o0?nF0ooo04mToookJP?o0?nFKOoonfX007Gooo]Z00?oo`00oookJ_oonfX03OoonfX00ooo
003ooo]ZoookJP08oookJP03ool00?oonf[ooo]Z00Kooo]Z1_oo0003oookJP03ool0]?oo003ooo]Z
00cooo]Z2_oo000noookJPWoobP000?ooo]Zob/0ool[0?l02OoonfX3ool000Gooo]Z0_oo0006oook
JP03o`3oU_oo003oo`0000coo`006ooonfX6oolX02kooo]Z0ooo0004oookJP;oo`00h_oonfX00ol0
o`Wooo]ZoookJP0=oookJP03ok3o0?oonf[ooo]Z00Sooo]Z00?oo`0DoookJ_oonfX02OoonfX00ooo
Z03ooo]ZoookJP03oookJP03ool0]?oo8@3ooo]Z013ooo]Z00?o0?o0oookJ_oonfX0@ooonfX00onC
0?oo0000o`000002onco0005ool00?oonf[ooo]ZoookJ_l[0?l04OoonfX2oolL00Oooo]Z0_l0oiH0
1?oonf[oo`1?ool0Cooo04mOoookJP;o0?nFL?oonfX007Kooo]Z00?oo`00oookJ_oonfX03OoonfX0
0ooo003ooo]ZoookJP07oookJP03ool00?oonf[ooo]Z00Kooo]Z1Ooo0004oookJP03ool0]?oo003o
oo]Z00gooo]Z1ooo0011oookJPSoobP00ooonfX00ol[0?oooo]ZoookJP07oookJP03ool00?oonf[o
oo]Z00Kooo]Z00?oo`00oookJ_oonfX01OoonfX00ol0oiKoo`00ool00009ool0023ooo]Z0_oo:00/
oookJPGoo`000_oonfX2ool00>Gooo]Z00?o0?l9oookJ_oonfX03OoonfX00on`o`3ooo]ZoookJP07
oookJP03ool05?oonf[ooo]Z00[ooo]Z00?oojP0oookJ_oonfX00_oonfX00ooo0;Coob40oookJP0A
oookJP03o`3o`?oonf[ooo]Z04;ooo]Z00Oo0000oi<0ool0003o0000oookJ_o/o`3oo`0000?ooo]Z
0_l[0?lAoookJP03oolL0?oonf[ooo]Z00Kooo]Z0_l0oiH2oookJP?oo`1?FOoonfX3o`3oUW;ooo]Z
001foookJP03ool00?oonf[ooo]Z00gooo]Z00?oo`00oookJ_oonfX02?oonfX00ooo003ooo]Zoook
JP06oookJP;oo`0000?ooo]Zool00?oonfX01?oonfX2ool000gooo]Z1_oo0013oookJPSoobP00ooo
nfX00ol[0?oooo]ZoookJP0IoookJP[oo`00COoonfX8ool00>Oooo]Z00?o0?l9oookJ_oonfX03Ooo
nfX00on`o`3ooo]ZoookJP08oookJP03ool05?oonf[ooo]Z00Wooo]Z00?oojP0oookJ_oonfX00ooo
nfX00ooo0;Coob40oookJP0@oookJP03o`3o`?oonf[ooo]Z04;ooo]Z0_l00002oi<0o`;ooo]Z00?o
k?l0ool00?ooV`000ooonfX00ol[0?oooo]ZoookJP0IoookJP?o0?nF0_oonfX2ool0CeGooo]Z0_l0
oiIeoookJP00MooonfX00ooo003ooo]ZoookJP0=oookJP03ool00?oonf[ooo]Z013ooo]Z00Goo`00
oookJ_oonf[ooo]Zool00004oookJP;oo`003OoonfX5ool004Cooo]Z00?o0000oolX0?oo:0001ooo
:002oookJP;o:`3o6ooonfX8ool004_ooo]Z2Ooo003YoookJP03o`3o2Ooonf[ooo]Z00gooo]Z00?o
/?l0oookJ_oonfX05?oonfX00oooZ03ooo]ZoookJP02oookJP03ool0]?oo8@3ooo]Z017ooo]Z00?o
0?o0oookJ_oonfX0@OoonfX4o`000004oi<0oooonf[ooo]Zonco00;oo`000ooonfX2ob/0oacooo]Z
0_l0oiH2oookJP?oo`1?CooonfX3o`3oUWOooo]Z001goookJP03ool00?oonf[ooo]Z00gooo]Z00?o
o`00oookJ_oonfX05?oonfX00ooo003ooo]ZoookJP03oookJP;oo`003OoonfX2ool000;ooo]Z00?o
o`00oookJ_oonfX0@OoonfX2o`0000[oobP00_oonfX00ol[0?oooo]ZoookJP0IoookJPKoo`0000Co
oo]Zool00?oo003oo`00AooonfX:ool00>Wooo]Z00?o0?l9oookJ_oonfX03OoonfX00on`o`3ooo]Z
oookJP0DoookJP03oonX0?oonf[ooo]Z00?ooo]Z00?oo`2doolQ0?oonfX04OoonfX00ol0ol3ooo]Z
oookJP10oookJPCo000000?ooo]Zoi<0oonC0?l00_oonfX00oo/o`3oo`00oonK0003oookJP03ob/0
oooonf[ooo]Z01_ooo]Z0ol0oiH2oookJP?oo`1?B_oonfX2o`3oUW[ooo]Z001hoookJP03ool00?oo
nf[ooo]Z00gooo]Z00?oo`00oookJ_oonfX05?oonfX00ooo003ooo]ZoookJP02oookJP?oo`003?oo
nfX00ooo003ooo]ZoookJP02oookJP03ool00?oonf[ooo]Z043ooo]Z0ol0000:oolX00;ooo]Z00?o
:`3ooookJ_oonfX06OoonfX5ool000Co0?nF0ooo0013oookJPcoo`00jOoonfX00ol0o`Wooo]Zoook
JP0=oookJP03ok3o0?oonf[ooo]Z01Cooo]Z00?oojP0oookJ_oonfX00ooonfX00ooo8@3ooo]Zoook
JP0@oookJP03o`3o`?oonf[ooo]Z043ooo]Z1?l00003oookJP06oi<0oooonf[ooo]Zonco0?oo003o
oi/00ooonfX00ol[0?oooo]ZoookJP0MoookJPCo0?nF00Cooo]Zool0Cooo04ooo`1?A?oonfX3o`3o
UWcooo]Z001hoookJP03ool00?oonf[ooo]Z00gooo]Z00?oo`00oookJ_oonfX05OoonfX01?oo003o
oo]ZoookJ_oonfX4ool0013ooo]Z00?oo`00oookJ_oonfX0@?oonfX3o`0000[oobP00ooonfX4oolX
01Wooo]Z0ooo0004oookJP?o0?nF00?oo`00oookJ_oonfX0?_oonfX>ool00>Wooo]Z00?o0?l9oook
J_oonfX03OoonfX00on`o`3ooo]ZoookJP0EoookJP03oonX0?oonf[ooo]Z00;ooo]Z00?oo`2doolQ
0?oonfX04OoonfX00ol0ol3ooo]ZoookJP0ooookJPCo00001?oonfX01_nC0?oooo]ZoookJ_o/o`3o
o`00oonK00?ooo]Z0_l[0?lQoookJPCo0?nF00?oo`1?oookJ_oonfX0?ooonfX2o`3oUWoooo]Z001h
oookJP03ool00?oonf[ooo]Z00gooo]Z00?oo`00oookJ_oonfX05OoonfX00ooo003ooo]ZoookJP02
oookJPCoo`004?oonfX00ooo003ooo]ZoookJP0ooookJPCo00002_oo:0001?oo003oobP0oolX0?oo
nfX7oolX01Gooo]Z00?oo`00oookJ_oonfX01ooonfX3o`3oUQKooo]Z0ooo:00SoookJP[oo`00k_oo
nfX00ol0o`Wooo]ZoookJP0=oookJP03ok3o0?oonf[ooo]Z01Gooo]Z00?oojP0oookJ_oonfX00ooo
nfX00ooo8@3ooo]ZoookJP0@oookJP03o`3o`?oonf[ooo]Z03oooo]Z1?l00005oookJP;oT`3o0_oo
nfX2ool00004oonK0?oonf[ooo]ZoookJP;o:`3o8ooonfX3o`3oUScooo]Z0ol0oiJ1oookJP00NOoo
nfX00ooo003ooo]ZoookJP0=oookJP03ool00?oonf[ooo]Z01Gooo]Z00Coo`00oookJ_oonf[ooo]Z
1Ooo000@oookJP03ool00?oonf[ooo]Z03kooo]Z1?l000000ooonf[oobP0oolX0005oolX0003oook
J_oo:03oobP000;oo`003Ooo:00MoookJPCo0?nF3OoonfX8oolX01oooo]Z0ol0oiH4ool00?Kooo]Z
00?o0?l9oookJ_oonfX03OoonfX00on`o`3ooo]ZoookJP0EoookJP03oonX0?oonf[ooo]Z00?ooo]Z
00?oob40oookJ_oonfX04?oonfX00ol0ol3ooo]ZoookJP0noookJPCo00001ooonfX01?nC0?oooo]Z
oookJ_oonfX2ool00004oonK0?oonf[ooo]ZoookJP;o:`3o9?oonfX4o`3oUSCooo]Z1?l0oiJ4oook
JP00NOoonfX00ooo003ooo]ZoookJP0=oookJP03ool00?oonf[ooo]Z01Gooo]Z00Coo`00oookJ_oo
nf[ooo]Z1_oo000?oookJP03ool00?oonf[ooo]Z03kooo]Z1?l00002oookJPGoobP000?ooo]ZoolX
0?oonfX00ooo:002ool000goobP07ooonfX4o`3oUPCooo]Z3Ooo:00IoookJPKo0?nFoOoonfX00ol0
o`Wooo]ZoookJP0=oookJP03ok3o0?oonf[ooo]Z01Gooo]Z00?oojP0oookJ_oonfX00ooonfX00ooo
8@3ooo]ZoookJP0AoookJP03o`3o`?oonf[ooo]Z03gooo]Z1?l00008oookJP03oi<0oooonf[ooo]Z
00;ooo]Z0_oo00001?ooV`3ooo]ZoookJ_oonfX2ob/0obKooo]Z1?l0oiHZoookJPKo0?nFR?oonfX0
07[ooo]Z00?oo`00oookJ_oonfX03OoonfX00ooo003ooo]ZoookJP0EoookJP04ool00?oonf[ooo]Z
oookJPKoo`003ooonfX00ooo003ooo]ZoookJP0moookJPGo00000_oonfX3oolX00?ooo]Z1_oo:000
0ooo003oobP0oolX000:oolX02?ooo]Z00?o0?nFoolX0?oo:0003_oo:00BoookJPOo0?nFoooonfX5
oookJP03o`3o2Ooonf[ooo]Z00gooo]Z00?o/?l0oookJ_oonfX05OoonfX00oooZ03ooo]ZoookJP03
oookJP03oolQ0?oonf[ooo]Z013ooo]Z00?o0?o0oookJ_oonfX0?OoonfX5o`0000Sooo]Z0_nC0?l3
oookJP03onco0?oo003ooi/000Cooo]Z0_l[0?lXoookJPSo0?nF6ooonfX7o`3oUXkooo]Z001joook
JP03ool00?oonf[ooo]Z00gooo]Z00?oo`00oookJ_oonfX05OoonfX01?oo003ooo]ZoookJ_oonfX7
ool000oooo]Z00?oo`00oookJ_oonfX0??oonfX4o`0000Cooo]Z00?oobP0oookJ_oonfX01?oonfX5
oolX00;oo`002Ooo:00XoookJQ7oobP02?oonfX6o`3oU_oooo]Z3?oonfX00ol0o`Wooo]ZoookJP0=
oookJP03ok3o0?oonf[ooo]Z01Gooo]Z00?oojP0oookJ_oonfX01?oonfX00ooo8@3ooo]ZoookJP0@
oookJP03o`3o`?oonf[ooo]Z03cooo]Z1?l0000;oookJP03oi<0oooonf[ooo]Z00;ooo]Z0_oo0000
0oooV`3ooo]ZoookJP02oookJP;o:`3o;_oonfX=o`3oUPSooo]Z1_l0oiJEoookJP00NooonfX00ooo
003ooo]ZoookJP0=oookJP03ool00?oonf[ooo]Z01Gooo]Z00?oo`00oookJ_oonfX02?oo000>oook
JP03ool00?oonf[ooo]Z03cooo]Z1?l0000<oookJPKoobP00_oo0007oolX02_ooo]Z2_oo:004oook
JPKoobP00_l0oiKooookJQ?ooo]Z00?o0?l9oookJ_oonfX03OoonfX00on`o`3ooo]ZoookJP0Eoook
JP03oonX0?oonf[ooo]Z00?ooo]Z00?oob40oookJ_oonfX04OoonfX00ol0ol3ooo]ZoookJP0koook
JPCo00003?oonfX2oi<0o`Cooo]Z0_oo00000oooV`3ooo]ZoookJP02oookJP03ob/0oooonf[ooo]Z
03Sooo]Z2?l0oiJKoookJP00NooonfX00ooo003ooo]ZoookJP0=oookJP03ool00?oonf[ooo]Z01Go
oo]Z00Coo`00oookJ_oonf[ooo]Z2?oo000>oookJP03ool00?oonf[ooo]Z03_ooo]Z1?l0000>oook
JPKoobP00_oo0006oolX02gooo]Z1ooo:03ooookJQoooo]Z00?o0?l9oookJ_oonfX03OoonfX00on`
o`3ooo]ZoookJP0EoookJP03oonX0?oonf[ooo]Z00Cooo]Z00?oob40oookJ_oonfX04?oonfX00ol0
ol3ooo]ZoookJP0koookJPCo00003_oonfX00onC0?oooo]ZoookJP03oookJP;oo`0000Cooi/0oook
J_oonf[ooo]Z0_l[0?oKoookJP00NooonfX00ooo003ooo]ZoookJP0=oookJP03ool00?oonf[ooo]Z
01Kooo]Z00?oo`00oookJ_oonfX01_oo000AoookJP03ool00?oonf[ooo]Z03[ooo]Z1?l0000?oook
JPGoobP000Cooo]ZoolX0?oo003oo`000_oo:002oookJP;oobP0;_oonfX4oolX0?oooo]Z7ooonfX0
0ol0o`Wooo]ZoookJP0=oookJP03ok3o0?oonf[ooo]Z01Kooo]Z00?oojP0oookJ_oonfX00ooonfX0
0ooo8@3oo`2doookJP0AoookJP03o`3o`?oonf[ooo]Z03[ooo]Z1?l0000?oookJP03oi<0oooonf[o
oo]Z00Cooo]Z0_oo00001?ooV`3ooo]ZoookJ_oonfX2ob/0omWooo]Z001loookJP03ool00?oonf[o
oo]Z00gooo]Z00?oo`00oookJ_oonfX05OoonfX00ooo003ooo]ZoookJP05ool001;ooo]Z00?oo`00
oookJ_oonfX0>_oonfX4o`00013ooo]Z00CoobP0oi<0oooo:03oobP00ooonfX00ooo:03oo`00ool0
0004oookJP;oobP0;ooonfX00ooo:03ooo]ZoookJP3ooookJQkooo]Z00?o0?l9oookJ_oonfX03Ooo
nfX00on`o`3ooo]ZoookJP0EoookJP03oonX0?oonf[ooo]Z00Cooo]Z00?oob40oookJ_oonfX04Ooo
nfX00ol0ol3ooo]ZoookJP0ioookJPCo00004?oonfX2oi<0o`Kooo]Z0_oo00001?ooV`3ooo]Zoook
J_oonfX2ob/0omOooo]Z001loookJP03ool00?oonf[ooo]Z00gooo]Z00?oo`00oookJ_oonfX05_oo
nfX00ooo003ooo]ZoookJP02ool000;ooo]Z00?oo`00oookJ_oonfX04?oonfX00ooo003ooo]Zoook
JP0ioookJPCo00004OoonfX00ooo:03oT`3ooi<0o`04oookJP;oobP00_oo0004oookJP;oobP0oooo
nfY>oookJP03o`3o2Ooonf[ooo]Z00gooo]Z00?o/?l0oookJ_oonfX05_oonfX00oooZ03ooo]Zoook
JP04oookJP03ool0]?oonf[ooo]Z013ooo]Z00?o0?o0oookJ_oonfX0>OoonfX4o`0001;ooo]Z0_nC
0?l6oookJP;oo`0000Cooi/0oookJ_oonf[ooo]Z0_l[0?oEoookJP00OOoonfX00ooo003ooo]Zoook
JP0=oookJP03ool00?oonf[ooo]Z01Gooo]Z00Coo`00oookJ_oonf[oo`000ooonfX00ooo003ooo]Z
oookJP0AoookJP03ool00?oonf[ooo]Z03Sooo]Z1?l0000BoookJP04oolX0?oonf[oT`3ooi<0o`Co
oo]Z0_oo:0000ooo003ooo]ZoookJP03oookJP;oobP0oooonfY=oookJP03o`3o2Ooonf[ooo]Z00go
oo]Z00?o/?l0oookJ_oonfX05OoonfX00oooZ03ooo]ZoookJP05oookJP03ool0]?oonf[ooo]Z013o
oo]Z00?o0?o0oookJ_oonfX0>?oonfX4o`0001Cooo]Z0_nC0?l5oookJP03onco0?oo003ooi/000Co
oo]Z0_l[0?oCoookJP00OOoonfX00ooo003ooo]ZoookJP0VoookJP03ool00?oonf[ooo]Z00Cooo]Z
00?oo`00oookJ_oonfX04?oonfX00ooo003ooo]ZoookJP0hoookJPCo00005_oonfX2oi<0o`Cooo]Z
00?oobP0ool00?oo00001OoonfX00ooo:03o:`3oob/0o`3ooookJT[ooo]Z00?o0?l9oookJ_oonfX0
9_oonfX00oooZ03ooo]ZoookJP04oookJP03ool0]?oonf[ooo]Z013ooo]Z00?o0?o0oookJ_oonfX0
>?oonfX4o`0001Kooo]Z0onC0?l4oookJP;oo`0000?ooi/0oookJ_oonfX00_oonfX3ob/0om3ooo]Z
001moookJP03ool00?oonf[ooo]Z02Oooo]Z00?oo`00oookJ_oonfX01?oonfX00ooo003ooo]Zoook
JP0@oookJP03ool00?oonf[ooo]Z03Oooo]Z1?l0000HoookJP;oT`3o1?oonfX00ooo:03oo`00ool0
0006oookJP?o:`3ooooonfY7oookJP03o`3o2Ooonf[ooo]Z02Oooo]Z00?oojP0oookJ_oonfX01?oo
nfX00ooo0;Cooo]ZoookJP0@oookJP03o`3o`?oonf[ooo]Z03Oooo]Z1?l0000IoookJP;oT`3o1?oo
nfX2ool00003oonK0?oonf[ooo]Z00?ooo]Z0ol[0?o=oookJP00O_oonfX00ooo003ooo]ZoookJP0V
oookJP03ool00?oonf[ooo]Z00Cooo]Z00?oo`00oookJ_oonfX04OoonfX00ooo003ooo]ZoookJP0f
oookJPCo00006_oonfX2oi<0o`Cooo]Z00?ok?l0ool00?oo00001ooo0003ob/0oooooo]ZAOoonfX0
0ol0o`Wooo]ZoookJP0VoookJP03oonX0?oonf[ooo]Z00Gooo]Z00?oo`2doookJ_oonfX04?oonfX0
0ol0ol3ooo]ZoookJP0foookJPCo00006ooonfX2oi<0o`Cooo]Z0ooo0006oookJP?o:`3ob_oonfX0
07kooo]Z00?oo`00oookJ_oonfX09ooonfX00ooo003ooo]ZoookJP04oookJP03ool00?oonf[ooo]Z
04Wooo]Z1?l0000LoookJP?oT`3o1?oonfX?ool00?oooo]Z@?oonfX00ol0o`Wooo]ZoookJP0Woook
JP03oonX0?oonf[ooo]Z00Gooo]Z00?oo`2doookJ_oonfX0B?oonfX4o`0001gooo]Z0_nC0?l5oook
JP?oo`001_oonfX4ob/0olKooo]Z001ooookJP03ool00?oonf[ooo]Z02Kooo]Z00?oo`00oookJ_oo
nfX01OoonfX00ooo003ooo]ZoookJP18oookJPCo00007ooonfX2oi<0o`?ooo]Z3Ooo0003ob/0oooo
oo]Z?ooonfX00ol0o`Wooo]ZoookJP0VoookJP03oonX0?oonf[ooo]Z00Gooo]Z00?oo`2doookJ_oo
nfX0B?oonfX4o`0001oooo]Z0_nC0?l5oookJP04onco0?oo003oo`00ool000Oooo]Z0ol[0?o3oook
JP00OooonfX00ooo003ooo]ZoookJP0WoookJP03ool00?oonf[ooo]Z00Cooo]Z00?oo`00oookJ_oo
nfX0B?oonfX4o`00027ooo]Z0_nC0?l3oookJP_oo`000ooonfX3ob/0oooooo]Z??oonfX00ol0o`Wo
oo]ZoookJP0WoookJP03oonX0?oonf[ooo]Z00Gooo]Z00?oo`2doookJ_oonfX0AooonfX4o`00027o
oo]Z0_nC0?l5oookJP;ok?l00ooo0007oookJPCo:`3o_ooonfX0083ooo]Z00?oo`00oookJ_oonfX0
;_oonfX00ooo003ooo]ZoookJP17oookJPGo00008_oonfX2oi<0o`;ooo]Z2_oo0006oookJP?o:`3o
oooonfXjoookJP03o`3o2Ooonf[ooo]Z02oooo]Z00?oo`2doookJ_oonfX0A_oonfX5o`0002;ooo]Z
0onC0?l5oookJP;ok?l00ooo0008oookJP?o:`3o_?oonfX0083ooo]Z00?oo`00oookJ_oonfX0;ooo
nfX00ooo003ooo]ZoookJP16oookJPCo00009OoonfX2oi<0o`;ooo]Z2_oo0007oookJP?o:`3o2Ooo
nfX9ool00?oooo]Z9OoonfX00ol0o`Wooo]ZoookJP0_oookJP03ool0]?oonf[ooo]Z04Kooo]Z1?l0
000VoookJP;oT`3o1OoonfX2onco0004oookJ_oo003oo`00ool000Sooo]Z0ol[0?nioookJP00P?oo
nfX00ooo003ooo]ZoookJP0_oookJP03ool00?oonf[ooo]Z04Kooo]Z1?l0000WoookJP;oT`3o00?o
oo]Zool00?oo00000ooo0002onco0003oookJ_oo003oo`0000;oo`001ooonfX00ol[0?ooo`00ool0
000?ool00?oooo]Z9OoonfX00ol0o`Wooo]ZoookJP0`oookJP03ool0]?oonf[ooo]Z04Gooo]Z1?l0
000XoookJP;oT`3o1OoonfX3onco0004oookJ_oo003oo`00ool000Sooo]Z1_l[0?ncoookJP00POoo
nfX00ooo003ooo]ZoookJP0_oookJP03ool00?oonf[ooo]Z04Gooo]Z1?l0000YoookJPWoo`000_o/
o`000ooonf[oo`00ool00002ool000Oooo]Z3ooo003ooookJRKooo]Z00?o0?l9oookJ_oonfX0<?oo
nfX00ooo0;Cooo]ZoookJP14oookJPCo0000:_oonfX3oi<0o`Gooo]Z0_o/o`02oookJP?oo`002ooo
nfX7ob/0ojcooo]Z002doookJP03ool00?oonf[ooo]Z04Cooo]Z1?l0000[oookJQ7oo`001ooonfX>
ool00?oooo]ZEooonfX00ooo0;Cooo]ZoookJP14oookJPCo0000;OoonfX3oi<0o`Cooo]Z0_o/o`03
oookJP?oo`003ooonfX7ob/0ojGooo]Z002doookJP03ool00?oonf[ooo]Z04Cooo]Z1?l0000/oook
JPkoo`0000?ooo]Zool00?oo00001?oonfX=ool000?ooo]Z1ooo003ooookJU7ooo]Z00?oo`2doook
J_oonfX0@ooonfX4o`00033ooo]Z0onC0?l3oookJP?ok?l00ooonfX00ooo003ooo]ZoookJP0Coook
JPOo:`3oW_oonfX00;Gooo]Z00?oo`00oookJ_oonfX0@ooonfX4o`0002kooo]Z8?oo000:oookJPCo
o`00oooonfY>oookJP03ool0]?oonf[ooo]Z04;ooo]Z1?l0000coookJP?oT`3o0ooonfX4onco01co
oo]Z0ol[0?nKoookJP00]OoonfX00ooo003ooo]ZoookJP13oookJPCo0000<?oonfX9ool000;ooo]Z
3_oo00000ooonf[oo`00ool00002ool00?oooo]ZG?oonfX00ooo0;Cooo]ZoookJP12oookJPCo0000
=_oonfX3oi<0o`Cooo]Z1_o/o`2doookJP00]_oonfX00ooo003ooo]ZoookJP12oookJPCo0000<Ooo
nfX7ool00004oookJ_oo003oo`00ool000;ooo]Z2ooo0004oookJP03ool00?oonf[ooo]Z0?oooo]Z
FooonfX00ooo0;Cooo]ZoookJP11oookJPCo0000>OoonfX3oi<0o`Oooo]Z1_o/o`2^oookJP00]ooo
nfX00ooo003ooo]ZoookJP11oookJPCo0000<ooonfX5ool000Cooo]Z0ooo00000ooonf[oo`00ool0
0006ool00003oookJ_oo003oo`0000?oo`00oooonfYNoookJP03ool0]?oonf[ooo]Z043ooo]Z1?l0
000loookJP?oT`3o2_oonfX5onco0:Wooo]Z002goookJP03ool00?oonf[ooo]Z02cooo]Z0ol007l5
oookJPGo001o2?oonfX4o`0003Gooo]Z0ooo0007oookJPWoo`001_oonfX6ool00?oooo]ZF?oonfX0
0ooo0;Cooo]ZoookJP0[oookJP?o001o1OoonfX5o`00O`Sooo]Z1?l0000ooookJP?oT`3o3?oonfX6
onco0:?ooo]Z002hoookJP03ool00?oonf[ooo]Z02_ooo]Z0ol007l4oookJPOo001o1ooonfX4o`00
03Kooo]Z00?oo`00oookJ_oonfX02OoonfX6ool000cooo]Z0ooo003ooookJUKooo]Z00?oo`2doook
J_oonfX0:_oonfX3o`00O`Cooo]Z1ol007l7oookJPCo0000@_oonfX3oi<0o`oooo]Z0oo/o`2Poook
JP00^OoonfX00ooo003ooo]ZoookJP0ZoookJP?o001o1?oonfX3o`00O`04oookJ_l007oo001oo`00
O`Oooo]Z1?l00015oookJP?oo`00oooonfYVoookJP03ool0]?oonf[ooo]Z02Wooo]Z0ol007l4oook
JP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`0004Gooo]Z0_nC0?n`oookJP00i_oonfX3o`00
O`?ooo]Z0ol007l3oookJP?o001o1_oonfX4o`000?oooo]Zf_oonfX3o`00O`?ooo]Z0ol007l3oook
JP?o001o1_oonfX4o`000?Oooo]Z003VoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPKo
0000oooonf[HoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPKo0000mOoonfX00>Kooo]Z
0ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0003ooookJ][ooo]Z0ol007l3oookJP?o001o
0ooonfX3o`00O`Kooo]Z1?l0003goookJP00i_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1_oo
nfX4o`000?oooo]Zf_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX4o`000?Oooo]Z003V
oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000oooonf[JoookJP?o001o0ooonfX3
o`00O`?ooo]Z0ol007l6oookJPCo0000mooonfX00>Kooo]Z0ol007l3oookJP?o001o0ooonfX3o`00
O`Kooo]Z1?l0003ooookJ][ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0003goook
JP00hooonfX6o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX4o`000?oooo]ZeooonfX6o`00O`?o
oo]Z0ol007l3oookJP?o001o1_oonfX4o`000?Oooo]Z003SoookJPKo001o1?oonfX3o`00O`04oook
J_l007oo001oo`00O`Oooo]Z1?l0003ooookJ]Oooo]Z1_l007l4oookJP?o001o00Cooo]Zo`00Ool0
07oo001o1ooonfX4o`000?Oooo]Z003UoookJPCo001o1?oonfX7o`00O`Oooo]Z1?l0003ooookJ]Wo
oo]Z1?l007l4oookJPOo001o1ooonfX4o`000?Oooo]Z003VoookJP?o001o1OoonfX5o`00O`Sooo]Z
1?l0003ooookJ][ooo]Z0ol007l5oookJPGo001o2?oonfX4o`000?Oooo]Z003koookJPCo0000oooo
nf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`00
0?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z
1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX5o`000?oooo]Zk_oonfX5o`000?Kooo]Z003k
oookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goook
JP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000
mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4
o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oo
oo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooo
nf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`00
0?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z
1Ol0003ooookJ^kooo]Z1Ol0003foookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003k
oookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goook
JP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000
mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4
o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oo
oo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooo
nf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`00
0?oooo]ZkooonfX4o`000?Oooo]Z003koookJPGo0000oooonf[^oookJPGo0000m_oonfX00?_ooo]Z
1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003k
oookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goook
JP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000
mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4
o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oo
oo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooo
nf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX5o`00
0?oooo]Zk_oonfX5o`000?Kooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z
1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003k
oookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goook
JP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000
mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4
o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00>Kooo]Z0ol007l5oookJPGo
001o2?oonfX4o`000?oooo]Zf_oonfX3o`00O`Gooo]Z1Ol007l8oookJPCo0000mooonfX00>Kooo]Z
0ol007l4oookJPOo001o1ooonfX4o`000?oooo]Zf_oonfX3o`00O`Cooo]Z1ol007l7oookJPCo0000
mooonfX00>Kooo]Z0ol007l3oookJPCo001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`000?oooo]Z
f_oonfX3o`00O`?ooo]Z1?l007l01?oonf[o001oo`00Ool007l7oookJPCo0000mooonfX00>Kooo]Z
0ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0003ooookJ][ooo]Z0ol007l3oookJP?o001o
0ooonfX3o`00O`Kooo]Z1?l0003goookJP00i_oonfX3o`00O`Wooo]Z0ol007l6oookJPKo0000oooo
nf[HoookJP?o001o2OoonfX3o`00O`Kooo]Z1_l0003eoookJP00i_oonfX3o`00O`Wooo]Z0ol007l6
oookJPCo0000oooonf[JoookJP?o001o2OoonfX3o`00O`Kooo]Z1?l0003goookJP00i_oonfX3o`00
O`Cooo]Z0_l007l2oookJPCo001o1_oonfX4o`000?oooo]Zf_oonfX3o`00O`Cooo]Z0_l007l2oook
JPCo001o1_oonfX4o`000?Oooo]Z003VoookJP?o001o1?oonfX7o`00Oooooo]ZiOoonfX3o`00O`Co
oo]Z1ol007oooookJP?ooo]Z003VoookJP?o001o1?oonfX6o`00Oooooo]Zi_oonfX3o`00O`Cooo]Z
1_l007oooookJPCooo]Z003SoookJPKo001o1?oonfX2o`00Oooooo]ZiooonfX6o`00O`Cooo]Z0_l0
07oooookJPSooo]Z003SoookJPKo001o1?oonfX2o`00Oooooo]ZiooonfX6o`00O`Cooo]Z0_l007oo
oookJPSooo]Z003UoookJPCo001o1OoonfX7o`00Oooooo]ZhooonfX4o`00O`Gooo]Z1ol007oooook
JP;ooo]Z003VoookJP?o001o1OoonfX7o`00Oooooo]Zi?oonfX3o`00O`Gooo]Z1ol007oooookJP;o
oo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[o
oookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Z
oooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX0
0?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]Z
jooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooook
J_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooo
nf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oook
JP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooo
nf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oo
oo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003o
oookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_o
oo]Z0000\
\>"],
  ImageRangeCache->{{{0, 999}, {999, 0}} -> {-0.0500105, -0.0500105, \
0.00210213, 0.00210213}, {{23.75, 476.812}, {975.188, 522.125}} -> {-1.17208, \
-1.15742, 0.00462332, 0.00462332}, {{522.125, 975.188}, {975.188, 522.125}} -> \
{-3.47623, -1.15742, 0.00462332, 0.00462332}, {{23.75, 476.812}, {476.812, \
23.75}} -> {-17.9973, -53.1523, 0.070991, 0.070991}, {{522.125, 975.188}, \
{476.812, 23.75}} -> {-53.3774, -53.1523, 0.070991, 0.070991}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
In this final example, the eigenvalues are pure imaginary, and the \
system of equations exhibit stable orbits around a fixed point. The \
eigenvectors are complex and and there are no directions along which the \
system will evolve along a straight trajectory.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CritPointPlotPointsMany[\(-0.25\), \(-2.0\), 2, 0.25]\)], "Input",
  CellTags->"mmtag:25:fixed_point__circulation_node_visualization"],

Cell[BoxData[
    \("Stable Orbits about Fixed Point"\)], "Print"],

Cell[BoxData[
    \("Circulation"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Eigenvalues = "\[InvisibleSpace]\(1.984313483298443`\
\ \[ImaginaryI]\)\[InvisibleSpace]" and \
"\[InvisibleSpace]\(\(-1.984313483298443`\)\ \[ImaginaryI]\)\),
      SequenceForm[ "Eigenvalues = ", 
        Complex[ 0, 1.984313483298443], " and ", 
        Complex[ 0, -1.984313483298443]],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{\(-4.316143927509186`*^-17\) + 
          1.984313483298443`\ \[ImaginaryI], \(-4.316143927509186`*^-17\) - 
          1.984313483298443`\ \[ImaginaryI]}, {{\(\(0.7071067811865475`\)\(\
\[InvisibleSpace]\)\) + 0.`\ \[ImaginaryI], \(-0.08838834764831842`\) - 
            0.701560760020114`\ \[ImaginaryI]}, {\(\(0.7071067811865475`\)\(\
\[InvisibleSpace]\)\) + 0.`\ \[ImaginaryI], \(-0.08838834764831842`\) + 
            0.701560760020114`\ \[ImaginaryI]}}}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 1000 1000 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto fill
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto
-15. 3.75 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -13.4688 -20 ]
[0 .4875 13.4688 0 ]
[.125 .4875 -25.9688 -20 ]
[.125 .4875 25.9688 0 ]
[.25 .4875 -20.9688 -20 ]
[.25 .4875 20.9688 0 ]
[.375 .4875 -25.9688 -20 ]
[.375 .4875 25.9688 0 ]
[.625 .4875 -19.5 -20 ]
[.625 .4875 19.5 0 ]
[.75 .4875 -14.5 -20 ]
[.75 .4875 14.5 0 ]
[.875 .4875 -19.5 -20 ]
[.875 .4875 19.5 0 ]
[1 .4875 -7 -20 ]
[1 .4875 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .125 -51.9375 -10 ]
[.4875 .125 0 10 ]
[.4875 .25 -41.9375 -10 ]
[.4875 .25 0 10 ]
[.4875 .375 -51.9375 -10 ]
[.4875 .375 0 10 ]
[.4875 .625 -39 -10 ]
[.4875 .625 0 10 ]
[.4875 .75 -29 -10 ]
[.4875 .75 0 10 ]
[.4875 .875 -39 -10 ]
[.4875 .875 0 10 ]
[.4875 1 -14 -10 ]
[.4875 1 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 .5 m
.125 .50625 L
s
gsave
.125 .4875 -86.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.25 .5 m
.25 .50625 L
s
gsave
.25 .4875 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.375 .5 m
.375 .50625 L
s
gsave
.375 .4875 -86.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.625 .5 m
.625 .50625 L
s
gsave
.625 .4875 -80.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.75 .5 m
.75 .50625 L
s
gsave
.75 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.875 .5 m
.875 .50625 L
s
gsave
.875 .4875 -80.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .125 m
.50625 .125 L
s
gsave
.4875 .125 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.5 .25 m
.50625 .25 L
s
gsave
.4875 .25 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .375 m
.50625 .375 L
s
gsave
.4875 .375 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.5 .625 m
.50625 .625 L
s
gsave
.4875 .625 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.5 .75 m
.50625 .75 L
s
gsave
.4875 .75 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .875 m
.50625 .875 L
s
gsave
.4875 .875 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.01 w
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.141 1 0 r
.5 Mabswid
1 0 0 r
% Start of user PostScript
1.4813326 -5.1363763 2.4360207 -4.8688276 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
3.2951048 -4.410197 4.0248694 -3.7784839 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.974482 2.8385834 3.2337812 3.6430719 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-3.4274844 4.3156512 -4.1325781 3.6571427 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-3.8603215 -2.9823265 -3.0961358 -3.7648817 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
3.5560616 -4.2163177 4.2357023 -3.5317444 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3.7418784 3.122761 2.9550557 3.8825149 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3.6806938 4.1123067 -4.3341275 3.402428 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-3.6192841 -3.2597311 -2.8106972 -3.9958409 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
3.8012426 -4.0037336 4.4277444 -3.269337 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
3.4926747 3.393085 2.6632207 4.1047339 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-3.9175745 3.8907188 -4.5164493 3.132619 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3.3621905 -3.5226747 -2.5127896 -4.2090732 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4.0295602 -3.7733878 4.6001438 -2.9924258 MAarrowhead1
% End of user PostScript
0 .535 1 r
1 0 0 r
% Start of user PostScript
-5.0648138 -6.1572604 -3.6162495 -7.1956882 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-2.0257619 -7.9517142 -0.35577129 -8.3956674 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
8.3023861 -2.9107504 8.5116055 -1.2763232 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.7492311 8.0486636 0.072272007 8.4381784 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-8.3606484 2.6426705 -8.5140127 0.99526955 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1.4707598 -8.1366841 0.21130745 -8.4713282 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
8.4096356 -2.3716589 8.5069746 -0.7131118 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1.1906569 8.2156778 -0.49465248 8.4950801 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8.4492932 2.0980162 -8.490499 0.43016294 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-0.9092331 -8.2855572 0.77744876 -8.5094077 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
8.4795774 -1.822046 8.4646042 -0.14673686 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
0.6268006 8.3462448 -1.0593825 8.5142951 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-8.5004545 1.5440544 -8.429319 -0.136852 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-0.34367273 -8.3976732 1.3401411 -8.509737 MAarrowhead1
% End of user PostScript
.544 1 0 r
1 0 0 r
% Start of user PostScript
0.85363896 -5.9579588 1.9994741 -5.8194097 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
3.066838 -5.4524722 4.0138408 -4.8715471 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
5.0574074 2.4946056 4.3369055 3.5124674 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-3.235287 5.3693834 -4.1582918 4.7545561 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-4.9496485 -2.6734457 -4.1984037 -3.6708292 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
3.4001468 -5.2803379 4.2981296 -4.6322903 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
4.8363985 2.8493199 4.0552443 3.8251186 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3.5612346 5.1854346 -4.4331992 4.5048857 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-4.7177831 -3.0220332 -3.907586 -3.9751646 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
3.7183716 -5.0847786 4.5633506 -4.3724834 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
4.5939339 3.1913938 3.7555928 4.1208005 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-3.8713835 4.9784816 -4.6884396 4.2352303 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4.4649883 -3.357214 -3.5994331 -4.2618649 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4.0201005 -4.8666616 4.8083273 -4.0932787 MAarrowhead1
% End of user PostScript
1 0 .015 r
1 0 0 r
% Start of user PostScript
-6.6534691 -4.1271207 -5.537643 -5.4706148 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-4.2044866 -6.5994094 -2.7063212 -7.4692037 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
7.2503193 -4.9585641 7.913193 -3.543848 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
3.9629975 6.7645662 2.4427534 7.58724 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-7.3823163 4.7332541 -7.9945548 3.2911369 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-3.7171119 -6.9222184 -2.1764758 -7.6968591 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
7.5061236 -4.5026932 8.0670475 -3.0347747 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3.4671026 7.0721914 1.9077835 7.7979395 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7.6216037 4.267137 -8.1305907 2.7750457 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-3.2132469 -7.2143185 -1.6369749 -7.890369 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
7.7286285 -4.026847 8.1851141 -2.5122382 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
2.9558266 7.3484422 1.3643502 7.9740451 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-7.8270794 3.7820896 -8.230557 2.2466437 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2.6951271 -7.4744137 -1.0902119 -8.0488749 MAarrowhead1
% End of user PostScript
.428 0 1 r
1 0 0 r
% Start of user PostScript
-3.5934854 8.0142465 -5.0260731 7.3420371 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-6.2614076 6.3816823 -7.2510071 5.1708721 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-5.5382098 -5.6124041 -4.1768561 -6.7420505 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
6.4458708 -6.1947478 7.3901272 -4.9463121 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
5.3235147 5.8187349 3.9307103 6.9067992 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-6.6231832 6.000941 -7.5210489 4.7162647 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-5.1029138 -6.0186106 -3.6802039 -7.0638856 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6.7931479 -5.8004768 7.6436268 -4.4809852 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
4.8766519 6.2118092 3.4256147 7.2131355 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-6.9555764 5.5935777 -7.7577251 4.2407346 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-4.6449798 -6.3981167 -3.1672252 -7.3543832 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
7.1102885 -5.3804732 7.8632171 -3.9957793 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4.4081548 6.5773261 2.9053221 7.4874722 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-7.2571126 5.1613997 -7.9599857 3.7463912 MAarrowhead1
% End of user PostScript
.101 1 0 r
1 0 0 r
% Start of user PostScript
-7.765618 2.0416627 -7.8260226 0.50935519 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-7.5792874 -1.0429425 -7.0350957 -2.5543088 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.1320325 -7.7521555 3.5775204 -7.3689559 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
7.508275 1.3011465 6.9159378 2.7997495 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-2.3821135 7.7088178 -3.8078722 7.2757036 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-7.428933 -1.557907 -6.7891076 -3.0420841 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2.6295518 -7.656928 4.0339996 -7.1743798 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
7.3413495 1.8129392 6.6547456 3.2810439 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2.8740729 7.5965437 -4.2556517 7.0650968 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-7.2456217 -2.0659602 -6.513001 -3.5163637 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
3.1154056 -7.527732 4.4725827 -6.9479759 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
7.1418557 2.3166892 6.364031 3.7477826 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3.3532821 7.4505691 -4.6845519 6.8231471 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-7.0301666 -2.5648481 -6.2080009 -3.9750438 MAarrowhead1
% End of user PostScript
0 1 .096 r
1 0 0 r
% Start of user PostScript
-0.20510049 -9.3699497 1.6657342 -9.4595493 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
3.4711955 -9.1778996 5.1404264 -8.5360544 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
8.7540934 2.4948506 7.8691909 4.2472085 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-3.7627714 9.0948027 -5.4025285 8.394591 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-8.6287653 -2.7977747 -7.6892468 -4.5268103 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
4.050173 -9.0016162 5.6586372 -8.2438149 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
8.4938647 3.0975949 7.5007725 4.8013902 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4.3330814 8.8984434 -5.9084683 8.0838931 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8.3495411 -3.3939787 -7.3039769 -5.0706435 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
4.6111827 -8.7853988 6.1517446 -7.9150033 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
8.1959547 3.6865974 7.0990784 5.3342715 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-4.8841685 8.6626079 -6.3881963 7.7373327 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-8.0332758 -3.9751261 -6.8863043 -5.5919818 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
5.1517359 -8.5302069 6.6175611 -7.5510784 MAarrowhead1
% End of user PostScript
1 0 .819 r
1 0 0 r
% Start of user PostScript
-5.1380499 -4.5103793 -4.0134485 -5.5547727 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-2.7313353 -6.3811636 -1.3420283 -6.9571196 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
6.8202715 -3.4501151 7.202551 -2.1129812 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
2.50417 6.4960779 1.1021302 7.0274975 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-6.9036788 3.2337478 -7.2392601 1.8789137 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-2.2742265 -6.6037856 -0.86100942 -7.0900792 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
6.9794273 -3.013793 7.267938 -1.6427617 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2.0417601 6.7041671 0.61893344 7.1447953 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7.047433 2.7904947 -7.2885531 1.4047873 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-1.8070285 -6.7971112 -0.37617084 -7.1915851 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
7.1076204 -2.5641008 7.3010823 -1.1652545 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1.5702923 6.8825147 0.13299092 7.2303966 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-7.1599227 2.3348622 -7.3055119 0.92442889 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1.3318141 -6.9602828 0.11033655 -7.261187 MAarrowhead1
% End of user PostScript
0 1 .146 r
1 0 0 r
% Start of user PostScript
-6.6595571 -0.9728911 -6.1701744 -2.301151 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-5.4386372 -3.5391 -4.4936555 -4.6381536 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
4.342265 -5.8677547 5.3150759 -5.0355799 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
5.2940078 3.7345395 4.3166242 4.8058755 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-4.5185946 5.7433669 -5.4588513 4.8755088 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-5.1435052 -3.925836 -4.1348042 -4.968266 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
4.6899112 -5.6126076 5.5965708 -4.7100288 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4.9872966 4.1127773 3.9483971 5.1251447 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-4.856025 5.4756218 -5.7280816 4.5393237 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-4.8255551 -4.2951559 -3.7576097 -5.2763377 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
5.0167516 -5.3325614 5.8532377 -4.3635827 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
4.6584602 4.4727695 3.5626537 5.4216772 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-5.1719127 5.1835852 -5.9719004 4.1830008 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-4.4861974 -4.6454212 -3.3637453 -5.561002 MAarrowhead1
% End of user PostScript
.774 1 0 r
1 0 0 r
% Start of user PostScript
2.0085521 -0.34660132 1.9881197 0.050671137 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
1.8896615 0.44595496 1.7170418 0.82373685 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-0.71892981 1.9530861 -1.0750256 1.8204239 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.8657159 -0.51100714 -1.6812355 -0.8843704 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
0.78107192 -1.9360658 1.1310231 -1.7909678 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1.8397004 0.57549242 1.6435641 0.94402284 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-0.84234752 1.9168977 -1.1857659 1.7595249 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1.811644 -0.63933926 -1.6040693 -1.002628 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
0.90268863 -1.8956029 1.2391933 -1.72613 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
1.7815778 0.70247683 1.562795 1.0601209 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-0.96202832 1.8722053 -1.2912459 1.6908201 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1.7495352 -0.76483508 -1.519787 -1.1164377 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1.0203008 -1.8467306 1.341866 -1.6536345 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1.7155516 0.82634484 1.475093 1.1715159 MAarrowhead1
% End of user PostScript
0 1 .213 r
1 0 0 r
% Start of user PostScript
0.41923718 8.6994264 -1.3278915 8.8280771 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-3.0229058 8.6102615 -4.5992833 8.0545277 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-8.2459842 -2.1051322 -7.4611051 -3.7545022 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
3.297558 -8.540145 4.8477931 -7.9294751 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
8.1361512 2.3895821 7.2996378 4.0186122 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-3.5685518 8.4605543 -5.0909249 7.7956256 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-8.0172921 -2.671381 -7.1300724 -4.2782641 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3.8355868 -8.3715776 5.328409 -7.6531279 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
7.8895388 2.9502163 6.9525971 4.5331697 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-4.0983667 8.2733136 -5.5599818 7.5021399 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-7.7530329 -3.2257787 -6.7674087 -4.7830463 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
4.3565999 -8.1658714 5.7853864 -7.3428291 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
7.607926 3.4977625 6.5747126 5.0276167 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-4.61 8.0493701 -6.0043729 7.1753724 MAarrowhead1
% End of user PostScript
0 .028 1 r
1 0 0 r
% Start of user PostScript
-4.8992404 1.1067113 -4.9013164 0.13905046 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-4.7110355 -0.83406759 -4.3358655 -1.7744518 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.512453 -4.8387967 2.4066314 -4.5635133 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
4.6606597 0.99523523 4.2557069 1.9264505 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-1.6676874 4.8056481 -2.5483779 4.4993483 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-4.6051134 -1.1552988 -4.1708271 -2.076312 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1.8210716 -4.7671681 2.6872972 -4.4301918 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4.5444582 1.3140807 4.0813203 2.2238701 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-1.9724356 4.7233995 -2.8232353 4.3561205 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-4.4787616 -1.4714047 -3.9872857 -2.3689611 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
2.1216115 -4.6743909 2.9560413 -4.2772166 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
4.4080963 1.6270964 3.8888277 2.5114239 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2.2684336 4.6201966 -3.085568 4.1935677 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-4.3325407 -1.7809831 -3.7860555 -2.6511007 MAarrowhead1
% End of user PostScript
0 1 .037 r
1 0 0 r
% Start of user PostScript
9.3723063 9.1784175 7.1319601 11.088451 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
4.6117132 12.563308 1.9104752 13.545106 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-13.318611 6.0209085 -13.922771 3.4060212 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-4.1681052 -12.763849 -1.4467442 -13.658552 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
13.45744 -5.5957782 13.970958 -2.9510907 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
3.7198731 12.95023 0.98140818 13.756845 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-13.581339 5.16444 -14.003646 2.4928862 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3.2675143 -13.122244 -0.51498342 -13.839876 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
13.690171 -4.7273724 14.020799 -2.0319162 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
2.8115306 13.2797 0.047987351 13.907554 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-13.783816 4.2850604 -14.022397 1.568692 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-2.3524278 -13.422424 0.41906196 -13.959803 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
13.862169 -3.8379946 14.008439 -1.1037276 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1.8907152 13.550258 -0.88564636 13.996565 MAarrowhead1
% End of user PostScript
1 .885 0 r
1 0 0 r
% Start of user PostScript
8.4113447 -7.9698603 9.6209148 -6.3401586 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
10.452903 -4.4616312 10.874657 -2.4080028 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.0054392 10.046343 0.87571102 10.695868 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-10.553006 4.1270139 -10.903824 2.0517515 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-2.6539462 -10.183803 -0.51253321 -10.764206 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
10.641402 -3.7878181 10.920895 -1.693224 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2.299509 10.309965 0.1487868 10.820603 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-10.717993 3.4444202 -10.925851 1.332818 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-1.9425207 -10.42469 0.21512467 -10.864996 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
10.782693 -3.0972011 10.918686 -0.97093348 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
1.5833775 10.527849 -0.57879749 10.897335 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-10.835431 2.746546 -10.899408 0.6079718 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1.2224777 -10.619329 0.9418282 -10.917585 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
10.876149 -2.392844 10.868038 -0.24433565 MAarrowhead1
% End of user PostScript
0 1 .739 r
1 0 0 r
% Start of user PostScript
5.5528756 3.9722053 4.5167612 5.0962148 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
3.303382 6.0202184 1.9603585 6.7079527 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-6.5381111 3.9871466 -7.0396381 2.7088748 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-3.0856147 -6.1530198 -1.7258866 -6.7981783 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
6.6408849 -3.7822056 7.0971229 -2.4824453 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
2.8644242 6.2789952 1.4895 6.880862 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-6.7362913 3.5730687 -7.1467342 2.2532619 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2.640056 -6.3980048 -1.251461 -6.9559123 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
6.8242247 -3.359968 7.1884171 -2.0215786 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
2.412759 6.5099165 1.0120337 7.0232457 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-6.9045874 3.1431397 -7.2221253 1.7876527 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-2.1827852 -6.6146062 -0.7714836 -7.0827878 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
6.9772902 -2.9228245 7.2478214 -1.5517436 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1.95039 6.7119579 0.53007766 7.1344723 MAarrowhead1
% End of user PostScript
1 .142 0 r
1 0 0 r
% Start of user PostScript
8.8878511 -3.8312166 9.2539287 -2.0852619 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
9.2568269 -0.25746911 8.8964319 1.5804283 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.0607807 9.3005649 -2.8615492 9.1382847 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-9.2214951 -0.052308337 -8.8011212 -1.8848006 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
1.3679245 -9.2988226 3.1546914 -9.0755069 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
9.1759331 0.36202775 8.6960467 2.187082 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1.6735508 9.2867644 -3.444334 9.0026609 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-9.1201915 -0.67134554 -8.581325 -2.486937 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
1.9773205 -9.2644037 3.7301554 -8.9198276 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
9.0543321 0.97991856 8.4570833 2.7840331 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-2.2788966 9.2317651 -4.0118387 8.8270987 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-8.9784281 -1.2874045 -8.3234594 -3.0780407 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2.5779445 -9.1888851 4.2890713 -8.7245773 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
8.8925635 1.5934622 8.1806017 3.3686335 MAarrowhead1
% End of user PostScript
1 .98 0 r
1 0 0 r
% Start of user PostScript
-6.6116151 -7.3841962 -4.8505011 -8.7363544 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-2.8990245 -9.7456459 -0.83377291 -10.37246 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
10.234797 -3.9869016 10.571924 -1.9741337 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
2.5581302 9.8784391 0.48164983 10.438213 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-10.320002 3.6578766 -10.587966 1.6264642 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-2.214398 -10.000273 -0.12899243 -10.492387 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
10.393757 -3.3247937 10.592262 -1.2769903 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1.8682092 10.111014 -0.22380808 10.53492 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-10.455983 2.9880224 -10.584808 0.92609971 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-1.5199478 -10.210537 0.5763603 -10.565766 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
10.506608 -2.6479361 10.565611 -0.57418174 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1.1700002 10.298733 -0.92827312 10.58489 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-10.545578 2.3049123 -10.534693 0.22162678 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-0.81875466 -10.375503 1.2791561 -10.592272 MAarrowhead1
% End of user PostScript
1 .629 0 r
1 0 0 r
% Start of user PostScript
-7.3724319 3.447958 -7.7297342 2.0011041 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-7.7836756 0.47571485 -7.5321391 -1.0683443 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
0.63073287 -7.7921159 2.1509071 -7.7074179 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
7.7626675 -0.21617988 7.460498 1.3250582 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-0.88928698 7.7993163 -2.3993967 7.6632837 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-7.7330477 -0.043594906 -7.3805804 -1.5803021 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1.1468545 -7.7978642 2.6452245 -7.610648 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
7.694849 0.30332133 7.2924749 1.8337928 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-1.4031498 7.7877614 -2.8881178 7.5495692 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-7.6481137 -0.56271126 -7.1962792 -2.0852492 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
1.6578884 -7.7690189 3.127807 -7.480115 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
7.5928938 0.82147692 7.0921002 2.3343922 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1.9107878 7.7416577 -3.3640262 7.4023625 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-7.5292505 -1.0793313 -6.9800533 -2.5809455 MAarrowhead1
% End of user PostScript
0 1 .422 r
1 0 0 r
% Start of user PostScript
3.5455434 -1.6029414 3.7063998 -0.90683366 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
3.7217949 -0.17513636 3.5911245 0.56343433 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-0.35432229 3.731551 -1.0799916 3.6806043 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-3.7099933 0.050848175 -3.5551529 -0.68602562 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
0.47789245 -3.7332447 1.1984044 -3.6577546 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
3.694076 0.073496423 3.5152371 0.80785584 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-0.60093244 3.7307967 -1.3154877 3.630847 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3.6740605 -0.19775948 -3.4714217 -0.92878984 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
0.72330577 -3.7242098 1.4311117 -3.5999115 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
3.6499691 0.32180316 3.4237551 1.0486935 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-0.84487667 3.7134914 -1.545148 3.5649822 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-3.6218285 -0.44548983 -3.3722903 -1.1674337 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
0.96551029 -3.6986533 1.6574702 -3.5260981 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3.5896698 0.56868228 3.3170843 1.2848788 MAarrowhead1
% End of user PostScript
0 .574 1 r
1 0 0 r
% Start of user PostScript
-2.8533979 -5.836222 -1.5669386 -6.4335897 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-0.21898321 -6.778465 1.1375664 -6.8573128 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
6.8623354 -0.96168515 6.7483184 0.3967793 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.0095831975 6.8104962 -1.3623352 6.8440971 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-6.8620162 0.73484537 -6.7029426 -0.62473824 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
0.23813898 -6.834972 1.5855926 -6.8232887 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
6.8540844 -0.50719036 6.6501307 0.85200411 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-0.46643057 6.8518651 -1.8070911 6.7949107 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6.8385488 0.27897268 -6.5899412 -1.0783248 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
0.69420471 -6.861157 2.0265847 -6.7589945 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
6.8154267 -0.050445519 6.522441 1.3034492 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-0.92120872 6.8628372 -2.2438302 6.71558 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-6.7847436 -0.17813761 -6.4477049 -1.5271276 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1.1471908 -6.8569039 2.4585863 -6.6647154 MAarrowhead1
% End of user PostScript
0 .692 1 r
1 0 0 r
% Start of user PostScript
-2.9212057 -0.32768254 -2.7262238 -0.90980544 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-2.4242487 -1.4562221 -2.0271315 -1.945488 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.8132874 -2.602264 2.249714 -2.2555481 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
2.3638528 1.5428967 1.9521994 2.0206144 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-1.8920211 2.5508741 -2.3147367 2.1882467 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-2.3008346 -1.6278597 -1.8751016 -2.0934992 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1.9686559 -2.4966544 2.3771914 -2.1185177 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2.2352638 1.7110167 1.7959236 2.1640614 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2.0431067 2.4396649 -2.4370089 2.0464385 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-2.1672133 -1.7922755 -1.7147532 -2.2322229 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
2.1152909 -2.3799689 2.4941228 -1.972089 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
2.0967585 1.8715461 1.6316805 2.2979081 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2.1851284 2.3176326 -2.5484698 1.8955517 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2.0239776 -1.9487403 -1.5467977 -2.3610439 MAarrowhead1
% End of user PostScript
0 .34 1 r
1 0 0 r
% Start of user PostScript
3.0922075 -8.5466873 4.6528723 -7.9768526 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
6.0309306 -7.0939586 7.1722992 -5.9326552 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
6.2888889 5.3022734 4.9557805 6.5794555 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-6.240397 6.9173537 -7.3373632 5.7135108 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-6.0810376 -5.5326724 -4.7113921 -6.7697576 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
6.4429404 -6.7330749 7.4942874 -5.4880279 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
5.8664401 5.7569335 4.4617771 6.9525494 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6.6383362 6.5413265 -7.6428975 5.2564567 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-5.6453346 -5.9748079 -4.2072122 -7.1276282 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
6.8263675 -6.3423213 7.7830287 -5.0190541 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
5.4179661 6.186054 3.9479799 7.2947997 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-7.0068257 6.1362801 -7.9145256 4.7760834 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-5.1845871 -6.3904374 -3.6843678 -7.4538786 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
7.1795108 -5.9234314 8.0372422 -4.5278143 MAarrowhead1
% End of user PostScript
.833 1 0 r
1 0 0 r
% Start of user PostScript
-1.0469308 -9.5210088 0.89134493 -9.7786592 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
2.794639 -9.6525367 4.5882548 -9.147591 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
9.3289097 1.7611544 8.5642295 3.6238976 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-3.1053605 9.5938772 -4.8735068 9.0268884 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-9.2254782 -2.0807013 -8.4019057 -3.9245596 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
3.4126371 -9.5245745 5.1533523 -8.8961716 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
9.1118122 2.39794 8.230261 4.2208678 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3.7161276 9.4447054 -5.4274807 8.7555856 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8.9880378 -2.7125183 -8.0494859 -4.5124934 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
4.0154956 -9.3543586 5.695588 -8.6052863 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
8.8542921 3.0240875 7.8597808 4.7991129 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-4.3104089 9.2536341 -5.9573767 8.4454404 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-8.7107237 -3.3323018 -7.6613562 -5.0804084 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4.6005403 -9.1426439 6.2125564 -8.2762253 MAarrowhead1
% End of user PostScript
.963 1 0 r
1 0 0 r
% Start of user PostScript
3.3105851 0.92342839 2.9799229 1.5860229 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
2.5323107 2.1863724 1.9853156 2.7009156 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.5645199 2.790983 -3.0050439 2.2959885 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-2.4468933 -2.2793327 -1.8852255 -2.7773889 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
2.6460195 -2.7150644 3.0678358 -2.203481 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
2.3587613 2.3697644 1.7830439 2.8507811 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2.7245836 2.6361338 -3.1272243 2.1085289 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2.2680126 -2.4575671 -1.6788842 -2.9210107 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
2.8001252 -2.5542786 3.1831436 -2.0112377 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
2.1747478 2.5426434 1.5728621 2.9879997 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-2.8725603 2.4695899 -3.2355315 1.9117153 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-2.0790703 -2.624899 -1.465095 -3.051674 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
2.9418087 -2.3821614 3.28433 -1.810072 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1.9810864 2.7042426 1.3557026 3.1119627 MAarrowhead1
% End of user PostScript
0 1 .57 r
1 0 0 r
% Start of user PostScript
6.1805693 4.7937878 4.9533078 6.0467969 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
3.5316489 7.0624937 1.971387 7.801016 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-7.6210366 4.3311244 -8.1427625 2.8394794 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-3.2778121 -7.2067521 -1.7001729 -7.8955916 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
7.7302119 -4.0910864 8.1993908 -2.5764979 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
3.020339 7.3430154 1.4270727 7.981408 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-7.8308115 3.8465098 -8.2469228 2.3106581 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2.7595152 -7.4711326 -1.1523893 -8.05837 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
7.9227237 -3.5976659 8.2853059 -2.0422549 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
2.49563 7.5909614 0.87642745 8.1263921 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-8.0058466 3.3448309 -8.3144974 1.7715861 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-2.2289763 -7.702369 -0.59949333 -8.185399 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
8.0800879 -3.0882852 8.334465 -1.4989519 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1.9598497 7.8052317 0.32189414 8.2353252 MAarrowhead1
% End of user PostScript
.434 0 1 r
1 0 0 r
% Start of user PostScript
-9.5234936 -5.8613563 -7.9354929 -7.7841369 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-6.036056 -9.4014215 -3.8997283 -10.649738 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
10.335317 -7.1106641 11.288635 -5.094209 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
5.6918137 9.6382591 3.5237335 10.819413 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-10.524896 6.7896389 -11.406001 4.7338427 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-5.341257 -9.8644041 -3.1438295 -10.977085 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
10.702799 -6.4610815 11.510714 -4.3682248 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4.9847748 10.079606 2.7604378 11.122579 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-10.868829 6.1253562 -11.602657 3.9977608 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-4.6227626 -10.283625 -2.3739837 -11.255734 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
11.022801 -5.7828356 11.681728 -3.6228618 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
4.2556219 10.476236 1.9848959 11.376402 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-11.164545 5.4338996 -11.74784 3.2439437 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3.8837602 -10.657225 -1.5936062 -11.484449 MAarrowhead1
% End of user PostScript
1 .64 0 r
1 0 0 r
% Start of user PostScript
-2.1644907 -1.3564015 -1.7987555 -1.7935357 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-1.3624265 -2.1602807 -0.87262768 -2.4422435 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.3713716 -1.6091618 2.5856667 -1.1463828 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.2834423 2.2138777 0.7865059 2.4804265 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-2.4141197 1.5354233 -2.6118631 1.0637663 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1.2030343 -2.2650186 -0.69951158 -2.5158578 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2.4541896 -1.4599815 2.635162 -0.97996964 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1.1212917 2.3136468 0.61174124 2.548498 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2.4915369 1.38292 -2.6555375 0.89508585 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-1.0383051 -2.3597082 -0.52329224 -2.578311 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
2.5261201 -1.3043243 2.672967 -0.80920906 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
0.95416668 2.4031518 0.43426271 2.6052636 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2.5579009 1.2242816 -2.6874312 0.72243456 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-0.8689697 -2.4439295 -0.34475142 -2.629326 MAarrowhead1
% End of user PostScript
1 0 .804 r
1 0 0 r
% Start of user PostScript
-6.260283 -2.7208254 -5.4413546 -3.978866 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-4.4088748 -5.0807521 -3.2033646 -5.9832391 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
5.7490196 -4.9985244 6.4865797 -3.88231 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
4.2173901 5.2472398 2.9873136 6.1125487 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-5.8894898 4.8237526 -6.5860793 3.678717 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-4.0212266 -5.4079064 -2.7679485 -6.2350771 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
6.0234263 -4.6436294 6.6782724 -3.4710429 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3.820602 5.5625735 2.5455128 6.3506885 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6.1506806 4.4583547 -6.7630568 3.2595181 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-3.615739 -5.7110696 -2.3202531 -6.4592545 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
6.2711113 -4.2681339 6.8403383 -3.0443773 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
3.4068647 5.85323 2.0924193 6.5606547 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-6.3845851 4.0731782 -6.9100313 2.825859 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3.1942109 -5.9888969 -1.8622643 -6.6547767 MAarrowhead1
% End of user PostScript
0 .283 1 r
1 0 0 r
% Start of user PostScript
0.15715847 -4.2187452 0.98839414 -4.2095128 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
1.7808393 -4.0350741 2.5033938 -3.7022749 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.8124173 1.3535662 3.3739799 2.1181122 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.907821 3.9899903 -2.6157722 3.6317261 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-3.7488727 -1.4864624 -3.2868554 -2.2390755 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
2.0326861 -3.9404802 2.7252487 -3.5571484 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3.6811693 1.6177094 3.1960845 2.3575548 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2.1552962 3.8865985 -2.8317019 3.4786244 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-3.609382 -1.7471618 -3.1017679 -2.4734187 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
2.2755153 -3.8284051 2.9350137 -3.3962413 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
3.5335906 1.874676 3.0040103 2.5865386 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-2.3932099 3.7659646 -3.0350694 3.3100905 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3.453879 -2.0001104 -2.9029201 -2.696789 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2.5082496 -3.6993461 3.1317581 -3.2202675 MAarrowhead1
% End of user PostScript
1 0 .673 r
1 0 0 r
% Start of user PostScript
-5.480966 0.71581995 -5.3795127 -0.36946188 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-5.0669353 -1.4402438 -4.555501 -2.454502 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.1740965 -5.2637256 3.1232879 -4.8591954 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
4.9945218 1.6155647 4.4514724 2.616349 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-2.3404509 5.2099154 -3.2715547 4.7720517 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-4.9165675 -1.7890933 -4.3425055 -2.7752936 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2.5042089 -5.1503253 3.4161922 -4.6796139 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4.8331589 1.9606372 4.2287211 2.9311593 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2.6651887 5.0850217 -3.5570398 4.5819847 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-4.7443884 -2.1300059 -4.1102454 -3.0837732 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
2.8232119 -5.0140767 3.6939413 -4.4792723 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
4.6503546 2.2970117 3.9872099 3.232966 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2.978103 4.9375693 -3.8267449 4.3715907 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-4.5511618 -2.4614692 -3.8597511 -3.3785722 MAarrowhead1
% End of user PostScript
1 .118 0 r
1 0 0 r
% Start of user PostScript
3.5332509 -8.7247411 5.1096848 -8.0682037 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
6.4855841 -7.0950218 7.6069504 -5.8433889 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
6.2251157 5.7603413 4.8038291 7.0272403 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-6.6929264 6.9031599 -7.7669533 5.6093299 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-6.0021919 -5.9902675 -4.5451322 -7.2140724 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
6.8928437 -6.7036398 7.9183398 -5.3690481 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
5.7726093 6.2135481 4.281393 7.3929013 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-7.0851141 6.4966828 -8.0609418 5.1228099 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-5.5366227 -6.4299356 -4.0129042 -7.5635287 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
7.2695245 -6.2825185 8.1946011 -4.8708886 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
5.2944939 6.6391899 3.7399635 7.7257652 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-7.4458703 6.0613845 -8.3191695 4.6135636 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-5.0464915 -6.8410787 -3.4628738 -7.8794309 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
7.6139557 -5.8335261 8.4345087 -4.3511204 MAarrowhead1
% End of user PostScript
.791 0 1 r
1 0 0 r
% Start of user PostScript
-4.0543946 7.2895347 -5.3224975 6.5219691 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-6.3817138 5.4984424 -7.1904736 4.2591241 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-4.6309525 -5.8301977 -3.2666614 -6.7807165 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
6.5359587 -5.3042538 7.2992776 -4.0332762 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
4.4132569 6.0068685 3.0235416 6.9150543 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-6.6829527 5.1041808 -7.3999838 3.8029538 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-4.1906652 -6.1768754 -2.7770675 -7.0417208 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6.8225328 -4.8984452 7.4924806 -3.5684126 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
3.9634245 6.3400298 2.5275126 7.1605752 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-6.9545441 4.6872755 -7.5766655 3.3299126 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-3.7317869 -6.4961506 -2.2751538 -7.2714859 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
7.0788402 -4.4709057 7.6524449 -3.0877184 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3.4960093 6.6450648 2.0202709 7.3743297 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-7.1952831 4.249576 -7.7197348 2.8420988 MAarrowhead1
% End of user PostScript
1 0 .108 r
1 0 0 r
% Start of user PostScript
-8.1257251 0.80667371 -7.9247396 -0.80362187 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-7.41274 -2.3823785 -6.6098201 -3.8676364 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.4581162 -7.7307379 4.840392 -7.083947 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
7.2975592 2.6398691 6.4485994 4.1035841 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-3.7011788 7.6428108 -5.0551779 6.9472673 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-7.1742826 -2.8944312 -6.2802246 -4.3349794 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3.9401354 -7.5464049 5.2643557 -6.8028805 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
7.043047 3.1457821 6.1048827 4.5615655 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-4.1747208 7.4416271 -5.4676934 6.6509467 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-6.903998 -3.3936432 -5.9227682 -4.7830911 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
4.4046749 -7.3285938 5.6649653 -6.4916345 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
6.7572898 3.6377395 5.7340831 4.9993105 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4.6297425 7.2074302 -5.8559526 6.3251206 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-6.6030852 -3.8778001 -5.5390366 -5.2099837 MAarrowhead1
% End of user PostScript
1 0 .342 r
1 0 0 r
% Start of user PostScript
-9.7816224 -0.52988427 -9.2414561 -2.4761581 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-8.3385999 -4.3252526 -7.1084873 -6.0045985 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
5.5481279 -8.8761768 7.0650706 -7.8200928 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
8.1538063 4.6208948 6.8731683 6.2650653 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-5.8197098 8.7222669 -7.2939978 7.6114199 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-7.959967 -4.9114107 -6.6302243 -6.5185817 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
6.0848355 -8.5586807 7.5148332 -7.394303 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
7.7572971 5.1964779 6.3799249 6.7648666 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6.3432107 8.3855996 -7.7273318 7.168983 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-7.5460214 -5.4757803 -6.1225477 -7.0036466 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
6.5945489 -8.2032157 7.9312579 -6.9357099 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
7.3263742 5.7490079 5.8583783 7.2346569 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-6.8385712 8.0117313 -8.1263851 6.6947424 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-7.0985993 -6.0158577 -5.5877097 -7.4576413 MAarrowhead1
% End of user PostScript
1 .525 0 r
1 0 0 r
% Start of user PostScript
-2.7724999 4.3147966 -3.5065439 3.7864226 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-4.1029702 3.1094468 -4.5383715 2.3104377 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.5484096 -3.7949164 -1.681097 -4.321044 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
4.1878511 -2.9830481 4.5943644 -2.166515 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
2.4089232 3.8942739 1.5280707 4.393205 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-4.268086 2.85334 -4.6452605 2.0201889 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2.2667645 -3.9893112 -1.3733493 -4.4604922 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4.343586 -2.7204665 4.6910031 -1.8716216 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
2.122091 4.0799228 1.2171042 4.522831 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-4.4142673 2.584575 -4.7315417 1.7209779 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-1.9750633 -4.1660082 -1.059509 -4.5801522 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
4.4800514 -2.4458161 4.7668311 -1.5684251 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1.8258445 4.2474719 0.90073833 4.6323924 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-4.5408655 2.304344 -4.7968324 1.4141322 MAarrowhead1
% End of user PostScript
0 1 .17 r
1 0 0 r
% Start of user PostScript
-2.8340786 3.2152153 -3.346909 2.6688738 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-3.7283867 2.0177897 -3.9635402 1.2875156 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.5017 -3.5367607 -0.73221629 -3.8535717 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
3.7784044 -1.8999895 3.9879285 -1.1591632 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
1.3758513 3.6000444 0.59938885 3.8921804 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-3.8242304 1.7800815 -4.0078925 1.0295249 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1.2484762 -3.6593342 -0.46589645 -3.9264712 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3.8658139 -1.6581986 4.0234103 -0.89874439 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
1.119716 3.7145645 0.33188719 3.956406 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-3.9031087 1.5344762 -4.0344646 0.76696687 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-0.98971372 -3.7656739 -0.19750975 -3.9819517 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
3.9360734 -1.4090515 4.0410431 -0.6343385 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
0.85861342 3.8126057 0.062913186 4.0030798 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3.9646716 1.2820636 -4.0431386 0.5010064 MAarrowhead1
% End of user PostScript
.942 0 1 r
1 0 0 r
% Start of user PostScript
1.65494 3.8498107 0.81644342 4.198701 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-0.054095283 4.3828092 -0.92251096 4.3949098 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-4.4091285 0.42460017 -4.2974658 -0.44923637 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
0.2009518 -4.3969515 1.0656483 -4.3799469 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
4.4024353 -0.27814924 4.2619719 0.59512093 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-0.34758539 4.4062159 -1.2076034 4.360125 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-4.3908582 0.13138973 -4.2217498 -0.74034527 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
0.49383337 -4.4105922 1.3482188 -4.335466 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
4.3744099 0.015515539 4.1768441 0.88474828 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-0.6395335 4.4100754 -1.4873386 4.3059974 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-4.3531087 -0.1624036 -4.1273048 -1.0281698 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
0.78452414 -4.4046661 1.6248083 -4.2717517 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4.3269782 0.30911148 4.0731867 1.1704506 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-0.92864445 4.3943705 -1.7604754 4.2327671 MAarrowhead1
% End of user PostScript
1 0 .255 r
1 0 0 r
% Start of user PostScript
-6.7367895 -6.8594691 -5.0743684 -8.2337626 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-3.2127989 -9.2849142 -1.2251399 -9.9716703 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
9.8152394 -4.2527467 10.22384 -2.3247268 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
2.885879 9.426562 0.8846106 10.049101 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-9.9113605 3.9387727 -10.253304 1.9900175 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-2.5557575 -9.5577522 -0.54309991 -10.115383 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
9.9964861 -3.620429 10.271393 -1.6531006 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2.2228008 9.6783392 0.20098671 10.170444 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-10.070522 3.2980689 -10.278088 1.3143498 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-1.8873781 -9.7881893 0.14134945 -10.214221 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
10.133385 -2.9720499 10.27338 -0.97414086 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1.5498616 9.8871805 -0.48352881 10.246667 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-10.185007 2.6427338 -10.257274 0.63285122 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1.2106257 -9.975203 0.82517175 -10.267746 MAarrowhead1
% End of user PostScript
1 0 .317 r
1 0 0 r
% Start of user PostScript
-7.6783508 7.1376563 -8.7551587 5.6492548 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-9.4883618 3.9391427 -9.849185 2.0744351 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.6164604 -9.1314283 -0.68581027 -9.6988976 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
9.5755093 -3.6349987 9.8720275 -1.7513903 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
2.2975252 9.2525006 0.3569989 9.7572319 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-9.6520338 3.3268222 -9.8839182 1.4264024 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1.9760413 -9.3633083 -0.027791483 -9.8047416 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9.7178506 -3.0149549 9.8848439 -1.0998322 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
1.6523651 9.4637285 -0.30144677 9.8413741 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-9.7728865 2.6997429 -9.8748035 0.7720418 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-1.3268559 -9.5536499 0.6303506 -9.8670888 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
9.8170806 -2.3815359 9.8538082 -0.44339493 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
0.99987466 9.6329726 -0.95855513 9.8818571 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-9.8503838 2.0606868 -9.8218812 0.11425616 MAarrowhead1
% End of user PostScript
0 .717 1 r
1 0 0 r
% Start of user PostScript
-9.220683 -6.5633547 -7.5066649 -8.4296295 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-5.4980405 -9.9650753 -3.2736401 -11.109432 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
10.826614 -6.6300875 11.662603 -4.5135113 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
5.1374344 10.185906 2.8851894 11.259765 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-10.997728 6.2908217 -11.758701 4.138478 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-4.7711288 -10.395437 -2.4935378 -11.397607 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
11.156642 -5.9445769 11.841754 -3.7588535 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4.3995303 10.593435 2.09912 11.522805 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-11.303179 5.5917373 -11.911671 3.3750591 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-4.0230511 -10.779681 -1.7023735 -11.635219 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
11.437176 -5.2326944 11.968372 -2.9875204 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
3.6421087 10.953969 1.3037384 11.734726 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-11.558485 4.8678464 -12.011796 2.5966675 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3.2571259 -11.116104 -0.90365691 -11.821214 MAarrowhead1
% End of user PostScript
0 1 .328 r
1 0 0 r
% Start of user PostScript
-6.6239076 5.494004 -7.4210178 4.206541 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-7.9268829 2.7539883 -8.1216498 1.1933526 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.6448076 -7.6873812 -0.0442743 -8.0542646 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
7.9816671 -2.4979418 8.1231245 -0.92508612 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
1.3789592 7.7705811 -0.22628569 8.0850768 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-8.0275966 2.2391241 -8.1155875 0.6557934 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1.111581 -7.8451605 0.49659465 -8.1069196 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
8.0646205 -1.9778223 8.0990472 -0.38577315 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
0.8429696 7.9110366 -0.76635269 8.1197687 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-8.0926976 1.7143264 -8.073522 0.11532493 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-0.57342305 -7.9681363 1.0352606 -8.1236098 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
8.1117968 -1.4489287 8.0390402 0.15525123 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
0.30324035 8.0163963 -1.3030199 8.1184388 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-8.121897 1.1819235 -7.99564 -0.42565516 MAarrowhead1
% End of user PostScript
0 .969 1 r
1 0 0 r
% Start of user PostScript
-8.5734285 -3.4262852 -7.5114915 -5.1476026 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-6.1547586 -6.6668973 -4.5564763 -7.9245432 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
7.5964876 -6.9313585 8.6359457 -5.4581468 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
5.9017395 6.8977627 4.2688356 8.1063398 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-7.7930591 6.7016121 -8.7781294 5.1881459 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-5.6421732 -7.1209759 -3.9764591 -8.2791433 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
7.9809851 -6.464431 8.9105749 -4.9123893 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5.3763475 7.3362891 3.6796712 8.4427621 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8.1600572 6.2200785 -9.0331351 4.631183 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-5.1045573 -7.5434637 -3.3788012 -8.5970147 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
8.3300766 -5.9688255 9.1456741 -4.344839 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
4.8271043 7.7422696 3.0741827 8.7417299 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-8.4908548 5.7109508 -9.2480671 4.0536749 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-4.5442962 -7.9324864 -2.7661538 -8.8767472 MAarrowhead1
% End of user PostScript
.745 0 1 r
1 0 0 r
% Start of user PostScript
-1.658976 -0.46858515 -1.492116 -0.80065009 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-1.2666964 -1.1012927 -0.99156408 -1.3587141 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.2905066 -1.3969229 1.5106864 -1.1477946 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.223713 1.1478206 0.94124708 1.3969441 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-1.3312653 1.358692 -1.5420368 1.1012661 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1.179372 -1.1930751 -0.88988587 -1.4336244 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1.3705471 -1.3189538 1.5716766 -1.0535158 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1.1337227 1.237006 0.83753744 1.4687143 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-1.4083084 1.2777524 -1.5995728 1.0045968 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-1.0868156 -1.2795645 -0.78425986 -1.5021747 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
1.4445074 -1.2351334 1.6256944 -0.95456325 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1.0387029 1.3207036 0.73011224 1.5339687 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1.4791038 1.1911443 -1.6500126 0.90347077 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-0.98943782 -1.3603775 -0.67515465 -1.564061 MAarrowhead1
% End of user PostScript
0 .388 1 r
1 0 0 r
% Start of user PostScript
4.2727721 2.180581 3.6495481 3.0409064 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
2.883094 3.7818885 2.00349 4.3744467 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-4.2224562 3.3189073 -4.6941629 2.4972495 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-2.742455 -3.8924326 -1.8471398 -4.4576236 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
4.3138002 -3.1892605 4.7556863 -2.3487777 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
2.5987736 3.9986585 1.6887403 4.5358552 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-4.4003585 3.0560757 -4.8119338 2.1977003 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2.4522092 -4.1004484 -1.5284674 -4.6090548 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
4.4820352 -2.9195005 4.8628431 -2.0441847 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
2.3029244 4.1976893 1.3664989 4.6771413 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-4.5587396 2.7796865 -4.9083576 1.8884014 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-2.1510847 -4.2902734 -1.2030143 -4.740039 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4.6303866 -2.6367887 4.9484268 -1.7305231 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1.9968587 4.3780979 1.0381952 4.7976782 MAarrowhead1
% End of user PostScript
1 0 .738 r
1 0 0 r
% Start of user PostScript
-4.6467747 -6.4918771 -3.150311 -7.4489891 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-1.5302103 -8.1137583 0.14994496 -8.4600952 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
8.3950108 -2.4290648 8.5044061 -0.77372283 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.2505945 8.1946641 -0.43320444 8.4858658 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-8.4366649 2.156122 -8.4899772 0.49108087 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-0.96959132 -8.2664788 0.71598334 -8.5022224 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
8.4689594 -1.8807873 8.4661296 -0.20789412 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
0.68751247 8.3291229 -0.99796793 8.5091469 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-8.4918586 1.603366 -8.4328899 -0.075523268 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-0.40467091 -8.3825269 1.2788454 -8.5066314 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
8.5053372 -1.324166 8.3902949 0.35885687 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
0.12138041 8.4266314 -1.5583041 8.4946788 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-8.50938 1.043497 -8.3383919 -0.64179236 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
0.16204474 -8.4613875 1.8360341 -8.4733024 MAarrowhead1
% End of user PostScript
1 .773 0 r
1 0 0 r
% Start of user PostScript
-3.0524562 -6.2549004 -1.6739596 -6.8940017 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-0.22976685 -7.2625412 1.2234433 -7.3460552 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
7.3517087 -1.0254703 7.2286081 0.42989526 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.015099309 7.296697 -1.4642093 7.3317366 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-7.3512058 0.78243642 -7.1798391 -0.6740962 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
0.25994871 -7.3227579 1.7033509 -7.3092842 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
7.3425476 -0.53853455 7.1231049 0.9175493 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-0.50450974 7.340695 -1.9406029 7.278723 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7.3257437 0.29403523 -7.0584685 -1.1599845 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
0.74851106 -7.3504886 2.175702 -7.240087 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
7.3008127 -0.049209713 6.9860016 1.4011328 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-0.99168201 7.3521276 -2.4083874 7.1934189 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-7.2677824 -0.19567039 -6.9057845 -1.6407268 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1.2337528 -7.3456104 2.638401 -7.1387706 MAarrowhead1
% End of user PostScript
1 0 .527 r
1 0 0 r
% Start of user PostScript
-5.5725601 9.5350141 -7.2193211 8.4775103 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-8.5827527 7.0872984 -9.6093459 5.4189386 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-5.918225 -7.8746398 -4.0904923 -9.091585 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
8.7798733 -6.8250148 9.7455895 -5.1161217 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
5.6257904 8.1019631 3.7658923 9.2619896 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-8.9672536 6.5551596 -9.8710215 4.8076291 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-5.3271147 -8.3202983 -3.4371144 -9.4221192 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
9.1446858 -6.2780323 9.9855028 -4.493803 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
5.0225292 8.5294031 3.1045235 9.571796 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-9.3119731 5.9939402 -10.088906 4.1749916 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-4.7123717 -8.7290456 -2.7684885 -9.710854 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
9.4689299 -5.7031986 10.181117 -3.8515485 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4.3969865 8.9190042 2.4293821 9.839139 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-9.615382 5.4061299 -10.262034 3.5238326 MAarrowhead1
% End of user PostScript
.159 0 1 r
1 0 0 r
% Start of user PostScript
6.0972891 -0.074684358 5.8410473 1.1363972 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
5.3555679 2.3028797 4.659904 3.3789834 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-3.0845972 5.6489003 -4.0698388 5.0654707 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-5.252828 -2.4910297 -4.5243484 -3.547701 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
3.2595551 -5.5659307 4.220533 -4.9473061 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
5.1442608 2.6764163 4.3837735 3.7124828 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-3.430897 5.4767863 -4.366545 4.823653 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5.0299866 -2.8588337 -4.2383353 -3.873146 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
3.5984326 -5.381566 4.5077128 -4.6946487 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
4.9101322 3.0380796 4.0881952 4.0295125 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-3.7619763 5.2803755 -4.6438799 4.5604362 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-4.7848307 -3.213955 -3.9335197 -4.1814087 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3.9213464 -5.1733271 4.7748951 -4.4211644 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4.6542209 3.386265 3.7744805 4.3286661 MAarrowhead1
% End of user PostScript
.852 1 0 r
1 0 0 r
% Start of user PostScript
0.66670916 -6.7121544 1.9707063 -6.6146782 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
3.1973611 -6.2576025 4.2985324 -5.6549412 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
5.8501742 2.5381279 5.085779 3.7137314 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-3.3922151 6.1730641 -4.4679264 5.5312465 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-5.7371884 -2.7437364 -4.9369641 -3.8979627 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
3.5833058 -6.0816774 4.6323637 -5.4014156 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
5.6178379 2.9463012 4.7826722 4.0778697 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3.7704213 5.9835439 -4.791662 5.2655924 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-5.492255 -3.1455974 -4.6230745 -4.2532528 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
3.9533539 -5.8787723 4.9456445 -5.1239277 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
5.3605791 3.3414039 4.458348 4.4239174 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-4.1319007 5.7674789 -5.0941404 4.9765786 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-5.2229564 -3.5335035 -4.2886756 -4.5896742 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4.3058637 -5.6497871 5.2369849 -4.8237086 MAarrowhead1
% End of user PostScript
1 .894 0 r
1 0 0 r
% Start of user PostScript
7.5161065 -9.7038856 9.1100119 -8.2610988 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
10.346386 -6.4940972 11.176706 -4.4722284 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
5.0688801 9.7168155 2.9128867 10.774608 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-10.515217 6.1704555 -11.273727 4.1133544 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-4.7186458 -9.9223372 -2.5373884 -10.911613 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
10.672383 -5.8399685 11.358241 -3.7499172 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
4.3631767 10.116851 2.1590751 11.036513 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-10.817709 5.5030026 -11.430154 3.3823199 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-4.0028671 -10.300142 -1.7783667 -11.149169 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
10.951034 -5.1599319 11.489386 -3.0109702 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
3.6381169 10.472006 1.3956853 11.249457 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-11.07221 4.8111368 -11.535873 2.6362803 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3.2693306 -10.632252 -1.0114556 -11.337264 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
11.181103 -4.4570044 11.569562 -2.2586657 MAarrowhead1
% End of user PostScript
1 0 .522 r
1 0 0 r
% Start of user PostScript
-8.9455567 8.3563477 -10.208167 6.6225182 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-11.070149 4.6287816 -11.497671 2.453384 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-3.0858533 -10.650109 -0.83258751 -11.31876 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
11.17293 -4.2740544 11.525403 -2.0763857 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
2.7137123 10.792467 0.44870654 11.387919 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-11.263317 3.9145856 -11.540348 1.697084 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2.3385607 -10.922851 -0.064327796 -11.444444 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
11.341208 -3.550774 11.54249 -1.3158996 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
1.9608147 11.041118 -0.32012232 11.488273 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-11.406518 3.1830233 -11.531828 0.93325529 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-1.5808935 -11.147137 0.70421729 -11.519358 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
11.459173 -2.8117414 11.508372 -0.54957567 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1.1992185 11.240788 -1.087531 11.537662 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-11.499116 2.4373402 -11.47215 0.16528637 MAarrowhead1
% End of user PostScript
1 0 .405 r
1 0 0 r
% Start of user PostScript
-9.3527455 -6.8629306 -7.5733333 -8.7570067 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-5.4966982 -10.307406 -3.2043399 -11.45328 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
11.171411 -6.6661574 11.999238 -4.4812614 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
5.1246078 10.529438 2.8046767 11.602539 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-11.342098 6.3154494 -12.092654 4.0948112 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-4.7468322 -10.739789 -2.4019021 -11.738927 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
11.500203 -5.9577351 12.172655 -3.7038183 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4.3637906 10.938225 1.9964629 11.862291 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-11.645549 5.5934115 -12.239152 3.3087164 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-3.9759079 -11.124527 -1.5888088 -11.972496 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
11.777976 -5.2228826 12.292071 -2.909944 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
3.5836144 11.298488 1.1793921 12.069419 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-11.897337 4.8465596 -12.331354 2.5079432 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3.1873453 -11.459914 -0.76866704 -12.152952 MAarrowhead1
% End of user PostScript
0 1 .174 r
1 0 0 r
% Start of user PostScript
-5.0350684 4.0374108 -5.6134066 3.0580408 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-5.9714411 1.958655 -6.0951207 0.78239987 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.1221918 -5.803698 0.080837195 -6.0569226 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
6.0088184 -1.765349 6.0924282 -0.58065965 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
0.92205384 5.8624971 -0.28376002 6.0762629 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-6.0395296 1.5700846 -6.0829769 0.37827525 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-0.72089293 -5.9147925 0.48636804 -6.0888623 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
6.0635407 -1.3730784 6.0667773 -0.17547121 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
0.51893228 5.9605262 -0.68843649 6.0947067 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-6.0808249 1.1745488 -6.0438473 -0.027527507 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-0.31639593 -5.9996473 0.88974121 -6.0937899 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
6.0913633 -0.97471632 6.0142123 0.23049568 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
0.11350858 6.0321126 -1.0900589 6.0861127 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-6.0951439 0.77380245 -5.9779053 -0.43320815 MAarrowhead1
% End of user PostScript
1 .331 0 r
1 0 0 r
% Start of user PostScript
2.8462006 -4.3931337 3.5925328 -3.8505245 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
4.1978725 -3.1567977 4.6384627 -2.3391793 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.5825928 3.8853794 1.6957863 4.4187705 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-4.2838919 3.0273859 -4.6949449 2.1920017 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-2.4399076 -3.9862137 -1.53941 -4.4917804 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
4.3651589 -2.8946156 4.7462186 -2.0423922 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2.2945156 4.0826258 1.3813259 4.5598071 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4.4415832 2.758634 -4.7922269 1.890517 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2.1465781 -4.1745086 -1.2217094 -4.6227753 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
4.5130801 -2.6195921 4.8329189 -1.7365445 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
1.9962592 4.2617604 1.0607375 4.680615 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-4.5795702 2.477644 -4.8682493 1.5806454 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1.8437257 -4.3442842 -0.8985889 -4.7332622 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4.6409799 -2.3329473 4.8981789 -1.4229929 MAarrowhead1
% End of user PostScript
1 .408 0 r
1 0 0 r
% Start of user PostScript
7.0122013 3.976708 5.9103117 5.3906946 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
4.5764661 6.593118 3.0630127 7.5367882 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-7.2970324 5.3327445 -8.0321753 3.9106976 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-4.3334211 -6.7707378 -2.795482 -7.6670433 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
7.4413673 -5.1072289 8.1252855 -3.6553284 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
4.0855687 6.9408462 2.5248501 7.7887927 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-7.5774469 4.8760475 -8.2093816 3.3959042 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3.8331838 -7.1032546 -2.2514171 -7.9019014 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
7.7051202 -4.6394567 8.2843704 -3.1327125 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
3.5765464 7.2577827 1.9754864 8.0062438 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-7.8242456 4.397719 -8.3501687 2.8660455 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-3.3159413 -7.4042592 -1.6973642 -8.1017043 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
7.9346909 -4.1511025 8.4067034 -2.596199 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3.0516575 7.5425216 1.4173589 8.1881769 MAarrowhead1
% End of user PostScript
0 .621 1 r
1 0 0 r
% Start of user PostScript
2.6747717 1.5645185 2.2449991 2.1041254 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
1.7271193 2.5611538 1.141457 2.9176673 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.8273717 2.0205088 -3.103124 1.4692716 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.6329469 -2.6284517 -1.0381 -2.9666049 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
2.8817609 -1.932962 3.1377004 -1.3704617 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1.536963 2.6928336 0.93359147 3.0122514 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2.9329531 1.8432707 -3.1687959 1.2701315 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1.439274 -2.7542281 -0.82804718 -3.0545561 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
2.9808916 -1.7515346 3.1963759 -1.1683923 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
1.3399883 2.8125671 0.72158427 3.0934722 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-3.0255231 1.6578554 -3.22041 1.0653568 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1.2392161 -2.8677859 -0.61432085 -3.1289565 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3.0667981 -1.5623369 3.2408714 -0.96113947 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1.1370691 2.9198233 0.50637592 3.1609695 MAarrowhead1
% End of user PostScript
1 0 .949 r
1 0 0 r
% Start of user PostScript
9.0742146 6.0268912 7.4732983 7.8612675 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
5.5790853 9.3871207 3.4659156 10.544567 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-10.25573 6.6485814 -11.120775 4.6455305 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-5.2374938 -9.6085675 -3.0955117 -10.699298 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
10.430177 -6.3285452 11.223878 -4.2891649 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
4.8900919 9.8193548 2.7216737 10.842159 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-10.593053 6.0014882 -11.31453 3.928041 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4.5372651 -10.019249 -2.3448164 -10.972991 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
10.744178 -5.6677733 11.39263 -3.5625594 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
4.1794047 10.208027 1.9653577 11.091651 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-10.883383 5.3277706 -11.458091 3.1931256 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-3.8169077 -10.385481 -1.5837187 -11.198005 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
11.010514 -4.9818575 11.51084 -2.8201494 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
3.4501763 10.551414 1.2003228 11.291937 MAarrowhead1
% End of user PostScript
1 .086 0 r
1 0 0 r
% Start of user PostScript
-0.85025471 -3.8197839 -0.053499855 -4.0086347 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
0.74535466 -4.0401627 1.514957 -3.9131306 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.9652308 0.30948425 3.7274481 1.0989497 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.87742611 4.0298546 -1.6391085 3.8765274 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-3.936006 -0.44370815 -3.6728537 -1.2280667 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1.0085242 -4.0150758 1.7614417 -3.8356238 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3.9024147 0.5774398 3.6141847 1.3558213 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1.1385034 3.9958428 -1.8818207 3.7904649 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-3.8644941 -0.71053086 -3.5515062 -1.4820717 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
1.2672195 -3.9721769 2.0001121 -3.741101 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
3.8222864 0.84283366 3.4848877 1.606678 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1.3945299 3.9441043 -2.1161845 3.6875868 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3.7758382 -0.97420144 -3.4144031 -1.7295018 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1.5202932 -3.9116562 2.2299094 -3.6299816 MAarrowhead1
% End of user PostScript
1 0 .842 r
1 0 0 r
% Start of user PostScript
-3.7607307 -6.2471685 -2.352281 -7.0269565 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-0.85151382 -7.5309649 0.68267187 -7.7394133 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
7.7108931 -1.6813887 7.7021479 -0.15807625 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
0.59468418 7.5869676 -0.93921024 7.7446784 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-7.7307005 1.4286867 -7.6708653 -0.099878689 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-0.3371948 -7.6345534 1.1947067 -7.7413517 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
7.7419316 -1.1743997 7.6310727 0.35772283 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
0.079331343 7.6736696 -1.4488777 7.7294369 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7.7445739 0.91880989 -7.5828144 -0.61517012 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
0.17862012 -7.7042727 1.7014414 -7.7089472 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
7.7386245 -0.66220075 7.5261438 0.87193495 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-0.43637343 7.7263289 -1.9521175 7.6799053 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-7.7240901 0.40485698 -7.4611239 -1.1277325 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
0.69364263 -7.7398136 2.200628 -7.6423435 MAarrowhead1
% End of user PostScript
.887 1 0 r
1 0 0 r
% Start of user PostScript
-8.5811826 0.37079877 -8.2733437 -1.332264 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-7.6408095 -2.9830408 -6.7084042 -4.5167453 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
4.0959713 -8.0262411 5.508602 -7.2542553 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
7.5043834 3.2503739 6.5249271 4.7583655 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-4.3459226 7.9179797 -5.7259302 7.0957666 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-7.3596321 -3.514101 -6.3342114 -4.9947069 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
4.5910527 -7.8009342 5.9369062 -6.929406 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
7.2067162 3.7739297 6.1364686 5.2255073 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-4.8310895 7.6752345 -6.1412959 6.755358 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-7.0458052 -4.0295717 -5.9319181 -5.4505106 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
5.0657668 -7.54102 6.3388725 -6.5738158 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
6.8770778 4.2807433 5.7207869 5.6694671 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-5.2948243 7.3984397 -6.5294169 6.3849807 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-6.7007211 -4.5271659 -5.5033091 -5.8821341 MAarrowhead1
% End of user PostScript
0 .614 1 r
1 0 0 r
% Start of user PostScript
0.38773409 5.068502 -0.63656536 5.1719645 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-1.6358822 5.0724481 -2.5709972 4.7738586 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-4.8785214 -1.0940808 -4.4442431 -2.0690984 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.7983729 -5.0360071 2.7190233 -4.7049424 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
4.8186223 1.261817 4.3536795 2.2258077 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1.9588686 4.9939793 -2.864033 4.6308065 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-4.7533776 -1.4281534 -4.2582861 -2.3800477 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2.1171912 -4.9464113 3.0058653 -4.5515334 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
4.6828595 1.5929054 4.1581686 2.5316474 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-2.273165 4.8933558 -3.144363 4.4672108 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-4.6071463 -1.7558902 -4.0534381 -2.6804385 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
2.4266169 -4.8348717 3.2793724 -4.3779325 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4.5263221 1.9169271 3.9442108 2.8262559 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2.5773769 4.7710238 -3.4107438 4.2837973 MAarrowhead1
% End of user PostScript
0 .714 1 r
1 0 0 r
% Start of user PostScript
-6.868852 -7.159045 -5.1410368 -8.5611398 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-3.2114566 -9.6272444 -1.1558397 -10.315518 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
10.160037 -4.2888166 10.560474 -2.2924769 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
2.8730524 9.7700937 0.80409798 10.391875 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-10.25573 3.9634004 -10.587257 1.9463507 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-2.5314609 -9.9021042 -0.45146419 -10.456703 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
10.340047 -3.6335872 10.602294 -1.5980654 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2.1870611 10.023129 0.098329563 10.50993 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-10.412892 3.299743 -10.605569 1.2480071 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-1.8402349 -10.133035 0.25491415 -10.551498 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
10.474185 -2.9622382 10.597078 -0.89656437 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1.4913672 10.2317 -0.60787507 10.58136 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-10.523859 2.6214471 -10.576832 0.54412699 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1.1408451 -10.319013 0.96016162 -10.599484 MAarrowhead1
% End of user PostScript
1 0 .938 r
1 0 0 r
% Start of user PostScript
-6.0895117 5.6810631 -6.9475475 4.5007545 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-7.5329201 3.1438094 -7.8226559 1.6634824 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.0938446 -7.247745 -0.56069878 -7.7015557 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
7.6026605 -2.902406 7.8413313 -1.4069638 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
1.8406199 7.3444166 0.29952458 7.7484179 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-7.6639668 2.6577827 -7.8513077 1.1488843 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1.5853532 -7.4329403 -0.038018092 -7.7866843 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
7.7167707 -2.410211 7.8525739 -0.88953025 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
1.3283278 7.5132182 -0.22353057 7.8163122 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-7.7610138 2.1599653 -7.8451287 0.62918937 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-1.0698288 -7.5851609 0.48483125 -7.8372688 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
7.796647 -1.9073235 7.8289803 -0.36815048 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
0.81014289 7.6486889 -0.74559407 7.849531 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-7.8236308 1.6525657 -7.8041465 0.10670317 MAarrowhead1
% End of user PostScript
1 .328 0 r
1 0 0 r
% Start of user PostScript
2.1989462 -7.5302031 3.5973594 -7.1325514 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
4.8545907 -6.4549757 5.9212989 -5.5240682 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
5.8127187 4.1866504 4.7224437 5.3634061 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-5.0481971 6.3155293 -6.0785911 5.3454272 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-5.6445765 -4.3970041 -4.5199818 -5.5414483 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
5.2362032 -6.1690767 6.2291399 -5.1608561 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
5.4701723 4.6024799 4.3125055 5.7133429 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-5.4184003 6.0157801 -6.3727781 4.9705596 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-5.2896996 -4.8028498 -4.1002449 -5.8788992 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
5.5945863 -5.8558098 6.5093466 -4.7747489 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
5.1033586 4.9978915 3.8834356 6.0379336 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-5.7645658 5.6893431 -6.6386936 4.5736412 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4.911356 -5.1873886 -3.6623182 -6.1902696 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
5.9281502 -5.5165648 6.7606758 -4.3674595 MAarrowhead1
% End of user PostScript
0 1 .934 r
1 0 0 r
% Start of user PostScript
2.0472697 9.9392972 -0.018590108 10.397886 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-2.0837204 10.448399 -4.067073 10.088855 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-10.232347 -0.95771387 -9.587136 -2.9957725 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
2.424533 -10.4165 4.3863954 -9.9890735 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
10.151592 1.3046602 9.4410366 3.3284823 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-2.7626559 10.373045 -4.7008516 9.8782105 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-10.059575 -1.6501592 -9.2844636 -3.6574997 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
3.097714 -10.318083 5.0100927 -9.7563888 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
9.9563982 1.9938275 9.1175905 3.9824594 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-3.4293356 10.251674 -5.3137758 9.6237435 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-9.842176 -2.3352838 -8.9406026 -4.3030011 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
3.7571527 -10.173891 5.6115638 -9.4804218 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
9.7170351 2.6741495 8.7536961 4.6187691 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-4.0808016 10.084823 -5.9031265 9.3265827 MAarrowhead1
% End of user PostScript
0 .258 1 r
1 0 0 r
% Start of user PostScript
9.8285711 -4.0423478 10.194775 -2.110582 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
10.160874 -0.095984481 9.7282007 1.9223801 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.3524585 10.229286 -3.3247868 10.013894 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-10.115828 -0.24472622 -9.6174608 -2.2559166 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
1.6893902 -10.221135 3.6451193 -9.938755 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
10.059558 0.58516543 9.4960514 2.5869505 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2.0244478 10.201644 -3.9614078 9.8525905 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-9.9921293 -0.92495547 -9.3641073 -2.9151145 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
2.3572594 -10.170836 4.2733017 -9.7554957 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
9.9136152 1.2637194 9.2217748 3.2400445 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-2.6874559 10.128745 -4.5804549 9.6475783 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-9.824103 -1.6010813 -9.0692119 -3.5613801 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3.0146711 -10.075417 4.8825266 -9.528958 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
9.7236922 1.9366671 8.9065877 3.8787647 MAarrowhead1
% End of user PostScript
1 .727 0 r
1 0 0 r
% Start of user PostScript
-7.9379867 -7.9498168 -6.0055201 -9.5684606 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-3.8373609 -10.811581 -1.5186009 -11.63039 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
11.442839 -5.0490495 11.937295 -2.8017929 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
3.45623 10.979752 1.1210008 11.723711 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-11.557957 4.6833427 -11.974633 2.4113068 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-3.0712647 -11.135741 -0.7221572 -11.804025 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
11.660253 -4.3124403 11.998686 -2.0181456 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2.6828922 11.279378 0.3225124 11.871244 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-11.749613 3.9367538 -12.009428 1.6227456 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-2.2915434 -11.4105 0.077490183 -11.925293 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
11.825938 -3.5566999 12.006847 -1.2255453 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1.8976523 11.528965 -0.4774068 11.966113 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-11.889144 3.1727003 -11.990946 0.82698544 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1.5016561 -11.634639 0.87679379 -11.993658 MAarrowhead1
% End of user PostScript
1 .547 0 r
1 0 0 r
% Start of user PostScript
6.4749736 4.6156976 5.2700078 5.9262735 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
3.8582155 7.0042671 2.2950037 7.8073714 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-7.6089342 4.6538618 -8.1953229 3.1663039 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-3.6047818 -7.159275 -2.022039 -7.9128327 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
7.729 -4.4154051 8.2626717 -2.9027482 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
3.3473491 7.3063406 1.7468311 8.0095156 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-7.8404914 4.1720501 -8.3208541 2.6359722 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3.0862029 -7.4453006 -1.4696852 -8.0973129 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
7.9432848 -3.9240666 8.3698054 -2.3662719 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
2.8216328 7.576001 1.1909089 8.1761273 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-8.037266 3.6717299 -8.4094715 2.0939466 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-2.5539326 -7.6982967 -0.91081146 -8.2458711 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
8.1223308 -3.4153198 8.4398082 -1.8192982 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
2.283399 7.8120521 0.62970356 8.3064672 MAarrowhead1
% End of user PostScript
.114 1 0 r
1 0 0 r
% Start of user PostScript
-2.8349453 -2.2740597 -2.2570726 -2.8491905 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-1.590619 -3.312502 -0.86173999 -3.6458112 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.5650862 -1.9650837 3.7970278 -1.2669809 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.4718753 3.3779538 0.73527094 3.688011 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-3.6141106 1.8525729 -3.8215178 1.144143 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1.3514988 -3.4396582 -0.6079862 -3.7261194 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3.6591254 -1.7380069 3.8417682 -1.0200357 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1.2296229 3.4975466 0.48002697 3.7600942 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-3.700081 1.6215128 -3.8577567 0.8947968 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-1.1063829 -3.551555 -0.3515352 -3.7898975 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
3.7369317 -1.5032198 3.8694654 -0.76856525 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
0.98191549 3.6016233 0.22265345 3.8154964 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3.7696367 1.3832592 -3.8768814 0.64148106 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-0.85635877 -3.647696 -0.093524686 -3.8368624 MAarrowhead1
% End of user PostScript
1 .12 0 r
1 0 0 r
% Start of user PostScript
2.2690721 -5.8094173 3.3224645 -5.3888613 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
4.2454635 -4.7568142 5.0018452 -3.9380813 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
4.1882465 3.7584309 3.2552773 4.6101877 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-4.384963 4.6316307 -5.1102699 3.784528 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-4.0421949 -3.9126984 -3.0850676 -4.7362404 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
4.5195979 -4.5013089 5.2130255 -3.6267762 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3.891659 4.0626252 2.9114354 4.8570388 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4.6492189 4.3659935 -5.3099977 3.465001 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-3.7368057 -4.208045 -2.7345733 -4.9724489 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
4.7736821 -4.2258346 5.4010792 -3.2993817 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
3.5778068 4.3487965 2.5546775 5.0823427 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-4.8928495 4.0809876 -5.4861688 3.1301022 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3.4148388 -4.4847235 -2.3719476 -5.1865982 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
5.0065888 -3.9316132 5.5651722 -2.9573502 MAarrowhead1
% End of user PostScript
1 .005 0 r
1 0 0 r
% Start of user PostScript
-5.8515352 1.3156705 -5.8527911 0.15988744 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-5.6243484 -1.0021706 -5.1751728 -2.1248974 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.8121221 -5.7775785 2.879504 -5.4476479 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
5.5639914 1.1946066 5.0792641 2.3063443 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-1.9974441 5.7377893 -3.048681 5.3708296 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-5.4974618 -1.3857173 -4.9777205 -2.4852325 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2.1805501 -5.6916347 3.2144758 -5.288053 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5.4248334 1.5752907 4.8706547 2.6613637 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2.3612371 5.6391659 -3.3767046 5.19941 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-5.3461867 -1.7631166 -4.7581855 -2.8345425 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
2.5393046 -5.5804411 3.5351873 -5.1049988 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
5.2616092 1.9489864 4.6404377 3.0045766 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2.714555 5.5155254 -3.6897481 5.0049242 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-5.1711944 -2.1326941 -4.5175419 -3.1712775 MAarrowhead1
% End of user PostScript
.564 1 0 r
1 0 0 r
% Start of user PostScript
-8.2876694 2.4701562 -8.4100014 0.83635612 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-8.2022748 -0.83026759 -7.6726419 -2.4643067 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.0065593 -8.3567318 3.5777489 -8.0016143 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
8.1354415 1.1086084 7.5534765 2.7308195 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-2.2775296 8.3198069 -3.8293355 7.9106578 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-8.059583 -1.3857194 -7.4259313 -2.9943027 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2.5459732 -8.2736522 4.0766738 -7.8109254 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
7.9747833 1.6612931 7.290148 3.2544642 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2.8115923 8.2183189 -4.3194895 7.7025278 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-7.8811365 -1.9350238 -7.1462771 -3.5110152 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
3.0740923 -8.1538684 4.5575133 -7.5855851 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
7.7787466 2.2066077 6.9944783 3.7636712 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-3.333182 8.080372 -4.790481 7.460227 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-7.667727 -2.4757438 -6.8349199 -4.0121518 MAarrowhead1
% End of user PostScript
.973 1 0 r
1 0 0 r
% Start of user PostScript
3.5227542 -9.3874389 5.2313262 -8.7364419 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
6.7345898 -7.7425747 7.9735478 -6.4448427 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
6.8421829 5.9404921 5.3576678 7.3309354 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-6.9624849 7.5447125 -8.1519977 6.2006685 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-6.6102808 -6.1917867 -5.0861461 -7.5374634 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
7.1826561 -7.3384803 8.3214039 -5.9496153 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
6.3710453 6.4362122 4.8089819 7.7356295 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-7.3948589 7.1241069 -8.4815784 5.6919618 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6.1247419 -6.6734976 -4.5264828 -7.9252138 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
7.598858 -6.9018302 8.6323437 -5.4279936 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
5.8716439 6.9033795 4.238962 8.1060061 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-7.7944271 6.6718967 -8.7735324 5.1580038 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-5.6120319 -7.1256029 -3.9467386 -8.2778057 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
7.9813492 -6.4345616 8.904988 -4.8822918 MAarrowhead1
% End of user PostScript
1 0 .563 r
1 0 0 r
% Start of user PostScript
-0.93220179 9.6288419 -2.8039122 9.4938204 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-4.5655803 8.9862048 -6.1480678 8.1259168 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-8.4048239 -3.6186893 -7.3121541 -5.3075097 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
4.845523 -8.8656757 6.3916165 -7.9491376 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
8.2434323 3.9139818 7.0992661 5.5722747 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-5.1200901 8.7353112 -6.6280745 7.7635397 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-8.0728955 -4.2049321 -6.8785023 -5.8308578 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5.3889771 -8.595256 6.8571794 -7.5693291 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
7.8934028 4.4912176 6.6501077 6.0829723 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-5.6518857 8.4456653 -7.078677 7.3667212 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-7.7051533 -4.7725205 -6.4143355 -6.3283385 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
5.9085241 -8.2867051 7.2923217 -7.1559408 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
7.5083558 5.048529 6.1714474 6.5666842 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-6.1586078 8.1185518 -7.4978765 6.9372218 MAarrowhead1
% End of user PostScript
1 .93 0 r
1 0 0 r
% Start of user PostScript
-1.8632186 -5.7417659 -0.63954934 -6.1419024 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
0.60921962 -6.3009939 1.8340792 -6.2127968 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
6.2630346 -0.074855214 5.9994578 1.1691574 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.8178249 6.3034871 -2.0339054 6.1738553 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-6.235795 -0.13509743 -5.9317137 -1.3747923 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1.0255229 -6.2989874 2.2314752 -6.1280645 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
6.2016375 0.34490019 5.8573891 1.5789021 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1.2320832 6.2874997 -2.4265695 6.0754754 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6.1606001 -0.55432033 -5.7765665 -1.7812603 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
1.4372766 -6.2690367 2.6189718 -6.0161463 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
6.1127281 0.76312552 5.6893354 1.9816424 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1.6408756 6.243619 -2.8084687 5.950143 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-6.0580749 -0.97108411 -5.5957927 -2.179826 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1.8426542 -6.2112747 2.9948499 -5.8775387 MAarrowhead1
% End of user PostScript
0 .216 1 r
1 0 0 r
% Start of user PostScript
-2.3703751 -6.5121446 -0.97109147 -7.0170642 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
0.46630359 -7.2465924 1.8853981 -7.191721 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
7.2363594 -0.32225104 6.9786644 1.1138618 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.70732776 7.2573257 -2.1178391 7.1546211 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-7.2128002 0.08052854 -6.9081247 -1.3521635 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
0.94756723 -7.2600079 2.3479307 -7.1095841 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
7.1812392 0.1612833 6.8299213 1.5889651 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1.1867555 7.254636 -2.5754175 7.0566598 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7.1417115 -0.40291622 -6.7441409 -1.824004 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
1.4246272 -7.2412159 2.8000471 -6.9959071 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
7.0942609 0.64410215 6.6508787 2.0570193 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1.6609184 7.2197625 -3.0215705 6.9273931 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-7.03894 -0.88457352 -6.5502381 -2.2877526 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1.8953671 -7.1902997 3.2397417 -6.8511941 MAarrowhead1
% End of user PostScript
0 1 .876 r
1 0 0 r
% Start of user PostScript
0.01474355 -7.8891141 1.5815768 -7.9273128 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
3.0863395 -7.6543964 4.4699758 -7.0810758 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
7.2736493 2.2735508 6.4985363 3.7306054 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-3.3286057 7.5786704 -4.686425 6.9568192 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-7.1627821 -2.5259764 -6.3424438 -3.9623188 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
3.5671792 -7.4945367 4.8976752 -6.8248447 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
7.0439687 2.7755998 6.179315 4.1896365 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-3.8017953 7.4020888 -5.103492 6.6852989 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6.9173409 -3.022144 -6.0093311 -4.4123063 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
4.0321938 -7.3014291 5.3036471 -6.5383365 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
6.7830391 3.2653355 5.8326805 4.6300812 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-4.2581191 7.1926693 -5.4979184 6.3841207 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-6.6412123 -3.5049044 -5.6495593 -4.8427195 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4.4793205 -7.0759301 5.6860904 -6.2228224 MAarrowhead1
% End of user PostScript
1 0 .244 r
1 0 0 r
% Start of user PostScript
6.6464025 -1.3419547 6.6175416 -0.028376402 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
6.3289688 1.2863155 5.7920094 2.5505248 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.1989696 6.5187324 -3.3964126 6.1158029 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-6.2557268 -1.5034374 -5.6788838 -2.7542261 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
2.4073315 -6.4686568 3.5855613 -6.0240668 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
6.1755449 1.7188914 5.5594582 2.954872 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2.6130227 6.4114051 -3.7707323 5.9256478 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6.088512 -1.9324385 -5.433865 -3.1522398 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
2.8158151 -6.3470406 3.9517201 -5.8206549 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
5.9947246 2.1438418 5.3022435 3.3461106 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-3.0154837 6.2756349 -4.1283239 5.7092048 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-5.8942867 -2.3528668 -5.1647399 -3.5362692 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3.2118069 -6.197267 4.3003479 -5.5914209 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
5.7873098 2.5592815 5.0215066 3.7225048 MAarrowhead1
% End of user PostScript
.751 0 1 r
1 0 0 r
% Start of user PostScript
-4.8969586 -4.3242428 -3.8200593 -5.3197634 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-2.5932381 -6.1065047 -1.2646428 -6.6535903 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
6.5237836 -3.2809206 6.8856275 -2.0018139 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
2.375948 6.2157835 1.0353006 6.7202654 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-6.6029202 3.0738892 -6.9201106 1.7779794 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-2.156022 -6.3181667 -0.80480985 -6.7794853 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
6.6747316 -2.8634476 6.9469167 -1.5521725 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1.9337042 6.4135407 0.57342626 6.8311841 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-6.7391383 2.6498293 -6.9660161 1.3246437 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-1.7092412 -6.5017995 -0.34140651 -6.8753045 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
6.7960686 -2.4332714 6.9773874 -1.0956453 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1.4828819 6.5828454 0.10900802 6.9117976 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-6.8454595 2.2140141 -6.9810182 0.86543146 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-1.2548776 -6.6565884 0.12351141 -6.9406228 MAarrowhead1
% End of user PostScript
0 .266 1 r
1 0 0 r
% Start of user PostScript
5.7940985 -0.42511488 5.6209634 0.72389878 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
5.2272281 1.8445023 4.6283452 2.8927166 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.6043559 5.4694555 -3.5752948 4.9805096 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-5.1404838 -2.0266756 -4.5092615 -3.0586043 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
2.775572 -5.4019522 3.7254865 -4.8786355 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
5.0480368 2.2066004 4.3851753 3.2210989 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2.9437089 5.3284562 -3.8715452 4.7713491 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4.9499896 -2.3840774 -4.2562242 -3.38002 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
3.10858 -5.2490488 4.0133089 -4.6587695 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
4.8464509 2.5589094 4.1225514 3.5351914 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-3.2700026 5.1638182 -4.1506202 4.5410215 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-4.7375357 -2.7309027 -3.9843051 -3.686441 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
3.4277975 -5.072859 4.283327 -4.4182358 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4.6233647 2.8998663 3.8416387 3.8336008 MAarrowhead1
% End of user PostScript
.335 0 1 r
1 0 0 r
% Start of user PostScript
6.98341 -6.4102699 7.9465899 -5.056154 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
8.5978982 -3.5036046 8.9117736 -1.8135527 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.3045419 8.2816615 0.55659968 8.7827257 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-8.6746565 3.2277641 -8.9303125 1.5210231 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-2.0156118 -8.3891699 -0.25915437 -8.833387 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
8.7417912 -2.9483428 8.9389443 -1.2268062 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1.7244456 8.4873715 -0.038578443 8.8742487 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-8.799228 2.6656507 -8.9376593 0.93122818 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-1.4313664 -8.5761573 0.33626846 -8.9052655 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
8.846903 -2.3800014 8.9264591 -0.63461712 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
1.1366992 8.6554289 -0.63358542 8.9264029 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-8.8847635 2.0917117 -8.905356 0.33730203 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-0.84077105 -8.7250984 0.9301995 -8.9376376 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
8.9127674 -1.8011016 8.8743735 -0.039612739 MAarrowhead1
% End of user PostScript
0 .8 1 r
1 0 0 r
% Start of user PostScript
-0.55674152 -1.7204265 -0.19015754 -1.8400145 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
0.18388936 -1.8873894 0.55071934 -1.8606919 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.8758188 -0.021006397 1.7965951 0.35159069 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-0.24636797 1.8880891 -0.61055921 1.8489814 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-1.867613 -0.041880904 -1.776259 -0.41317541 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
0.30857326 -1.8866942 0.66972175 -1.8352196 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1.8573352 0.10472174 1.7539523 0.47430177 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-0.37043623 1.8832062 -0.7281413 1.8194218 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-1.8449969 -0.16744641 -1.7296998 -0.53490194 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
0.43188824 -1.877629 0.78575307 -1.8016056 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
1.8306119 0.22998531 1.7035284 0.59490871 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-0.49286113 1.8699688 -0.84249314 1.7817908 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1.814196 -0.29226907 -1.6754672 -0.65425549 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
0.55328724 -1.860234 0.89829856 -1.7599993 MAarrowhead1
% End of user PostScript
1 0 .096 r
.18714 .14845 m
.2709 .08445 L
.36366 .03677 L
.46176 .00726 L
s
.46176 .00726 m
.53288 0 L
s
.59088 0 m
.65855 .00666 L
.74953 .03559 L
.83071 .08275 L
.89891 .14628 L
.95145 .2237 L
.98628 .31196 L
s
.98628 .31196 m
1 .39532 L
s
1 .45824 m
.99806 .50686 L
.97455 .60586 L
.93242 .7007 L
.87332 .78766 L
.79957 .86334 L
.71406 .92475 L
.62015 .9695 L
.52152 .99582 L
s
.52152 .99582 m
.46088 1 L
s
.40198 1 m
.32564 .98981 L
.23607 .95772 L
.15686 .90767 L
.09112 .84161 L
.04142 .76215 L
.00972 .67241 L
s
.00972 .67241 m
0 .59709 L
s
0 .53845 m
.00454 .4764 L
.03125 .37783 L
.07637 .28406 L
.13811 .19876 L
.21405 .12529 L
.30122 .06652 L
.39618 .02476 L
.49522 .00166 L
s
.49522 .00166 m
.54152 0 L
s
.60564 0 m
.68997 .01426 L
.77804 .04947 L
.85519 .10237 L
.91841 .17087 L
.9652 .25228 L
.99374 .34342 L
s
.99374 .34342 m
1 .40995 L
s
1 .46798 m
.99232 .54032 L
.96242 .63835 L
.91437 .73095 L
.85006 .81448 L
.77201 .88568 L
.68329 .94173 L
.58737 .98045 L
s
.58737 .98045 m
.48963 1 L
s
.38648 1 m
.29462 .98113 L
.20816 .94284 L
.13315 .88716 L
.07253 .81629 L
.02869 .733 L
.00335 .64057 L
s
.00335 .64057 m
0 .58444 L
s
0 .52469 m
.01137 .44301 L
.04442 .34563 L
.09535 .2543 L
.16216 .17262 L
.24222 .10379 L
.33241 .05051 L
.42917 .01486 L
s
.42917 .01486 m
.51828 0 L
s
.58414 0 m
.62712 .00135 L
.72055 .02401 L
.80532 .06535 L
.87811 .12375 L
.93605 .19691 L
.97689 .28197 L
.99901 .37559 L
s
.99901 .37559 m
1 .4142 L
s
1 .48303 m
.98439 .5736 L
.94823 .67023 L
.89448 .76017 L
.82525 .83991 L
.74325 .90631 L
.65171 .95676 L
.55421 .98928 L
s
.55421 .98928 m
.47405 1 L
s
.41482 1 m
.35674 .9962 L
.26452 .97032 L
.18154 .92599 L
.11106 .86493 L
.05584 .78956 L
.01806 .70282 L
s
.01806 .70282 m
0 .61219 L
s
0 .50904 m
.02038 .40987 L
.05961 .31411 L
.11612 .22564 L
.18771 .14793 L
.27154 .08405 L
.36434 .03649 L
.46247 .00712 L
s
.46247 .00712 m
.53318 0 L
s
.59117 0 m
.65923 .0068 L
.75015 .03587 L
.83124 .08315 L
.89934 .14679 L
.95176 .2243 L
.98646 .31262 L
s
.98646 .31262 m
1 .39565 L
s
1 .45822 m
.99796 .50758 L
.97432 .60655 L
.93206 .70135 L
.87284 .78825 L
.79899 .86383 L
.71341 .92513 L
.61945 .96975 L
.52081 .99594 L
s
.52081 .99594 m
.46066 1 L
s
.40167 1 m
.32497 .98965 L
.23546 .95742 L
.15634 .90725 L
.0907 .84109 L
.04113 .76154 L
.00956 .67173 L
s
.00956 .67173 m
0 .59678 L
s
0 .53821 m
.00466 .47568 L
.03151 .37714 L
.07675 .28341 L
.1386 .19819 L
.21464 .12481 L
.30187 .06615 L
.39688 .02453 L
.49594 .00156 L
s
.49594 .00156 m
.54137 0 L
s
.60597 0 m
.69064 .01444 L
.77863 .04979 L
.8557 .1028 L
.9188 .17141 L
.96547 .25291 L
.99387 .3441 L
s
.99387 .3441 m
1 .41023 L
s
1 .46828 m
.99217 .54103 L
.96214 .63904 L
.91397 .73158 L
.84955 .81504 L
.77141 .88614 L
.68262 .94208 L
.58667 .98067 L
s
.58667 .98067 m
.48928 1 L
s
.38614 1 m
.29397 .98093 L
.20758 .9425 L
.13266 .8867 L
.07216 .81573 L
.02845 .73237 L
.00324 .63989 L
s
.00324 .63989 m
0 .58427 L
s
0 .52437 m
.01154 .4423 L
.04472 .34495 L
.09577 .25368 L
.16269 .17208 L
.24284 .10335 L
.33308 .05019 L
.42988 .01468 L
s
.42988 .01468 m
.51861 0 L
s
.58388 0 m
.62782 .00144 L
.72119 .02424 L
.80589 .06571 L
.87858 .12422 L
.93641 .19748 L
.97711 .28261 L
.99909 .37628 L
s
.99909 .37628 m
1 .41354 L
s
1 .48336 m
.9842 .57431 L
.94791 .6709 L
.89404 .76079 L
.8247 .84044 L
.74263 .90673 L
.65103 .95706 L
.5535 .98945 L
s
.5535 .98945 m
.47373 1 L
s
.41461 1 m
.35606 .99608 L
.26389 .97007 L
.18099 .92561 L
.11061 .86444 L
.05551 .78897 L
.01786 .70216 L
s
.01786 .70216 m
0 .61185 L
s
0 .51365 m
5e-05 .50846 L
.0206 .40917 L
.05996 .31344 L
.11659 .22504 L
.18827 .14742 L
.27218 .08365 L
.36503 .03621 L
.46318 .00698 L
s
.46318 .00698 m
.53347 0 L
s
.59146 0 m
.65991 .00694 L
.75077 .03615 L
.83178 .08355 L
.89977 .1473 L
.95208 .2249 L
.98664 .31328 L
s
1 0 0 r
.18714 .14845 m
.2709 .08445 L
s
% Start of user PostScript
-0.62571057 -0.7031094 -0.45819108 -0.83109738 MAarrowhead1
% End of user PostScript
1 .158 0 r
.36366 .03677 m
.46176 .00726 L
s
% Start of user PostScript
-0.27268945 -0.92646815 -0.076485848 -0.98547877 MAarrowhead1
% End of user PostScript
1 .473 0 r
.98628 .31196 m
0 0 rlineto s
.98628 .31196 m
1 .39532 L
s
% Start of user PostScript
0.97255478 -0.37608573 1.0040402 -0.18480938 MAarrowhead1
% End of user PostScript
1 .788 0 r
.62015 .9695 m
.52152 .99582 L
s
% Start of user PostScript
0.24029619 0.93899458 0.043043898 0.99163428 MAarrowhead1
% End of user PostScript
.897 1 0 r
.00972 .67241 m
0 0 rlineto s
.00972 .67241 m
0 .59709 L
s
% Start of user PostScript
-0.98055842 0.34481028 -1.0054739 0.15178064 MAarrowhead1
% End of user PostScript
.581 1 0 r
.39618 .02476 m
.49522 .00166 L
s
% Start of user PostScript
-0.20763636 -0.9504793 -0.0095541966 -0.9966897 MAarrowhead1
% End of user PostScript
.266 1 0 r
.99374 .34342 m
0 0 rlineto s
.99374 .34342 m
1 .40995 L
s
% Start of user PostScript
0.98747424 -0.3131523 1.0057921 -0.11858351 MAarrowhead1
% End of user PostScript
0 1 .049 r
.58737 .98045 m
0 0 rlineto s
.58737 .98045 m
.48963 1 L
s
% Start of user PostScript
0.17474618 0.96090959 -0.023946104 1.0006394 MAarrowhead1
% End of user PostScript
0 1 .364 r
.00335 .64057 m
0 0 rlineto s
.00335 .64057 m
0 .58444 L
s
% Start of user PostScript
-0.99329458 0.28114692 -1.0049946 0.085254836 MAarrowhead1
% End of user PostScript
0 1 .679 r
.42917 .01486 m
0 0 rlineto s
.42917 .01486 m
.51828 0 L
s
% Start of user PostScript
-0.14166214 -0.97027385 0.05741984 -1.003479 MAarrowhead1
% End of user PostScript
0 1 .995 r
.99901 .37559 m
0 0 rlineto s
.99901 .37559 m
1 .4142 L
s
% Start of user PostScript
0.99801297 -0.24882964 1.0030821 -0.051831579 MAarrowhead1
% End of user PostScript
0 .69 1 r
.55421 .98928 m
0 0 rlineto s
.55421 .98928 m
.47405 1 L
s
% Start of user PostScript
0.10842095 0.97856172 -0.090829875 1.0052054 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1.0016242 0.21623631 -1.0000567 0.018350821 MAarrowhead1
% End of user PostScript
0 .06 1 r
.46247 .00712 m
0 0 rlineto s
.46247 .00712 m
.53318 0 L
s
% Start of user PostScript
-0.075059469 -0.98576398 0.12413914 -1.0058166 MAarrowhead1
% End of user PostScript
1 0 .785 r
1 0 0 r
% Start of user PostScript
-2.6445324 -2.8413144 -1.9624175 -3.3815693 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-1.2032856 -3.7891112 -0.39692961 -4.0479458 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.9901534 -1.6268439 4.1359919 -0.84252124 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.070384 3.8432971 0.25917056 4.076008 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-4.025805 1.4988338 -4.1446242 0.70676009 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-0.93629503 -3.8932194 -0.12112399 -4.0995483 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
4.0569906 -1.3691609 4.1486585 -0.57021488 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
0.8011673 3.9388225 -0.017056958 4.1185407 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-4.0836754 1.237969 -4.1480904 0.43303708 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-0.66515078 -3.980056 0.15521898 -4.132964 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
4.1058298 -1.1054038 4.1429205 -0.29537888 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
0.52839634 4.0168741 -0.29320881 4.1428023 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4.1234293 0.97161221 -4.1331544 0.15739299 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-0.39105572 -4.049236 0.43087335 -4.1480447 MAarrowhead1
% End of user PostScript
1 0 .452 r
1 0 0 r
% Start of user PostScript
4.6140272 -6.354327 5.6714328 -5.4706924 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
6.5062575 -4.3723552 7.0857378 -3.1024207 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.4783577 6.078809 2.1159135 6.8016147 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-6.6221125 4.169886 -7.1562134 2.8758767 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-3.2577925 -6.217697 -1.8775588 -6.8974026 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
6.730621 -3.9627908 7.2187499 -2.6461423 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
3.0336132 6.3496872 1.6371212 6.9855387 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-6.8316627 3.7512994 -7.2732781 2.4134723 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2.8060684 -6.4746331 -1.3948673 -7.0659251 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
6.9251255 -3.5356463 7.3197375 -2.1781248 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
2.5754106 6.5923962 1.151066 7.1384727 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-7.0109057 3.3160709 -7.3580765 1.940361 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2.3418957 -6.7028459 -0.9059878 -7.2031011 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
7.0889081 -3.0928166 7.3882526 -1.7004446 MAarrowhead1
% End of user PostScript
1 .456 0 r
1 0 0 r
% Start of user PostScript
8.5618267 -6.1409865 9.4013274 -4.4718511 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
9.871864 -2.6272136 9.9549696 -0.67946849 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
1.2396467 9.6613247 -0.73507644 9.9579973 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-9.9131534 2.3054201 -9.9304862 0.34779369 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-0.90946554 -9.7381122 1.0658349 -9.9695814 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
9.9434453 -1.9810691 9.894986 -0.015733051 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
0.57827543 9.8040964 -1.395411 9.9701054 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-9.9627061 1.6545204 -9.8485085 -0.31634504 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-0.2464438 -9.8592041 1.723439 -9.9595688 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
9.9709145 -1.3261361 9.7911053 0.64807218 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-0.085661242 9.9033743 -2.049555 9.9379832 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-9.9680614 0.99628068 -9.72284 -0.97908036 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
0.41767125 -9.9365578 2.3733974 -9.9053726 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
9.9541498 -0.66531997 9.6437883 1.3090024 MAarrowhead1
% End of user PostScript
.335 1 0 r
1 0 0 r
% Start of user PostScript
-8.1220379 7.8526519 -9.3211822 6.2798215 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-10.154508 4.4605335 -10.58931 2.4661875 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-3.0468914 -9.7457503 -0.97504496 -10.401945 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
10.255992 -4.1359281 10.621786 -2.119726 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
2.7052912 9.8835072 0.6212611 10.472547 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-10.346098 3.8067344 -10.642479 1.7709129 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2.3606898 -10.0103 -0.26678803 -10.531532 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
10.424726 -3.4733175 10.651365 -1.4201352 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
2.0134694 10.125987 -0.087981018 10.578833 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-10.49179 3.1360474 -10.648434 1.067782 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-1.6640154 -10.23044 0.44265246 -10.614398 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
10.547214 -2.7952983 10.633691 -0.71424419 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1.3127154 10.323544 -0.79683283 10.638187 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-10.590937 2.4514481 -10.60715 0.35991405 MAarrowhead1
% End of user PostScript
1 .219 0 r
1 0 0 r
% Start of user PostScript
-0.98322239 -4.8298101 0.020126293 -5.0503457 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
1.0226851 -5.0726757 1.9851076 -4.8959235 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
4.9662076 0.47609708 4.650818 1.4653153 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-1.1880965 5.0568181 -2.1400142 4.8471177 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-4.9266352 -0.64452644 -4.5795398 -1.6267601 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
1.3521898 -5.0353506 2.2925467 -4.7929346 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
4.8815973 0.81224078 4.503181 1.7864002 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-1.514783 5.008297 -2.4425358 4.7334343 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-4.8311439 -0.97905403 -4.4218266 -1.9440585 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
1.6756957 -4.9756873 2.5898153 -4.6686828 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
4.7753309 1.1447811 4.3355666 2.0995601 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1.8347495 4.9375576 -2.7342216 4.598752 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-4.7142202 -1.3092382 -4.2444968 -2.2527325 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
1.9917678 -4.8939504 2.8755947 -4.5237194 MAarrowhead1
% End of user PostScript
.952 0 1 r
1 0 0 r
% Start of user PostScript
5.0882979 -6.4351288 6.1406723 -5.4576825 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
6.95205 -4.2660443 7.4905878 -2.9069809 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.3076404 6.5396849 1.8612147 7.2309734 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-7.0622188 4.0482245 -7.55258 2.6661362 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-3.0724164 -6.6745206 -1.609658 -7.3197754 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
7.164553 -3.8259137 7.6061935 -2.4223336 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2.8337839 6.8019518 1.3563156 7.400457 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-7.2589389 3.5993585 -7.6513688 2.1758438 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2.5920076 -6.921837 -1.1014686 -7.4729287 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
7.3452719 -3.3688103 7.6880558 -1.9269401 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
2.3473559 7.0340432 0.84539958 7.53711 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-7.4234562 3.1345247 -7.7162139 1.6758987 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2.1001 -7.1384461 -0.58839271 -7.5929298 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
7.493405 -2.8967618 7.7358117 -1.4229981 MAarrowhead1
% End of user PostScript
0 1 .378 r
1 0 0 r
% Start of user PostScript
9.147696 -9.0831602 10.54573 -7.3129567 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
11.529887 -5.2557492 12.061542 -2.9922747 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
3.6521197 11.044879 1.2952412 11.828099 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-11.65153 4.8878732 -12.104683 2.5983117 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-3.2640378 -11.207682 -0.89206596 -11.914642 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
11.760246 -4.5145747 12.134396 -2.2014662 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2.8723348 11.35805 0.48790103 11.987967 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-11.855916 4.1362678 -12.150646 1.8021784 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2.4774453 -11.495819 -0.083194842 -12.047993 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
11.938433 -3.7533722 12.153417 -1.4008913 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
2.0798074 11.620834 -0.32160365 12.094653 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-12.007706 3.3663127 -12.142706 0.9980501 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1.6798622 -11.732957 0.72604535 -12.127896 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
12.063658 -2.9755187 12.118523 -0.59410167 MAarrowhead1
% End of user PostScript
1 0 .722 r
1 0 0 r
% Start of user PostScript
1.8803686 7.913973 0.22434089 8.3288413 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-1.4404913 8.4168361 -3.04879 8.1745041 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-8.2767478 -0.53157416 -7.8031513 -2.1788531 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.7161681 -8.3991308 3.3086925 -8.1019322 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
8.2195867 0.8113272 7.6929474 2.4487072 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-1.989941 8.3721076 -3.5649244 8.0203722 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-8.153307 -1.0901802 -7.5742091 -2.7158448 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2.2615063 -8.3357966 3.8172015 -7.9299145 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
8.0779821 1.3678237 7.4470681 2.9799695 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-2.5305627 8.2902379 -4.0652438 7.8306595 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-7.9936957 -1.6439498 -7.3116655 -3.2407882 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
2.7968117 -8.2354823 4.3087762 -7.7227174 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
7.9005412 1.9182522 7.1681515 3.4980117 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3.0599581 8.1715903 -4.5475286 7.6062078 MAarrowhead1
% End of user PostScript
1 .889 0 r
1 0 0 r
% Start of user PostScript
3.64916 8.7046884 1.7573858 9.4751203 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-0.20335866 9.8736918 -2.1561221 9.8847607 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-9.9213619 0.87442448 -9.6540051 -1.0922931 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
0.53381323 -9.9028166 2.4776717 -9.8483793 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
9.903582 -0.54458761 9.5714803 1.4203168 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-0.8636756 9.9209554 -2.7964727 9.8010723 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-9.8748152 0.21414658 -9.4783372 -1.7467649 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
1.1925798 -9.928088 3.1121712 -9.7428921 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
9.8350935 0.11653202 9.3746789 2.0712751 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-1.520161 9.9242067 -3.4244172 9.6739034 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-9.7844609 -0.44708134 -9.2606205 -2.3934874 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
1.8460558 -9.9093155 3.7328642 -9.5941826 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
9.7229736 0.77713468 9.1362886 2.7130445 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2.1699025 9.8834312 -4.0371701 9.5038182 MAarrowhead1
% End of user PostScript
1 0 .859 r
1 0 0 r
% Start of user PostScript
2.3908794 -4.2928395 3.1375273 -3.8401753 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
3.76104 -3.2367996 4.236947 -2.5063926 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.7255189 3.4364091 1.921564 3.9958576 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-3.8518199 3.1223418 -4.3009492 2.373301 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-2.5972249 -3.5404061 -1.7783107 -4.074906 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
3.9383266 -3.0044202 4.3601801 -2.2375766 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
2.4660496 3.6404754 1.6330845 4.1494338 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4.0204643 2.8831655 -4.4145739 2.0993698 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-2.3321384 -3.7365061 -1.4860466 -4.2193583 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
4.0981417 -2.7587122 4.4640702 -1.9588341 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
2.1956401 3.8283916 1.3373601 4.284602 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-4.1712727 2.6311986 -4.5086141 1.8161252 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-2.0567059 -3.9160299 -1.18719 -4.3450923 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4.2397762 -2.5007659 4.5481563 -1.6714016 MAarrowhead1
% End of user PostScript
1 0 .684 r
1 0 0 r
% Start of user PostScript
7.9122091 8.8791121 5.7962468 10.497479 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
3.4528051 11.703862 0.97385475 12.450915 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-12.287202 4.7590488 -12.686498 2.3425139 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-3.0435506 -11.862373 -0.55130074 -12.528938 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
12.388575 -4.3639442 12.704861 -1.9252078 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
2.6309196 12.007725 0.12813512 12.593062 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-12.476204 3.9639984 -12.709128 1.5057659 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-2.21537 -12.139755 0.29517265 -12.643215 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
12.549992 -3.559655 12.699297 -1.0846535 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
1.7973626 12.258318 -0.71815296 12.679342 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-12.609857 3.1513625 -12.675377 0.66233782 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-1.3773613 -12.363282 1.1403366 -12.701403 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
12.655734 -2.739574 12.637396 -0.23928737 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
0.95583198 12.45453 -1.5612551 12.709373 MAarrowhead1
% End of user PostScript
1 .925 0 r
1 0 0 r
% Start of user PostScript
-4.7602622 4.3487824 -5.4126845 3.4256369 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-5.8526807 2.368049 -6.0629828 1.2175246 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-1.5517031 -5.6392616 -0.36225019 -5.9769686 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
5.9043639 -2.1802199 6.0750484 -1.0184475 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
1.3550442 5.711879 0.15990624 6.0108904 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-5.9494968 1.9899722 -6.0803744 0.81824047 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-1.156882 -5.7781598 0.042615099 -6.0381439 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
5.9880295 -1.7975168 6.078955 -0.61712572 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
0.95743646 5.8380303 -0.24508916 6.0586987 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-6.0199192 1.6030674 -6.0707917 0.41532634 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-0.75692872 -5.8914243 0.44729133 -6.0725321 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
6.0451305 -1.4068394 6.0558936 -0.21306621 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
0.55558127 5.9382824 -0.64899728 6.0796288 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-6.0636355 1.2090508 -6.0342772 0.010569699 MAarrowhead1
% End of user PostScript
0 1 .348 r
1 0 0 r
% Start of user PostScript
1.2063591 6.7003279 -0.17856345 6.9749501 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-1.5564781 6.9758337 -2.8733072 6.7029439 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-6.8080127 -0.80598769 -6.3451918 -2.1628741 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
1.7832351 -6.9489883 3.0846489 -6.6309042 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
6.7486178 1.0374403 6.2424502 2.3837322 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-2.0080139 6.9144339 -3.2925686 6.5515083 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-6.6817361 -1.267742 -6.1327834 -2.6019457 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2.230565 -6.8722088 3.4968355 -6.4648443 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
6.6074418 1.4966372 6.016313 2.8172728 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-2.4506416 6.8223597 -3.6972231 6.3710084 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-6.5258174 -1.7238722 -5.8931682 -3.0294744 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
2.6679995 -6.764942 3.8935091 -6.2701045 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
6.4369533 1.9491946 5.7634856 3.2383151 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-2.8823975 6.7000195 -4.0854757 6.1622447 MAarrowhead1
% End of user PostScript
.151 1 0 r
1 0 0 r
% Start of user PostScript
-2.7360651 4.2069789 -3.4503067 3.685282 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-4.0291376 3.0189527 -4.4498412 2.2341416 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-2.4677431 -3.730403 -1.616835 -4.2401667 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
4.1113317 -2.8947027 4.5036937 -2.0929128 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
2.3308054 3.826818 1.4668288 4.3098761 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-4.1889647 2.7672415 -4.5525499 1.9493621 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-2.191282 -3.9189875 -1.3151953 -4.3748043 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
4.2619506 -2.6367103 4.5963556 -1.8036488 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
2.0493276 4.0068094 1.1621027 4.4348791 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-4.3302083 2.5032539 -4.6350622 1.6559346 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-1.9050997 -4.0901863 -1.0077209 -4.4900339 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
4.3936622 -2.3670205 4.6686268 -1.5063834 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
1.7587583 4.1690255 0.8522212 4.5402076 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-4.4522418 2.2281612 -4.697012 1.355161 MAarrowhead1
% End of user PostScript
1 .319 0 r
1 0 0 r
% Start of user PostScript
0.45495092 -8.6888236 2.1611072 -8.6437266 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
3.7824488 -8.2593981 5.2553444 -7.5509216 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
7.784067 2.9089287 6.8600179 4.4707107 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-4.0417156 8.1625093 -5.4838337 7.4020139 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-7.649448 -3.1808005 -6.6773658 -4.7172523 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
4.2964987 -8.0565652 5.7062392 -7.2448946 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
7.5063429 3.4491436 6.4873059 4.9585608 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4.5465153 7.9416833 -5.9223144 7.079738 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-7.3549104 -3.7136603 -6.2900492 -5.1943683 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
4.7914881 -7.817991 6.1318194 -6.9067272 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
7.1953185 3.974057 6.0858143 5.4244133 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-5.0311453 7.6856256 -6.334522 6.7260542 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-7.0277442 -4.2300451 -5.874828 -5.6484406 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
5.2652211 -7.5447338 6.5301971 -6.5379194 MAarrowhead1
% End of user PostScript
0 .179 1 r
1 0 0 r
% Start of user PostScript
3.2103358 -4.2877806 3.9195462 -3.6722721 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
4.4749301 -2.9126418 4.8546912 -2.0387019 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
2.2970257 4.1912789 1.3621361 4.6695254 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
-4.5514381 2.7730412 -4.9000603 1.8831723 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
-2.1454292 -4.2836416 -1.198928 -4.7322489 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
4.6228967 -2.6303644 4.9399935 -1.7255535 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
1.9914527 4.3712522 1.0343897 4.7897226 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
-4.6892267 2.4847694 -4.9744463 1.5660203 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
-1.8352668 -4.4540133 -0.86870395 -4.8418826 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
4.7503547 -2.3364179 5.0033806 -1.4047499 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
1.6770449 4.5318333 0.70205446 4.8886712 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
-4.8062126 2.1854744 -5.0267641 1.2419211 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
-1.5169626 -4.6046257 -0.53462611 -4.9300363 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
4.8567387 -2.0321064 5.0445711 -1.0777145 MAarrowhead1
% End of user PostScript
1 0 .05 r
1 0 0 r
% Start of user PostScript
0.13091841 5.7466499 -1.0167045 5.8026209 MAarrowhead1
% End of user PostScript
1 .158 0 r
% Start of user PostScript
-2.1244258 5.6308625 -3.1487719 5.2381154 MAarrowhead1
% End of user PostScript
1 .473 0 r
% Start of user PostScript
-5.371594 -1.525374 -4.8297003 -2.6006086 MAarrowhead1
% End of user PostScript
1 .788 0 r
% Start of user PostScript
2.3033395 -5.5800563 3.3096366 -5.1514959 MAarrowhead1
% End of user PostScript
.897 1 0 r
% Start of user PostScript
5.2948757 1.711231 4.7194649 2.7721915 MAarrowhead1
% End of user PostScript
.581 1 0 r
% Start of user PostScript
-2.4796979 5.5230597 -3.4668296 5.0591615 MAarrowhead1
% End of user PostScript
.266 1 0 r
% Start of user PostScript
-5.2122835 -1.8951897 -4.6039939 -2.9406989 MAarrowhead1
% End of user PostScript
0 1 .049 r
% Start of user PostScript
2.6533054 -5.4599358 3.6201766 -4.9612145 MAarrowhead1
% End of user PostScript
0 1 .364 r
% Start of user PostScript
5.1239089 2.0770458 4.4834153 3.1059439 MAarrowhead1
% End of user PostScript
0 1 .679 r
% Start of user PostScript
-2.8239694 5.3907549 -3.7695074 4.8577637 MAarrowhead1
% End of user PostScript
0 1 .995 r
% Start of user PostScript
-5.0298498 -2.2565978 -4.3578629 -3.2677433 MAarrowhead1
% End of user PostScript
0 .69 1 r
% Start of user PostScript
2.9915005 -5.3155935 3.9146564 -4.7489237 MAarrowhead1
% End of user PostScript
0 .375 1 r
% Start of user PostScript
4.9302108 2.4336463 4.227476 3.4259175 MAarrowhead1
% End of user PostScript
0 .06 1 r
% Start of user PostScript
-3.1557129 5.2345352 -4.0554625 4.6348154 MAarrowhead1
% End of user PostScript
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -13.4688 -20 ]
[0 .4875 13.4688 0 ]
[.125 .4875 -25.9688 -20 ]
[.125 .4875 25.9688 0 ]
[.25 .4875 -20.9688 -20 ]
[.25 .4875 20.9688 0 ]
[.375 .4875 -25.9688 -20 ]
[.375 .4875 25.9688 0 ]
[.625 .4875 -19.5 -20 ]
[.625 .4875 19.5 0 ]
[.75 .4875 -14.5 -20 ]
[.75 .4875 14.5 0 ]
[.875 .4875 -19.5 -20 ]
[.875 .4875 19.5 0 ]
[1 .4875 -7 -20 ]
[1 .4875 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .125 -51.9375 -10 ]
[.4875 .125 0 10 ]
[.4875 .25 -41.9375 -10 ]
[.4875 .25 0 10 ]
[.4875 .375 -51.9375 -10 ]
[.4875 .375 0 10 ]
[.4875 .625 -39 -10 ]
[.4875 .625 0 10 ]
[.4875 .75 -29 -10 ]
[.4875 .75 0 10 ]
[.4875 .875 -39 -10 ]
[.4875 .875 0 10 ]
[.4875 1 -14 -10 ]
[.4875 1 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 .5 m
.125 .50625 L
s
gsave
.125 .4875 -86.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.25 .5 m
.25 .50625 L
s
gsave
.25 .4875 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.375 .5 m
.375 .50625 L
s
gsave
.375 .4875 -86.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.625 .5 m
.625 .50625 L
s
gsave
.625 .4875 -80.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.75 .5 m
.75 .50625 L
s
gsave
.75 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.875 .5 m
.875 .50625 L
s
gsave
.875 .4875 -80.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .125 m
.50625 .125 L
s
gsave
.4875 .125 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.5 .25 m
.50625 .25 L
s
gsave
.4875 .25 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .375 m
.50625 .375 L
s
gsave
.4875 .375 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.5 .625 m
.50625 .625 L
s
gsave
.4875 .625 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.5 .75 m
.50625 .75 L
s
gsave
.4875 .75 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .875 m
.50625 .875 L
s
gsave
.4875 .875 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.01 w
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.141 1 0 r
.5 Mabswid
0 .535 1 r
.544 1 0 r
1 0 .015 r
.428 0 1 r
.101 1 0 r
0 1 .096 r
1 0 .819 r
0 1 .146 r
.774 1 0 r
0 1 .213 r
0 .028 1 r
0 1 .037 r
1 .885 0 r
0 1 .739 r
1 .142 0 r
1 .98 0 r
1 .629 0 r
0 1 .422 r
0 .574 1 r
0 .692 1 r
0 .34 1 r
.833 1 0 r
.963 1 0 r
0 1 .57 r
.434 0 1 r
1 .64 0 r
1 0 .804 r
0 .283 1 r
1 0 .673 r
1 .118 0 r
.791 0 1 r
1 0 .108 r
1 0 .342 r
1 .525 0 r
0 1 .17 r
.942 0 1 r
1 0 .255 r
1 0 .317 r
0 .717 1 r
0 1 .328 r
0 .969 1 r
.745 0 1 r
0 .388 1 r
1 0 .738 r
1 .773 0 r
1 0 .527 r
.159 0 1 r
.852 1 0 r
1 .894 0 r
1 0 .522 r
1 0 .405 r
0 1 .174 r
1 .331 0 r
1 .408 0 r
0 .621 1 r
1 0 .949 r
1 .086 0 r
1 0 .842 r
.887 1 0 r
0 .614 1 r
0 .714 1 r
1 0 .938 r
1 .328 0 r
0 1 .934 r
0 .258 1 r
1 .727 0 r
1 .547 0 r
.114 1 0 r
1 .12 0 r
1 .005 0 r
.564 1 0 r
.973 1 0 r
1 0 .563 r
1 .93 0 r
0 .216 1 r
0 1 .876 r
1 0 .244 r
.751 0 1 r
0 .266 1 r
.335 0 1 r
0 .8 1 r
1 0 .096 r
.18714 .14845 m
.2709 .08445 L
.36366 .03677 L
.46176 .00726 L
s
.46176 .00726 m
.53288 0 L
s
.59088 0 m
.65855 .00666 L
.74953 .03559 L
.83071 .08275 L
.89891 .14628 L
.95145 .2237 L
.98628 .31196 L
s
.98628 .31196 m
1 .39532 L
s
1 .45824 m
.99806 .50686 L
.97455 .60586 L
.93242 .7007 L
.87332 .78766 L
.79957 .86334 L
.71406 .92475 L
.62015 .9695 L
.52152 .99582 L
s
.52152 .99582 m
.46088 1 L
s
.40198 1 m
.32564 .98981 L
.23607 .95772 L
.15686 .90767 L
.09112 .84161 L
.04142 .76215 L
.00972 .67241 L
s
.00972 .67241 m
0 .59709 L
s
0 .53845 m
.00454 .4764 L
.03125 .37783 L
.07637 .28406 L
.13811 .19876 L
.21405 .12529 L
.30122 .06652 L
.39618 .02476 L
.49522 .00166 L
s
.49522 .00166 m
.54152 0 L
s
.60564 0 m
.68997 .01426 L
.77804 .04947 L
.85519 .10237 L
.91841 .17087 L
.9652 .25228 L
.99374 .34342 L
s
.99374 .34342 m
1 .40995 L
s
1 .46798 m
.99232 .54032 L
.96242 .63835 L
.91437 .73095 L
.85006 .81448 L
.77201 .88568 L
.68329 .94173 L
.58737 .98045 L
s
.58737 .98045 m
.48963 1 L
s
.38648 1 m
.29462 .98113 L
.20816 .94284 L
.13315 .88716 L
.07253 .81629 L
.02869 .733 L
.00335 .64057 L
s
.00335 .64057 m
0 .58444 L
s
0 .52469 m
.01137 .44301 L
.04442 .34563 L
.09535 .2543 L
.16216 .17262 L
.24222 .10379 L
.33241 .05051 L
.42917 .01486 L
s
.42917 .01486 m
.51828 0 L
s
.58414 0 m
.62712 .00135 L
.72055 .02401 L
.80532 .06535 L
.87811 .12375 L
.93605 .19691 L
.97689 .28197 L
.99901 .37559 L
s
.99901 .37559 m
1 .4142 L
s
1 .48303 m
.98439 .5736 L
.94823 .67023 L
.89448 .76017 L
.82525 .83991 L
.74325 .90631 L
.65171 .95676 L
.55421 .98928 L
s
.55421 .98928 m
.47405 1 L
s
.41482 1 m
.35674 .9962 L
.26452 .97032 L
.18154 .92599 L
.11106 .86493 L
.05584 .78956 L
.01806 .70282 L
s
.01806 .70282 m
0 .61219 L
s
0 .50904 m
.02038 .40987 L
.05961 .31411 L
.11612 .22564 L
.18771 .14793 L
.27154 .08405 L
.36434 .03649 L
.46247 .00712 L
s
.46247 .00712 m
.53318 0 L
s
.59117 0 m
.65923 .0068 L
.75015 .03587 L
.83124 .08315 L
.89934 .14679 L
.95176 .2243 L
.98646 .31262 L
s
.98646 .31262 m
1 .39565 L
s
1 .45822 m
.99796 .50758 L
.97432 .60655 L
.93206 .70135 L
.87284 .78825 L
.79899 .86383 L
.71341 .92513 L
.61945 .96975 L
.52081 .99594 L
s
.52081 .99594 m
.46066 1 L
s
.40167 1 m
.32497 .98965 L
.23546 .95742 L
.15634 .90725 L
.0907 .84109 L
.04113 .76154 L
.00956 .67173 L
s
.00956 .67173 m
0 .59678 L
s
0 .53821 m
.00466 .47568 L
.03151 .37714 L
.07675 .28341 L
.1386 .19819 L
.21464 .12481 L
.30187 .06615 L
.39688 .02453 L
.49594 .00156 L
s
.49594 .00156 m
.54137 0 L
s
.60597 0 m
.69064 .01444 L
.77863 .04979 L
.8557 .1028 L
.9188 .17141 L
.96547 .25291 L
.99387 .3441 L
s
.99387 .3441 m
1 .41023 L
s
1 .46828 m
.99217 .54103 L
.96214 .63904 L
.91397 .73158 L
.84955 .81504 L
.77141 .88614 L
.68262 .94208 L
.58667 .98067 L
s
.58667 .98067 m
.48928 1 L
s
.38614 1 m
.29397 .98093 L
.20758 .9425 L
.13266 .8867 L
.07216 .81573 L
.02845 .73237 L
.00324 .63989 L
s
.00324 .63989 m
0 .58427 L
s
0 .52437 m
.01154 .4423 L
.04472 .34495 L
.09577 .25368 L
.16269 .17208 L
.24284 .10335 L
.33308 .05019 L
.42988 .01468 L
s
.42988 .01468 m
.51861 0 L
s
.58388 0 m
.62782 .00144 L
.72119 .02424 L
.80589 .06571 L
.87858 .12422 L
.93641 .19748 L
.97711 .28261 L
.99909 .37628 L
s
.99909 .37628 m
1 .41354 L
s
1 .48336 m
.9842 .57431 L
.94791 .6709 L
.89404 .76079 L
.8247 .84044 L
.74263 .90673 L
.65103 .95706 L
.5535 .98945 L
s
.5535 .98945 m
.47373 1 L
s
.41461 1 m
.35606 .99608 L
.26389 .97007 L
.18099 .92561 L
.11061 .86444 L
.05551 .78897 L
.01786 .70216 L
s
.01786 .70216 m
0 .61185 L
s
0 .51365 m
5e-05 .50846 L
.0206 .40917 L
.05996 .31344 L
.11659 .22504 L
.18827 .14742 L
.27218 .08365 L
.36503 .03621 L
.46318 .00698 L
s
.46318 .00698 m
.53347 0 L
s
.59146 0 m
.65991 .00694 L
.75077 .03615 L
.83178 .08355 L
.89977 .1473 L
.95208 .2249 L
.98664 .31328 L
s
1 0 .785 r
1 0 .452 r
1 .456 0 r
.335 1 0 r
1 .219 0 r
.952 0 1 r
0 1 .378 r
1 0 .722 r
1 .889 0 r
1 0 .859 r
1 0 .684 r
1 .925 0 r
0 1 .348 r
.151 1 0 r
1 .319 0 r
0 .179 1 r
1 0 .05 r
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0333333 0.5 0.0333333 [
[0 .4875 -18.4688 -20 ]
[0 .4875 18.4688 0 ]
[.16667 .4875 -18.4688 -20 ]
[.16667 .4875 18.4688 0 ]
[.33333 .4875 -13.4688 -20 ]
[.33333 .4875 13.4688 0 ]
[.66667 .4875 -7 -20 ]
[.66667 .4875 7 0 ]
[.83333 .4875 -12 -20 ]
[.83333 .4875 12 0 ]
[1 .4875 -12 -20 ]
[1 .4875 12 0 ]
[.4875 0 -36.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .16667 -36.9375 -10 ]
[.4875 .16667 0 10 ]
[.4875 .33333 -26.9375 -10 ]
[.4875 .33333 0 10 ]
[.4875 .66667 -14 -10 ]
[.4875 .66667 0 10 ]
[.4875 .83333 -24 -10 ]
[.4875 .83333 0 10 ]
[.4875 1 -24 -10 ]
[.4875 1 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.16667 .5 m
.16667 .50625 L
s
gsave
.16667 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.33333 .5 m
.33333 .50625 L
s
gsave
.33333 .4875 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.66667 .5 m
.66667 .50625 L
s
gsave
.66667 .4875 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.83333 .5 m
.83333 .50625 L
s
gsave
.83333 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.5 .16667 m
.50625 .16667 L
s
gsave
.4875 .16667 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 .33333 m
.50625 .33333 L
s
gsave
.4875 .33333 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .66667 m
.50625 .66667 L
s
gsave
.4875 .66667 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .83333 m
.50625 .83333 L
s
gsave
.4875 .83333 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.01 w
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.141 1 0 r
.5 Mabswid
.54938 .32879 m
.5812 .33771 L
.60984 .35299 L
.63416 .37405 L
.65322 .40005 L
.66627 .42997 L
.67279 .46264 L
.67253 .49678 L
.6655 .53104 L
.65197 .56409 L
.63248 .59462 L
.60779 .62144 L
.57887 .64349 L
.54686 .65991 L
.513 .67005 L
.47864 .67352 L
.44511 .67018 L
.41374 .66016 L
.38575 .64386 L
.36225 .6219 L
.34415 .59517 L
.33217 .5647 L
.32678 .53169 L
.32818 .49744 L
.33633 .46329 L
.3509 .43058 L
.37132 .40059 L
.3968 .3745 L
.42632 .35334 L
.45873 .33794 L
.49277 .3289 L
.52709 .32657 L
.56034 .33104 L
.59123 .34215 L
.61854 .35946 L
.64119 .38228 L
.6583 .40971 L
.6692 .4407 L
.67346 .47401 L
.67092 .50834 L
.66166 .54234 L
.64606 .57468 L
.62473 .60409 L
.5985 .62942 L
.56841 .64966 L
.53563 .66404 L
.50145 .67197 L
.46722 .67316 L
.43427 .66755 L
.40391 .65536 L
Mistroke
.37731 .63708 L
.35553 .61341 L
.33942 .5853 L
.32961 .55384 L
.32649 .52026 L
.33017 .4859 L
.34053 .45208 L
.35714 .42014 L
.37936 .39134 L
.40631 .36681 L
.43694 .3475 L
.47004 .33417 L
.50432 .32735 L
.53844 .32731 L
.57104 .33405 L
.60085 .3473 L
.62671 .36654 L
.64759 .39102 L
.66268 .41978 L
.67139 .45168 L
.67337 .48549 L
.66854 .51986 L
.65711 .55345 L
.6395 .58494 L
.61642 .6131 L
.58877 .63682 L
.55764 .65518 L
.52425 .66744 L
.4899 .67313 L
.45595 .67202 L
.42373 .66417 L
.3945 .64987 L
.36941 .62969 L
.34945 .60442 L
.3354 .57505 L
.3278 .54274 L
.32697 .50875 L
.33292 .47441 L
.34543 .44108 L
.36401 .41007 L
.38793 .38258 L
.41624 .3597 L
.44784 .34232 L
.48149 .33114 L
.51586 .32658 L
.54961 .32883 L
.58142 .33779 L
.61003 .35312 L
.63432 .37422 L
.65334 .40025 L
Mistroke
.66634 .4302 L
.67281 .46289 L
.6725 .49703 L
.66543 .53129 L
.65185 .56432 L
.63232 .59483 L
.6076 .62161 L
.57865 .64362 L
.54662 .66 L
.51276 .6701 L
.47839 .67352 L
.44488 .67013 L
.41352 .66006 L
.38556 .64372 L
.3621 .62173 L
.34404 .59496 L
.33211 .56447 L
.32676 .53145 L
.32822 .49719 L
.33641 .46305 L
.35103 .43035 L
.37149 .40039 L
.39699 .37433 L
.42654 .35321 L
.45897 .33785 L
.49301 .32885 L
.52733 .32657 L
.56057 .3311 L
.59144 .34226 L
.61872 .3596 L
.64133 .38246 L
.6584 .40993 L
.66926 .44093 L
.67347 .47425 L
.67087 .50858 L
.66157 .54258 L
.64593 .5749 L
.62456 .60429 L
.5983 .62958 L
.56818 .64979 L
.53539 .66412 L
.50121 .672 L
.46698 .67314 L
.43405 .66748 L
.4037 .65525 L
.37714 .63693 L
.35539 .61323 L
.33932 .58509 L
.32956 .5536 L
.32649 .52002 L
Mistroke
.33023 .48565 L
.34063 .45184 L
.35728 .41992 L
.37953 .39115 L
.40652 .36665 L
.43717 .34738 L
.47029 .3341 L
.50457 .32733 L
.53868 .32734 L
.57126 .33412 L
.60105 .34742 L
.62688 .3667 L
.64772 .39121 L
.66277 .42 L
.67143 .45192 L
.67336 .48573 L
.66849 .5201 L
.657 .55368 L
.63935 .58516 L
.61624 .61329 L
.58856 .63698 L
.55741 .65529 L
.524 .6675 L
.48965 .67314 L
.45571 .67199 L
.42351 .66409 L
.39431 .64975 L
.36925 .62953 L
.34933 .60422 L
.33532 .57483 L
.32777 .5425 L
.32699 .5085 L
.33299 .47417 L
.34555 .44085 L
.36417 .40985 L
.38812 .3824 L
.41646 .35955 L
.44808 .34222 L
.48173 .33108 L
.51611 .32657 L
.54985 .32887 L
.58164 .33788 L
.61022 .35326 L
.63447 .37439 L
.65345 .40045 L
.66641 .43043 L
.67284 .46313 L
.67248 .49727 L
.66535 .53153 L
.65173 .56455 L
Mistroke
.63216 .59503 L
Mfstroke
1 0 0 r
.54938 .32879 m
.5812 .33771 L
s
% Start of user PostScript
1.4813326 -5.1363763 2.4360207 -4.8688276 MAarrowhead1
% End of user PostScript
1 .158 0 r
.60984 .35299 m
.63416 .37405 L
s
% Start of user PostScript
3.2951048 -4.410197 4.0248694 -3.7784839 MAarrowhead1
% End of user PostScript
1 .473 0 r
.63248 .59462 m
.60779 .62144 L
s
% Start of user PostScript
3.974482 2.8385834 3.2337812 3.6430719 MAarrowhead1
% End of user PostScript
1 .788 0 r
.38575 .64386 m
.36225 .6219 L
s
% Start of user PostScript
-3.4274844 4.3156512 -4.1325781 3.6571427 MAarrowhead1
% End of user PostScript
.897 1 0 r
.37132 .40059 m
.3968 .3745 L
s
% Start of user PostScript
-3.8603215 -2.9823265 -3.0961358 -3.7648817 MAarrowhead1
% End of user PostScript
.581 1 0 r
.61854 .35946 m
.64119 .38228 L
s
% Start of user PostScript
3.5560616 -4.2163177 4.2357023 -3.5317444 MAarrowhead1
% End of user PostScript
.266 1 0 r
.62473 .60409 m
.5985 .62942 L
s
% Start of user PostScript
3.7418784 3.122761 2.9550557 3.8825149 MAarrowhead1
% End of user PostScript
0 1 .049 r
.37731 .63708 m
.35553 .61341 L
s
% Start of user PostScript
-3.6806938 4.1123067 -4.3341275 3.402428 MAarrowhead1
% End of user PostScript
0 1 .364 r
.37936 .39134 m
.40631 .36681 L
s
% Start of user PostScript
-3.6192841 -3.2597311 -2.8106972 -3.9958409 MAarrowhead1
% End of user PostScript
0 1 .679 r
.62671 .36654 m
.64759 .39102 L
s
% Start of user PostScript
3.8012426 -4.0037336 4.4277444 -3.269337 MAarrowhead1
% End of user PostScript
0 1 .995 r
.61642 .6131 m
.58877 .63682 L
s
% Start of user PostScript
3.4926747 3.393085 2.6632207 4.1047339 MAarrowhead1
% End of user PostScript
0 .69 1 r
.36941 .62969 m
.34945 .60442 L
s
% Start of user PostScript
-3.9175745 3.8907188 -4.5164493 3.132619 MAarrowhead1
% End of user PostScript
0 .375 1 r
.38793 .38258 m
.41624 .3597 L
s
% Start of user PostScript
-3.3621905 -3.5226747 -2.5127896 -4.2090732 MAarrowhead1
% End of user PostScript
0 .06 1 r
.63432 .37422 m
.65334 .40025 L
s
% Start of user PostScript
4.0295602 -3.7733878 4.6001438 -2.9924258 MAarrowhead1
% End of user PostScript
0 .535 1 r
.33117 .29476 m
.37946 .26014 L
.43247 .23494 L
.48814 .22014 L
.54427 .21633 L
.59867 .22365 L
.64919 .24181 L
.69386 .27011 L
.73091 .30743 L
.75891 .3523 L
.77675 .40297 L
.78372 .45746 L
.77956 .51361 L
.76443 .56922 L
.73892 .62212 L
.70403 .67023 L
.66114 .71166 L
.61192 .74478 L
.55831 .76829 L
.50241 .78127 L
.44642 .78322 L
.39253 .77405 L
.34285 .75412 L
.29935 .72422 L
.26372 .68552 L
.23736 .63955 L
.22131 .58809 L
.2162 .53318 L
.22223 .47696 L
.23915 .42165 L
.26632 .36941 L
.30265 .3223 L
.34673 .28216 L
.39683 .25058 L
.45097 .22878 L
.50704 .21762 L
.56284 .21755 L
.61616 .22856 L
.66493 .25023 L
.70722 .2817 L
.74139 .32173 L
.76608 .36876 L
.78032 .42094 L
.78357 .47623 L
.77568 .53245 L
.75698 .58739 L
.72819 .63891 L
.69044 .68497 L
.64523 .72377 L
.59431 .75379 L
Mistroke
.53969 .77386 L
.48351 .78317 L
.42798 .78137 L
.37528 .76853 L
.32747 .74515 L
.28643 .71214 L
.25378 .67082 L
.23078 .62278 L
.21836 .56993 L
.21698 .51434 L
.22672 .45818 L
.24718 .40366 L
.27756 .35293 L
.31667 .30796 L
.36297 .27054 L
.41466 .24212 L
.46969 .22381 L
.52591 .21635 L
.58112 .22002 L
.63314 .23468 L
.67994 .25975 L
.71967 .29425 L
.75079 .33683 L
.77206 .38581 L
.78265 .43927 L
.78215 .49511 L
.77058 .55114 L
.74839 .60517 L
.71645 .65507 L
.67601 .69889 L
.62867 .7349 L
.57628 .76169 L
.52089 .77821 L
.46469 .78381 L
.40987 .77827 L
.35858 .76182 L
.31285 .73508 L
.27446 .69912 L
.24493 .65535 L
.2254 .60548 L
.21665 .55147 L
.21902 .49544 L
.23242 .43959 L
.25632 .38611 L
.28978 .3371 L
.3315 .29448 L
.37982 .25993 L
.43287 .2348 L
.48854 .22008 L
.54467 .21634 L
Mistroke
.59905 .22374 L
.64953 .24198 L
.69415 .27034 L
.73115 .30772 L
.75908 .35265 L
.77684 .40335 L
.78373 .45786 L
.77949 .51401 L
.76428 .56961 L
.7387 .62249 L
.70375 .67055 L
.6608 .71192 L
.61155 .74498 L
.55791 .76842 L
.50201 .78133 L
.44602 .78319 L
.39215 .77394 L
.34252 .75394 L
.29906 .72398 L
.26349 .68522 L
.23721 .63919 L
.22124 .58771 L
.2162 .53277 L
.22231 .47656 L
.23931 .42126 L
.26655 .36905 L
.30294 .32199 L
.34707 .28191 L
.39721 .25038 L
.45137 .22866 L
.50745 .21758 L
.56323 .21759 L
.61653 .22868 L
.66526 .25042 L
.7075 .28195 L
.7416 .32204 L
.76622 .36912 L
.78038 .42133 L
.78355 .47663 L
.77559 .53285 L
.75681 .58778 L
.72795 .63926 L
.69015 .68528 L
.64488 .72402 L
.59393 .75398 L
.53929 .77396 L
.48311 .7832 L
.42759 .78132 L
.37492 .7684 L
.32715 .74494 L
Mistroke
.28617 .71188 L
.25358 .67049 L
.23066 .62242 L
.21831 .56954 L
.21701 .51394 L
.22683 .45778 L
.24736 .40328 L
.27781 .35258 L
.31698 .30767 L
.36333 .2703 L
.41504 .24195 L
.47009 .22372 L
.52632 .21634 L
.58151 .22009 L
.6335 .23483 L
.68025 .25997 L
.71993 .29453 L
.75098 .33716 L
.77217 .38617 L
.78269 .43966 L
.78211 .49551 L
.77046 .55154 L
.74819 .60555 L
.71619 .65541 L
.6757 .69918 L
.62831 .73512 L
.57589 .76184 L
.52049 .77829 L
.46429 .78381 L
.40948 .77819 L
.35823 .76166 L
.31255 .73486 L
.27422 .69884 L
.24475 .65501 L
.2253 .6051 L
.21663 .55107 L
.21908 .49503 L
.23256 .43919 L
.25653 .38574 L
.29006 .33677 L
.33182 .2942 L
.38019 .25971 L
.43326 .23466 L
.48895 .22001 L
.54507 .21636 L
.59942 .22383 L
.64988 .24215 L
.69444 .27058 L
.73138 .30802 L
.75924 .35299 L
Mistroke
.77692 .40373 L
Mfstroke
1 0 0 r
.33117 .29476 m
.37946 .26014 L
s
% Start of user PostScript
-5.0648138 -6.1572604 -3.6162495 -7.1956882 MAarrowhead1
% End of user PostScript
1 .158 0 r
.43247 .23494 m
.48814 .22014 L
s
% Start of user PostScript
-2.0257619 -7.9517142 -0.35577129 -8.3956674 MAarrowhead1
% End of user PostScript
1 .473 0 r
.77675 .40297 m
.78372 .45746 L
s
% Start of user PostScript
8.3023861 -2.9107504 8.5116055 -1.2763232 MAarrowhead1
% End of user PostScript
1 .788 0 r
.55831 .76829 m
.50241 .78127 L
s
% Start of user PostScript
1.7492311 8.0486636 0.072272007 8.4381784 MAarrowhead1
% End of user PostScript
.897 1 0 r
.22131 .58809 m
.2162 .53318 L
s
% Start of user PostScript
-8.3606484 2.6426705 -8.5140127 0.99526955 MAarrowhead1
% End of user PostScript
.581 1 0 r
.45097 .22878 m
.50704 .21762 L
s
% Start of user PostScript
-1.4707598 -8.1366841 0.21130745 -8.4713282 MAarrowhead1
% End of user PostScript
.266 1 0 r
.78032 .42094 m
.78357 .47623 L
s
% Start of user PostScript
8.4096356 -2.3716589 8.5069746 -0.7131118 MAarrowhead1
% End of user PostScript
0 1 .049 r
.53969 .77386 m
.48351 .78317 L
s
% Start of user PostScript
1.1906569 8.2156778 -0.49465248 8.4950801 MAarrowhead1
% End of user PostScript
0 1 .364 r
.21836 .56993 m
.21698 .51434 L
s
% Start of user PostScript
-8.4492932 2.0980162 -8.490499 0.43016294 MAarrowhead1
% End of user PostScript
0 1 .679 r
.46969 .22381 m
.52591 .21635 L
s
% Start of user PostScript
-0.9092331 -8.2855572 0.77744876 -8.5094077 MAarrowhead1
% End of user PostScript
0 1 .995 r
.78265 .43927 m
.78215 .49511 L
s
% Start of user PostScript
8.4795774 -1.822046 8.4646042 -0.14673686 MAarrowhead1
% End of user PostScript
0 .69 1 r
.52089 .77821 m
.46469 .78381 L
s
% Start of user PostScript
0.6268006 8.3462448 -1.0593825 8.5142951 MAarrowhead1
% End of user PostScript
0 .375 1 r
.21665 .55147 m
.21902 .49544 L
s
% Start of user PostScript
-8.5004545 1.5440544 -8.429319 -0.136852 MAarrowhead1
% End of user PostScript
0 .06 1 r
.48854 .22008 m
.54467 .21634 L
s
% Start of user PostScript
-0.34367273 -8.3976732 1.3401411 -8.509737 MAarrowhead1
% End of user PostScript
.544 1 0 r
.52845 .3014 m
.56665 .30602 L
.60223 .31825 L
.63379 .33762 L
.66011 .36335 L
.68014 .39445 L
.69311 .42969 L
.69849 .4677 L
.69608 .50697 L
.68598 .54596 L
.66858 .58315 L
.64456 .61708 L
.61487 .64642 L
.58067 .67 L
.54331 .68692 L
.50425 .6965 L
.46501 .69837 L
.42716 .69245 L
.39216 .67898 L
.36139 .65849 L
.33606 .63177 L
.31717 .59989 L
.30545 .56408 L
.30137 .52576 L
.30508 .48643 L
.31645 .44763 L
.33501 .41089 L
.36005 .37764 L
.39059 .3492 L
.42541 .32667 L
.46317 .31095 L
.50237 .30264 L
.54148 .30209 L
.57896 .30929 L
.61334 .32399 L
.64327 .34559 L
.66758 .37325 L
.68531 .40589 L
.69577 .44222 L
.69855 .48081 L
.69354 .52016 L
.68092 .55872 L
.66121 .59498 L
.63517 .6275 L
.60383 .65503 L
.56841 .67647 L
.53031 .69098 L
.49102 .698 L
.45208 .69724 L
.41502 .68875 L
Mistroke
.38129 .67285 L
.35223 .65016 L
.32896 .62158 L
.31241 .58823 L
.30322 .55142 L
.30175 .51259 L
.30806 .47327 L
.32191 .43499 L
.34274 .39927 L
.36975 .36749 L
.40187 .34092 L
.43784 .3206 L
.47625 .30731 L
.51559 .30158 L
.55432 .30365 L
.59092 .31342 L
.62395 .33051 L
.65211 .35425 L
.67431 .38371 L
.68966 .41774 L
.69758 .455 L
.69773 .49402 L
.69013 .53327 L
.67507 .57122 L
.65313 .60638 L
.62519 .63736 L
.59233 .66295 L
.55585 .68214 L
.51717 .69419 L
.47783 .69861 L
.43935 .69524 L
.40325 .68421 L
.37095 .66595 L
.34372 .64117 L
.32262 .61086 L
.30848 .57619 L
.30185 .53854 L
.30301 .49937 L
.31189 .46022 L
.32816 .42264 L
.35117 .38809 L
.38002 .35794 L
.41358 .33336 L
.45053 .31532 L
.48943 .30453 L
.52873 .30141 L
.56692 .30608 L
.60247 .31837 L
.634 .33778 L
.66028 .36356 L
Mistroke
.68026 .39469 L
.69317 .42996 L
.6985 .46797 L
.69604 .50725 L
.68588 .54624 L
.66843 .58341 L
.64437 .61731 L
.61464 .64661 L
.58042 .67015 L
.54303 .68701 L
.50396 .69654 L
.46474 .69835 L
.42689 .69238 L
.39192 .67886 L
.36119 .65831 L
.3359 .63156 L
.31706 .59964 L
.3054 .56381 L
.30137 .52548 L
.30514 .48615 L
.31655 .44736 L
.33517 .41063 L
.36025 .37742 L
.39082 .34901 L
.42568 .32653 L
.46345 .31086 L
.50265 .30261 L
.54175 .30211 L
.57922 .30937 L
.61357 .32412 L
.64347 .34577 L
.66773 .37347 L
.68542 .40614 L
.69582 .44249 L
.69854 .4811 L
.69347 .52045 L
.68081 .55899 L
.66105 .59523 L
.63497 .62772 L
.60359 .6552 L
.56815 .67659 L
.53003 .69106 L
.49073 .69802 L
.4518 .69721 L
.41476 .68866 L
.38107 .67271 L
.35204 .64998 L
.32882 .62136 L
.31231 .58798 L
.30318 .55115 L
Mistroke
.30177 .51231 L
.30813 .47299 L
.32203 .43472 L
.34291 .39902 L
.36996 .36728 L
.40211 .34075 L
.4381 .32048 L
.47653 .30724 L
.51587 .30157 L
.55459 .30369 L
.59117 .31351 L
.62417 .33065 L
.65229 .35444 L
.67444 .38394 L
.68975 .418 L
.6976 .45527 L
.69771 .4943 L
.69005 .53355 L
.67493 .57149 L
.65295 .60662 L
.62497 .63756 L
.59208 .66311 L
.55558 .68226 L
.51689 .69425 L
.47755 .69862 L
.43908 .69519 L
.40301 .68411 L
.37074 .66579 L
.34354 .64098 L
.32249 .61062 L
.3084 .57593 L
.30183 .53826 L
.30304 .49908 L
.31198 .45995 L
.3283 .42238 L
.35135 .38786 L
.38024 .35774 L
.41383 .3332 L
.45081 .31521 L
.48971 .30448 L
.52901 .30141 L
.56718 .30614 L
.60271 .31848 L
.63421 .33794 L
.66044 .36376 L
.68038 .39493 L
.69324 .43022 L
.69851 .46825 L
.69599 .50753 L
.68578 .54651 L
Mistroke
.66828 .58367 L
Mfstroke
1 0 0 r
.52845 .3014 m
.56665 .30602 L
s
% Start of user PostScript
0.85363896 -5.9579588 1.9994741 -5.8194097 MAarrowhead1
% End of user PostScript
1 .158 0 r
.60223 .31825 m
.63379 .33762 L
s
% Start of user PostScript
3.066838 -5.4524722 4.0138408 -4.8715471 MAarrowhead1
% End of user PostScript
1 .473 0 r
.66858 .58315 m
.64456 .61708 L
s
% Start of user PostScript
5.0574074 2.4946056 4.3369055 3.5124674 MAarrowhead1
% End of user PostScript
1 .788 0 r
.39216 .67898 m
.36139 .65849 L
s
% Start of user PostScript
-3.235287 5.3693834 -4.1582918 4.7545561 MAarrowhead1
% End of user PostScript
.897 1 0 r
.33501 .41089 m
.36005 .37764 L
s
% Start of user PostScript
-4.9496485 -2.6734457 -4.1984037 -3.6708292 MAarrowhead1
% End of user PostScript
.581 1 0 r
.61334 .32399 m
.64327 .34559 L
s
% Start of user PostScript
3.4001468 -5.2803379 4.2981296 -4.6322903 MAarrowhead1
% End of user PostScript
.266 1 0 r
.66121 .59498 m
.63517 .6275 L
s
% Start of user PostScript
4.8363985 2.8493199 4.0552443 3.8251186 MAarrowhead1
% End of user PostScript
0 1 .049 r
.38129 .67285 m
.35223 .65016 L
s
% Start of user PostScript
-3.5612346 5.1854346 -4.4331992 4.5048857 MAarrowhead1
% End of user PostScript
0 1 .364 r
.34274 .39927 m
.36975 .36749 L
s
% Start of user PostScript
-4.7177831 -3.0220332 -3.907586 -3.9751646 MAarrowhead1
% End of user PostScript
0 1 .679 r
.62395 .33051 m
.65211 .35425 L
s
% Start of user PostScript
3.7183716 -5.0847786 4.5633506 -4.3724834 MAarrowhead1
% End of user PostScript
0 1 .995 r
.65313 .60638 m
.62519 .63736 L
s
% Start of user PostScript
4.5939339 3.1913938 3.7555928 4.1208005 MAarrowhead1
% End of user PostScript
0 .69 1 r
.37095 .66595 m
.34372 .64117 L
s
% Start of user PostScript
-3.8713835 4.9784816 -4.6884396 4.2352303 MAarrowhead1
% End of user PostScript
0 .375 1 r
.35117 .38809 m
.38002 .35794 L
s
% Start of user PostScript
-4.4649883 -3.357214 -3.5994331 -4.2618649 MAarrowhead1
% End of user PostScript
0 .06 1 r
.634 .33778 m
.66028 .36356 L
s
% Start of user PostScript
4.0201005 -4.8666616 4.8083273 -4.0932787 MAarrowhead1
% End of user PostScript
1 0 .015 r
.27822 .36243 m
.31541 .31765 L
.35985 .28002 L
.40979 .25103 L
.46327 .2318 L
.51819 .22311 L
.5724 .22528 L
.62376 .23823 L
.67027 .26146 L
.7101 .29404 L
.74168 .33471 L
.76377 .38187 L
.77552 .43366 L
.77645 .48806 L
.76653 .54293 L
.74615 .59611 L
.71611 .64552 L
.67759 .68921 L
.6321 .72549 L
.58143 .75291 L
.52755 .7704 L
.4726 .77729 L
.41873 .77329 L
.36804 .75857 L
.32253 .7337 L
.28399 .69965 L
.25392 .65778 L
.23351 .6097 L
.22357 .55733 L
.22446 .5027 L
.23618 .44797 L
.25825 .39528 L
.2898 .3467 L
.3296 .30414 L
.3761 .26926 L
.42745 .24344 L
.48165 .22769 L
.53657 .22262 L
.59006 .22844 L
.64001 .24492 L
.68447 .27141 L
.72169 .30687 L
.7502 .34991 L
.7689 .39884 L
.77705 .45174 L
.77432 .50654 L
.76082 .56107 L
.73709 .61322 L
.70406 .66091 L
.66301 .7023 L
Mistroke
.61557 .73574 L
.56359 .75993 L
.50912 .77392 L
.45429 .77716 L
.40125 .76952 L
.35209 .75131 L
.30873 .72323 L
.27288 .68639 L
.24595 .64224 L
.22898 .5925 L
.22265 .53913 L
.22721 .48423 L
.24247 .42995 L
.26783 .37841 L
.30231 .33165 L
.34455 .2915 L
.39289 .25952 L
.44543 .23699 L
.50012 .22477 L
.5548 .22336 L
.60733 .23281 L
.65564 .25274 L
.69785 .28238 L
.73229 .32055 L
.75762 .36577 L
.77284 .41626 L
.77735 .47003 L
.77097 .52498 L
.75396 .57895 L
.72698 .62982 L
.6911 .6756 L
.64771 .71448 L
.59853 .74495 L
.54548 .7658 L
.49064 .77622 L
.43618 .7758 L
.38422 .76456 L
.3368 .74294 L
.29578 .71178 L
.26279 .6723 L
.2391 .62607 L
.22565 .57489 L
.22297 .52077 L
.23116 .46583 L
.2499 .41224 L
.27845 .36209 L
.31571 .31735 L
.36019 .27978 L
.41016 .25085 L
.46366 .2317 L
Mistroke
.51858 .22308 L
.57278 .22533 L
.62411 .23836 L
.67058 .26166 L
.71035 .29431 L
.74187 .33503 L
.76389 .38223 L
.77556 .43405 L
.77641 .48846 L
.76642 .54332 L
.74597 .59648 L
.71586 .64585 L
.67729 .6895 L
.63175 .72572 L
.58105 .75307 L
.52716 .77049 L
.47221 .7773 L
.41835 .77322 L
.36769 .75842 L
.32223 .73348 L
.28374 .69938 L
.25374 .65745 L
.23341 .60934 L
.22353 .55694 L
.22451 .50231 L
.2363 .44758 L
.25844 .39492 L
.29006 .34637 L
.32992 .30386 L
.37645 .26904 L
.42783 .24329 L
.48205 .22761 L
.53697 .22262 L
.59043 .22852 L
.64035 .24508 L
.68476 .27163 L
.72192 .30715 L
.75037 .35024 L
.769 .39921 L
.77706 .45213 L
.77426 .50693 L
.76069 .56146 L
.73689 .61358 L
.70379 .66123 L
.66269 .70257 L
.61521 .73595 L
.56321 .76007 L
.50873 .77398 L
.4539 .77715 L
.40088 .76943 L
Mistroke
.35176 .75114 L
.30845 .723 L
.27266 .6861 L
.24579 .6419 L
.2289 .59213 L
.22264 .53874 L
.22728 .48384 L
.24261 .42957 L
.26805 .37806 L
.30259 .33134 L
.34488 .29124 L
.39326 .25933 L
.44582 .23686 L
.50051 .22473 L
.55518 .22339 L
.60769 .23292 L
.65597 .25292 L
.69813 .28262 L
.73251 .32085 L
.75777 .36612 L
.77291 .41663 L
.77734 .47042 L
.77088 .52537 L
.7538 .57933 L
.72675 .63017 L
.69081 .6759 L
.64738 .71473 L
.59816 .74513 L
.54509 .76591 L
.49025 .77626 L
.43579 .77576 L
.38386 .76444 L
.33648 .74274 L
.29552 .71152 L
.26258 .67199 L
.23896 .62572 L
.22559 .57451 L
.22299 .52037 L
.23125 .46544 L
.25007 .41186 L
.27869 .36174 L
.316 .31705 L
.36053 .27954 L
.41054 .25068 L
.46405 .2316 L
.51898 .22306 L
.57316 .22539 L
.62447 .23849 L
.67089 .26186 L
.71061 .29457 L
Mistroke
.74206 .33535 L
Mfstroke
1 0 0 r
.27822 .36243 m
.31541 .31765 L
s
% Start of user PostScript
-6.6534691 -4.1271207 -5.537643 -5.4706148 MAarrowhead1
% End of user PostScript
1 .158 0 r
.35985 .28002 m
.40979 .25103 L
s
% Start of user PostScript
-4.2044866 -6.5994094 -2.7063212 -7.4692037 MAarrowhead1
% End of user PostScript
1 .473 0 r
.74168 .33471 m
.76377 .38187 L
s
% Start of user PostScript
7.2503193 -4.9585641 7.913193 -3.543848 MAarrowhead1
% End of user PostScript
1 .788 0 r
.6321 .72549 m
.58143 .75291 L
s
% Start of user PostScript
3.9629975 6.7645662 2.4427534 7.58724 MAarrowhead1
% End of user PostScript
.897 1 0 r
.25392 .65778 m
.23351 .6097 L
s
% Start of user PostScript
-7.3823163 4.7332541 -7.9945548 3.2911369 MAarrowhead1
% End of user PostScript
.581 1 0 r
.3761 .26926 m
.42745 .24344 L
s
% Start of user PostScript
-3.7171119 -6.9222184 -2.1764758 -7.6968591 MAarrowhead1
% End of user PostScript
.266 1 0 r
.7502 .34991 m
.7689 .39884 L
s
% Start of user PostScript
7.5061236 -4.5026932 8.0670475 -3.0347747 MAarrowhead1
% End of user PostScript
0 1 .049 r
.61557 .73574 m
.56359 .75993 L
s
% Start of user PostScript
3.4671026 7.0721914 1.9077835 7.7979395 MAarrowhead1
% End of user PostScript
0 1 .364 r
.24595 .64224 m
.22898 .5925 L
s
% Start of user PostScript
-7.6216037 4.267137 -8.1305907 2.7750457 MAarrowhead1
% End of user PostScript
0 1 .679 r
.39289 .25952 m
.44543 .23699 L
s
% Start of user PostScript
-3.2132469 -7.2143185 -1.6369749 -7.890369 MAarrowhead1
% End of user PostScript
0 1 .995 r
.75762 .36577 m
.77284 .41626 L
s
% Start of user PostScript
7.7286285 -4.026847 8.1851141 -2.5122382 MAarrowhead1
% End of user PostScript
0 .69 1 r
.59853 .74495 m
.54548 .7658 L
s
% Start of user PostScript
2.9558266 7.3484422 1.3643502 7.9740451 MAarrowhead1
% End of user PostScript
0 .375 1 r
.2391 .62607 m
.22565 .57489 L
s
% Start of user PostScript
-7.8270794 3.7820896 -8.230557 2.2466437 MAarrowhead1
% End of user PostScript
0 .06 1 r
.41016 .25085 m
.46366 .2317 L
s
% Start of user PostScript
-2.6951271 -7.4744137 -1.0902119 -8.0488749 MAarrowhead1
% End of user PostScript
.428 0 1 r
.38022 .76714 m
.33246 .74473 L
.29129 .71272 L
.2583 .67236 L
.2348 .62524 L
.22171 .5732 L
.21954 .51828 L
.22837 .46265 L
.24787 .40849 L
.27726 .35792 L
.31539 .31292 L
.36077 .27526 L
.41161 .24643 L
.46593 .22755 L
.52157 .21936 L
.57638 .22218 L
.62818 .23591 L
.67495 .26 L
.71486 .29351 L
.74634 .33512 L
.76815 .38321 L
.77943 .43588 L
.77975 .49106 L
.76908 .5466 L
.74786 .60031 L
.71691 .65008 L
.67745 .69396 L
.63102 .73023 L
.57945 .75746 L
.52477 .77459 L
.46911 .78094 L
.41466 .77627 L
.36356 .76075 L
.31782 .735 L
.27923 .70003 L
.2493 .65721 L
.22921 .60822 L
.21975 .55498 L
.22128 .49958 L
.23376 .4442 L
.25668 .39101 L
.28915 .3421 L
.3299 .29938 L
.37733 .26454 L
.42956 .23894 L
.48457 .22358 L
.54018 .21907 L
.59421 .22559 L
.64454 .24288 L
.6892 .27026 L
Mistroke
.72644 .30665 L
.75479 .35063 L
.77314 .40048 L
.78077 .45423 L
.77738 .50978 L
.7631 .56494 L
.7385 .61756 L
.70454 .66556 L
.66256 .70706 L
.61419 .74044 L
.56134 .76438 L
.50608 .77794 L
.45059 .7806 L
.39703 .77225 L
.34752 .75321 L
.30399 .72423 L
.26815 .68645 L
.24141 .64136 L
.22482 .59072 L
.21903 .53651 L
.22427 .48088 L
.24033 .42599 L
.26657 .37401 L
.30199 .32698 L
.34517 .28673 L
.39443 .25485 L
.44783 .2326 L
.50328 .22084 L
.5586 .22003 L
.61162 .23022 L
.66026 .25099 L
.70261 .28153 L
.73701 .32065 L
.76211 .36681 L
.77692 .41819 L
.78086 .47279 L
.77378 .52845 L
.75596 .58299 L
.72809 .63428 L
.69127 .6803 L
.64694 .71924 L
.59684 .74958 L
.54295 .77013 L
.48737 .78007 L
.43228 .77902 L
.37986 .76702 L
.33214 .74454 L
.29102 .71246 L
.2581 .67205 L
.23467 .62488 L
Mistroke
.22165 .57281 L
.21956 .51789 L
.22847 .46226 L
.24804 .40811 L
.2775 .35757 L
.31569 .31262 L
.36112 .27503 L
.41199 .24626 L
.46632 .22745 L
.52197 .21934 L
.57676 .22224 L
.62854 .23604 L
.67527 .26021 L
.71512 .29378 L
.74653 .33545 L
.76826 .38357 L
.77947 .43627 L
.77971 .49146 L
.76897 .54699 L
.74767 .60068 L
.71666 .65041 L
.67714 .69425 L
.63067 .73046 L
.57907 .75762 L
.52437 .77467 L
.46871 .78095 L
.41428 .7762 L
.36321 .7606 L
.31752 .73478 L
.27898 .69975 L
.24912 .65688 L
.2291 .60785 L
.21972 .55459 L
.22133 .49918 L
.23389 .44381 L
.25688 .39064 L
.28942 .34177 L
.33022 .2991 L
.37769 .26432 L
.42995 .23879 L
.48497 .22351 L
.54057 .21908 L
.59458 .22568 L
.64488 .24304 L
.6895 .27049 L
.72667 .30694 L
.75496 .35097 L
.77323 .40085 L
.78078 .45462 L
.77732 .51018 L
Mistroke
.76296 .56533 L
.73829 .61792 L
.70427 .66588 L
.66223 .70733 L
.61382 .74064 L
.56095 .76451 L
.50568 .778 L
.45019 .78058 L
.39666 .77215 L
.34718 .75303 L
.3037 .72399 L
.26792 .68615 L
.24125 .64101 L
.22474 .59034 L
.21903 .53612 L
.22434 .48048 L
.24048 .42561 L
.2668 .37365 L
.30227 .32666 L
.3455 .28647 L
.3948 .25466 L
.44822 .23248 L
.50368 .22079 L
.55899 .22007 L
.61199 .23033 L
.66059 .25117 L
.70289 .28178 L
.73722 .32096 L
.76225 .36716 L
.77699 .41857 L
.78085 .47318 L
.77369 .52885 L
.75579 .58338 L
.72785 .63463 L
.69097 .68061 L
.6466 .71949 L
.59647 .74977 L
.54255 .77024 L
.48697 .7801 L
.4319 .77897 L
.37949 .76689 L
.33182 .74434 L
.29075 .7122 L
.25789 .67173 L
.23454 .62452 L
.2216 .57243 L
.21958 .51749 L
.22858 .46186 L
.24822 .40773 L
.27775 .35723 L
Mistroke
.316 .31232 L
Mfstroke
1 0 0 r
.38022 .76714 m
.33246 .74473 L
s
% Start of user PostScript
-3.5934854 8.0142465 -5.0260731 7.3420371 MAarrowhead1
% End of user PostScript
1 .158 0 r
.29129 .71272 m
.2583 .67236 L
s
% Start of user PostScript
-6.2614076 6.3816823 -7.2510071 5.1708721 MAarrowhead1
% End of user PostScript
1 .473 0 r
.31539 .31292 m
.36077 .27526 L
s
% Start of user PostScript
-5.5382098 -5.6124041 -4.1768561 -6.7420505 MAarrowhead1
% End of user PostScript
1 .788 0 r
.71486 .29351 m
.74634 .33512 L
s
% Start of user PostScript
6.4458708 -6.1947478 7.3901272 -4.9463121 MAarrowhead1
% End of user PostScript
.897 1 0 r
.67745 .69396 m
.63102 .73023 L
s
% Start of user PostScript
5.3235147 5.8187349 3.9307103 6.9067992 MAarrowhead1
% End of user PostScript
.581 1 0 r
.27923 .70003 m
.2493 .65721 L
s
% Start of user PostScript
-6.6231832 6.000941 -7.5210489 4.7162647 MAarrowhead1
% End of user PostScript
.266 1 0 r
.3299 .29938 m
.37733 .26454 L
s
% Start of user PostScript
-5.1029138 -6.0186106 -3.6802039 -7.0638856 MAarrowhead1
% End of user PostScript
0 1 .049 r
.72644 .30665 m
.75479 .35063 L
s
% Start of user PostScript
6.7931479 -5.8004768 7.6436268 -4.4809852 MAarrowhead1
% End of user PostScript
0 1 .364 r
.66256 .70706 m
.61419 .74044 L
s
% Start of user PostScript
4.8766519 6.2118092 3.4256147 7.2131355 MAarrowhead1
% End of user PostScript
0 1 .679 r
.26815 .68645 m
.24141 .64136 L
s
% Start of user PostScript
-6.9555764 5.5935777 -7.7577251 4.2407346 MAarrowhead1
% End of user PostScript
0 1 .995 r
.34517 .28673 m
.39443 .25485 L
s
% Start of user PostScript
-4.6449798 -6.3981167 -3.1672252 -7.3543832 MAarrowhead1
% End of user PostScript
0 .69 1 r
.73701 .32065 m
.76211 .36681 L
s
% Start of user PostScript
7.1102885 -5.3804732 7.8632171 -3.9957793 MAarrowhead1
% End of user PostScript
0 .375 1 r
.64694 .71924 m
.59684 .74958 L
s
% Start of user PostScript
4.4081548 6.5773261 2.9053221 7.4874722 MAarrowhead1
% End of user PostScript
0 .06 1 r
.2581 .67205 m
.23467 .62488 L
s
% Start of user PostScript
-7.2571126 5.1613997 -7.9599857 3.7463912 MAarrowhead1
% End of user PostScript
.101 1 0 r
.24115 .56806 m
.23913 .51698 L
.24736 .46524 L
.2655 .41486 L
.29284 .36782 L
.32831 .32597 L
.37052 .29095 L
.41782 .26413 L
.46833 .24658 L
.5201 .23896 L
.57107 .24159 L
.61925 .25437 L
.66275 .27678 L
.69987 .30796 L
.72914 .34667 L
.74942 .39139 L
.75991 .44039 L
.7602 .49172 L
.75028 .54337 L
.73053 .59332 L
.70174 .63962 L
.66503 .68043 L
.62184 .71416 L
.57388 .73948 L
.52301 .75541 L
.47124 .76131 L
.4206 .75696 L
.37307 .74252 L
.33053 .71857 L
.29463 .68604 L
.2668 .6462 L
.24812 .60063 L
.23933 .55111 L
.24076 .49958 L
.25237 .44807 L
.2737 .3986 L
.30391 .3531 L
.34181 .31338 L
.38592 .28097 L
.43451 .25717 L
.48567 .24289 L
.5374 .2387 L
.58765 .24477 L
.63447 .26085 L
.676 .28632 L
.71063 .32018 L
.737 .36109 L
.75406 .40746 L
.76115 .45746 L
.75799 .50912 L
Mistroke
.74471 .56043 L
.72182 .60937 L
.69023 .65401 L
.65117 .69261 L
.60618 .72365 L
.55702 .74592 L
.50563 .75853 L
.45401 .761 L
.4042 .75322 L
.35814 .7355 L
.31766 .70855 L
.28433 .6734 L
.25947 .63146 L
.24404 .58435 L
.23866 .53393 L
.24354 .48218 L
.25848 .43113 L
.2829 .38279 L
.31584 .33904 L
.35601 .30161 L
.40183 .27197 L
.4515 .25127 L
.50308 .24034 L
.55453 .2396 L
.60385 .24908 L
.64909 .2684 L
.68847 .29682 L
.72047 .3332 L
.7438 .37614 L
.75758 .42393 L
.76124 .47472 L
.75465 .52649 L
.73806 .57722 L
.71213 .62493 L
.67788 .66773 L
.63665 .70394 L
.59005 .73216 L
.53992 .75126 L
.48822 .7605 L
.43699 .75952 L
.38822 .74835 L
.34385 .72744 L
.3056 .6976 L
.27498 .66 L
.2532 .61613 L
.2411 .5677 L
.23916 .51661 L
.24745 .46487 L
.26566 .41451 L
.29307 .3675 L
Mistroke
.32859 .32569 L
.37085 .29073 L
.41817 .26397 L
.4687 .24649 L
.52047 .23895 L
.57143 .24165 L
.61958 .2545 L
.66304 .27698 L
.70011 .30821 L
.72932 .34697 L
.74953 .39173 L
.75995 .44075 L
.76016 .49209 L
.75017 .54374 L
.73036 .59367 L
.7015 .63993 L
.66474 .6807 L
.62151 .71437 L
.57352 .73963 L
.52264 .75549 L
.47087 .76132 L
.42024 .75689 L
.37275 .74238 L
.33024 .71836 L
.2944 .68577 L
.26663 .64589 L
.24802 .60029 L
.2393 .55074 L
.24081 .49921 L
.25249 .44771 L
.27388 .39825 L
.30415 .3528 L
.34211 .31312 L
.38626 .28077 L
.43487 .25703 L
.48605 .24282 L
.53776 .23871 L
.588 .24485 L
.63479 .261 L
.67628 .28654 L
.71085 .32045 L
.73715 .36141 L
.75415 .40781 L
.76117 .45782 L
.75793 .50949 L
.74458 .56079 L
.72163 .60971 L
.68998 .65431 L
.65087 .69286 L
.60584 .72385 L
Mistroke
.55666 .74604 L
.50526 .75858 L
.45364 .76098 L
.40385 .75313 L
.35783 .73534 L
.31739 .70832 L
.28412 .67313 L
.25932 .63113 L
.24397 .584 L
.23866 .53356 L
.24361 .48181 L
.25862 .43078 L
.28311 .38246 L
.3161 .33875 L
.35632 .30137 L
.40217 .27179 L
.45187 .25116 L
.50345 .2403 L
.5549 .23963 L
.60419 .24918 L
.64939 .26857 L
.68873 .29705 L
.72067 .33349 L
.74394 .37647 L
.75764 .42429 L
.76123 .47509 L
.75456 .52686 L
.73791 .57758 L
.71192 .62525 L
.67761 .66801 L
.63633 .70418 L
.5897 .73233 L
.53955 .75136 L
.48785 .76053 L
.43663 .75948 L
.38789 .74824 L
.34355 .72725 L
.30535 .69735 L
.27479 .65971 L
.25307 .6158 L
.24104 .56734 L
.23918 .51624 L
.24755 .4645 L
.26583 .41415 L
.29329 .36718 L
.32887 .32542 L
.37117 .2905 L
.41852 .26381 L
.46907 .24639 L
.52084 .23893 L
Mistroke
.57178 .24171 L
Mfstroke
1 0 0 r
.24115 .56806 m
.23913 .51698 L
s
% Start of user PostScript
-7.765618 2.0416627 -7.8260226 0.50935519 MAarrowhead1
% End of user PostScript
1 .158 0 r
.24736 .46524 m
.2655 .41486 L
s
% Start of user PostScript
-7.5792874 -1.0429425 -7.0350957 -2.5543088 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57107 .24159 m
.61925 .25437 L
s
% Start of user PostScript
2.1320325 -7.7521555 3.5775204 -7.3689559 MAarrowhead1
% End of user PostScript
1 .788 0 r
.75028 .54337 m
.73053 .59332 L
s
% Start of user PostScript
7.508275 1.3011465 6.9159378 2.7997495 MAarrowhead1
% End of user PostScript
.897 1 0 r
.4206 .75696 m
.37307 .74252 L
s
% Start of user PostScript
-2.3821135 7.7088178 -3.8078722 7.2757036 MAarrowhead1
% End of user PostScript
.581 1 0 r
.25237 .44807 m
.2737 .3986 L
s
% Start of user PostScript
-7.428933 -1.557907 -6.7891076 -3.0420841 MAarrowhead1
% End of user PostScript
.266 1 0 r
.58765 .24477 m
.63447 .26085 L
s
% Start of user PostScript
2.6295518 -7.656928 4.0339996 -7.1743798 MAarrowhead1
% End of user PostScript
0 1 .049 r
.74471 .56043 m
.72182 .60937 L
s
% Start of user PostScript
7.3413495 1.8129392 6.6547456 3.2810439 MAarrowhead1
% End of user PostScript
0 1 .364 r
.4042 .75322 m
.35814 .7355 L
s
% Start of user PostScript
-2.8740729 7.5965437 -4.2556517 7.0650968 MAarrowhead1
% End of user PostScript
0 1 .679 r
.25848 .43113 m
.2829 .38279 L
s
% Start of user PostScript
-7.2456217 -2.0659602 -6.513001 -3.5163637 MAarrowhead1
% End of user PostScript
0 1 .995 r
.60385 .24908 m
.64909 .2684 L
s
% Start of user PostScript
3.1154056 -7.527732 4.4725827 -6.9479759 MAarrowhead1
% End of user PostScript
0 .69 1 r
.73806 .57722 m
.71213 .62493 L
s
% Start of user PostScript
7.1418557 2.3166892 6.364031 3.7477826 MAarrowhead1
% End of user PostScript
0 .375 1 r
.38822 .74835 m
.34385 .72744 L
s
% Start of user PostScript
-3.3532821 7.4505691 -4.6845519 6.8231471 MAarrowhead1
% End of user PostScript
0 .06 1 r
.26566 .41451 m
.29307 .3675 L
s
% Start of user PostScript
-7.0301666 -2.5648481 -6.2080009 -3.9750438 MAarrowhead1
% End of user PostScript
0 1 .096 r
.49316 .18767 m
.55552 .18468 L
.61571 .19407 L
.67135 .21546 L
.72026 .24803 L
.76054 .29048 L
.79058 .34115 L
.80923 .39806 L
.81573 .45897 L
.80985 .52149 L
.7918 .58316 L
.76231 .64157 L
.72252 .69443 L
.67399 .73965 L
.61864 .77547 L
.55863 .80048 L
.49632 .8137 L
.43416 .8146 L
.37457 .80316 L
.31992 .77982 L
.27232 .7455 L
.23367 .70154 L
.20547 .64967 L
.18882 .59193 L
.18439 .53058 L
.19235 .46804 L
.21237 .40674 L
.24369 .34911 L
.28507 .29739 L
.33488 .25363 L
.39117 .21954 L
.45173 .19646 L
.51419 .18528 L
.57609 .18646 L
.63501 .19995 L
.68862 .22521 L
.73483 .26125 L
.77183 .30667 L
.79816 .35967 L
.81279 .41818 L
.81514 .4799 L
.80512 .54241 L
.78313 .60325 L
.75003 .66005 L
.70711 .71056 L
.65607 .75281 L
.5989 .78513 L
.53785 .80627 L
.47531 .81539 L
.41375 .81213 L
Mistroke
.35556 .79661 L
.30305 .76946 L
.25827 .73174 L
.22297 .68491 L
.19855 .63084 L
.18595 .57162 L
.18569 .5096 L
.19775 .4472 L
.22168 .38687 L
.25653 .33098 L
.30094 .28172 L
.35316 .24103 L
.41114 .21051 L
.47261 .19134 L
.53516 .18429 L
.59632 .18963 L
.65371 .20715 L
.70506 .23617 L
.74836 .27553 L
.78192 .32371 L
.80441 .37881 L
.81496 .43866 L
.81314 .50092 L
.79904 .56314 L
.7732 .62289 L
.73664 .67781 L
.69079 .72575 L
.63745 .76484 L
.57872 .79353 L
.5169 .8107 L
.45441 .81568 L
.39372 .80826 L
.33719 .78875 L
.28706 .75791 L
.24528 .71695 L
.2135 .66747 L
.19297 .61142 L
.18448 .55099 L
.18837 .48857 L
.2045 .42659 L
.23222 .3675 L
.27046 .3136 L
.3177 .26702 L
.37209 .22958 L
.43151 .20276 L
.49361 .1876 L
.55597 .18471 L
.61612 .19418 L
.67172 .21566 L
.72059 .2483 L
Mistroke
.76079 .29081 L
.79076 .34154 L
.80932 .39848 L
.81573 .45941 L
.80976 .52193 L
.79163 .58359 L
.76206 .64197 L
.7222 .69478 L
.67362 .73995 L
.61822 .77569 L
.55819 .80062 L
.49587 .81375 L
.43372 .81456 L
.37416 .80303 L
.31955 .77961 L
.27201 .74521 L
.23343 .70119 L
.2053 .64928 L
.18875 .5915 L
.1844 .53014 L
.19245 .46759 L
.21256 .40631 L
.24395 .34871 L
.2854 .29705 L
.33526 .25335 L
.39159 .21933 L
.45218 .19633 L
.51464 .18525 L
.57653 .18652 L
.63541 .20009 L
.68898 .22543 L
.73513 .26154 L
.77206 .30702 L
.79831 .36007 L
.81285 .41861 L
.81511 .48035 L
.805 .54285 L
.78293 .60368 L
.74975 .66043 L
.70677 .71089 L
.65568 .75308 L
.59847 .78533 L
.5374 .80638 L
.47486 .81541 L
.41331 .81206 L
.35516 .79646 L
.3027 .76923 L
.25798 .73143 L
.22276 .68455 L
.19841 .63043 L
Mistroke
.18591 .57118 L
.18573 .50915 L
.19788 .44675 L
.22189 .38645 L
.25682 .3306 L
.30129 .2814 L
.35356 .24078 L
.41157 .21033 L
.47306 .19125 L
.5356 .18429 L
.59675 .18972 L
.6541 .20732 L
.7054 .23641 L
.74864 .27585 L
.78212 .32408 L
.80453 .37922 L
.81499 .4391 L
.81309 .50137 L
.79889 .56358 L
.77297 .6233 L
.73634 .67818 L
.69043 .72607 L
.63704 .76508 L
.57828 .79369 L
.51645 .81078 L
.45397 .81567 L
.3933 .80817 L
.33681 .78857 L
.28673 .75765 L
.24502 .71662 L
.21331 .66709 L
.19286 .611 L
.18446 .55055 L
.18845 .48812 L
.20466 .42615 L
.23246 .36709 L
.27077 .31324 L
.31806 .26672 L
.3725 .22935 L
.43195 .20261 L
.49406 .18754 L
.55641 .18473 L
.61654 .19429 L
.6721 .21586 L
.72091 .24857 L
.76104 .29115 L
.79093 .34193 L
.80941 .39891 L
.81574 .45986 L
.80967 .52238 L
Mistroke
.79146 .58403 L
Mfstroke
1 0 0 r
.49316 .18767 m
.55552 .18468 L
s
% Start of user PostScript
-0.20510049 -9.3699497 1.6657342 -9.4595493 MAarrowhead1
% End of user PostScript
1 .158 0 r
.61571 .19407 m
.67135 .21546 L
s
% Start of user PostScript
3.4711955 -9.1778996 5.1404264 -8.5360544 MAarrowhead1
% End of user PostScript
1 .473 0 r
.7918 .58316 m
.76231 .64157 L
s
% Start of user PostScript
8.7540934 2.4948506 7.8691909 4.2472085 MAarrowhead1
% End of user PostScript
1 .788 0 r
.37457 .80316 m
.31992 .77982 L
s
% Start of user PostScript
-3.7627714 9.0948027 -5.4025285 8.394591 MAarrowhead1
% End of user PostScript
.897 1 0 r
.21237 .40674 m
.24369 .34911 L
s
% Start of user PostScript
-8.6287653 -2.7977747 -7.6892468 -4.5268103 MAarrowhead1
% End of user PostScript
.581 1 0 r
.63501 .19995 m
.68862 .22521 L
s
% Start of user PostScript
4.050173 -9.0016162 5.6586372 -8.2438149 MAarrowhead1
% End of user PostScript
.266 1 0 r
.78313 .60325 m
.75003 .66005 L
s
% Start of user PostScript
8.4938647 3.0975949 7.5007725 4.8013902 MAarrowhead1
% End of user PostScript
0 1 .049 r
.35556 .79661 m
.30305 .76946 L
s
% Start of user PostScript
-4.3330814 8.8984434 -5.9084683 8.0838931 MAarrowhead1
% End of user PostScript
0 1 .364 r
.22168 .38687 m
.25653 .33098 L
s
% Start of user PostScript
-8.3495411 -3.3939787 -7.3039769 -5.0706435 MAarrowhead1
% End of user PostScript
0 1 .679 r
.65371 .20715 m
.70506 .23617 L
s
% Start of user PostScript
4.6111827 -8.7853988 6.1517446 -7.9150033 MAarrowhead1
% End of user PostScript
0 1 .995 r
.7732 .62289 m
.73664 .67781 L
s
% Start of user PostScript
8.1959547 3.6865974 7.0990784 5.3342715 MAarrowhead1
% End of user PostScript
0 .69 1 r
.33719 .78875 m
.28706 .75791 L
s
% Start of user PostScript
-4.8841685 8.6626079 -6.3881963 7.7373327 MAarrowhead1
% End of user PostScript
0 .375 1 r
.23222 .3675 m
.27046 .3136 L
s
% Start of user PostScript
-8.0332758 -3.9751261 -6.8863043 -5.5919818 MAarrowhead1
% End of user PostScript
0 .06 1 r
.67172 .21566 m
.72059 .2483 L
s
% Start of user PostScript
5.1517359 -8.5302069 6.6175611 -7.5510784 MAarrowhead1
% End of user PostScript
1 0 .819 r
.32873 .34965 m
.36622 .31484 L
.40896 .28729 L
.45527 .2681 L
.50333 .258 L
.55127 .2574 L
.59719 .26632 L
.6393 .28441 L
.67594 .31097 L
.70568 .34494 L
.72734 .385 L
.74009 .42957 L
.74341 .4769 L
.73717 .52514 L
.72163 .5724 L
.69739 .61681 L
.66541 .65664 L
.62693 .69032 L
.58347 .71654 L
.53674 .73425 L
.48856 .74277 L
.44083 .74176 L
.39543 .73127 L
.35413 .7117 L
.31855 .68382 L
.29009 .64872 L
.26988 .60779 L
.25869 .56263 L
.25698 .51501 L
.2648 .4668 L
.28185 .4199 L
.30746 .37614 L
.34064 .33724 L
.38006 .30472 L
.42419 .27987 L
.4713 .26366 L
.51953 .25673 L
.567 .25934 L
.61184 .2714 L
.65229 .29243 L
.68676 .3216 L
.7139 .35778 L
.73265 .39954 L
.74226 .44524 L
.74237 .49309 L
.73297 .54121 L
.71442 .58772 L
.68746 .63078 L
.65314 .66871 L
.61282 .70001 L
Mistroke
.56806 .72347 L
.52063 .73816 L
.47239 .7435 L
.42524 .73929 L
.38102 .72568 L
.34147 .70321 L
.30814 .67278 L
.28234 .63556 L
.26509 .59302 L
.25705 .54683 L
.25855 .4988 L
.26952 .45082 L
.28954 .40477 L
.31782 .36245 L
.35325 .32554 L
.39443 .29547 L
.43977 .27343 L
.48746 .26028 L
.53565 .25654 L
.58244 .26235 L
.62599 .27749 L
.6646 .30137 L
.69675 .33303 L
.72117 .37126 L
.73692 .41453 L
.74337 .46116 L
.74027 .50931 L
.72773 .5571 L
.70627 .60264 L
.6767 .64416 L
.6402 .68002 L
.5982 .70882 L
.55234 .72942 L
.50443 .74101 L
.45635 .74315 L
.40998 .73575 L
.36714 .71909 L
.32952 .69383 L
.29858 .66097 L
.27556 .62179 L
.26134 .57783 L
.25648 .53081 L
.26119 .48259 L
.27526 .43505 L
.29816 .39006 L
.32898 .34938 L
.36651 .31462 L
.40928 .28713 L
.45561 .26799 L
.50368 .25796 L
Mistroke
.55161 .25743 L
.59751 .26642 L
.63958 .28457 L
.67618 .31118 L
.70586 .34521 L
.72747 .3853 L
.74014 .4299 L
.74339 .47725 L
.73709 .52549 L
.72149 .57273 L
.69719 .61712 L
.66515 .65691 L
.62664 .69054 L
.58315 .71669 L
.5364 .73434 L
.48822 .7428 L
.4405 .74172 L
.39512 .73116 L
.35385 .71152 L
.31832 .68359 L
.28992 .64845 L
.26976 .60748 L
.25865 .5623 L
.257 .51467 L
.26489 .46646 L
.282 .41957 L
.30768 .37584 L
.3409 .33698 L
.38036 .30452 L
.42452 .27973 L
.47164 .26358 L
.51988 .25671 L
.56733 .2594 L
.61215 .27152 L
.65256 .29261 L
.68698 .32184 L
.71407 .35806 L
.73275 .39986 L
.7423 .44558 L
.74234 .49344 L
.73287 .54155 L
.71426 .58804 L
.68724 .63107 L
.65287 .66896 L
.61251 .70021 L
.56773 .72361 L
.52029 .73823 L
.47205 .7435 L
.42491 .73922 L
.38072 .72555 L
Mistroke
.34121 .70302 L
.30793 .67253 L
.28219 .63527 L
.26499 .5927 L
.25702 .54649 L
.25859 .49845 L
.26963 .45048 L
.28971 .40445 L
.31805 .36217 L
.35352 .3253 L
.39475 .29528 L
.4401 .2733 L
.48781 .26022 L
.53599 .25655 L
.58276 .26243 L
.62629 .27763 L
.66485 .30157 L
.69695 .33329 L
.72132 .37155 L
.737 .41485 L
.74338 .4615 L
.74021 .50966 L
.72761 .55743 L
.70608 .60296 L
.67646 .64444 L
.63992 .68026 L
.59788 .709 L
.552 .72953 L
.50409 .74106 L
.45601 .74313 L
.40966 .73566 L
.36685 .71894 L
.32927 .69362 L
.29839 .66071 L
.27542 .62149 L
.26127 .5775 L
.25648 .53047 L
.26126 .48225 L
.2754 .43472 L
.29835 .38975 L
.32922 .34911 L
.3668 .31439 L
.4096 .28696 L
.45595 .26789 L
.50402 .25792 L
.55194 .25746 L
.59782 .26652 L
.63987 .28474 L
.67642 .3114 L
.70605 .34547 L
Mistroke
.72759 .38561 L
Mfstroke
1 0 0 r
.32873 .34965 m
.36622 .31484 L
s
% Start of user PostScript
-5.1380499 -4.5103793 -4.0134485 -5.5547727 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40896 .28729 m
.45527 .2681 L
s
% Start of user PostScript
-2.7313353 -6.3811636 -1.3420283 -6.9571196 MAarrowhead1
% End of user PostScript
1 .473 0 r
.72734 .385 m
.74009 .42957 L
s
% Start of user PostScript
6.8202715 -3.4501151 7.202551 -2.1129812 MAarrowhead1
% End of user PostScript
1 .788 0 r
.58347 .71654 m
.53674 .73425 L
s
% Start of user PostScript
2.50417 6.4960779 1.1021302 7.0274975 MAarrowhead1
% End of user PostScript
.897 1 0 r
.26988 .60779 m
.25869 .56263 L
s
% Start of user PostScript
-6.9036788 3.2337478 -7.2392601 1.8789137 MAarrowhead1
% End of user PostScript
.581 1 0 r
.42419 .27987 m
.4713 .26366 L
s
% Start of user PostScript
-2.2742265 -6.6037856 -0.86100942 -7.0900792 MAarrowhead1
% End of user PostScript
.266 1 0 r
.73265 .39954 m
.74226 .44524 L
s
% Start of user PostScript
6.9794273 -3.013793 7.267938 -1.6427617 MAarrowhead1
% End of user PostScript
0 1 .049 r
.56806 .72347 m
.52063 .73816 L
s
% Start of user PostScript
2.0417601 6.7041671 0.61893344 7.1447953 MAarrowhead1
% End of user PostScript
0 1 .364 r
.26509 .59302 m
.25705 .54683 L
s
% Start of user PostScript
-7.047433 2.7904947 -7.2885531 1.4047873 MAarrowhead1
% End of user PostScript
0 1 .679 r
.43977 .27343 m
.48746 .26028 L
s
% Start of user PostScript
-1.8070285 -6.7971112 -0.37617084 -7.1915851 MAarrowhead1
% End of user PostScript
0 1 .995 r
.73692 .41453 m
.74337 .46116 L
s
% Start of user PostScript
7.1076204 -2.5641008 7.3010823 -1.1652545 MAarrowhead1
% End of user PostScript
0 .69 1 r
.55234 .72942 m
.50443 .74101 L
s
% Start of user PostScript
1.5702923 6.8825147 0.13299092 7.2303966 MAarrowhead1
% End of user PostScript
0 .375 1 r
.26134 .57783 m
.25648 .53081 L
s
% Start of user PostScript
-7.1599227 2.3348622 -7.3055119 0.92442889 MAarrowhead1
% End of user PostScript
0 .06 1 r
.45561 .26799 m
.50368 .25796 L
s
% Start of user PostScript
-1.3318141 -6.9602828 0.11033655 -7.261187 MAarrowhead1
% End of user PostScript
0 1 .146 r
.27801 .46757 m
.29433 .42329 L
.31871 .38203 L
.35021 .34539 L
.38759 .31483 L
.42938 .29153 L
.47394 .27641 L
.51952 .27007 L
.56434 .27275 L
.60663 .28435 L
.64474 .30441 L
.67717 .33215 L
.70264 .36647 L
.72016 .40604 L
.72904 .4493 L
.72894 .49454 L
.71984 .54 L
.70212 .58389 L
.67647 .62448 L
.64389 .6602 L
.60566 .68962 L
.56329 .7116 L
.51843 .72528 L
.47285 .73012 L
.42834 .72592 L
.38663 .71286 L
.34938 .69145 L
.31804 .66252 L
.29384 .62721 L
.27773 .58691 L
.27034 .5432 L
.27197 .4978 L
.28254 .45248 L
.30166 .40902 L
.32855 .36914 L
.36217 .33439 L
.40121 .30614 L
.44412 .2855 L
.48922 .27328 L
.53474 .26996 L
.57891 .27566 L
.61997 .29017 L
.65633 .31291 L
.68655 .343 L
.70945 .37925 L
.72413 .42023 L
.73002 .46435 L
.72687 .50987 L
.71483 .555 L
.69435 .59797 L
Mistroke
.66624 .63709 L
.63161 .67084 L
.59182 .69788 L
.54842 .71715 L
.50312 .72791 L
.4577 .72971 L
.41394 .72251 L
.37355 .70657 L
.33813 .68252 L
.30906 .65131 L
.28749 .61416 L
.27425 .57253 L
.26988 .52806 L
.27453 .48248 L
.28804 .43759 L
.30986 .39515 L
.33915 .35683 L
.37475 .32412 L
.41526 .29832 L
.4591 .28043 L
.50454 .27116 L
.54981 .27087 L
.59312 .27957 L
.63278 .29692 L
.66723 .32225 L
.69511 .35455 L
.71533 .39255 L
.72711 .43478 L
.72997 .47956 L
.72381 .52515 L
.70886 .56975 L
.68571 .61161 L
.65528 .64909 L
.61876 .68072 L
.57757 .70526 L
.53334 .72174 L
.4878 .72952 L
.44273 .72829 L
.39992 .71811 L
.36104 .69936 L
.3276 .67279 L
.30094 .63943 L
.28208 .60061 L
.27178 .55783 L
.27044 .51279 L
.2781 .46725 L
.29447 .42299 L
.31891 .38175 L
.35046 .34515 L
.38788 .31463 L
Mistroke
.42969 .29139 L
.47427 .27633 L
.51985 .27005 L
.56466 .2728 L
.60692 .28446 L
.645 .30458 L
.67738 .33237 L
.7028 .36674 L
.72026 .40634 L
.72908 .44961 L
.7289 .49487 L
.71975 .54032 L
.70196 .58419 L
.67626 .62476 L
.64363 .66043 L
.60537 .68981 L
.56297 .71173 L
.5181 .72535 L
.47253 .73012 L
.42802 .72586 L
.38635 .71274 L
.34913 .69126 L
.31784 .66229 L
.29369 .62694 L
.27764 .58661 L
.27032 .54288 L
.27201 .49747 L
.28265 .45216 L
.30182 .40872 L
.32877 .36887 L
.36244 .33416 L
.4015 .30597 L
.44443 .28538 L
.48955 .27323 L
.53507 .26997 L
.57921 .27573 L
.62025 .2903 L
.65657 .3131 L
.68674 .34324 L
.70959 .37953 L
.72421 .42054 L
.73003 .46467 L
.72682 .51019 L
.71471 .55531 L
.69417 .59826 L
.66602 .63736 L
.63134 .67106 L
.59152 .69805 L
.5481 .71726 L
.50279 .72795 L
Mistroke
.45738 .72969 L
.41363 .72242 L
.37328 .70642 L
.3379 .68232 L
.30888 .65106 L
.28736 .61388 L
.27419 .57222 L
.26988 .52773 L
.2746 .48216 L
.28817 .43728 L
.31005 .39486 L
.33938 .35657 L
.37502 .32391 L
.41556 .29816 L
.45942 .28033 L
.50487 .27112 L
.55013 .2709 L
.59342 .27967 L
.63305 .29708 L
.66745 .32246 L
.69528 .3548 L
.71545 .39284 L
.72716 .43509 L
.72996 .47989 L
.72373 .52548 L
.70872 .57006 L
.68552 .6119 L
.65504 .64934 L
.61847 .68092 L
.57726 .70541 L
.53301 .72183 L
.48747 .72955 L
.44242 .72825 L
.39963 .718 L
.36077 .69919 L
.32739 .67257 L
.30077 .63917 L
.28198 .60031 L
.27174 .55752 L
.27046 .51246 L
.27819 .46692 L
.29462 .42268 L
.31912 .38147 L
.35071 .34491 L
.38816 .31444 L
.43 .29125 L
.47459 .27625 L
.52018 .27004 L
.56497 .27285 L
.60721 .28457 L
Mistroke
.64525 .30475 L
Mfstroke
1 0 0 r
.27801 .46757 m
.29433 .42329 L
s
% Start of user PostScript
-6.6595571 -0.9728911 -6.1701744 -2.301151 MAarrowhead1
% End of user PostScript
1 .158 0 r
.31871 .38203 m
.35021 .34539 L
s
% Start of user PostScript
-5.4386372 -3.5391 -4.4936555 -4.6381536 MAarrowhead1
% End of user PostScript
1 .473 0 r
.64474 .30441 m
.67717 .33215 L
s
% Start of user PostScript
4.342265 -5.8677547 5.3150759 -5.0355799 MAarrowhead1
% End of user PostScript
1 .788 0 r
.67647 .62448 m
.64389 .6602 L
s
% Start of user PostScript
5.2940078 3.7345395 4.3166242 4.8058755 MAarrowhead1
% End of user PostScript
.897 1 0 r
.34938 .69145 m
.31804 .66252 L
s
% Start of user PostScript
-4.5185946 5.7433669 -5.4588513 4.8755088 MAarrowhead1
% End of user PostScript
.581 1 0 r
.32855 .36914 m
.36217 .33439 L
s
% Start of user PostScript
-5.1435052 -3.925836 -4.1348042 -4.968266 MAarrowhead1
% End of user PostScript
.266 1 0 r
.65633 .31291 m
.68655 .343 L
s
% Start of user PostScript
4.6899112 -5.6126076 5.5965708 -4.7100288 MAarrowhead1
% End of user PostScript
0 1 .049 r
.66624 .63709 m
.63161 .67084 L
s
% Start of user PostScript
4.9872966 4.1127773 3.9483971 5.1251447 MAarrowhead1
% End of user PostScript
0 1 .364 r
.33813 .68252 m
.30906 .65131 L
s
% Start of user PostScript
-4.856025 5.4756218 -5.7280816 4.5393237 MAarrowhead1
% End of user PostScript
0 1 .679 r
.33915 .35683 m
.37475 .32412 L
s
% Start of user PostScript
-4.8255551 -4.2951559 -3.7576097 -5.2763377 MAarrowhead1
% End of user PostScript
0 1 .995 r
.66723 .32225 m
.69511 .35455 L
s
% Start of user PostScript
5.0167516 -5.3325614 5.8532377 -4.3635827 MAarrowhead1
% End of user PostScript
0 .69 1 r
.65528 .64909 m
.61876 .68072 L
s
% Start of user PostScript
4.6584602 4.4727695 3.5626537 5.4216772 MAarrowhead1
% End of user PostScript
0 .375 1 r
.3276 .67279 m
.30094 .63943 L
s
% Start of user PostScript
-5.1719127 5.1835852 -5.9719004 4.1830008 MAarrowhead1
% End of user PostScript
0 .06 1 r
.35046 .34515 m
.38788 .31463 L
s
% Start of user PostScript
-4.4861974 -4.6454212 -3.3637453 -5.561002 MAarrowhead1
% End of user PostScript
.774 1 0 r
.56695 .48845 m
.56627 .50169 L
.56299 .51487 L
.55723 .52746 L
.54923 .53897 L
.5393 .54896 L
.52783 .55702 L
.51526 .56285 L
.50209 .56621 L
.48885 .56697 L
.47604 .5651 L
.46417 .56068 L
.4537 .55388 L
.44506 .54496 L
.43857 .53428 L
.43449 .52225 L
.43298 .50935 L
.4341 .49608 L
.43781 .48297 L
.44396 .47052 L
.45231 .45923 L
.46253 .44954 L
.47422 .44184 L
.48692 .43641 L
.50014 .43348 L
.51335 .43316 L
.52604 .43546 L
.5377 .4403 L
.54789 .44748 L
.55619 .45672 L
.56229 .46766 L
.56595 .47987 L
.56702 .49287 L
.56545 .50615 L
.56132 .51918 L
.55479 .53147 L
.5461 .54252 L
.5356 .5519 L
.52371 .55924 L
.51088 .56426 L
.49763 .56676 L
.48447 .56663 L
.47192 .5639 L
.46047 .55865 L
.45058 .5511 L
.44262 .54155 L
.43692 .53037 L
.43369 .51799 L
.43306 .50491 L
.43506 .49163 L
Mistroke
.43961 .47869 L
.44653 .46658 L
.45555 .45578 L
.46631 .44672 L
.4784 .43975 L
.49133 .43514 L
.5046 .43308 L
.51769 .43364 L
.53009 .43681 L
.54131 .44246 L
.5509 .45037 L
.5585 .46022 L
.5638 .47164 L
.5666 .48417 L
.56678 .49732 L
.56435 .51058 L
.55939 .52342 L
.55209 .53534 L
.54276 .54587 L
.53174 .55461 L
.51948 .5612 L
.50645 .56539 L
.49318 .56701 L
.48016 .566 L
.46793 .56241 L
.45696 .55636 L
.44767 .5481 L
.44044 .53796 L
.43555 .52632 L
.43318 .51365 L
.43344 .50045 L
.43631 .48723 L
.44168 .47451 L
.44934 .46279 L
.45899 .45253 L
.47024 .44413 L
.48267 .43793 L
.49577 .43416 L
.50904 .43297 L
.52196 .43442 L
.53401 .43844 L
.54473 .44488 L
.55369 .45348 L
.56055 .4639 L
.56503 .47575 L
.56696 .48854 L
.56626 .50178 L
.56296 .51496 L
.55719 .52754 L
.54917 .53905 L
Mistroke
.53922 .54902 L
.52774 .55707 L
.51517 .56288 L
.502 .56622 L
.48875 .56697 L
.47595 .56508 L
.46409 .56064 L
.45363 .55382 L
.445 .54489 L
.43853 .53419 L
.43447 .52216 L
.43298 .50925 L
.43412 .49599 L
.43785 .48287 L
.44401 .47044 L
.45237 .45916 L
.46261 .44948 L
.47431 .44179 L
.48702 .43638 L
.50023 .43347 L
.51344 .43317 L
.52612 .43549 L
.53778 .44034 L
.54795 .44754 L
.55624 .45679 L
.56233 .46774 L
.56597 .47996 L
.56702 .49296 L
.56543 .50624 L
.56128 .51927 L
.55473 .53155 L
.54603 .54259 L
.53552 .55196 L
.52362 .55929 L
.51079 .56429 L
.49753 .56677 L
.48438 .56662 L
.47184 .56387 L
.4604 .5586 L
.45051 .55104 L
.44257 .54148 L
.43689 .53028 L
.43367 .5179 L
.43307 .50481 L
.43509 .49154 L
.43965 .4786 L
.44659 .4665 L
.45562 .45571 L
.46639 .44666 L
.47849 .43971 L
Mistroke
.49142 .43512 L
.50469 .43307 L
.51778 .43366 L
.53017 .43685 L
.54138 .44251 L
.55096 .45043 L
.55855 .4603 L
.56383 .47173 L
.56661 .48426 L
.56678 .49742 L
.56432 .51067 L
.55934 .52351 L
.55203 .53542 L
.54268 .54594 L
.53166 .55466 L
.51939 .56124 L
.50636 .56541 L
.49308 .56701 L
.48007 .56599 L
.46785 .56237 L
.45689 .55631 L
.44761 .54804 L
.4404 .53788 L
.43552 .52623 L
.43318 .51356 L
.43345 .50035 L
.43634 .48713 L
.44173 .47442 L
.4494 .46271 L
.45906 .45246 L
.47033 .44408 L
.48276 .43789 L
.49587 .43414 L
.50914 .43298 L
.52205 .43444 L
.53409 .43848 L
.5448 .44493 L
.55375 .45355 L
.56059 .46398 L
.56505 .47584 L
.56696 .48863 L
.56624 .50188 L
.56292 .51505 L
.55714 .52763 L
.5491 .53913 L
.53915 .54909 L
.52765 .55712 L
.51507 .56292 L
.5019 .56624 L
.48866 .56696 L
Mistroke
.47586 .56506 L
Mfstroke
1 0 0 r
.56695 .48845 m
.56627 .50169 L
s
% Start of user PostScript
2.0085521 -0.34660132 1.9881197 0.050671137 MAarrowhead1
% End of user PostScript
1 .158 0 r
.56299 .51487 m
.55723 .52746 L
s
% Start of user PostScript
1.8896615 0.44595496 1.7170418 0.82373685 MAarrowhead1
% End of user PostScript
1 .473 0 r
.47604 .5651 m
.46417 .56068 L
s
% Start of user PostScript
-0.71892981 1.9530861 -1.0750256 1.8204239 MAarrowhead1
% End of user PostScript
1 .788 0 r
.43781 .48297 m
.44396 .47052 L
s
% Start of user PostScript
-1.8657159 -0.51100714 -1.6812355 -0.8843704 MAarrowhead1
% End of user PostScript
.897 1 0 r
.52604 .43546 m
.5377 .4403 L
s
% Start of user PostScript
0.78107192 -1.9360658 1.1310231 -1.7909678 MAarrowhead1
% End of user PostScript
.581 1 0 r
.56132 .51918 m
.55479 .53147 L
s
% Start of user PostScript
1.8397004 0.57549242 1.6435641 0.94402284 MAarrowhead1
% End of user PostScript
.266 1 0 r
.47192 .5639 m
.46047 .55865 L
s
% Start of user PostScript
-0.84234752 1.9168977 -1.1857659 1.7595249 MAarrowhead1
% End of user PostScript
0 1 .049 r
.43961 .47869 m
.44653 .46658 L
s
% Start of user PostScript
-1.811644 -0.63933926 -1.6040693 -1.002628 MAarrowhead1
% End of user PostScript
0 1 .364 r
.53009 .43681 m
.54131 .44246 L
s
% Start of user PostScript
0.90268863 -1.8956029 1.2391933 -1.72613 MAarrowhead1
% End of user PostScript
0 1 .679 r
.55939 .52342 m
.55209 .53534 L
s
% Start of user PostScript
1.7815778 0.70247683 1.562795 1.0601209 MAarrowhead1
% End of user PostScript
0 1 .995 r
.46793 .56241 m
.45696 .55636 L
s
% Start of user PostScript
-0.96202832 1.8722053 -1.2912459 1.6908201 MAarrowhead1
% End of user PostScript
0 .69 1 r
.44168 .47451 m
.44934 .46279 L
s
% Start of user PostScript
-1.7495352 -0.76483508 -1.519787 -1.1164377 MAarrowhead1
% End of user PostScript
0 .375 1 r
.53401 .43844 m
.54473 .44488 L
s
% Start of user PostScript
1.0203008 -1.8467306 1.341866 -1.6536345 MAarrowhead1
% End of user PostScript
0 .06 1 r
.55719 .52754 m
.54917 .53905 L
s
% Start of user PostScript
1.7155516 0.82634484 1.475093 1.1715159 MAarrowhead1
% End of user PostScript
0 1 .213 r
.51397 .78998 m
.45574 .79427 L
.39924 .78701 L
.34669 .76848 L
.30016 .73942 L
.26148 .70097 L
.23215 .65462 L
.21334 .60221 L
.20577 .54578 L
.20976 .48756 L
.22513 .42983 L
.2513 .37485 L
.28722 .32478 L
.33149 .28159 L
.38238 .24697 L
.43788 .22228 L
.49583 .20849 L
.55393 .20615 L
.60992 .21533 L
.66159 .23568 L
.70693 .26641 L
.74414 .30631 L
.77177 .35381 L
.78873 .40704 L
.79436 .46393 L
.78845 .52223 L
.77121 .57965 L
.74332 .63395 L
.70589 .683 L
.66037 .72486 L
.60857 .7579 L
.5525 .78081 L
.49437 .79271 L
.43646 .79311 L
.38105 .78202 L
.3303 .75985 L
.28622 .72749 L
.25052 .6862 L
.22462 .6376 L
.20952 .5836 L
.20582 .52632 L
.21367 .46801 L
.23276 .41095 L
.26233 .35739 L
.30123 .30943 L
.34793 .26894 L
.40061 .23752 L
.45718 .2164 L
.51543 .20642 L
.57307 .20795 L
Mistroke
.62785 .22095 L
.67761 .2449 L
.7204 .27886 L
.75454 .3215 L
.77869 .37114 L
.79191 .42584 L
.79366 .48345 L
.78389 .54172 L
.76298 .59834 L
.73175 .65111 L
.69143 .69794 L
.64359 .73701 L
.59011 .76677 L
.5331 .78607 L
.47479 .79414 L
.41747 .79066 L
.36339 .77578 L
.31467 .75007 L
.27322 .71455 L
.24067 .67061 L
.2183 .61997 L
.20699 .56463 L
.20718 .50675 L
.21885 .4486 L
.24157 .39247 L
.27442 .34057 L
.31613 .29491 L
.36505 .25731 L
.41927 .22923 L
.47666 .21178 L
.53496 .20564 L
.59189 .21105 L
.64522 .2278 L
.69285 .25524 L
.7329 .29228 L
.76382 .33747 L
.78438 .38904 L
.79379 .44497 L
.79166 .50306 L
.77809 .56102 L
.7536 .61659 L
.71916 .66759 L
.67612 .71201 L
.62616 .7481 L
.57126 .77446 L
.51356 .79005 L
.45532 .79426 L
.39884 .78692 L
.34633 .76831 L
.29985 .73918 L
Mistroke
.26123 .70066 L
.23198 .65426 L
.21324 .60181 L
.20576 .54537 L
.20983 .48714 L
.22528 .42942 L
.25152 .37447 L
.28751 .32445 L
.33184 .28131 L
.38276 .24676 L
.43829 .22215 L
.49624 .20844 L
.55434 .20617 L
.61031 .21544 L
.66194 .23587 L
.70722 .26667 L
.74437 .30662 L
.77193 .35417 L
.78881 .40744 L
.79436 .46434 L
.78836 .52264 L
.77104 .58006 L
.74309 .63433 L
.70559 .68333 L
.66002 .72513 L
.60818 .7581 L
.55209 .78094 L
.49395 .79275 L
.43605 .79308 L
.38067 .7819 L
.32996 .75966 L
.28593 .72723 L
.2503 .68588 L
.22447 .63723 L
.20945 .5832 L
.20584 .52591 L
.21377 .4676 L
.23293 .41056 L
.26258 .35703 L
.30154 .30911 L
.34829 .26868 L
.401 .23733 L
.45759 .21629 L
.51585 .20639 L
.57348 .208 L
.62823 .22108 L
.67795 .2451 L
.72068 .27913 L
.75475 .32183 L
.77883 .37152 L
Mistroke
.79196 .42625 L
.79363 .48387 L
.78378 .54213 L
.7628 .59874 L
.73149 .65146 L
.69111 .69825 L
.64322 .73725 L
.58971 .76695 L
.53269 .78617 L
.47437 .79415 L
.41707 .79059 L
.36302 .77563 L
.31434 .74985 L
.27295 .71426 L
.24048 .67027 L
.21818 .61959 L
.20695 .56422 L
.20722 .50633 L
.21898 .44819 L
.24177 .39208 L
.27469 .34021 L
.31645 .29461 L
.36542 .25707 L
.41967 .22907 L
.47708 .2117 L
.53538 .20564 L
.59229 .21113 L
.64558 .22796 L
.69316 .25547 L
.73316 .29258 L
.76401 .33782 L
.78449 .38943 L
.79381 .44538 L
.7916 .50347 L
.77795 .56143 L
.75338 .61698 L
.71888 .66793 L
.67578 .7123 L
.62578 .74833 L
.57085 .77461 L
.51314 .79012 L
.45491 .79425 L
.39845 .78682 L
.34598 .76814 L
.29955 .73893 L
.26099 .70035 L
.2318 .65391 L
.21315 .60142 L
.20575 .54496 L
.2099 .48673 L
Mistroke
.22543 .42902 L
Mfstroke
1 0 0 r
.51397 .78998 m
.45574 .79427 L
s
% Start of user PostScript
0.41923718 8.6994264 -1.3278915 8.8280771 MAarrowhead1
% End of user PostScript
1 .158 0 r
.39924 .78701 m
.34669 .76848 L
s
% Start of user PostScript
-3.0229058 8.6102615 -4.5992833 8.0545277 MAarrowhead1
% End of user PostScript
1 .473 0 r
.22513 .42983 m
.2513 .37485 L
s
% Start of user PostScript
-8.2459842 -2.1051322 -7.4611051 -3.7545022 MAarrowhead1
% End of user PostScript
1 .788 0 r
.60992 .21533 m
.66159 .23568 L
s
% Start of user PostScript
3.297558 -8.540145 4.8477931 -7.9294751 MAarrowhead1
% End of user PostScript
.897 1 0 r
.77121 .57965 m
.74332 .63395 L
s
% Start of user PostScript
8.1361512 2.3895821 7.2996378 4.0186122 MAarrowhead1
% End of user PostScript
.581 1 0 r
.38105 .78202 m
.3303 .75985 L
s
% Start of user PostScript
-3.5685518 8.4605543 -5.0909249 7.7956256 MAarrowhead1
% End of user PostScript
.266 1 0 r
.23276 .41095 m
.26233 .35739 L
s
% Start of user PostScript
-8.0172921 -2.671381 -7.1300724 -4.2782641 MAarrowhead1
% End of user PostScript
0 1 .049 r
.62785 .22095 m
.67761 .2449 L
s
% Start of user PostScript
3.8355868 -8.3715776 5.328409 -7.6531279 MAarrowhead1
% End of user PostScript
0 1 .364 r
.76298 .59834 m
.73175 .65111 L
s
% Start of user PostScript
7.8895388 2.9502163 6.9525971 4.5331697 MAarrowhead1
% End of user PostScript
0 1 .679 r
.36339 .77578 m
.31467 .75007 L
s
% Start of user PostScript
-4.0983667 8.2733136 -5.5599818 7.5021399 MAarrowhead1
% End of user PostScript
0 1 .995 r
.24157 .39247 m
.27442 .34057 L
s
% Start of user PostScript
-7.7530329 -3.2257787 -6.7674087 -4.7830463 MAarrowhead1
% End of user PostScript
0 .69 1 r
.64522 .2278 m
.69285 .25524 L
s
% Start of user PostScript
4.3565999 -8.1658714 5.7853864 -7.3428291 MAarrowhead1
% End of user PostScript
0 .375 1 r
.7536 .61659 m
.71916 .66759 L
s
% Start of user PostScript
7.607926 3.4977625 6.5747126 5.0276167 MAarrowhead1
% End of user PostScript
0 .06 1 r
.34633 .76831 m
.29985 .73918 L
s
% Start of user PostScript
-4.61 8.0493701 -6.0043729 7.1753724 MAarrowhead1
% End of user PostScript
0 .028 1 r
.33669 .53689 m
.33662 .50464 L
.34297 .4722 L
.35547 .44085 L
.37365 .41183 L
.39679 .38626 L
.42397 .36516 L
.45414 .34935 L
.48611 .33946 L
.51863 .33586 L
.55042 .33871 L
.58022 .34788 L
.60688 .36303 L
.62934 .38355 L
.64673 .40864 L
.65836 .43732 L
.66377 .46846 L
.66276 .50083 L
.65536 .53317 L
.64186 .56422 L
.62279 .59274 L
.59891 .61762 L
.57114 .63788 L
.54058 .65273 L
.50843 .66159 L
.47595 .66411 L
.44441 .66019 L
.41505 .64998 L
.38903 .63388 L
.36736 .61253 L
.3509 .58677 L
.34029 .55759 L
.33595 .52616 L
.33804 .4937 L
.3465 .46149 L
.36097 .43079 L
.3809 .40281 L
.40551 .37864 L
.43383 .35923 L
.46474 .34535 L
.49703 .33753 L
.52945 .3361 L
.5607 .34109 L
.58958 .35233 L
.61494 .36936 L
.63578 .39151 L
.6513 .41792 L
.66088 .44756 L
.66415 .47925 L
.66097 .51176 L
Mistroke
.65148 .5438 L
.63604 .57413 L
.61527 .60155 L
.58997 .62498 L
.56113 .6435 L
.5299 .6564 L
.4975 .66316 L
.46519 .66351 L
.43425 .65745 L
.40589 .6452 L
.38123 .62726 L
.36122 .60433 L
.34666 .5773 L
.33812 .54723 L
.33593 .51532 L
.34018 .4828 L
.35071 .45095 L
.36709 .42103 L
.38869 .39422 L
.41466 .37155 L
.44397 .35392 L
.47549 .34203 L
.50797 .33633 L
.54013 .33706 L
.57072 .34419 L
.59853 .35743 L
.62248 .37626 L
.64162 .39995 L
.6552 .42757 L
.6627 .45803 L
.6638 .49014 L
.65848 .52263 L
.64694 .55424 L
.62963 .58371 L
.60723 .60991 L
.58063 .63179 L
.55086 .64849 L
.51909 .65937 L
.48658 .664 L
.45459 .66218 L
.42439 .65401 L
.39715 .63979 L
.37395 .62008 L
.35569 .59566 L
.3431 .56749 L
.33667 .53666 L
.33665 .5044 L
.34303 .47197 L
.35558 .44063 L
.3738 .41163 L
Mistroke
.39697 .38609 L
.42418 .36503 L
.45437 .34926 L
.48635 .33941 L
.51886 .33586 L
.55064 .33875 L
.58042 .34797 L
.60706 .36316 L
.62949 .38372 L
.64683 .40884 L
.65842 .43754 L
.66379 .46869 L
.66273 .50107 L
.65528 .5334 L
.64174 .56443 L
.62264 .59293 L
.59872 .61778 L
.57093 .63801 L
.54036 .65282 L
.5082 .66163 L
.47572 .66411 L
.44419 .66014 L
.41485 .64988 L
.38886 .63375 L
.36723 .61236 L
.3508 .58657 L
.34024 .55737 L
.33594 .52593 L
.33808 .49347 L
.34658 .46126 L
.3611 .43058 L
.38107 .40262 L
.4057 .37848 L
.43404 .35911 L
.46497 .34527 L
.49727 .3375 L
.52968 .33611 L
.56092 .34115 L
.58977 .35243 L
.6151 .3695 L
.63591 .39169 L
.65139 .41813 L
.66093 .44778 L
.66415 .47948 L
.66093 .51199 L
.65139 .54403 L
.63591 .57434 L
.6151 .60173 L
.58977 .62513 L
.56092 .64362 L
Mistroke
.52967 .65647 L
.49727 .66318 L
.46496 .66349 L
.43404 .65738 L
.4057 .64509 L
.38106 .62712 L
.3611 .60415 L
.34658 .57709 L
.33808 .54701 L
.33594 .51508 L
.34024 .48256 L
.35081 .45073 L
.36723 .42083 L
.38886 .39404 L
.41486 .3714 L
.44419 .35381 L
.47572 .34196 L
.5082 .33632 L
.54036 .33709 L
.57093 .34426 L
.59872 .35754 L
.62264 .37641 L
.64174 .40014 L
.65528 .42778 L
.66273 .45825 L
.66379 .49037 L
.65842 .52286 L
.64683 .55446 L
.62948 .58391 L
.60705 .61008 L
.58042 .63192 L
.55064 .64859 L
.51886 .65943 L
.48635 .66401 L
.45437 .66215 L
.42418 .65393 L
.39697 .63966 L
.3738 .61992 L
.35558 .59547 L
.34303 .56727 L
.33665 .53644 L
.33667 .50417 L
.3431 .47174 L
.35569 .44042 L
.37395 .41143 L
.39715 .38593 L
.42439 .3649 L
.45459 .34917 L
.48658 .33936 L
.51909 .33586 L
Mistroke
.55086 .33879 L
Mfstroke
1 0 0 r
.33669 .53689 m
.33662 .50464 L
s
% Start of user PostScript
-4.8992404 1.1067113 -4.9013164 0.13905046 MAarrowhead1
% End of user PostScript
1 .158 0 r
.34297 .4722 m
.35547 .44085 L
s
% Start of user PostScript
-4.7110355 -0.83406759 -4.3358655 -1.7744518 MAarrowhead1
% End of user PostScript
1 .473 0 r
.55042 .33871 m
.58022 .34788 L
s
% Start of user PostScript
1.512453 -4.8387967 2.4066314 -4.5635133 MAarrowhead1
% End of user PostScript
1 .788 0 r
.65536 .53317 m
.64186 .56422 L
s
% Start of user PostScript
4.6606597 0.99523523 4.2557069 1.9264505 MAarrowhead1
% End of user PostScript
.897 1 0 r
.44441 .66019 m
.41505 .64998 L
s
% Start of user PostScript
-1.6676874 4.8056481 -2.5483779 4.4993483 MAarrowhead1
% End of user PostScript
.581 1 0 r
.3465 .46149 m
.36097 .43079 L
s
% Start of user PostScript
-4.6051134 -1.1552988 -4.1708271 -2.076312 MAarrowhead1
% End of user PostScript
.266 1 0 r
.5607 .34109 m
.58958 .35233 L
s
% Start of user PostScript
1.8210716 -4.7671681 2.6872972 -4.4301918 MAarrowhead1
% End of user PostScript
0 1 .049 r
.65148 .5438 m
.63604 .57413 L
s
% Start of user PostScript
4.5444582 1.3140807 4.0813203 2.2238701 MAarrowhead1
% End of user PostScript
0 1 .364 r
.43425 .65745 m
.40589 .6452 L
s
% Start of user PostScript
-1.9724356 4.7233995 -2.8232353 4.3561205 MAarrowhead1
% End of user PostScript
0 1 .679 r
.35071 .45095 m
.36709 .42103 L
s
% Start of user PostScript
-4.4787616 -1.4714047 -3.9872857 -2.3689611 MAarrowhead1
% End of user PostScript
0 1 .995 r
.57072 .34419 m
.59853 .35743 L
s
% Start of user PostScript
2.1216115 -4.6743909 2.9560413 -4.2772166 MAarrowhead1
% End of user PostScript
0 .69 1 r
.64694 .55424 m
.62963 .58371 L
s
% Start of user PostScript
4.4080963 1.6270964 3.8888277 2.5114239 MAarrowhead1
% End of user PostScript
0 .375 1 r
.42439 .65401 m
.39715 .63979 L
s
% Start of user PostScript
-2.2684336 4.6201966 -3.085568 4.1935677 MAarrowhead1
% End of user PostScript
0 .06 1 r
.35558 .44063 m
.3738 .41163 L
s
% Start of user PostScript
-4.3325407 -1.7809831 -3.7860555 -2.6511007 MAarrowhead1
% End of user PostScript
0 1 .037 r
.81241 .80595 m
.73773 .86962 L
.65372 .91878 L
.56368 .9515 L
.47114 .96651 L
.37973 .96321 L
.29305 .94173 L
.21448 .90291 L
.14712 .84828 L
.09361 .77998 L
.05605 .7007 L
.03591 .61353 L
.03398 .52192 L
.05035 .42944 L
.08436 .33973 L
.13468 .25631 L
.19934 .18245 L
.2758 .12106 L
.36106 .07454 L
.45178 .04471 L
.54438 .03276 L
.63524 .03914 L
.7208 .06361 L
.79769 .10521 L
.86289 .1623 L
.91386 .23264 L
.94858 .31347 L
.9657 .40163 L
.96454 .49365 L
.94515 .58591 L
.90829 .67481 L
.8554 .75684 L
.78857 .8288 L
.71041 .88785 L
.624 .93167 L
.53271 .95856 L
.44015 .96745 L
.34993 .958 L
.2656 .93057 L
.19047 .88624 L
.12749 .82675 L
.07913 .75444 L
.04729 .67215 L
.03321 .5831 L
.03745 .49078 L
.05985 .39883 L
.09952 .31085 L
.15491 .23029 L
.22384 .16032 L
.30361 .10368 L
Mistroke
.39108 .06259 L
.48283 .03867 L
.57526 .03286 L
.66473 .04537 L
.74774 .07573 L
.82102 .12274 L
.8817 .18456 L
.92741 .25876 L
.95634 .34242 L
.96736 .43227 L
.96004 .52478 L
.93466 .61631 L
.89223 .70328 L
.8344 .78227 L
.76345 .85019 L
.68216 .90436 L
.59372 .94266 L
.5016 .96359 L
.40942 .96632 L
.32079 .95075 L
.2392 .9175 L
.16784 .86785 L
.10952 .80378 L
.06652 .72778 L
.04054 .64284 L
.03259 .55229 L
.04298 .45969 L
.07131 .36868 L
.11646 .28281 L
.17666 .20548 L
.24956 .1397 L
.33228 .08806 L
.42159 .05259 L
.51397 .03467 L
.6058 .03502 L
.69349 .05362 L
.77357 .08974 L
.84293 .14196 L
.89882 .20822 L
.93906 .28595 L
.96207 .37207 L
.96695 .46321 L
.9535 .5558 L
.92225 .64619 L
.87443 .73085 L
.81192 .80645 L
.73716 .87002 L
.6531 .91907 L
.56302 .95168 L
.47048 .96655 L
Mistroke
.37909 .96312 L
.29245 .94151 L
.21395 .90257 L
.14668 .84784 L
.09328 .77945 L
.05584 .7001 L
.03583 .61289 L
.03404 .52125 L
.05053 .42878 L
.08466 .3391 L
.1351 .25574 L
.19985 .18196 L
.27639 .12067 L
.3617 .07426 L
.45244 .04456 L
.54504 .03274 L
.63588 .03925 L
.72138 .06385 L
.7982 .10556 L
.86331 .16276 L
.91417 .23318 L
.94877 .31408 L
.96576 .40228 L
.96446 .49431 L
.94494 .58657 L
.90796 .67542 L
.85497 .7574 L
.78805 .82927 L
.70982 .88822 L
.62335 .93193 L
.53205 .95869 L
.43949 .96745 L
.3493 .95786 L
.26503 .93031 L
.18998 .88586 L
.12709 .82628 L
.07884 .75389 L
.04712 .67153 L
.03318 .58244 L
.03755 .49012 L
.06007 .39818 L
.09986 .31024 L
.15536 .22975 L
.22437 .15986 L
.30421 .10333 L
.39173 .06236 L
.4835 .03856 L
.57591 .03288 L
.66535 .04553 L
.7483 .07601 L
Mistroke
.8215 .12314 L
.88209 .18505 L
.92768 .25933 L
.95648 .34305 L
.96737 .43293 L
.95992 .52544 L
.93442 .61695 L
.89187 .70388 L
.83394 .7828 L
.7629 .85063 L
.68155 .90469 L
.59307 .94287 L
.50093 .96367 L
.40877 .96627 L
.32018 .95058 L
.23865 .9172 L
.16738 .86744 L
.10916 .80327 L
.06628 .72719 L
.04042 .6422 L
.0326 .55163 L
.04312 .45903 L
.07157 .36804 L
.11684 .28223 L
.17714 .20496 L
.25012 .13927 L
.3329 .08774 L
.42224 .05239 L
.51463 .03461 L
.60645 .03509 L
.69409 .05382 L
.77411 .09006 L
.84338 .14238 L
.89917 .20874 L
.93929 .28654 L
.96217 .37271 L
.96692 .46387 L
.95334 .55646 L
.92196 .64682 L
.87403 .73143 L
.81142 .80695 L
.73659 .87043 L
.65247 .91937 L
.56237 .95185 L
.46982 .96659 L
.37845 .96303 L
.29185 .94129 L
.21343 .90224 L
.14625 .84739 L
.09295 .77892 L
Mistroke
.05563 .6995 L
Mfstroke
1 0 0 r
.81241 .80595 m
.73773 .86962 L
s
% Start of user PostScript
9.3723063 9.1784175 7.1319601 11.088451 MAarrowhead1
% End of user PostScript
1 .158 0 r
.65372 .91878 m
.56368 .9515 L
s
% Start of user PostScript
4.6117132 12.563308 1.9104752 13.545106 MAarrowhead1
% End of user PostScript
1 .473 0 r
.05605 .7007 m
.03591 .61353 L
s
% Start of user PostScript
-13.318611 6.0209085 -13.922771 3.4060212 MAarrowhead1
% End of user PostScript
1 .788 0 r
.36106 .07454 m
.45178 .04471 L
s
% Start of user PostScript
-4.1681052 -12.763849 -1.4467442 -13.658552 MAarrowhead1
% End of user PostScript
.897 1 0 r
.94858 .31347 m
.9657 .40163 L
s
% Start of user PostScript
13.45744 -5.5957782 13.970958 -2.9510907 MAarrowhead1
% End of user PostScript
.581 1 0 r
.624 .93167 m
.53271 .95856 L
s
% Start of user PostScript
3.7198731 12.95023 0.98140818 13.756845 MAarrowhead1
% End of user PostScript
.266 1 0 r
.04729 .67215 m
.03321 .5831 L
s
% Start of user PostScript
-13.581339 5.16444 -14.003646 2.4928862 MAarrowhead1
% End of user PostScript
0 1 .049 r
.39108 .06259 m
.48283 .03867 L
s
% Start of user PostScript
-3.2675143 -13.122244 -0.51498342 -13.839876 MAarrowhead1
% End of user PostScript
0 1 .364 r
.95634 .34242 m
.96736 .43227 L
s
% Start of user PostScript
13.690171 -4.7273724 14.020799 -2.0319162 MAarrowhead1
% End of user PostScript
0 1 .679 r
.59372 .94266 m
.5016 .96359 L
s
% Start of user PostScript
2.8115306 13.2797 0.047987351 13.907554 MAarrowhead1
% End of user PostScript
0 1 .995 r
.04054 .64284 m
.03259 .55229 L
s
% Start of user PostScript
-13.783816 4.2850604 -14.022397 1.568692 MAarrowhead1
% End of user PostScript
0 .69 1 r
.42159 .05259 m
.51397 .03467 L
s
% Start of user PostScript
-2.3524278 -13.422424 0.41906196 -13.959803 MAarrowhead1
% End of user PostScript
0 .375 1 r
.96207 .37207 m
.96695 .46321 L
s
% Start of user PostScript
13.862169 -3.8379946 14.008439 -1.1037276 MAarrowhead1
% End of user PostScript
0 .06 1 r
.56302 .95168 m
.47048 .96655 L
s
% Start of user PostScript
1.8907152 13.550258 -0.88564636 13.996565 MAarrowhead1
% End of user PostScript
1 .885 0 r
.78038 .23434 m
.8207 .28866 L
.84843 .35128 L
.86249 .41973 L
.86232 .49134 L
.84793 .56328 L
.81989 .63274 L
.77929 .69699 L
.72774 .75351 L
.66724 .80008 L
.60018 .83488 L
.52919 .85653 L
.45705 .86419 L
.3866 .85755 L
.3206 .83689 L
.26164 .803 L
.21204 .75722 L
.17373 .70134 L
.14823 .63757 L
.13654 .56839 L
.13911 .49653 L
.15584 .42481 L
.18608 .35604 L
.22864 .29291 L
.28186 .23792 L
.34363 .19321 L
.41154 .16054 L
.48292 .14119 L
.55497 .13593 L
.62486 .14495 L
.68985 .16791 L
.7474 .2039 L
.79523 .25151 L
.83148 .30887 L
.85471 .37374 L
.86403 .44356 L
.85906 .51559 L
.84 .58702 L
.80759 .65502 L
.76312 .71695 L
.70831 .77036 L
.64533 .81316 L
.57665 .84367 L
.50496 .86069 L
.43307 .86355 L
.36382 .85215 L
.2999 .82693 L
.24384 .78887 L
.19783 .73948 L
.16368 .68069 L
Mistroke
.14273 .61481 L
.1358 .54443 L
.14317 .4723 L
.16454 .40125 L
.19907 .33409 L
.24542 .27343 L
.30175 .22167 L
.36587 .18082 L
.43525 .15251 L
.50717 .13783 L
.57881 .13737 L
.64736 .15114 L
.71012 .1786 L
.76464 .21867 L
.80877 .26979 L
.84078 .32994 L
.85942 .39676 L
.86396 .46764 L
.85421 .53978 L
.83055 .61037 L
.79393 .67662 L
.74577 .73594 L
.68796 .786 L
.62278 .82484 L
.55278 .85093 L
.48071 .86324 L
.40939 .8613 L
.34163 .84519 L
.28009 .81552 L
.22717 .77347 L
.18497 .72069 L
.15513 .65924 L
.13882 .59155 L
.13669 .52027 L
.14881 .44818 L
.17472 .37814 L
.2134 .31287 L
.26332 .25495 L
.32253 .20665 L
.38871 .16986 L
.45925 .14602 L
.53139 .13608 L
.60231 .14042 L
.6692 .15887 L
.72946 .19071 L
.78071 .23469 L
.82094 .28908 L
.84858 .35175 L
.86254 .42024 L
.86227 .49186 L
Mistroke
.84778 .56379 L
.81964 .63323 L
.77896 .69743 L
.72733 .75389 L
.66678 .80038 L
.59968 .83508 L
.52867 .85663 L
.45654 .86419 L
.38611 .85745 L
.32015 .83669 L
.26125 .80271 L
.21172 .75685 L
.1735 .70091 L
.1481 .63709 L
.13651 .56788 L
.13918 .49601 L
.15601 .4243 L
.18635 .35556 L
.22899 .29249 L
.28227 .23756 L
.34409 .19293 L
.41204 .16035 L
.48343 .1411 L
.55548 .13594 L
.62535 .14507 L
.6903 .16812 L
.74778 .2042 L
.79553 .25189 L
.83169 .30932 L
.85483 .37423 L
.86405 .44407 L
.85897 .51611 L
.83981 .58752 L
.80731 .65549 L
.76276 .71736 L
.70789 .7707 L
.64486 .81342 L
.57614 .84384 L
.50444 .86076 L
.43257 .86352 L
.36334 .85202 L
.29947 .8267 L
.24347 .78856 L
.19754 .73909 L
.16349 .68024 L
.14263 .61432 L
.13581 .54391 L
.14327 .47178 L
.16474 .40076 L
.19936 .33363 L
Mistroke
.24579 .27302 L
.30219 .22133 L
.36635 .18058 L
.43576 .15236 L
.50769 .13778 L
.57932 .13742 L
.64783 .15129 L
.71054 .17884 L
.76499 .219 L
.80905 .27019 L
.84097 .33039 L
.85951 .39726 L
.86394 .46815 L
.85408 .5403 L
.83034 .61086 L
.79362 .67707 L
.74539 .73633 L
.68752 .78632 L
.62229 .82507 L
.55227 .85107 L
.48019 .86328 L
.40889 .86124 L
.34117 .84502 L
.27968 .81526 L
.22683 .77313 L
.18471 .72028 L
.15496 .65878 L
.13875 .59105 L
.13672 .51975 L
.14895 .44767 L
.17495 .37765 L
.21372 .31243 L
.26371 .25457 L
.32298 .20634 L
.3892 .16964 L
.45977 .1459 L
.53191 .13606 L
.6028 .1405 L
.66966 .15906 L
.72986 .19099 L
.78104 .23505 L
.82119 .28951 L
.84873 .35223 L
.86259 .42074 L
.86221 .49237 L
.84763 .5643 L
.81939 .63371 L
.77863 .69786 L
.72693 .75426 L
.66632 .80067 L
Mistroke
.59918 .83528 L
Mfstroke
1 0 0 r
.78038 .23434 m
.8207 .28866 L
s
% Start of user PostScript
8.4113447 -7.9698603 9.6209148 -6.3401586 MAarrowhead1
% End of user PostScript
1 .158 0 r
.84843 .35128 m
.86249 .41973 L
s
% Start of user PostScript
10.452903 -4.4616312 10.874657 -2.4080028 MAarrowhead1
% End of user PostScript
1 .473 0 r
.60018 .83488 m
.52919 .85653 L
s
% Start of user PostScript
3.0054392 10.046343 0.87571102 10.695868 MAarrowhead1
% End of user PostScript
1 .788 0 r
.14823 .63757 m
.13654 .56839 L
s
% Start of user PostScript
-10.553006 4.1270139 -10.903824 2.0517515 MAarrowhead1
% End of user PostScript
.897 1 0 r
.41154 .16054 m
.48292 .14119 L
s
% Start of user PostScript
-2.6539462 -10.183803 -0.51253321 -10.764206 MAarrowhead1
% End of user PostScript
.581 1 0 r
.85471 .37374 m
.86403 .44356 L
s
% Start of user PostScript
10.641402 -3.7878181 10.920895 -1.693224 MAarrowhead1
% End of user PostScript
.266 1 0 r
.57665 .84367 m
.50496 .86069 L
s
% Start of user PostScript
2.299509 10.309965 0.1487868 10.820603 MAarrowhead1
% End of user PostScript
0 1 .049 r
.14273 .61481 m
.1358 .54443 L
s
% Start of user PostScript
-10.717993 3.4444202 -10.925851 1.332818 MAarrowhead1
% End of user PostScript
0 1 .364 r
.43525 .15251 m
.50717 .13783 L
s
% Start of user PostScript
-1.9425207 -10.42469 0.21512467 -10.864996 MAarrowhead1
% End of user PostScript
0 1 .679 r
.85942 .39676 m
.86396 .46764 L
s
% Start of user PostScript
10.782693 -3.0972011 10.918686 -0.97093348 MAarrowhead1
% End of user PostScript
0 1 .995 r
.55278 .85093 m
.48071 .86324 L
s
% Start of user PostScript
1.5833775 10.527849 -0.57879749 10.897335 MAarrowhead1
% End of user PostScript
0 .69 1 r
.13882 .59155 m
.13669 .52027 L
s
% Start of user PostScript
-10.835431 2.746546 -10.899408 0.6079718 MAarrowhead1
% End of user PostScript
0 .375 1 r
.45925 .14602 m
.53139 .13608 L
s
% Start of user PostScript
-1.2224777 -10.619329 0.9418282 -10.917585 MAarrowhead1
% End of user PostScript
0 .06 1 r
.86254 .42024 m
.86227 .49186 L
s
% Start of user PostScript
10.876149 -2.392844 10.868038 -0.24433565 MAarrowhead1
% End of user PostScript
0 1 .739 r
.6851 .63241 m
.65056 .66987 L
.61011 .70067 L
.56535 .7236 L
.51801 .73775 L
.46997 .74257 L
.42311 .73786 L
.37927 .72383 L
.34017 .70101 L
.30733 .6703 L
.28206 .6329 L
.26535 .5903 L
.25784 .54414 L
.25983 .49626 L
.27125 .44852 L
.29165 .4028 L
.32023 .3609 L
.35586 .32445 L
.39715 .2949 L
.44247 .27339 L
.49005 .26078 L
.53802 .25756 L
.58451 .26385 L
.62767 .27941 L
.66582 .30363 L
.69747 .33555 L
.72136 .37393 L
.73657 .41725 L
.74249 .46382 L
.7389 .51182 L
.72593 .55935 L
.7041 .60455 L
.67425 .64564 L
.63756 .68102 L
.59548 .7093 L
.54965 .72936 L
.50187 .74042 L
.45402 .74205 L
.40797 .73417 L
.36553 .71711 L
.32837 .69152 L
.29795 .65842 L
.27546 .6191 L
.26178 .57511 L
.25744 .52817 L
.26263 .48012 L
.27713 .43285 L
.30038 .38822 L
.33147 .34798 L
.36917 .3137 L
Mistroke
.412 .28673 L
.45828 .26814 L
.50621 .25864 L
.55389 .25861 L
.59945 .26806 L
.64112 .28661 L
.67724 .31354 L
.70641 .34778 L
.72747 .388 L
.73961 .43261 L
.74235 .47987 L
.73557 .52792 L
.71955 .57487 L
.69492 .61888 L
.66263 .65823 L
.62396 .69137 L
.58043 .717 L
.53373 .73411 L
.48572 .74203 L
.43827 .74046 L
.39323 .72944 L
.35239 .70943 L
.31734 .68119 L
.28946 .64584 L
.26985 .60477 L
.25926 .55959 L
.25813 .51207 L
.26648 .46407 L
.284 .41749 L
.31 .37414 L
.34345 .33573 L
.38305 .30377 L
.42724 .27951 L
.47428 .26391 L
.52234 .25757 L
.56951 .26074 L
.61396 .27331 L
.65394 .29477 L
.68787 .32428 L
.71443 .36069 L
.73258 .40257 L
.74159 .44828 L
.74113 .49601 L
.7312 .5439 L
.7122 .59006 L
.68487 .6327 L
.65029 .67012 L
.60981 .70087 L
.56501 .72373 L
.51767 .73782 L
Mistroke
.46963 .74257 L
.42279 .7378 L
.37897 .7237 L
.33991 .70081 L
.30712 .67005 L
.28191 .63262 L
.26526 .58998 L
.25782 .5438 L
.25988 .49591 L
.27137 .44818 L
.29183 .40249 L
.32046 .36062 L
.35614 .32422 L
.39746 .29472 L
.44281 .27327 L
.4904 .26073 L
.53837 .25757 L
.58483 .26393 L
.62796 .27955 L
.66607 .30383 L
.69767 .3358 L
.7215 .37422 L
.73665 .41758 L
.7425 .46417 L
.73884 .51216 L
.72581 .55968 L
.70391 .60486 L
.67401 .64592 L
.63728 .68125 L
.59516 .70947 L
.54931 .72947 L
.50153 .74047 L
.45368 .74203 L
.40765 .73408 L
.36525 .71695 L
.32813 .69131 L
.29776 .65816 L
.27533 .6188 L
.26171 .57478 L
.25745 .52782 L
.2627 .47978 L
.27727 .43252 L
.30058 .38792 L
.33172 .34771 L
.36946 .31348 L
.41232 .28657 L
.45862 .26804 L
.50655 .2586 L
.55422 .25865 L
.59977 .26816 L
Mistroke
.6414 .28678 L
.67747 .31376 L
.70659 .34805 L
.72759 .38831 L
.73967 .43295 L
.74233 .48022 L
.73549 .52826 L
.71941 .5752 L
.69471 .61919 L
.66237 .65849 L
.62366 .69158 L
.5801 .71715 L
.53339 .7342 L
.48538 .74205 L
.43793 .74041 L
.39292 .72933 L
.35212 .70925 L
.31712 .68096 L
.28929 .64557 L
.26974 .60446 L
.25922 .55925 L
.25815 .51172 L
.26658 .46373 L
.28416 .41716 L
.31021 .37385 L
.34372 .33548 L
.38335 .30357 L
.42757 .27937 L
.47463 .26383 L
.52268 .25756 L
.56984 .2608 L
.61426 .27343 L
.6542 .29495 L
.68809 .32452 L
.71459 .36098 L
.73267 .40289 L
.74162 .44861 L
.74109 .49635 L
.7311 .54424 L
.71203 .59038 L
.68465 .63298 L
.65002 .67037 L
.6095 .70106 L
.56468 .72386 L
.51733 .73788 L
.46929 .74257 L
.42246 .73773 L
.37867 .72356 L
.33965 .70062 L
.30692 .66981 L
Mistroke
.28176 .63233 L
Mfstroke
1 0 0 r
.6851 .63241 m
.65056 .66987 L
s
% Start of user PostScript
5.5528756 3.9722053 4.5167612 5.0962148 MAarrowhead1
% End of user PostScript
1 .158 0 r
.61011 .70067 m
.56535 .7236 L
s
% Start of user PostScript
3.303382 6.0202184 1.9603585 6.7079527 MAarrowhead1
% End of user PostScript
1 .473 0 r
.28206 .6329 m
.26535 .5903 L
s
% Start of user PostScript
-6.5381111 3.9871466 -7.0396381 2.7088748 MAarrowhead1
% End of user PostScript
1 .788 0 r
.39715 .2949 m
.44247 .27339 L
s
% Start of user PostScript
-3.0856147 -6.1530198 -1.7258866 -6.7981783 MAarrowhead1
% End of user PostScript
.897 1 0 r
.72136 .37393 m
.73657 .41725 L
s
% Start of user PostScript
6.6408849 -3.7822056 7.0971229 -2.4824453 MAarrowhead1
% End of user PostScript
.581 1 0 r
.59548 .7093 m
.54965 .72936 L
s
% Start of user PostScript
2.8644242 6.2789952 1.4895 6.880862 MAarrowhead1
% End of user PostScript
.266 1 0 r
.27546 .6191 m
.26178 .57511 L
s
% Start of user PostScript
-6.7362913 3.5730687 -7.1467342 2.2532619 MAarrowhead1
% End of user PostScript
0 1 .049 r
.412 .28673 m
.45828 .26814 L
s
% Start of user PostScript
-2.640056 -6.3980048 -1.251461 -6.9559123 MAarrowhead1
% End of user PostScript
0 1 .364 r
.72747 .388 m
.73961 .43261 L
s
% Start of user PostScript
6.8242247 -3.359968 7.1884171 -2.0215786 MAarrowhead1
% End of user PostScript
0 1 .679 r
.58043 .717 m
.53373 .73411 L
s
% Start of user PostScript
2.412759 6.5099165 1.0120337 7.0232457 MAarrowhead1
% End of user PostScript
0 1 .995 r
.26985 .60477 m
.25926 .55959 L
s
% Start of user PostScript
-6.9045874 3.1431397 -7.2221253 1.7876527 MAarrowhead1
% End of user PostScript
0 .69 1 r
.42724 .27951 m
.47428 .26391 L
s
% Start of user PostScript
-2.1827852 -6.6146062 -0.7714836 -7.0827878 MAarrowhead1
% End of user PostScript
0 .375 1 r
.73258 .40257 m
.74159 .44828 L
s
% Start of user PostScript
6.9772902 -2.9228245 7.2478214 -1.5517436 MAarrowhead1
% End of user PostScript
0 .06 1 r
.56501 .72373 m
.51767 .73782 L
s
% Start of user PostScript
1.95039 6.7119579 0.53007766 7.1344723 MAarrowhead1
% End of user PostScript
1 .142 0 r
.79626 .37229 m
.80846 .43049 L
.80856 .49142 L
.79655 .55268 L
.7729 .61188 L
.73853 .66668 L
.69481 .71495 L
.64344 .75477 L
.58644 .7846 L
.52605 .80326 L
.46464 .81002 L
.40462 .80461 L
.34833 .78725 L
.298 .75861 L
.2556 .71982 L
.22279 .67241 L
.20086 .61823 L
.19067 .55941 L
.19262 .49826 L
.20663 .43717 L
.23216 .37856 L
.26819 .3247 L
.31333 .27773 L
.36579 .23948 L
.42352 .21146 L
.48425 .19476 L
.5456 .19004 L
.60516 .19748 L
.66059 .2168 L
.70972 .24723 L
.75062 .28758 L
.78168 .33627 L
.80169 .39138 L
.80986 .45076 L
.80586 .51207 L
.78987 .5729 L
.7625 .63088 L
.72482 .68371 L
.67832 .72934 L
.62483 .76597 L
.56643 .79216 L
.50543 .80688 L
.44421 .80956 L
.38519 .80009 L
.33067 .77884 L
.28279 .74665 L
.24344 .70478 L
.21416 .65487 L
.1961 .59889 L
.18996 .53902 L
Mistroke
.19599 .47762 L
.21396 .4171 L
.24314 .35984 L
.28241 .30807 L
.33022 .26384 L
.38469 .22887 L
.44369 .20455 L
.5049 .19182 L
.56591 .19119 L
.62434 .20267 L
.67789 .22583 L
.72445 .25974 L
.76221 .30309 L
.78968 .35416 L
.80578 .41095 L
.80987 .47124 L
.80181 .53266 L
.7819 .5928 L
.75093 .6493 L
.71011 .69993 L
.66105 .74272 L
.60566 .77598 L
.54613 .79842 L
.48478 .80914 L
.42404 .80773 L
.36627 .79424 L
.31376 .7692 L
.26855 .7336 L
.23242 .68883 L
.2068 .63665 L
.19269 .57911 L
.19063 .51846 L
.20072 .45709 L
.22255 .3974 L
.25527 .34174 L
.2976 .29229 L
.34787 .25099 L
.40411 .21946 L
.46411 .19895 L
.52552 .19025 L
.58593 .1937 L
.64297 .20918 L
.6944 .23607 L
.73819 .27332 L
.77264 .31946 L
.79639 .37269 L
.80851 .43092 L
.80852 .49186 L
.79642 .55312 L
.77269 .61229 L
Mistroke
.73825 .66705 L
.69447 .71526 L
.64305 .75502 L
.58602 .78478 L
.52561 .80335 L
.4642 .81002 L
.4042 .80453 L
.34795 .78708 L
.29767 .75836 L
.25533 .71951 L
.22259 .67204 L
.20074 .61782 L
.19064 .55898 L
.19267 .49782 L
.20677 .43674 L
.23238 .37815 L
.26849 .32434 L
.31368 .27743 L
.36619 .23925 L
.42395 .2113 L
.48469 .19468 L
.54603 .19005 L
.60557 .19758 L
.66097 .21698 L
.71004 .24749 L
.75088 .2879 L
.78186 .33664 L
.80179 .3918 L
.80987 .45119 L
.80579 .51251 L
.78971 .57333 L
.76226 .63128 L
.72452 .68407 L
.67796 .72964 L
.62442 .7662 L
.566 .7923 L
.50499 .80694 L
.44378 .80953 L
.38478 .79998 L
.3303 .77865 L
.28248 .74638 L
.2432 .70445 L
.21399 .65449 L
.19601 .59847 L
.18996 .53858 L
.19608 .47718 L
.21413 .41668 L
.24339 .35944 L
.28273 .30772 L
.33059 .26355 L
Mistroke
.3851 .22866 L
.44412 .20442 L
.50534 .19177 L
.56634 .19123 L
.62474 .2028 L
.67825 .22603 L
.72476 .26002 L
.76245 .30343 L
.78984 .35455 L
.80585 .41138 L
.80986 .47168 L
.80171 .5331 L
.78172 .59322 L
.75067 .64968 L
.70979 .70027 L
.66067 .743 L
.60524 .77619 L
.54569 .79854 L
.48434 .80917 L
.42361 .80767 L
.36587 .7941 L
.3134 .76898 L
.26826 .73331 L
.2322 .68848 L
.20666 .63625 L
.19263 .57868 L
.19066 .51802 L
.20083 .45665 L
.22275 .39698 L
.25554 .34136 L
.29793 .29196 L
.34825 .25073 L
.40453 .21928 L
.46455 .19884 L
.52596 .19023 L
.58636 .19377 L
.64336 .20933 L
.69474 .2363 L
.73848 .27362 L
.77285 .31982 L
.79652 .3731 L
.80855 .43135 L
.80847 .4923 L
.79629 .55355 L
.77248 .6127 L
.73797 .66742 L
.69412 .71558 L
.64266 .75527 L
.5856 .78495 L
.52518 .80344 L
Mistroke
.46376 .81003 L
Mfstroke
1 0 0 r
.79626 .37229 m
.80846 .43049 L
s
% Start of user PostScript
8.8878511 -3.8312166 9.2539287 -2.0852619 MAarrowhead1
% End of user PostScript
1 .158 0 r
.80856 .49142 m
.79655 .55268 L
s
% Start of user PostScript
9.2568269 -0.25746911 8.8964319 1.5804283 MAarrowhead1
% End of user PostScript
1 .473 0 r
.46464 .81002 m
.40462 .80461 L
s
% Start of user PostScript
-1.0607807 9.3005649 -2.8615492 9.1382847 MAarrowhead1
% End of user PostScript
1 .788 0 r
.19262 .49826 m
.20663 .43717 L
s
% Start of user PostScript
-9.2214951 -0.052308337 -8.8011212 -1.8848006 MAarrowhead1
% End of user PostScript
.897 1 0 r
.5456 .19004 m
.60516 .19748 L
s
% Start of user PostScript
1.3679245 -9.2988226 3.1546914 -9.0755069 MAarrowhead1
% End of user PostScript
.581 1 0 r
.80586 .51207 m
.78987 .5729 L
s
% Start of user PostScript
9.1759331 0.36202775 8.6960467 2.187082 MAarrowhead1
% End of user PostScript
.266 1 0 r
.44421 .80956 m
.38519 .80009 L
s
% Start of user PostScript
-1.6735508 9.2867644 -3.444334 9.0026609 MAarrowhead1
% End of user PostScript
0 1 .049 r
.19599 .47762 m
.21396 .4171 L
s
% Start of user PostScript
-9.1201915 -0.67134554 -8.581325 -2.486937 MAarrowhead1
% End of user PostScript
0 1 .364 r
.56591 .19119 m
.62434 .20267 L
s
% Start of user PostScript
1.9773205 -9.2644037 3.7301554 -8.9198276 MAarrowhead1
% End of user PostScript
0 1 .679 r
.80181 .53266 m
.7819 .5928 L
s
% Start of user PostScript
9.0543321 0.97991856 8.4570833 2.7840331 MAarrowhead1
% End of user PostScript
0 1 .995 r
.42404 .80773 m
.36627 .79424 L
s
% Start of user PostScript
-2.2788966 9.2317651 -4.0118387 8.8270987 MAarrowhead1
% End of user PostScript
0 .69 1 r
.20072 .45709 m
.22255 .3974 L
s
% Start of user PostScript
-8.9784281 -1.2874045 -8.3234594 -3.0780407 MAarrowhead1
% End of user PostScript
0 .375 1 r
.58593 .1937 m
.64297 .20918 L
s
% Start of user PostScript
2.5779445 -9.1888851 4.2890713 -8.7245773 MAarrowhead1
% End of user PostScript
0 .06 1 r
.79642 .55312 m
.77269 .61229 L
s
% Start of user PostScript
8.8925635 1.5934622 8.1806017 3.3686335 MAarrowhead1
% End of user PostScript
1 .98 0 r
.27961 .25386 m
.33832 .20879 L
.40337 .17515 L
.47221 .15425 L
.54214 .14693 L
.61042 .15346 L
.67436 .17359 L
.73147 .20653 L
.77948 .25099 L
.81653 .30523 L
.84116 .3671 L
.8524 .4342 L
.8498 .50387 L
.83348 .57339 L
.80407 .64004 L
.76273 .70118 L
.71108 .75443 L
.65114 .7977 L
.58527 .82928 L
.51605 .84794 L
.44621 .85294 L
.37847 .8441 L
.31551 .82174 L
.25978 .78677 L
.21349 .74053 L
.17843 .68486 L
.156 .62193 L
.14707 .55422 L
.15199 .48437 L
.17056 .41515 L
.20207 .34925 L
.24527 .28927 L
.29846 .23755 L
.35957 .19614 L
.42619 .16666 L
.4957 .15025 L
.56538 .14758 L
.6325 .15873 L
.69442 .18328 L
.7487 .22025 L
.79323 .26821 L
.82624 .32526 L
.84646 .38917 L
.85308 .45743 L
.84584 .52736 L
.82502 .59622 L
.79145 .6613 L
.74645 .72005 L
.69177 .77017 L
.62956 .80968 L
Mistroke
.56227 .83703 L
.49254 .85116 L
.4231 .85151 L
.35668 .83807 L
.29588 .81135 L
.24309 .77242 L
.20039 .72279 L
.16944 .66442 L
.15147 .5996 L
.14717 .53087 L
.15673 .46093 L
.17975 .39252 L
.21534 .32833 L
.26211 .27087 L
.31821 .22241 L
.38145 .18485 L
.44934 .15965 L
.51921 .14781 L
.58833 .14979 L
.65399 .16551 L
.7136 .19437 L
.76483 .23521 L
.80567 .28645 L
.83451 .34607 L
.85022 .41174 L
.85219 .48086 L
.84033 .55074 L
.81512 .61862 L
.77754 .68185 L
.72907 .73794 L
.67161 .7847 L
.60741 .82028 L
.539 .84329 L
.46906 .85283 L
.40033 .84852 L
.33551 .83053 L
.27715 .79958 L
.22754 .75686 L
.18862 .70406 L
.16191 .64326 L
.14848 .57683 L
.14884 .50739 L
.16299 .43765 L
.19036 .37037 L
.22988 .30817 L
.28001 .2535 L
.33876 .2085 L
.40385 .17495 L
.47271 .15415 L
.54264 .14692 L
Mistroke
.6109 .15356 L
.6748 .17378 L
.73184 .20681 L
.77979 .25135 L
.81676 .30565 L
.84129 .36757 L
.85243 .43469 L
.84974 .50437 L
.83332 .57388 L
.80382 .6405 L
.7624 .70159 L
.71068 .75478 L
.65069 .79797 L
.58478 .82946 L
.51555 .84803 L
.44571 .85293 L
.378 .84398 L
.31508 .82154 L
.25942 .78647 L
.21319 .74016 L
.17823 .68443 L
.15589 .62146 L
.14705 .55372 L
.15207 .48387 L
.17074 .41466 L
.20234 .34879 L
.24562 .28886 L
.29888 .23722 L
.36003 .19589 L
.42668 .16649 L
.4962 .15019 L
.56588 .14761 L
.63296 .15886 L
.69483 .1835 L
.74906 .22056 L
.79351 .26859 L
.82644 .3257 L
.84656 .38965 L
.85307 .45793 L
.84573 .52786 L
.82483 .5967 L
.79117 .66175 L
.74609 .72044 L
.69135 .77049 L
.6291 .80992 L
.56178 .83718 L
.49204 .85122 L
.42261 .85146 L
.35622 .83792 L
.29547 .81111 L
Mistroke
.24275 .7721 L
.20012 .7224 L
.16926 .66398 L
.15139 .59912 L
.14719 .53037 L
.15684 .46043 L
.17996 .39204 L
.21564 .32789 L
.26248 .27049 L
.31864 .2221 L
.38192 .18462 L
.44983 .15952 L
.51971 .14777 L
.58882 .14985 L
.65444 .16568 L
.714 .19462 L
.76517 .23555 L
.80592 .28685 L
.83467 .34653 L
.85028 .41222 L
.85215 .48136 L
.8402 .55123 L
.81489 .61909 L
.77723 .68228 L
.72869 .73832 L
.67117 .785 L
.60693 .82049 L
.5385 .84341 L
.46856 .85285 L
.39985 .84844 L
.33507 .83036 L
.27676 .79931 L
.22722 .75652 L
.18838 .70365 L
.16177 .6428 L
.14843 .57634 L
.1489 .50689 L
.16314 .43716 L
.1906 .3699 L
.23021 .30775 L
.2804 .25314 L
.33921 .20822 L
.40433 .17475 L
.47321 .15405 L
.54314 .14692 L
.61137 .15365 L
.67524 .17398 L
.73222 .20709 L
.7801 .25171 L
.81698 .30607 L
Mistroke
.84142 .36803 L
Mfstroke
1 0 0 r
.27961 .25386 m
.33832 .20879 L
s
% Start of user PostScript
-6.6116151 -7.3841962 -4.8505011 -8.7363544 MAarrowhead1
% End of user PostScript
1 .158 0 r
.40337 .17515 m
.47221 .15425 L
s
% Start of user PostScript
-2.8990245 -9.7456459 -0.83377291 -10.37246 MAarrowhead1
% End of user PostScript
1 .473 0 r
.84116 .3671 m
.8524 .4342 L
s
% Start of user PostScript
10.234797 -3.9869016 10.571924 -1.9741337 MAarrowhead1
% End of user PostScript
1 .788 0 r
.58527 .82928 m
.51605 .84794 L
s
% Start of user PostScript
2.5581302 9.8784391 0.48164983 10.438213 MAarrowhead1
% End of user PostScript
.897 1 0 r
.156 .62193 m
.14707 .55422 L
s
% Start of user PostScript
-10.320002 3.6578766 -10.587966 1.6264642 MAarrowhead1
% End of user PostScript
.581 1 0 r
.42619 .16666 m
.4957 .15025 L
s
% Start of user PostScript
-2.214398 -10.000273 -0.12899243 -10.492387 MAarrowhead1
% End of user PostScript
.266 1 0 r
.84646 .38917 m
.85308 .45743 L
s
% Start of user PostScript
10.393757 -3.3247937 10.592262 -1.2769903 MAarrowhead1
% End of user PostScript
0 1 .049 r
.56227 .83703 m
.49254 .85116 L
s
% Start of user PostScript
1.8682092 10.111014 -0.22380808 10.53492 MAarrowhead1
% End of user PostScript
0 1 .364 r
.15147 .5996 m
.14717 .53087 L
s
% Start of user PostScript
-10.455983 2.9880224 -10.584808 0.92609971 MAarrowhead1
% End of user PostScript
0 1 .679 r
.44934 .15965 m
.51921 .14781 L
s
% Start of user PostScript
-1.5199478 -10.210537 0.5763603 -10.565766 MAarrowhead1
% End of user PostScript
0 1 .995 r
.85022 .41174 m
.85219 .48086 L
s
% Start of user PostScript
10.506608 -2.6479361 10.565611 -0.57418174 MAarrowhead1
% End of user PostScript
0 .69 1 r
.539 .84329 m
.46906 .85283 L
s
% Start of user PostScript
1.1700002 10.298733 -0.92827312 10.58489 MAarrowhead1
% End of user PostScript
0 .375 1 r
.14848 .57683 m
.14884 .50739 L
s
% Start of user PostScript
-10.545578 2.3049123 -10.534693 0.22162678 MAarrowhead1
% End of user PostScript
0 .06 1 r
.47271 .15415 m
.54264 .14692 L
s
% Start of user PostScript
-0.81875466 -10.375503 1.2791561 -10.592272 MAarrowhead1
% End of user PostScript
1 .629 0 r
.25425 .61493 m
.24234 .5667 L
.24054 .51586 L
.24893 .46439 L
.26717 .41432 L
.29454 .36761 L
.32998 .3261 L
.37209 .29141 L
.41923 .26491 L
.46953 .24763 L
.52102 .24026 L
.5717 .24309 L
.61956 .25599 L
.66272 .27847 L
.6995 .30965 L
.72845 .3483 L
.74844 .3929 L
.75867 .4417 L
.75876 .49279 L
.74868 .54417 L
.72885 .59381 L
.70004 .63977 L
.66337 .68024 L
.6203 .71364 L
.5725 .73866 L
.52186 .75431 L
.47036 .75998 L
.42002 .75544 L
.37282 .74088 L
.33062 .71687 L
.29506 .68435 L
.26754 .64459 L
.24915 .59915 L
.2406 .54983 L
.24223 .49855 L
.25398 .44732 L
.27538 .39817 L
.3056 .35301 L
.34345 .31362 L
.38745 .28154 L
.43586 .25804 L
.48678 .24403 L
.53823 .24007 L
.58817 .24631 L
.63466 .26251 L
.67586 .28803 L
.71016 .32186 L
.73621 .36269 L
.75299 .40891 L
.75984 .4587 L
Mistroke
.75649 .51011 L
.74308 .56113 L
.72013 .60974 L
.68854 .65405 L
.64955 .69232 L
.60469 .72303 L
.55572 .745 L
.50456 .75734 L
.45323 .75959 L
.40373 .75165 L
.35801 .73384 L
.31786 .70684 L
.28486 .67173 L
.2603 .62988 L
.24515 .58293 L
.24001 .53273 L
.24506 .48124 L
.26012 .43049 L
.2846 .38247 L
.31753 .33906 L
.35762 .30196 L
.4033 .27264 L
.45277 .25224 L
.5041 .24157 L
.55526 .24103 L
.60426 .25066 L
.64917 .27008 L
.68822 .29852 L
.71988 .33486 L
.74292 .37769 L
.75642 .42532 L
.75986 .47588 L
.7531 .52738 L
.7364 .57781 L
.71043 .62519 L
.6762 .66765 L
.63506 .70354 L
.58861 .73143 L
.53869 .75025 L
.48725 .75924 L
.43631 .75806 L
.38787 .74675 L
.34383 .72575 L
.30591 .6959 L
.27562 .65836 L
.25413 .6146 L
.24229 .56635 L
.24057 .51549 L
.24902 .46402 L
.26733 .41397 L
Mistroke
.29477 .36729 L
.33026 .32582 L
.37242 .29119 L
.41958 .26475 L
.46989 .24754 L
.52139 .24025 L
.57205 .24314 L
.61988 .25612 L
.66301 .27867 L
.69974 .3099 L
.72863 .3486 L
.74855 .39324 L
.75871 .44206 L
.75872 .49316 L
.74858 .54453 L
.72868 .59415 L
.6998 .64008 L
.66309 .68051 L
.61997 .71385 L
.57214 .73881 L
.52149 .75439 L
.46999 .75998 L
.41967 .75537 L
.3725 .74074 L
.33033 .71667 L
.29483 .68408 L
.26737 .64428 L
.24905 .59881 L
.24057 .54946 L
.24228 .49818 L
.2541 .44696 L
.27557 .39783 L
.30585 .3527 L
.34375 .31336 L
.38778 .28134 L
.43621 .2579 L
.48715 .24397 L
.53859 .24008 L
.58852 .24639 L
.63498 .26266 L
.67613 .28824 L
.71038 .32213 L
.73636 .363 L
.75307 .40925 L
.75985 .45906 L
.75643 .51048 L
.74295 .56149 L
.71993 .61008 L
.68828 .65435 L
.64924 .69257 L
Mistroke
.60435 .72322 L
.55536 .74512 L
.50419 .7574 L
.45286 .75957 L
.40339 .75156 L
.3577 .73367 L
.3176 .70662 L
.28465 .67145 L
.26016 .62956 L
.24508 .58258 L
.24001 .53236 L
.24514 .48087 L
.26027 .43014 L
.28481 .38214 L
.31779 .33877 L
.35793 .30172 L
.40364 .27246 L
.45313 .25213 L
.50447 .24153 L
.55562 .24107 L
.6046 .25077 L
.64947 .27025 L
.68847 .29875 L
.72008 .33515 L
.74305 .37802 L
.75648 .42567 L
.75984 .47625 L
.75301 .52775 L
.73625 .57817 L
.71021 .62551 L
.67593 .66794 L
.63474 .70377 L
.58826 .7316 L
.53832 .75035 L
.48688 .75927 L
.43595 .75801 L
.38753 .74663 L
.34353 .72557 L
.30567 .69566 L
.27543 .65806 L
.25401 .61427 L
.24224 .56599 L
.24059 .51512 L
.24912 .46366 L
.2675 .41362 L
.295 .36697 L
.33054 .32555 L
.37274 .29097 L
.41993 .26459 L
.47026 .24746 L
Mistroke
.52176 .24023 L
Mfstroke
1 0 0 r
.25425 .61493 m
.24234 .5667 L
s
% Start of user PostScript
-7.3724319 3.447958 -7.7297342 2.0011041 MAarrowhead1
% End of user PostScript
1 .158 0 r
.24054 .51586 m
.24893 .46439 L
s
% Start of user PostScript
-7.7836756 0.47571485 -7.5321391 -1.0683443 MAarrowhead1
% End of user PostScript
1 .473 0 r
.52102 .24026 m
.5717 .24309 L
s
% Start of user PostScript
0.63073287 -7.7921159 2.1509071 -7.7074179 MAarrowhead1
% End of user PostScript
1 .788 0 r
.75876 .49279 m
.74868 .54417 L
s
% Start of user PostScript
7.7626675 -0.21617988 7.460498 1.3250582 MAarrowhead1
% End of user PostScript
.897 1 0 r
.47036 .75998 m
.42002 .75544 L
s
% Start of user PostScript
-0.88928698 7.7993163 -2.3993967 7.6632837 MAarrowhead1
% End of user PostScript
.581 1 0 r
.24223 .49855 m
.25398 .44732 L
s
% Start of user PostScript
-7.7330477 -0.043594906 -7.3805804 -1.5803021 MAarrowhead1
% End of user PostScript
.266 1 0 r
.53823 .24007 m
.58817 .24631 L
s
% Start of user PostScript
1.1468545 -7.7978642 2.6452245 -7.610648 MAarrowhead1
% End of user PostScript
0 1 .049 r
.75649 .51011 m
.74308 .56113 L
s
% Start of user PostScript
7.694849 0.30332133 7.2924749 1.8337928 MAarrowhead1
% End of user PostScript
0 1 .364 r
.45323 .75959 m
.40373 .75165 L
s
% Start of user PostScript
-1.4031498 7.7877614 -2.8881178 7.5495692 MAarrowhead1
% End of user PostScript
0 1 .679 r
.24506 .48124 m
.26012 .43049 L
s
% Start of user PostScript
-7.6481137 -0.56271126 -7.1962792 -2.0852492 MAarrowhead1
% End of user PostScript
0 1 .995 r
.55526 .24103 m
.60426 .25066 L
s
% Start of user PostScript
1.6578884 -7.7690189 3.127807 -7.480115 MAarrowhead1
% End of user PostScript
0 .69 1 r
.7531 .52738 m
.7364 .57781 L
s
% Start of user PostScript
7.5928938 0.82147692 7.0921002 2.3343922 MAarrowhead1
% End of user PostScript
0 .375 1 r
.43631 .75806 m
.38787 .74675 L
s
% Start of user PostScript
-1.9107878 7.7416577 -3.3640262 7.4023625 MAarrowhead1
% End of user PostScript
0 .06 1 r
.24902 .46402 m
.26733 .41397 L
s
% Start of user PostScript
-7.5292505 -1.0793313 -6.9800533 -2.5809455 MAarrowhead1
% End of user PostScript
0 1 .422 r
.61818 .44657 m
.62355 .46977 L
.62406 .49416 L
.6197 .51878 L
.61065 .54266 L
.59725 .56487 L
.58004 .58453 L
.55969 .60088 L
.53699 .61326 L
.51284 .6212 L
.48819 .62439 L
.464 .62269 L
.44122 .61617 L
.42075 .6051 L
.4034 .5899 L
.38983 .57118 L
.38058 .54966 L
.37603 .52619 L
.37633 .50169 L
.38149 .47713 L
.39131 .45347 L
.40539 .43163 L
.42318 .41247 L
.44398 .39675 L
.46699 .38508 L
.49129 .37793 L
.51593 .37556 L
.53995 .37807 L
.5624 .38538 L
.5824 .39718 L
.59916 .41301 L
.61204 .43226 L
.62052 .45417 L
.62426 .47788 L
.62314 .50245 L
.61717 .52693 L
.60661 .55035 L
.59187 .5718 L
.57352 .59042 L
.55229 .6055 L
.529 .61644 L
.50457 .62281 L
.47997 .62436 L
.45615 .62103 L
.43405 .61295 L
.41454 .60043 L
.39839 .58398 L
.38622 .56423 L
.37852 .54195 L
.37558 .51803 L
Mistroke
.37753 .49341 L
.38429 .46904 L
.39558 .44589 L
.41098 .42486 L
.42986 .40678 L
.4515 .39236 L
.47505 .38216 L
.49957 .37659 L
.52411 .37586 L
.5477 .38 L
.56943 .38886 L
.58842 .40207 L
.60395 .41913 L
.6154 .43936 L
.62231 .46197 L
.62443 .48608 L
.62167 .51073 L
.61413 .53496 L
.60211 .55781 L
.58608 .5784 L
.56667 .59591 L
.54465 .60966 L
.52088 .61911 L
.49629 .62388 L
.47184 .62378 L
.4485 .61883 L
.42717 .60922 L
.40871 .59532 L
.39383 .57768 L
.38312 .55699 L
.37699 .53406 L
.37569 .5098 L
.37927 .48515 L
.38759 .46109 L
.40032 .43855 L
.41696 .41842 L
.43686 .4015 L
.45924 .38844 L
.48322 .37976 L
.50786 .3758 L
.53218 .37671 L
.55525 .38246 L
.57615 .39283 L
.59405 .4074 L
.60827 .4256 L
.61824 .44673 L
.62357 .46994 L
.62405 .49434 L
.61966 .51896 L
.61057 .54283 L
Mistroke
.59714 .56502 L
.57991 .58466 L
.55953 .60098 L
.53682 .61333 L
.51267 .62124 L
.48801 .62439 L
.46383 .62266 L
.44107 .61611 L
.42062 .60501 L
.40328 .58978 L
.38975 .57103 L
.38053 .5495 L
.37601 .52602 L
.37635 .50152 L
.38155 .47696 L
.39139 .4533 L
.4055 .43148 L
.42332 .41235 L
.44414 .39665 L
.46716 .38502 L
.49146 .37789 L
.51611 .37556 L
.54011 .37811 L
.56255 .38545 L
.58253 .39728 L
.59927 .41314 L
.61212 .43241 L
.62056 .45433 L
.62427 .47805 L
.62311 .50263 L
.61711 .5271 L
.60652 .55051 L
.59175 .57194 L
.57338 .59055 L
.55213 .6056 L
.52883 .6165 L
.5044 .62284 L
.47979 .62435 L
.45598 .62099 L
.4339 .61287 L
.41441 .60033 L
.39829 .58385 L
.38615 .56407 L
.37848 .54179 L
.37558 .51786 L
.37756 .49323 L
.38435 .46887 L
.39568 .44573 L
.4111 .42472 L
.43001 .40666 L
Mistroke
.45167 .39227 L
.47522 .3821 L
.49975 .37657 L
.52428 .37587 L
.54787 .38005 L
.56957 .38894 L
.58855 .40218 L
.60405 .41926 L
.61546 .43951 L
.62235 .46214 L
.62443 .48625 L
.62163 .5109 L
.61405 .53513 L
.602 .55797 L
.58595 .57854 L
.56652 .59603 L
.54449 .60975 L
.5207 .61916 L
.49611 .62389 L
.47167 .62376 L
.44833 .61878 L
.42703 .60913 L
.40859 .5952 L
.39374 .57754 L
.38306 .55683 L
.37696 .53389 L
.3757 .50962 L
.37932 .48497 L
.38767 .46092 L
.40043 .43839 L
.41709 .41829 L
.43701 .40139 L
.45941 .38836 L
.48339 .37971 L
.50803 .37579 L
.53235 .37674 L
.55541 .38252 L
.57629 .39292 L
.59417 .40752 L
.60836 .42575 L
.6183 .44689 L
.62359 .47012 L
.62403 .49452 L
.61961 .51913 L
.61049 .543 L
.59703 .56517 L
.57977 .58479 L
.55938 .60108 L
.53665 .61341 L
.51249 .62128 L
Mistroke
.48784 .6244 L
Mfstroke
1 0 0 r
.61818 .44657 m
.62355 .46977 L
s
% Start of user PostScript
3.5455434 -1.6029414 3.7063998 -0.90683366 MAarrowhead1
% End of user PostScript
1 .158 0 r
.62406 .49416 m
.6197 .51878 L
s
% Start of user PostScript
3.7217949 -0.17513636 3.5911245 0.56343433 MAarrowhead1
% End of user PostScript
1 .473 0 r
.48819 .62439 m
.464 .62269 L
s
% Start of user PostScript
-0.35432229 3.731551 -1.0799916 3.6806043 MAarrowhead1
% End of user PostScript
1 .788 0 r
.37633 .50169 m
.38149 .47713 L
s
% Start of user PostScript
-3.7099933 0.050848175 -3.5551529 -0.68602562 MAarrowhead1
% End of user PostScript
.897 1 0 r
.51593 .37556 m
.53995 .37807 L
s
% Start of user PostScript
0.47789245 -3.7332447 1.1984044 -3.6577546 MAarrowhead1
% End of user PostScript
.581 1 0 r
.62314 .50245 m
.61717 .52693 L
s
% Start of user PostScript
3.694076 0.073496423 3.5152371 0.80785584 MAarrowhead1
% End of user PostScript
.266 1 0 r
.47997 .62436 m
.45615 .62103 L
s
% Start of user PostScript
-0.60093244 3.7307967 -1.3154877 3.630847 MAarrowhead1
% End of user PostScript
0 1 .049 r
.37753 .49341 m
.38429 .46904 L
s
% Start of user PostScript
-3.6740605 -0.19775948 -3.4714217 -0.92878984 MAarrowhead1
% End of user PostScript
0 1 .364 r
.52411 .37586 m
.5477 .38 L
s
% Start of user PostScript
0.72330577 -3.7242098 1.4311117 -3.5999115 MAarrowhead1
% End of user PostScript
0 1 .679 r
.62167 .51073 m
.61413 .53496 L
s
% Start of user PostScript
3.6499691 0.32180316 3.4237551 1.0486935 MAarrowhead1
% End of user PostScript
0 1 .995 r
.47184 .62378 m
.4485 .61883 L
s
% Start of user PostScript
-0.84487667 3.7134914 -1.545148 3.5649822 MAarrowhead1
% End of user PostScript
0 .69 1 r
.37927 .48515 m
.38759 .46109 L
s
% Start of user PostScript
-3.6218285 -0.44548983 -3.3722903 -1.1674337 MAarrowhead1
% End of user PostScript
0 .375 1 r
.53218 .37671 m
.55525 .38246 L
s
% Start of user PostScript
0.96551029 -3.6986533 1.6574702 -3.5260981 MAarrowhead1
% End of user PostScript
0 .06 1 r
.61966 .51896 m
.61057 .54283 L
s
% Start of user PostScript
3.5896698 0.56868228 3.3170843 1.2848788 MAarrowhead1
% End of user PostScript
0 .574 1 r
.40489 .30546 m
.44777 .28555 L
.4927 .27405 L
.53792 .27142 L
.58165 .27777 L
.62217 .29283 L
.65791 .31602 L
.68744 .34644 L
.70962 .38288 L
.72357 .42392 L
.72874 .46794 L
.72494 .51323 L
.71232 .55799 L
.69135 .60048 L
.66288 .63902 L
.62802 .67211 L
.58813 .69844 L
.54478 .71699 L
.49968 .72702 L
.45459 .72814 L
.41128 .7203 L
.37145 .70382 L
.33667 .67935 L
.3083 .64783 L
.28745 .61051 L
.27494 .56885 L
.27127 .52449 L
.27657 .47918 L
.29064 .43467 L
.31293 .39273 L
.34256 .35501 L
.37837 .32297 L
.41895 .29788 L
.46271 .28072 L
.50794 .27217 L
.55285 .27256 L
.59569 .28187 L
.63478 .29975 L
.66857 .32548 L
.69575 .35807 L
.71525 .39622 L
.7263 .43845 L
.72847 .48309 L
.72167 .5284 L
.70617 .57259 L
.68258 .61393 L
.65183 .65081 L
.61511 .68176 L
.57388 .70558 L
.52975 .72133 L
Mistroke
.48445 .7284 L
.43976 .7265 L
.39744 .71571 L
.35914 .69646 L
.32637 .66949 L
.30041 .63588 L
.28229 .59693 L
.27271 .55418 L
.27205 .5093 L
.28034 .46406 L
.29724 .42022 L
.32211 .37952 L
.35396 .34355 L
.39153 .31371 L
.43337 .29119 L
.47782 .27687 L
.52314 .27129 L
.56755 .2747 L
.60931 .28695 L
.64679 .30756 L
.6785 .33572 L
.7032 .37033 L
.71993 .41003 L
.72803 .45325 L
.72718 .49832 L
.71741 .54345 L
.69912 .58687 L
.673 .62689 L
.6401 .66192 L
.6017 .6906 L
.55931 .7118 L
.51459 .72469 L
.46929 .72876 L
.42521 .72385 L
.38405 .71016 L
.34745 .68822 L
.31684 .65889 L
.29341 .62332 L
.27809 .58292 L
.27148 .53926 L
.27384 .49406 L
.28508 .4491 L
.30475 .40613 L
.33208 .36684 L
.366 .33278 L
.40518 .30529 L
.44809 .28543 L
.49303 .274 L
.53824 .27144 L
.58195 .27784 L
Mistroke
.62245 .29297 L
.65814 .31622 L
.68763 .34668 L
.70975 .38316 L
.72364 .42423 L
.72875 .46827 L
.72488 .51355 L
.71219 .5583 L
.69118 .60077 L
.66265 .63928 L
.62775 .67232 L
.58783 .6986 L
.54447 .71709 L
.49936 .72706 L
.45427 .72811 L
.41098 .72022 L
.37118 .70368 L
.33644 .67914 L
.30812 .64758 L
.28733 .61022 L
.27488 .56854 L
.27127 .52417 L
.27664 .47885 L
.29077 .43436 L
.31312 .39245 L
.34279 .35475 L
.37864 .32276 L
.41925 .29773 L
.46303 .28063 L
.50826 .27214 L
.55317 .27259 L
.59599 .28197 L
.63504 .29991 L
.66879 .32569 L
.69592 .35832 L
.71536 .39651 L
.72635 .43876 L
.72845 .48342 L
.72159 .52872 L
.70603 .5729 L
.68239 .61422 L
.65158 .65105 L
.61483 .68196 L
.57357 .70572 L
.52943 .72141 L
.48413 .72841 L
.43945 .72645 L
.39715 .7156 L
.35888 .69629 L
.32616 .66927 L
Mistroke
.30025 .63562 L
.28219 .59663 L
.27267 .55386 L
.27208 .50897 L
.28043 .46373 L
.29739 .41992 L
.32231 .37925 L
.35421 .34331 L
.39182 .31353 L
.43368 .29106 L
.47814 .27679 L
.52346 .27129 L
.56786 .27476 L
.6096 .28707 L
.64704 .30773 L
.6787 .33594 L
.70335 .3706 L
.72002 .41032 L
.72806 .45357 L
.72714 .49864 L
.71731 .54377 L
.69896 .58717 L
.67279 .62716 L
.63984 .66215 L
.60141 .69078 L
.55899 .71193 L
.51426 .72475 L
.46897 .72876 L
.4249 .72379 L
.38377 .71003 L
.34721 .68803 L
.31664 .65865 L
.29327 .62305 L
.27801 .58262 L
.27147 .53894 L
.27389 .49374 L
.28519 .44878 L
.30492 .40583 L
.3323 .36658 L
.36626 .33256 L
.40548 .30512 L
.4484 .28532 L
.49335 .27395 L
.53856 .27145 L
.58226 .27792 L
.62272 .29311 L
.65838 .31641 L
.68781 .34692 L
.70988 .38344 L
.7237 .42453 L
Mistroke
.72875 .46859 L
Mfstroke
1 0 0 r
.40489 .30546 m
.44777 .28555 L
s
% Start of user PostScript
-2.8533979 -5.836222 -1.5669386 -6.4335897 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4927 .27405 m
.53792 .27142 L
s
% Start of user PostScript
-0.21898321 -6.778465 1.1375664 -6.8573128 MAarrowhead1
% End of user PostScript
1 .473 0 r
.72874 .46794 m
.72494 .51323 L
s
% Start of user PostScript
6.8623354 -0.96168515 6.7483184 0.3967793 MAarrowhead1
% End of user PostScript
1 .788 0 r
.49968 .72702 m
.45459 .72814 L
s
% Start of user PostScript
-0.0095831975 6.8104962 -1.3623352 6.8440971 MAarrowhead1
% End of user PostScript
.897 1 0 r
.27127 .52449 m
.27657 .47918 L
s
% Start of user PostScript
-6.8620162 0.73484537 -6.7029426 -0.62473824 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50794 .27217 m
.55285 .27256 L
s
% Start of user PostScript
0.23813898 -6.834972 1.5855926 -6.8232887 MAarrowhead1
% End of user PostScript
.266 1 0 r
.72847 .48309 m
.72167 .5284 L
s
% Start of user PostScript
6.8540844 -0.50719036 6.6501307 0.85200411 MAarrowhead1
% End of user PostScript
0 1 .049 r
.48445 .7284 m
.43976 .7265 L
s
% Start of user PostScript
-0.46643057 6.8518651 -1.8070911 6.7949107 MAarrowhead1
% End of user PostScript
0 1 .364 r
.27205 .5093 m
.28034 .46406 L
s
% Start of user PostScript
-6.8385488 0.27897268 -6.5899412 -1.0783248 MAarrowhead1
% End of user PostScript
0 1 .679 r
.52314 .27129 m
.56755 .2747 L
s
% Start of user PostScript
0.69420471 -6.861157 2.0265847 -6.7589945 MAarrowhead1
% End of user PostScript
0 1 .995 r
.72718 .49832 m
.71741 .54345 L
s
% Start of user PostScript
6.8154267 -0.050445519 6.522441 1.3034492 MAarrowhead1
% End of user PostScript
0 .69 1 r
.46929 .72876 m
.42521 .72385 L
s
% Start of user PostScript
-0.92120872 6.8628372 -2.2438302 6.71558 MAarrowhead1
% End of user PostScript
0 .375 1 r
.27384 .49406 m
.28508 .4491 L
s
% Start of user PostScript
-6.7847436 -0.17813761 -6.4477049 -1.5271276 MAarrowhead1
% End of user PostScript
0 .06 1 r
.53824 .27144 m
.58195 .27784 L
s
% Start of user PostScript
1.1471908 -6.8569039 2.4585863 -6.6647154 MAarrowhead1
% End of user PostScript
0 .692 1 r
.40263 .48908 m
.40913 .46967 L
.41919 .45146 L
.43243 .43515 L
.44832 .42139 L
.46624 .41071 L
.48548 .40353 L
.50529 .40015 L
.5249 .40068 L
.54352 .4051 L
.56044 .41326 L
.57499 .42482 L
.58659 .43932 L
.5948 .45621 L
.59929 .47482 L
.59988 .49442 L
.59654 .51423 L
.58942 .53349 L
.5788 .55143 L
.56507 .56735 L
.5488 .58063 L
.53061 .59075 L
.51121 .5973 L
.49138 .60004 L
.47189 .59885 L
.4535 .59378 L
.43693 .58503 L
.42284 .57294 L
.41178 .55799 L
.40418 .54077 L
.40034 .52194 L
.40041 .50225 L
.40439 .48248 L
.41212 .46339 L
.42331 .44574 L
.4375 .43022 L
.45414 .41743 L
.47258 .40789 L
.4921 .40196 L
.51193 .39988 L
.5313 .40173 L
.54943 .40744 L
.56562 .41678 L
.57924 .42938 L
.58975 .44476 L
.59673 .4623 L
.59992 .48133 L
.59919 .50108 L
.59457 .5208 L
.58623 .53969 L
Mistroke
.57451 .55703 L
.55986 .57214 L
.54287 .58441 L
.52419 .59336 L
.50457 .59866 L
.48476 .60008 L
.46555 .59757 L
.4477 .59124 L
.4319 .58132 L
.41877 .56821 L
.40882 .55243 L
.40246 .53459 L
.39993 .51539 L
.40132 .49558 L
.40658 .47595 L
.41551 .45727 L
.42776 .44026 L
.44284 .42559 L
.46017 .41385 L
.47906 .40548 L
.49877 .40083 L
.51852 .40007 L
.53756 .40323 L
.55511 .41019 L
.57051 .42067 L
.58314 .43426 L
.5925 .45044 L
.59824 .46856 L
.60012 .48792 L
.59807 .50774 L
.59217 .52727 L
.58265 .54572 L
.56989 .56238 L
.55439 .5766 L
.53675 .5878 L
.51767 .59556 L
.4979 .59957 L
.47821 .59967 L
.45937 .59586 L
.44213 .58829 L
.42716 .57725 L
.41505 .56319 L
.40627 .54664 L
.40117 .52826 L
.39995 .50877 L
.40266 .48894 L
.40919 .46954 L
.41928 .45133 L
.43253 .43504 L
.44844 .4213 L
Mistroke
.46637 .41064 L
.48562 .4035 L
.50543 .40014 L
.52503 .40069 L
.54365 .40515 L
.56056 .41333 L
.57508 .42491 L
.58667 .43944 L
.59485 .45634 L
.5993 .47496 L
.59987 .49456 L
.59651 .51437 L
.58936 .53362 L
.57871 .55155 L
.56497 .56746 L
.54867 .58072 L
.53047 .59081 L
.51107 .59734 L
.49124 .60005 L
.47175 .59883 L
.45337 .59373 L
.43682 .58495 L
.42275 .57284 L
.41171 .55788 L
.40414 .54064 L
.40033 .5218 L
.40043 .50211 L
.40443 .48234 L
.41219 .46326 L
.4234 .44562 L
.43761 .43011 L
.45427 .41735 L
.47272 .40784 L
.49225 .40194 L
.51208 .39988 L
.53143 .40176 L
.54955 .40749 L
.56573 .41686 L
.57933 .42948 L
.58981 .44488 L
.59677 .46243 L
.59993 .48147 L
.59917 .50122 L
.59452 .52094 L
.58616 .53982 L
.57441 .55715 L
.55975 .57223 L
.54274 .58448 L
.52406 .59342 L
.50443 .59868 L
Mistroke
.48462 .60008 L
.46542 .59754 L
.44758 .59118 L
.43179 .58124 L
.41868 .56811 L
.40877 .55231 L
.40243 .53445 L
.39992 .51525 L
.40134 .49544 L
.40663 .47582 L
.41559 .45714 L
.42786 .44014 L
.44296 .4255 L
.4603 .41378 L
.47919 .40544 L
.49891 .40081 L
.51866 .40008 L
.53769 .40326 L
.55523 .41025 L
.57061 .42075 L
.58322 .43437 L
.59256 .45056 L
.59826 .4687 L
.60012 .48806 L
.59804 .50789 L
.59211 .52741 L
.58257 .54585 L
.56979 .5625 L
.55427 .57669 L
.53662 .58787 L
.51753 .59561 L
.49776 .59959 L
.47807 .59966 L
.45924 .59582 L
.44202 .58822 L
.42706 .57716 L
.41498 .56307 L
.40622 .54651 L
.40115 .52812 L
.39996 .50863 L
.40269 .48879 L
.40925 .4694 L
.41936 .45121 L
.43264 .43493 L
.44856 .42121 L
.4665 .41058 L
.48576 .40346 L
.50557 .40013 L
.52517 .40071 L
.54378 .4052 L
Mistroke
.56067 .4134 L
Mfstroke
1 0 0 r
.40263 .48908 m
.40913 .46967 L
s
% Start of user PostScript
-2.9212057 -0.32768254 -2.7262238 -0.90980544 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41919 .45146 m
.43243 .43515 L
s
% Start of user PostScript
-2.4242487 -1.4562221 -2.0271315 -1.945488 MAarrowhead1
% End of user PostScript
1 .473 0 r
.56044 .41326 m
.57499 .42482 L
s
% Start of user PostScript
1.8132874 -2.602264 2.249714 -2.2555481 MAarrowhead1
% End of user PostScript
1 .788 0 r
.5788 .55143 m
.56507 .56735 L
s
% Start of user PostScript
2.3638528 1.5428967 1.9521994 2.0206144 MAarrowhead1
% End of user PostScript
.897 1 0 r
.43693 .58503 m
.42284 .57294 L
s
% Start of user PostScript
-1.8920211 2.5508741 -2.3147367 2.1882467 MAarrowhead1
% End of user PostScript
.581 1 0 r
.42331 .44574 m
.4375 .43022 L
s
% Start of user PostScript
-2.3008346 -1.6278597 -1.8751016 -2.0934992 MAarrowhead1
% End of user PostScript
.266 1 0 r
.56562 .41678 m
.57924 .42938 L
s
% Start of user PostScript
1.9686559 -2.4966544 2.3771914 -2.1185177 MAarrowhead1
% End of user PostScript
0 1 .049 r
.57451 .55703 m
.55986 .57214 L
s
% Start of user PostScript
2.2352638 1.7110167 1.7959236 2.1640614 MAarrowhead1
% End of user PostScript
0 1 .364 r
.4319 .58132 m
.41877 .56821 L
s
% Start of user PostScript
-2.0431067 2.4396649 -2.4370089 2.0464385 MAarrowhead1
% End of user PostScript
0 1 .679 r
.42776 .44026 m
.44284 .42559 L
s
% Start of user PostScript
-2.1672133 -1.7922755 -1.7147532 -2.2322229 MAarrowhead1
% End of user PostScript
0 1 .995 r
.57051 .42067 m
.58314 .43426 L
s
% Start of user PostScript
2.1152909 -2.3799689 2.4941228 -1.972089 MAarrowhead1
% End of user PostScript
0 .69 1 r
.56989 .56238 m
.55439 .5766 L
s
% Start of user PostScript
2.0967585 1.8715461 1.6316805 2.2979081 MAarrowhead1
% End of user PostScript
0 .375 1 r
.42716 .57725 m
.41505 .56319 L
s
% Start of user PostScript
-2.1851284 2.3176326 -2.5484698 1.8955517 MAarrowhead1
% End of user PostScript
0 .06 1 r
.43253 .43504 m
.44844 .4213 L
s
% Start of user PostScript
-2.0239776 -1.9487403 -1.5467977 -2.3610439 MAarrowhead1
% End of user PostScript
0 .34 1 r
.60307 .21511 m
.6551 .2341 L
.70103 .26353 L
.73908 .30224 L
.76774 .34872 L
.78589 .40112 L
.79283 .45741 L
.78827 .51537 L
.7724 .57273 L
.74584 .62723 L
.70963 .67674 L
.66519 .71932 L
.61427 .75328 L
.55887 .77731 L
.50115 .79045 L
.44339 .79219 L
.38785 .78247 L
.33672 .76166 L
.29199 .73058 L
.25542 .69045 L
.22845 .64285 L
.21214 .58964 L
.20713 .53291 L
.21361 .47489 L
.23133 .41786 L
.2596 .36405 L
.2973 .31558 L
.34295 .27434 L
.39477 .24196 L
.45072 .21971 L
.5086 .20846 L
.56615 .20864 L
.6211 .22027 L
.67129 .24287 L
.71476 .27556 L
.74981 .31707 L
.77505 .36575 L
.7895 .4197 L
.79258 .4768 L
.78418 .53481 L
.76463 .59146 L
.7347 .64451 L
.69555 .6919 L
.64873 .73175 L
.59607 .76251 L
.53964 .78297 L
.48165 .79232 L
.42439 .7902 L
.37009 .77669 L
.32089 .75232 L
Mistroke
.27872 .71804 L
.24524 .67522 L
.22175 .62551 L
.20918 .57088 L
.20803 .51347 L
.21834 .45552 L
.23969 .39933 L
.27127 .34708 L
.31182 .30084 L
.35976 .26241 L
.4132 .23331 L
.47005 .21467 L
.52807 .20723 L
.58499 .21129 L
.63858 .22667 L
.68673 .25278 L
.72755 .28859 L
.75943 .3327 L
.78114 .38337 L
.79181 .43862 L
.79104 .49629 L
.77883 .55409 L
.75569 .60978 L
.72251 .66115 L
.6806 .7062 L
.6316 .74316 L
.57744 .77058 L
.52023 .78737 L
.46223 .79289 L
.40572 .78691 L
.3529 .76968 L
.30586 .74186 L
.26644 .70454 L
.23618 .6592 L
.21628 .60761 L
.20751 .5518 L
.21022 .49396 L
.22431 .43635 L
.24921 .38124 L
.28396 .33079 L
.32718 .28699 L
.37719 .25154 L
.43201 .22584 L
.48951 .2109 L
.54742 .20731 L
.60346 .21521 L
.65545 .23428 L
.70133 .26378 L
.73932 .30255 L
.76791 .34907 L
Mistroke
.78598 .40152 L
.79284 .45783 L
.7882 .51579 L
.77225 .57313 L
.74561 .62761 L
.70934 .67707 L
.66485 .71959 L
.61389 .75349 L
.55846 .77744 L
.50074 .7905 L
.44298 .79216 L
.38747 .78236 L
.33637 .76147 L
.29169 .73032 L
.25519 .69013 L
.2283 .64248 L
.21207 .58924 L
.20714 .5325 L
.2137 .47448 L
.2315 .41746 L
.25984 .36368 L
.2976 .31525 L
.34331 .27408 L
.39516 .24176 L
.45113 .21959 L
.50902 .20842 L
.56655 .20869 L
.62147 .22039 L
.67163 .24307 L
.71505 .27583 L
.75003 .31739 L
.77519 .36612 L
.78956 .4201 L
.79256 .47721 L
.78408 .53522 L
.76445 .59185 L
.73445 .64487 L
.69524 .69221 L
.64837 .73201 L
.59567 .76269 L
.53922 .78307 L
.48124 .79234 L
.42399 .79014 L
.36972 .77655 L
.32056 .7521 L
.27845 .71777 L
.24503 .67488 L
.22162 .62513 L
.20913 .57047 L
.20806 .51305 L
Mistroke
.21845 .45511 L
.23989 .39894 L
.27153 .34673 L
.31214 .30053 L
.36013 .26217 L
.4136 .23314 L
.47046 .21458 L
.52849 .20722 L
.58539 .21136 L
.63895 .22682 L
.68705 .253 L
.72781 .28888 L
.75963 .33304 L
.78126 .38376 L
.79185 .43903 L
.79099 .4967 L
.77871 .5545 L
.75549 .61016 L
.72224 .6615 L
.68027 .7065 L
.63123 .74339 L
.57703 .77073 L
.51982 .78745 L
.46182 .79289 L
.40532 .78683 L
.35254 .76951 L
.30555 .74162 L
.26619 .70424 L
.236 .65885 L
.21618 .60723 L
.20749 .55139 L
.21028 .49354 L
.22445 .43595 L
.24943 .38086 L
.28424 .33045 L
.32752 .2867 L
.37757 .25132 L
.43242 .22569 L
.48993 .21084 L
.54783 .20733 L
.60385 .2153 L
.6558 .23446 L
.70164 .26403 L
.73956 .30286 L
.76808 .34943 L
.78607 .40191 L
.79285 .45824 L
.78812 .51621 L
.77209 .57354 L
.74539 .62798 L
Mistroke
.70905 .67741 L
Mfstroke
1 0 0 r
.60307 .21511 m
.6551 .2341 L
s
% Start of user PostScript
3.0922075 -8.5466873 4.6528723 -7.9768526 MAarrowhead1
% End of user PostScript
1 .158 0 r
.70103 .26353 m
.73908 .30224 L
s
% Start of user PostScript
6.0309306 -7.0939586 7.1722992 -5.9326552 MAarrowhead1
% End of user PostScript
1 .473 0 r
.70963 .67674 m
.66519 .71932 L
s
% Start of user PostScript
6.2888889 5.3022734 4.9557805 6.5794555 MAarrowhead1
% End of user PostScript
1 .788 0 r
.29199 .73058 m
.25542 .69045 L
s
% Start of user PostScript
-6.240397 6.9173537 -7.3373632 5.7135108 MAarrowhead1
% End of user PostScript
.897 1 0 r
.2973 .31558 m
.34295 .27434 L
s
% Start of user PostScript
-6.0810376 -5.5326724 -4.7113921 -6.7697576 MAarrowhead1
% End of user PostScript
.581 1 0 r
.71476 .27556 m
.74981 .31707 L
s
% Start of user PostScript
6.4429404 -6.7330749 7.4942874 -5.4880279 MAarrowhead1
% End of user PostScript
.266 1 0 r
.69555 .6919 m
.64873 .73175 L
s
% Start of user PostScript
5.8664401 5.7569335 4.4617771 6.9525494 MAarrowhead1
% End of user PostScript
0 1 .049 r
.27872 .71804 m
.24524 .67522 L
s
% Start of user PostScript
-6.6383362 6.5413265 -7.6428975 5.2564567 MAarrowhead1
% End of user PostScript
0 1 .364 r
.31182 .30084 m
.35976 .26241 L
s
% Start of user PostScript
-5.6453346 -5.9748079 -4.2072122 -7.1276282 MAarrowhead1
% End of user PostScript
0 1 .679 r
.72755 .28859 m
.75943 .3327 L
s
% Start of user PostScript
6.8263675 -6.3423213 7.7830287 -5.0190541 MAarrowhead1
% End of user PostScript
0 1 .995 r
.6806 .7062 m
.6316 .74316 L
s
% Start of user PostScript
5.4179661 6.186054 3.9479799 7.2947997 MAarrowhead1
% End of user PostScript
0 .69 1 r
.26644 .70454 m
.23618 .6592 L
s
% Start of user PostScript
-7.0068257 6.1362801 -7.9145256 4.7760834 MAarrowhead1
% End of user PostScript
0 .375 1 r
.32718 .28699 m
.37719 .25154 L
s
% Start of user PostScript
-5.1845871 -6.3904374 -3.6843678 -7.4538786 MAarrowhead1
% End of user PostScript
0 .06 1 r
.73932 .30255 m
.76791 .34907 L
s
% Start of user PostScript
7.1795108 -5.9234314 8.0372422 -4.5278143 MAarrowhead1
% End of user PostScript
.833 1 0 r
.4651 .18263 m
.52971 .17404 L
.59315 .17825 L
.65294 .19508 L
.70673 .22388 L
.7524 .26351 L
.78816 .31243 L
.81262 .36871 L
.82481 .43014 L
.82425 .49431 L
.81096 .55871 L
.78547 .6208 L
.74878 .67815 L
.70232 .72851 L
.64793 .7699 L
.58772 .8007 L
.52408 .81969 L
.45949 .82614 L
.39649 .8198 L
.33755 .8009 L
.28499 .77019 L
.24086 .72888 L
.20691 .67858 L
.18446 .62128 L
.17439 .55921 L
.1771 .49483 L
.19248 .43064 L
.21994 .36918 L
.25838 .31285 L
.30631 .26387 L
.36183 .22415 L
.42279 .19526 L
.48677 .17833 L
.55127 .17403 L
.61375 .18251 L
.67178 .20346 L
.72306 .23605 L
.76559 .27899 L
.79769 .33061 L
.81811 .38887 L
.82605 .4515 L
.82119 .51603 L
.80373 .57993 L
.77434 .6407 L
.73419 .69594 L
.68485 .74349 L
.62825 .78149 L
.56662 .80844 L
.50237 .82328 L
.43804 .82544 L
Mistroke
.37613 .81482 L
.31908 .79185 L
.26914 .75743 L
.22825 .7129 L
.19803 .66002 L
.17967 .60085 L
.17387 .53773 L
.18087 .47313 L
.2004 .40958 L
.23168 .34958 L
.2735 .29549 L
.3242 .24942 L
.38181 .21318 L
.44405 .1882 L
.50849 .17546 L
.57259 .17546 L
.63385 .18819 L
.68985 .21316 L
.73841 .24938 L
.7776 .29545 L
.8059 .34954 L
.8222 .40953 L
.82585 .47308 L
.81671 .53768 L
.79514 .6008 L
.76199 .65997 L
.71856 .71286 L
.66655 .7574 L
.608 .79183 L
.54522 .81481 L
.48066 .82544 L
.41686 .82329 L
.35632 .80845 L
.30142 .78151 L
.25432 .74353 L
.21685 .69598 L
.1905 .64074 L
.1763 .57998 L
.1748 .51608 L
.18606 .45155 L
.20964 .38892 L
.24462 .33065 L
.28962 .27903 L
.34288 .23608 L
.40231 .20348 L
.46556 .18253 L
.53017 .17403 L
.5936 .17832 L
.65335 .19525 L
.70709 .22413 L
Mistroke
.75269 .26383 L
.78838 .31281 L
.81275 .36913 L
.82485 .43059 L
.8242 .49477 L
.81082 .55916 L
.78525 .62123 L
.74848 .67854 L
.70196 .72884 L
.64751 .77016 L
.58728 .80088 L
.52362 .81979 L
.45903 .82614 L
.39605 .8197 L
.33715 .80072 L
.28464 .76993 L
.24058 .72854 L
.20671 .67819 L
.18434 .62085 L
.17436 .55876 L
.17717 .49436 L
.19264 .43019 L
.22017 .36876 L
.25869 .31247 L
.30668 .26355 L
.36226 .22391 L
.42324 .1951 L
.48723 .17826 L
.55172 .17404 L
.61419 .18262 L
.67217 .20365 L
.7234 .23632 L
.76586 .27933 L
.79788 .331 L
.81822 .38931 L
.82606 .45196 L
.82111 .51649 L
.80356 .58038 L
.77409 .64111 L
.73387 .69631 L
.68446 .7438 L
.62782 .78172 L
.56617 .80859 L
.50191 .82334 L
.43758 .82541 L
.3757 .8147 L
.3187 .79165 L
.26881 .75714 L
.228 .71255 L
.19786 .65961 L
Mistroke
.17958 .60041 L
.17387 .53727 L
.18097 .47267 L
.20058 .40914 L
.23195 .34917 L
.27383 .29513 L
.32459 .24912 L
.38224 .21296 L
.44451 .18807 L
.50895 .17542 L
.57305 .1755 L
.63427 .18832 L
.69023 .21338 L
.73872 .24968 L
.77784 .29581 L
.80606 .34995 L
.82227 .40998 L
.82583 .47354 L
.8166 .53814 L
.79495 .60124 L
.76172 .66037 L
.71822 .71321 L
.66615 .75768 L
.60757 .79204 L
.54476 .81493 L
.4802 .82547 L
.41641 .82323 L
.3559 .8083 L
.30105 .78128 L
.25401 .74322 L
.21662 .69561 L
.19036 .64033 L
.17624 .57953 L
.17483 .51562 L
.18618 .45109 L
.20985 .38849 L
.24491 .33026 L
.28998 .27869 L
.34329 .2358 L
.40275 .20329 L
.46602 .18242 L
.53064 .17401 L
.59404 .1784 L
.65376 .19541 L
.70744 .22437 L
.75298 .26415 L
.7886 .31319 L
.81288 .36956 L
.82489 .43104 L
.82415 .49524 L
Mistroke
.81068 .55962 L
Mfstroke
1 0 0 r
.4651 .18263 m
.52971 .17404 L
s
% Start of user PostScript
-1.0469308 -9.5210088 0.89134493 -9.7786592 MAarrowhead1
% End of user PostScript
1 .158 0 r
.59315 .17825 m
.65294 .19508 L
s
% Start of user PostScript
2.794639 -9.6525367 4.5882548 -9.147591 MAarrowhead1
% End of user PostScript
1 .473 0 r
.81096 .55871 m
.78547 .6208 L
s
% Start of user PostScript
9.3289097 1.7611544 8.5642295 3.6238976 MAarrowhead1
% End of user PostScript
1 .788 0 r
.39649 .8198 m
.33755 .8009 L
s
% Start of user PostScript
-3.1053605 9.5938772 -4.8735068 9.0268884 MAarrowhead1
% End of user PostScript
.897 1 0 r
.19248 .43064 m
.21994 .36918 L
s
% Start of user PostScript
-9.2254782 -2.0807013 -8.4019057 -3.9245596 MAarrowhead1
% End of user PostScript
.581 1 0 r
.61375 .18251 m
.67178 .20346 L
s
% Start of user PostScript
3.4126371 -9.5245745 5.1533523 -8.8961716 MAarrowhead1
% End of user PostScript
.266 1 0 r
.80373 .57993 m
.77434 .6407 L
s
% Start of user PostScript
9.1118122 2.39794 8.230261 4.2208678 MAarrowhead1
% End of user PostScript
0 1 .049 r
.37613 .81482 m
.31908 .79185 L
s
% Start of user PostScript
-3.7161276 9.4447054 -5.4274807 8.7555856 MAarrowhead1
% End of user PostScript
0 1 .364 r
.2004 .40958 m
.23168 .34958 L
s
% Start of user PostScript
-8.9880378 -2.7125183 -8.0494859 -4.5124934 MAarrowhead1
% End of user PostScript
0 1 .679 r
.63385 .18819 m
.68985 .21316 L
s
% Start of user PostScript
4.0154956 -9.3543586 5.695588 -8.6052863 MAarrowhead1
% End of user PostScript
0 1 .995 r
.79514 .6008 m
.76199 .65997 L
s
% Start of user PostScript
8.8542921 3.0240875 7.8597808 4.7991129 MAarrowhead1
% End of user PostScript
0 .69 1 r
.35632 .80845 m
.30142 .78151 L
s
% Start of user PostScript
-4.3104089 9.2536341 -5.9573767 8.4454404 MAarrowhead1
% End of user PostScript
0 .375 1 r
.20964 .38892 m
.24462 .33065 L
s
% Start of user PostScript
-8.7107237 -3.3323018 -7.6613562 -5.0804084 MAarrowhead1
% End of user PostScript
0 .06 1 r
.65335 .19525 m
.70709 .22413 L
s
% Start of user PostScript
4.6005403 -9.1426439 6.2125564 -8.2762253 MAarrowhead1
% End of user PostScript
.963 1 0 r
.61035 .53078 m
.59933 .55287 L
.58441 .57288 L
.56618 .59003 L
.54535 .60365 L
.52274 .6132 L
.49923 .61831 L
.47576 .61877 L
.45324 .61457 L
.43256 .60588 L
.41452 .59303 L
.39983 .57653 L
.38908 .55703 L
.38268 .53529 L
.38088 .51216 L
.38376 .48856 L
.3912 .4654 L
.40292 .44361 L
.41844 .42402 L
.43716 .40742 L
.45835 .39445 L
.48117 .38563 L
.50473 .38129 L
.52811 .38161 L
.55038 .38658 L
.57068 .396 L
.5882 .4095 L
.60226 .42655 L
.61231 .44649 L
.61795 .46852 L
.61896 .49179 L
.6153 .51539 L
.60712 .53837 L
.59473 .55986 L
.57863 .57899 L
.55943 .59503 L
.53791 .60733 L
.5149 .61542 L
.4913 .61899 L
.46805 .61788 L
.44605 .61214 L
.42617 .60201 L
.40918 .58787 L
.39576 .57028 L
.38643 .54994 L
.38156 .52763 L
.38133 .50424 L
.38576 .48069 L
.39468 .45789 L
.40773 .43674 L
Mistroke
.4244 .41808 L
.44404 .40263 L
.46587 .39101 L
.48904 .38366 L
.51265 .38087 L
.53575 .38277 L
.55746 .38926 L
.57691 .4001 L
.59334 .41486 L
.6061 .43296 L
.61471 .45369 L
.61881 .47624 L
.61825 .49972 L
.61305 .52322 L
.60341 .5458 L
.58971 .56658 L
.57249 .58475 L
.55243 .5996 L
.53031 .61054 L
.507 .61713 L
.48341 .61914 L
.46048 .61646 L
.4391 .60922 L
.4201 .59768 L
.40425 .58232 L
.39215 .56372 L
.38428 .54263 L
.38096 .51986 L
.3823 .49631 L
.38827 .4729 L
.39862 .45056 L
.41295 .43016 L
.4307 .4125 L
.45116 .39828 L
.47355 .38804 L
.49697 .3822 L
.52051 .38099 L
.54324 .38444 L
.56428 .39243 L
.58279 .40464 L
.59806 .42059 L
.60948 .43966 L
.6166 .4611 L
.61914 .48407 L
.61701 .50766 L
.61029 .53094 L
.59924 .55302 L
.58429 .57301 L
.56604 .59014 L
.54519 .60373 L
Mistroke
.52257 .61325 L
.49906 .61833 L
.4756 .61876 L
.45309 .61453 L
.43242 .6058 L
.4144 .59293 L
.39974 .5764 L
.38902 .55688 L
.38265 .53513 L
.38089 .51199 L
.3838 .48839 L
.39127 .46524 L
.40301 .44346 L
.41856 .42389 L
.4373 .40731 L
.45851 .39437 L
.48134 .38558 L
.5049 .38127 L
.52827 .38163 L
.55054 .38663 L
.57081 .39608 L
.58831 .40961 L
.60235 .42668 L
.61236 .44664 L
.61797 .46869 L
.61895 .49196 L
.61526 .51555 L
.60704 .53854 L
.59463 .56 L
.5785 .57912 L
.55929 .59513 L
.53775 .6074 L
.51473 .61546 L
.49114 .61899 L
.46789 .61785 L
.4459 .61209 L
.42603 .60192 L
.40907 .58776 L
.39568 .57015 L
.38638 .54979 L
.38154 .52747 L
.38135 .50408 L
.38581 .48052 L
.39476 .45773 L
.40784 .4366 L
.42453 .41796 L
.44419 .40254 L
.46603 .39094 L
.48921 .38362 L
.51282 .38087 L
Mistroke
.53592 .3828 L
.55761 .38932 L
.57704 .40019 L
.59344 .41498 L
.60618 .4331 L
.61475 .45385 L
.61882 .47641 L
.61823 .49989 L
.61299 .52338 L
.60332 .54596 L
.5896 .56672 L
.57236 .58487 L
.55228 .59969 L
.53014 .6106 L
.50683 .61717 L
.48325 .61913 L
.46032 .61643 L
.43895 .60915 L
.41998 .59759 L
.40415 .5822 L
.39208 .56358 L
.38424 .54247 L
.38095 .51969 L
.38233 .49614 L
.38833 .47274 L
.39871 .45041 L
.41307 .43003 L
.43084 .41239 L
.45132 .39819 L
.47371 .38799 L
.49714 .38218 L
.52067 .381 L
.5434 .38448 L
.56442 .3925 L
.58292 .40474 L
.59816 .42072 L
.60954 .43981 L
.61663 .46126 L
.61914 .48423 L
.61698 .50782 L
.61022 .53111 L
.59914 .55317 L
.58417 .57315 L
.5659 .59025 L
.54503 .60382 L
.5224 .6133 L
.4989 .61835 L
.47543 .61874 L
.45293 .61448 L
.43228 .60573 L
Mistroke
.41428 .59282 L
Mfstroke
1 0 0 r
.61035 .53078 m
.59933 .55287 L
s
% Start of user PostScript
3.3105851 0.92342839 2.9799229 1.5860229 MAarrowhead1
% End of user PostScript
1 .158 0 r
.58441 .57288 m
.56618 .59003 L
s
% Start of user PostScript
2.5323107 2.1863724 1.9853156 2.7009156 MAarrowhead1
% End of user PostScript
1 .473 0 r
.41452 .59303 m
.39983 .57653 L
s
% Start of user PostScript
-2.5645199 2.790983 -3.0050439 2.2959885 MAarrowhead1
% End of user PostScript
1 .788 0 r
.41844 .42402 m
.43716 .40742 L
s
% Start of user PostScript
-2.4468933 -2.2793327 -1.8852255 -2.7773889 MAarrowhead1
% End of user PostScript
.897 1 0 r
.5882 .4095 m
.60226 .42655 L
s
% Start of user PostScript
2.6460195 -2.7150644 3.0678358 -2.203481 MAarrowhead1
% End of user PostScript
.581 1 0 r
.57863 .57899 m
.55943 .59503 L
s
% Start of user PostScript
2.3587613 2.3697644 1.7830439 2.8507811 MAarrowhead1
% End of user PostScript
.266 1 0 r
.40918 .58787 m
.39576 .57028 L
s
% Start of user PostScript
-2.7245836 2.6361338 -3.1272243 2.1085289 MAarrowhead1
% End of user PostScript
0 1 .049 r
.4244 .41808 m
.44404 .40263 L
s
% Start of user PostScript
-2.2680126 -2.4575671 -1.6788842 -2.9210107 MAarrowhead1
% End of user PostScript
0 1 .364 r
.59334 .41486 m
.6061 .43296 L
s
% Start of user PostScript
2.8001252 -2.5542786 3.1831436 -2.0112377 MAarrowhead1
% End of user PostScript
0 1 .679 r
.57249 .58475 m
.55243 .5996 L
s
% Start of user PostScript
2.1747478 2.5426434 1.5728621 2.9879997 MAarrowhead1
% End of user PostScript
0 1 .995 r
.40425 .58232 m
.39215 .56372 L
s
% Start of user PostScript
-2.8725603 2.4695899 -3.2355315 1.9117153 MAarrowhead1
% End of user PostScript
0 .69 1 r
.4307 .4125 m
.45116 .39828 L
s
% Start of user PostScript
-2.0790703 -2.624899 -1.465095 -3.051674 MAarrowhead1
% End of user PostScript
0 .375 1 r
.59806 .42059 m
.60948 .43966 L
s
% Start of user PostScript
2.9418087 -2.3821614 3.28433 -1.810072 MAarrowhead1
% End of user PostScript
0 .06 1 r
.56604 .59014 m
.54519 .60373 L
s
% Start of user PostScript
1.9810864 2.7042426 1.3557026 3.1119627 MAarrowhead1
% End of user PostScript
0 1 .57 r
.70602 .65979 m
.66511 .70156 L
.61772 .73542 L
.56571 .76003 L
.51113 .77445 L
.4561 .77809 L
.4028 .77081 L
.35331 .75291 L
.30958 .72509 L
.27333 .68843 L
.24597 .64437 L
.22857 .59465 L
.22184 .54121 L
.22601 .48616 L
.24095 .43165 L
.26604 .37982 L
.30032 .33271 L
.34244 .29216 L
.39074 .25977 L
.44333 .23681 L
.49814 .22418 L
.55302 .22237 L
.60583 .23146 L
.65448 .25109 L
.69707 .28049 L
.73192 .3185 L
.75767 .36363 L
.77331 .41412 L
.77823 .46797 L
.77222 .52309 L
.75553 .5773 L
.72881 .62847 L
.69311 .6746 L
.64984 .71388 L
.60068 .74477 L
.54757 .76605 L
.49259 .77689 L
.43791 .77686 L
.38566 .76596 L
.3379 .74463 L
.2965 .7137 L
.26309 .67438 L
.23897 .62822 L
.2251 .57702 L
.22202 .5228 L
.22985 .46769 L
.24828 .41385 L
.27659 .36338 L
.31367 .31828 L
.35806 .28031 L
Mistroke
.40802 .25096 L
.46159 .23139 L
.51667 .22236 L
.57109 .22422 L
.62272 .23691 L
.66954 .25992 L
.70971 .29235 L
.74164 .33294 L
.76409 .38008 L
.77618 .43192 L
.77742 .48644 L
.76778 .54149 L
.74763 .59492 L
.71777 .64461 L
.67935 .68864 L
.6339 .72525 L
.58319 .75303 L
.52921 .77088 L
.47409 .7781 L
.41999 .7744 L
.36903 .75993 L
.3232 .73526 L
.28432 .70136 L
.2539 .65956 L
.23314 .61149 L
.22285 .55905 L
.22344 .50429 L
.23488 .44937 L
.25673 .39643 L
.28812 .34755 L
.32783 .30466 L
.3743 .26943 L
.4257 .24325 L
.48002 .22715 L
.53512 .22176 L
.58884 .22729 L
.63907 .24352 L
.68385 .26981 L
.72141 .30514 L
.75029 .34812 L
.76934 .39706 L
.77782 .45003 L
.77539 .50497 L
.76216 .55972 L
.73864 .61212 L
.70575 .66012 L
.66479 .70183 L
.61736 .73563 L
.56533 .76017 L
.51073 .77451 L
Mistroke
.45571 .77807 L
.40243 .77072 L
.35298 .75275 L
.30929 .72485 L
.2731 .68813 L
.2458 .64403 L
.22849 .59428 L
.22183 .54082 L
.22608 .48576 L
.24109 .43127 L
.26626 .37946 L
.3006 .33239 L
.34277 .2919 L
.3911 .25958 L
.44372 .23669 L
.49854 .22413 L
.55341 .2224 L
.60619 .23157 L
.65481 .25127 L
.69735 .28073 L
.73214 .3188 L
.75782 .36398 L
.77339 .41449 L
.77822 .46837 L
.77214 .52348 L
.75537 .57768 L
.72859 .62882 L
.69283 .67491 L
.6495 .71413 L
.60031 .74496 L
.54718 .76616 L
.4922 .77692 L
.43752 .77682 L
.3853 .76585 L
.33758 .74444 L
.29623 .71345 L
.26288 .67407 L
.23884 .62787 L
.22504 .57664 L
.22204 .52241 L
.22994 .4673 L
.24845 .41347 L
.27682 .36304 L
.31396 .31798 L
.3584 .28007 L
.40839 .25079 L
.46198 .23128 L
.51706 .22233 L
.57147 .22427 L
.62308 .23704 L
Mistroke
.66986 .26012 L
.70997 .29262 L
.74184 .33325 L
.76422 .38043 L
.77622 .43231 L
.77739 .48684 L
.76768 .54189 L
.74745 .59529 L
.71752 .64495 L
.67905 .68893 L
.63355 .72549 L
.58281 .7532 L
.52882 .77097 L
.4737 .77811 L
.41961 .77433 L
.36868 .75979 L
.3229 .73505 L
.28407 .70109 L
.25372 .65924 L
.23303 .61113 L
.22282 .55867 L
.22348 .5039 L
.235 .44898 L
.25692 .39606 L
.28838 .34722 L
.32814 .30438 L
.37465 .26921 L
.42608 .2431 L
.48041 .22708 L
.53551 .22176 L
.58921 .22737 L
.63942 .24367 L
.68415 .27004 L
.72165 .30543 L
.75046 .34845 L
.76944 .39742 L
.77784 .45042 L
.77533 .50537 L
.76203 .5601 L
.73844 .61248 L
.70549 .66044 L
.66447 .7021 L
.617 .73584 L
.56494 .76031 L
.51033 .77458 L
.45532 .77806 L
.40206 .77063 L
.35264 .75258 L
.30901 .72462 L
.27287 .68784 L
Mistroke
.24564 .64369 L
Mfstroke
1 0 0 r
.70602 .65979 m
.66511 .70156 L
s
% Start of user PostScript
6.1805693 4.7937878 4.9533078 6.0467969 MAarrowhead1
% End of user PostScript
1 .158 0 r
.61772 .73542 m
.56571 .76003 L
s
% Start of user PostScript
3.5316489 7.0624937 1.971387 7.801016 MAarrowhead1
% End of user PostScript
1 .473 0 r
.24597 .64437 m
.22857 .59465 L
s
% Start of user PostScript
-7.6210366 4.3311244 -8.1427625 2.8394794 MAarrowhead1
% End of user PostScript
1 .788 0 r
.39074 .25977 m
.44333 .23681 L
s
% Start of user PostScript
-3.2778121 -7.2067521 -1.7001729 -7.8955916 MAarrowhead1
% End of user PostScript
.897 1 0 r
.75767 .36363 m
.77331 .41412 L
s
% Start of user PostScript
7.7302119 -4.0910864 8.1993908 -2.5764979 MAarrowhead1
% End of user PostScript
.581 1 0 r
.60068 .74477 m
.54757 .76605 L
s
% Start of user PostScript
3.020339 7.3430154 1.4270727 7.981408 MAarrowhead1
% End of user PostScript
.266 1 0 r
.23897 .62822 m
.2251 .57702 L
s
% Start of user PostScript
-7.8308115 3.8465098 -8.2469228 2.3106581 MAarrowhead1
% End of user PostScript
0 1 .049 r
.40802 .25096 m
.46159 .23139 L
s
% Start of user PostScript
-2.7595152 -7.4711326 -1.1523893 -8.05837 MAarrowhead1
% End of user PostScript
0 1 .364 r
.76409 .38008 m
.77618 .43192 L
s
% Start of user PostScript
7.9227237 -3.5976659 8.2853059 -2.0422549 MAarrowhead1
% End of user PostScript
0 1 .679 r
.58319 .75303 m
.52921 .77088 L
s
% Start of user PostScript
2.49563 7.5909614 0.87642745 8.1263921 MAarrowhead1
% End of user PostScript
0 1 .995 r
.23314 .61149 m
.22285 .55905 L
s
% Start of user PostScript
-8.0058466 3.3448309 -8.3144974 1.7715861 MAarrowhead1
% End of user PostScript
0 .69 1 r
.4257 .24325 m
.48002 .22715 L
s
% Start of user PostScript
-2.2289763 -7.702369 -0.59949333 -8.185399 MAarrowhead1
% End of user PostScript
0 .375 1 r
.76934 .39706 m
.77782 .45003 L
s
% Start of user PostScript
8.0800879 -3.0882852 8.334465 -1.4989519 MAarrowhead1
% End of user PostScript
0 .06 1 r
.56533 .76017 m
.51073 .77451 L
s
% Start of user PostScript
1.9598497 7.8052317 0.32189414 8.2353252 MAarrowhead1
% End of user PostScript
.434 0 1 r
.18255 .30462 m
.23548 .24053 L
.2988 .18662 L
.37001 .14501 L
.44632 .11733 L
.52474 .10467 L
.60219 .10752 L
.67563 .12578 L
.74217 .15873 L
.79921 .20506 L
.84451 .26298 L
.87629 .33019 L
.8933 .40407 L
.89487 .48172 L
.88095 .56008 L
.85207 .63608 L
.80938 .70675 L
.75455 .76929 L
.68973 .82128 L
.61746 .86065 L
.54058 .88586 L
.46211 .89594 L
.38512 .89047 L
.31265 .86968 L
.24752 .83439 L
.19231 .78597 L
.14917 .72632 L
.1198 .65779 L
.10535 .58308 L
.10639 .5051 L
.12288 .42692 L
.15417 .3516 L
.19903 .28212 L
.2557 .22118 L
.32196 .17119 L
.39521 .1341 L
.47257 .11137 L
.551 .10389 L
.62744 .11196 L
.69887 .13526 L
.7625 .17287 L
.81583 .22332 L
.85676 .28463 L
.88369 .35439 L
.89556 .42987 L
.89191 .5081 L
.87288 .58601 L
.83921 .66054 L
.79223 .72878 L
.73378 .78803 L
Mistroke
.66616 .83599 L
.59201 .87075 L
.51426 .89097 L
.43594 .89584 L
.36014 .88518 L
.28983 .8594 L
.22777 .81951 L
.17639 .76709 L
.13771 .70418 L
.11324 .63326 L
.10396 .55711 L
.11022 .47872 L
.13178 .40116 L
.16779 .32749 L
.21684 .26058 L
.277 .20307 L
.34591 .15721 L
.42087 .12481 L
.49893 .10713 L
.57704 .10487 L
.65212 .11812 L
.72124 .14635 L
.78167 .18846 L
.83104 .2428 L
.86743 .30724 L
.88939 .37924 L
.89607 .45598 L
.88721 .53444 L
.86315 .61156 L
.82484 .68429 L
.77378 .7498 L
.71198 .8055 L
.64185 .84921 L
.56616 .87921 L
.48788 .89434 L
.41006 .89398 L
.33578 .87817 L
.26794 .84751 L
.20921 .80322 L
.1619 .74702 L
.12785 .68113 L
.10841 .60813 L
.10433 .53089 L
.11578 .45243 L
.14232 .37585 L
.18289 .30413 L
.2359 .2401 L
.29928 .18628 L
.37054 .14476 L
.44688 .11719 L
Mistroke
.5253 .10463 L
.60273 .1076 L
.67613 .12597 L
.74262 .15901 L
.79958 .20544 L
.84479 .26343 L
.87646 .3307 L
.89336 .40462 L
.89483 .48228 L
.88079 .56064 L
.85182 .63661 L
.80903 .70723 L
.75412 .76971 L
.68923 .8216 L
.61692 .86088 L
.54002 .88599 L
.46155 .89596 L
.38458 .89038 L
.31215 .86948 L
.24709 .83408 L
.19195 .78558 L
.14891 .72586 L
.11964 .65728 L
.1053 .58252 L
.10645 .50453 L
.12305 .42636 L
.15444 .35108 L
.19939 .28165 L
.25614 .22078 L
.32246 .17087 L
.39575 .13388 L
.47313 .11126 L
.55156 .10389 L
.62797 .11207 L
.69936 .13548 L
.76292 .17319 L
.81617 .22372 L
.857 .2851 L
.88383 .35492 L
.89559 .43042 L
.89183 .50866 L
.87269 .58656 L
.83892 .66106 L
.79185 .72924 L
.73333 .78842 L
.66565 .83628 L
.59147 .87095 L
.5137 .89106 L
.43539 .89582 L
.35962 .88504 L
Mistroke
.28935 .85916 L
.22736 .81918 L
.17606 .76667 L
.13748 .7037 L
.11312 .63273 L
.10395 .55655 L
.11032 .47816 L
.13199 .40062 L
.1681 .32698 L
.21723 .26013 L
.27746 .2027 L
.34643 .15693 L
.42142 .12463 L
.4995 .10706 L
.57759 .10491 L
.65264 .11827 L
.7217 .14661 L
.78206 .18881 L
.83135 .24323 L
.86764 .30773 L
.88949 .37977 L
.89606 .45654 L
.88709 .535 L
.86293 .6121 L
.82452 .68479 L
.77337 .75023 L
.7115 .80586 L
.64133 .84947 L
.56561 .87938 L
.48731 .89439 L
.40952 .89392 L
.33527 .878 L
.26749 .84724 L
.20883 .80285 L
.1616 .74658 L
.12766 .68063 L
.10832 .60759 L
.10436 .53033 L
.11592 .45188 L
.14256 .37531 L
.18323 .30364 L
.23632 .23968 L
.29977 .18593 L
.37107 .14451 L
.44744 .11704 L
.52587 .1046 L
.60328 .10768 L
.67664 .12615 L
.74306 .1593 L
.79995 .20582 L
Mistroke
.84507 .26388 L
Mfstroke
1 0 0 r
.18255 .30462 m
.23548 .24053 L
s
% Start of user PostScript
-9.5234936 -5.8613563 -7.9354929 -7.7841369 MAarrowhead1
% End of user PostScript
1 .158 0 r
.2988 .18662 m
.37001 .14501 L
s
% Start of user PostScript
-6.036056 -9.4014215 -3.8997283 -10.649738 MAarrowhead1
% End of user PostScript
1 .473 0 r
.84451 .26298 m
.87629 .33019 L
s
% Start of user PostScript
10.335317 -7.1106641 11.288635 -5.094209 MAarrowhead1
% End of user PostScript
1 .788 0 r
.68973 .82128 m
.61746 .86065 L
s
% Start of user PostScript
5.6918137 9.6382591 3.5237335 10.819413 MAarrowhead1
% End of user PostScript
.897 1 0 r
.14917 .72632 m
.1198 .65779 L
s
% Start of user PostScript
-10.524896 6.7896389 -11.406001 4.7338427 MAarrowhead1
% End of user PostScript
.581 1 0 r
.32196 .17119 m
.39521 .1341 L
s
% Start of user PostScript
-5.341257 -9.8644041 -3.1438295 -10.977085 MAarrowhead1
% End of user PostScript
.266 1 0 r
.85676 .28463 m
.88369 .35439 L
s
% Start of user PostScript
10.702799 -6.4610815 11.510714 -4.3682248 MAarrowhead1
% End of user PostScript
0 1 .049 r
.66616 .83599 m
.59201 .87075 L
s
% Start of user PostScript
4.9847748 10.079606 2.7604378 11.122579 MAarrowhead1
% End of user PostScript
0 1 .364 r
.13771 .70418 m
.11324 .63326 L
s
% Start of user PostScript
-10.868829 6.1253562 -11.602657 3.9977608 MAarrowhead1
% End of user PostScript
0 1 .679 r
.34591 .15721 m
.42087 .12481 L
s
% Start of user PostScript
-4.6227626 -10.283625 -2.3739837 -11.255734 MAarrowhead1
% End of user PostScript
0 1 .995 r
.86743 .30724 m
.88939 .37924 L
s
% Start of user PostScript
11.022801 -5.7828356 11.681728 -3.6228618 MAarrowhead1
% End of user PostScript
0 .69 1 r
.64185 .84921 m
.56616 .87921 L
s
% Start of user PostScript
4.2556219 10.476236 1.9848959 11.376402 MAarrowhead1
% End of user PostScript
0 .375 1 r
.12785 .68113 m
.10841 .60813 L
s
% Start of user PostScript
-11.164545 5.4338996 -11.74784 3.2439437 MAarrowhead1
% End of user PostScript
0 .06 1 r
.37054 .14476 m
.44688 .11719 L
s
% Start of user PostScript
-3.8837602 -10.657225 -1.5936062 -11.484449 MAarrowhead1
% End of user PostScript
1 .64 0 r
.42785 .45479 m
.44004 .44022 L
.45459 .42799 L
.47091 .41859 L
.48838 .41239 L
.5063 .40962 L
.52398 .4104 L
.54072 .4147 L
.55585 .42235 L
.5688 .43304 L
.57905 .44636 L
.58619 .46179 L
.58995 .47871 L
.59018 .49647 L
.58687 .51437 L
.58015 .53171 L
.57029 .5478 L
.55767 .56201 L
.54278 .5738 L
.52622 .58268 L
.50862 .58832 L
.49069 .59049 L
.47312 .58912 L
.45661 .58424 L
.4418 .57606 L
.42928 .56489 L
.41953 .55118 L
.41294 .53546 L
.40976 .51835 L
.41013 .50051 L
.41402 .48266 L
.42129 .46549 L
.43165 .44967 L
.44469 .43582 L
.4599 .4245 L
.47668 .41614 L
.49438 .41107 L
.5123 .40949 L
.52974 .41146 L
.54601 .41691 L
.56047 .42562 L
.57256 .43724 L
.58181 .45133 L
.58784 .46733 L
.59042 .48462 L
.58946 .5025 L
.58499 .52029 L
.57718 .53728 L
.56634 .55281 L
.55289 .56627 L
Mistroke
.53738 .57712 L
.52039 .58495 L
.50261 .58944 L
.48472 .59043 L
.46743 .58786 L
.45142 .58185 L
.43732 .57263 L
.42567 .56055 L
.41695 .5461 L
.41148 .52984 L
.40949 .5124 L
.41105 .49449 L
.4161 .47678 L
.42444 .45999 L
.43575 .44477 L
.44958 .43172 L
.46539 .42134 L
.48256 .41406 L
.50041 .41014 L
.51824 .40976 L
.53536 .41291 L
.5511 .41948 L
.56482 .42921 L
.576 .44172 L
.5842 .45652 L
.5891 .47303 L
.5905 .49059 L
.58834 .50852 L
.58272 .52612 L
.57386 .54269 L
.56209 .55759 L
.54789 .57022 L
.53181 .58011 L
.51448 .58684 L
.49658 .59017 L
.47881 .58996 L
.46188 .58622 L
.44644 .5791 L
.43311 .56887 L
.4224 .55594 L
.41474 .54081 L
.41042 .52408 L
.40962 .50641 L
.41236 .48848 L
.41855 .47101 L
.42793 .45468 L
.44014 .44012 L
.4547 .42791 L
.47103 .41854 L
.48851 .41236 L
Mistroke
.50643 .40962 L
.52411 .41042 L
.54083 .41475 L
.55596 .42241 L
.56888 .43313 L
.57911 .44647 L
.58623 .4619 L
.58996 .47884 L
.59017 .4966 L
.58683 .5145 L
.58009 .53183 L
.57021 .54791 L
.55757 .56211 L
.54267 .57387 L
.52609 .58273 L
.5085 .58835 L
.49056 .5905 L
.473 .58909 L
.4565 .58419 L
.44171 .57599 L
.4292 .5648 L
.41947 .55107 L
.4129 .53534 L
.40975 .51822 L
.41015 .50038 L
.41406 .48253 L
.42136 .46537 L
.43173 .44956 L
.44479 .43573 L
.46001 .42443 L
.47681 .41609 L
.49451 .41104 L
.51243 .40949 L
.52986 .41149 L
.54612 .41696 L
.56057 .42569 L
.57264 .43734 L
.58186 .45144 L
.58787 .46745 L
.59043 .48474 L
.58944 .50263 L
.58494 .52042 L
.57711 .5374 L
.56625 .55292 L
.55279 .56635 L
.53726 .57719 L
.52027 .58499 L
.50248 .58946 L
.48459 .59042 L
.46731 .58783 L
Mistroke
.45131 .5818 L
.43723 .57255 L
.4256 .56045 L
.4169 .54599 L
.41146 .52971 L
.40949 .51228 L
.41107 .49436 L
.41615 .47666 L
.42451 .45988 L
.43584 .44467 L
.44969 .43163 L
.46551 .42128 L
.48268 .41402 L
.50054 .41013 L
.51837 .40977 L
.53548 .41294 L
.5512 .41954 L
.56491 .42929 L
.57607 .44182 L
.58425 .45664 L
.58912 .47315 L
.59049 .49072 L
.58832 .50865 L
.58267 .52624 L
.57378 .5428 L
.562 .55769 L
.54778 .57031 L
.53169 .58016 L
.51435 .58688 L
.49645 .59018 L
.47869 .58995 L
.46176 .58618 L
.44634 .57903 L
.43302 .56878 L
.42233 .55583 L
.41469 .54069 L
.4104 .52396 L
.40962 .50628 L
.41239 .48836 L
.4186 .47089 L
.42801 .45456 L
.44023 .44002 L
.45481 .42783 L
.47116 .41848 L
.48864 .41232 L
.50656 .40961 L
.52423 .41044 L
.54095 .41479 L
.55606 .42248 L
.56897 .43321 L
Mistroke
.57917 .44657 L
Mfstroke
1 0 0 r
.42785 .45479 m
.44004 .44022 L
s
% Start of user PostScript
-2.1644907 -1.3564015 -1.7987555 -1.7935357 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45459 .42799 m
.47091 .41859 L
s
% Start of user PostScript
-1.3624265 -2.1602807 -0.87262768 -2.4422435 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57905 .44636 m
.58619 .46179 L
s
% Start of user PostScript
2.3713716 -1.6091618 2.5856667 -1.1463828 MAarrowhead1
% End of user PostScript
1 .788 0 r
.54278 .5738 m
.52622 .58268 L
s
% Start of user PostScript
1.2834423 2.2138777 0.7865059 2.4804265 MAarrowhead1
% End of user PostScript
.897 1 0 r
.41953 .55118 m
.41294 .53546 L
s
% Start of user PostScript
-2.4141197 1.5354233 -2.6118631 1.0637663 MAarrowhead1
% End of user PostScript
.581 1 0 r
.4599 .4245 m
.47668 .41614 L
s
% Start of user PostScript
-1.2030343 -2.2650186 -0.69951158 -2.5158578 MAarrowhead1
% End of user PostScript
.266 1 0 r
.58181 .45133 m
.58784 .46733 L
s
% Start of user PostScript
2.4541896 -1.4599815 2.635162 -0.97996964 MAarrowhead1
% End of user PostScript
0 1 .049 r
.53738 .57712 m
.52039 .58495 L
s
% Start of user PostScript
1.1212917 2.3136468 0.61174124 2.548498 MAarrowhead1
% End of user PostScript
0 1 .364 r
.41695 .5461 m
.41148 .52984 L
s
% Start of user PostScript
-2.4915369 1.38292 -2.6555375 0.89508585 MAarrowhead1
% End of user PostScript
0 1 .679 r
.46539 .42134 m
.48256 .41406 L
s
% Start of user PostScript
-1.0383051 -2.3597082 -0.52329224 -2.578311 MAarrowhead1
% End of user PostScript
0 1 .995 r
.5842 .45652 m
.5891 .47303 L
s
% Start of user PostScript
2.5261201 -1.3043243 2.672967 -0.80920906 MAarrowhead1
% End of user PostScript
0 .69 1 r
.53181 .58011 m
.51448 .58684 L
s
% Start of user PostScript
0.95416668 2.4031518 0.43426271 2.6052636 MAarrowhead1
% End of user PostScript
0 .375 1 r
.41474 .54081 m
.41042 .52408 L
s
% Start of user PostScript
-2.5579009 1.2242816 -2.6874312 0.72243456 MAarrowhead1
% End of user PostScript
0 .06 1 r
.47103 .41854 m
.48851 .41236 L
s
% Start of user PostScript
-0.8689697 -2.4439295 -0.34475142 -2.629326 MAarrowhead1
% End of user PostScript
1 0 .804 r
.29132 .40931 m
.31862 .36737 L
.35304 .33064 L
.39322 .30056 L
.4376 .2783 L
.48442 .26475 L
.53185 .26043 L
.57804 .26551 L
.62116 .27979 L
.65953 .30271 L
.69163 .33338 L
.71622 .37059 L
.73232 .41288 L
.7393 .45858 L
.73689 .50591 L
.72518 .55301 L
.70464 .59803 L
.67607 .6392 L
.64058 .67491 L
.59958 .70375 L
.55467 .7246 L
.50761 .73663 L
.46026 .73938 L
.41446 .73273 L
.37202 .71695 L
.33461 .69265 L
.30368 .66079 L
.28046 .62262 L
.26586 .57964 L
.26045 .53354 L
.26443 .48612 L
.27766 .43924 L
.29962 .39475 L
.32944 .35438 L
.36596 .31974 L
.40774 .29216 L
.45313 .27275 L
.50037 .26225 L
.54759 .26109 L
.59294 .2693 L
.63465 .28656 L
.67107 .3122 L
.70078 .34521 L
.72261 .3843 L
.7357 .42793 L
.73954 .47438 L
.73398 .52184 L
.71924 .56845 L
.69589 .61236 L
.66486 .65187 L
Mistroke
.62735 .68542 L
.58485 .71169 L
.53902 .72965 L
.49165 .7386 L
.44462 .73819 L
.39975 .72842 L
.35882 .7097 L
.32344 .68274 L
.29498 .64861 L
.27456 .60865 L
.263 .56443 L
.26074 .51767 L
.26786 .47022 L
.2841 .42395 L
.30881 .38065 L
.34102 .34204 L
.37948 .30963 L
.42266 .28469 L
.46888 .2682 L
.51632 .26081 L
.56312 .2628 L
.60744 .27411 L
.64754 .29428 L
.68186 .32252 L
.70904 .35773 L
.72801 .39852 L
.73804 .4433 L
.73872 .4903 L
.73004 .53768 L
.71232 .58358 L
.68628 .6262 L
.65292 .66387 L
.61356 .69511 L
.56975 .71869 L
.5232 .73369 L
.47573 .73951 L
.42922 .73594 L
.38549 .72311 L
.34625 .70152 L
.31305 .67202 L
.28718 .63577 L
.26967 .5942 L
.26119 .54892 L
.26209 .50173 L
.27232 .45447 L
.29149 .40899 L
.31884 .36709 L
.35331 .3304 L
.39353 .30037 L
.43792 .27817 L
Mistroke
.48476 .26468 L
.53219 .26043 L
.57836 .26558 L
.62145 .27992 L
.65978 .30291 L
.69184 .33363 L
.71637 .37088 L
.7324 .41319 L
.73932 .45892 L
.73684 .50625 L
.72507 .55334 L
.70446 .59834 L
.67583 .63948 L
.6403 .67514 L
.59927 .70393 L
.55433 .72472 L
.50727 .73668 L
.45992 .73936 L
.41414 .73265 L
.37174 .7168 L
.33436 .69245 L
.30349 .66054 L
.28033 .62233 L
.26579 .57932 L
.26044 .5332 L
.26449 .48578 L
.27779 .43891 L
.29981 .39444 L
.32968 .35411 L
.36624 .31951 L
.40805 .29199 L
.45347 .27264 L
.50071 .26221 L
.54792 .26111 L
.59326 .26939 L
.63493 .28671 L
.67131 .31241 L
.70097 .34547 L
.72273 .3846 L
.73576 .42825 L
.73954 .47472 L
.73391 .52218 L
.7191 .56877 L
.6957 .61266 L
.66461 .65214 L
.62706 .68563 L
.58453 .71185 L
.53868 .72975 L
.49131 .73863 L
.44428 .73815 L
Mistroke
.39944 .72832 L
.35855 .70953 L
.32321 .68252 L
.2948 .64834 L
.27445 .60835 L
.26295 .5641 L
.26075 .51733 L
.26795 .46989 L
.28425 .42362 L
.30901 .38036 L
.34128 .34179 L
.37977 .30942 L
.42298 .28454 L
.46921 .26812 L
.51666 .26079 L
.56344 .26285 L
.60774 .27422 L
.64781 .29445 L
.68208 .32275 L
.7092 .358 L
.72812 .39883 L
.73808 .44363 L
.73869 .49064 L
.72994 .53801 L
.71216 .5839 L
.68606 .62649 L
.65266 .66412 L
.61326 .69531 L
.56942 .71883 L
.52286 .73376 L
.47539 .73952 L
.4289 .73588 L
.38519 .72298 L
.34599 .70133 L
.31283 .67178 L
.28702 .63549 L
.26957 .59388 L
.26116 .54859 L
.26213 .50139 L
.27243 .45413 L
.29166 .40868 L
.31907 .3668 L
.35358 .33016 L
.39383 .30018 L
.43825 .27805 L
.4851 .26462 L
.53253 .26043 L
.57868 .26565 L
.62175 .28006 L
.66004 .3031 L
Mistroke
.69204 .33387 L
Mfstroke
1 0 0 r
.29132 .40931 m
.31862 .36737 L
s
% Start of user PostScript
-6.260283 -2.7208254 -5.4413546 -3.978866 MAarrowhead1
% End of user PostScript
1 .158 0 r
.35304 .33064 m
.39322 .30056 L
s
% Start of user PostScript
-4.4088748 -5.0807521 -3.2033646 -5.9832391 MAarrowhead1
% End of user PostScript
1 .473 0 r
.69163 .33338 m
.71622 .37059 L
s
% Start of user PostScript
5.7490196 -4.9985244 6.4865797 -3.88231 MAarrowhead1
% End of user PostScript
1 .788 0 r
.64058 .67491 m
.59958 .70375 L
s
% Start of user PostScript
4.2173901 5.2472398 2.9873136 6.1125487 MAarrowhead1
% End of user PostScript
.897 1 0 r
.30368 .66079 m
.28046 .62262 L
s
% Start of user PostScript
-5.8894898 4.8237526 -6.5860793 3.678717 MAarrowhead1
% End of user PostScript
.581 1 0 r
.36596 .31974 m
.40774 .29216 L
s
% Start of user PostScript
-4.0212266 -5.4079064 -2.7679485 -6.2350771 MAarrowhead1
% End of user PostScript
.266 1 0 r
.70078 .34521 m
.72261 .3843 L
s
% Start of user PostScript
6.0234263 -4.6436294 6.6782724 -3.4710429 MAarrowhead1
% End of user PostScript
0 1 .049 r
.62735 .68542 m
.58485 .71169 L
s
% Start of user PostScript
3.820602 5.5625735 2.5455128 6.3506885 MAarrowhead1
% End of user PostScript
0 1 .364 r
.29498 .64861 m
.27456 .60865 L
s
% Start of user PostScript
-6.1506806 4.4583547 -6.7630568 3.2595181 MAarrowhead1
% End of user PostScript
0 1 .679 r
.37948 .30963 m
.42266 .28469 L
s
% Start of user PostScript
-3.615739 -5.7110696 -2.3202531 -6.4592545 MAarrowhead1
% End of user PostScript
0 1 .995 r
.70904 .35773 m
.72801 .39852 L
s
% Start of user PostScript
6.2711113 -4.2681339 6.8403383 -3.0443773 MAarrowhead1
% End of user PostScript
0 .69 1 r
.61356 .69511 m
.56975 .71869 L
s
% Start of user PostScript
3.4068647 5.85323 2.0924193 6.5606547 MAarrowhead1
% End of user PostScript
0 .375 1 r
.28718 .63577 m
.26967 .5942 L
s
% Start of user PostScript
-6.3845851 4.0731782 -6.9100313 2.825859 MAarrowhead1
% End of user PostScript
0 .06 1 r
.39353 .30037 m
.43792 .27817 L
s
% Start of user PostScript
-3.1942109 -5.9888969 -1.8622643 -6.6547767 MAarrowhead1
% End of user PostScript
0 .283 1 r
.50524 .35938 m
.53295 .35968 L
.55936 .3655 L
.58345 .37659 L
.60426 .39253 L
.62098 .41268 L
.63295 .43626 L
.6397 .46235 L
.64097 .48991 L
.63671 .51786 L
.62708 .54512 L
.61247 .5706 L
.59344 .59332 L
.57074 .61237 L
.54527 .62701 L
.51802 .63667 L
.49007 .64096 L
.4625 .63972 L
.43641 .633 L
.41281 .62106 L
.39263 .60436 L
.37667 .58358 L
.36555 .55951 L
.3597 .5331 L
.35936 .5054 L
.36454 .47748 L
.37504 .45045 L
.39044 .42536 L
.41014 .40321 L
.43337 .38485 L
.45921 .37101 L
.48665 .36223 L
.51462 .35886 L
.54201 .36103 L
.56776 .36865 L
.59084 .38143 L
.61036 .39886 L
.62555 .42026 L
.63581 .44479 L
.64074 .47149 L
.64015 .4993 L
.63406 .52715 L
.62271 .55392 L
.60654 .57859 L
.58619 .60016 L
.56245 .61781 L
.53627 .63083 L
.50866 .63872 L
.48071 .64116 L
.45352 .63807 L
Mistroke
.42816 .62955 L
.40561 .61595 L
.38677 .5978 L
.37237 .57582 L
.36298 .55085 L
.35897 .52389 L
.36049 .496 L
.36749 .46826 L
.37969 .44176 L
.39661 .41755 L
.41759 .39658 L
.4418 .37967 L
.4683 .36747 L
.49604 .36048 L
.52393 .35897 L
.55089 .36299 L
.57585 .37239 L
.59783 .38679 L
.61598 .40564 L
.62957 .42819 L
.63808 .45356 L
.64116 .48075 L
.63871 .5087 L
.63082 .53631 L
.61779 .56249 L
.60013 .58622 L
.57855 .60656 L
.55389 .62273 L
.52711 .63407 L
.49926 .64016 L
.47145 .64074 L
.44475 .6358 L
.42023 .62553 L
.39883 .61034 L
.38141 .59081 L
.36864 .56772 L
.36102 .54197 L
.35886 .51458 L
.36224 .48661 L
.37102 .45917 L
.38487 .43333 L
.40324 .41011 L
.4254 .39041 L
.45049 .37502 L
.47752 .36453 L
.50544 .35936 L
.53314 .35971 L
.55954 .36556 L
.58361 .37669 L
.60439 .39266 L
Mistroke
.62108 .41284 L
.63301 .43644 L
.63973 .46254 L
.64096 .49011 L
.63666 .51806 L
.62699 .54531 L
.61234 .57078 L
.59329 .59347 L
.57057 .61249 L
.54508 .6271 L
.51782 .63672 L
.48987 .64097 L
.46231 .63969 L
.43623 .63293 L
.41265 .62095 L
.3925 .60423 L
.37657 .58341 L
.36549 .55932 L
.35968 .53291 L
.35938 .5052 L
.3646 .47728 L
.37513 .45026 L
.39056 .42519 L
.41029 .40306 L
.43354 .38473 L
.4594 .37093 L
.48685 .36219 L
.51482 .35885 L
.5422 .36106 L
.56793 .36872 L
.591 .38154 L
.61049 .399 L
.62564 .42043 L
.63587 .44497 L
.64076 .47168 L
.64013 .4995 L
.634 .52734 L
.62261 .55411 L
.6064 .57875 L
.58603 .6003 L
.56227 .61792 L
.53607 .63091 L
.50846 .63876 L
.48051 .64116 L
.45333 .63803 L
.42798 .62947 L
.40546 .61584 L
.38665 .59766 L
.37228 .57565 L
.36293 .55066 L
Mistroke
.35896 .52369 L
.36052 .49579 L
.36756 .46806 L
.37979 .44158 L
.39674 .41739 L
.41775 .39644 L
.44198 .37956 L
.46849 .36741 L
.49624 .36045 L
.52413 .35898 L
.55108 .36304 L
.57602 .37247 L
.59798 .38691 L
.61609 .40579 L
.62965 .42836 L
.63812 .45375 L
.64117 .48095 L
.63867 .5089 L
.63074 .5365 L
.61768 .56267 L
.59999 .58638 L
.57838 .60669 L
.5537 .62282 L
.52691 .63413 L
.49906 .64018 L
.47125 .64072 L
.44457 .63575 L
.42006 .62544 L
.39869 .61021 L
.3813 .59066 L
.36856 .56754 L
.36099 .54178 L
.35886 .51438 L
.36228 .48641 L
.37111 .45898 L
.38499 .43315 L
.40338 .40995 L
.42557 .39029 L
.45068 .37493 L
.47772 .36447 L
.50564 .35934 L
.53334 .35973 L
.55973 .36562 L
.58377 .37679 L
.60453 .39279 L
.62118 .413 L
.63308 .43662 L
.63976 .46273 L
.64095 .49031 L
.63661 .51826 L
Mistroke
.62691 .5455 L
Mfstroke
1 0 0 r
.50524 .35938 m
.53295 .35968 L
s
% Start of user PostScript
0.15715847 -4.2187452 0.98839414 -4.2095128 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55936 .3655 m
.58345 .37659 L
s
% Start of user PostScript
1.7808393 -4.0350741 2.5033938 -3.7022749 MAarrowhead1
% End of user PostScript
1 .473 0 r
.62708 .54512 m
.61247 .5706 L
s
% Start of user PostScript
3.8124173 1.3535662 3.3739799 2.1181122 MAarrowhead1
% End of user PostScript
1 .788 0 r
.43641 .633 m
.41281 .62106 L
s
% Start of user PostScript
-1.907821 3.9899903 -2.6157722 3.6317261 MAarrowhead1
% End of user PostScript
.897 1 0 r
.37504 .45045 m
.39044 .42536 L
s
% Start of user PostScript
-3.7488727 -1.4864624 -3.2868554 -2.2390755 MAarrowhead1
% End of user PostScript
.581 1 0 r
.56776 .36865 m
.59084 .38143 L
s
% Start of user PostScript
2.0326861 -3.9404802 2.7252487 -3.5571484 MAarrowhead1
% End of user PostScript
.266 1 0 r
.62271 .55392 m
.60654 .57859 L
s
% Start of user PostScript
3.6811693 1.6177094 3.1960845 2.3575548 MAarrowhead1
% End of user PostScript
0 1 .049 r
.42816 .62955 m
.40561 .61595 L
s
% Start of user PostScript
-2.1552962 3.8865985 -2.8317019 3.4786244 MAarrowhead1
% End of user PostScript
0 1 .364 r
.37969 .44176 m
.39661 .41755 L
s
% Start of user PostScript
-3.609382 -1.7471618 -3.1017679 -2.4734187 MAarrowhead1
% End of user PostScript
0 1 .679 r
.57585 .37239 m
.59783 .38679 L
s
% Start of user PostScript
2.2755153 -3.8284051 2.9350137 -3.3962413 MAarrowhead1
% End of user PostScript
0 1 .995 r
.61779 .56249 m
.60013 .58622 L
s
% Start of user PostScript
3.5335906 1.874676 3.0040103 2.5865386 MAarrowhead1
% End of user PostScript
0 .69 1 r
.42023 .62553 m
.39883 .61034 L
s
% Start of user PostScript
-2.3932099 3.7659646 -3.0350694 3.3100905 MAarrowhead1
% End of user PostScript
0 .375 1 r
.38487 .43333 m
.40324 .41011 L
s
% Start of user PostScript
-3.453879 -2.0001104 -2.9029201 -2.696789 MAarrowhead1
% End of user PostScript
0 .06 1 r
.58361 .37669 m
.60439 .39266 L
s
% Start of user PostScript
2.5082496 -3.6993461 3.1317581 -3.2202675 MAarrowhead1
% End of user PostScript
1 0 .673 r
.3173 .52386 m
.32068 .48768 L
.3311 .45199 L
.34815 .41818 L
.37116 .38759 L
.39922 .3614 L
.43124 .34065 L
.46596 .32616 L
.50201 .31849 L
.53799 .31794 L
.57247 .32454 L
.60411 .33803 L
.63166 .35787 L
.65405 .38329 L
.67039 .41329 L
.68004 .44669 L
.68263 .48218 L
.67805 .51838 L
.66648 .55385 L
.64838 .58721 L
.62446 .61715 L
.59565 .64249 L
.56308 .66223 L
.52805 .67561 L
.49191 .6821 L
.45608 .68144 L
.42198 .67366 L
.39095 .65907 L
.36419 .63823 L
.34276 .61197 L
.32751 .58131 L
.31902 .54746 L
.31764 .51175 L
.32341 .47558 L
.33611 .44036 L
.35525 .40749 L
.38007 .37825 L
.40959 .35378 L
.44266 .33506 L
.47798 .3228 L
.51417 .31751 L
.5498 .31937 L
.58347 .32832 L
.61387 .34401 L
.6398 .36583 L
.66025 .3929 L
.6744 .42418 L
.68171 .45844 L
.68189 .49433 L
.67493 .53044 L
Mistroke
.66111 .56535 L
.64096 .59771 L
.61528 .62622 L
.58507 .64978 L
.55153 .66747 L
.51597 .67858 L
.47977 .68268 L
.44438 .67962 L
.41116 .6695 L
.38143 .65273 L
.35636 .62997 L
.33692 .60211 L
.32388 .57024 L
.31776 .53561 L
.31878 .49959 L
.32692 .46358 L
.34185 .429 L
.36299 .39721 L
.38951 .36945 L
.42036 .34682 L
.45434 .33019 L
.4901 .32023 L
.52626 .31733 L
.56139 .3216 L
.59411 .33286 L
.62313 .35069 L
.64732 .37438 L
.66573 .40299 L
.67764 .43542 L
.68257 .47038 L
.68034 .5065 L
.67103 .54236 L
.65501 .57657 L
.63291 .60777 L
.60559 .63473 L
.57412 .65642 L
.53975 .67196 L
.50381 .68075 L
.46773 .68245 L
.43291 .67699 L
.40073 .66459 L
.37244 .64572 L
.34916 .62113 L
.3318 .5918 L
.32104 .55885 L
.3173 .5236 L
.32073 .48743 L
.3312 .45174 L
.34829 .41795 L
.37134 .38738 L
Mistroke
.39944 .36123 L
.43148 .34053 L
.46621 .32608 L
.50227 .31846 L
.53824 .31797 L
.57271 .32462 L
.60432 .33815 L
.63184 .35803 L
.65419 .38349 L
.67048 .41352 L
.68009 .44694 L
.68262 .48244 L
.67799 .51864 L
.66638 .5541 L
.64823 .58744 L
.62427 .61735 L
.59543 .64265 L
.56284 .66235 L
.52779 .67569 L
.49165 .68212 L
.45583 .68141 L
.42175 .67358 L
.39074 .65894 L
.36402 .63806 L
.34263 .61176 L
.32742 .58108 L
.31899 .54721 L
.31765 .51149 L
.32348 .47532 L
.33623 .44012 L
.35541 .40727 L
.38026 .37805 L
.40982 .35363 L
.44291 .33495 L
.47824 .32274 L
.51443 .31749 L
.55005 .31941 L
.5837 .32841 L
.61408 .34415 L
.63997 .366 L
.66037 .39311 L
.67448 .42442 L
.68174 .45869 L
.68187 .49459 L
.67486 .5307 L
.66098 .5656 L
.64079 .59792 L
.61508 .62641 L
.58484 .64993 L
.55128 .66757 L
Mistroke
.51571 .67863 L
.47952 .68269 L
.44413 .67957 L
.41093 .6694 L
.38123 .65259 L
.3562 .62979 L
.3368 .60189 L
.32381 .57 L
.31774 .53536 L
.31882 .49933 L
.32701 .46332 L
.34198 .42876 L
.36316 .39699 L
.38971 .36927 L
.42059 .34667 L
.45459 .3301 L
.49036 .32019 L
.52652 .31734 L
.56163 .32165 L
.59433 .33297 L
.62332 .35084 L
.64748 .37457 L
.66584 .40321 L
.6777 .43566 L
.68258 .47063 L
.6803 .50676 L
.67094 .54262 L
.65487 .5768 L
.63273 .60798 L
.60537 .63491 L
.57388 .65655 L
.53949 .67205 L
.50355 .68079 L
.46748 .68244 L
.43267 .67693 L
.40051 .66447 L
.37226 .64556 L
.34901 .62094 L
.3317 .59157 L
.32098 .55861 L
.3173 .52335 L
.32078 .48717 L
.3313 .45149 L
.34844 .41772 L
.37153 .38718 L
.39966 .36106 L
.43172 .3404 L
.46647 .326 L
.50253 .31843 L
.53849 .31799 L
Mistroke
.57295 .32469 L
Mfstroke
1 0 0 r
.3173 .52386 m
.32068 .48768 L
s
% Start of user PostScript
-5.480966 0.71581995 -5.3795127 -0.36946188 MAarrowhead1
% End of user PostScript
1 .158 0 r
.3311 .45199 m
.34815 .41818 L
s
% Start of user PostScript
-5.0669353 -1.4402438 -4.555501 -2.454502 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57247 .32454 m
.60411 .33803 L
s
% Start of user PostScript
2.1740965 -5.2637256 3.1232879 -4.8591954 MAarrowhead1
% End of user PostScript
1 .788 0 r
.66648 .55385 m
.64838 .58721 L
s
% Start of user PostScript
4.9945218 1.6155647 4.4514724 2.616349 MAarrowhead1
% End of user PostScript
.897 1 0 r
.42198 .67366 m
.39095 .65907 L
s
% Start of user PostScript
-2.3404509 5.2099154 -3.2715547 4.7720517 MAarrowhead1
% End of user PostScript
.581 1 0 r
.33611 .44036 m
.35525 .40749 L
s
% Start of user PostScript
-4.9165675 -1.7890933 -4.3425055 -2.7752936 MAarrowhead1
% End of user PostScript
.266 1 0 r
.58347 .32832 m
.61387 .34401 L
s
% Start of user PostScript
2.5042089 -5.1503253 3.4161922 -4.6796139 MAarrowhead1
% End of user PostScript
0 1 .049 r
.66111 .56535 m
.64096 .59771 L
s
% Start of user PostScript
4.8331589 1.9606372 4.2287211 2.9311593 MAarrowhead1
% End of user PostScript
0 1 .364 r
.41116 .6695 m
.38143 .65273 L
s
% Start of user PostScript
-2.6651887 5.0850217 -3.5570398 4.5819847 MAarrowhead1
% End of user PostScript
0 1 .679 r
.34185 .429 m
.36299 .39721 L
s
% Start of user PostScript
-4.7443884 -2.1300059 -4.1102454 -3.0837732 MAarrowhead1
% End of user PostScript
0 1 .995 r
.59411 .33286 m
.62313 .35069 L
s
% Start of user PostScript
2.8232119 -5.0140767 3.6939413 -4.4792723 MAarrowhead1
% End of user PostScript
0 .69 1 r
.65501 .57657 m
.63291 .60777 L
s
% Start of user PostScript
4.6503546 2.2970117 3.9872099 3.232966 MAarrowhead1
% End of user PostScript
0 .375 1 r
.40073 .66459 m
.37244 .64572 L
s
% Start of user PostScript
-2.978103 4.9375693 -3.8267449 4.3715907 MAarrowhead1
% End of user PostScript
0 .06 1 r
.34829 .41795 m
.37134 .38738 L
s
% Start of user PostScript
-4.5511618 -2.4614692 -3.8597511 -3.3785722 MAarrowhead1
% End of user PostScript
1 .118 0 r
.61778 .20918 m
.67032 .23106 L
.71619 .2635 L
.75357 .30522 L
.78099 .35459 L
.79739 .40966 L
.80212 .46828 L
.79499 .52814 L
.77629 .5869 L
.74674 .64225 L
.7075 .69201 L
.66013 .73424 L
.60647 .76728 L
.54863 .78983 L
.48888 .801 L
.42957 .80036 L
.37302 .78793 L
.32146 .7642 L
.2769 .73011 L
.2411 .68698 L
.21546 .63651 L
.20099 .58069 L
.19825 .5217 L
.20735 .46186 L
.22794 .40351 L
.25921 .34895 L
.29993 .30032 L
.3485 .25953 L
.40301 .22817 L
.46133 .20749 L
.52117 .19828 L
.58018 .20091 L
.63604 .21528 L
.68656 .24083 L
.72976 .27655 L
.76394 .32103 L
.78777 .37254 L
.8003 .42905 L
.80104 .48835 L
.78998 .5481 L
.76753 .60597 L
.73458 .65968 L
.69242 .70712 L
.64271 .74643 L
.5874 .77607 L
.52867 .79488 L
.4688 .80211 L
.41016 .79749 L
.35505 .78119 L
.30563 .75385 L
Mistroke
.26383 .71656 L
.2313 .67076 L
.20932 .61826 L
.19875 .56112 L
.19999 .50159 L
.21302 .44199 L
.2373 .38466 L
.2719 .33187 L
.31545 .28567 L
.36624 .24788 L
.42228 .21999 L
.48137 .20309 L
.54119 .19784 L
.59939 .20445 L
.6537 .22265 L
.70197 .25175 L
.74232 .29058 L
.77315 .33764 L
.79327 .39106 L
.80188 .44877 L
.79863 .50848 L
.78367 .56786 L
.75758 .62457 L
.72137 .6764 L
.67648 .72131 L
.62467 .75753 L
.56796 .78364 L
.50858 .79862 L
.44886 .80188 L
.39116 .79329 L
.33772 .7732 L
.29065 .74238 L
.2518 .70205 L
.22269 .65379 L
.20447 .59949 L
.19784 .54129 L
.20307 .48147 L
.21995 .42237 L
.24783 .36633 L
.2856 .31553 L
.33178 .27196 L
.38457 .23735 L
.44189 .21305 L
.50149 .20001 L
.56103 .19874 L
.61817 .20929 L
.67068 .23126 L
.71649 .26377 L
.7538 .30555 L
.78115 .35496 L
Mistroke
.79747 .41007 L
.80211 .4687 L
.7949 .52857 L
.77611 .58731 L
.74649 .64262 L
.70719 .69234 L
.65976 .73451 L
.60606 .76748 L
.5482 .78995 L
.48845 .80104 L
.42915 .80031 L
.37263 .7878 L
.32111 .76399 L
.27661 .72983 L
.24088 .68664 L
.21532 .63613 L
.20093 .58027 L
.19827 .52127 L
.20746 .46143 L
.22813 .40311 L
.25947 .34858 L
.30025 .3 L
.34887 .25927 L
.40342 .22799 L
.46176 .20738 L
.5216 .19826 L
.58059 .20097 L
.63642 .21543 L
.6869 .24105 L
.73004 .27683 L
.76415 .32138 L
.7879 .37293 L
.80035 .42947 L
.80101 .48878 L
.78985 .54853 L
.76733 .60637 L
.7343 .66004 L
.69209 .70743 L
.64233 .74668 L
.58699 .77624 L
.52824 .79497 L
.46838 .80212 L
.40975 .79741 L
.35467 .78103 L
.3053 .75362 L
.26356 .71626 L
.23111 .67041 L
.2092 .61787 L
.19871 .5607 L
.20005 .50116 L
Mistroke
.21315 .44156 L
.23752 .38427 L
.27218 .33151 L
.31579 .28537 L
.36662 .24765 L
.42269 .21983 L
.4818 .20301 L
.54162 .19784 L
.5998 .20454 L
.65407 .22283 L
.70229 .25199 L
.74257 .29089 L
.77334 .338 L
.79337 .39146 L
.80189 .44919 L
.79857 .50891 L
.78352 .56828 L
.75735 .62497 L
.72108 .67675 L
.67613 .7216 L
.62427 .75775 L
.56754 .78379 L
.50815 .79868 L
.44844 .80186 L
.39076 .79319 L
.33736 .77301 L
.29035 .74212 L
.25156 .70173 L
.22252 .65342 L
.20438 .59908 L
.19783 .54086 L
.20315 .48104 L
.22011 .42196 L
.24806 .36594 L
.2859 .31519 L
.33214 .27168 L
.38497 .23714 L
.44231 .21291 L
.50192 .19995 L
.56145 .19877 L
.61857 .20941 L
.67103 .23145 L
.71679 .26404 L
.75403 .30588 L
.78131 .35534 L
.79754 .41048 L
.8021 .46913 L
.7948 .52899 L
.77594 .58772 L
.74624 .643 L
Mistroke
.70688 .69267 L
Mfstroke
1 0 0 r
.61778 .20918 m
.67032 .23106 L
s
% Start of user PostScript
3.5332509 -8.7247411 5.1096848 -8.0682037 MAarrowhead1
% End of user PostScript
1 .158 0 r
.71619 .2635 m
.75357 .30522 L
s
% Start of user PostScript
6.4855841 -7.0950218 7.6069504 -5.8433889 MAarrowhead1
% End of user PostScript
1 .473 0 r
.7075 .69201 m
.66013 .73424 L
s
% Start of user PostScript
6.2251157 5.7603413 4.8038291 7.0272403 MAarrowhead1
% End of user PostScript
1 .788 0 r
.2769 .73011 m
.2411 .68698 L
s
% Start of user PostScript
-6.6929264 6.9031599 -7.7669533 5.6093299 MAarrowhead1
% End of user PostScript
.897 1 0 r
.29993 .30032 m
.3485 .25953 L
s
% Start of user PostScript
-6.0021919 -5.9902675 -4.5451322 -7.2140724 MAarrowhead1
% End of user PostScript
.581 1 0 r
.72976 .27655 m
.76394 .32103 L
s
% Start of user PostScript
6.8928437 -6.7036398 7.9183398 -5.3690481 MAarrowhead1
% End of user PostScript
.266 1 0 r
.69242 .70712 m
.64271 .74643 L
s
% Start of user PostScript
5.7726093 6.2135481 4.281393 7.3929013 MAarrowhead1
% End of user PostScript
0 1 .049 r
.26383 .71656 m
.2313 .67076 L
s
% Start of user PostScript
-7.0851141 6.4966828 -8.0609418 5.1228099 MAarrowhead1
% End of user PostScript
0 1 .364 r
.31545 .28567 m
.36624 .24788 L
s
% Start of user PostScript
-5.5366227 -6.4299356 -4.0129042 -7.5635287 MAarrowhead1
% End of user PostScript
0 1 .679 r
.74232 .29058 m
.77315 .33764 L
s
% Start of user PostScript
7.2695245 -6.2825185 8.1946011 -4.8708886 MAarrowhead1
% End of user PostScript
0 1 .995 r
.67648 .72131 m
.62467 .75753 L
s
% Start of user PostScript
5.2944939 6.6391899 3.7399635 7.7257652 MAarrowhead1
% End of user PostScript
0 .69 1 r
.2518 .70205 m
.22269 .65379 L
s
% Start of user PostScript
-7.4458703 6.0613845 -8.3191695 4.6135636 MAarrowhead1
% End of user PostScript
0 .375 1 r
.33178 .27196 m
.38457 .23735 L
s
% Start of user PostScript
-5.0464915 -6.8410787 -3.4628738 -7.8794309 MAarrowhead1
% End of user PostScript
0 .06 1 r
.7538 .30555 m
.78115 .35496 L
s
% Start of user PostScript
7.6139557 -5.8335261 8.4345087 -4.3511204 MAarrowhead1
% End of user PostScript
.791 0 1 r
.36485 .74298 m
.32258 .7174 L
.28728 .68328 L
.26032 .64197 L
.24277 .59509 L
.23531 .54447 L
.23824 .49211 L
.25144 .44006 L
.2744 .39037 L
.30622 .34497 L
.34563 .30566 L
.39111 .27398 L
.44086 .25116 L
.49293 .23812 L
.54528 .23535 L
.59585 .24296 L
.64266 .26067 L
.68387 .28776 L
.71787 .32319 L
.74331 .36556 L
.7592 .4132 L
.76493 .46425 L
.76025 .5167 L
.74536 .5685 L
.72084 .61761 L
.68766 .6621 L
.64711 .70023 L
.60078 .7305 L
.55051 .75173 L
.49824 .76308 L
.44605 .7641 L
.39598 .75476 L
.34998 .73542 L
.30988 .70684 L
.27723 .67014 L
.25333 .62677 L
.23911 .57842 L
.23513 .52699 L
.24155 .4745 L
.2581 .42302 L
.28415 .37455 L
.31867 .33101 L
.36031 .2941 L
.40743 .26528 L
.45818 .24566 L
.51058 .23603 L
.56256 .23675 L
.61208 .24781 L
.65721 .26876 L
.69616 .29879 L
Mistroke
.72742 .33672 L
.74975 .38105 L
.76228 .43006 L
.76452 .4818 L
.75637 .53426 L
.73816 .58538 L
.71061 .63315 L
.67479 .67569 L
.63211 .71133 L
.58425 .73869 L
.53308 .75667 L
.48061 .76458 L
.4289 .76211 L
.37999 .74935 L
.33578 .7268 L
.29802 .69536 L
.26818 .65624 L
.24744 .611 L
.23662 .5614 L
.23613 .50938 L
.246 .457 L
.26583 .40631 L
.29486 .3593 L
.33193 .3178 L
.37561 .28346 L
.42416 .25762 L
.47569 .24129 L
.52818 .23511 L
.57956 .23932 L
.62781 .25377 L
.67105 .27788 L
.70758 .31071 L
.73596 .35097 L
.75508 .39708 L
.76419 .44722 L
.76293 .49944 L
.75135 .55168 L
.72991 .60189 L
.69944 .6481 L
.66115 .6885 L
.61653 .7215 L
.56734 .74581 L
.51551 .76047 L
.46307 .76491 L
.41207 .75895 L
.36453 .74283 L
.3223 .71718 L
.28705 .68301 L
.26016 .64165 L
.24268 .59474 L
Mistroke
.23529 .5441 L
.2383 .49174 L
.25158 .4397 L
.2746 .39002 L
.30647 .34467 L
.34594 .3054 L
.39145 .27378 L
.44123 .25103 L
.49331 .23806 L
.54565 .23536 L
.5962 .24305 L
.64298 .26083 L
.68414 .28799 L
.71808 .32347 L
.74346 .36588 L
.75928 .41356 L
.76493 .46462 L
.76018 .51708 L
.74522 .56886 L
.72064 .61794 L
.68739 .6624 L
.6468 .70048 L
.60044 .73069 L
.55014 .75185 L
.49787 .76312 L
.44568 .76407 L
.39563 .75465 L
.34967 .73524 L
.30962 .7066 L
.27703 .66985 L
.2532 .62643 L
.23905 .57806 L
.23514 .52661 L
.24163 .47413 L
.25826 .42266 L
.28437 .37422 L
.31895 .33072 L
.36063 .29387 L
.40778 .2651 L
.45856 .24555 L
.51095 .23599 L
.56292 .23679 L
.61242 .24792 L
.65751 .26895 L
.69641 .29904 L
.72761 .33702 L
.74987 .38139 L
.76233 .43042 L
.76449 .48218 L
.75628 .53464 L
Mistroke
.738 .58574 L
.71038 .63347 L
.67451 .67597 L
.63179 .71156 L
.58389 .73885 L
.53271 .75676 L
.48024 .7646 L
.42854 .76205 L
.37965 .74922 L
.33548 .72661 L
.29777 .6951 L
.268 .65594 L
.24733 .61065 L
.23658 .56103 L
.23616 .50901 L
.2461 .45663 L
.26601 .40596 L
.2951 .35898 L
.33223 .31753 L
.37594 .28324 L
.42452 .25747 L
.47607 .2412 L
.52855 .2351 L
.57992 .23939 L
.62814 .25391 L
.67134 .27809 L
.70781 .31098 L
.73613 .35128 L
.75518 .39742 L
.76422 .44759 L
.76288 .49982 L
.75123 .55205 L
.72972 .60224 L
.6992 .64841 L
.66085 .68876 L
.6162 .72171 L
.56698 .74595 L
.51513 .76054 L
.46269 .76491 L
.41172 .75887 L
.36421 .74268 L
.32202 .71697 L
.28683 .68274 L
.26 .64133 L
.24259 .59438 L
.23528 .54373 L
.23836 .49136 L
.25171 .43933 L
.2748 .38968 L
.30673 .34436 L
Mistroke
.34625 .30515 L
Mfstroke
1 0 0 r
.36485 .74298 m
.32258 .7174 L
s
% Start of user PostScript
-4.0543946 7.2895347 -5.3224975 6.5219691 MAarrowhead1
% End of user PostScript
1 .158 0 r
.28728 .68328 m
.26032 .64197 L
s
% Start of user PostScript
-6.3817138 5.4984424 -7.1904736 4.2591241 MAarrowhead1
% End of user PostScript
1 .473 0 r
.34563 .30566 m
.39111 .27398 L
s
% Start of user PostScript
-4.6309525 -5.8301977 -3.2666614 -6.7807165 MAarrowhead1
% End of user PostScript
1 .788 0 r
.71787 .32319 m
.74331 .36556 L
s
% Start of user PostScript
6.5359587 -5.3042538 7.2992776 -4.0332762 MAarrowhead1
% End of user PostScript
.897 1 0 r
.64711 .70023 m
.60078 .7305 L
s
% Start of user PostScript
4.4132569 6.0068685 3.0235416 6.9150543 MAarrowhead1
% End of user PostScript
.581 1 0 r
.27723 .67014 m
.25333 .62677 L
s
% Start of user PostScript
-6.6829527 5.1041808 -7.3999838 3.8029538 MAarrowhead1
% End of user PostScript
.266 1 0 r
.36031 .2941 m
.40743 .26528 L
s
% Start of user PostScript
-4.1906652 -6.1768754 -2.7770675 -7.0417208 MAarrowhead1
% End of user PostScript
0 1 .049 r
.72742 .33672 m
.74975 .38105 L
s
% Start of user PostScript
6.8225328 -4.8984452 7.4924806 -3.5684126 MAarrowhead1
% End of user PostScript
0 1 .364 r
.63211 .71133 m
.58425 .73869 L
s
% Start of user PostScript
3.9634245 6.3400298 2.5275126 7.1605752 MAarrowhead1
% End of user PostScript
0 1 .679 r
.26818 .65624 m
.24744 .611 L
s
% Start of user PostScript
-6.9545441 4.6872755 -7.5766655 3.3299126 MAarrowhead1
% End of user PostScript
0 1 .995 r
.37561 .28346 m
.42416 .25762 L
s
% Start of user PostScript
-3.7317869 -6.4961506 -2.2751538 -7.2714859 MAarrowhead1
% End of user PostScript
0 .69 1 r
.73596 .35097 m
.75508 .39708 L
s
% Start of user PostScript
7.0788402 -4.4709057 7.6524449 -3.0877184 MAarrowhead1
% End of user PostScript
0 .375 1 r
.61653 .7215 m
.56734 .74581 L
s
% Start of user PostScript
3.4960093 6.6450648 2.0202709 7.3743297 MAarrowhead1
% End of user PostScript
0 .06 1 r
.26016 .64165 m
.24268 .59474 L
s
% Start of user PostScript
-7.1952831 4.249576 -7.7197348 2.8420988 MAarrowhead1
% End of user PostScript
1 0 .108 r
.22914 .52689 m
.23584 .47321 L
.25291 .42059 L
.27967 .37108 L
.31508 .32663 L
.35775 .28898 L
.406 .25962 L
.45794 .23969 L
.51153 .22998 L
.56467 .23086 L
.61527 .24231 L
.66135 .26387 L
.70109 .2947 L
.73294 .33358 L
.75565 .379 L
.76833 .42916 L
.77047 .4821 L
.762 .53575 L
.74325 .588 L
.71495 .63679 L
.67822 .68021 L
.63449 .71656 L
.58548 .74441 L
.53312 .76267 L
.47946 .77062 L
.4266 .76795 L
.37663 .75476 L
.33149 .73158 L
.29297 .6993 L
.26258 .65921 L
.2415 .61286 L
.23057 .56209 L
.23021 .50888 L
.24044 .45532 L
.26086 .40352 L
.29066 .3555 L
.32868 .31315 L
.37342 .27814 L
.42313 .25183 L
.47585 .23526 L
.52953 .22909 L
.58204 .23354 L
.63134 .24845 L
.67548 .27324 L
.71273 .30692 L
.74164 .34818 L
.76106 .3954 L
.77024 .44673 L
.76881 .50014 L
.75683 .55355 L
Mistroke
.73477 .60486 L
.7035 .65205 L
.66424 .69328 L
.61853 .72692 L
.56818 .75165 L
.51515 .76651 L
.46152 .77091 L
.4094 .76468 L
.36084 .74805 L
.31774 .7217 L
.2818 .68664 L
.25441 .64426 L
.23667 .59622 L
.22926 .5444 L
.23248 .49084 L
.24619 .43763 L
.26987 .38688 L
.30257 .34056 L
.34303 .30051 L
.38965 .26828 L
.44059 .24514 L
.49387 .23201 L
.54739 .2294 L
.59905 .2374 L
.64682 .25571 L
.68883 .28361 L
.72343 .32 L
.74926 .36346 L
.76531 .41227 L
.77094 .46453 L
.76595 .51818 L
.75051 .57111 L
.72524 .62126 L
.69114 .66664 L
.64953 .70549 L
.60205 .73627 L
.55057 .75778 L
.4971 .76917 L
.44375 .77 L
.39261 .76023 L
.34568 .74025 L
.3048 .71084 L
.27159 .67315 L
.24734 .62867 L
.23301 .57914 L
.22915 .52651 L
.23593 .47283 L
.25307 .42022 L
.2799 .37074 L
.31537 .32633 L
Mistroke
.35808 .28874 L
.40636 .25944 L
.45832 .23959 L
.51192 .22995 L
.56504 .23091 L
.61562 .24243 L
.66166 .26406 L
.70135 .29495 L
.73314 .33388 L
.75578 .37934 L
.76838 .42953 L
.77045 .48249 L
.76191 .53613 L
.74308 .58836 L
.71472 .63712 L
.67793 .6805 L
.63415 .71679 L
.58512 .74457 L
.53274 .76276 L
.47907 .77064 L
.42623 .76789 L
.37628 .75463 L
.33119 .73138 L
.29273 .69904 L
.26239 .6589 L
.24139 .61251 L
.23053 .56172 L
.23025 .5085 L
.24055 .45494 L
.26104 .40316 L
.2909 .35517 L
.32898 .31287 L
.37376 .27792 L
.4235 .25168 L
.47624 .23518 L
.52991 .22908 L
.58241 .23361 L
.63167 .2486 L
.67577 .27345 L
.71297 .30719 L
.74181 .3485 L
.76116 .39576 L
.77026 .4471 L
.76876 .50053 L
.7567 .55393 L
.73458 .60521 L
.70324 .65237 L
.66393 .69355 L
.61819 .72713 L
.5678 .75179 L
Mistroke
.51476 .76658 L
.46114 .7709 L
.40904 .76459 L
.36051 .7479 L
.31746 .72148 L
.28157 .68636 L
.25425 .64393 L
.23658 .59586 L
.22925 .54402 L
.23254 .49045 L
.24633 .43726 L
.27007 .38653 L
.30284 .34025 L
.34334 .30025 L
.39 .26808 L
.44097 .24501 L
.49426 .23195 L
.54777 .22942 L
.59941 .2375 L
.64715 .25588 L
.68911 .28384 L
.72365 .32029 L
.74941 .36379 L
.76539 .41264 L
.77095 .46491 L
.76587 .51856 L
.75036 .57149 L
.72503 .6216 L
.69086 .66695 L
.64921 .70574 L
.60169 .73646 L
.55019 .7579 L
.49672 .76921 L
.44337 .76997 L
.39225 .76012 L
.34536 .74007 L
.30453 .7106 L
.27138 .67286 L
.2472 .62833 L
.23294 .57877 L
.22916 .52612 L
.23601 .47245 L
.25323 .41985 L
.28012 .3704 L
.31565 .32604 L
.35841 .2885 L
.40673 .25927 L
.4587 .23948 L
.5123 .22992 L
.56542 .23095 L
Mistroke
.61597 .24255 L
Mfstroke
1 0 0 r
.22914 .52689 m
.23584 .47321 L
s
% Start of user PostScript
-8.1257251 0.80667371 -7.9247396 -0.80362187 MAarrowhead1
% End of user PostScript
1 .158 0 r
.25291 .42059 m
.27967 .37108 L
s
% Start of user PostScript
-7.41274 -2.3823785 -6.6098201 -3.8676364 MAarrowhead1
% End of user PostScript
1 .473 0 r
.61527 .24231 m
.66135 .26387 L
s
% Start of user PostScript
3.4581162 -7.7307379 4.840392 -7.083947 MAarrowhead1
% End of user PostScript
1 .788 0 r
.74325 .588 m
.71495 .63679 L
s
% Start of user PostScript
7.2975592 2.6398691 6.4485994 4.1035841 MAarrowhead1
% End of user PostScript
.897 1 0 r
.37663 .75476 m
.33149 .73158 L
s
% Start of user PostScript
-3.7011788 7.6428108 -5.0551779 6.9472673 MAarrowhead1
% End of user PostScript
.581 1 0 r
.26086 .40352 m
.29066 .3555 L
s
% Start of user PostScript
-7.1742826 -2.8944312 -6.2802246 -4.3349794 MAarrowhead1
% End of user PostScript
.266 1 0 r
.63134 .24845 m
.67548 .27324 L
s
% Start of user PostScript
3.9401354 -7.5464049 5.2643557 -6.8028805 MAarrowhead1
% End of user PostScript
0 1 .049 r
.73477 .60486 m
.7035 .65205 L
s
% Start of user PostScript
7.043047 3.1457821 6.1048827 4.5615655 MAarrowhead1
% End of user PostScript
0 1 .364 r
.36084 .74805 m
.31774 .7217 L
s
% Start of user PostScript
-4.1747208 7.4416271 -5.4676934 6.6509467 MAarrowhead1
% End of user PostScript
0 1 .679 r
.26987 .38688 m
.30257 .34056 L
s
% Start of user PostScript
-6.903998 -3.3936432 -5.9227682 -4.7830911 MAarrowhead1
% End of user PostScript
0 1 .995 r
.64682 .25571 m
.68883 .28361 L
s
% Start of user PostScript
4.4046749 -7.3285938 5.6649653 -6.4916345 MAarrowhead1
% End of user PostScript
0 .69 1 r
.72524 .62126 m
.69114 .66664 L
s
% Start of user PostScript
6.7572898 3.6377395 5.7340831 4.9993105 MAarrowhead1
% End of user PostScript
0 .375 1 r
.34568 .74025 m
.3048 .71084 L
s
% Start of user PostScript
-4.6297425 7.2074302 -5.8559526 6.3251206 MAarrowhead1
% End of user PostScript
0 .06 1 r
.2799 .37074 m
.31537 .32633 L
s
% Start of user PostScript
-6.6030852 -3.8778001 -5.5390366 -5.2099837 MAarrowhead1
% End of user PostScript
1 0 .342 r
.17395 .48234 m
.19195 .41746 L
.22205 .35582 L
.26305 .29985 L
.31335 .25172 L
.37098 .21334 L
.43367 .18622 L
.49897 .1714 L
.5643 .16948 L
.62711 .18054 L
.68494 .20413 L
.7355 .23933 L
.77682 .28476 L
.80728 .33864 L
.82568 .39886 L
.8313 .46304 L
.82391 .52867 L
.80381 .59318 L
.77179 .65403 L
.72911 .70884 L
.67743 .75545 L
.61878 .79203 L
.55548 .81715 L
.49 .82983 L
.42491 .82956 L
.36277 .81636 L
.30601 .79074 L
.25687 .75371 L
.21727 .70673 L
.18876 .65163 L
.17247 .59058 L
.16904 .52598 L
.17859 .46035 L
.20076 .39628 L
.23467 .33629 L
.27899 .28271 L
.33199 .23767 L
.39158 .20292 L
.45543 .17983 L
.52103 .1693 L
.5858 .17176 L
.6472 .18709 L
.70283 .21471 L
.75049 .25352 L
.78833 .30201 L
.81485 .35827 L
.82901 .42008 L
.83026 .48504 L
.81855 .55058 L
.79434 .61414 L
Mistroke
.75858 .67322 L
.71266 .7255 L
.65841 .76893 L
.59793 .8018 L
.53361 .82283 L
.46797 .83119 L
.40359 .82656 L
.343 .8091 L
.28856 .77952 L
.24242 .73897 L
.20639 .68903 L
.18189 .63168 L
.16987 .56916 L
.1708 .50393 L
.18466 .43854 L
.21089 .37557 L
.24847 .31747 L
.29592 .26655 L
.35137 .22478 L
.41267 .19381 L
.47738 .17486 L
.54299 .16868 L
.60691 .17549 L
.66663 .19504 L
.71982 .22656 L
.76438 .26881 L
.79856 .32013 L
.82102 .37852 L
.83089 .44167 L
.82777 .50711 L
.81178 .57227 L
.78356 .63459 L
.74421 .69163 L
.69528 .74116 L
.63868 .78121 L
.57664 .81023 L
.51159 .82708 L
.44609 .83109 L
.3827 .8221 L
.32392 .80048 L
.27205 .76706 L
.22912 .72316 L
.19682 .6705 L
.17643 .61115 L
.16873 .54744 L
.17403 .48187 L
.19213 .41701 L
.2223 .3554 L
.26338 .29947 L
.31374 .25141 L
Mistroke
.37142 .21311 L
.43414 .18606 L
.49944 .17134 L
.56477 .16952 L
.62755 .18066 L
.68533 .20434 L
.73583 .23962 L
.77708 .28512 L
.80746 .33906 L
.82577 .39931 L
.83129 .46351 L
.82381 .52914 L
.80363 .59363 L
.77152 .65445 L
.72876 .7092 L
.67703 .75575 L
.61834 .79225 L
.55501 .81729 L
.48953 .82987 L
.42445 .82951 L
.36234 .81622 L
.30563 .79052 L
.25655 .75341 L
.21702 .70636 L
.1886 .65121 L
.1724 .59013 L
.16906 .52551 L
.1787 .45988 L
.20096 .39584 L
.23495 .33588 L
.27934 .28236 L
.3324 .23738 L
.39203 .20271 L
.4559 .17971 L
.5215 .16928 L
.58625 .17182 L
.64762 .18725 L
.7032 .21495 L
.7508 .25384 L
.78856 .30239 L
.815 .35869 L
.82907 .42054 L
.83023 .48551 L
.81842 .55105 L
.79412 .61458 L
.75828 .67362 L
.7123 .72584 L
.65799 .7692 L
.59748 .802 L
.53314 .82294 L
Mistroke
.4675 .83121 L
.40314 .82648 L
.34258 .80893 L
.2882 .77927 L
.24213 .73864 L
.20618 .68865 L
.18176 .63125 L
.16983 .5687 L
.17086 .50346 L
.1848 .43808 L
.21112 .37513 L
.24877 .31708 L
.29629 .26621 L
.35179 .22452 L
.41312 .19363 L
.47785 .17477 L
.54346 .16868 L
.60736 .17559 L
.66704 .19523 L
.72017 .22683 L
.76466 .26915 L
.79876 .32053 L
.82114 .37895 L
.83091 .44213 L
.8277 .50758 L
.81162 .57273 L
.78332 .63502 L
.74389 .69202 L
.6949 .74148 L
.63825 .78146 L
.57618 .8104 L
.51112 .82715 L
.44563 .83107 L
.38226 .82199 L
.32352 .80028 L
.27171 .76678 L
.22885 .72281 L
.19663 .6701 L
.17633 .61071 L
.16872 .54697 L
.17411 .4814 L
.1923 .41655 L
.22256 .35498 L
.26371 .2991 L
.31413 .2511 L
.37185 .21287 L
.4346 .18591 L
.49991 .17128 L
.56523 .16955 L
.62798 .18079 L
Mistroke
.68572 .20455 L
Mfstroke
1 0 0 r
.17395 .48234 m
.19195 .41746 L
s
% Start of user PostScript
-9.7816224 -0.52988427 -9.2414561 -2.4761581 MAarrowhead1
% End of user PostScript
1 .158 0 r
.22205 .35582 m
.26305 .29985 L
s
% Start of user PostScript
-8.3385999 -4.3252526 -7.1084873 -6.0045985 MAarrowhead1
% End of user PostScript
1 .473 0 r
.68494 .20413 m
.7355 .23933 L
s
% Start of user PostScript
5.5481279 -8.8761768 7.0650706 -7.8200928 MAarrowhead1
% End of user PostScript
1 .788 0 r
.77179 .65403 m
.72911 .70884 L
s
% Start of user PostScript
8.1538063 4.6208948 6.8731683 6.2650653 MAarrowhead1
% End of user PostScript
.897 1 0 r
.30601 .79074 m
.25687 .75371 L
s
% Start of user PostScript
-5.8197098 8.7222669 -7.2939978 7.6114199 MAarrowhead1
% End of user PostScript
.581 1 0 r
.23467 .33629 m
.27899 .28271 L
s
% Start of user PostScript
-7.959967 -4.9114107 -6.6302243 -6.5185817 MAarrowhead1
% End of user PostScript
.266 1 0 r
.70283 .21471 m
.75049 .25352 L
s
% Start of user PostScript
6.0848355 -8.5586807 7.5148332 -7.394303 MAarrowhead1
% End of user PostScript
0 1 .049 r
.75858 .67322 m
.71266 .7255 L
s
% Start of user PostScript
7.7572971 5.1964779 6.3799249 6.7648666 MAarrowhead1
% End of user PostScript
0 1 .364 r
.28856 .77952 m
.24242 .73897 L
s
% Start of user PostScript
-6.3432107 8.3855996 -7.7273318 7.168983 MAarrowhead1
% End of user PostScript
0 1 .679 r
.24847 .31747 m
.29592 .26655 L
s
% Start of user PostScript
-7.5460214 -5.4757803 -6.1225477 -7.0036466 MAarrowhead1
% End of user PostScript
0 1 .995 r
.71982 .22656 m
.76438 .26881 L
s
% Start of user PostScript
6.5945489 -8.2032157 7.9312579 -6.9357099 MAarrowhead1
% End of user PostScript
0 .69 1 r
.74421 .69163 m
.69528 .74116 L
s
% Start of user PostScript
7.3263742 5.7490079 5.8583783 7.2346569 MAarrowhead1
% End of user PostScript
0 .375 1 r
.27205 .76706 m
.22912 .72316 L
s
% Start of user PostScript
-6.8385712 8.0117313 -8.1263851 6.6947424 MAarrowhead1
% End of user PostScript
0 .06 1 r
.26338 .29947 m
.31374 .25141 L
s
% Start of user PostScript
-7.0985993 -6.0158577 -5.5877097 -7.4576413 MAarrowhead1
% End of user PostScript
1 .525 0 r
.40758 .64383 m
.38312 .62621 L
.36323 .60365 L
.34872 .57701 L
.34014 .54736 L
.33784 .51584 L
.3419 .48371 L
.35217 .45221 L
.36824 .42259 L
.38948 .396 L
.41505 .3735 L
.44396 .35597 L
.47507 .34408 L
.50716 .33831 L
.53897 .33889 L
.56925 .3458 L
.59681 .35875 L
.62057 .37725 L
.6396 .40057 L
.65315 .42778 L
.66069 .45783 L
.66192 .48954 L
.6568 .52166 L
.64552 .55293 L
.62854 .58212 L
.60651 .60808 L
.5803 .62981 L
.55094 .64644 L
.51957 .65732 L
.48745 .66203 L
.45581 .66038 L
.42591 .65244 L
.39891 .63851 L
.37589 .61915 L
.35773 .59511 L
.34516 .56734 L
.33866 .53693 L
.3385 .50506 L
.34467 .473 L
.35694 .442 L
.37483 .41327 L
.39763 .38795 L
.42444 .36702 L
.45422 .35132 L
.4858 .34145 L
.51793 .3378 L
.54936 .34052 L
.57886 .34949 L
.60526 .36438 L
.62752 .38458 L
Mistroke
.64479 .40932 L
.65637 .43761 L
.66181 .46836 L
.6609 .50034 L
.65368 .53231 L
.64043 .56302 L
.62167 .59125 L
.59813 .6159 L
.57074 .636 L
.54057 .65076 L
.50881 .65961 L
.47671 .66219 L
.44552 .65841 L
.41647 .64841 L
.39069 .63259 L
.36921 .61156 L
.35286 .58615 L
.34228 .55737 L
.3379 .52633 L
.33987 .49426 L
.34813 .46241 L
.36235 .43204 L
.38198 .40434 L
.40623 .38039 L
.43416 .36113 L
.46468 .34733 L
.49659 .33952 L
.52863 .338 L
.55954 .34284 L
.58812 .35385 L
.61324 .3706 L
.63391 .39243 L
.64934 .41847 L
.65889 .44772 L
.66222 .47902 L
.65917 .51114 L
.64988 .54282 L
.63471 .57283 L
.61425 .59997 L
.58931 .6232 L
.56086 .64158 L
.53002 .65441 L
.49801 .66118 L
.46607 .66163 L
.43547 .65573 L
.40739 .64372 L
.38296 .62607 L
.36311 .60347 L
.34864 .57681 L
.34011 .54714 L
Mistroke
.33785 .51561 L
.34196 .48348 L
.35226 .45199 L
.36837 .42239 L
.38965 .39583 L
.41525 .37336 L
.44418 .35586 L
.4753 .34402 L
.50739 .3383 L
.53919 .33892 L
.56945 .34587 L
.59699 .35887 L
.62072 .3774 L
.63971 .40075 L
.65322 .42799 L
.66072 .45806 L
.66191 .48977 L
.65674 .52189 L
.64542 .55314 L
.6284 .58232 L
.60633 .60826 L
.5801 .62995 L
.55072 .64654 L
.51935 .65738 L
.48722 .66204 L
.45559 .66035 L
.4257 .65236 L
.39873 .63839 L
.37574 .61899 L
.35762 .59492 L
.34509 .56713 L
.33864 .5367 L
.33852 .50483 L
.34474 .47277 L
.35705 .44178 L
.37498 .41308 L
.39781 .38778 L
.42465 .36689 L
.45444 .35122 L
.48603 .3414 L
.51816 .33779 L
.54958 .34056 L
.57906 .34958 L
.60543 .3645 L
.62767 .38474 L
.64489 .40951 L
.65643 .43783 L
.66183 .46858 L
.66087 .50057 L
.65361 .53254 L
Mistroke
.64031 .56323 L
.62151 .59144 L
.59794 .61606 L
.57053 .63612 L
.54035 .65085 L
.50858 .65965 L
.47648 .66219 L
.4453 .65836 L
.41627 .64832 L
.39052 .63245 L
.36907 .61139 L
.35276 .58596 L
.34223 .55715 L
.33789 .5261 L
.33991 .49403 L
.34821 .46219 L
.36247 .43183 L
.38213 .40415 L
.40642 .38023 L
.43438 .36101 L
.46491 .34725 L
.49682 .33948 L
.52885 .33801 L
.55976 .3429 L
.58831 .35395 L
.6134 .37074 L
.63404 .3926 L
.64943 .41867 L
.65894 .44794 L
.66222 .47925 L
.65913 .51137 L
.6498 .54305 L
.63458 .57303 L
.61409 .60015 L
.58912 .62335 L
.56065 .64169 L
.5298 .65448 L
.49778 .66121 L
.46585 .66161 L
.43526 .65567 L
.4072 .64361 L
.3828 .62592 L
.36299 .60329 L
.34855 .57661 L
.34007 .54692 L
.33786 .51538 L
.34201 .48325 L
.35236 .45177 L
.36851 .42218 L
.38981 .39565 L
Mistroke
.41545 .37321 L
Mfstroke
1 0 0 r
.40758 .64383 m
.38312 .62621 L
s
% Start of user PostScript
-2.7724999 4.3147966 -3.5065439 3.7864226 MAarrowhead1
% End of user PostScript
1 .158 0 r
.36323 .60365 m
.34872 .57701 L
s
% Start of user PostScript
-4.1029702 3.1094468 -4.5383715 2.3104377 MAarrowhead1
% End of user PostScript
1 .473 0 r
.41505 .3735 m
.44396 .35597 L
s
% Start of user PostScript
-2.5484096 -3.7949164 -1.681097 -4.321044 MAarrowhead1
% End of user PostScript
1 .788 0 r
.6396 .40057 m
.65315 .42778 L
s
% Start of user PostScript
4.1878511 -2.9830481 4.5943644 -2.166515 MAarrowhead1
% End of user PostScript
.897 1 0 r
.5803 .62981 m
.55094 .64644 L
s
% Start of user PostScript
2.4089232 3.8942739 1.5280707 4.393205 MAarrowhead1
% End of user PostScript
.581 1 0 r
.35773 .59511 m
.34516 .56734 L
s
% Start of user PostScript
-4.268086 2.85334 -4.6452605 2.0201889 MAarrowhead1
% End of user PostScript
.266 1 0 r
.42444 .36702 m
.45422 .35132 L
s
% Start of user PostScript
-2.2667645 -3.9893112 -1.3733493 -4.4604922 MAarrowhead1
% End of user PostScript
0 1 .049 r
.64479 .40932 m
.65637 .43761 L
s
% Start of user PostScript
4.343586 -2.7204665 4.6910031 -1.8716216 MAarrowhead1
% End of user PostScript
0 1 .364 r
.57074 .636 m
.54057 .65076 L
s
% Start of user PostScript
2.122091 4.0799228 1.2171042 4.522831 MAarrowhead1
% End of user PostScript
0 1 .679 r
.35286 .58615 m
.34228 .55737 L
s
% Start of user PostScript
-4.4142673 2.584575 -4.7315417 1.7209779 MAarrowhead1
% End of user PostScript
0 1 .995 r
.43416 .36113 m
.46468 .34733 L
s
% Start of user PostScript
-1.9750633 -4.1660082 -1.059509 -4.5801522 MAarrowhead1
% End of user PostScript
0 .69 1 r
.64934 .41847 m
.65889 .44772 L
s
% Start of user PostScript
4.4800514 -2.4458161 4.7668311 -1.5684251 MAarrowhead1
% End of user PostScript
0 .375 1 r
.56086 .64158 m
.53002 .65441 L
s
% Start of user PostScript
1.8258445 4.2474719 0.90073833 4.6323924 MAarrowhead1
% End of user PostScript
0 .06 1 r
.34864 .57681 m
.34011 .54714 L
s
% Start of user PostScript
-4.5408655 2.304344 -4.7968324 1.4141322 MAarrowhead1
% End of user PostScript
0 1 .17 r
.40553 .60717 m
.38844 .58896 L
.37572 .56726 L
.36788 .54292 L
.36523 .51689 L
.36786 .4902 L
.37569 .4639 L
.38839 .43901 L
.40547 .41651 L
.42626 .3973 L
.44994 .38211 L
.47559 .37155 L
.5022 .36603 L
.52872 .36577 L
.55411 .37077 L
.57738 .38085 L
.59762 .39561 L
.61402 .41446 L
.62595 .43667 L
.63293 .46136 L
.6347 .48757 L
.63118 .51427 L
.62251 .54041 L
.60904 .56496 L
.59128 .58696 L
.56994 .60555 L
.54586 .62 L
.51998 .62974 L
.49331 .63439 L
.46691 .63376 L
.4418 .62788 L
.41898 .61698 L
.39934 .6015 L
.38365 .58203 L
.37253 .55934 L
.3664 .53432 L
.36552 .50795 L
.36992 .48127 L
.37943 .45533 L
.39366 .43114 L
.41207 .40966 L
.43393 .39171 L
.45838 .37802 L
.48447 .36912 L
.51117 .36535 L
.53742 .36687 L
.56221 .37361 L
.58456 .38531 L
.60359 .40151 L
.61855 .42158 L
Mistroke
.62886 .44473 L
.63411 .47004 L
.6341 .49653 L
.62883 .52316 L
.6185 .54888 L
.60352 .57268 L
.58448 .59362 L
.56212 .6109 L
.53732 .62382 L
.51106 .63188 L
.48437 .63477 L
.45829 .63236 L
.43384 .62476 L
.41199 .61227 L
.3936 .59537 L
.37938 .57473 L
.3699 .55115 L
.36552 .52557 L
.36642 .49898 L
.37256 .47243 L
.3837 .44697 L
.39941 .42358 L
.41907 .4032 L
.4419 .38661 L
.46701 .37448 L
.49342 .36727 L
.52008 .36527 L
.54596 .36856 L
.57003 .377 L
.59136 .39028 L
.6091 .40786 L
.62255 .42905 L
.6312 .45303 L
.6347 .47886 L
.63291 .50551 L
.62591 .53195 L
.61396 .55713 L
.59755 .58007 L
.5773 .59987 L
.55402 .61575 L
.52862 .62709 L
.5021 .63344 L
.47549 .63455 L
.44985 .63038 L
.42617 .6211 L
.40539 .60706 L
.38833 .58882 L
.37565 .56709 L
.36784 .54274 L
.36523 .5167 L
Mistroke
.3679 .49001 L
.37576 .46371 L
.38849 .43884 L
.4056 .41636 L
.42642 .39717 L
.45012 .38202 L
.47578 .37149 L
.50239 .36601 L
.52891 .36578 L
.55429 .37083 L
.57754 .38094 L
.59775 .39573 L
.61412 .41461 L
.62601 .43684 L
.63296 .46154 L
.63469 .48776 L
.63113 .51446 L
.62243 .54059 L
.60892 .56513 L
.59114 .58711 L
.56978 .60567 L
.54568 .62009 L
.51979 .62979 L
.49312 .6344 L
.46672 .63373 L
.44163 .62782 L
.41883 .61689 L
.39921 .60137 L
.38355 .58187 L
.37246 .55916 L
.36638 .53413 L
.36554 .50776 L
.36997 .48108 L
.37951 .45515 L
.39378 .43098 L
.41222 .40951 L
.4341 .3916 L
.45857 .37794 L
.48466 .36907 L
.51136 .36534 L
.53761 .3669 L
.56238 .37367 L
.58471 .38541 L
.60371 .40164 L
.61864 .42174 L
.62892 .4449 L
.63413 .47023 L
.63408 .49672 L
.62877 .52335 L
.61841 .54906 L
Mistroke
.6034 .57284 L
.58433 .59376 L
.56195 .61101 L
.53714 .62389 L
.51087 .63192 L
.48418 .63477 L
.4581 .63233 L
.43367 .62469 L
.41185 .61216 L
.39348 .59523 L
.3793 .57457 L
.36985 .55097 L
.36551 .52538 L
.36644 .49879 L
.37262 .47224 L
.3838 .44679 L
.39954 .42343 L
.41922 .40307 L
.44207 .38651 L
.4672 .37441 L
.49361 .36724 L
.52027 .36527 L
.54614 .3686 L
.5702 .37708 L
.5915 .39039 L
.60921 .408 L
.62263 .42921 L
.63125 .45321 L
.63471 .47904 L
.63288 .5057 L
.62584 .53213 L
.61386 .5573 L
.59741 .58023 L
.57714 .6 L
.55384 .61585 L
.52843 .62715 L
.50191 .63346 L
.4753 .63454 L
.44967 .63033 L
.42601 .62101 L
.40526 .60694 L
.38822 .58867 L
.37557 .56693 L
.36781 .54255 L
.36523 .51651 L
.36794 .48982 L
.37583 .46353 L
.3886 .43867 L
.40574 .41621 L
.42658 .39705 L
Mistroke
.4503 .38192 L
Mfstroke
1 0 0 r
.40553 .60717 m
.38844 .58896 L
s
% Start of user PostScript
-2.8340786 3.2152153 -3.346909 2.6688738 MAarrowhead1
% End of user PostScript
1 .158 0 r
.37572 .56726 m
.36788 .54292 L
s
% Start of user PostScript
-3.7283867 2.0177897 -3.9635402 1.2875156 MAarrowhead1
% End of user PostScript
1 .473 0 r
.44994 .38211 m
.47559 .37155 L
s
% Start of user PostScript
-1.5017 -3.5367607 -0.73221629 -3.8535717 MAarrowhead1
% End of user PostScript
1 .788 0 r
.62595 .43667 m
.63293 .46136 L
s
% Start of user PostScript
3.7784044 -1.8999895 3.9879285 -1.1591632 MAarrowhead1
% End of user PostScript
.897 1 0 r
.54586 .62 m
.51998 .62974 L
s
% Start of user PostScript
1.3758513 3.6000444 0.59938885 3.8921804 MAarrowhead1
% End of user PostScript
.581 1 0 r
.37253 .55934 m
.3664 .53432 L
s
% Start of user PostScript
-3.8242304 1.7800815 -4.0078925 1.0295249 MAarrowhead1
% End of user PostScript
.266 1 0 r
.45838 .37802 m
.48447 .36912 L
s
% Start of user PostScript
-1.2484762 -3.6593342 -0.46589645 -3.9264712 MAarrowhead1
% End of user PostScript
0 1 .049 r
.62886 .44473 m
.63411 .47004 L
s
% Start of user PostScript
3.8658139 -1.6581986 4.0234103 -0.89874439 MAarrowhead1
% End of user PostScript
0 1 .364 r
.53732 .62382 m
.51106 .63188 L
s
% Start of user PostScript
1.119716 3.7145645 0.33188719 3.956406 MAarrowhead1
% End of user PostScript
0 1 .679 r
.3699 .55115 m
.36552 .52557 L
s
% Start of user PostScript
-3.9031087 1.5344762 -4.0344646 0.76696687 MAarrowhead1
% End of user PostScript
0 1 .995 r
.46701 .37448 m
.49342 .36727 L
s
% Start of user PostScript
-0.98971372 -3.7656739 -0.19750975 -3.9819517 MAarrowhead1
% End of user PostScript
0 .69 1 r
.6312 .45303 m
.6347 .47886 L
s
% Start of user PostScript
3.9360734 -1.4090515 4.0410431 -0.6343385 MAarrowhead1
% End of user PostScript
0 .375 1 r
.52862 .62709 m
.5021 .63344 L
s
% Start of user PostScript
0.85861342 3.8126057 0.062913186 4.0030798 MAarrowhead1
% End of user PostScript
0 .06 1 r
.36784 .54274 m
.36523 .5167 L
s
% Start of user PostScript
-3.9646716 1.2820636 -4.0431386 0.5010064 MAarrowhead1
% End of user PostScript
.942 0 1 r
.55516 .62833 m
.52721 .63996 L
.4982 .64609 L
.46925 .6465 L
.44151 .64115 L
.41606 .63027 L
.39391 .61427 L
.37593 .59378 L
.36281 .56962 L
.35507 .54273 L
.35303 .51415 L
.35675 .48503 L
.3661 .45649 L
.38069 .42965 L
.39998 .40558 L
.42318 .38522 L
.4494 .36935 L
.47761 .35862 L
.5067 .35343 L
.53552 .354 L
.56295 .3603 L
.58791 .37208 L
.60942 .38888 L
.62663 .41004 L
.63888 .43473 L
.64567 .46198 L
.64675 .49073 L
.64207 .51984 L
.63181 .54817 L
.61638 .57461 L
.59638 .59812 L
.5726 .61778 L
.54597 .63282 L
.51754 .64265 L
.48841 .64687 L
.45975 .64534 L
.43266 .6381 L
.40821 .62544 L
.38737 .60785 L
.37095 .58604 L
.35959 .56085 L
.35375 .53327 L
.35364 .50438 L
.35928 .47532 L
.37043 .44723 L
.38668 .42121 L
.40737 .39829 L
.4317 .37935 L
.45871 .36515 L
.48734 .35625 L
Mistroke
.51646 .35298 L
.54494 .35548 L
.57166 .36366 L
.59556 .37719 L
.61571 .39553 L
.63133 .41798 L
.64178 .44365 L
.64668 .47152 L
.64581 .50052 L
.63923 .52949 L
.62718 .55731 L
.61014 .58288 L
.58877 .60519 L
.56393 .62338 L
.53657 .63672 L
.50778 .6447 L
.47868 .647 L
.45042 .64353 L
.42411 .63443 L
.40077 .62005 L
.38133 .60096 L
.36655 .57791 L
.357 .5518 L
.35306 .52366 L
.3549 .49459 L
.36242 .46573 L
.37535 .43821 L
.39317 .41312 L
.41518 .39145 L
.44052 .37403 L
.46819 .36155 L
.49712 .35451 L
.52615 .35318 L
.55416 .35761 L
.58004 .36763 L
.60279 .38284 L
.6215 .40265 L
.63544 .42629 L
.64406 .45281 L
.64703 .48119 L
.64423 .5103 L
.63577 .53902 L
.62198 .5662 L
.60341 .59078 L
.58077 .6118 L
.55497 .62843 L
.52701 .64002 L
.49799 .64612 L
.46905 .64648 L
.44132 .64109 L
Mistroke
.41589 .63017 L
.39377 .61414 L
.37581 .59362 L
.36273 .56944 L
.35504 .54253 L
.35304 .51395 L
.3568 .48482 L
.36618 .45629 L
.38082 .42947 L
.40013 .40542 L
.42336 .38508 L
.4496 .36926 L
.47782 .35856 L
.50691 .35342 L
.53572 .35403 L
.56314 .36036 L
.58808 .37218 L
.60956 .38901 L
.62674 .4102 L
.63895 .43492 L
.6457 .46219 L
.64673 .49094 L
.64201 .52004 L
.63172 .54837 L
.61625 .57479 L
.59622 .59828 L
.57242 .61791 L
.54577 .63291 L
.51733 .6427 L
.48821 .64688 L
.45955 .64531 L
.43247 .63803 L
.40805 .62533 L
.38724 .60771 L
.37085 .58587 L
.35953 .56066 L
.35372 .53306 L
.35366 .50417 L
.35934 .47512 L
.37053 .44704 L
.38681 .42104 L
.40753 .39814 L
.43188 .37923 L
.45891 .36507 L
.48754 .3562 L
.51667 .35298 L
.54514 .35552 L
.57184 .36374 L
.59572 .3773 L
.61584 .39568 L
Mistroke
.63142 .41815 L
.64184 .44384 L
.64669 .47173 L
.64579 .50073 L
.63916 .5297 L
.62707 .5575 L
.61 .58305 L
.58861 .60534 L
.56374 .62349 L
.53637 .6368 L
.50757 .64474 L
.47848 .647 L
.45023 .64349 L
.42393 .63435 L
.40062 .61993 L
.38121 .60081 L
.36646 .57773 L
.35695 .5516 L
.35306 .52345 L
.35493 .49438 L
.3625 .46552 L
.37546 .43802 L
.39331 .41296 L
.41535 .3913 L
.44071 .37392 L
.4684 .36148 L
.49732 .35448 L
.52636 .35319 L
.55435 .35766 L
.58022 .36772 L
.60294 .38297 L
.62161 .40281 L
.63552 .42647 L
.6441 .45301 L
.64703 .4814 L
.64419 .51051 L
.63569 .53922 L
.62187 .56638 L
.60326 .59094 L
.5806 .61193 L
.55478 .62853 L
.5268 .64008 L
.49778 .64614 L
.46884 .64646 L
.44113 .64103 L
.41572 .63007 L
.39362 .614 L
.3757 .59346 L
.36266 .56925 L
.35501 .54233 L
Mistroke
.35304 .51374 L
Mfstroke
1 0 0 r
.55516 .62833 m
.52721 .63996 L
s
% Start of user PostScript
1.65494 3.8498107 0.81644342 4.198701 MAarrowhead1
% End of user PostScript
1 .158 0 r
.4982 .64609 m
.46925 .6465 L
s
% Start of user PostScript
-0.054095283 4.3828092 -0.92251096 4.3949098 MAarrowhead1
% End of user PostScript
1 .473 0 r
.35303 .51415 m
.35675 .48503 L
s
% Start of user PostScript
-4.4091285 0.42460017 -4.2974658 -0.44923637 MAarrowhead1
% End of user PostScript
1 .788 0 r
.5067 .35343 m
.53552 .354 L
s
% Start of user PostScript
0.2009518 -4.3969515 1.0656483 -4.3799469 MAarrowhead1
% End of user PostScript
.897 1 0 r
.64675 .49073 m
.64207 .51984 L
s
% Start of user PostScript
4.4024353 -0.27814924 4.2619719 0.59512093 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48841 .64687 m
.45975 .64534 L
s
% Start of user PostScript
-0.34758539 4.4062159 -1.2076034 4.360125 MAarrowhead1
% End of user PostScript
.266 1 0 r
.35364 .50438 m
.35928 .47532 L
s
% Start of user PostScript
-4.3908582 0.13138973 -4.2217498 -0.74034527 MAarrowhead1
% End of user PostScript
0 1 .049 r
.51646 .35298 m
.54494 .35548 L
s
% Start of user PostScript
0.49383337 -4.4105922 1.3482188 -4.335466 MAarrowhead1
% End of user PostScript
0 1 .364 r
.64581 .50052 m
.63923 .52949 L
s
% Start of user PostScript
4.3744099 0.015515539 4.1768441 0.88474828 MAarrowhead1
% End of user PostScript
0 1 .679 r
.47868 .647 m
.45042 .64353 L
s
% Start of user PostScript
-0.6395335 4.4100754 -1.4873386 4.3059974 MAarrowhead1
% End of user PostScript
0 1 .995 r
.3549 .49459 m
.36242 .46573 L
s
% Start of user PostScript
-4.3531087 -0.1624036 -4.1273048 -1.0281698 MAarrowhead1
% End of user PostScript
0 .69 1 r
.52615 .35318 m
.55416 .35761 L
s
% Start of user PostScript
0.78452414 -4.4046661 1.6248083 -4.2717517 MAarrowhead1
% End of user PostScript
0 .375 1 r
.64423 .5103 m
.63577 .53902 L
s
% Start of user PostScript
4.3269782 0.30911148 4.0731867 1.1704506 MAarrowhead1
% End of user PostScript
0 .06 1 r
.46905 .64648 m
.44132 .64109 L
s
% Start of user PostScript
-0.92864445 4.3943705 -1.7604754 4.2327671 MAarrowhead1
% End of user PostScript
1 0 .255 r
.27544 .27135 m
.33085 .22554 L
.39291 .1905 L
.45916 .16761 L
.52702 .15776 L
.59382 .16135 L
.65693 .17822 L
.71389 .20773 L
.76245 .2487 L
.80071 .29954 L
.82717 .35824 L
.84079 .42251 L
.84104 .48982 L
.8279 .55753 L
.80189 .62298 L
.76404 .6836 L
.71582 .73702 L
.65913 .78114 L
.5962 .81422 L
.52949 .83497 L
.46162 .84258 L
.39526 .83674 L
.33301 .81768 L
.27732 .78616 L
.23036 .7434 L
.19399 .6911 L
.16962 .63129 L
.15822 .56633 L
.16024 .49877 L
.17559 .43126 L
.20367 .36644 L
.24338 .30687 L
.29316 .25487 L
.35106 .2125 L
.41481 .18141 L
.4819 .16282 L
.5497 .15747 L
.61554 .16555 L
.67686 .18677 L
.73123 .22028 L
.77653 .26476 L
.81098 .31848 L
.83322 .37932 L
.84238 .4449 L
.83811 .51264 L
.82056 .57988 L
.79044 .64399 L
.74892 .70245 L
.69763 .75296 L
.63858 .79355 L
Mistroke
.57409 .82261 L
.5067 .83901 L
.43904 .84211 L
.37378 .83179 L
.31347 .80844 L
.26048 .77298 L
.21689 .72681 L
.18441 .67175 L
.16432 .60994 L
.1574 .54381 L
.16392 .47597 L
.18364 .40907 L
.21577 .34574 L
.25906 .28846 L
.3118 .23948 L
.37193 .20073 L
.43709 .17373 L
.50471 .15953 L
.57215 .15869 L
.63676 .17124 L
.696 .1967 L
.74755 .23406 L
.78938 .28186 L
.81986 .33822 L
.83778 .40093 L
.84245 .46753 L
.83367 .5354 L
.8118 .60188 L
.7777 .66437 L
.73269 .7204 L
.67856 .76778 L
.61741 .80466 L
.55166 .82957 L
.48388 .84156 L
.41674 .84013 L
.35286 .82536 L
.29475 .79782 L
.2447 .7586 L
.20467 .70922 L
.17623 .65163 L
.1605 .58809 L
.15809 .5211 L
.1691 .45327 L
.1931 .38728 L
.22914 .32571 L
.27581 .27099 L
.33128 .22525 L
.39337 .19029 L
.45965 .16749 L
.52751 .15774 L
Mistroke
.59429 .16142 L
.65737 .17839 L
.71427 .20798 L
.76277 .24903 L
.80095 .29993 L
.82732 .35869 L
.84084 .42298 L
.84099 .4903 L
.82776 .55801 L
.80166 .62343 L
.76373 .68401 L
.71544 .73737 L
.6587 .78141 L
.59573 .81441 L
.529 .83507 L
.46114 .84258 L
.3948 .83665 L
.33259 .8175 L
.27695 .78589 L
.23006 .74306 L
.19377 .69069 L
.16949 .63084 L
.15819 .56586 L
.1603 .49828 L
.17574 .43078 L
.20391 .36599 L
.2437 .30647 L
.29355 .25453 L
.3515 .21223 L
.41528 .18123 L
.48238 .16273 L
.55018 .15748 L
.616 .16566 L
.67728 .18697 L
.73159 .22056 L
.77682 .26511 L
.81118 .31889 L
.83333 .37978 L
.8424 .44538 L
.83803 .51312 L
.82039 .58035 L
.79018 .64443 L
.74858 .70284 L
.69723 .75329 L
.63813 .7938 L
.57362 .82277 L
.50621 .83908 L
.43856 .84209 L
.37333 .83166 L
.31306 .80822 L
Mistroke
.26013 .77269 L
.21661 .72645 L
.18422 .67132 L
.16422 .60947 L
.1574 .54333 L
.16402 .47548 L
.18383 .4086 L
.21605 .3453 L
.25941 .28808 L
.31221 .23917 L
.37238 .2005 L
.43757 .17358 L
.5052 .15947 L
.57263 .15873 L
.63721 .17138 L
.6964 .19693 L
.74788 .23437 L
.78964 .28224 L
.82003 .33865 L
.83786 .4014 L
.84243 .46801 L
.83356 .53588 L
.8116 .60235 L
.77741 .66479 L
.73234 .72077 L
.67814 .76809 L
.61696 .80488 L
.55118 .82971 L
.4834 .84159 L
.41626 .84008 L
.35242 .82521 L
.29436 .79758 L
.24438 .75828 L
.20443 .70883 L
.17607 .65119 L
.16043 .58762 L
.15812 .52061 L
.16923 .45279 L
.19331 .38682 L
.22944 .3253 L
.27618 .27063 L
.3317 .22496 L
.39383 .19009 L
.46013 .16738 L
.52799 .15772 L
.59475 .1615 L
.6578 .17856 L
.71465 .20824 L
.76308 .24936 L
.80118 .30033 L
Mistroke
.82746 .35913 L
Mfstroke
1 0 0 r
.27544 .27135 m
.33085 .22554 L
s
% Start of user PostScript
-6.7367895 -6.8594691 -5.0743684 -8.2337626 MAarrowhead1
% End of user PostScript
1 .158 0 r
.39291 .1905 m
.45916 .16761 L
s
% Start of user PostScript
-3.2127989 -9.2849142 -1.2251399 -9.9716703 MAarrowhead1
% End of user PostScript
1 .473 0 r
.82717 .35824 m
.84079 .42251 L
s
% Start of user PostScript
9.8152394 -4.2527467 10.22384 -2.3247268 MAarrowhead1
% End of user PostScript
1 .788 0 r
.5962 .81422 m
.52949 .83497 L
s
% Start of user PostScript
2.885879 9.426562 0.8846106 10.049101 MAarrowhead1
% End of user PostScript
.897 1 0 r
.16962 .63129 m
.15822 .56633 L
s
% Start of user PostScript
-9.9113605 3.9387727 -10.253304 1.9900175 MAarrowhead1
% End of user PostScript
.581 1 0 r
.41481 .18141 m
.4819 .16282 L
s
% Start of user PostScript
-2.5557575 -9.5577522 -0.54309991 -10.115383 MAarrowhead1
% End of user PostScript
.266 1 0 r
.83322 .37932 m
.84238 .4449 L
s
% Start of user PostScript
9.9964861 -3.620429 10.271393 -1.6531006 MAarrowhead1
% End of user PostScript
0 1 .049 r
.57409 .82261 m
.5067 .83901 L
s
% Start of user PostScript
2.2228008 9.6783392 0.20098671 10.170444 MAarrowhead1
% End of user PostScript
0 1 .364 r
.16432 .60994 m
.1574 .54381 L
s
% Start of user PostScript
-10.070522 3.2980689 -10.278088 1.3143498 MAarrowhead1
% End of user PostScript
0 1 .679 r
.43709 .17373 m
.50471 .15953 L
s
% Start of user PostScript
-1.8873781 -9.7881893 0.14134945 -10.214221 MAarrowhead1
% End of user PostScript
0 1 .995 r
.83778 .40093 m
.84245 .46753 L
s
% Start of user PostScript
10.133385 -2.9720499 10.27338 -0.97414086 MAarrowhead1
% End of user PostScript
0 .69 1 r
.55166 .82957 m
.48388 .84156 L
s
% Start of user PostScript
1.5498616 9.8871805 -0.48352881 10.246667 MAarrowhead1
% End of user PostScript
0 .375 1 r
.1605 .58809 m
.15809 .5211 L
s
% Start of user PostScript
-10.185007 2.6427338 -10.257274 0.63285122 MAarrowhead1
% End of user PostScript
0 .06 1 r
.45965 .16749 m
.52751 .15774 L
s
% Start of user PostScript
-1.2106257 -9.975203 0.82517175 -10.267746 MAarrowhead1
% End of user PostScript
1 0 .317 r
.24405 .73792 m
.20816 .68831 L
.18372 .6313 L
.17169 .56915 L
.17255 .50428 L
.18626 .43924 L
.21228 .37658 L
.24959 .31877 L
.29673 .26808 L
.35185 .22648 L
.41278 .19562 L
.47714 .1767 L
.54239 .17048 L
.60598 .17718 L
.66541 .19656 L
.71835 .22784 L
.76272 .2698 L
.79677 .3208 L
.81918 .37883 L
.82907 .44162 L
.82604 .5067 L
.81021 .57151 L
.78221 .63352 L
.74313 .69029 L
.69452 .73959 L
.63826 .77949 L
.57658 .80842 L
.5119 .82524 L
.44675 .8293 L
.38369 .82044 L
.32519 .799 L
.27355 .76582 L
.23081 .72222 L
.19862 .66989 L
.17827 .61089 L
.17054 .54755 L
.17574 .48233 L
.19366 .41781 L
.22361 .35652 L
.26441 .30086 L
.31445 .25301 L
.37178 .21485 L
.43413 .18789 L
.49907 .17318 L
.56405 .17129 L
.62652 .1823 L
.68401 .20578 L
.73429 .24081 L
.77537 .28601 L
.80565 .33961 L
Mistroke
.82393 .3995 L
.82949 .46334 L
.82213 .52862 L
.80212 .59277 L
.77026 .65328 L
.72779 .70778 L
.67638 .75412 L
.61804 .79049 L
.55508 .81546 L
.48995 .82805 L
.42522 .82776 L
.36342 .81461 L
.30698 .78911 L
.25812 .75227 L
.21875 .70553 L
.19042 .65072 L
.17424 .58999 L
.17084 .52573 L
.18036 .46047 L
.20243 .39675 L
.23617 .33709 L
.28027 .28382 L
.33299 .23903 L
.39227 .20449 L
.45577 .18155 L
.52101 .1711 L
.58543 .17356 L
.64649 .18883 L
.7018 .21631 L
.7492 .25493 L
.78681 .30317 L
.81317 .35913 L
.82724 .42062 L
.82846 .48522 L
.81679 .5504 L
.79269 .61361 L
.75711 .67236 L
.71143 .72434 L
.65746 .76752 L
.5973 .8002 L
.53333 .8211 L
.46805 .8294 L
.40402 .82476 L
.34376 .80739 L
.28963 .77795 L
.24376 .7376 L
.20794 .68792 L
.18359 .63087 L
.17165 .56869 L
.1726 .50381 L
Mistroke
.1864 .43878 L
.21251 .37615 L
.2499 .31838 L
.2971 .26774 L
.35227 .22622 L
.41324 .19544 L
.47761 .17661 L
.54286 .17048 L
.60642 .17728 L
.66581 .19674 L
.7187 .2281 L
.763 .27014 L
.79698 .3212 L
.8193 .37927 L
.82909 .44208 L
.82597 .50717 L
.81005 .57197 L
.78197 .63395 L
.74282 .69067 L
.69414 .73991 L
.63784 .77974 L
.57613 .80858 L
.51143 .82532 L
.44629 .82928 L
.38325 .82033 L
.32479 .7988 L
.27321 .76555 L
.23054 .72187 L
.19843 .66949 L
.17816 .61045 L
.17053 .54708 L
.17582 .48187 L
.19384 .41736 L
.22387 .3561 L
.26474 .30048 L
.31484 .2527 L
.37221 .21462 L
.43459 .18774 L
.49954 .17312 L
.56451 .17132 L
.62695 .18242 L
.6844 .20599 L
.73462 .2411 L
.77563 .28637 L
.80582 .34002 L
.82401 .39995 L
.82949 .4638 L
.82203 .52908 L
.80194 .59322 L
.76999 .6537 L
Mistroke
.72745 .70814 L
.67598 .75442 L
.61761 .79071 L
.55462 .81559 L
.48948 .82809 L
.42476 .82771 L
.36299 .81447 L
.3066 .78889 L
.2578 .75197 L
.21851 .70516 L
.19026 .6503 L
.17417 .58954 L
.17086 .52527 L
.18048 .46 L
.20263 .39631 L
.23645 .33668 L
.28062 .28347 L
.33339 .23875 L
.39271 .20428 L
.45624 .18142 L
.52148 .17107 L
.58588 .17362 L
.64691 .18898 L
.70217 .21655 L
.7495 .25524 L
.78704 .30354 L
.81331 .35955 L
.82729 .42107 L
.82842 .48569 L
.81666 .55087 L
.79248 .61405 L
.75681 .67276 L
.71107 .72469 L
.65704 .76779 L
.59685 .80039 L
.53286 .8212 L
.46758 .82941 L
.40357 .82468 L
.34335 .80722 L
.28927 .77769 L
.24347 .73727 L
.20773 .68754 L
.18346 .63044 L
.17161 .56823 L
.17266 .50334 L
.18655 .43832 L
.21274 .37572 L
.2502 .31799 L
.29747 .26741 L
.35269 .22596 L
Mistroke
.41369 .19526 L
Mfstroke
1 0 0 r
.24405 .73792 m
.20816 .68831 L
s
% Start of user PostScript
-7.6783508 7.1376563 -8.7551587 5.6492548 MAarrowhead1
% End of user PostScript
1 .158 0 r
.18372 .6313 m
.17169 .56915 L
s
% Start of user PostScript
-9.4883618 3.9391427 -9.849185 2.0744351 MAarrowhead1
% End of user PostScript
1 .473 0 r
.41278 .19562 m
.47714 .1767 L
s
% Start of user PostScript
-2.6164604 -9.1314283 -0.68581027 -9.6988976 MAarrowhead1
% End of user PostScript
1 .788 0 r
.81918 .37883 m
.82907 .44162 L
s
% Start of user PostScript
9.5755093 -3.6349987 9.8720275 -1.7513903 MAarrowhead1
% End of user PostScript
.897 1 0 r
.57658 .80842 m
.5119 .82524 L
s
% Start of user PostScript
2.2975252 9.2525006 0.3569989 9.7572319 MAarrowhead1
% End of user PostScript
.581 1 0 r
.17827 .61089 m
.17054 .54755 L
s
% Start of user PostScript
-9.6520338 3.3268222 -9.8839182 1.4264024 MAarrowhead1
% End of user PostScript
.266 1 0 r
.43413 .18789 m
.49907 .17318 L
s
% Start of user PostScript
-1.9760413 -9.3633083 -0.027791483 -9.8047416 MAarrowhead1
% End of user PostScript
0 1 .049 r
.82393 .3995 m
.82949 .46334 L
s
% Start of user PostScript
9.7178506 -3.0149549 9.8848439 -1.0998322 MAarrowhead1
% End of user PostScript
0 1 .364 r
.55508 .81546 m
.48995 .82805 L
s
% Start of user PostScript
1.6523651 9.4637285 -0.30144677 9.8413741 MAarrowhead1
% End of user PostScript
0 1 .679 r
.17424 .58999 m
.17084 .52573 L
s
% Start of user PostScript
-9.7728865 2.6997429 -9.8748035 0.7720418 MAarrowhead1
% End of user PostScript
0 1 .995 r
.45577 .18155 m
.52101 .1711 L
s
% Start of user PostScript
-1.3268559 -9.5536499 0.6303506 -9.8670888 MAarrowhead1
% End of user PostScript
0 .69 1 r
.82724 .42062 m
.82846 .48522 L
s
% Start of user PostScript
9.8170806 -2.3815359 9.8538082 -0.44339493 MAarrowhead1
% End of user PostScript
0 .375 1 r
.53333 .8211 m
.46805 .8294 L
s
% Start of user PostScript
0.99987466 9.6329726 -0.95855513 9.8818571 MAarrowhead1
% End of user PostScript
0 .06 1 r
.17165 .56869 m
.1726 .50381 L
s
% Start of user PostScript
-9.8503838 2.0606868 -9.8218812 0.11425616 MAarrowhead1
% End of user PostScript
0 .717 1 r
.19264 .28122 m
.24978 .21901 L
.31673 .16783 L
.39088 .12969 L
.46931 .10607 L
.54894 .09792 L
.62665 .10555 L
.6994 .12866 L
.76431 .16634 L
.81886 .21712 L
.86089 .279 L
.88875 .34955 L
.90136 .42601 L
.89822 .50537 L
.87945 .58452 L
.84579 .66035 L
.79855 .72989 L
.7396 .79041 L
.67125 .83953 L
.59617 .87533 L
.51732 .89639 L
.43779 .9019 L
.36071 .89163 L
.28909 .866 L
.22574 .826 L
.17316 .77321 L
.13341 .70969 L
.10804 .63795 L
.09806 .56079 L
.10385 .48125 L
.12519 .40244 L
.16124 .32746 L
.21058 .25925 L
.27128 .20049 L
.34096 .15349 L
.41688 .12008 L
.49606 .10158 L
.5754 .09873 L
.65178 .11161 L
.7222 .13975 L
.7839 .18202 L
.83446 .23677 L
.87189 .30185 L
.89473 .3747 L
.90207 .45248 L
.89364 .53212 L
.86975 .6105 L
.83136 .68454 L
.77996 .75134 L
.71758 .80828 L
Mistroke
.64665 .85311 L
.56997 .88409 L
.49054 .9 L
.41149 .9002 L
.33591 .88471 L
.26677 .85411 L
.20678 .80961 L
.1583 .75297 L
.12323 .68639 L
.10294 .6125 L
.09824 .5342 L
.10931 .45455 L
.13571 .37669 L
.17641 .30366 L
.2298 .23835 L
.29381 .1833 L
.3659 .14068 L
.44325 .11216 L
.52284 .09886 L
.60152 .10131 L
.67623 .1194 L
.74401 .15243 L
.80222 .1991 L
.84857 .25758 L
.88124 .32558 L
.89895 .40042 L
.901 .47916 L
.88731 .55873 L
.85842 .63599 L
.81546 .70791 L
.76013 .77168 L
.69458 .82478 L
.6214 .86513 L
.54346 .89116 L
.46381 .90183 L
.38558 .89674 L
.31184 .87607 L
.24548 .84064 L
.18911 .79185 L
.14495 .7316 L
.11472 .66226 L
.09961 .58656 L
.10021 .50745 L
.1165 .42806 L
.14785 .35149 L
.19301 .28074 L
.25023 .2186 L
.31724 .16751 L
.39143 .12946 L
.46988 .10596 L
Mistroke
.54951 .09792 L
.6272 .10566 L
.69989 .12888 L
.76474 .16666 L
.81921 .21752 L
.86114 .27948 L
.8889 .35008 L
.9014 .42657 L
.89814 .50594 L
.87926 .58508 L
.84549 .66088 L
.79817 .73036 L
.73914 .7908 L
.67073 .83984 L
.59562 .87553 L
.51675 .89649 L
.43723 .90188 L
.36017 .89151 L
.2886 .86576 L
.22532 .82567 L
.17283 .77279 L
.13317 .70921 L
.10792 .63741 L
.09805 .56023 L
.10395 .48067 L
.1254 .40188 L
.16155 .32694 L
.21098 .25879 L
.27175 .20011 L
.34149 .1532 L
.41744 .11989 L
.49664 .10151 L
.57596 .09876 L
.65231 .11176 L
.72267 .14 L
.7843 .18237 L
.83477 .2372 L
.87211 .30235 L
.89483 .37525 L
.90207 .45305 L
.89352 .53269 L
.86953 .61105 L
.83104 .68505 L
.77955 .75179 L
.71709 .80864 L
.64612 .85339 L
.56941 .88426 L
.48997 .90006 L
.41093 .90015 L
.33539 .88454 L
Mistroke
.2663 .85384 L
.20639 .80925 L
.158 .75252 L
.12303 .68588 L
.10285 .61195 L
.09827 .53363 L
.10945 .45398 L
.13595 .37614 L
.17675 .30317 L
.23023 .23791 L
.2943 .18295 L
.36644 .14042 L
.44382 .11201 L
.52341 .09882 L
.60208 .10138 L
.67674 .11959 L
.74447 .15272 L
.8026 .19948 L
.84886 .25804 L
.88142 .32609 L
.89902 .40097 L
.90095 .47973 L
.88715 .55929 L
.85816 .63653 L
.81511 .7084 L
.75969 .7721 L
.69408 .82511 L
.62086 .86537 L
.54289 .89129 L
.46324 .90185 L
.38503 .89664 L
.31133 .87587 L
.24504 .84034 L
.18875 .79145 L
.14468 .73113 L
.11455 .66174 L
.09955 .586 L
.10027 .50688 L
.11668 .42749 L
.14812 .35095 L
.19338 .28026 L
.25067 .2182 L
.31775 .16719 L
.39198 .12924 L
.47045 .10585 L
.55008 .09792 L
.62774 .10577 L
.70039 .1291 L
.76517 .16698 L
.81955 .21793 L
Mistroke
.86139 .27995 L
Mfstroke
1 0 0 r
.19264 .28122 m
.24978 .21901 L
s
% Start of user PostScript
-9.220683 -6.5633547 -7.5066649 -8.4296295 MAarrowhead1
% End of user PostScript
1 .158 0 r
.31673 .16783 m
.39088 .12969 L
s
% Start of user PostScript
-5.4980405 -9.9650753 -3.2736401 -11.109432 MAarrowhead1
% End of user PostScript
1 .473 0 r
.86089 .279 m
.88875 .34955 L
s
% Start of user PostScript
10.826614 -6.6300875 11.662603 -4.5135113 MAarrowhead1
% End of user PostScript
1 .788 0 r
.67125 .83953 m
.59617 .87533 L
s
% Start of user PostScript
5.1374344 10.185906 2.8851894 11.259765 MAarrowhead1
% End of user PostScript
.897 1 0 r
.13341 .70969 m
.10804 .63795 L
s
% Start of user PostScript
-10.997728 6.2908217 -11.758701 4.138478 MAarrowhead1
% End of user PostScript
.581 1 0 r
.34096 .15349 m
.41688 .12008 L
s
% Start of user PostScript
-4.7711288 -10.395437 -2.4935378 -11.397607 MAarrowhead1
% End of user PostScript
.266 1 0 r
.87189 .30185 m
.89473 .3747 L
s
% Start of user PostScript
11.156642 -5.9445769 11.841754 -3.7588535 MAarrowhead1
% End of user PostScript
0 1 .049 r
.64665 .85311 m
.56997 .88409 L
s
% Start of user PostScript
4.3995303 10.593435 2.09912 11.522805 MAarrowhead1
% End of user PostScript
0 1 .364 r
.12323 .68639 m
.10294 .6125 L
s
% Start of user PostScript
-11.303179 5.5917373 -11.911671 3.3750591 MAarrowhead1
% End of user PostScript
0 1 .679 r
.3659 .14068 m
.44325 .11216 L
s
% Start of user PostScript
-4.0230511 -10.779681 -1.7023735 -11.635219 MAarrowhead1
% End of user PostScript
0 1 .995 r
.88124 .32558 m
.89895 .40042 L
s
% Start of user PostScript
11.437176 -5.2326944 11.968372 -2.9875204 MAarrowhead1
% End of user PostScript
0 .69 1 r
.6214 .86513 m
.54346 .89116 L
s
% Start of user PostScript
3.6421087 10.953969 1.3037384 11.734726 MAarrowhead1
% End of user PostScript
0 .375 1 r
.11472 .66226 m
.09961 .58656 L
s
% Start of user PostScript
-11.558485 4.8678464 -12.011796 2.5966675 MAarrowhead1
% End of user PostScript
0 .06 1 r
.39143 .12946 m
.46988 .10596 L
s
% Start of user PostScript
-3.2571259 -11.116104 -0.90365691 -11.821214 MAarrowhead1
% End of user PostScript
0 1 .328 r
.2792 .68313 m
.25263 .64022 L
.23577 .5918 L
.22928 .53978 L
.23341 .4862 L
.24801 .43316 L
.27249 .38274 L
.3059 .33692 L
.34694 .29751 L
.39397 .26604 L
.44517 .24375 L
.49852 .23152 L
.55193 .22983 L
.6033 .23874 L
.65062 .25791 L
.69203 .28657 L
.7259 .32361 L
.7509 .36757 L
.76606 .41674 L
.77077 .46916 L
.76486 .5228 L
.74855 .57555 L
.72249 .62533 L
.6877 .67019 L
.64554 .70837 L
.59767 .73837 L
.54597 .75902 L
.49246 .7695 L
.43925 .76941 L
.38842 .75874 L
.34197 .73792 L
.30172 .70776 L
.26926 .66945 L
.24585 .62449 L
.23241 .57464 L
.22948 .52186 L
.23716 .46822 L
.25516 .41584 L
.28277 .36675 L
.3189 .32289 L
.36214 .28599 L
.4108 .25748 L
.46295 .23849 L
.51655 .22977 L
.56951 .23165 L
.61974 .24406 L
.66527 .26652 L
.70431 .29814 L
.73533 .33768 L
.75712 .38359 L
Mistroke
.76882 .43407 L
.76997 .48714 L
.76052 .54071 L
.74085 .59269 L
.71172 .64103 L
.67429 .68383 L
.63002 .71942 L
.58064 .74639 L
.5281 .7637 L
.47445 .77066 L
.42181 .76699 L
.37224 .75285 L
.32768 .72879 L
.28989 .69574 L
.26034 .65501 L
.24019 .6082 L
.23024 .55714 L
.23088 .50384 L
.24208 .45039 L
.26341 .39889 L
.29402 .35135 L
.33271 .30965 L
.37797 .27542 L
.42801 .25 L
.48089 .2344 L
.53451 .22921 L
.58678 .23466 L
.63564 .25052 L
.67918 .27617 L
.71569 .3106 L
.74373 .35247 L
.76221 .40013 L
.77039 .4517 L
.76797 .50518 L
.75503 .55844 L
.73208 .60942 L
.70002 .6561 L
.66011 .69666 L
.61392 .72949 L
.56325 .75332 L
.51011 .76721 L
.45657 .77061 L
.40473 .7634 L
.35663 .74584 L
.31416 .71863 L
.27898 .68285 L
.25248 .63989 L
.23569 .59144 L
.22927 .5394 L
.23348 .48581 L
Mistroke
.24815 .43278 L
.2727 .38239 L
.30617 .33662 L
.34725 .29725 L
.39433 .26585 L
.44555 .24363 L
.49891 .23147 L
.55231 .22986 L
.60366 .23884 L
.65094 .25808 L
.6923 .28681 L
.72611 .3239 L
.75104 .36791 L
.76613 .4171 L
.77077 .46955 L
.76478 .52319 L
.7484 .57592 L
.72227 .62567 L
.68742 .67049 L
.64522 .70861 L
.59731 .73855 L
.54559 .75913 L
.49207 .76954 L
.43887 .76937 L
.38807 .75863 L
.34166 .73774 L
.30146 .70751 L
.26906 .66915 L
.24572 .62414 L
.23235 .57427 L
.2295 .52148 L
.23726 .46784 L
.25533 .41547 L
.283 .36642 L
.31919 .3226 L
.36248 .28575 L
.41116 .25731 L
.46333 .23839 L
.51694 .22974 L
.56988 .2317 L
.62008 .24419 L
.66557 .26671 L
.70456 .29839 L
.73552 .33799 L
.75724 .38394 L
.76887 .43445 L
.76994 .48753 L
.76042 .54109 L
.74067 .59305 L
.71148 .64136 L
Mistroke
.674 .68411 L
.62968 .71964 L
.58027 .74655 L
.52772 .76379 L
.47407 .77067 L
.42144 .76693 L
.3719 .75271 L
.32738 .72858 L
.28964 .69547 L
.26016 .6547 L
.24008 .60785 L
.23021 .55677 L
.23093 .50346 L
.2422 .45001 L
.26359 .39853 L
.29427 .35103 L
.33301 .30938 L
.37831 .2752 L
.42838 .24985 L
.48127 .23432 L
.53489 .22921 L
.58714 .23473 L
.63597 .25067 L
.67947 .27638 L
.71592 .31088 L
.7439 .35279 L
.7623 .40048 L
.77041 .45208 L
.76791 .50556 L
.7549 .55882 L
.73188 .60977 L
.69976 .65642 L
.6598 .69692 L
.61357 .7297 L
.56288 .75346 L
.50972 .76728 L
.45619 .7706 L
.40437 .76331 L
.3563 .74568 L
.31388 .71841 L
.27876 .68257 L
.25232 .63956 L
.2356 .59107 L
.22926 .53902 L
.23355 .48543 L
.24829 .43241 L
.27291 .38204 L
.30644 .33631 L
.34757 .297 L
.39468 .26565 L
Mistroke
.44593 .24351 L
Mfstroke
1 0 0 r
.2792 .68313 m
.25263 .64022 L
s
% Start of user PostScript
-6.6239076 5.494004 -7.4210178 4.206541 MAarrowhead1
% End of user PostScript
1 .158 0 r
.23577 .5918 m
.22928 .53978 L
s
% Start of user PostScript
-7.9268829 2.7539883 -8.1216498 1.1933526 MAarrowhead1
% End of user PostScript
1 .473 0 r
.44517 .24375 m
.49852 .23152 L
s
% Start of user PostScript
-1.6448076 -7.6873812 -0.0442743 -8.0542646 MAarrowhead1
% End of user PostScript
1 .788 0 r
.76606 .41674 m
.77077 .46916 L
s
% Start of user PostScript
7.9816671 -2.4979418 8.1231245 -0.92508612 MAarrowhead1
% End of user PostScript
.897 1 0 r
.54597 .75902 m
.49246 .7695 L
s
% Start of user PostScript
1.3789592 7.7705811 -0.22628569 8.0850768 MAarrowhead1
% End of user PostScript
.581 1 0 r
.23241 .57464 m
.22948 .52186 L
s
% Start of user PostScript
-8.0275966 2.2391241 -8.1155875 0.6557934 MAarrowhead1
% End of user PostScript
.266 1 0 r
.46295 .23849 m
.51655 .22977 L
s
% Start of user PostScript
-1.111581 -7.8451605 0.49659465 -8.1069196 MAarrowhead1
% End of user PostScript
0 1 .049 r
.76882 .43407 m
.76997 .48714 L
s
% Start of user PostScript
8.0646205 -1.9778223 8.0990472 -0.38577315 MAarrowhead1
% End of user PostScript
0 1 .364 r
.5281 .7637 m
.47445 .77066 L
s
% Start of user PostScript
0.8429696 7.9110366 -0.76635269 8.1197687 MAarrowhead1
% End of user PostScript
0 1 .679 r
.23024 .55714 m
.23088 .50384 L
s
% Start of user PostScript
-8.0926976 1.7143264 -8.073522 0.11532493 MAarrowhead1
% End of user PostScript
0 1 .995 r
.48089 .2344 m
.53451 .22921 L
s
% Start of user PostScript
-0.57342305 -7.9681363 1.0352606 -8.1236098 MAarrowhead1
% End of user PostScript
0 .69 1 r
.77039 .4517 m
.76797 .50518 L
s
% Start of user PostScript
8.1117968 -1.4489287 8.0390402 0.15525123 MAarrowhead1
% End of user PostScript
0 .375 1 r
.51011 .76721 m
.45657 .77061 L
s
% Start of user PostScript
0.30324035 8.0163963 -1.3030199 8.1184388 MAarrowhead1
% End of user PostScript
0 .06 1 r
.22927 .5394 m
.23348 .48581 L
s
% Start of user PostScript
-8.121897 1.1819235 -7.99564 -0.42565516 MAarrowhead1
% End of user PostScript
0 .969 1 r
.21422 .38579 m
.24962 .32841 L
.29484 .27777 L
.34812 .23585 L
.40735 .20429 L
.47023 .18434 L
.53427 .17678 L
.59696 .18191 L
.65586 .19951 L
.70863 .22892 L
.75322 .26895 L
.78786 .31806 L
.81122 .37431 L
.82235 .43549 L
.82084 .4992 L
.80673 .56294 L
.78059 .62422 L
.74343 .68062 L
.69672 .72993 L
.64229 .77021 L
.58228 .79989 L
.51904 .8178 L
.45505 .82324 L
.39282 .816 L
.3348 .79635 L
.28326 .76507 L
.24023 .72339 L
.2074 .67294 L
.18604 .6157 L
.17701 .55393 L
.18066 .49003 L
.19684 .42653 L
.22491 .36591 L
.26378 .31056 L
.31193 .26263 L
.36745 .22403 L
.42818 .19625 L
.49172 .1804 L
.55559 .17709 L
.61728 .18645 L
.67436 .20812 L
.72461 .24124 L
.76603 .28452 L
.79702 .33625 L
.81635 .39441 L
.82326 .45672 L
.81749 .52072 L
.79926 .58391 L
.76928 .64381 L
.72873 .69806 L
Mistroke
.67921 .74454 L
.62266 .78143 L
.56129 .80726 L
.49751 .82104 L
.43383 .82222 L
.37275 .81075 L
.31667 .78709 L
.26778 .75216 L
.228 .70734 L
.1989 .65437 L
.18161 .59535 L
.17682 .53259 L
.18471 .46854 L
.20498 .40574 L
.23683 .34663 L
.279 .29354 L
.32985 .24855 L
.38737 .21343 L
.44932 .18956 L
.51325 .17787 L
.57667 .17883 L
.63707 .19239 L
.6921 .21802 L
.73959 .25471 L
.77767 .30104 L
.80486 .35517 L
.82008 .41499 L
.82274 .47814 L
.81273 .54215 L
.79045 .60451 L
.75678 .66276 L
.71302 .71463 L
.6609 .75808 L
.60247 .79139 L
.54002 .81327 L
.476 .82286 L
.41292 .81977 L
.35325 .80413 L
.29935 .77656 L
.25332 .73814 L
.21697 .69037 L
.19173 .63512 L
.17859 .57458 L
.17806 .5111 L
.19017 .4472 L
.21443 .38536 L
.24991 .32802 L
.2952 .27744 L
.34852 .23558 L
.40779 .20411 L
Mistroke
.47068 .18425 L
.53473 .17677 L
.5974 .18199 L
.65626 .19968 L
.70898 .22917 L
.7535 .26928 L
.78807 .31844 L
.81134 .37473 L
.82239 .43594 L
.82078 .49966 L
.80659 .5634 L
.78036 .62464 L
.74313 .681 L
.69636 .73025 L
.64188 .77046 L
.58184 .80006 L
.51858 .81789 L
.45459 .82324 L
.39239 .8159 L
.3344 .79616 L
.28292 .76481 L
.23996 .72305 L
.2072 .67255 L
.18593 .61527 L
.17699 .55347 L
.18073 .48957 L
.197 .42608 L
.22515 .36549 L
.2641 .31018 L
.3123 .26232 L
.36787 .22379 L
.42863 .1961 L
.49218 .18033 L
.55604 .17711 L
.61771 .18656 L
.67475 .20832 L
.72494 .24152 L
.76629 .28486 L
.7972 .33665 L
.81644 .39485 L
.82327 .45718 L
.8174 .52118 L
.79908 .58436 L
.76903 .64422 L
.72841 .69843 L
.67883 .74484 L
.62223 .78165 L
.56083 .80741 L
.49705 .8211 L
.43338 .82218 L
Mistroke
.37233 .81063 L
.31629 .78688 L
.26746 .75187 L
.22775 .70698 L
.19873 .65397 L
.18153 .59491 L
.17683 .53213 L
.18482 .46809 L
.20517 .4053 L
.23709 .34622 L
.27934 .29318 L
.33024 .24826 L
.3878 .21322 L
.44977 .18943 L
.51371 .17783 L
.57711 .17888 L
.63749 .19253 L
.69247 .21824 L
.73989 .25501 L
.7779 .3014 L
.80501 .35558 L
.82014 .41543 L
.82271 .4786 L
.81262 .54261 L
.79025 .60494 L
.7565 .66316 L
.71267 .71498 L
.6605 .75835 L
.60204 .79159 L
.53956 .81338 L
.47554 .82288 L
.41247 .8197 L
.35284 .80398 L
.29899 .77632 L
.25302 .73783 L
.21675 .68999 L
.19159 .6347 L
.17854 .57413 L
.1781 .51065 L
.1903 .44674 L
.21465 .38493 L
.2502 .32763 L
.29555 .2771 L
.34893 .23532 L
.40824 .20392 L
.47114 .18415 L
.53518 .17677 L
.59784 .18207 L
.65666 .19986 L
.70933 .22942 L
Mistroke
.75379 .2696 L
Mfstroke
1 0 0 r
.21422 .38579 m
.24962 .32841 L
s
% Start of user PostScript
-8.5734285 -3.4262852 -7.5114915 -5.1476026 MAarrowhead1
% End of user PostScript
1 .158 0 r
.29484 .27777 m
.34812 .23585 L
s
% Start of user PostScript
-6.1547586 -6.6668973 -4.5564763 -7.9245432 MAarrowhead1
% End of user PostScript
1 .473 0 r
.75322 .26895 m
.78786 .31806 L
s
% Start of user PostScript
7.5964876 -6.9313585 8.6359457 -5.4581468 MAarrowhead1
% End of user PostScript
1 .788 0 r
.69672 .72993 m
.64229 .77021 L
s
% Start of user PostScript
5.9017395 6.8977627 4.2688356 8.1063398 MAarrowhead1
% End of user PostScript
.897 1 0 r
.24023 .72339 m
.2074 .67294 L
s
% Start of user PostScript
-7.7930591 6.7016121 -8.7781294 5.1881459 MAarrowhead1
% End of user PostScript
.581 1 0 r
.31193 .26263 m
.36745 .22403 L
s
% Start of user PostScript
-5.6421732 -7.1209759 -3.9764591 -8.2791433 MAarrowhead1
% End of user PostScript
.266 1 0 r
.76603 .28452 m
.79702 .33625 L
s
% Start of user PostScript
7.9809851 -6.464431 8.9105749 -4.9123893 MAarrowhead1
% End of user PostScript
0 1 .049 r
.67921 .74454 m
.62266 .78143 L
s
% Start of user PostScript
5.3763475 7.3362891 3.6796712 8.4427621 MAarrowhead1
% End of user PostScript
0 1 .364 r
.228 .70734 m
.1989 .65437 L
s
% Start of user PostScript
-8.1600572 6.2200785 -9.0331351 4.631183 MAarrowhead1
% End of user PostScript
0 1 .679 r
.32985 .24855 m
.38737 .21343 L
s
% Start of user PostScript
-5.1045573 -7.5434637 -3.3788012 -8.5970147 MAarrowhead1
% End of user PostScript
0 1 .995 r
.77767 .30104 m
.80486 .35517 L
s
% Start of user PostScript
8.3300766 -5.9688255 9.1456741 -4.344839 MAarrowhead1
% End of user PostScript
0 .69 1 r
.6609 .75808 m
.60247 .79139 L
s
% Start of user PostScript
4.8271043 7.7422696 3.0741827 8.7417299 MAarrowhead1
% End of user PostScript
0 .375 1 r
.21697 .69037 m
.19173 .63512 L
s
% Start of user PostScript
-8.4908548 5.7109508 -9.2480671 4.0536749 MAarrowhead1
% End of user PostScript
0 .06 1 r
.34852 .23558 m
.40779 .20411 L
s
% Start of user PostScript
-4.5442962 -7.9324864 -2.7661538 -8.8767472 MAarrowhead1
% End of user PostScript
.745 0 1 r
.4447 .48438 m
.45026 .47331 L
.45778 .46329 L
.46695 .45471 L
.47742 .44791 L
.48877 .44315 L
.50057 .44062 L
.51234 .44042 L
.52363 .44256 L
.53399 .44696 L
.54302 .45344 L
.55036 .46174 L
.55572 .47155 L
.5589 .48247 L
.55976 .49408 L
.55828 .50592 L
.55451 .51753 L
.54861 .52845 L
.54079 .53826 L
.53137 .54656 L
.52073 .55304 L
.50927 .55744 L
.49744 .55958 L
.48572 .55938 L
.47456 .55685 L
.46439 .55209 L
.45562 .54529 L
.4486 .53671 L
.44359 .52669 L
.4408 .51562 L
.44032 .50394 L
.4422 .4921 L
.44634 .48057 L
.45258 .46981 L
.46069 .46023 L
.47034 .45221 L
.48115 .44607 L
.4927 .44204 L
.50454 .44029 L
.51621 .44088 L
.52723 .44379 L
.53719 .44891 L
.54568 .45603 L
.55239 .46488 L
.55704 .47511 L
.55945 .48631 L
.55952 .49805 L
.55726 .50987 L
.55276 .5213 L
.54618 .53189 L
Mistroke
.53779 .54123 L
.52792 .54896 L
.51695 .55476 L
.50532 .55841 L
.49347 .55977 L
.48189 .55879 L
.47101 .5555 L
.46127 .55003 L
.45306 .54259 L
.44668 .53349 L
.4424 .52307 L
.44038 .51174 L
.44069 .49996 L
.44334 .48817 L
.44821 .47685 L
.45511 .46644 L
.46377 .45735 L
.47386 .44993 L
.48497 .44447 L
.49667 .4412 L
.5085 .44023 L
.52 .44161 L
.53071 .44528 L
.54022 .45109 L
.54815 .45883 L
.55419 .46818 L
.5581 .47878 L
.55974 .49022 L
.55902 .50203 L
.556 .51377 L
.55077 .52497 L
.54355 .53519 L
.53462 .54402 L
.52434 .55113 L
.5131 .55623 L
.50134 .55913 L
.48953 .5597 L
.47813 .55794 L
.4676 .55389 L
.45833 .54774 L
.4507 .5397 L
.445 .53012 L
.44146 .51934 L
.44022 .50781 L
.44133 .49598 L
.44473 .4843 L
.45031 .47324 L
.45784 .46322 L
.46702 .45465 L
.47749 .44786 L
Mistroke
.48885 .44312 L
.50065 .44061 L
.51242 .44043 L
.52371 .44259 L
.53406 .447 L
.54308 .45349 L
.5504 .46181 L
.55575 .47162 L
.55891 .48255 L
.55976 .49416 L
.55826 .50601 L
.55448 .51761 L
.54856 .52853 L
.54073 .53833 L
.5313 .54662 L
.52065 .55308 L
.50918 .55746 L
.49736 .55958 L
.48564 .55937 L
.47448 .55683 L
.46432 .55205 L
.45557 .54523 L
.44856 .53664 L
.44356 .52661 L
.44078 .51554 L
.44033 .50385 L
.44222 .49202 L
.44637 .48049 L
.45263 .46974 L
.46075 .46017 L
.47041 .45216 L
.48123 .44603 L
.49279 .44202 L
.50463 .44029 L
.51629 .4409 L
.52731 .44382 L
.53725 .44896 L
.54574 .45609 L
.55243 .46495 L
.55706 .47519 L
.55946 .48639 L
.55952 .49814 L
.55724 .50995 L
.55272 .52138 L
.54613 .53196 L
.53772 .5413 L
.52784 .54901 L
.51687 .55479 L
.50523 .55843 L
.49339 .55977 L
Mistroke
.48181 .55877 L
.47094 .55546 L
.46121 .54998 L
.453 .54253 L
.44664 .53342 L
.44238 .52299 L
.44037 .51166 L
.4407 .49987 L
.44337 .48809 L
.44825 .47678 L
.45517 .46637 L
.46384 .45729 L
.47393 .44988 L
.48505 .44444 L
.49676 .44118 L
.50859 .44023 L
.52008 .44162 L
.53079 .44531 L
.54028 .45114 L
.5482 .45889 L
.55423 .46825 L
.55812 .47886 L
.55974 .4903 L
.55901 .50212 L
.55597 .51385 L
.55072 .52505 L
.54349 .53526 L
.53455 .54408 L
.52426 .55118 L
.51301 .55626 L
.50126 .55914 L
.48945 .5597 L
.47806 .55791 L
.46752 .55386 L
.45827 .54768 L
.45065 .53964 L
.44497 .53004 L
.44144 .51926 L
.44022 .50773 L
.44134 .49589 L
.44477 .48422 L
.45036 .47316 L
.4579 .46316 L
.46709 .4546 L
.47757 .44782 L
.48894 .4431 L
.50074 .4406 L
.51251 .44044 L
.52378 .44261 L
.53413 .44704 L
Mistroke
.54313 .45354 L
Mfstroke
1 0 0 r
.4447 .48438 m
.45026 .47331 L
s
% Start of user PostScript
-1.658976 -0.46858515 -1.492116 -0.80065009 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45778 .46329 m
.46695 .45471 L
s
% Start of user PostScript
-1.2666964 -1.1012927 -0.99156408 -1.3587141 MAarrowhead1
% End of user PostScript
1 .473 0 r
.54302 .45344 m
.55036 .46174 L
s
% Start of user PostScript
1.2905066 -1.3969229 1.5106864 -1.1477946 MAarrowhead1
% End of user PostScript
1 .788 0 r
.54079 .53826 m
.53137 .54656 L
s
% Start of user PostScript
1.223713 1.1478206 0.94124708 1.3969441 MAarrowhead1
% End of user PostScript
.897 1 0 r
.45562 .54529 m
.4486 .53671 L
s
% Start of user PostScript
-1.3312653 1.358692 -1.5420368 1.1012661 MAarrowhead1
% End of user PostScript
.581 1 0 r
.46069 .46023 m
.47034 .45221 L
s
% Start of user PostScript
-1.179372 -1.1930751 -0.88988587 -1.4336244 MAarrowhead1
% End of user PostScript
.266 1 0 r
.54568 .45603 m
.55239 .46488 L
s
% Start of user PostScript
1.3705471 -1.3189538 1.5716766 -1.0535158 MAarrowhead1
% End of user PostScript
0 1 .049 r
.53779 .54123 m
.52792 .54896 L
s
% Start of user PostScript
1.1337227 1.237006 0.83753744 1.4687143 MAarrowhead1
% End of user PostScript
0 1 .364 r
.45306 .54259 m
.44668 .53349 L
s
% Start of user PostScript
-1.4083084 1.2777524 -1.5995728 1.0045968 MAarrowhead1
% End of user PostScript
0 1 .679 r
.46377 .45735 m
.47386 .44993 L
s
% Start of user PostScript
-1.0868156 -1.2795645 -0.78425986 -1.5021747 MAarrowhead1
% End of user PostScript
0 1 .995 r
.54815 .45883 m
.55419 .46818 L
s
% Start of user PostScript
1.4445074 -1.2351334 1.6256944 -0.95456325 MAarrowhead1
% End of user PostScript
0 .69 1 r
.53462 .54402 m
.52434 .55113 L
s
% Start of user PostScript
1.0387029 1.3207036 0.73011224 1.5339687 MAarrowhead1
% End of user PostScript
0 .375 1 r
.4507 .5397 m
.445 .53012 L
s
% Start of user PostScript
-1.4791038 1.1911443 -1.6500126 0.90347077 MAarrowhead1
% End of user PostScript
0 .06 1 r
.46702 .45465 m
.47749 .44786 L
s
% Start of user PostScript
-0.98943782 -1.3603775 -0.67515465 -1.564061 MAarrowhead1
% End of user PostScript
0 .388 1 r
.64243 .57269 m
.62165 .60136 L
.5961 .62606 L
.56678 .64581 L
.53484 .65984 L
.50153 .6676 L
.46816 .66878 L
.43605 .66333 L
.40644 .65148 L
.3805 .63368 L
.35925 .61063 L
.34353 .58324 L
.33395 .55259 L
.33088 .51987 L
.33445 .48637 L
.34452 .4534 L
.36069 .42227 L
.38233 .39418 L
.40858 .37025 L
.43843 .35141 L
.47069 .3384 L
.5041 .33174 L
.53735 .33168 L
.56913 .33822 L
.5982 .35111 L
.62342 .36985 L
.64379 .39369 L
.65852 .42171 L
.66703 .4528 L
.66898 .48574 L
.6643 .51924 L
.65318 .55198 L
.63604 .58269 L
.61356 .61015 L
.58663 .63329 L
.55629 .6512 L
.52375 .66317 L
.49027 .66874 L
.45718 .66768 L
.42576 .66005 L
.39727 .64613 L
.3728 .62648 L
.35332 .60187 L
.3396 .57326 L
.33218 .54177 L
.33134 .50864 L
.33712 .47518 L
.3493 .44268 L
.36738 .41244 L
.39068 .38564 L
Mistroke
.41826 .36332 L
.44905 .34636 L
.48184 .33544 L
.51535 .33098 L
.54825 .33314 L
.57925 .34186 L
.60715 .35678 L
.63084 .37733 L
.6494 .40268 L
.66209 .43186 L
.66843 .46371 L
.66815 .49699 L
.66127 .53038 L
.64807 .56258 L
.62905 .59233 L
.60497 .61845 L
.57676 .63992 L
.54555 .6559 L
.51255 .66577 L
.47905 .66913 L
.44638 .66585 L
.41581 .65606 L
.38855 .64014 L
.36566 .61873 L
.34804 .59266 L
.33639 .56295 L
.33116 .53077 L
.33255 .49738 L
.34051 .46409 L
.35474 .43222 L
.37466 .403 L
.39951 .3776 L
.4283 .35699 L
.4599 .342 L
.49308 .33321 L
.52652 .33096 L
.55893 .33535 L
.58902 .3462 L
.61562 .36309 L
.63769 .38535 L
.65435 .41211 L
.66495 .44232 L
.66908 .47479 L
.66657 .50825 L
.65752 .54139 L
.6423 .5729 L
.62148 .60156 L
.59591 .62622 L
.56656 .64594 L
.53461 .65992 L
Mistroke
.50129 .66763 L
.46793 .66876 L
.43582 .66327 L
.40624 .65137 L
.38033 .63353 L
.35912 .61045 L
.34344 .58303 L
.3339 .55236 L
.33088 .51963 L
.3345 .48613 L
.34461 .45317 L
.36083 .42206 L
.3825 .394 L
.40879 .3701 L
.43865 .3513 L
.47093 .33833 L
.50434 .33171 L
.53758 .3317 L
.56935 .33829 L
.5984 .35123 L
.62358 .37 L
.64392 .39388 L
.65861 .42192 L
.66707 .45303 L
.66897 .48598 L
.66425 .51948 L
.65308 .55221 L
.6359 .5829 L
.61338 .61033 L
.58642 .63344 L
.55606 .6513 L
.52351 .66323 L
.49003 .66875 L
.45695 .66765 L
.42555 .65997 L
.39707 .64601 L
.37264 .62632 L
.3532 .60168 L
.33953 .57304 L
.33215 .54154 L
.33136 .5084 L
.33719 .47494 L
.3494 .44246 L
.36753 .41224 L
.39086 .38546 L
.41847 .36318 L
.44928 .34626 L
.48208 .33539 L
.51559 .33097 L
.54848 .33318 L
Mistroke
.57947 .34194 L
.60734 .35691 L
.631 .37749 L
.64951 .40288 L
.66216 .43208 L
.66845 .46395 L
.66812 .49723 L
.6612 .53062 L
.64795 .56281 L
.62889 .59253 L
.60478 .61862 L
.57655 .64006 L
.54532 .656 L
.51231 .66582 L
.47882 .66913 L
.44615 .6658 L
.41561 .65596 L
.38837 .64001 L
.36551 .61856 L
.34794 .59245 L
.33633 .56272 L
.33114 .53053 L
.33258 .49714 L
.34059 .46386 L
.35486 .432 L
.37483 .40281 L
.3997 .37743 L
.42852 .35686 L
.46013 .34191 L
.49332 .33317 L
.52676 .33097 L
.55916 .33541 L
.58923 .3463 L
.6158 .36323 L
.63783 .38552 L
.65444 .41231 L
.665 .44254 L
.66908 .47503 L
.66653 .50849 L
.65744 .54162 L
.64217 .57312 L
.62132 .60175 L
.59571 .62638 L
.56634 .64606 L
.53437 .66 L
.50105 .66766 L
.46769 .66875 L
.4356 .66321 L
.40604 .65126 L
.38016 .63338 L
Mistroke
.35899 .61027 L
Mfstroke
1 0 0 r
.64243 .57269 m
.62165 .60136 L
s
% Start of user PostScript
4.2727721 2.180581 3.6495481 3.0409064 MAarrowhead1
% End of user PostScript
1 .158 0 r
.5961 .62606 m
.56678 .64581 L
s
% Start of user PostScript
2.883094 3.7818885 2.00349 4.3744467 MAarrowhead1
% End of user PostScript
1 .473 0 r
.35925 .61063 m
.34353 .58324 L
s
% Start of user PostScript
-4.2224562 3.3189073 -4.6941629 2.4972495 MAarrowhead1
% End of user PostScript
1 .788 0 r
.40858 .37025 m
.43843 .35141 L
s
% Start of user PostScript
-2.742455 -3.8924326 -1.8471398 -4.4576236 MAarrowhead1
% End of user PostScript
.897 1 0 r
.64379 .39369 m
.65852 .42171 L
s
% Start of user PostScript
4.3138002 -3.1892605 4.7556863 -2.3487777 MAarrowhead1
% End of user PostScript
.581 1 0 r
.58663 .63329 m
.55629 .6512 L
s
% Start of user PostScript
2.5987736 3.9986585 1.6887403 4.5358552 MAarrowhead1
% End of user PostScript
.266 1 0 r
.35332 .60187 m
.3396 .57326 L
s
% Start of user PostScript
-4.4003585 3.0560757 -4.8119338 2.1977003 MAarrowhead1
% End of user PostScript
0 1 .049 r
.41826 .36332 m
.44905 .34636 L
s
% Start of user PostScript
-2.4522092 -4.1004484 -1.5284674 -4.6090548 MAarrowhead1
% End of user PostScript
0 1 .364 r
.6494 .40268 m
.66209 .43186 L
s
% Start of user PostScript
4.4820352 -2.9195005 4.8628431 -2.0441847 MAarrowhead1
% End of user PostScript
0 1 .679 r
.57676 .63992 m
.54555 .6559 L
s
% Start of user PostScript
2.3029244 4.1976893 1.3664989 4.6771413 MAarrowhead1
% End of user PostScript
0 1 .995 r
.34804 .59266 m
.33639 .56295 L
s
% Start of user PostScript
-4.5587396 2.7796865 -4.9083576 1.8884014 MAarrowhead1
% End of user PostScript
0 .69 1 r
.4283 .35699 m
.4599 .342 L
s
% Start of user PostScript
-2.1510847 -4.2902734 -1.2030143 -4.740039 MAarrowhead1
% End of user PostScript
0 .375 1 r
.65435 .41211 m
.66495 .44232 L
s
% Start of user PostScript
4.6303866 -2.6367887 4.9484268 -1.7305231 MAarrowhead1
% End of user PostScript
0 .06 1 r
.56656 .64594 m
.53461 .65992 L
s
% Start of user PostScript
1.9968587 4.3780979 1.0381952 4.7976782 MAarrowhead1
% End of user PostScript
1 0 .738 r
.34511 .2836 m
.39499 .2517 L
.44899 .22954 L
.505 .218 L
.56081 .21752 L
.61423 .22813 L
.66317 .24941 L
.70571 .28052 L
.74017 .32025 L
.7652 .36703 L
.77983 .41903 L
.78348 .47421 L
.776 .5304 L
.75769 .5854 L
.72927 .63704 L
.69184 .68331 L
.64689 .72238 L
.59618 .75273 L
.54169 .77316 L
.48556 .78286 L
.43 .78147 L
.37719 .76903 L
.32919 .74603 L
.28791 .71337 L
.25494 .67234 L
.23159 .62455 L
.21878 .57187 L
.217 .51637 L
.22633 .46023 L
.2464 .40564 L
.27642 .35476 L
.31522 .30958 L
.36127 .27188 L
.41276 .24312 L
.46768 .22445 L
.52387 .21659 L
.57912 .21986 L
.63126 .23412 L
.67825 .25881 L
.71825 .29297 L
.74968 .33525 L
.77131 .384 L
.7823 .43731 L
.7822 .49307 L
.77103 .54911 L
.74923 .60321 L
.71764 .65327 L
.67751 .69731 L
.63041 .73361 L
.5782 .76074 L
Mistroke
.52292 .77764 L
.46673 .78364 L
.41186 .77851 L
.36044 .76245 L
.3145 .73609 L
.27584 .70046 L
.24598 .65696 L
.22608 .60731 L
.21694 .55345 L
.2189 .49748 L
.2319 .44162 L
.25542 .38805 L
.28854 .33887 L
.32996 .29601 L
.37805 .26116 L
.43092 .23569 L
.48651 .22058 L
.54263 .21645 L
.59707 .22344 L
.64771 .24128 L
.69254 .26928 L
.72983 .30634 L
.75809 .35099 L
.77622 .40149 L
.78351 .45586 L
.77968 .51196 L
.76487 .56759 L
.73966 .62057 L
.70505 .66882 L
.66239 .71044 L
.61336 .7438 L
.55988 .7676 L
.50405 .78089 L
.44806 .78316 L
.39411 .77431 L
.34431 .7547 L
.30063 .7251 L
.26477 .68666 L
.23814 .64089 L
.22179 .58959 L
.21635 .53478 L
.22205 .47861 L
.23866 .42327 L
.26553 .37094 L
.30159 .32368 L
.34545 .28334 L
.39536 .25151 L
.44939 .22942 L
.5054 .21795 L
.5612 .21756 L
Mistroke
.6146 .22824 L
.6635 .2496 L
.70598 .28078 L
.74038 .32056 L
.76535 .36739 L
.7799 .41942 L
.78347 .47461 L
.77591 .5308 L
.75752 .58578 L
.72903 .6374 L
.69155 .68362 L
.64655 .72263 L
.5958 .75291 L
.54129 .77326 L
.48516 .78289 L
.42961 .78142 L
.37682 .7689 L
.32887 .74583 L
.28764 .71311 L
.25474 .67202 L
.23146 .62419 L
.21873 .57148 L
.21703 .51597 L
.22644 .45983 L
.24658 .40526 L
.27667 .35442 L
.31553 .30928 L
.36162 .27164 L
.41315 .24295 L
.46808 .22436 L
.52427 .21658 L
.5795 .21992 L
.63162 .23426 L
.67857 .25902 L
.71851 .29325 L
.74987 .33558 L
.77143 .38437 L
.78234 .4377 L
.78216 .49347 L
.77092 .5495 L
.74904 .60359 L
.71738 .65361 L
.6772 .6976 L
.63006 .73384 L
.57781 .7609 L
.52251 .77772 L
.46633 .78364 L
.41147 .77843 L
.36009 .76229 L
.31419 .73586 L
Mistroke
.27559 .70017 L
.2458 .65663 L
.22598 .60694 L
.21691 .55305 L
.21896 .49708 L
.23203 .44122 L
.25563 .38767 L
.28881 .33853 L
.33028 .29573 L
.37841 .26094 L
.43131 .23554 L
.48691 .22051 L
.54303 .21646 L
.59745 .22353 L
.64805 .24145 L
.69284 .26952 L
.73006 .30663 L
.75825 .35133 L
.77631 .40187 L
.78352 .45626 L
.77961 .51236 L
.76472 .56798 L
.73944 .62094 L
.70477 .66914 L
.66206 .71071 L
.61299 .74401 L
.55948 .76773 L
.50364 .78094 L
.44766 .78313 L
.39373 .77421 L
.34397 .75452 L
.30034 .72485 L
.26454 .68635 L
.23798 .64054 L
.22171 .58921 L
.21636 .53438 L
.22213 .4782 L
.23882 .42288 L
.26575 .37059 L
.30188 .32337 L
.34578 .28308 L
.39574 .25131 L
.44979 .2293 L
.5058 .21791 L
.56159 .21759 L
.61497 .22836 L
.66383 .24979 L
.70626 .28103 L
.7406 .32087 L
.76549 .36774 L
Mistroke
.77996 .4198 L
Mfstroke
1 0 0 r
.34511 .2836 m
.39499 .2517 L
s
% Start of user PostScript
-4.6467747 -6.4918771 -3.150311 -7.4489891 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44899 .22954 m
.505 .218 L
s
% Start of user PostScript
-1.5302103 -8.1137583 0.14994496 -8.4600952 MAarrowhead1
% End of user PostScript
1 .473 0 r
.77983 .41903 m
.78348 .47421 L
s
% Start of user PostScript
8.3950108 -2.4290648 8.5044061 -0.77372283 MAarrowhead1
% End of user PostScript
1 .788 0 r
.54169 .77316 m
.48556 .78286 L
s
% Start of user PostScript
1.2505945 8.1946641 -0.43320444 8.4858658 MAarrowhead1
% End of user PostScript
.897 1 0 r
.21878 .57187 m
.217 .51637 L
s
% Start of user PostScript
-8.4366649 2.156122 -8.4899772 0.49108087 MAarrowhead1
% End of user PostScript
.581 1 0 r
.46768 .22445 m
.52387 .21659 L
s
% Start of user PostScript
-0.96959132 -8.2664788 0.71598334 -8.5022224 MAarrowhead1
% End of user PostScript
.266 1 0 r
.7823 .43731 m
.7822 .49307 L
s
% Start of user PostScript
8.4689594 -1.8807873 8.4661296 -0.20789412 MAarrowhead1
% End of user PostScript
0 1 .049 r
.52292 .77764 m
.46673 .78364 L
s
% Start of user PostScript
0.68751247 8.3291229 -0.99796793 8.5091469 MAarrowhead1
% End of user PostScript
0 1 .364 r
.21694 .55345 m
.2189 .49748 L
s
% Start of user PostScript
-8.4918586 1.603366 -8.4328899 -0.075523268 MAarrowhead1
% End of user PostScript
0 1 .679 r
.48651 .22058 m
.54263 .21645 L
s
% Start of user PostScript
-0.40467091 -8.3825269 1.2788454 -8.5066314 MAarrowhead1
% End of user PostScript
0 1 .995 r
.78351 .45586 m
.77968 .51196 L
s
% Start of user PostScript
8.5053372 -1.324166 8.3902949 0.35885687 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50405 .78089 m
.44806 .78316 L
s
% Start of user PostScript
0.12138041 8.4266314 -1.5583041 8.4946788 MAarrowhead1
% End of user PostScript
0 .375 1 r
.21635 .53478 m
.22205 .47861 L
s
% Start of user PostScript
-8.50938 1.043497 -8.3383919 -0.64179236 MAarrowhead1
% End of user PostScript
0 .06 1 r
.5054 .21795 m
.5612 .21756 L
s
% Start of user PostScript
0.16204474 -8.4613875 1.8360341 -8.4733024 MAarrowhead1
% End of user PostScript
1 .773 0 r
.39825 .2915 m
.4442 .2702 L
.49234 .25792 L
.54078 .25513 L
.58762 .26196 L
.63102 .27813 L
.66928 .303 L
.7009 .33561 L
.72463 .37467 L
.73954 .41865 L
.74506 .46582 L
.74095 .51433 L
.72739 .56228 L
.70491 .60779 L
.67438 .64906 L
.63701 .68449 L
.59427 .71267 L
.54782 .73251 L
.4995 .74322 L
.45119 .74439 L
.4048 .73597 L
.36215 .71828 L
.32491 .69203 L
.29454 .65825 L
.27223 .61825 L
.25886 .57361 L
.25496 .52608 L
.26067 .47753 L
.27578 .42986 L
.29968 .38494 L
.33145 .34454 L
.36983 .31024 L
.41332 .28339 L
.46021 .26504 L
.50866 .25591 L
.55678 .25636 L
.60266 .26637 L
.64452 .28555 L
.6807 .31315 L
.7098 .34807 L
.73065 .38897 L
.74246 .43422 L
.74475 .48205 L
.73744 .53058 L
.7208 .57792 L
.6955 .6222 L
.66253 .66168 L
.62318 .69482 L
.579 .72031 L
.53171 .73715 L
Mistroke
.48318 .74469 L
.43531 .74262 L
.38998 .73104 L
.34897 .71038 L
.31388 .68147 L
.2861 .64544 L
.26671 .60369 L
.25648 .55788 L
.25581 .5098 L
.26472 .46133 L
.28286 .41438 L
.30953 .37079 L
.34367 .33228 L
.38394 .30034 L
.42877 .27624 L
.4764 .26092 L
.52495 .25498 L
.57252 .25866 L
.61725 .27182 L
.65738 .29392 L
.69132 .32412 L
.71776 .36121 L
.73566 .40376 L
.7443 .45008 L
.74336 .49836 L
.73287 .5467 L
.71323 .59322 L
.68523 .63607 L
.64996 .67358 L
.60881 .70428 L
.56338 .72697 L
.51546 .74074 L
.46694 .74507 L
.41972 .73978 L
.37565 .72508 L
.33646 .70155 L
.30368 .6701 L
.27861 .63198 L
.26223 .58868 L
.25518 .5419 L
.25774 .49348 L
.26981 .44531 L
.29091 .39929 L
.32021 .35722 L
.35658 .32075 L
.39857 .29132 L
.44454 .27008 L
.49269 .25786 L
.54113 .25515 L
.58795 .26204 L
Mistroke
.63132 .27827 L
.66953 .30321 L
.7011 .33587 L
.72477 .37497 L
.73962 .41898 L
.74506 .46616 L
.74089 .51468 L
.72726 .56262 L
.70472 .6081 L
.67414 .64934 L
.63672 .68472 L
.59394 .71284 L
.54748 .73262 L
.49915 .74327 L
.45085 .74436 L
.40448 .73587 L
.36186 .71812 L
.32467 .69182 L
.29435 .65798 L
.2721 .61794 L
.2588 .57328 L
.25497 .52573 L
.26075 .47718 L
.27592 .42953 L
.29988 .38464 L
.3317 .34427 L
.37012 .31002 L
.41365 .28323 L
.46056 .26494 L
.50901 .25588 L
.55712 .2564 L
.60298 .26647 L
.6448 .28572 L
.68094 .31337 L
.70998 .34835 L
.73077 .38928 L
.74251 .43455 L
.74473 .4824 L
.73735 .53093 L
.72065 .57825 L
.69529 .6225 L
.66227 .66194 L
.62288 .69503 L
.57867 .72046 L
.53137 .73724 L
.48284 .74471 L
.43498 .74257 L
.38967 .73092 L
.34869 .7102 L
.31366 .68124 L
Mistroke
.28593 .64516 L
.26661 .60338 L
.25644 .55755 L
.25584 .50945 L
.26482 .46099 L
.28302 .41406 L
.30975 .3705 L
.34393 .33202 L
.38425 .30014 L
.42911 .2761 L
.47675 .26084 L
.5253 .25498 L
.57286 .25872 L
.61756 .27194 L
.65764 .29411 L
.69154 .32436 L
.71792 .3615 L
.73575 .40408 L
.74433 .45042 L
.74332 .49871 L
.73276 .54705 L
.71306 .59354 L
.685 .63636 L
.64969 .67383 L
.60849 .70448 L
.56304 .7271 L
.51512 .74081 L
.4666 .74507 L
.41939 .73971 L
.37535 .72494 L
.3362 .70135 L
.30347 .66985 L
.27846 .63169 L
.26215 .58836 L
.25517 .54156 L
.25779 .49313 L
.26993 .44497 L
.29109 .39897 L
.32045 .35693 L
.35686 .32051 L
.39889 .29114 L
.44488 .26996 L
.49304 .25781 L
.54147 .25516 L
.58827 .26212 L
.63161 .27842 L
.66978 .30342 L
.7013 .33613 L
.72491 .37527 L
.73969 .4193 L
Mistroke
.74507 .46651 L
Mfstroke
1 0 0 r
.39825 .2915 m
.4442 .2702 L
s
% Start of user PostScript
-3.0524562 -6.2549004 -1.6739596 -6.8940017 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49234 .25792 m
.54078 .25513 L
s
% Start of user PostScript
-0.22976685 -7.2625412 1.2234433 -7.3460552 MAarrowhead1
% End of user PostScript
1 .473 0 r
.74506 .46582 m
.74095 .51433 L
s
% Start of user PostScript
7.3517087 -1.0254703 7.2286081 0.42989526 MAarrowhead1
% End of user PostScript
1 .788 0 r
.4995 .74322 m
.45119 .74439 L
s
% Start of user PostScript
-0.015099309 7.296697 -1.4642093 7.3317366 MAarrowhead1
% End of user PostScript
.897 1 0 r
.25496 .52608 m
.26067 .47753 L
s
% Start of user PostScript
-7.3512058 0.78243642 -7.1798391 -0.6740962 MAarrowhead1
% End of user PostScript
.581 1 0 r
.50866 .25591 m
.55678 .25636 L
s
% Start of user PostScript
0.25994871 -7.3227579 1.7033509 -7.3092842 MAarrowhead1
% End of user PostScript
.266 1 0 r
.74475 .48205 m
.73744 .53058 L
s
% Start of user PostScript
7.3425476 -0.53853455 7.1231049 0.9175493 MAarrowhead1
% End of user PostScript
0 1 .049 r
.48318 .74469 m
.43531 .74262 L
s
% Start of user PostScript
-0.50450974 7.340695 -1.9406029 7.278723 MAarrowhead1
% End of user PostScript
0 1 .364 r
.25581 .5098 m
.26472 .46133 L
s
% Start of user PostScript
-7.3257437 0.29403523 -7.0584685 -1.1599845 MAarrowhead1
% End of user PostScript
0 1 .679 r
.52495 .25498 m
.57252 .25866 L
s
% Start of user PostScript
0.74851106 -7.3504886 2.175702 -7.240087 MAarrowhead1
% End of user PostScript
0 1 .995 r
.74336 .49836 m
.73287 .5467 L
s
% Start of user PostScript
7.3008127 -0.049209713 6.9860016 1.4011328 MAarrowhead1
% End of user PostScript
0 .69 1 r
.46694 .74507 m
.41972 .73978 L
s
% Start of user PostScript
-0.99168201 7.3521276 -2.4083874 7.1934189 MAarrowhead1
% End of user PostScript
0 .375 1 r
.25774 .49348 m
.26981 .44531 L
s
% Start of user PostScript
-7.2677824 -0.19567039 -6.9057845 -1.6407268 MAarrowhead1
% End of user PostScript
0 .06 1 r
.54113 .25515 m
.58795 .26204 L
s
% Start of user PostScript
1.2337528 -7.3456104 2.638401 -7.1387706 MAarrowhead1
% End of user PostScript
1 0 .527 r
.31425 .81783 m
.25936 .78258 L
.21391 .73624 L
.17969 .68063 L
.15804 .61793 L
.14981 .5506 L
.15533 .48129 L
.17437 .4127 L
.20619 .34755 L
.24954 .28838 L
.30273 .23751 L
.36365 .19695 L
.42993 .16828 L
.49895 .15262 L
.56802 .1506 L
.63442 .1623 L
.69554 .18724 L
.74899 .22446 L
.79266 .2725 L
.82485 .32946 L
.84429 .39312 L
.85022 .46097 L
.84241 .53035 L
.82115 .59854 L
.7873 .66287 L
.74216 .7208 L
.68753 .77007 L
.62553 .80873 L
.55861 .83528 L
.48938 .84868 L
.42058 .84838 L
.35489 .83442 L
.29489 .80733 L
.24295 .76818 L
.20109 .71851 L
.17097 .66025 L
.15375 .59571 L
.15013 .52742 L
.16024 .45804 L
.18368 .39032 L
.21954 .3269 L
.2664 .27027 L
.32243 .22266 L
.38543 .18593 L
.45293 .16153 L
.52227 .15041 L
.59074 .15301 L
.65565 .16923 L
.71445 .19843 L
.76483 .23947 L
Mistroke
.80482 .29073 L
.83285 .35021 L
.84781 .41556 L
.84913 .48423 L
.83674 .55351 L
.81114 .6207 L
.77332 .68315 L
.72478 .73841 L
.66742 .78431 L
.60348 .81906 L
.53549 .84128 L
.4661 .85012 L
.39804 .84521 L
.33399 .82675 L
.27645 .79547 L
.22768 .75259 L
.1896 .6998 L
.1637 .63917 L
.151 .57307 L
.152 .50411 L
.16666 .43499 L
.19439 .36842 L
.23412 .30701 L
.28429 .25318 L
.34292 .20903 L
.40772 .1763 L
.47613 .15628 L
.54549 .14975 L
.61306 .15696 L
.67619 .17764 L
.73241 .21096 L
.7795 .25563 L
.81563 .30989 L
.83937 .37162 L
.84979 .43838 L
.84648 .50755 L
.82958 .57644 L
.79974 .64232 L
.75814 .70262 L
.7064 .75496 L
.64657 .7973 L
.58098 .82797 L
.51221 .84577 L
.44297 .85 L
.37596 .84049 L
.31383 .81762 L
.25899 .78229 L
.21362 .73588 L
.17949 .6802 L
.15793 .61746 L
Mistroke
.1498 .55011 L
.15542 .48079 L
.17455 .41222 L
.20646 .3471 L
.24989 .28798 L
.30314 .23718 L
.36411 .1967 L
.43041 .16812 L
.49945 .15256 L
.56851 .15064 L
.63488 .16243 L
.69595 .18747 L
.74934 .22477 L
.79294 .27288 L
.82504 .3299 L
.84439 .39359 L
.85022 .46146 L
.8423 .53085 L
.82095 .59902 L
.78701 .66331 L
.7418 .72119 L
.68711 .77038 L
.62506 .80897 L
.55812 .83543 L
.48889 .84872 L
.42009 .84833 L
.35443 .83427 L
.29449 .80709 L
.24261 .76786 L
.20083 .71812 L
.1708 .65981 L
.15368 .59523 L
.15015 .52692 L
.16036 .45755 L
.18389 .38985 L
.21983 .32646 L
.26677 .26989 L
.32286 .22235 L
.3859 .18571 L
.45342 .1614 L
.52277 .15038 L
.59122 .15308 L
.65609 .1694 L
.71484 .19869 L
.76516 .2398 L
.80507 .29113 L
.833 .35066 L
.84787 .41604 L
.84909 .48472 L
.8366 .55401 L
Mistroke
.81091 .62117 L
.77301 .68357 L
.7244 .73877 L
.66698 .7846 L
.60301 .81927 L
.53499 .8414 L
.46561 .85013 L
.39757 .84512 L
.33355 .82657 L
.27606 .7952 L
.22737 .75224 L
.18937 .69939 L
.16356 .63871 L
.15096 .57259 L
.15206 .50361 L
.16681 .4345 L
.19464 .36796 L
.23445 .3066 L
.28468 .25282 L
.34337 .20875 L
.4082 .17611 L
.47663 .15619 L
.54598 .14975 L
.61353 .15706 L
.67662 .17783 L
.73278 .21124 L
.7798 .25599 L
.81585 .31031 L
.83949 .37208 L
.84982 .43887 L
.84641 .50805 L
.82941 .57692 L
.79948 .64277 L
.7578 .70302 L
.706 .7553 L
.64611 .79756 L
.58049 .82815 L
.51172 .84585 L
.44248 .84998 L
.3755 .84038 L
.3134 .81741 L
.25863 .78199 L
.21333 .73551 L
.17929 .67978 L
.15783 .61699 L
.14979 .54961 L
.15551 .48029 L
.17474 .41174 L
.20673 .34665 L
.25024 .28759 L
Mistroke
.30355 .23685 L
Mfstroke
1 0 0 r
.31425 .81783 m
.25936 .78258 L
s
% Start of user PostScript
-5.5725601 9.5350141 -7.2193211 8.4775103 MAarrowhead1
% End of user PostScript
1 .158 0 r
.21391 .73624 m
.17969 .68063 L
s
% Start of user PostScript
-8.5827527 7.0872984 -9.6093459 5.4189386 MAarrowhead1
% End of user PostScript
1 .473 0 r
.30273 .23751 m
.36365 .19695 L
s
% Start of user PostScript
-5.918225 -7.8746398 -4.0904923 -9.091585 MAarrowhead1
% End of user PostScript
1 .788 0 r
.79266 .2725 m
.82485 .32946 L
s
% Start of user PostScript
8.7798733 -6.8250148 9.7455895 -5.1161217 MAarrowhead1
% End of user PostScript
.897 1 0 r
.68753 .77007 m
.62553 .80873 L
s
% Start of user PostScript
5.6257904 8.1019631 3.7658923 9.2619896 MAarrowhead1
% End of user PostScript
.581 1 0 r
.20109 .71851 m
.17097 .66025 L
s
% Start of user PostScript
-8.9672536 6.5551596 -9.8710215 4.8076291 MAarrowhead1
% End of user PostScript
.266 1 0 r
.32243 .22266 m
.38543 .18593 L
s
% Start of user PostScript
-5.3271147 -8.3202983 -3.4371144 -9.4221192 MAarrowhead1
% End of user PostScript
0 1 .049 r
.80482 .29073 m
.83285 .35021 L
s
% Start of user PostScript
9.1446858 -6.2780323 9.9855028 -4.493803 MAarrowhead1
% End of user PostScript
0 1 .364 r
.66742 .78431 m
.60348 .81906 L
s
% Start of user PostScript
5.0225292 8.5294031 3.1045235 9.571796 MAarrowhead1
% End of user PostScript
0 1 .679 r
.1896 .6998 m
.1637 .63917 L
s
% Start of user PostScript
-9.3119731 5.9939402 -10.088906 4.1749916 MAarrowhead1
% End of user PostScript
0 1 .995 r
.34292 .20903 m
.40772 .1763 L
s
% Start of user PostScript
-4.7123717 -8.7290456 -2.7684885 -9.710854 MAarrowhead1
% End of user PostScript
0 .69 1 r
.81563 .30989 m
.83937 .37162 L
s
% Start of user PostScript
9.4689299 -5.7031986 10.181117 -3.8515485 MAarrowhead1
% End of user PostScript
0 .375 1 r
.64657 .7973 m
.58098 .82797 L
s
% Start of user PostScript
4.3969865 8.9190042 2.4293821 9.839139 MAarrowhead1
% End of user PostScript
0 .06 1 r
.17949 .6802 m
.15793 .61746 L
s
% Start of user PostScript
-9.615382 5.4061299 -10.262034 3.5238326 MAarrowhead1
% End of user PostScript
.159 0 1 r
.70324 .49751 m
.6947 .53788 L
.67852 .57676 L
.65533 .61263 L
.62605 .64408 L
.59181 .66988 L
.55398 .68901 L
.51403 .70072 L
.47352 .70455 L
.43406 .70035 L
.39718 .6883 L
.36434 .66885 L
.33682 .64277 L
.31571 .6111 L
.30183 .57506 L
.29572 .53608 L
.29764 .49568 L
.30749 .45545 L
.32491 .41697 L
.34919 .38174 L
.37939 .35116 L
.41432 .32642 L
.45262 .30849 L
.49278 .29808 L
.53322 .29559 L
.57236 .30113 L
.60865 .31447 L
.64068 .33509 L
.6672 .36218 L
.68715 .39468 L
.69975 .43132 L
.70452 .47065 L
.70125 .51113 L
.6901 .55118 L
.67148 .58921 L
.64613 .62375 L
.61504 .65343 L
.57944 .67709 L
.54072 .69379 L
.50041 .7029 L
.46008 .70403 L
.42131 .69717 L
.38564 .68256 L
.35445 .66079 L
.32897 .63271 L
.31021 .59942 L
.29889 .56223 L
.29547 .52259 L
.30008 .48207 L
.31253 .44226 L
Mistroke
.33233 .40471 L
.35872 .3709 L
.39066 .34215 L
.42688 .3196 L
.46597 .30413 L
.5064 .29635 L
.54658 .29656 L
.58493 .30476 L
.61995 .32061 L
.65026 .34351 L
.67467 .37255 L
.69223 .40659 L
.70224 .4443 L
.70432 .48419 L
.69837 .5247 L
.68465 .56425 L
.66367 .60127 L
.63627 .63432 L
.60353 .66209 L
.56672 .68351 L
.52729 .69772 L
.48679 .70417 L
.44681 .70261 L
.40892 .6931 L
.3746 .67601 L
.3452 .65201 L
.32188 .62205 L
.30555 .5873 L
.29685 .54912 L
.29612 .50901 L
.3034 .46855 L
.31839 .42932 L
.34051 .39287 L
.36888 .36062 L
.40241 .33384 L
.43976 .31358 L
.47948 .30064 L
.52 .29553 L
.55974 .29843 L
.59713 .30925 L
.63071 .32756 L
.65916 .35263 L
.68137 .38348 L
.69646 .41891 L
.70383 .45752 L
.70321 .4978 L
.69461 .53817 L
.67838 .57703 L
.65514 .61288 L
.62582 .64429 L
Mistroke
.59155 .67004 L
.5537 .68912 L
.51374 .70077 L
.47323 .70455 L
.43378 .7003 L
.39693 .68818 L
.36412 .66868 L
.33665 .64257 L
.31558 .61085 L
.30176 .57479 L
.29571 .53579 L
.29768 .49539 L
.30759 .45516 L
.32506 .4167 L
.34939 .38151 L
.37962 .35096 L
.41459 .32627 L
.4529 .30839 L
.49307 .29804 L
.53351 .29561 L
.57263 .3012 L
.6089 .31459 L
.6409 .33526 L
.66736 .3624 L
.68726 .39493 L
.69981 .43159 L
.70452 .47094 L
.7012 .51142 L
.68999 .55146 L
.67132 .58948 L
.64592 .62398 L
.6148 .65362 L
.57917 .67723 L
.54044 .69389 L
.50012 .70293 L
.45979 .70401 L
.42104 .69709 L
.3854 .68243 L
.35424 .66061 L
.32881 .63249 L
.3101 .59916 L
.29884 .56195 L
.29548 .5223 L
.30014 .48178 L
.31264 .44198 L
.3325 .40445 L
.35893 .37067 L
.3909 .34197 L
.42715 .31947 L
.46626 .30405 L
Mistroke
.50669 .29633 L
.54686 .29659 L
.5852 .30484 L
.62018 .32075 L
.65045 .3437 L
.67482 .37278 L
.69233 .40685 L
.70228 .44458 L
.7043 .48448 L
.6983 .52499 L
.68452 .56452 L
.6635 .60152 L
.63606 .63454 L
.60328 .66227 L
.56644 .68364 L
.527 .6978 L
.4865 .70419 L
.44653 .70257 L
.40866 .69301 L
.37437 .67586 L
.34501 .65182 L
.32174 .62182 L
.30546 .58703 L
.29682 .54883 L
.29615 .50872 L
.30348 .46826 L
.31852 .42905 L
.34069 .39262 L
.36911 .36041 L
.40266 .33367 L
.44004 .31346 L
.47977 .30058 L
.52029 .29552 L
.56001 .29848 L
.59739 .30936 L
.63094 .32771 L
.65935 .35283 L
.6815 .38372 L
.69654 .41918 L
.70386 .45781 L
.70318 .49809 L
.69452 .53845 L
.67823 .5773 L
.65495 .61312 L
.62559 .64449 L
.59129 .6702 L
.55342 .68923 L
.51344 .70083 L
.47294 .70455 L
.43351 .70024 L
Mistroke
.39668 .68807 L
Mfstroke
1 0 0 r
.70324 .49751 m
.6947 .53788 L
s
% Start of user PostScript
6.0972891 -0.074684358 5.8410473 1.1363972 MAarrowhead1
% End of user PostScript
1 .158 0 r
.67852 .57676 m
.65533 .61263 L
s
% Start of user PostScript
5.3555679 2.3028797 4.659904 3.3789834 MAarrowhead1
% End of user PostScript
1 .473 0 r
.39718 .6883 m
.36434 .66885 L
s
% Start of user PostScript
-3.0845972 5.6489003 -4.0698388 5.0654707 MAarrowhead1
% End of user PostScript
1 .788 0 r
.32491 .41697 m
.34919 .38174 L
s
% Start of user PostScript
-5.252828 -2.4910297 -4.5243484 -3.547701 MAarrowhead1
% End of user PostScript
.897 1 0 r
.60865 .31447 m
.64068 .33509 L
s
% Start of user PostScript
3.2595551 -5.5659307 4.220533 -4.9473061 MAarrowhead1
% End of user PostScript
.581 1 0 r
.67148 .58921 m
.64613 .62375 L
s
% Start of user PostScript
5.1442608 2.6764163 4.3837735 3.7124828 MAarrowhead1
% End of user PostScript
.266 1 0 r
.38564 .68256 m
.35445 .66079 L
s
% Start of user PostScript
-3.430897 5.4767863 -4.366545 4.823653 MAarrowhead1
% End of user PostScript
0 1 .049 r
.33233 .40471 m
.35872 .3709 L
s
% Start of user PostScript
-5.0299866 -2.8588337 -4.2383353 -3.873146 MAarrowhead1
% End of user PostScript
0 1 .364 r
.61995 .32061 m
.65026 .34351 L
s
% Start of user PostScript
3.5984326 -5.381566 4.5077128 -4.6946487 MAarrowhead1
% End of user PostScript
0 1 .679 r
.66367 .60127 m
.63627 .63432 L
s
% Start of user PostScript
4.9101322 3.0380796 4.0881952 4.0295125 MAarrowhead1
% End of user PostScript
0 1 .995 r
.3746 .67601 m
.3452 .65201 L
s
% Start of user PostScript
-3.7619763 5.2803755 -4.6438799 4.5604362 MAarrowhead1
% End of user PostScript
0 .69 1 r
.34051 .39287 m
.36888 .36062 L
s
% Start of user PostScript
-4.7848307 -3.213955 -3.9335197 -4.1814087 MAarrowhead1
% End of user PostScript
0 .375 1 r
.63071 .32756 m
.65916 .35263 L
s
% Start of user PostScript
3.9213464 -5.1733271 4.7748951 -4.4211644 MAarrowhead1
% End of user PostScript
0 .06 1 r
.65514 .61288 m
.62582 .64429 L
s
% Start of user PostScript
4.6542209 3.386265 3.7744805 4.3286661 MAarrowhead1
% End of user PostScript
.852 1 0 r
.52222 .27626 m
.56569 .27951 L
.60658 .29141 L
.64328 .3115 L
.67437 .33899 L
.69861 .37279 L
.71505 .41159 L
.72306 .45386 L
.72231 .49794 L
.71283 .5421 L
.69501 .5846 L
.66953 .62379 L
.63739 .65812 L
.59987 .68624 L
.55842 .70706 L
.51469 .71974 L
.47037 .72381 L
.42722 .71909 L
.38693 .70577 L
.35107 .68437 L
.32106 .65574 L
.29807 .621 L
.283 .58151 L
.27646 .53882 L
.27868 .49461 L
.28959 .45061 L
.30876 .40854 L
.33543 .37007 L
.36857 .33669 L
.40686 .30973 L
.4488 .29023 L
.49276 .27896 L
.537 .27637 L
.57979 .28256 L
.61944 .29728 L
.65441 .31995 L
.68332 .34969 L
.70503 .38533 L
.7187 .42548 L
.72379 .46854 L
.72009 .51284 L
.70775 .55664 L
.68726 .59821 L
.65942 .63593 L
.62533 .66831 L
.58631 .69409 L
.54391 .71225 L
.49979 .72208 L
.45567 .7232 L
.41329 .71556 L
Mistroke
.37432 .69945 L
.34028 .67552 L
.31251 .6447 L
.29209 .6082 L
.27984 .56746 L
.27622 .52406 L
.28139 .47973 L
.29514 .43618 L
.31692 .39515 L
.3459 .35822 L
.38092 .32687 L
.42061 .3023 L
.46342 .2855 L
.50767 .27711 L
.55161 .27748 L
.59353 .28657 L
.63178 .30404 L
.66485 .3292 L
.69146 .36107 L
.71055 .39838 L
.72138 .43969 L
.72352 .48336 L
.71689 .52769 L
.70175 .57093 L
.67869 .61138 L
.64861 .64746 L
.6127 .67776 L
.57237 .70108 L
.5292 .71651 L
.48489 .72344 L
.44116 .7216 L
.39975 .71107 L
.36227 .69225 L
.3302 .66589 L
.30478 .63301 L
.28704 .59492 L
.27764 .5531 L
.27698 .5092 L
.28507 .46493 L
.30159 .42204 L
.3259 .38222 L
.35704 .34701 L
.3938 .31781 L
.43472 .29576 L
.4782 .28172 L
.52254 .27625 L
.56599 .27957 L
.60686 .29153 L
.64353 .31167 L
.67457 .33921 L
Mistroke
.69875 .37306 L
.71514 .41188 L
.72308 .45417 L
.72227 .49826 L
.71273 .54241 L
.69485 .5849 L
.66932 .62406 L
.63714 .65834 L
.59958 .68642 L
.55812 .70718 L
.51437 .7198 L
.47006 .7238 L
.42692 .71902 L
.38665 .70564 L
.35083 .68419 L
.32087 .65552 L
.29793 .62073 L
.28293 .58122 L
.27644 .53851 L
.27873 .49429 L
.2897 .4503 L
.30893 .40825 L
.33565 .36981 L
.36882 .33648 L
.40715 .30956 L
.44911 .29012 L
.49308 .27891 L
.53731 .27639 L
.58008 .28263 L
.61971 .29741 L
.65464 .32014 L
.6835 .34993 L
.70516 .38561 L
.71877 .42578 L
.72379 .46886 L
.72003 .51316 L
.70763 .55694 L
.68709 .5985 L
.6592 .63618 L
.62506 .66852 L
.58602 .69425 L
.5436 .71235 L
.49947 .72212 L
.45536 .72318 L
.413 .71547 L
.37406 .69931 L
.34006 .67532 L
.31233 .64446 L
.29197 .60792 L
.27978 .56715 L
Mistroke
.27623 .52375 L
.28146 .47941 L
.29527 .43588 L
.31711 .39487 L
.34613 .35798 L
.38119 .32667 L
.42091 .30216 L
.46374 .28541 L
.50799 .27709 L
.55192 .27751 L
.59382 .28667 L
.63204 .30419 L
.66507 .32941 L
.69163 .36132 L
.71066 .39867 L
.72143 .44 L
.72351 .48368 L
.71681 .528 L
.70161 .57123 L
.67849 .61166 L
.64837 .6477 L
.61243 .67795 L
.57207 .70122 L
.52889 .71659 L
.48457 .72346 L
.44086 .72156 L
.39947 .71096 L
.36202 .69209 L
.32999 .66567 L
.30463 .63276 L
.28694 .59463 L
.27761 .55279 L
.27701 .50888 L
.28516 .46462 L
.30174 .42175 L
.3261 .38195 L
.35729 .34678 L
.39408 .31762 L
.43502 .29563 L
.47852 .28165 L
.52286 .27625 L
.5663 .27962 L
.60714 .29164 L
.64377 .31185 L
.67477 .33943 L
.6989 .37332 L
.71523 .41218 L
.72311 .45448 L
.72223 .49857 L
.71263 .54272 L
Mistroke
.69469 .58519 L
Mfstroke
1 0 0 r
.52222 .27626 m
.56569 .27951 L
s
% Start of user PostScript
0.66670916 -6.7121544 1.9707063 -6.6146782 MAarrowhead1
% End of user PostScript
1 .158 0 r
.60658 .29141 m
.64328 .3115 L
s
% Start of user PostScript
3.1973611 -6.2576025 4.2985324 -5.6549412 MAarrowhead1
% End of user PostScript
1 .473 0 r
.69501 .5846 m
.66953 .62379 L
s
% Start of user PostScript
5.8501742 2.5381279 5.085779 3.7137314 MAarrowhead1
% End of user PostScript
1 .788 0 r
.38693 .70577 m
.35107 .68437 L
s
% Start of user PostScript
-3.3922151 6.1730641 -4.4679264 5.5312465 MAarrowhead1
% End of user PostScript
.897 1 0 r
.30876 .40854 m
.33543 .37007 L
s
% Start of user PostScript
-5.7371884 -2.7437364 -4.9369641 -3.8979627 MAarrowhead1
% End of user PostScript
.581 1 0 r
.61944 .29728 m
.65441 .31995 L
s
% Start of user PostScript
3.5833058 -6.0816774 4.6323637 -5.4014156 MAarrowhead1
% End of user PostScript
.266 1 0 r
.68726 .59821 m
.65942 .63593 L
s
% Start of user PostScript
5.6178379 2.9463012 4.7826722 4.0778697 MAarrowhead1
% End of user PostScript
0 1 .049 r
.37432 .69945 m
.34028 .67552 L
s
% Start of user PostScript
-3.7704213 5.9835439 -4.791662 5.2655924 MAarrowhead1
% End of user PostScript
0 1 .364 r
.31692 .39515 m
.3459 .35822 L
s
% Start of user PostScript
-5.492255 -3.1455974 -4.6230745 -4.2532528 MAarrowhead1
% End of user PostScript
0 1 .679 r
.63178 .30404 m
.66485 .3292 L
s
% Start of user PostScript
3.9533539 -5.8787723 4.9456445 -5.1239277 MAarrowhead1
% End of user PostScript
0 1 .995 r
.67869 .61138 m
.64861 .64746 L
s
% Start of user PostScript
5.3605791 3.3414039 4.458348 4.4239174 MAarrowhead1
% End of user PostScript
0 .69 1 r
.36227 .69225 m
.3302 .66589 L
s
% Start of user PostScript
-4.1319007 5.7674789 -5.0941404 4.9765786 MAarrowhead1
% End of user PostScript
0 .375 1 r
.3259 .38222 m
.35704 .34701 L
s
% Start of user PostScript
-5.2229564 -3.5335035 -4.2886756 -4.5896742 MAarrowhead1
% End of user PostScript
0 .06 1 r
.64353 .31167 m
.67457 .33921 L
s
% Start of user PostScript
4.3058637 -5.6497871 5.2369849 -4.8237086 MAarrowhead1
% End of user PostScript
1 .894 0 r
.75054 .17654 m
.80367 .22463 L
.84488 .28353 L
.87256 .35093 L
.88561 .42417 L
.88354 .50039 L
.86641 .5766 L
.8349 .6498 L
.79024 .71712 L
.7342 .77592 L
.66896 .82389 L
.5971 .85915 L
.52142 .88032 L
.4449 .88656 L
.37055 .87762 L
.30127 .85387 L
.2398 .81623 L
.18853 .76618 L
.14949 .70568 L
.12421 .63711 L
.11367 .56316 L
.1183 .48673 L
.13791 .41082 L
.17172 .33841 L
.21842 .27234 L
.27618 .21521 L
.34271 .16926 L
.41542 .13628 L
.49145 .11758 L
.56781 .11389 L
.64151 .12535 L
.70966 .15151 L
.76958 .19135 L
.81892 .24331 L
.85575 .30533 L
.87861 .375 L
.88661 .44958 L
.87944 .52613 L
.85738 .60166 L
.82129 .67319 L
.7726 .73794 L
.7132 .79334 L
.64544 .83723 L
.57197 .86788 L
.49567 .8841 L
.41955 .88524 L
.34658 .87127 L
.27964 .84272 L
.22134 .80072 L
.17398 .74692 L
Mistroke
.13941 .68343 L
.11899 .61274 L
.11353 .53763 L
.12324 .46104 L
.14773 .38598 L
.18605 .31539 L
.23669 .25205 L
.29766 .19844 L
.36657 .15666 L
.44072 .12836 L
.5172 .11465 L
.593 .11605 L
.66515 .13253 L
.73082 .16343 L
.78743 .20754 L
.83276 .26312 L
.86503 .328 L
.88298 .39963 L
.88589 .47521 L
.87366 .55175 L
.84677 .62626 L
.80626 .69582 L
.75374 .75769 L
.69126 .80945 L
.62127 .84907 L
.54652 .87498 L
.46995 .88618 L
.39456 .88222 L
.3233 .86326 L
.25898 .83005 L
.20412 .78388 L
.16087 .72657 L
.13093 .66037 L
.11547 .58788 L
.11511 .51193 L
.12985 .43552 L
.15912 .36164 L
.20176 .29319 L
.25611 .23285 L
.32004 .183 L
.39102 .14559 L
.46628 .12209 L
.54287 .11342 L
.61777 .11992 L
.68805 .14134 L
.75096 .17684 L
.80401 .22502 L
.84513 .28399 L
.8727 .35143 L
.88565 .42471 L
Mistroke
.88347 .50094 L
.86623 .57714 L
.83462 .65031 L
.78988 .71758 L
.73376 .77631 L
.66847 .82419 L
.59656 .85936 L
.52087 .88042 L
.44436 .88655 L
.37003 .87751 L
.3008 .85365 L
.23939 .81591 L
.18821 .76578 L
.14926 .70522 L
.12408 .6366 L
.11365 .56262 L
.11839 .48618 L
.1381 .41029 L
.17201 .33791 L
.2188 .2719 L
.27662 .21484 L
.34321 .16897 L
.41596 .13609 L
.492 .1175 L
.56835 .11391 L
.64203 .12548 L
.71012 .15175 L
.76998 .19168 L
.81923 .24372 L
.85596 .30581 L
.87872 .37552 L
.88661 .45012 L
.87934 .52668 L
.85717 .60219 L
.82099 .67369 L
.77221 .73837 L
.71274 .7937 L
.64493 .8375 L
.57143 .86805 L
.49512 .88416 L
.41901 .8852 L
.34608 .87111 L
.27918 .84247 L
.22096 .80038 L
.17368 .7465 L
.13921 .68295 L
.1189 .61222 L
.11355 .53708 L
.12336 .46049 L
.14796 .38545 L
Mistroke
.18637 .31491 L
.23709 .25163 L
.29813 .19809 L
.36709 .15641 L
.44126 .12821 L
.51775 .1146 L
.59353 .11612 L
.66565 .1327 L
.73126 .1637 L
.7878 .2079 L
.83304 .26356 L
.86522 .32849 L
.88305 .40017 L
.88586 .47575 L
.87352 .55229 L
.84653 .62678 L
.80593 .69629 L
.75333 .7581 L
.69078 .80978 L
.62075 .8493 L
.54598 .87512 L
.4694 .88621 L
.39403 .88214 L
.32281 .86308 L
.25855 .82976 L
.20376 .78351 L
.1606 .72613 L
.13076 .65987 L
.11541 .58734 L
.11516 .51138 L
.13001 .43498 L
.15938 .36112 L
.20211 .29272 L
.25654 .23245 L
.32052 .18269 L
.39155 .14537 L
.46683 .12198 L
.54342 .11341 L
.6183 .12003 L
.68853 .14155 L
.75137 .17714 L
.80435 .2254 L
.84538 .28444 L
.87285 .35194 L
.88569 .42525 L
.88339 .50149 L
.86605 .57768 L
.83434 .65081 L
.78951 .71803 L
.73332 .77669 L
Mistroke
.66797 .82449 L
Mfstroke
1 0 0 r
.75054 .17654 m
.80367 .22463 L
s
% Start of user PostScript
7.5161065 -9.7038856 9.1100119 -8.2610988 MAarrowhead1
% End of user PostScript
1 .158 0 r
.84488 .28353 m
.87256 .35093 L
s
% Start of user PostScript
10.346386 -6.4940972 11.176706 -4.4722284 MAarrowhead1
% End of user PostScript
1 .473 0 r
.66896 .82389 m
.5971 .85915 L
s
% Start of user PostScript
5.0688801 9.7168155 2.9128867 10.774608 MAarrowhead1
% End of user PostScript
1 .788 0 r
.14949 .70568 m
.12421 .63711 L
s
% Start of user PostScript
-10.515217 6.1704555 -11.273727 4.1133544 MAarrowhead1
% End of user PostScript
.897 1 0 r
.34271 .16926 m
.41542 .13628 L
s
% Start of user PostScript
-4.7186458 -9.9223372 -2.5373884 -10.911613 MAarrowhead1
% End of user PostScript
.581 1 0 r
.85575 .30533 m
.87861 .375 L
s
% Start of user PostScript
10.672383 -5.8399685 11.358241 -3.7499172 MAarrowhead1
% End of user PostScript
.266 1 0 r
.64544 .83723 m
.57197 .86788 L
s
% Start of user PostScript
4.3631767 10.116851 2.1590751 11.036513 MAarrowhead1
% End of user PostScript
0 1 .049 r
.13941 .68343 m
.11899 .61274 L
s
% Start of user PostScript
-10.817709 5.5030026 -11.430154 3.3823199 MAarrowhead1
% End of user PostScript
0 1 .364 r
.36657 .15666 m
.44072 .12836 L
s
% Start of user PostScript
-4.0028671 -10.300142 -1.7783667 -11.149169 MAarrowhead1
% End of user PostScript
0 1 .679 r
.86503 .328 m
.88298 .39963 L
s
% Start of user PostScript
10.951034 -5.1599319 11.489386 -3.0109702 MAarrowhead1
% End of user PostScript
0 1 .995 r
.62127 .84907 m
.54652 .87498 L
s
% Start of user PostScript
3.6381169 10.472006 1.3956853 11.249457 MAarrowhead1
% End of user PostScript
0 .69 1 r
.13093 .66037 m
.11547 .58788 L
s
% Start of user PostScript
-11.07221 4.8111368 -11.535873 2.6362803 MAarrowhead1
% End of user PostScript
0 .375 1 r
.39102 .14559 m
.46628 .12209 L
s
% Start of user PostScript
-3.2693306 -10.632252 -1.0114556 -11.337264 MAarrowhead1
% End of user PostScript
0 .06 1 r
.8727 .35143 m
.88565 .42471 L
s
% Start of user PostScript
11.181103 -4.4570044 11.569562 -2.2586657 MAarrowhead1
% End of user PostScript
1 0 .522 r
.20181 .77854 m
.15973 .72075 L
.131 .65429 L
.11674 .58178 L
.11753 .50606 L
.13334 .4301 L
.16353 .35688 L
.20692 .28928 L
.26182 .22995 L
.32607 .18122 L
.39714 .145 L
.47225 .12271 L
.54845 .11523 L
.62274 .12285 L
.69222 .14527 L
.75416 .18161 L
.80612 .23045 L
.84607 .28987 L
.87243 .35753 L
.88418 .43079 L
.88085 .50676 L
.86258 .58247 L
.83007 .65494 L
.78461 .72133 L
.72798 .77903 L
.66241 .82578 L
.59046 .85975 L
.51496 .8796 L
.43887 .88455 L
.36518 .87441 L
.29678 .84957 L
.23636 .81102 L
.18629 .76026 L
.14853 .69928 L
.12456 .63049 L
.11532 .55657 L
.12118 .48043 L
.14191 .40506 L
.1767 .33342 L
.22417 .26832 L
.28247 .2123 L
.3493 .16758 L
.42205 .1359 L
.49786 .11852 L
.57375 .1161 L
.64675 .12876 L
.71398 .15598 L
.77282 .1967 L
.82096 .24933 L
.85649 .31179 L
Mistroke
.87804 .38164 L
.88475 .45614 L
.87636 .53235 L
.8532 .6073 L
.81618 .67804 L
.76674 .74179 L
.70684 .79605 L
.63883 .83869 L
.56536 .86804 L
.48933 .88294 L
.41372 .88282 L
.34149 .86767 L
.27549 .83809 L
.21829 .79525 L
.17215 .74081 L
.13888 .67693 L
.11978 .6061 L
.11561 .53111 L
.12651 .4549 L
.15208 .38045 L
.1913 .3107 L
.24264 .24838 L
.30408 .19593 L
.3732 .15542 L
.4473 .12843 L
.52347 .11602 L
.59872 .11868 L
.6701 .13631 L
.7348 .16821 L
.79028 .21313 L
.83437 .26931 L
.86534 .33455 L
.88197 .40628 L
.88361 .48168 L
.8702 .55781 L
.84225 .63166 L
.80088 .70035 L
.74769 .76118 L
.68479 .81175 L
.61463 .85009 L
.53997 .87469 L
.46375 .88459 L
.38895 .87939 L
.3185 .8593 L
.25518 .82512 L
.20147 .77817 L
.15947 .7203 L
.13084 .65379 L
.1167 .58124 L
.1176 .50551 L
Mistroke
.1335 .42956 L
.16379 .35637 L
.20728 .28882 L
.26225 .22956 L
.32655 .18091 L
.39767 .14479 L
.47279 .1226 L
.54899 .11523 L
.62326 .12296 L
.6927 .14548 L
.75457 .18192 L
.80645 .23084 L
.8463 .29033 L
.87257 .35804 L
.88421 .43133 L
.88077 .50731 L
.86239 .583 L
.82979 .65544 L
.78424 .72177 L
.72754 .77941 L
.66191 .82607 L
.58993 .85994 L
.51441 .87969 L
.43833 .88453 L
.36467 .87428 L
.29632 .84934 L
.23596 .81069 L
.18597 .75985 L
.1483 .69881 L
.12444 .62997 L
.11531 .55603 L
.12128 .47989 L
.14211 .40453 L
.17699 .33293 L
.22455 .26788 L
.28292 .21194 L
.3498 .16731 L
.42258 .13573 L
.4984 .11845 L
.57428 .11614 L
.64725 .1289 L
.71444 .15622 L
.77321 .19704 L
.82126 .24974 L
.8567 .31227 L
.87814 .38216 L
.88474 .45668 L
.87625 .5329 L
.85298 .60783 L
.81586 .67852 L
Mistroke
.76635 .74221 L
.70638 .7964 L
.63832 .83895 L
.56482 .8682 L
.48878 .883 L
.41318 .88276 L
.34099 .86751 L
.27504 .83783 L
.21792 .7949 L
.17187 .74039 L
.13869 .67644 L
.1197 .60557 L
.11563 .53056 L
.12665 .45435 L
.15232 .37993 L
.19163 .31022 L
.24305 .24797 L
.30455 .1956 L
.37372 .15518 L
.44785 .12829 L
.52402 .11599 L
.59925 .11876 L
.67059 .13649 L
.73523 .16849 L
.79064 .2135 L
.83464 .26975 L
.86551 .33504 L
.88204 .40681 L
.88357 .48223 L
.87005 .55835 L
.842 .63218 L
.80054 .70082 L
.74727 .76158 L
.68431 .81207 L
.61411 .85032 L
.53943 .87482 L
.4632 .88461 L
.38842 .8793 L
.31802 .85911 L
.25476 .82482 L
.20112 .77779 L
.15922 .71985 L
.13069 .65329 L
.11665 .58071 L
.11766 .50496 L
.13367 .42902 L
.16406 .35586 L
.20763 .28836 L
.26268 .22917 L
.32704 .18061 L
Mistroke
.39819 .14458 L
Mfstroke
1 0 0 r
.20181 .77854 m
.15973 .72075 L
s
% Start of user PostScript
-8.9455567 8.3563477 -10.208167 6.6225182 MAarrowhead1
% End of user PostScript
1 .158 0 r
.131 .65429 m
.11674 .58178 L
s
% Start of user PostScript
-11.070149 4.6287816 -11.497671 2.453384 MAarrowhead1
% End of user PostScript
1 .473 0 r
.39714 .145 m
.47225 .12271 L
s
% Start of user PostScript
-3.0858533 -10.650109 -0.83258751 -11.31876 MAarrowhead1
% End of user PostScript
1 .788 0 r
.87243 .35753 m
.88418 .43079 L
s
% Start of user PostScript
11.17293 -4.2740544 11.525403 -2.0763857 MAarrowhead1
% End of user PostScript
.897 1 0 r
.59046 .85975 m
.51496 .8796 L
s
% Start of user PostScript
2.7137123 10.792467 0.44870654 11.387919 MAarrowhead1
% End of user PostScript
.581 1 0 r
.12456 .63049 m
.11532 .55657 L
s
% Start of user PostScript
-11.263317 3.9145856 -11.540348 1.697084 MAarrowhead1
% End of user PostScript
.266 1 0 r
.42205 .1359 m
.49786 .11852 L
s
% Start of user PostScript
-2.3385607 -10.922851 -0.064327796 -11.444444 MAarrowhead1
% End of user PostScript
0 1 .049 r
.87804 .38164 m
.88475 .45614 L
s
% Start of user PostScript
11.341208 -3.550774 11.54249 -1.3158996 MAarrowhead1
% End of user PostScript
0 1 .364 r
.56536 .86804 m
.48933 .88294 L
s
% Start of user PostScript
1.9608147 11.041118 -0.32012232 11.488273 MAarrowhead1
% End of user PostScript
0 1 .679 r
.11978 .6061 m
.11561 .53111 L
s
% Start of user PostScript
-11.406518 3.1830233 -11.531828 0.93325529 MAarrowhead1
% End of user PostScript
0 1 .995 r
.4473 .12843 m
.52347 .11602 L
s
% Start of user PostScript
-1.5808935 -11.147137 0.70421729 -11.519358 MAarrowhead1
% End of user PostScript
0 .69 1 r
.88197 .40628 m
.88361 .48168 L
s
% Start of user PostScript
11.459173 -2.8117414 11.508372 -0.54957567 MAarrowhead1
% End of user PostScript
0 .375 1 r
.53997 .87469 m
.46375 .88459 L
s
% Start of user PostScript
1.1992185 11.240788 -1.087531 11.537662 MAarrowhead1
% End of user PostScript
0 .06 1 r
.1167 .58124 m
.1176 .50551 L
s
% Start of user PostScript
-11.499116 2.4373402 -11.47215 0.16528637 MAarrowhead1
% End of user PostScript
1 0 .405 r
.18824 .27124 m
.24756 .2081 L
.31678 .15642 L
.39319 .11822 L
.47379 .09501 L
.55542 .08769 L
.63488 .09656 L
.70905 .12125 L
.77501 .16081 L
.83017 .21369 L
.87238 .27779 L
.89997 .35062 L
.91187 .42932 L
.9076 .51078 L
.88734 .59183 L
.85187 .66927 L
.8026 .74006 L
.74145 .80144 L
.67082 .85098 L
.59349 .88675 L
.51249 .90734 L
.431 .91195 L
.35222 .90039 L
.27923 .87311 L
.21492 .83119 L
.16179 .77627 L
.12193 .71051 L
.09691 .63649 L
.08771 .55712 L
.09469 .4755 L
.11758 .39484 L
.15548 .31831 L
.2069 .24891 L
.26982 .18936 L
.34177 .14201 L
.41994 .1087 L
.50124 .09075 L
.5825 .08887 L
.66052 .10312 L
.73224 .13294 L
.79485 .17717 L
.84588 .23407 L
.88334 .30141 L
.90576 .37654 L
.91225 .45652 L
.90256 .5382 L
.87707 .61838 L
.83679 .69392 L
.78328 .76185 L
.71866 .8195 L
Mistroke
.64546 .86461 L
.56655 .89541 L
.48503 .91069 L
.40409 .90986 L
.32692 .89294 L
.25654 .8606 L
.19572 .81411 L
.14684 .75529 L
.11182 .68645 L
.09203 .61029 L
.08825 .52981 L
.10064 .44815 L
.12869 .36853 L
.17132 .29407 L
.22685 .22769 L
.2931 .172 L
.36747 .12918 L
.44704 .10092 L
.52869 .08831 L
.60921 .09187 L
.68545 .11144 L
.75441 .14626 L
.81338 .19496 L
.86005 .25564 L
.8926 .3259 L
.90974 .403 L
.91079 .48391 L
.89573 .56544 L
.86513 .64441 L
.8202 .71771 L
.76271 .78247 L
.69491 .83614 L
.61945 .87662 L
.53931 .90231 L
.45763 .91222 L
.37761 .90595 L
.30239 .88375 L
.23493 .84649 L
.17787 .79563 L
.13345 .73317 L
.10342 .66155 L
.08895 .5836 L
.09062 .50236 L
.10835 .42104 L
.14145 .34281 L
.18863 .27075 L
.24802 .20769 L
.3173 .1561 L
.39376 .118 L
.47438 .0949 L
Mistroke
.55601 .0877 L
.63544 .09668 L
.70955 .12148 L
.77544 .16115 L
.83052 .21411 L
.87263 .27829 L
.90012 .35117 L
.9119 .42989 L
.90752 .51137 L
.88714 .5924 L
.85157 .6698 L
.8022 .74054 L
.74097 .80184 L
.67029 .85129 L
.59292 .88695 L
.5119 .90743 L
.43042 .91192 L
.35167 .90025 L
.27874 .87286 L
.21449 .83084 L
.16145 .77584 L
.1217 .71001 L
.09679 .63594 L
.08771 .55653 L
.0948 .47491 L
.1178 .39427 L
.1558 .31778 L
.20731 .24844 L
.2703 .18898 L
.34231 .14172 L
.42051 .10852 L
.50183 .09068 L
.58308 .08891 L
.66106 .10328 L
.73273 .13321 L
.79526 .17754 L
.8462 .23452 L
.88356 .30192 L
.90586 .3771 L
.91223 .4571 L
.90243 .53878 L
.87683 .61894 L
.83645 .69444 L
.78286 .7623 L
.71816 .81987 L
.64491 .86488 L
.56597 .89558 L
.48444 .91075 L
.40352 .9098 L
.32639 .89276 L
Mistroke
.25607 .86031 L
.19532 .81373 L
.14653 .75483 L
.11162 .68592 L
.09194 .60973 L
.08828 .52922 L
.10078 .44757 L
.12895 .36798 L
.17168 .29356 L
.22729 .22725 L
.29361 .17165 L
.36803 .12893 L
.44762 .10077 L
.52927 .08828 L
.60978 .09195 L
.68597 .11164 L
.75487 .14656 L
.81376 .19536 L
.86034 .25611 L
.89278 .32644 L
.9098 .40357 L
.91074 .48449 L
.89556 .56602 L
.86486 .64496 L
.81983 .71821 L
.76226 .78289 L
.69439 .83648 L
.61889 .87685 L
.53873 .90244 L
.45705 .91224 L
.37705 .90585 L
.30188 .88354 L
.23448 .84617 L
.1775 .79522 L
.13319 .73268 L
.10326 .66101 L
.08891 .58302 L
.09069 .50178 L
.10853 .42046 L
.14174 .34227 L
.18901 .27026 L
.24848 .20727 L
.31783 .15577 L
.39432 .11778 L
.47496 .09479 L
.55659 .08771 L
.63599 .0968 L
.71006 .12172 L
.77588 .16148 L
.83087 .21453 L
Mistroke
.87288 .27878 L
Mfstroke
1 0 0 r
.18824 .27124 m
.24756 .2081 L
s
% Start of user PostScript
-9.3527455 -6.8629306 -7.5733333 -8.7570067 MAarrowhead1
% End of user PostScript
1 .158 0 r
.31678 .15642 m
.39319 .11822 L
s
% Start of user PostScript
-5.4966982 -10.307406 -3.2043399 -11.45328 MAarrowhead1
% End of user PostScript
1 .473 0 r
.87238 .27779 m
.89997 .35062 L
s
% Start of user PostScript
11.171411 -6.6661574 11.999238 -4.4812614 MAarrowhead1
% End of user PostScript
1 .788 0 r
.67082 .85098 m
.59349 .88675 L
s
% Start of user PostScript
5.1246078 10.529438 2.8046767 11.602539 MAarrowhead1
% End of user PostScript
.897 1 0 r
.12193 .71051 m
.09691 .63649 L
s
% Start of user PostScript
-11.342098 6.3154494 -12.092654 4.0948112 MAarrowhead1
% End of user PostScript
.581 1 0 r
.34177 .14201 m
.41994 .1087 L
s
% Start of user PostScript
-4.7468322 -10.739789 -2.4019021 -11.738927 MAarrowhead1
% End of user PostScript
.266 1 0 r
.88334 .30141 m
.90576 .37654 L
s
% Start of user PostScript
11.500203 -5.9577351 12.172655 -3.7038183 MAarrowhead1
% End of user PostScript
0 1 .049 r
.64546 .86461 m
.56655 .89541 L
s
% Start of user PostScript
4.3637906 10.938225 1.9964629 11.862291 MAarrowhead1
% End of user PostScript
0 1 .364 r
.11182 .68645 m
.09203 .61029 L
s
% Start of user PostScript
-11.645549 5.5934115 -12.239152 3.3087164 MAarrowhead1
% End of user PostScript
0 1 .679 r
.36747 .12918 m
.44704 .10092 L
s
% Start of user PostScript
-3.9759079 -11.124527 -1.5888088 -11.972496 MAarrowhead1
% End of user PostScript
0 1 .995 r
.8926 .3259 m
.90974 .403 L
s
% Start of user PostScript
11.777976 -5.2228826 12.292071 -2.909944 MAarrowhead1
% End of user PostScript
0 .69 1 r
.61945 .87662 m
.53931 .90231 L
s
% Start of user PostScript
3.5836144 11.298488 1.1793921 12.069419 MAarrowhead1
% End of user PostScript
0 .375 1 r
.10342 .66155 m
.08895 .5836 L
s
% Start of user PostScript
-11.897337 4.8465596 -12.331354 2.5079432 MAarrowhead1
% End of user PostScript
0 .06 1 r
.39376 .118 m
.47438 .0949 L
s
% Start of user PostScript
-3.1873453 -11.459914 -0.76866704 -12.152952 MAarrowhead1
% End of user PostScript
0 1 .174 r
.33216 .63458 m
.31289 .60193 L
.30095 .56529 L
.29683 .52608 L
.30068 .48585 L
.31235 .44617 L
.33139 .40861 L
.35705 .37463 L
.38831 .34557 L
.42396 .32258 L
.46259 .30654 L
.50269 .2981 L
.54269 .29759 L
.58101 .30501 L
.61615 .32009 L
.64673 .34223 L
.67156 .37056 L
.68965 .40397 L
.70029 .44116 L
.70308 .48064 L
.6979 .52089 L
.68495 .56032 L
.66474 .59739 L
.63807 .63062 L
.60597 .65874 L
.56972 .68062 L
.53074 .69542 L
.49054 .70254 L
.45072 .70172 L
.41283 .69298 L
.37836 .67666 L
.34867 .65342 L
.32491 .62415 L
.30803 .59001 L
.29868 .55234 L
.29723 .51261 L
.30374 .47239 L
.31796 .43325 L
.33931 .39673 L
.36697 .36427 L
.39986 .33713 L
.43667 .31638 L
.47597 .30284 L
.51621 .29704 L
.55582 .2992 L
.59323 .30924 L
.62699 .32677 L
.65576 .3511 L
.67842 .38128 L
.69408 .41611 L
Mistroke
.70212 .45423 L
.70223 .49415 L
.6944 .5343 L
.67894 .5731 L
.65646 .60904 L
.62784 .64069 L
.5942 .66683 L
.55686 .68641 L
.5173 .69868 L
.47705 .70316 L
.43771 .69966 L
.40081 .68832 L
.3678 .66959 L
.33998 .64421 L
.31844 .61317 L
.30403 .57768 L
.29731 .53915 L
.29854 .49908 L
.30768 .45905 L
.32436 .42062 L
.34794 .38531 L
.37749 .3545 L
.41185 .3294 L
.44966 .311 L
.48945 .30001 L
.52966 .29687 L
.5687 .30171 L
.60504 .31432 L
.63727 .33423 L
.6641 .36064 L
.68449 .39251 L
.69765 .42861 L
.70305 .46751 L
.70047 .50768 L
.69003 .54756 L
.67214 .58556 L
.64748 .62021 L
.61704 .65014 L
.58201 .67418 L
.54375 .69138 L
.50378 .70107 L
.46366 .70287 L
.42497 .69671 L
.38922 .68283 L
.35782 .66177 L
.332 .63436 L
.31277 .60168 L
.30089 .56501 L
.29683 .52579 L
.30074 .48556 L
Mistroke
.31246 .44589 L
.33155 .40835 L
.35725 .3744 L
.38855 .34539 L
.42423 .32244 L
.46288 .30646 L
.50298 .29807 L
.54297 .29761 L
.58127 .30509 L
.61639 .32023 L
.64693 .34241 L
.67171 .37079 L
.68975 .40423 L
.70034 .44143 L
.70307 .48093 L
.69783 .52118 L
.68483 .5606 L
.66457 .59764 L
.63785 .63085 L
.60573 .65892 L
.56945 .68075 L
.53045 .6955 L
.49025 .70256 L
.45044 .70168 L
.41257 .69289 L
.37813 .67652 L
.34848 .65323 L
.32477 .62392 L
.30794 .58975 L
.29864 .55206 L
.29725 .51232 L
.30382 .4721 L
.31808 .43298 L
.33949 .39648 L
.36719 .36405 L
.40011 .33695 L
.43695 .31626 L
.47626 .30277 L
.5165 .29703 L
.5561 .29925 L
.59349 .30934 L
.62721 .32693 L
.65595 .3513 L
.67856 .38151 L
.69416 .41637 L
.70215 .45451 L
.7022 .49444 L
.69431 .53459 L
.6788 .57337 L
.65627 .60928 L
Mistroke
.62761 .6409 L
.59394 .66699 L
.55659 .68653 L
.51701 .69874 L
.47677 .70316 L
.43743 .6996 L
.40055 .68821 L
.36758 .66943 L
.3398 .64401 L
.31831 .61293 L
.30395 .57742 L
.29729 .53887 L
.29858 .49879 L
.30777 .45877 L
.32451 .42036 L
.34814 .38507 L
.37772 .3543 L
.41211 .32925 L
.44994 .31089 L
.48974 .29996 L
.52994 .29688 L
.56897 .30177 L
.60529 .31444 L
.63748 .33439 L
.66427 .36085 L
.68462 .39276 L
.69772 .42888 L
.70306 .46779 L
.70043 .50797 L
.68993 .54784 L
.67198 .58582 L
.64728 .62044 L
.61681 .65033 L
.58174 .67433 L
.54347 .69148 L
.50349 .70111 L
.46338 .70285 L
.4247 .69664 L
.38898 .6827 L
.35762 .66159 L
.33184 .63415 L
.31266 .60143 L
.30084 .56474 L
.29683 .52551 L
.30079 .48527 L
.31258 .44561 L
.33171 .40809 L
.35746 .37418 L
.3888 .3452 L
.4245 .3223 L
Mistroke
.46316 .30637 L
Mfstroke
1 0 0 r
.33216 .63458 m
.31289 .60193 L
s
% Start of user PostScript
-5.0350684 4.0374108 -5.6134066 3.0580408 MAarrowhead1
% End of user PostScript
1 .158 0 r
.30095 .56529 m
.29683 .52608 L
s
% Start of user PostScript
-5.9714411 1.958655 -6.0951207 0.78239987 MAarrowhead1
% End of user PostScript
1 .473 0 r
.46259 .30654 m
.50269 .2981 L
s
% Start of user PostScript
-1.1221918 -5.803698 0.080837195 -6.0569226 MAarrowhead1
% End of user PostScript
1 .788 0 r
.70029 .44116 m
.70308 .48064 L
s
% Start of user PostScript
6.0088184 -1.765349 6.0924282 -0.58065965 MAarrowhead1
% End of user PostScript
.897 1 0 r
.53074 .69542 m
.49054 .70254 L
s
% Start of user PostScript
0.92205384 5.8624971 -0.28376002 6.0762629 MAarrowhead1
% End of user PostScript
.581 1 0 r
.29868 .55234 m
.29723 .51261 L
s
% Start of user PostScript
-6.0395296 1.5700846 -6.0829769 0.37827525 MAarrowhead1
% End of user PostScript
.266 1 0 r
.47597 .30284 m
.51621 .29704 L
s
% Start of user PostScript
-0.72089293 -5.9147925 0.48636804 -6.0888623 MAarrowhead1
% End of user PostScript
0 1 .049 r
.70212 .45423 m
.70223 .49415 L
s
% Start of user PostScript
6.0635407 -1.3730784 6.0667773 -0.17547121 MAarrowhead1
% End of user PostScript
0 1 .364 r
.5173 .69868 m
.47705 .70316 L
s
% Start of user PostScript
0.51893228 5.9605262 -0.68843649 6.0947067 MAarrowhead1
% End of user PostScript
0 1 .679 r
.29731 .53915 m
.29854 .49908 L
s
% Start of user PostScript
-6.0808249 1.1745488 -6.0438473 -0.027527507 MAarrowhead1
% End of user PostScript
0 1 .995 r
.48945 .30001 m
.52966 .29687 L
s
% Start of user PostScript
-0.31639593 -5.9996473 0.88974121 -6.0937899 MAarrowhead1
% End of user PostScript
0 .69 1 r
.70305 .46751 m
.70047 .50768 L
s
% Start of user PostScript
6.0913633 -0.97471632 6.0142123 0.23049568 MAarrowhead1
% End of user PostScript
0 .375 1 r
.50378 .70107 m
.46366 .70287 L
s
% Start of user PostScript
0.11350858 6.0321126 -1.0900589 6.0861127 MAarrowhead1
% End of user PostScript
0 .06 1 r
.29683 .52579 m
.30074 .48556 L
s
% Start of user PostScript
-6.0951439 0.77380245 -5.9779053 -0.43320815 MAarrowhead1
% End of user PostScript
1 .331 0 r
.59487 .35356 m
.61975 .37165 L
.63993 .39477 L
.65462 .42203 L
.66323 .45234 L
.66545 .48453 L
.66116 .51732 L
.65056 .54943 L
.63404 .5796 L
.61227 .60665 L
.58609 .62951 L
.55653 .64729 L
.52475 .65929 L
.492 .66504 L
.45956 .66431 L
.42871 .65713 L
.40066 .64379 L
.37651 .6248 L
.3572 .60091 L
.3435 .57307 L
.33594 .54235 L
.33482 .50998 L
.34018 .47721 L
.35182 .44534 L
.36926 .41561 L
.39185 .38919 L
.41867 .36713 L
.44869 .35027 L
.48072 .3393 L
.5135 .33463 L
.54576 .33645 L
.57622 .34469 L
.60369 .35902 L
.62709 .37889 L
.64551 .40351 L
.65821 .43192 L
.6647 .463 L
.66473 .49553 L
.65829 .52824 L
.64565 .55984 L
.62728 .58909 L
.60392 .61484 L
.57648 .63609 L
.54604 .65199 L
.5138 .66193 L
.48101 .66552 L
.44897 .66261 L
.41893 .65332 L
.39207 .63801 L
.36945 .61728 L
Mistroke
.35195 .59195 L
.34026 .56302 L
.33484 .53161 L
.3359 .49896 L
.34341 .46635 L
.35705 .43506 L
.37631 .40632 L
.40043 .38125 L
.42845 .36085 L
.45928 .34591 L
.4917 .33701 L
.52446 .33451 L
.55625 .33851 L
.58583 .34885 L
.61205 .36511 L
.63387 .38667 L
.65044 .41268 L
.6611 .44212 L
.66544 .47382 L
.66328 .50656 L
.65472 .53903 L
.64009 .56998 L
.61995 .59818 L
.59511 .62252 L
.56654 .64206 L
.53536 .65602 L
.50279 .66386 L
.47011 .66527 L
.4386 .66019 L
.4095 .64882 L
.38395 .63162 L
.36296 .60925 L
.34735 .58259 L
.33773 .55269 L
.33447 .52072 L
.33771 .48794 L
.34732 .45563 L
.36293 .42507 L
.38391 .39744 L
.40945 .37384 L
.43854 .35519 L
.47005 .34222 L
.50273 .33545 L
.5353 .33513 L
.56649 .34129 L
.59507 .35367 L
.61991 .3718 L
.64005 .39496 L
.6547 .42224 L
.66327 .45257 L
Mistroke
.66544 .48476 L
.66111 .51755 L
.65046 .54965 L
.63391 .57981 L
.61209 .60683 L
.58589 .62966 L
.5563 .6474 L
.52451 .65936 L
.49176 .66506 L
.45933 .66428 L
.4285 .65706 L
.40047 .64367 L
.37635 .62464 L
.35708 .60073 L
.34343 .57286 L
.33591 .54213 L
.33484 .50974 L
.34024 .47698 L
.35192 .44511 L
.36941 .41541 L
.39202 .38902 L
.41887 .36699 L
.44891 .35017 L
.48095 .33924 L
.51374 .33462 L
.54599 .33649 L
.57643 .34477 L
.60388 .35915 L
.62724 .37905 L
.64562 .4037 L
.65828 .43213 L
.66472 .46323 L
.66471 .49577 L
.65822 .52847 L
.64553 .56006 L
.62713 .58928 L
.60374 .61501 L
.57628 .63622 L
.54582 .65209 L
.51356 .66198 L
.48078 .66552 L
.44874 .66257 L
.41872 .65323 L
.39189 .63788 L
.3693 .61712 L
.35184 .59176 L
.3402 .5628 L
.33482 .53138 L
.33593 .49872 L
.34348 .46612 L
Mistroke
.35717 .43484 L
.37647 .40612 L
.40061 .38109 L
.42866 .36072 L
.4595 .34582 L
.49194 .33697 L
.52469 .33452 L
.55647 .33856 L
.58604 .34894 L
.61222 .36525 L
.63401 .38684 L
.65053 .41288 L
.66115 .44234 L
.66544 .47405 L
.66324 .50679 L
.65464 .53926 L
.63996 .57019 L
.61979 .59837 L
.59492 .62268 L
.56633 .64218 L
.53513 .6561 L
.50255 .66389 L
.46987 .66525 L
.43838 .66013 L
.4093 .64872 L
.38379 .63148 L
.36283 .60907 L
.34726 .58238 L
.33768 .55246 L
.33447 .52049 L
.33776 .4877 L
.34742 .45541 L
.36306 .42486 L
.38408 .39726 L
.40965 .37369 L
.43876 .35508 L
.47028 .34215 L
.50296 .33543 L
.53553 .33516 L
.5667 .34136 L
.59526 .35378 L
.62008 .37195 L
.64018 .39514 L
.65478 .42244 L
.66331 .45279 L
.66543 .48499 L
.66106 .51779 L
.65036 .54988 L
.63377 .58001 L
.61192 .60701 L
Mistroke
.58568 .62981 L
Mfstroke
1 0 0 r
.59487 .35356 m
.61975 .37165 L
s
% Start of user PostScript
2.8462006 -4.3931337 3.5925328 -3.8505245 MAarrowhead1
% End of user PostScript
1 .158 0 r
.63993 .39477 m
.65462 .42203 L
s
% Start of user PostScript
4.1978725 -3.1567977 4.6384627 -2.3391793 MAarrowhead1
% End of user PostScript
1 .473 0 r
.58609 .62951 m
.55653 .64729 L
s
% Start of user PostScript
2.5825928 3.8853794 1.6957863 4.4187705 MAarrowhead1
% End of user PostScript
1 .788 0 r
.3572 .60091 m
.3435 .57307 L
s
% Start of user PostScript
-4.2838919 3.0273859 -4.6949449 2.1920017 MAarrowhead1
% End of user PostScript
.897 1 0 r
.41867 .36713 m
.44869 .35027 L
s
% Start of user PostScript
-2.4399076 -3.9862137 -1.53941 -4.4917804 MAarrowhead1
% End of user PostScript
.581 1 0 r
.64551 .40351 m
.65821 .43192 L
s
% Start of user PostScript
4.3651589 -2.8946156 4.7462186 -2.0423922 MAarrowhead1
% End of user PostScript
.266 1 0 r
.57648 .63609 m
.54604 .65199 L
s
% Start of user PostScript
2.2945156 4.0826258 1.3813259 4.5598071 MAarrowhead1
% End of user PostScript
0 1 .049 r
.35195 .59195 m
.34026 .56302 L
s
% Start of user PostScript
-4.4415832 2.758634 -4.7922269 1.890517 MAarrowhead1
% End of user PostScript
0 1 .364 r
.42845 .36085 m
.45928 .34591 L
s
% Start of user PostScript
-2.1465781 -4.1745086 -1.2217094 -4.6227753 MAarrowhead1
% End of user PostScript
0 1 .679 r
.65044 .41268 m
.6611 .44212 L
s
% Start of user PostScript
4.5130801 -2.6195921 4.8329189 -1.7365445 MAarrowhead1
% End of user PostScript
0 1 .995 r
.56654 .64206 m
.53536 .65602 L
s
% Start of user PostScript
1.9962592 4.2617604 1.0607375 4.680615 MAarrowhead1
% End of user PostScript
0 .69 1 r
.34735 .58259 m
.33773 .55269 L
s
% Start of user PostScript
-4.5795702 2.477644 -4.8682493 1.5806454 MAarrowhead1
% End of user PostScript
0 .375 1 r
.43854 .35519 m
.47005 .34222 L
s
% Start of user PostScript
-1.8437257 -4.3442842 -0.8985889 -4.7332622 MAarrowhead1
% End of user PostScript
0 .06 1 r
.6547 .42224 m
.66327 .45257 L
s
% Start of user PostScript
4.6409799 -2.3329473 4.8981789 -1.4229929 MAarrowhead1
% End of user PostScript
1 .408 0 r
.73374 .63256 m
.69701 .67969 L
.65255 .71977 L
.6021 .75123 L
.54764 .77282 L
.49132 .78371 L
.43533 .78347 L
.38189 .7721 L
.33308 .75005 L
.29082 .71818 L
.25677 .67776 L
.23226 .63036 L
.21826 .57784 L
.21532 .52227 L
.22356 .46582 L
.24264 .41072 L
.27182 .35911 L
.30996 .31304 L
.35555 .27431 L
.40682 .24443 L
.46174 .22459 L
.51816 .21555 L
.57387 .21767 L
.62668 .23088 L
.67452 .25465 L
.71551 .28804 L
.74805 .32976 L
.77084 .37816 L
.78301 .43133 L
.78407 .48721 L
.77398 .54358 L
.75314 .59825 L
.72237 .64906 L
.68286 .69402 L
.63619 .73136 L
.58416 .75963 L
.52883 .7777 L
.47238 .78488 L
.417 .78088 L
.36488 .76585 L
.31807 .74039 L
.2784 .70549 L
.24742 .66253 L
.22635 .6132 L
.21603 .55942 L
.21685 .5033 L
.22878 .44706 L
.25136 .3929 L
.28369 .34294 L
.32452 .29914 L
Mistroke
.37223 .26322 L
.42495 .2366 L
.48062 .22032 L
.53705 .21501 L
.59203 .22089 L
.6434 .23772 L
.68913 .26484 L
.72745 .3012 L
.75684 .34535 L
.77615 .39558 L
.78462 .4499 L
.78192 .50619 L
.76815 .56223 L
.74387 .61584 L
.71001 .6649 L
.66791 .70748 L
.61922 .74193 L
.56585 .76687 L
.5099 .78135 L
.45356 .78478 L
.39904 .77704 L
.34848 .75842 L
.30387 .72966 L
.26696 .69189 L
.23919 .64659 L
.22166 .59553 L
.21505 .54073 L
.21963 .48433 L
.23521 .42854 L
.26118 .37555 L
.29652 .32745 L
.33985 .28613 L
.38947 .25319 L
.44342 .22994 L
.49959 .21729 L
.55578 .21574 L
.60978 .22534 L
.65947 .24572 L
.70291 .27608 L
.73838 .31523 L
.76449 .36163 L
.78022 .41346 L
.78496 .46869 L
.77851 .52514 L
.76113 .58061 L
.73351 .63292 L
.69672 .68 L
.65221 .72003 L
.60172 .75142 L
.54725 .77294 L
Mistroke
.49091 .78375 L
.43494 .78342 L
.38152 .77197 L
.33275 .74985 L
.29054 .71792 L
.25655 .67744 L
.23212 .63 L
.2182 .57745 L
.21534 .52186 L
.22365 .46542 L
.24281 .41033 L
.27206 .35876 L
.31026 .31274 L
.3559 .27406 L
.4072 .24425 L
.46214 .22448 L
.51857 .21552 L
.57426 .21773 L
.62705 .23101 L
.67484 .25485 L
.71578 .28831 L
.74824 .33008 L
.77097 .37852 L
.78306 .43173 L
.78404 .48761 L
.77387 .54398 L
.75296 .59863 L
.72211 .6494 L
.68255 .69431 L
.63583 .7316 L
.58377 .75979 L
.52843 .77779 L
.47197 .78489 L
.41661 .78081 L
.36453 .7657 L
.31776 .74017 L
.27814 .70521 L
.24723 .6622 L
.22624 .61282 L
.21599 .55902 L
.21689 .5029 L
.22891 .44666 L
.25156 .39252 L
.28396 .3426 L
.32484 .29885 L
.37259 .263 L
.42534 .23645 L
.48103 .22024 L
.53746 .21501 L
.59242 .22097 L
Mistroke
.64375 .23788 L
.68944 .26507 L
.72769 .30149 L
.75701 .34569 L
.77625 .39595 L
.78464 .4503 L
.78186 .50659 L
.76802 .56263 L
.74366 .61621 L
.70973 .66523 L
.66758 .70776 L
.61885 .74214 L
.56546 .76702 L
.50949 .78141 L
.45316 .78477 L
.39866 .77694 L
.34814 .75825 L
.30358 .72942 L
.26673 .69159 L
.23903 .64624 L
.22157 .59515 L
.21505 .54033 L
.2197 .48392 L
.23536 .42815 L
.2614 .37519 L
.29681 .32713 L
.34019 .28586 L
.38984 .25299 L
.44382 .22981 L
.5 .21724 L
.55618 .21577 L
.61016 .22545 L
.65981 .24591 L
.70319 .27633 L
.7386 .31554 L
.76464 .36198 L
.7803 .41385 L
.78495 .46909 L
.77843 .52555 L
.76097 .581 L
.73328 .63327 L
.69642 .68032 L
.65186 .72029 L
.60134 .75161 L
.54685 .77306 L
.49051 .78379 L
.43455 .78338 L
.38115 .77185 L
.33242 .74966 L
.29027 .71766 L
Mistroke
.25634 .67712 L
Mfstroke
1 0 0 r
.73374 .63256 m
.69701 .67969 L
s
% Start of user PostScript
7.0122013 3.976708 5.9103117 5.3906946 MAarrowhead1
% End of user PostScript
1 .158 0 r
.65255 .71977 m
.6021 .75123 L
s
% Start of user PostScript
4.5764661 6.593118 3.0630127 7.5367882 MAarrowhead1
% End of user PostScript
1 .473 0 r
.25677 .67776 m
.23226 .63036 L
s
% Start of user PostScript
-7.2970324 5.3327445 -8.0321753 3.9106976 MAarrowhead1
% End of user PostScript
1 .788 0 r
.35555 .27431 m
.40682 .24443 L
s
% Start of user PostScript
-4.3334211 -6.7707378 -2.795482 -7.6670433 MAarrowhead1
% End of user PostScript
.897 1 0 r
.74805 .32976 m
.77084 .37816 L
s
% Start of user PostScript
7.4413673 -5.1072289 8.1252855 -3.6553284 MAarrowhead1
% End of user PostScript
.581 1 0 r
.63619 .73136 m
.58416 .75963 L
s
% Start of user PostScript
4.0855687 6.9408462 2.5248501 7.7887927 MAarrowhead1
% End of user PostScript
.266 1 0 r
.24742 .66253 m
.22635 .6132 L
s
% Start of user PostScript
-7.5774469 4.8760475 -8.2093816 3.3959042 MAarrowhead1
% End of user PostScript
0 1 .049 r
.37223 .26322 m
.42495 .2366 L
s
% Start of user PostScript
-3.8331838 -7.1032546 -2.2514171 -7.9019014 MAarrowhead1
% End of user PostScript
0 1 .364 r
.75684 .34535 m
.77615 .39558 L
s
% Start of user PostScript
7.7051202 -4.6394567 8.2843704 -3.1327125 MAarrowhead1
% End of user PostScript
0 1 .679 r
.61922 .74193 m
.56585 .76687 L
s
% Start of user PostScript
3.5765464 7.2577827 1.9754864 8.0062438 MAarrowhead1
% End of user PostScript
0 1 .995 r
.23919 .64659 m
.22166 .59553 L
s
% Start of user PostScript
-7.8242456 4.397719 -8.3501687 2.8660455 MAarrowhead1
% End of user PostScript
0 .69 1 r
.38947 .25319 m
.44342 .22994 L
s
% Start of user PostScript
-3.3159413 -7.4042592 -1.6973642 -8.1017043 MAarrowhead1
% End of user PostScript
0 .375 1 r
.76449 .36163 m
.78022 .41346 L
s
% Start of user PostScript
7.9346909 -4.1511025 8.4067034 -2.596199 MAarrowhead1
% End of user PostScript
0 .06 1 r
.60172 .75142 m
.54725 .77294 L
s
% Start of user PostScript
3.0516575 7.5425216 1.4173589 8.1881769 MAarrowhead1
% End of user PostScript
0 .621 1 r
.58916 .55215 m
.57483 .57014 L
.55757 .58537 L
.53805 .59726 L
.51703 .60532 L
.49535 .60926 L
.47385 .6089 L
.45337 .60427 L
.43473 .59555 L
.41864 .58308 L
.40575 .56735 L
.39656 .54898 L
.39143 .52868 L
.39056 .50726 L
.39398 .48555 L
.40157 .46441 L
.41301 .44467 L
.42788 .4271 L
.44557 .41238 L
.4654 .40111 L
.48658 .39372 L
.5083 .3905 L
.52968 .39158 L
.54991 .39691 L
.56817 .40629 L
.58376 .41935 L
.59606 .43557 L
.60459 .45432 L
.60902 .47486 L
.60916 .49639 L
.60503 .51806 L
.59677 .53902 L
.58471 .55845 L
.56933 .57559 L
.55123 .58976 L
.53112 .60041 L
.50979 .60712 L
.48807 .60962 L
.46682 .60782 L
.44687 .60179 L
.42901 .59176 L
.41393 .57814 L
.40223 .56144 L
.39437 .54234 L
.39066 .52157 L
.39123 .49996 L
.39608 .47835 L
.405 .45759 L
.41765 .43849 L
.43353 .42181 L
Mistroke
.45202 .40819 L
.4724 .39818 L
.49386 .39217 L
.51555 .39038 L
.53664 .3929 L
.55629 .39962 L
.57373 .41029 L
.58828 .42447 L
.59936 .44162 L
.60655 .46105 L
.60955 .48202 L
.60825 .50369 L
.6027 .52522 L
.59313 .54576 L
.57989 .5645 L
.56353 .58071 L
.54467 .59375 L
.52405 .60312 L
.5025 .60843 L
.48084 .60949 L
.45994 .60626 L
.44061 .59885 L
.42361 .58757 L
.4096 .57284 L
.39915 .55526 L
.39265 .53551 L
.39037 .51437 L
.39239 .49266 L
.39863 .47124 L
.40885 .45095 L
.42265 .43258 L
.43948 .41686 L
.45869 .40441 L
.47952 .3957 L
.50116 .39109 L
.52274 .39075 L
.54344 .3947 L
.56243 .40278 L
.57897 .41468 L
.59241 .42993 L
.60223 .44792 L
.60803 .46796 L
.60959 .48926 L
.60685 .51098 L
.59992 .53227 L
.58907 .55229 L
.57472 .57026 L
.55744 .58547 L
.5379 .59733 L
.51688 .60537 L
Mistroke
.49519 .60927 L
.4737 .60888 L
.45323 .60422 L
.4346 .59548 L
.41854 .58298 L
.40567 .56723 L
.39651 .54884 L
.39141 .52853 L
.39057 .5071 L
.39402 .4854 L
.40164 .46426 L
.41311 .44453 L
.42799 .42698 L
.4457 .41229 L
.46554 .40105 L
.48674 .39368 L
.50845 .39049 L
.52983 .3916 L
.55004 .39697 L
.56829 .40637 L
.58386 .41945 L
.59613 .43569 L
.60464 .45446 L
.60903 .47501 L
.60915 .49655 L
.60498 .51822 L
.5967 .53917 L
.58462 .55859 L
.56921 .5757 L
.55109 .58985 L
.53097 .60047 L
.50963 .60715 L
.48791 .60962 L
.46667 .60779 L
.44674 .60173 L
.42889 .59168 L
.41384 .57803 L
.40216 .56131 L
.39433 .54219 L
.39065 .52142 L
.39125 .4998 L
.39613 .47819 L
.40508 .45744 L
.41775 .43836 L
.43366 .4217 L
.45216 .40811 L
.47255 .39812 L
.49401 .39214 L
.51571 .39039 L
.53679 .39294 L
Mistroke
.55643 .39969 L
.57385 .41038 L
.58837 .42458 L
.59943 .44175 L
.60658 .4612 L
.60955 .48217 L
.60822 .50385 L
.60265 .52537 L
.59304 .5459 L
.57979 .56462 L
.5634 .58081 L
.54452 .59383 L
.5239 .60317 L
.50234 .60846 L
.48069 .60949 L
.45979 .60622 L
.44047 .59878 L
.42349 .58747 L
.40952 .57273 L
.39909 .55513 L
.39262 .53536 L
.39037 .51421 L
.39242 .49251 L
.39869 .47109 L
.40894 .45081 L
.42276 .43246 L
.43961 .41676 L
.45884 .40433 L
.47968 .39565 L
.50131 .39107 L
.5229 .39076 L
.54358 .39474 L
.56256 .40285 L
.57908 .41478 L
.5925 .43005 L
.60228 .44806 L
.60806 .46811 L
.60959 .48941 L
.60682 .51113 L
.59986 .53242 L
.58898 .55242 L
.57461 .57038 L
.55731 .58557 L
.53776 .5974 L
.51673 .60541 L
.49504 .60928 L
.47355 .60887 L
.45309 .60418 L
.43448 .5954 L
.41844 .58288 L
Mistroke
.4056 .5671 L
Mfstroke
1 0 0 r
.58916 .55215 m
.57483 .57014 L
s
% Start of user PostScript
2.6747717 1.5645185 2.2449991 2.1041254 MAarrowhead1
% End of user PostScript
1 .158 0 r
.55757 .58537 m
.53805 .59726 L
s
% Start of user PostScript
1.7271193 2.5611538 1.141457 2.9176673 MAarrowhead1
% End of user PostScript
1 .473 0 r
.40575 .56735 m
.39656 .54898 L
s
% Start of user PostScript
-2.8273717 2.0205088 -3.103124 1.4692716 MAarrowhead1
% End of user PostScript
1 .788 0 r
.44557 .41238 m
.4654 .40111 L
s
% Start of user PostScript
-1.6329469 -2.6284517 -1.0381 -2.9666049 MAarrowhead1
% End of user PostScript
.897 1 0 r
.59606 .43557 m
.60459 .45432 L
s
% Start of user PostScript
2.8817609 -1.932962 3.1377004 -1.3704617 MAarrowhead1
% End of user PostScript
.581 1 0 r
.55123 .58976 m
.53112 .60041 L
s
% Start of user PostScript
1.536963 2.6928336 0.93359147 3.0122514 MAarrowhead1
% End of user PostScript
.266 1 0 r
.40223 .56144 m
.39437 .54234 L
s
% Start of user PostScript
-2.9329531 1.8432707 -3.1687959 1.2701315 MAarrowhead1
% End of user PostScript
0 1 .049 r
.45202 .40819 m
.4724 .39818 L
s
% Start of user PostScript
-1.439274 -2.7542281 -0.82804718 -3.0545561 MAarrowhead1
% End of user PostScript
0 1 .364 r
.59936 .44162 m
.60655 .46105 L
s
% Start of user PostScript
2.9808916 -1.7515346 3.1963759 -1.1683923 MAarrowhead1
% End of user PostScript
0 1 .679 r
.54467 .59375 m
.52405 .60312 L
s
% Start of user PostScript
1.3399883 2.8125671 0.72158427 3.0934722 MAarrowhead1
% End of user PostScript
0 1 .995 r
.39915 .55526 m
.39265 .53551 L
s
% Start of user PostScript
-3.0255231 1.6578554 -3.22041 1.0653568 MAarrowhead1
% End of user PostScript
0 .69 1 r
.45869 .40441 m
.47952 .3957 L
s
% Start of user PostScript
-1.2392161 -2.8677859 -0.61432085 -3.1289565 MAarrowhead1
% End of user PostScript
0 .375 1 r
.60223 .44792 m
.60803 .46796 L
s
% Start of user PostScript
3.0667981 -1.5623369 3.2408714 -0.96113947 MAarrowhead1
% End of user PostScript
0 .06 1 r
.5379 .59733 m
.51688 .60537 L
s
% Start of user PostScript
1.1370691 2.9198233 0.50637592 3.1609695 MAarrowhead1
% End of user PostScript
1 0 .949 r
.80247 .7009 m
.74911 .76204 L
.68597 .8129 L
.61553 .85149 L
.54056 .87627 L
.46399 .88629 L
.38884 .88115 L
.31805 .86105 L
.2544 .82678 L
.20039 .77969 L
.15814 .72162 L
.12931 .65485 L
.11502 .58201 L
.11584 .50594 L
.13174 .42964 L
.16209 .35611 L
.20571 .28822 L
.26087 .22864 L
.32542 .17971 L
.39682 .14336 L
.47227 .121 L
.5488 .11351 L
.62342 .12119 L
.6932 .14374 L
.7554 .18027 L
.80757 .22935 L
.84767 .28905 L
.87413 .35703 L
.8859 .43062 L
.88253 .50693 L
.86415 .58297 L
.83147 .65576 L
.78579 .72243 L
.72889 .78037 L
.663 .82731 L
.59072 .86141 L
.51488 .88132 L
.43846 .88626 L
.36445 .87605 L
.29576 .85107 L
.23508 .81232 L
.18481 .76131 L
.1469 .70005 L
.12285 .63093 L
.1136 .55668 L
.11952 .4802 L
.14037 .4045 L
.17533 .33255 L
.22304 .26717 L
.28161 .21092 L
Mistroke
.34876 .16603 L
.42184 .13423 L
.49799 .1168 L
.57422 .1144 L
.64753 .12714 L
.71506 .1545 L
.77414 .19543 L
.82247 .24832 L
.85814 .31107 L
.87975 .38125 L
.88647 .45608 L
.87801 .53264 L
.85472 .60792 L
.81751 .67896 L
.76783 .74298 L
.70765 .79746 L
.63931 .84027 L
.56551 .86972 L
.48914 .88467 L
.41319 .88451 L
.34065 .86927 L
.27437 .83953 L
.21694 .79647 L
.17062 .74178 L
.13722 .67759 L
.11806 .60644 L
.1139 .53111 L
.12488 .45455 L
.15059 .37978 L
.19001 .30973 L
.2416 .24715 L
.30332 .19449 L
.37277 .15382 L
.44721 .12673 L
.52372 .1143 L
.5993 .117 L
.67098 .13473 L
.73596 .1668 L
.79167 .21195 L
.83594 .2684 L
.86702 .33394 L
.88369 .406 L
.88531 .48174 L
.87181 .5582 L
.84372 .63238 L
.80213 .70137 L
.74869 .76245 L
.68549 .81323 L
.61501 .85171 L
.54001 .8764 L
Mistroke
.46345 .88631 L
.38831 .88106 L
.31757 .86086 L
.25398 .82649 L
.20005 .77931 L
.15789 .72117 L
.12915 .65435 L
.11497 .58147 L
.1159 .50539 L
.13191 .4291 L
.16236 .3556 L
.20606 .28776 L
.2613 .22825 L
.32591 .17941 L
.39735 .14315 L
.47281 .12089 L
.54935 .11351 L
.62395 .1213 L
.69368 .14395 L
.75581 .18058 L
.8079 .22974 L
.84791 .28951 L
.87427 .35754 L
.88593 .43116 L
.88245 .50748 L
.86396 .58351 L
.83119 .65626 L
.78542 .72288 L
.72844 .78075 L
.6625 .8276 L
.59019 .8616 L
.51433 .8814 L
.43791 .88624 L
.36393 .87592 L
.29529 .85084 L
.23468 .812 L
.18449 .76091 L
.14668 .69958 L
.12273 .63042 L
.11359 .55614 L
.11962 .47965 L
.14057 .40397 L
.17563 .33205 L
.22342 .26673 L
.28207 .21056 L
.34926 .16575 L
.42238 .13406 L
.49854 .11673 L
.57476 .11444 L
.64804 .12728 L
Mistroke
.71551 .15475 L
.77453 .19577 L
.82277 .24873 L
.85835 .31155 L
.87986 .38177 L
.88646 .45663 L
.87789 .53319 L
.8545 .60844 L
.81719 .67945 L
.76744 .7434 L
.70718 .79781 L
.6388 .84053 L
.56497 .86988 L
.48859 .88472 L
.41266 .88446 L
.34015 .86911 L
.27392 .83927 L
.21656 .79612 L
.17033 .74135 L
.13703 .6771 L
.11798 .60591 L
.11392 .53056 L
.12501 .45401 L
.15082 .37926 L
.19034 .30925 L
.242 .24673 L
.3038 .19415 L
.37329 .15357 L
.44775 .12659 L
.52427 .11426 L
.59983 .11707 L
.67148 .13491 L
.73639 .16708 L
.79203 .21231 L
.83621 .26884 L
.86719 .33443 L
.88376 .40653 L
.88527 .48229 L
.87166 .55875 L
.84346 .6329 L
.80179 .70183 L
.74827 .76285 L
.68501 .81355 L
.61448 .85194 L
.53946 .87652 L
.4629 .88633 L
.38779 .88097 L
.31708 .86066 L
.25356 .8262 L
.1997 .77893 L
Mistroke
.15763 .72072 L
Mfstroke
1 0 0 r
.80247 .7009 m
.74911 .76204 L
s
% Start of user PostScript
9.0742146 6.0268912 7.4732983 7.8612675 MAarrowhead1
% End of user PostScript
1 .158 0 r
.68597 .8129 m
.61553 .85149 L
s
% Start of user PostScript
5.5790853 9.3871207 3.4659156 10.544567 MAarrowhead1
% End of user PostScript
1 .473 0 r
.15814 .72162 m
.12931 .65485 L
s
% Start of user PostScript
-10.25573 6.6485814 -11.120775 4.6455305 MAarrowhead1
% End of user PostScript
1 .788 0 r
.32542 .17971 m
.39682 .14336 L
s
% Start of user PostScript
-5.2374938 -9.6085675 -3.0955117 -10.699298 MAarrowhead1
% End of user PostScript
.897 1 0 r
.84767 .28905 m
.87413 .35703 L
s
% Start of user PostScript
10.430177 -6.3285452 11.223878 -4.2891649 MAarrowhead1
% End of user PostScript
.581 1 0 r
.663 .82731 m
.59072 .86141 L
s
% Start of user PostScript
4.8900919 9.8193548 2.7216737 10.842159 MAarrowhead1
% End of user PostScript
.266 1 0 r
.1469 .70005 m
.12285 .63093 L
s
% Start of user PostScript
-10.593053 6.0014882 -11.31453 3.928041 MAarrowhead1
% End of user PostScript
0 1 .049 r
.34876 .16603 m
.42184 .13423 L
s
% Start of user PostScript
-4.5372651 -10.019249 -2.3448164 -10.972991 MAarrowhead1
% End of user PostScript
0 1 .364 r
.85814 .31107 m
.87975 .38125 L
s
% Start of user PostScript
10.744178 -5.6677733 11.39263 -3.5625594 MAarrowhead1
% End of user PostScript
0 1 .679 r
.63931 .84027 m
.56551 .86972 L
s
% Start of user PostScript
4.1794047 10.208027 1.9653577 11.091651 MAarrowhead1
% End of user PostScript
0 1 .995 r
.13722 .67759 m
.11806 .60644 L
s
% Start of user PostScript
-10.883383 5.3277706 -11.458091 3.1931256 MAarrowhead1
% End of user PostScript
0 .69 1 r
.37277 .15382 m
.44721 .12673 L
s
% Start of user PostScript
-3.8169077 -10.385481 -1.5837187 -11.198005 MAarrowhead1
% End of user PostScript
0 .375 1 r
.86702 .33394 m
.88369 .406 L
s
% Start of user PostScript
11.010514 -4.9818575 11.51084 -2.8201494 MAarrowhead1
% End of user PostScript
0 .06 1 r
.61501 .85171 m
.54001 .8764 L
s
% Start of user PostScript
3.4501763 10.551414 1.2003228 11.291937 MAarrowhead1
% End of user PostScript
1 .086 0 r
.47166 .37267 m
.49822 .36638 L
.52485 .36533 L
.5505 .36956 L
.57417 .37892 L
.59493 .39302 L
.61197 .41133 L
.62461 .43311 L
.63236 .45752 L
.63491 .4836 L
.63217 .51032 L
.62425 .53663 L
.61145 .56151 L
.59427 .58397 L
.57339 .60314 L
.54964 .61826 L
.52393 .62874 L
.49729 .63417 L
.47075 .63433 L
.44536 .62922 L
.42212 .61904 L
.40193 .60418 L
.38559 .58524 L
.37374 .56295 L
.36685 .53819 L
.36518 .51194 L
.3688 .48521 L
.37757 .45906 L
.39115 .43453 L
.409 .41256 L
.43042 .39402 L
.45457 .37964 L
.4805 .36999 L
.5072 .36543 L
.53362 .36616 L
.55871 .37215 L
.58151 .38315 L
.6011 .39873 L
.61673 .41829 L
.62777 .44106 L
.6338 .46614 L
.63458 .49255 L
.63008 .51925 L
.62047 .54519 L
.60614 .56937 L
.58764 .59082 L
.5657 .6087 L
.54118 .62232 L
.51504 .63114 L
.48832 .63481 L
Mistroke
.46205 .63319 L
.43727 .62635 L
.41496 .61454 L
.39598 .59824 L
.38108 .57809 L
.37086 .55487 L
.3657 .52949 L
.36581 .50296 L
.37118 .47632 L
.38162 .4506 L
.3967 .42682 L
.41583 .40591 L
.43827 .3887 L
.46312 .37585 L
.48943 .36788 L
.51615 .36509 L
.54224 .36759 L
.56667 .3753 L
.58848 .38789 L
.60682 .40489 L
.62097 .42562 L
.63037 .44927 L
.63466 .47491 L
.63366 .50153 L
.62741 .52809 L
.61616 .55356 L
.60036 .57692 L
.58061 .59726 L
.55771 .61378 L
.53253 .62584 L
.50608 .63296 L
.4794 .63486 L
.45352 .63147 L
.42946 .62292 L
.40817 .60954 L
.39049 .59187 L
.37711 .57059 L
.36854 .54654 L
.36514 .52067 L
.36703 .49398 L
.37414 .46753 L
.38619 .44235 L
.4027 .41944 L
.42303 .39968 L
.44639 .38387 L
.47185 .37261 L
.49841 .36635 L
.52503 .36534 L
.55068 .36961 L
.57433 .379 L
Mistroke
.59507 .39314 L
.61207 .41147 L
.62468 .43328 L
.63239 .4577 L
.63491 .48379 L
.63214 .51051 L
.62417 .53682 L
.61134 .56168 L
.59413 .58412 L
.57323 .60327 L
.54946 .61835 L
.52374 .6288 L
.4971 .63419 L
.47057 .63431 L
.44519 .62916 L
.42196 .61894 L
.4018 .60406 L
.38549 .58509 L
.37367 .56278 L
.36681 .53801 L
.36518 .51174 L
.36884 .48502 L
.37765 .45888 L
.39126 .43436 L
.40914 .41241 L
.43058 .3939 L
.45475 .37955 L
.48069 .36994 L
.50739 .36542 L
.5338 .36619 L
.55889 .37221 L
.58166 .38324 L
.60123 .39886 L
.61682 .41844 L
.62783 .44123 L
.63383 .46632 L
.63457 .49274 L
.63003 .51944 L
.62039 .54537 L
.60602 .56953 L
.58749 .59096 L
.56553 .60882 L
.54099 .6224 L
.51485 .63119 L
.48813 .63482 L
.46187 .63316 L
.4371 .62628 L
.41481 .61444 L
.39586 .59811 L
.38099 .57793 L
Mistroke
.3708 .55469 L
.36568 .52931 L
.36583 .50277 L
.37124 .47613 L
.38171 .45042 L
.39682 .42666 L
.41598 .40577 L
.43844 .38859 L
.46331 .37578 L
.48962 .36784 L
.51634 .36509 L
.54242 .36763 L
.56684 .37537 L
.58863 .388 L
.60694 .40503 L
.62106 .42578 L
.63042 .44944 L
.63467 .47509 L
.63363 .50172 L
.62735 .52828 L
.61607 .55373 L
.60023 .57707 L
.58046 .59739 L
.55753 .61388 L
.53235 .62591 L
.50589 .63299 L
.47921 .63486 L
.45334 .63143 L
.4293 .62284 L
.40803 .60943 L
.39038 .59173 L
.37703 .57043 L
.3685 .54636 L
.36514 .52048 L
.36706 .49379 L
.37421 .46734 L
.38629 .44218 L
.40283 .41928 L
.42319 .39956 L
.44656 .38377 L
.47203 .37255 L
.4986 .36633 L
.52522 .36535 L
.55085 .36966 L
.57449 .37909 L
.5952 .39326 L
.61218 .41162 L
.62475 .43344 L
.63243 .45788 L
.63491 .48398 L
Mistroke
.6321 .5107 L
Mfstroke
1 0 0 r
.47166 .37267 m
.49822 .36638 L
s
% Start of user PostScript
-0.85025471 -3.8197839 -0.053499855 -4.0086347 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52485 .36533 m
.5505 .36956 L
s
% Start of user PostScript
0.74535466 -4.0401627 1.514957 -3.9131306 MAarrowhead1
% End of user PostScript
1 .473 0 r
.63217 .51032 m
.62425 .53663 L
s
% Start of user PostScript
3.9652308 0.30948425 3.7274481 1.0989497 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47075 .63433 m
.44536 .62922 L
s
% Start of user PostScript
-0.87742611 4.0298546 -1.6391085 3.8765274 MAarrowhead1
% End of user PostScript
.897 1 0 r
.3688 .48521 m
.37757 .45906 L
s
% Start of user PostScript
-3.936006 -0.44370815 -3.6728537 -1.2280667 MAarrowhead1
% End of user PostScript
.581 1 0 r
.53362 .36616 m
.55871 .37215 L
s
% Start of user PostScript
1.0085242 -4.0150758 1.7614417 -3.8356238 MAarrowhead1
% End of user PostScript
.266 1 0 r
.63008 .51925 m
.62047 .54519 L
s
% Start of user PostScript
3.9024147 0.5774398 3.6141847 1.3558213 MAarrowhead1
% End of user PostScript
0 1 .049 r
.46205 .63319 m
.43727 .62635 L
s
% Start of user PostScript
-1.1385034 3.9958428 -1.8818207 3.7904649 MAarrowhead1
% End of user PostScript
0 1 .364 r
.37118 .47632 m
.38162 .4506 L
s
% Start of user PostScript
-3.8644941 -0.71053086 -3.5515062 -1.4820717 MAarrowhead1
% End of user PostScript
0 1 .679 r
.54224 .36759 m
.56667 .3753 L
s
% Start of user PostScript
1.2672195 -3.9721769 2.0001121 -3.741101 MAarrowhead1
% End of user PostScript
0 1 .995 r
.62741 .52809 m
.61616 .55356 L
s
% Start of user PostScript
3.8222864 0.84283366 3.4848877 1.606678 MAarrowhead1
% End of user PostScript
0 .69 1 r
.45352 .63147 m
.42946 .62292 L
s
% Start of user PostScript
-1.3945299 3.9441043 -2.1161845 3.6875868 MAarrowhead1
% End of user PostScript
0 .375 1 r
.37414 .46753 m
.38619 .44235 L
s
% Start of user PostScript
-3.7758382 -0.97420144 -3.4144031 -1.7295018 MAarrowhead1
% End of user PostScript
0 .06 1 r
.55068 .36961 m
.57433 .379 L
s
% Start of user PostScript
1.5202932 -3.9116562 2.2299094 -3.6299816 MAarrowhead1
% End of user PostScript
1 0 .842 r
.37464 .29176 m
.42159 .26577 L
.47162 .24897 L
.52276 .24202 L
.573 .2452 L
.62038 .25837 L
.66304 .28103 L
.6993 .31228 L
.72774 .3509 L
.74723 .39538 L
.75703 .44395 L
.75674 .49473 L
.74637 .54571 L
.72633 .5949 L
.69742 .64037 L
.66075 .68033 L
.61777 .7132 L
.57017 .73772 L
.51982 .7529 L
.46869 .75816 L
.41879 .75328 L
.37208 .73847 L
.33038 .71429 L
.29535 .68171 L
.26834 .64199 L
.25043 .59671 L
.24231 .54762 L
.2443 .49667 L
.25633 .44585 L
.27793 .39715 L
.30823 .35249 L
.34607 .31362 L
.38994 .28207 L
.43814 .25906 L
.48876 .24551 L
.53982 .24195 L
.58932 .24852 L
.63532 .26496 L
.676 .29062 L
.70978 .3245 L
.73532 .36526 L
.75163 .41132 L
.75806 .46085 L
.75437 .51192 L
.74069 .56253 L
.71757 .61068 L
.6859 .65448 L
.64694 .69222 L
.60222 .72242 L
.55348 .74389 L
Mistroke
.50264 .75579 L
.4517 .75765 L
.40266 .7494 L
.35743 .73135 L
.31781 .70423 L
.28533 .6691 L
.26127 .62733 L
.24659 .58056 L
.24185 .53063 L
.24724 .47949 L
.26255 .42917 L
.28718 .38162 L
.32017 .33872 L
.36021 .30214 L
.40573 .27334 L
.45496 .25343 L
.50595 .24319 L
.55671 .24304 L
.60525 .25296 L
.64965 .27259 L
.68818 .30114 L
.71933 .33749 L
.74187 .38022 L
.75491 .42766 L
.75795 .47793 L
.75087 .52906 L
.73394 .57906 L
.70783 .62596 L
.67357 .66791 L
.63249 .70327 L
.58621 .73065 L
.53655 .74898 L
.48545 .75754 L
.43493 .756 L
.38696 .7444 L
.34342 .72322 L
.30603 .69327 L
.27626 .65574 L
.25526 .61209 L
.24387 .56405 L
.24253 .5135 L
.2513 .46241 L
.26982 .4128 L
.29738 .36661 L
.33289 .32566 L
.37496 .29154 L
.42194 .26561 L
.47198 .24888 L
.52312 .24201 L
.57335 .24526 L
Mistroke
.62071 .2585 L
.66332 .28123 L
.69953 .31254 L
.72791 .3512 L
.74734 .39571 L
.75706 .44431 L
.7567 .4951 L
.74626 .54608 L
.72616 .59525 L
.69718 .64068 L
.66046 .68059 L
.61745 .71341 L
.56982 .73786 L
.51946 .75297 L
.46833 .75816 L
.41844 .75321 L
.37176 .73833 L
.33011 .71409 L
.29512 .68145 L
.26818 .64169 L
.25034 .59637 L
.24229 .54726 L
.24436 .4963 L
.25646 .44549 L
.27811 .39682 L
.30848 .35219 L
.34636 .31337 L
.39028 .28187 L
.43849 .25893 L
.48913 .24545 L
.54019 .24197 L
.58967 .24861 L
.63563 .26511 L
.67627 .29084 L
.70999 .32477 L
.73547 .36558 L
.75171 .41166 L
.75807 .46122 L
.75431 .51229 L
.74056 .56288 L
.71737 .61101 L
.68565 .65477 L
.64664 .69247 L
.60188 .72261 L
.55312 .74401 L
.50228 .75584 L
.45134 .75762 L
.40232 .7493 L
.35713 .73119 L
.31755 .70401 L
Mistroke
.28512 .66882 L
.26113 .62701 L
.24652 .58021 L
.24185 .53026 L
.24731 .47913 L
.2627 .42881 L
.28739 .38129 L
.32043 .33843 L
.36051 .30191 L
.40607 .27316 L
.45532 .25332 L
.50632 .24315 L
.55707 .24307 L
.60558 .25307 L
.64995 .27276 L
.68844 .30137 L
.71952 .33778 L
.742 .38055 L
.75497 .42801 L
.75794 .47829 L
.75078 .52943 L
.73379 .57941 L
.70762 .62628 L
.6733 .66819 L
.63217 .70349 L
.58586 .73082 L
.53619 .74908 L
.48509 .75757 L
.43457 .75595 L
.38663 .74428 L
.34313 .72303 L
.30579 .69303 L
.27607 .65545 L
.25514 .61176 L
.24382 .5637 L
.24256 .51313 L
.25139 .46205 L
.26999 .41245 L
.29761 .3663 L
.33317 .32538 L
.37528 .29133 L
.42229 .26546 L
.47235 .2488 L
.52349 .24199 L
.57371 .24531 L
.62103 .25863 L
.66361 .28142 L
.69976 .31279 L
.72808 .3515 L
.74744 .39605 L
Mistroke
.7571 .44467 L
Mfstroke
1 0 0 r
.37464 .29176 m
.42159 .26577 L
s
% Start of user PostScript
-3.7607307 -6.2471685 -2.352281 -7.0269565 MAarrowhead1
% End of user PostScript
1 .158 0 r
.47162 .24897 m
.52276 .24202 L
s
% Start of user PostScript
-0.85151382 -7.5309649 0.68267187 -7.7394133 MAarrowhead1
% End of user PostScript
1 .473 0 r
.75703 .44395 m
.75674 .49473 L
s
% Start of user PostScript
7.7108931 -1.6813887 7.7021479 -0.15807625 MAarrowhead1
% End of user PostScript
1 .788 0 r
.51982 .7529 m
.46869 .75816 L
s
% Start of user PostScript
0.59468418 7.5869676 -0.93921024 7.7446784 MAarrowhead1
% End of user PostScript
.897 1 0 r
.24231 .54762 m
.2443 .49667 L
s
% Start of user PostScript
-7.7307005 1.4286867 -7.6708653 -0.099878689 MAarrowhead1
% End of user PostScript
.581 1 0 r
.48876 .24551 m
.53982 .24195 L
s
% Start of user PostScript
-0.3371948 -7.6345534 1.1947067 -7.7413517 MAarrowhead1
% End of user PostScript
.266 1 0 r
.75806 .46085 m
.75437 .51192 L
s
% Start of user PostScript
7.7419316 -1.1743997 7.6310727 0.35772283 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50264 .75579 m
.4517 .75765 L
s
% Start of user PostScript
0.079331343 7.6736696 -1.4488777 7.7294369 MAarrowhead1
% End of user PostScript
0 1 .364 r
.24185 .53063 m
.24724 .47949 L
s
% Start of user PostScript
-7.7445739 0.91880989 -7.5828144 -0.61517012 MAarrowhead1
% End of user PostScript
0 1 .679 r
.50595 .24319 m
.55671 .24304 L
s
% Start of user PostScript
0.17862012 -7.7042727 1.7014414 -7.7089472 MAarrowhead1
% End of user PostScript
0 1 .995 r
.75795 .47793 m
.75087 .52906 L
s
% Start of user PostScript
7.7386245 -0.66220075 7.5261438 0.87193495 MAarrowhead1
% End of user PostScript
0 .69 1 r
.48545 .75754 m
.43493 .756 L
s
% Start of user PostScript
-0.43637343 7.7263289 -1.9521175 7.6799053 MAarrowhead1
% End of user PostScript
0 .375 1 r
.24253 .5135 m
.2513 .46241 L
s
% Start of user PostScript
-7.7240901 0.40485698 -7.4611239 -1.1277325 MAarrowhead1
% End of user PostScript
0 .06 1 r
.52312 .24201 m
.57335 .24526 L
s
% Start of user PostScript
0.69364263 -7.7398136 2.200628 -7.6423435 MAarrowhead1
% End of user PostScript
.887 1 0 r
.21396 .51236 m
.22422 .45559 L
.24531 .40057 L
.27639 .34944 L
.31624 .30423 L
.36331 .2667 L
.41574 .23832 L
.47148 .22022 L
.52834 .21309 L
.58409 .21723 L
.63653 .23246 L
.68362 .25819 L
.7235 .29341 L
.75461 .33674 L
.77573 .38648 L
.78602 .44068 L
.7851 .4972 L
.77298 .55383 L
.75015 .60835 L
.7175 .65861 L
.67631 .70265 L
.62821 .73874 L
.57507 .76546 L
.51899 .78176 L
.46216 .787 L
.40682 .78098 L
.35514 .76393 L
.30914 .73653 L
.27063 .69984 L
.24112 .6553 L
.22177 .60468 L
.21334 .54994 L
.21616 .49324 L
.23013 .43681 L
.25468 .38286 L
.28886 .33351 L
.33133 .29069 L
.38041 .25609 L
.43419 .23105 L
.49056 .21658 L
.54729 .21322 L
.60217 .22112 L
.65304 .23997 L
.6979 .26902 L
.73499 .30714 L
.76286 .35282 L
.78042 .40428 L
.78697 .4595 L
.78226 .51631 L
.76647 .57247 L
Mistroke
.74022 .6258 L
.70455 .67418 L
.66085 .71573 L
.61083 .74882 L
.55647 .77213 L
.49989 .78477 L
.44331 .78623 L
.38896 .77646 L
.33896 .75584 L
.29529 .72518 L
.25965 .68568 L
.23344 .63889 L
.2177 .58665 L
.21303 .53101 L
.21963 .47416 L
.23723 .41832 L
.26514 .36568 L
.30227 .31832 L
.34716 .27808 L
.39805 .24656 L
.45294 .22498 L
.50967 .21419 L
.56603 .21463 L
.6198 .22626 L
.66886 .24863 L
.7113 .28087 L
.74544 .32171 L
.76995 .36955 L
.78387 .42251 L
.78665 .4785 L
.77817 .53535 L
.75878 .5908 L
.72924 .64269 L
.69069 .68898 L
.64467 .72786 L
.59296 .75779 L
.53761 .7776 L
.48078 .78652 L
.42471 .7842 L
.37159 .77072 L
.32351 .74661 L
.28235 .71283 L
.24974 .6707 L
.22695 .62186 L
.21488 .56825 L
.21399 .51195 L
.22434 .45519 L
.24549 .40018 L
.27664 .34909 L
.31656 .30393 L
Mistroke
.36367 .26646 L
.41613 .23815 L
.47189 .22012 L
.52875 .21308 L
.58448 .2173 L
.63689 .23261 L
.68393 .25841 L
.72376 .2937 L
.7548 .33708 L
.77584 .38686 L
.78606 .44107 L
.78505 .4976 L
.77285 .55423 L
.74995 .60872 L
.71723 .65895 L
.67599 .70294 L
.62784 .73897 L
.57468 .76562 L
.51858 .78184 L
.46176 .787 L
.40644 .7809 L
.35478 .76377 L
.30883 .73629 L
.27038 .69954 L
.24094 .65496 L
.22167 .6043 L
.21332 .54954 L
.21623 .49284 L
.23027 .43642 L
.25489 .38249 L
.28914 .33318 L
.33166 .29041 L
.38078 .25587 L
.43459 .23091 L
.49096 .21651 L
.54769 .21324 L
.60255 .22122 L
.65338 .24014 L
.69819 .26926 L
.73523 .30744 L
.76303 .35317 L
.78051 .40467 L
.78698 .4599 L
.78219 .51671 L
.76632 .57287 L
.74 .62616 L
.70426 .67451 L
.66051 .716 L
.61045 .74902 L
.55607 .77226 L
Mistroke
.49948 .78482 L
.44291 .7862 L
.38858 .77635 L
.33863 .75566 L
.295 .72493 L
.25943 .68537 L
.23329 .63853 L
.21763 .58626 L
.21304 .53061 L
.21972 .47375 L
.23739 .41793 L
.26537 .36532 L
.30257 .318 L
.3475 .27782 L
.39843 .24637 L
.45334 .22486 L
.51008 .21416 L
.56643 .21467 L
.62017 .22638 L
.66919 .24883 L
.71157 .28114 L
.74565 .32203 L
.77009 .36991 L
.78393 .4229 L
.78662 .47891 L
.77807 .53575 L
.75861 .59119 L
.72899 .64305 L
.69039 .68929 L
.64431 .7281 L
.59258 .75797 L
.5372 .77771 L
.48037 .78655 L
.42431 .78414 L
.37122 .77058 L
.32318 .74641 L
.28209 .71256 L
.24954 .67037 L
.22683 .62149 L
.21483 .56785 L
.21403 .51154 L
.22445 .45478 L
.24568 .3998 L
.2769 .34875 L
.31687 .30363 L
.36403 .26622 L
.41652 .23799 L
.47229 .22003 L
.52915 .21307 L
.58487 .21737 L
Mistroke
.63725 .23276 L
Mfstroke
1 0 0 r
.21396 .51236 m
.22422 .45559 L
s
% Start of user PostScript
-8.5811826 0.37079877 -8.2733437 -1.332264 MAarrowhead1
% End of user PostScript
1 .158 0 r
.24531 .40057 m
.27639 .34944 L
s
% Start of user PostScript
-7.6408095 -2.9830408 -6.7084042 -4.5167453 MAarrowhead1
% End of user PostScript
1 .473 0 r
.63653 .23246 m
.68362 .25819 L
s
% Start of user PostScript
4.0959713 -8.0262411 5.508602 -7.2542553 MAarrowhead1
% End of user PostScript
1 .788 0 r
.75015 .60835 m
.7175 .65861 L
s
% Start of user PostScript
7.5043834 3.2503739 6.5249271 4.7583655 MAarrowhead1
% End of user PostScript
.897 1 0 r
.35514 .76393 m
.30914 .73653 L
s
% Start of user PostScript
-4.3459226 7.9179797 -5.7259302 7.0957666 MAarrowhead1
% End of user PostScript
.581 1 0 r
.25468 .38286 m
.28886 .33351 L
s
% Start of user PostScript
-7.3596321 -3.514101 -6.3342114 -4.9947069 MAarrowhead1
% End of user PostScript
.266 1 0 r
.65304 .23997 m
.6979 .26902 L
s
% Start of user PostScript
4.5910527 -7.8009342 5.9369062 -6.929406 MAarrowhead1
% End of user PostScript
0 1 .049 r
.74022 .6258 m
.70455 .67418 L
s
% Start of user PostScript
7.2067162 3.7739297 6.1364686 5.2255073 MAarrowhead1
% End of user PostScript
0 1 .364 r
.33896 .75584 m
.29529 .72518 L
s
% Start of user PostScript
-4.8310895 7.6752345 -6.1412959 6.755358 MAarrowhead1
% End of user PostScript
0 1 .679 r
.26514 .36568 m
.30227 .31832 L
s
% Start of user PostScript
-7.0458052 -4.0295717 -5.9319181 -5.4505106 MAarrowhead1
% End of user PostScript
0 1 .995 r
.66886 .24863 m
.7113 .28087 L
s
% Start of user PostScript
5.0657668 -7.54102 6.3388725 -6.5738158 MAarrowhead1
% End of user PostScript
0 .69 1 r
.72924 .64269 m
.69069 .68898 L
s
% Start of user PostScript
6.8770778 4.2807433 5.7207869 5.6694671 MAarrowhead1
% End of user PostScript
0 .375 1 r
.32351 .74661 m
.28235 .71283 L
s
% Start of user PostScript
-5.2948243 7.3984397 -6.5294169 6.3849807 MAarrowhead1
% End of user PostScript
0 .06 1 r
.27664 .34909 m
.31656 .30393 L
s
% Start of user PostScript
-6.7007211 -4.5271659 -5.5033091 -5.8821341 MAarrowhead1
% End of user PostScript
0 .614 1 r
.51292 .66895 m
.47878 .6724 L
.44547 .66908 L
.4143 .65913 L
.38649 .64293 L
.36314 .62112 L
.34516 .59456 L
.33325 .56429 L
.32789 .53149 L
.32929 .49746 L
.33738 .46353 L
.35186 .43103 L
.37215 .40124 L
.39746 .37532 L
.42679 .35429 L
.45899 .33899 L
.49281 .33 L
.5269 .32769 L
.55995 .33213 L
.59063 .34317 L
.61777 .36036 L
.64027 .38303 L
.65728 .41029 L
.66811 .44107 L
.67234 .47417 L
.66982 .50828 L
.66062 .54206 L
.64512 .57419 L
.62393 .60341 L
.59787 .62858 L
.56797 .64869 L
.53541 .66297 L
.50145 .67086 L
.46744 .67204 L
.4347 .66647 L
.40453 .65436 L
.37811 .6362 L
.35647 .61269 L
.34046 .58476 L
.33071 .5535 L
.32761 .52014 L
.33127 .48599 L
.34155 .45239 L
.35806 .42067 L
.38013 .39205 L
.40691 .36767 L
.43734 .34848 L
.47023 .33524 L
.50429 .32847 L
.53818 .32843 L
Mistroke
.57057 .33512 L
.6002 .34828 L
.62589 .3674 L
.64664 .39172 L
.66163 .42029 L
.67028 .45199 L
.67225 .48557 L
.66746 .51972 L
.6561 .5531 L
.63861 .58439 L
.61568 .61237 L
.58821 .63594 L
.55728 .65417 L
.5241 .66636 L
.48997 .67201 L
.45624 .67092 L
.42423 .66311 L
.39519 .64891 L
.37026 .62886 L
.35043 .60375 L
.33646 .57457 L
.32892 .54247 L
.32808 .5087 L
.334 .47459 L
.34643 .44147 L
.36489 .41065 L
.38865 .38334 L
.41677 .36061 L
.44817 .34334 L
.4816 .33223 L
.51575 .3277 L
.54929 .32993 L
.58089 .33884 L
.60931 .35407 L
.63345 .37503 L
.65235 .40089 L
.66526 .43064 L
.6717 .46312 L
.67139 .49704 L
.66436 .53108 L
.65088 .5639 L
.63147 .59421 L
.60691 .62082 L
.57815 .64269 L
.54632 .65897 L
.51268 .669 L
.47854 .6724 L
.44524 .66903 L
.41409 .65903 L
.38631 .64279 L
Mistroke
.36299 .62095 L
.34505 .59436 L
.33319 .56406 L
.32788 .53125 L
.32932 .49722 L
.33746 .46329 L
.35198 .43081 L
.37231 .40104 L
.39765 .37515 L
.42701 .35416 L
.45923 .3389 L
.49305 .32996 L
.52715 .32769 L
.56018 .33219 L
.59084 .34327 L
.61794 .3605 L
.64042 .38321 L
.65738 .4105 L
.66817 .4413 L
.67235 .47441 L
.66977 .50852 L
.66053 .5423 L
.64499 .57441 L
.62376 .60361 L
.59767 .62874 L
.56775 .64882 L
.53517 .66305 L
.50121 .67089 L
.4672 .67202 L
.43448 .6664 L
.40433 .65425 L
.37793 .63605 L
.35633 .6125 L
.34036 .58454 L
.33066 .55327 L
.32761 .5199 L
.33132 .48575 L
.34165 .45216 L
.3582 .42045 L
.38031 .39186 L
.40712 .36751 L
.43757 .34837 L
.47047 .33517 L
.50454 .32845 L
.53842 .32845 L
.5708 .33519 L
.60039 .3484 L
.62605 .36756 L
.64676 .39191 L
.66172 .42051 L
Mistroke
.67032 .45222 L
.67224 .48582 L
.6674 .51997 L
.65599 .55333 L
.63846 .5846 L
.61549 .61255 L
.588 .63609 L
.55704 .65428 L
.52385 .66642 L
.48973 .67203 L
.456 .67088 L
.42401 .66303 L
.39499 .64878 L
.3701 .6287 L
.3503 .60356 L
.33638 .57435 L
.32889 .54223 L
.3281 .50845 L
.33406 .47434 L
.34654 .44124 L
.36504 .41044 L
.38883 .38316 L
.41699 .36046 L
.4484 .34324 L
.48185 .33217 L
.516 .32769 L
.54952 .32997 L
.5811 .33892 L
.6095 .3542 L
.6336 .3752 L
.65246 .40109 L
.66533 .43087 L
.67172 .46336 L
.67137 .49729 L
.66429 .53132 L
.65076 .56413 L
.63131 .59441 L
.60672 .621 L
.57793 .64283 L
.54609 .65906 L
.51244 .66905 L
.47829 .6724 L
.44501 .66899 L
.41387 .65894 L
.38612 .64266 L
.36284 .62077 L
.34494 .59415 L
.33313 .56383 L
.32787 .53101 L
.32936 .49697 L
Mistroke
.33755 .46305 L
Mfstroke
1 0 0 r
.51292 .66895 m
.47878 .6724 L
s
% Start of user PostScript
0.38773409 5.068502 -0.63656536 5.1719645 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44547 .66908 m
.4143 .65913 L
s
% Start of user PostScript
-1.6358822 5.0724481 -2.5709972 4.7738586 MAarrowhead1
% End of user PostScript
1 .473 0 r
.33738 .46353 m
.35186 .43103 L
s
% Start of user PostScript
-4.8785214 -1.0940808 -4.4442431 -2.0690984 MAarrowhead1
% End of user PostScript
1 .788 0 r
.55995 .33213 m
.59063 .34317 L
s
% Start of user PostScript
1.7983729 -5.0360071 2.7190233 -4.7049424 MAarrowhead1
% End of user PostScript
.897 1 0 r
.66062 .54206 m
.64512 .57419 L
s
% Start of user PostScript
4.8186223 1.261817 4.3536795 2.2258077 MAarrowhead1
% End of user PostScript
.581 1 0 r
.4347 .66647 m
.40453 .65436 L
s
% Start of user PostScript
-1.9588686 4.9939793 -2.864033 4.6308065 MAarrowhead1
% End of user PostScript
.266 1 0 r
.34155 .45239 m
.35806 .42067 L
s
% Start of user PostScript
-4.7533776 -1.4281534 -4.2582861 -2.3800477 MAarrowhead1
% End of user PostScript
0 1 .049 r
.57057 .33512 m
.6002 .34828 L
s
% Start of user PostScript
2.1171912 -4.9464113 3.0058653 -4.5515334 MAarrowhead1
% End of user PostScript
0 1 .364 r
.6561 .5531 m
.63861 .58439 L
s
% Start of user PostScript
4.6828595 1.5929054 4.1581686 2.5316474 MAarrowhead1
% End of user PostScript
0 1 .679 r
.42423 .66311 m
.39519 .64891 L
s
% Start of user PostScript
-2.273165 4.8933558 -3.144363 4.4672108 MAarrowhead1
% End of user PostScript
0 1 .995 r
.34643 .44147 m
.36489 .41065 L
s
% Start of user PostScript
-4.6071463 -1.7558902 -4.0534381 -2.6804385 MAarrowhead1
% End of user PostScript
0 .69 1 r
.58089 .33884 m
.60931 .35407 L
s
% Start of user PostScript
2.4266169 -4.8348717 3.2793724 -4.3779325 MAarrowhead1
% End of user PostScript
0 .375 1 r
.65088 .5639 m
.63147 .59421 L
s
% Start of user PostScript
4.5263221 1.9169271 3.9442108 2.8262559 MAarrowhead1
% End of user PostScript
0 .06 1 r
.41409 .65903 m
.38631 .64279 L
s
% Start of user PostScript
-2.5773769 4.7710238 -3.4107438 4.2837973 MAarrowhead1
% End of user PostScript
0 .714 1 r
.27104 .26137 m
.32863 .21463 L
.39295 .17909 L
.46147 .15615 L
.5315 .1467 L
.6003 .15112 L
.66516 .16923 L
.72354 .20032 L
.77314 .24317 L
.81203 .29611 L
.83867 .35704 L
.85202 .42358 L
.85155 .49313 L
.83728 .56294 L
.80978 .63028 L
.77012 .69251 L
.71986 .74719 L
.66098 .79216 L
.59577 .82567 L
.5268 .8464 L
.45679 .85353 L
.38847 .84678 L
.32452 .82643 L
.26746 .79327 L
.21953 .74859 L
.18261 .69416 L
.15814 .63211 L
.14709 .56488 L
.14989 .4951 L
.16643 .42551 L
.19606 .35884 L
.23762 .29772 L
.28948 .24453 L
.3496 .20137 L
.41562 .16993 L
.48495 .15144 L
.55488 .14664 L
.62265 .1557 L
.6856 .17827 L
.74127 .21347 L
.78748 .25992 L
.8224 .31578 L
.84467 .37888 L
.85341 .44673 L
.84828 .51667 L
.82948 .58596 L
.79776 .65187 L
.75434 .71183 L
.70095 .76347 L
.63967 .80477 L
Mistroke
.5729 .8341 L
.50328 .85033 L
.43352 .85281 L
.36638 .84144 L
.30448 .81667 L
.25025 .77947 L
.20583 .73131 L
.17295 .67407 L
.1529 .60999 L
.14648 .5416 L
.15393 .47158 L
.17497 .40267 L
.20876 .33758 L
.25398 .27887 L
.30885 .22883 L
.37123 .18944 L
.43866 .16223 L
.5085 .14828 L
.578 .14814 L
.64445 .1618 L
.70522 .18874 L
.75794 .22789 L
.80054 .27772 L
.83134 .33628 L
.84914 .40126 L
.85324 .47011 L
.84347 .54014 L
.82022 .6086 L
.78441 .67279 L
.73743 .7302 L
.68114 .77857 L
.61774 .81602 L
.54971 .84106 L
.47974 .85271 L
.41056 .85052 L
.34489 .83458 L
.28531 .80551 L
.23415 .76444 L
.19343 .713 L
.16474 .6532 L
.1492 .58738 L
.14744 .51814 L
.15951 .44818 L
.18494 .38026 L
.22274 .31704 L
.27142 .26099 L
.32907 .21433 L
.39343 .17888 L
.46197 .15603 L
.53201 .14668 L
Mistroke
.60078 .1512 L
.66561 .16941 L
.72393 .20059 L
.77346 .24352 L
.81226 .29652 L
.83881 .3575 L
.85206 .42408 L
.8515 .49363 L
.83713 .56344 L
.80954 .63075 L
.7698 .69294 L
.71947 .74755 L
.66053 .79245 L
.59528 .82587 L
.5263 .8465 L
.45629 .85353 L
.38799 .84669 L
.32408 .82624 L
.26709 .79299 L
.21923 .74824 L
.18239 .69374 L
.15801 .63165 L
.14706 .56438 L
.14996 .49459 L
.1666 .42502 L
.19632 .35838 L
.23796 .29731 L
.28988 .24418 L
.35005 .2011 L
.41611 .16975 L
.48545 .15136 L
.55537 .14665 L
.62312 .15581 L
.68603 .17848 L
.74164 .21377 L
.78777 .26028 L
.82261 .31621 L
.84478 .37935 L
.85342 .44723 L
.84819 .51717 L
.8293 .58645 L
.79749 .65233 L
.75399 .71223 L
.70053 .7638 L
.6392 .80502 L
.57241 .83427 L
.50277 .8504 L
.43303 .85278 L
.36592 .84131 L
.30406 .81645 L
Mistroke
.2499 .77917 L
.20555 .73093 L
.17276 .67363 L
.15281 .60951 L
.14649 .5411 L
.15404 .47108 L
.17516 .40218 L
.20904 .33713 L
.25434 .27847 L
.30927 .22851 L
.3717 .1892 L
.43915 .16208 L
.509 .14823 L
.57849 .14819 L
.6449 .16195 L
.70563 .18898 L
.75828 .22821 L
.8008 .27811 L
.83152 .33672 L
.84922 .40174 L
.85322 .47062 L
.84335 .54064 L
.82001 .60907 L
.78411 .67323 L
.73706 .73058 L
.68071 .77888 L
.61726 .81624 L
.54921 .84119 L
.47924 .85275 L
.41007 .85046 L
.34444 .83442 L
.28491 .80525 L
.23382 .76411 L
.19318 .7126 L
.16458 .65274 L
.14914 .58689 L
.14748 .51764 L
.15965 .44768 L
.18517 .37979 L
.22305 .31661 L
.27181 .26062 L
.32951 .21404 L
.39391 .17867 L
.46247 .15592 L
.53251 .14667 L
.60126 .15128 L
.66605 .16959 L
.72432 .20086 L
.77378 .24387 L
.8125 .29693 L
Mistroke
.83895 .35796 L
Mfstroke
1 0 0 r
.27104 .26137 m
.32863 .21463 L
s
% Start of user PostScript
-6.868852 -7.159045 -5.1410368 -8.5611398 MAarrowhead1
% End of user PostScript
1 .158 0 r
.39295 .17909 m
.46147 .15615 L
s
% Start of user PostScript
-3.2114566 -9.6272444 -1.1558397 -10.315518 MAarrowhead1
% End of user PostScript
1 .473 0 r
.83867 .35704 m
.85202 .42358 L
s
% Start of user PostScript
10.160037 -4.2888166 10.560474 -2.2924769 MAarrowhead1
% End of user PostScript
1 .788 0 r
.59577 .82567 m
.5268 .8464 L
s
% Start of user PostScript
2.8730524 9.7700937 0.80409798 10.391875 MAarrowhead1
% End of user PostScript
.897 1 0 r
.15814 .63211 m
.14709 .56488 L
s
% Start of user PostScript
-10.25573 3.9634004 -10.587257 1.9463507 MAarrowhead1
% End of user PostScript
.581 1 0 r
.41562 .16993 m
.48495 .15144 L
s
% Start of user PostScript
-2.5314609 -9.9021042 -0.45146419 -10.456703 MAarrowhead1
% End of user PostScript
.266 1 0 r
.84467 .37888 m
.85341 .44673 L
s
% Start of user PostScript
10.340047 -3.6335872 10.602294 -1.5980654 MAarrowhead1
% End of user PostScript
0 1 .049 r
.5729 .8341 m
.50328 .85033 L
s
% Start of user PostScript
2.1870611 10.023129 0.098329563 10.50993 MAarrowhead1
% End of user PostScript
0 1 .364 r
.1529 .60999 m
.14648 .5416 L
s
% Start of user PostScript
-10.412892 3.299743 -10.605569 1.2480071 MAarrowhead1
% End of user PostScript
0 1 .679 r
.43866 .16223 m
.5085 .14828 L
s
% Start of user PostScript
-1.8402349 -10.133035 0.25491415 -10.551498 MAarrowhead1
% End of user PostScript
0 1 .995 r
.84914 .40126 m
.85324 .47011 L
s
% Start of user PostScript
10.474185 -2.9622382 10.597078 -0.89656437 MAarrowhead1
% End of user PostScript
0 .69 1 r
.54971 .84106 m
.47974 .85271 L
s
% Start of user PostScript
1.4913672 10.2317 -0.60787507 10.58136 MAarrowhead1
% End of user PostScript
0 .375 1 r
.1492 .58738 m
.14744 .51814 L
s
% Start of user PostScript
-10.523859 2.6214471 -10.576832 0.54412699 MAarrowhead1
% End of user PostScript
0 .06 1 r
.46197 .15603 m
.53201 .14668 L
s
% Start of user PostScript
-1.1408451 -10.319013 0.96016162 -10.599484 MAarrowhead1
% End of user PostScript
1 0 .938 r
.29702 .68937 m
.26842 .65003 L
.2489 .60479 L
.23924 .55545 L
.23982 .50393 L
.25061 .45225 L
.27118 .40245 L
.30074 .35648 L
.33811 .31614 L
.38184 .28302 L
.43021 .25841 L
.48131 .24328 L
.53315 .23823 L
.58369 .24345 L
.63094 .25874 L
.67305 .2835 L
.70838 .31676 L
.73552 .3572 L
.75342 .40325 L
.76138 .4531 L
.75908 .50479 L
.74661 .55629 L
.72446 .60558 L
.6935 .65073 L
.65495 .68996 L
.61032 .72174 L
.56135 .74481 L
.50998 .75828 L
.45822 .76161 L
.4081 .75467 L
.36158 .73774 L
.3205 .71148 L
.28646 .67692 L
.26081 .63541 L
.24453 .58859 L
.23829 .5383 L
.24232 .4865 L
.25646 .43523 L
.28015 .3865 L
.31248 .34223 L
.35216 .30415 L
.39765 .27375 L
.44715 .25224 L
.49873 .24044 L
.55036 .23884 L
.60001 .24748 L
.64574 .26604 L
.68574 .29378 L
.71846 .32961 L
.7426 .37212 L
Mistroke
.75723 .41966 L
.76175 .47035 L
.75601 .5222 L
.74021 .57318 L
.71499 .62129 L
.68133 .66464 L
.64056 .70153 L
.59427 .73051 L
.54428 .75044 L
.49255 .76054 L
.44111 .76042 L
.39199 .75008 L
.3471 .72992 L
.30822 .70074 L
.27686 .66368 L
.25426 .6202 L
.2413 .572 L
.2385 .52097 L
.24595 .46912 L
.26338 .41849 L
.2901 .37105 L
.32505 .32867 L
.36687 .29302 L
.41392 .26549 L
.46434 .24716 L
.51616 .23876 L
.56735 .24061 L
.61589 .25264 L
.65989 .27437 L
.69761 .30497 L
.72758 .34321 L
.74861 .38761 L
.75989 .43642 L
.76097 .48773 L
.7518 .53952 L
.73276 .58975 L
.70457 .63647 L
.66836 .67782 L
.62555 .7122 L
.5778 .73826 L
.527 .75496 L
.47515 .76165 L
.42426 .75808 L
.37635 .74437 L
.3333 .72108 L
.29678 .68911 L
.26824 .64972 L
.2488 .60445 L
.23921 .55509 L
.23986 .50356 L
Mistroke
.25072 .45189 L
.27136 .40211 L
.30098 .35617 L
.3384 .31588 L
.38217 .28281 L
.43056 .25827 L
.48168 .24321 L
.53352 .23823 L
.58404 .24353 L
.63126 .25889 L
.67333 .28371 L
.7086 .31702 L
.73568 .35751 L
.75352 .4036 L
.7614 .45347 L
.75902 .50516 L
.74648 .55665 L
.72427 .60592 L
.69325 .65103 L
.65465 .69022 L
.60998 .72194 L
.56099 .74495 L
.50961 .75834 L
.45786 .7616 L
.40775 .75459 L
.36127 .73759 L
.32023 .71126 L
.28625 .67664 L
.26065 .63509 L
.24445 .58824 L
.23828 .53793 L
.24238 .48612 L
.25659 .43487 L
.28036 .38616 L
.31274 .34193 L
.35247 .3039 L
.39799 .27356 L
.44752 .25212 L
.49911 .2404 L
.55073 .23886 L
.60036 .24758 L
.64605 .26621 L
.68601 .294 L
.71867 .32989 L
.74274 .37245 L
.75729 .42001 L
.76175 .47072 L
.75593 .52257 L
.74007 .57354 L
.71478 .62162 L
Mistroke
.68107 .66493 L
.64025 .70177 L
.59392 .73068 L
.54391 .75055 L
.49218 .76058 L
.44075 .76038 L
.39165 .74997 L
.3468 .72974 L
.30796 .7005 L
.27666 .66339 L
.25413 .61987 L
.24124 .57164 L
.23851 .5206 L
.24604 .46875 L
.26354 .41813 L
.29032 .37072 L
.32533 .32839 L
.36719 .29279 L
.41427 .26532 L
.46471 .24707 L
.51653 .23873 L
.56771 .24066 L
.61623 .25276 L
.66018 .27456 L
.69785 .30521 L
.72776 .34351 L
.74873 .38795 L
.75993 .43678 L
.76094 .4881 L
.7517 .53988 L
.73259 .5901 L
.70434 .63678 L
.66808 .6781 L
.62522 .71242 L
.57745 .73841 L
.52663 .75504 L
.47478 .76166 L
.42391 .75801 L
.37603 .74424 L
.33301 .72088 L
.29655 .68885 L
.26807 .64941 L
.24869 .60411 L
.23918 .55472 L
.2399 .50318 L
.25083 .45152 L
.27154 .40176 L
.30122 .35586 L
.3387 .31561 L
.3825 .2826 L
Mistroke
.43092 .25812 L
Mfstroke
1 0 0 r
.29702 .68937 m
.26842 .65003 L
s
% Start of user PostScript
-6.0895117 5.6810631 -6.9475475 4.5007545 MAarrowhead1
% End of user PostScript
1 .158 0 r
.2489 .60479 m
.23924 .55545 L
s
% Start of user PostScript
-7.5329201 3.1438094 -7.8226559 1.6634824 MAarrowhead1
% End of user PostScript
1 .473 0 r
.43021 .25841 m
.48131 .24328 L
s
% Start of user PostScript
-2.0938446 -7.247745 -0.56069878 -7.7015557 MAarrowhead1
% End of user PostScript
1 .788 0 r
.75342 .40325 m
.76138 .4531 L
s
% Start of user PostScript
7.6026605 -2.902406 7.8413313 -1.4069638 MAarrowhead1
% End of user PostScript
.897 1 0 r
.56135 .74481 m
.50998 .75828 L
s
% Start of user PostScript
1.8406199 7.3444166 0.29952458 7.7484179 MAarrowhead1
% End of user PostScript
.581 1 0 r
.24453 .58859 m
.23829 .5383 L
s
% Start of user PostScript
-7.6639668 2.6577827 -7.8513077 1.1488843 MAarrowhead1
% End of user PostScript
.266 1 0 r
.44715 .25224 m
.49873 .24044 L
s
% Start of user PostScript
-1.5853532 -7.4329403 -0.038018092 -7.7866843 MAarrowhead1
% End of user PostScript
0 1 .049 r
.75723 .41966 m
.76175 .47035 L
s
% Start of user PostScript
7.7167707 -2.410211 7.8525739 -0.88953025 MAarrowhead1
% End of user PostScript
0 1 .364 r
.54428 .75044 m
.49255 .76054 L
s
% Start of user PostScript
1.3283278 7.5132182 -0.22353057 7.8163122 MAarrowhead1
% End of user PostScript
0 1 .679 r
.2413 .572 m
.2385 .52097 L
s
% Start of user PostScript
-7.7610138 2.1599653 -7.8451287 0.62918937 MAarrowhead1
% End of user PostScript
0 1 .995 r
.46434 .24716 m
.51616 .23876 L
s
% Start of user PostScript
-1.0698288 -7.5851609 0.48483125 -7.8372688 MAarrowhead1
% End of user PostScript
0 .69 1 r
.75989 .43642 m
.76097 .48773 L
s
% Start of user PostScript
7.796647 -1.9073235 7.8289803 -0.36815048 MAarrowhead1
% End of user PostScript
0 .375 1 r
.527 .75496 m
.47515 .76165 L
s
% Start of user PostScript
0.81014289 7.6486889 -0.74559407 7.849531 MAarrowhead1
% End of user PostScript
0 .06 1 r
.23921 .55509 m
.23986 .50356 L
s
% Start of user PostScript
-7.8236308 1.6525657 -7.8041465 0.10670317 MAarrowhead1
% End of user PostScript
1 .328 0 r
.5733 .24899 m
.61991 .26225 L
.66182 .28483 L
.69738 .31586 L
.72519 .35412 L
.74416 .3981 L
.75355 .44608 L
.75299 .49618 L
.7425 .54643 L
.7225 .59485 L
.69376 .63956 L
.65741 .67878 L
.61489 .71099 L
.56786 .73492 L
.51817 .74963 L
.46777 .75454 L
.41862 .74946 L
.37268 .73459 L
.33173 .71052 L
.29738 .67818 L
.27099 .63885 L
.25358 .59407 L
.24584 .5456 L
.24808 .49534 L
.26021 .44526 L
.28175 .39733 L
.31185 .35343 L
.34933 .31529 L
.39273 .28439 L
.44034 .26195 L
.49029 .24886 L
.54062 .24562 L
.58936 .25236 L
.63459 .26883 L
.67454 .29436 L
.70764 .32797 L
.73259 .36833 L
.74841 .41386 L
.75448 .46276 L
.75056 .51313 L
.73682 .56299 L
.71377 .61037 L
.68234 .65342 L
.64375 .69044 L
.59952 .72 L
.55138 .74092 L
.50123 .75239 L
.45103 .75395 L
.40275 .74554 L
.35829 .7275 L
Mistroke
.31939 .70053 L
.28757 .66569 L
.2641 .62434 L
.24988 .57812 L
.24548 .52883 L
.25107 .47841 L
.26642 .42884 L
.29095 .38206 L
.32368 .33991 L
.36333 .30404 L
.40834 .27586 L
.45695 .25648 L
.50725 .24665 L
.55726 .24677 L
.60503 .25683 L
.64868 .27643 L
.68649 .30481 L
.71698 .34084 L
.73895 .38312 L
.75155 .42999 L
.75428 .47961 L
.74703 .53002 L
.73008 .57926 L
.7041 .62539 L
.67011 .6666 L
.62945 .70126 L
.5837 .72803 L
.53467 .74585 L
.48428 .75402 L
.43451 .75223 L
.38731 .74053 L
.34453 .71939 L
.30785 .68964 L
.27871 .65245 L
.25826 .60928 L
.24729 .56182 L
.24624 .51193 L
.25516 .46157 L
.27368 .41273 L
.30108 .3673 L
.33629 .32709 L
.37792 .29366 L
.42435 .26833 L
.47374 .25209 L
.52417 .24558 L
.57364 .24905 L
.62023 .26238 L
.6621 .28503 L
.69761 .31611 L
.72536 .35442 L
Mistroke
.74426 .39844 L
.75358 .44644 L
.75295 .49654 L
.74239 .54678 L
.72232 .59519 L
.69352 .63986 L
.65713 .67904 L
.61457 .71119 L
.56752 .73506 L
.51781 .7497 L
.46741 .75454 L
.41828 .74939 L
.37236 .73445 L
.33146 .71031 L
.29716 .67792 L
.27083 .63855 L
.25349 .59374 L
.24582 .54525 L
.24813 .49498 L
.26033 .44491 L
.28193 .397 L
.31209 .35314 L
.34963 .31504 L
.39306 .28419 L
.44069 .26182 L
.49066 .2488 L
.54098 .24563 L
.5897 .25245 L
.6349 .26898 L
.6748 .29458 L
.70785 .32824 L
.73273 .36864 L
.74849 .4142 L
.75449 .46312 L
.7505 .51349 L
.73668 .56334 L
.71358 .61069 L
.68209 .6537 L
.64345 .69068 L
.59919 .72018 L
.55103 .74104 L
.50087 .75243 L
.45067 .75392 L
.40242 .74544 L
.35799 .72733 L
.31913 .7003 L
.28737 .66541 L
.26396 .62403 L
.24981 .57777 L
.24548 .52847 L
Mistroke
.25114 .47805 L
.26657 .42849 L
.29115 .38174 L
.32394 .33962 L
.36363 .30381 L
.40868 .27569 L
.4573 .25637 L
.50761 .24662 L
.55761 .24681 L
.60536 .25694 L
.64897 .2766 L
.68673 .30504 L
.71717 .34112 L
.73908 .38345 L
.75161 .43034 L
.75426 .47997 L
.74694 .53038 L
.72992 .57961 L
.70388 .6257 L
.66984 .66687 L
.62914 .70149 L
.58336 .72819 L
.53432 .74595 L
.48392 .75405 L
.43416 .75218 L
.38698 .74041 L
.34424 .71921 L
.30761 .6894 L
.27853 .65216 L
.25814 .60895 L
.24725 .56147 L
.24627 .51157 L
.25525 .46122 L
.27384 .41239 L
.3013 .36699 L
.33657 .32682 L
.37824 .29345 L
.42469 .26818 L
.4741 .25201 L
.52453 .24557 L
.57399 .24911 L
.62055 .26251 L
.66238 .28522 L
.69783 .31636 L
.72552 .35472 L
.74436 .39877 L
.75361 .44679 L
.75291 .49691 L
.74228 .54714 L
.72214 .59552 L
Mistroke
.69329 .64016 L
Mfstroke
1 0 0 r
.5733 .24899 m
.61991 .26225 L
s
% Start of user PostScript
2.1989462 -7.5302031 3.5973594 -7.1325514 MAarrowhead1
% End of user PostScript
1 .158 0 r
.66182 .28483 m
.69738 .31586 L
s
% Start of user PostScript
4.8545907 -6.4549757 5.9212989 -5.5240682 MAarrowhead1
% End of user PostScript
1 .473 0 r
.69376 .63956 m
.65741 .67878 L
s
% Start of user PostScript
5.8127187 4.1866504 4.7224437 5.3634061 MAarrowhead1
% End of user PostScript
1 .788 0 r
.33173 .71052 m
.29738 .67818 L
s
% Start of user PostScript
-5.0481971 6.3155293 -6.0785911 5.3454272 MAarrowhead1
% End of user PostScript
.897 1 0 r
.31185 .35343 m
.34933 .31529 L
s
% Start of user PostScript
-5.6445765 -4.3970041 -4.5199818 -5.5414483 MAarrowhead1
% End of user PostScript
.581 1 0 r
.67454 .29436 m
.70764 .32797 L
s
% Start of user PostScript
5.2362032 -6.1690767 6.2291399 -5.1608561 MAarrowhead1
% End of user PostScript
.266 1 0 r
.68234 .65342 m
.64375 .69044 L
s
% Start of user PostScript
5.4701723 4.6024799 4.3125055 5.7133429 MAarrowhead1
% End of user PostScript
0 1 .049 r
.31939 .70053 m
.28757 .66569 L
s
% Start of user PostScript
-5.4184003 6.0157801 -6.3727781 4.9705596 MAarrowhead1
% End of user PostScript
0 1 .364 r
.32368 .33991 m
.36333 .30404 L
s
% Start of user PostScript
-5.2896996 -4.8028498 -4.1002449 -5.8788992 MAarrowhead1
% End of user PostScript
0 1 .679 r
.68649 .30481 m
.71698 .34084 L
s
% Start of user PostScript
5.5945863 -5.8558098 6.5093466 -4.7747489 MAarrowhead1
% End of user PostScript
0 1 .995 r
.67011 .6666 m
.62945 .70126 L
s
% Start of user PostScript
5.1033586 4.9978915 3.8834356 6.0379336 MAarrowhead1
% End of user PostScript
0 .69 1 r
.30785 .68964 m
.27871 .65245 L
s
% Start of user PostScript
-5.7645658 5.6893431 -6.6386936 4.5736412 MAarrowhead1
% End of user PostScript
0 .375 1 r
.33629 .32709 m
.37792 .29366 L
s
% Start of user PostScript
-4.911356 -5.1873886 -3.6623182 -6.1902696 MAarrowhead1
% End of user PostScript
0 .06 1 r
.69761 .31611 m
.72536 .35442 L
s
% Start of user PostScript
5.9281502 -5.5165648 6.7606758 -4.3674595 MAarrowhead1
% End of user PostScript
0 1 .934 r
.56824 .83131 m
.49938 .8466 L
.43054 .84828 L
.36443 .8363 L
.30364 .81111 L
.25055 .77372 L
.20726 .72558 L
.17545 .6686 L
.15638 .60499 L
.1508 .53726 L
.15892 .46808 L
.18043 .40014 L
.21448 .33612 L
.25973 .27854 L
.31442 .22965 L
.37638 .19136 L
.4432 .16519 L
.51225 .15216 L
.58082 .15278 L
.64621 .16703 L
.70587 .19435 L
.75745 .23366 L
.79892 .28342 L
.82866 .34168 L
.84551 .40616 L
.84879 .47432 L
.83839 .54349 L
.8147 .61095 L
.77867 .67406 L
.73169 .73033 L
.67563 .77757 L
.61267 .81391 L
.54529 .83793 L
.47613 .84869 L
.40791 .84577 L
.3433 .82927 L
.28485 .79986 L
.23484 .75867 L
.19523 .70733 L
.16758 .64786 L
.15298 .58258 L
.152 .51406 L
.16468 .44499 L
.19052 .37808 L
.2285 .31596 L
.27714 .26105 L
.33452 .21553 L
.3984 .18117 L
.46627 .15932 L
.53546 .15084 L
Mistroke
.60326 .15606 L
.667 .17479 L
.72419 .20627 L
.77259 .24929 L
.81028 .30214 L
.8358 .36276 L
.84814 .42876 L
.84682 .49756 L
.83188 .56646 L
.80392 .63275 L
.76403 .69383 L
.71378 .7473 L
.65514 .79106 L
.59041 .82341 L
.52214 .84306 L
.45299 .84924 L
.38569 .84172 L
.32287 .82079 L
.26701 .78727 L
.22029 .74248 L
.18455 .68816 L
.16119 .62647 L
.15112 .55981 L
.15475 .4908 L
.17193 .42216 L
.20198 .35657 L
.24373 .29661 L
.29553 .24463 L
.35537 .20267 L
.42087 .17238 L
.48948 .15495 L
.55851 .15106 L
.62524 .16087 L
.68705 .18399 L
.74152 .2195 L
.78652 .26603 L
.82027 .32174 L
.84145 .38444 L
.84923 .45168 L
.8433 .52082 L
.8239 .58914 L
.79179 .65396 L
.74823 .71274 L
.69492 .76317 L
.63397 .80327 L
.56776 .83147 L
.49888 .84666 L
.43006 .84824 L
.36397 .83616 L
.30323 .81089 L
Mistroke
.25021 .77341 L
.20699 .7252 L
.17527 .66816 L
.1563 .60452 L
.15081 .53677 L
.15903 .46758 L
.18063 .39967 L
.21476 .33569 L
.26009 .27816 L
.31484 .22933 L
.37685 .19113 L
.44369 .16505 L
.51275 .15212 L
.5813 .15284 L
.64666 .16718 L
.70627 .19459 L
.75778 .23398 L
.79918 .28381 L
.82883 .34213 L
.84558 .40664 L
.84877 .47482 L
.83826 .54398 L
.81449 .61142 L
.77837 .67449 L
.73132 .7307 L
.6752 .77787 L
.6122 .81413 L
.5448 .83806 L
.47564 .84872 L
.40743 .8457 L
.34286 .82911 L
.28446 .7996 L
.23451 .75834 L
.19499 .70693 L
.16743 .64741 L
.15293 .5821 L
.15205 .51357 L
.16482 .4445 L
.19075 .37762 L
.22881 .31553 L
.27752 .26069 L
.33496 .21524 L
.39888 .18096 L
.46676 .15921 L
.53595 .15083 L
.60373 .15615 L
.66744 .17497 L
.72458 .20654 L
.7729 .24963 L
.81051 .30255 L
Mistroke
.83594 .36322 L
.84818 .42925 L
.84676 .49806 L
.83172 .56695 L
.80367 .63321 L
.76371 .69424 L
.71339 .74765 L
.6547 .79134 L
.58993 .82359 L
.52164 .84315 L
.4525 .84924 L
.38522 .84162 L
.32245 .82059 L
.26664 .78699 L
.21999 .74212 L
.18434 .68775 L
.16107 .62601 L
.1511 .55932 L
.15483 .49031 L
.1721 .42167 L
.20224 .35611 L
.24407 .2962 L
.29594 .24429 L
.35582 .20241 L
.42136 .17221 L
.48998 .15488 L
.559 .15109 L
.6257 .16099 L
.68747 .1842 L
.74188 .2198 L
.7868 .2664 L
.82047 .32217 L
.84155 .38491 L
.84923 .45218 L
.84321 .52132 L
.82372 .58962 L
.79152 .6544 L
.74788 .71313 L
.69451 .76349 L
.63351 .80351 L
.56727 .83162 L
.49839 .84672 L
.42957 .8482 L
.36352 .83603 L
.30282 .81066 L
.24986 .7731 L
.20672 .72482 L
.17509 .66772 L
.15621 .60404 L
.15082 .53628 L
Mistroke
.15914 .46709 L
Mfstroke
1 0 0 r
.56824 .83131 m
.49938 .8466 L
s
% Start of user PostScript
2.0472697 9.9392972 -0.018590108 10.397886 MAarrowhead1
% End of user PostScript
1 .158 0 r
.43054 .84828 m
.36443 .8363 L
s
% Start of user PostScript
-2.0837204 10.448399 -4.067073 10.088855 MAarrowhead1
% End of user PostScript
1 .473 0 r
.15892 .46808 m
.18043 .40014 L
s
% Start of user PostScript
-10.232347 -0.95771387 -9.587136 -2.9957725 MAarrowhead1
% End of user PostScript
1 .788 0 r
.58082 .15278 m
.64621 .16703 L
s
% Start of user PostScript
2.424533 -10.4165 4.3863954 -9.9890735 MAarrowhead1
% End of user PostScript
.897 1 0 r
.83839 .54349 m
.8147 .61095 L
s
% Start of user PostScript
10.151592 1.3046602 9.4410366 3.3284823 MAarrowhead1
% End of user PostScript
.581 1 0 r
.40791 .84577 m
.3433 .82927 L
s
% Start of user PostScript
-2.7626559 10.373045 -4.7008516 9.8782105 MAarrowhead1
% End of user PostScript
.266 1 0 r
.16468 .44499 m
.19052 .37808 L
s
% Start of user PostScript
-10.059575 -1.6501592 -9.2844636 -3.6574997 MAarrowhead1
% End of user PostScript
0 1 .049 r
.60326 .15606 m
.667 .17479 L
s
% Start of user PostScript
3.097714 -10.318083 5.0100927 -9.7563888 MAarrowhead1
% End of user PostScript
0 1 .364 r
.83188 .56646 m
.80392 .63275 L
s
% Start of user PostScript
9.9563982 1.9938275 9.1175905 3.9824594 MAarrowhead1
% End of user PostScript
0 1 .679 r
.38569 .84172 m
.32287 .82079 L
s
% Start of user PostScript
-3.4293356 10.251674 -5.3137758 9.6237435 MAarrowhead1
% End of user PostScript
0 1 .995 r
.17193 .42216 m
.20198 .35657 L
s
% Start of user PostScript
-9.842176 -2.3352838 -8.9406026 -4.3030011 MAarrowhead1
% End of user PostScript
0 .69 1 r
.62524 .16087 m
.68705 .18399 L
s
% Start of user PostScript
3.7571527 -10.173891 5.6115638 -9.4804218 MAarrowhead1
% End of user PostScript
0 .375 1 r
.8239 .58914 m
.79179 .65396 L
s
% Start of user PostScript
9.7170351 2.6741495 8.7536961 4.6187691 MAarrowhead1
% End of user PostScript
0 .06 1 r
.36397 .83616 m
.30323 .81089 L
s
% Start of user PostScript
-4.0808016 10.084823 -5.9031265 9.3265827 MAarrowhead1
% End of user PostScript
0 .258 1 r
.82762 .36526 m
.83983 .42965 L
.8387 .4968 L
.82427 .56408 L
.79712 .62884 L
.75831 .68855 L
.70937 .74086 L
.6522 .78371 L
.58906 .81543 L
.52243 .83477 L
.45492 .84098 L
.38917 .8338 L
.32778 .81352 L
.27314 .78093 L
.22741 .73732 L
.19238 .6844 L
.16941 .62424 L
.15943 .5592 L
.16281 .49184 L
.17942 .4248 L
.20861 .36071 L
.24924 .30209 L
.29971 .25124 L
.35804 .21015 L
.42195 .18043 L
.48891 .16325 L
.55631 .1593 L
.6215 .16871 L
.68193 .19112 L
.73521 .22566 L
.77926 .27096 L
.81235 .32526 L
.83319 .38641 L
.84094 .45201 L
.83532 .51951 L
.81654 .58623 L
.78533 .64957 L
.74292 .70705 L
.69099 .75639 L
.63155 .79568 L
.56696 .82335 L
.49973 .83834 L
.43252 .84005 L
.36795 .82842 L
.30857 .8039 L
.2567 .76744 L
.21438 .7205 L
.18327 .6649 L
.16458 .60282 L
.15907 .53672 L
Mistroke
.16693 .46917 L
.18786 .40283 L
.22105 .3403 L
.26518 .28405 L
.31853 .23626 L
.379 .19883 L
.44422 .17322 L
.51162 .16043 L
.57858 .16097 L
.64244 .17482 L
.70072 .20142 L
.75112 .23975 L
.79167 .28829 L
.82076 .34513 L
.83727 .40806 L
.84055 .47459 L
.83045 .54212 L
.80739 .608 L
.77227 .66964 L
.72646 .72462 L
.67176 .77079 L
.61032 .80633 L
.54455 .82984 L
.47703 .84041 L
.41042 .83762 L
.34732 .82159 L
.29021 .79293 L
.24134 .75277 L
.20261 .70269 L
.17556 .64466 L
.16124 .58095 L
.16022 .51407 L
.17253 .44663 L
.19769 .38129 L
.23472 .3206 L
.28216 .26696 L
.33815 .22246 L
.40049 .18886 L
.46673 .16746 L
.53428 .15912 L
.60049 .16415 L
.66275 .18237 L
.71863 .21305 L
.76592 .25499 L
.80278 .30655 L
.82775 .3657 L
.83987 .43012 L
.83864 .49729 L
.82412 .56456 L
.79689 .62929 L
Mistroke
.758 .68895 L
.70898 .7412 L
.65177 .78398 L
.5886 .81562 L
.52195 .83487 L
.45444 .84097 L
.38872 .8337 L
.32736 .81333 L
.27278 .78066 L
.22712 .73697 L
.19217 .68399 L
.1693 .62379 L
.1594 .55872 L
.16288 .49136 L
.17958 .42433 L
.20886 .36027 L
.24957 .3017 L
.3001 .25091 L
.35848 .20989 L
.42242 .18026 L
.4894 .16318 L
.55679 .15932 L
.62196 .16882 L
.68234 .19133 L
.73556 .22595 L
.77954 .27132 L
.81255 .32567 L
.83329 .38686 L
.84095 .45249 L
.83523 .51999 L
.81635 .5867 L
.78506 .65001 L
.74258 .70743 L
.69058 .75671 L
.63111 .79592 L
.56648 .82351 L
.49925 .8384 L
.43204 .84002 L
.36751 .82829 L
.30817 .80368 L
.25636 .76714 L
.21411 .72013 L
.18309 .66447 L
.1645 .60236 L
.15908 .53623 L
.16703 .46869 L
.18806 .40236 L
.22133 .33988 L
.26553 .28367 L
.31894 .23596 L
Mistroke
.37945 .19861 L
.44469 .17308 L
.51211 .16039 L
.57905 .16102 L
.64288 .17496 L
.70111 .20166 L
.75145 .24006 L
.79192 .28867 L
.82093 .34557 L
.83734 .40853 L
.84052 .47508 L
.83033 .54261 L
.80718 .60846 L
.77198 .67006 L
.72609 .72499 L
.67134 .77108 L
.60986 .80654 L
.54407 .82996 L
.47655 .84044 L
.40995 .83756 L
.34688 .82142 L
.28983 .79268 L
.24102 .75244 L
.20238 .7023 L
.17541 .64422 L
.16119 .58048 L
.16026 .51358 L
.17267 .44615 L
.19792 .38083 L
.23503 .32019 L
.28253 .26661 L
.33857 .22218 L
.40095 .18866 L
.46721 .16735 L
.53477 .15911 L
.60095 .16424 L
.66318 .18254 L
.719 .21331 L
.76622 .25533 L
.803 .30695 L
.82789 .36615 L
.8399 .4306 L
.83858 .49777 L
.82397 .56503 L
.79665 .62974 L
.75768 .68936 L
.7086 .74154 L
.65133 .78425 L
.58813 .8158 L
.52146 .83496 L
Mistroke
.45396 .84097 L
Mfstroke
1 0 0 r
.82762 .36526 m
.83983 .42965 L
s
% Start of user PostScript
9.8285711 -4.0423478 10.194775 -2.110582 MAarrowhead1
% End of user PostScript
1 .158 0 r
.8387 .4968 m
.82427 .56408 L
s
% Start of user PostScript
10.160874 -0.095984481 9.7282007 1.9223801 MAarrowhead1
% End of user PostScript
1 .473 0 r
.45492 .84098 m
.38917 .8338 L
s
% Start of user PostScript
-1.3524585 10.229286 -3.3247868 10.013894 MAarrowhead1
% End of user PostScript
1 .788 0 r
.16281 .49184 m
.17942 .4248 L
s
% Start of user PostScript
-10.115828 -0.24472622 -9.6174608 -2.2559166 MAarrowhead1
% End of user PostScript
.897 1 0 r
.55631 .1593 m
.6215 .16871 L
s
% Start of user PostScript
1.6893902 -10.221135 3.6451193 -9.938755 MAarrowhead1
% End of user PostScript
.581 1 0 r
.83532 .51951 m
.81654 .58623 L
s
% Start of user PostScript
10.059558 0.58516543 9.4960514 2.5869505 MAarrowhead1
% End of user PostScript
.266 1 0 r
.43252 .84005 m
.36795 .82842 L
s
% Start of user PostScript
-2.0244478 10.201644 -3.9614078 9.8525905 MAarrowhead1
% End of user PostScript
0 1 .049 r
.16693 .46917 m
.18786 .40283 L
s
% Start of user PostScript
-9.9921293 -0.92495547 -9.3641073 -2.9151145 MAarrowhead1
% End of user PostScript
0 1 .364 r
.57858 .16097 m
.64244 .17482 L
s
% Start of user PostScript
2.3572594 -10.170836 4.2733017 -9.7554957 MAarrowhead1
% End of user PostScript
0 1 .679 r
.83045 .54212 m
.80739 .608 L
s
% Start of user PostScript
9.9136152 1.2637194 9.2217748 3.2400445 MAarrowhead1
% End of user PostScript
0 1 .995 r
.41042 .83762 m
.34732 .82159 L
s
% Start of user PostScript
-2.6874559 10.128745 -4.5804549 9.6475783 MAarrowhead1
% End of user PostScript
0 .69 1 r
.17253 .44663 m
.19769 .38129 L
s
% Start of user PostScript
-9.824103 -1.6010813 -9.0692119 -3.5613801 MAarrowhead1
% End of user PostScript
0 .375 1 r
.60049 .16415 m
.66275 .18237 L
s
% Start of user PostScript
3.0146711 -10.075417 4.8825266 -9.528958 MAarrowhead1
% End of user PostScript
0 .06 1 r
.82412 .56456 m
.79689 .62929 L
s
% Start of user PostScript
9.7236922 1.9366671 8.9065877 3.8787647 MAarrowhead1
% End of user PostScript
1 .727 0 r
.2354 .23501 m
.29982 .18105 L
.37209 .13961 L
.44938 .11232 L
.52866 .10024 L
.60681 .10385 L
.68077 .12301 L
.74764 .15696 L
.80479 .20438 L
.84998 .26339 L
.88143 .3317 L
.89791 .40661 L
.89878 .48518 L
.88399 .56434 L
.85414 .64097 L
.81038 .71206 L
.75445 .77484 L
.68853 .82683 L
.61521 .86599 L
.53737 .89079 L
.45806 .90025 L
.3804 .89401 L
.30743 .8723 L
.24202 .83597 L
.18673 .78647 L
.14374 .72572 L
.11473 .65611 L
.10085 .58038 L
.10262 .50149 L
.11999 .42254 L
.15228 .34663 L
.19821 .27674 L
.25599 .21562 L
.32334 .16565 L
.39762 .12881 L
.47593 .10653 L
.55518 .0997 L
.63226 .10857 L
.70415 .13281 L
.76803 .17146 L
.82139 .223 L
.86214 .28542 L
.88868 .35625 L
.89996 .43273 L
.89554 .51185 L
.8756 .5905 L
.84092 .6656 L
.79286 .7342 L
.73331 .79361 L
.6646 .84149 L
Mistroke
.58943 .87598 L
.51075 .89571 L
.43165 .89991 L
.35523 .88841 L
.28449 .86167 L
.22221 .82074 L
.17084 .76722 L
.13238 .70321 L
.10835 .63123 L
.09969 .55409 L
.10674 .47484 L
.12922 .39657 L
.16626 .32236 L
.21639 .25512 L
.27765 .19749 L
.34765 .15174 L
.42362 .11965 L
.50258 .10249 L
.58145 .10093 L
.65712 .11503 L
.72662 .14424 L
.78723 .18742 L
.83657 .24286 L
.8727 .30839 L
.8942 .38144 L
.90023 .45915 L
.89055 .53846 L
.86555 .61626 L
.8262 .68949 L
.77404 .75529 L
.71114 .81107 L
.63994 .85465 L
.56326 .8843 L
.48409 .89887 L
.40554 .89779 L
.33071 .88109 L
.26251 .84944 L
.20364 .80408 L
.1564 .74678 L
.12264 .6798 L
.1037 .60576 L
.1003 .52757 L
.11259 .44829 L
.14009 .37105 L
.18171 .29887 L
.23583 .23458 L
.30031 .18071 L
.37263 .13937 L
.44994 .11218 L
.52923 .10021 L
Mistroke
.60736 .10393 L
.68128 .1232 L
.74809 .15726 L
.80516 .20476 L
.85025 .26385 L
.8816 .33222 L
.89797 .40716 L
.89872 .48575 L
.88383 .5649 L
.85387 .6415 L
.81002 .71255 L
.75401 .77525 L
.68802 .82716 L
.61466 .86622 L
.5368 .89091 L
.45749 .90026 L
.37985 .8939 L
.30693 .87209 L
.24159 .83566 L
.18638 .78607 L
.14348 .72525 L
.11458 .65559 L
.1008 .57982 L
.10269 .50092 L
.12017 .42198 L
.15256 .34611 L
.19858 .27627 L
.25644 .21522 L
.32385 .16534 L
.39818 .1286 L
.4765 .10643 L
.55574 .09971 L
.6328 .10869 L
.70464 .13304 L
.76845 .17179 L
.82173 .22341 L
.86238 .2859 L
.88881 .35678 L
.89998 .43329 L
.89545 .51241 L
.8754 .59105 L
.84062 .66612 L
.79247 .73466 L
.73285 .79399 L
.66408 .84179 L
.58887 .87617 L
.51018 .89579 L
.43109 .89988 L
.3547 .88827 L
.28401 .86143 L
Mistroke
.2218 .8204 L
.17051 .76679 L
.13215 .70272 L
.10823 .63069 L
.09968 .55353 L
.10684 .47427 L
.12944 .39602 L
.16657 .32185 L
.21679 .25467 L
.27813 .19712 L
.34817 .15146 L
.42417 .11947 L
.50315 .10242 L
.58201 .10098 L
.65764 .11519 L
.72709 .14451 L
.78763 .18777 L
.83688 .2433 L
.8729 .30889 L
.8943 .38199 L
.90021 .45971 L
.89043 .53902 L
.86531 .6168 L
.82587 .68999 L
.77363 .75573 L
.71065 .81143 L
.63941 .85491 L
.56269 .88446 L
.48352 .89892 L
.40499 .89772 L
.33019 .88092 L
.26205 .84917 L
.20326 .80371 L
.15611 .74633 L
.12245 .67929 L
.10362 .60521 L
.10033 .527 L
.11274 .44773 L
.14034 .37051 L
.18206 .29838 L
.23626 .23415 L
.3008 .18036 L
.37317 .13912 L
.45051 .11204 L
.52979 .10018 L
.60791 .10402 L
.68179 .12339 L
.74854 .15755 L
.80553 .20515 L
.85053 .26431 L
Mistroke
.88177 .33273 L
Mfstroke
1 0 0 r
.2354 .23501 m
.29982 .18105 L
s
% Start of user PostScript
-7.9379867 -7.9498168 -6.0055201 -9.5684606 MAarrowhead1
% End of user PostScript
1 .158 0 r
.37209 .13961 m
.44938 .11232 L
s
% Start of user PostScript
-3.8373609 -10.811581 -1.5186009 -11.63039 MAarrowhead1
% End of user PostScript
1 .473 0 r
.88143 .3317 m
.89791 .40661 L
s
% Start of user PostScript
11.442839 -5.0490495 11.937295 -2.8017929 MAarrowhead1
% End of user PostScript
1 .788 0 r
.61521 .86599 m
.53737 .89079 L
s
% Start of user PostScript
3.45623 10.979752 1.1210008 11.723711 MAarrowhead1
% End of user PostScript
.897 1 0 r
.11473 .65611 m
.10085 .58038 L
s
% Start of user PostScript
-11.557957 4.6833427 -11.974633 2.4113068 MAarrowhead1
% End of user PostScript
.581 1 0 r
.39762 .12881 m
.47593 .10653 L
s
% Start of user PostScript
-3.0712647 -11.135741 -0.7221572 -11.804025 MAarrowhead1
% End of user PostScript
.266 1 0 r
.88868 .35625 m
.89996 .43273 L
s
% Start of user PostScript
11.660253 -4.3124403 11.998686 -2.0181456 MAarrowhead1
% End of user PostScript
0 1 .049 r
.58943 .87598 m
.51075 .89571 L
s
% Start of user PostScript
2.6828922 11.279378 0.3225124 11.871244 MAarrowhead1
% End of user PostScript
0 1 .364 r
.10835 .63123 m
.09969 .55409 L
s
% Start of user PostScript
-11.749613 3.9367538 -12.009428 1.6227456 MAarrowhead1
% End of user PostScript
0 1 .679 r
.42362 .11965 m
.50258 .10249 L
s
% Start of user PostScript
-2.2915434 -11.4105 0.077490183 -11.925293 MAarrowhead1
% End of user PostScript
0 1 .995 r
.8942 .38144 m
.90023 .45915 L
s
% Start of user PostScript
11.825938 -3.5566999 12.006847 -1.2255453 MAarrowhead1
% End of user PostScript
0 .69 1 r
.56326 .8843 m
.48409 .89887 L
s
% Start of user PostScript
1.8976523 11.528965 -0.4774068 11.966113 MAarrowhead1
% End of user PostScript
0 .375 1 r
.1037 .60576 m
.1003 .52757 L
s
% Start of user PostScript
-11.889144 3.1727003 -11.990946 0.82698544 MAarrowhead1
% End of user PostScript
0 .06 1 r
.44994 .11218 m
.52923 .10021 L
s
% Start of user PostScript
-1.5016561 -11.634639 0.87679379 -11.993658 MAarrowhead1
% End of user PostScript
1 .547 0 r
.71583 .65386 m
.67567 .69754 L
.62861 .73348 L
.5765 .76025 L
.52139 .7768 L
.46544 .7825 L
.41085 .7771 L
.35976 .76083 L
.31417 .73433 L
.27587 .69863 L
.24637 .65513 L
.22682 .60554 L
.218 .55182 L
.22024 .49606 L
.23346 .44045 L
.25714 .38718 L
.29036 .33834 L
.3318 .29584 L
.37984 .26136 L
.4326 .23624 L
.488 .22147 L
.54388 .21764 L
.59803 .22488 L
.64833 .24292 L
.69282 .27106 L
.72973 .30817 L
.75763 .35282 L
.77542 .40324 L
.7824 .45746 L
.7783 .51335 L
.76327 .56871 L
.73792 .62138 L
.70322 .66929 L
.66055 .71055 L
.61158 .74354 L
.55823 .76698 L
.50259 .77994 L
.44685 .78192 L
.3932 .77283 L
.34374 .75303 L
.30041 .7233 L
.26492 .68481 L
.23865 .63907 L
.22264 .58787 L
.21751 .53321 L
.22347 .47726 L
.24028 .4222 L
.26729 .37019 L
.30343 .32328 L
.34728 .2833 L
Mistroke
.39713 .25182 L
.45101 .23009 L
.50682 .21895 L
.56236 .21884 L
.61545 .22976 L
.66401 .25129 L
.70613 .28258 L
.74017 .3224 L
.76478 .3692 L
.77899 .42112 L
.78226 .47615 L
.77445 .5321 L
.75587 .5868 L
.72725 .63809 L
.68971 .68397 L
.64472 .72262 L
.59405 .75253 L
.5397 .77254 L
.48378 .78185 L
.4285 .78009 L
.37603 .76735 L
.32842 .74411 L
.28755 .71129 L
.25501 .67018 L
.23209 .62239 L
.21968 .5698 L
.21828 .51447 L
.22793 .45857 L
.24826 .40429 L
.27847 .35378 L
.31737 .309 L
.36344 .27171 L
.41487 .24339 L
.46964 .22514 L
.5256 .21767 L
.58056 .22129 L
.63236 .23584 L
.67896 .26076 L
.71853 .29507 L
.74954 .33742 L
.77074 .38616 L
.78133 .43936 L
.78087 .49494 L
.76939 .55072 L
.74733 .60451 L
.71557 .65419 L
.67535 .69783 L
.62825 .7337 L
.57611 .7604 L
.52099 .77688 L
Mistroke
.46504 .7825 L
.41047 .77702 L
.35941 .76068 L
.31386 .7341 L
.27562 .69834 L
.24619 .65479 L
.22672 .60517 L
.21797 .55142 L
.2203 .49565 L
.23359 .44006 L
.25735 .38681 L
.29063 .33801 L
.33212 .29556 L
.3802 .26114 L
.43299 .2361 L
.4884 .22141 L
.54427 .21765 L
.59841 .22497 L
.64868 .24309 L
.69311 .27129 L
.72997 .30847 L
.7578 .35316 L
.77551 .40362 L
.78241 .45786 L
.77823 .51375 L
.76313 .5691 L
.7377 .62175 L
.70294 .66961 L
.66022 .71082 L
.61121 .74375 L
.55783 .76711 L
.50219 .78 L
.44646 .78189 L
.39283 .77273 L
.34341 .75285 L
.30013 .72306 L
.2647 .68451 L
.2385 .63872 L
.22256 .58748 L
.21751 .53282 L
.22355 .47686 L
.24044 .42181 L
.26752 .36983 L
.30372 .32296 L
.34762 .28304 L
.3975 .25163 L
.45141 .22997 L
.50722 .21891 L
.56275 .21888 L
.61581 .22988 L
Mistroke
.66434 .25148 L
.70641 .28284 L
.74038 .32272 L
.76492 .36955 L
.77906 .42151 L
.78224 .47655 L
.77436 .5325 L
.7557 .58718 L
.72701 .63844 L
.68941 .68427 L
.64438 .72287 L
.59368 .75271 L
.5393 .77264 L
.48338 .78187 L
.42811 .78004 L
.37567 .76722 L
.3281 .74391 L
.28728 .71102 L
.25481 .66986 L
.23196 .62203 L
.21963 .56941 L
.21831 .51406 L
.22804 .45817 L
.24844 .40391 L
.27872 .35343 L
.31768 .3087 L
.36379 .27148 L
.41525 .24322 L
.47004 .22505 L
.526 .21766 L
.58094 .22135 L
.63271 .23598 L
.67927 .26098 L
.71879 .29535 L
.74972 .33775 L
.77086 .38652 L
.78136 .43975 L
.78083 .49534 L
.76927 .55111 L
.74714 .60488 L
.71531 .65453 L
.67504 .69812 L
.62789 .73393 L
.57573 .76056 L
.52059 .77696 L
.46464 .7825 L
.41009 .77694 L
.35906 .76052 L
.31356 .73388 L
.27538 .69805 L
Mistroke
.24602 .65446 L
Mfstroke
1 0 0 r
.71583 .65386 m
.67567 .69754 L
s
% Start of user PostScript
6.4749736 4.6156976 5.2700078 5.9262735 MAarrowhead1
% End of user PostScript
1 .158 0 r
.62861 .73348 m
.5765 .76025 L
s
% Start of user PostScript
3.8582155 7.0042671 2.2950037 7.8073714 MAarrowhead1
% End of user PostScript
1 .473 0 r
.24637 .65513 m
.22682 .60554 L
s
% Start of user PostScript
-7.6089342 4.6538618 -8.1953229 3.1663039 MAarrowhead1
% End of user PostScript
1 .788 0 r
.37984 .26136 m
.4326 .23624 L
s
% Start of user PostScript
-3.6047818 -7.159275 -2.022039 -7.9128327 MAarrowhead1
% End of user PostScript
.897 1 0 r
.75763 .35282 m
.77542 .40324 L
s
% Start of user PostScript
7.729 -4.4154051 8.2626717 -2.9027482 MAarrowhead1
% End of user PostScript
.581 1 0 r
.61158 .74354 m
.55823 .76698 L
s
% Start of user PostScript
3.3473491 7.3063406 1.7468311 8.0095156 MAarrowhead1
% End of user PostScript
.266 1 0 r
.23865 .63907 m
.22264 .58787 L
s
% Start of user PostScript
-7.8404914 4.1720501 -8.3208541 2.6359722 MAarrowhead1
% End of user PostScript
0 1 .049 r
.39713 .25182 m
.45101 .23009 L
s
% Start of user PostScript
-3.0862029 -7.4453006 -1.4696852 -8.0973129 MAarrowhead1
% End of user PostScript
0 1 .364 r
.76478 .3692 m
.77899 .42112 L
s
% Start of user PostScript
7.9432848 -3.9240666 8.3698054 -2.3662719 MAarrowhead1
% End of user PostScript
0 1 .679 r
.59405 .75253 m
.5397 .77254 L
s
% Start of user PostScript
2.8216328 7.576001 1.1909089 8.1761273 MAarrowhead1
% End of user PostScript
0 1 .995 r
.23209 .62239 m
.21968 .5698 L
s
% Start of user PostScript
-8.037266 3.6717299 -8.4094715 2.0939466 MAarrowhead1
% End of user PostScript
0 .69 1 r
.41487 .24339 m
.46964 .22514 L
s
% Start of user PostScript
-2.5539326 -7.6982967 -0.91081146 -8.2458711 MAarrowhead1
% End of user PostScript
0 .375 1 r
.77074 .38616 m
.78133 .43936 L
s
% Start of user PostScript
8.1223308 -3.4153198 8.4398082 -1.8192982 MAarrowhead1
% End of user PostScript
0 .06 1 r
.57611 .7604 m
.52099 .77688 L
s
% Start of user PostScript
2.283399 7.8120521 0.62970356 8.3064672 MAarrowhead1
% End of user PostScript
.114 1 0 r
.4055 .4242 m
.42476 .40503 L
.44698 .38958 L
.47128 .37847 L
.4967 .37213 L
.52225 .37081 L
.54693 .37456 L
.56977 .38323 L
.58987 .39648 L
.60644 .4138 L
.61884 .4345 L
.62657 .45777 L
.62933 .48269 L
.62702 .5083 L
.61972 .53358 L
.60773 .55755 L
.5915 .57925 L
.57169 .59784 L
.54906 .6126 L
.52451 .62293 L
.49899 .62844 L
.47352 .62891 L
.44908 .62432 L
.42664 .61486 L
.40708 .60088 L
.39117 .58294 L
.37953 .56175 L
.37262 .53814 L
.3707 .51303 L
.37386 .4874 L
.38197 .46228 L
.39472 .43863 L
.41159 .41739 L
.43193 .39939 L
.45495 .38534 L
.47973 .3758 L
.50531 .37112 L
.53068 .37151 L
.55485 .37693 L
.57686 .38719 L
.59586 .40187 L
.6111 .42041 L
.62197 .44207 L
.62806 .466 L
.62912 .49127 L
.62512 .51688 L
.6162 .54182 L
.60272 .56513 L
.58522 .58588 L
.56437 .60326 L
Mistroke
.54099 .61658 L
.516 .62534 L
.49039 .62917 L
.46515 .62793 L
.44128 .62167 L
.41971 .61064 L
.4013 .59527 L
.38676 .57615 L
.37666 .55405 L
.37141 .52983 L
.3712 .50443 L
.37604 .47886 L
.38576 .45412 L
.39995 .43119 L
.41807 .41095 L
.43941 .39421 L
.46312 .38161 L
.48828 .37367 L
.5139 .37068 L
.53898 .37277 L
.56253 .37985 L
.58362 .39165 L
.60143 .4077 L
.61526 .42737 L
.62456 .44989 L
.62898 .47438 L
.62834 .49988 L
.62266 .52537 L
.61216 .54988 L
.59727 .57242 L
.57855 .59213 L
.55675 .60821 L
.53273 .62005 L
.50742 .62718 L
.48182 .62932 L
.45694 .62638 L
.43374 .61849 L
.41314 .60594 L
.39596 .58923 L
.38285 .56902 L
.37435 .54611 L
.37077 .52138 L
.37227 .49582 L
.37878 .47042 L
.39004 .44618 L
.40563 .42405 L
.42491 .4049 L
.44715 .38949 L
.47145 .37841 L
.49688 .3721 L
Mistroke
.52243 .37082 L
.5471 .3746 L
.56992 .38331 L
.59 .39659 L
.60655 .41394 L
.61891 .43466 L
.62661 .45794 L
.62933 .48288 L
.62699 .50849 L
.61965 .53376 L
.60763 .55771 L
.59137 .5794 L
.57154 .59796 L
.54889 .61269 L
.52433 .62299 L
.49881 .62847 L
.47334 .6289 L
.44891 .62427 L
.42649 .61477 L
.40696 .60076 L
.39107 .5828 L
.37946 .56159 L
.37258 .53796 L
.37071 .51284 L
.3739 .48722 L
.38205 .4621 L
.39482 .43847 L
.41172 .41725 L
.43209 .39928 L
.45512 .38526 L
.47992 .37574 L
.5055 .37111 L
.53086 .37153 L
.55502 .37699 L
.57701 .38728 L
.59598 .40199 L
.61119 .42055 L
.62203 .44223 L
.62808 .46618 L
.62911 .49145 L
.62507 .51706 L
.61612 .542 L
.60261 .56529 L
.58508 .58602 L
.56421 .60337 L
.54081 .61666 L
.51582 .62538 L
.4902 .62918 L
.46497 .62791 L
.44112 .62161 L
Mistroke
.41957 .61055 L
.40118 .59514 L
.38667 .576 L
.37661 .55388 L
.37139 .52965 L
.37122 .50425 L
.3761 .47868 L
.38584 .45395 L
.40007 .43103 L
.41821 .41082 L
.43957 .3941 L
.4633 .38154 L
.48847 .37363 L
.51409 .37068 L
.53915 .3728 L
.56269 .37992 L
.58376 .39175 L
.60154 .40783 L
.61534 .42752 L
.62461 .45006 L
.629 .47456 L
.62831 .50006 L
.6226 .52555 L
.61207 .55005 L
.59714 .57257 L
.57841 .59225 L
.55659 .60831 L
.53255 .62012 L
.50724 .62722 L
.48164 .62932 L
.45676 .62634 L
.43358 .61841 L
.41301 .60583 L
.39585 .5891 L
.38277 .56887 L
.3743 .54594 L
.37076 .5212 L
.3723 .49563 L
.37884 .47024 L
.39014 .44601 L
.40575 .4239 L
.42506 .40478 L
.44732 .38939 L
.47163 .37835 L
.49707 .37208 L
.52261 .37083 L
.54727 .37465 L
.57008 .38339 L
.59013 .3967 L
.60665 .41407 L
Mistroke
.61898 .43481 L
Mfstroke
1 0 0 r
.4055 .4242 m
.42476 .40503 L
s
% Start of user PostScript
-2.8349453 -2.2740597 -2.2570726 -2.8491905 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44698 .38958 m
.47128 .37847 L
s
% Start of user PostScript
-1.590619 -3.312502 -0.86173999 -3.6458112 MAarrowhead1
% End of user PostScript
1 .473 0 r
.61884 .4345 m
.62657 .45777 L
s
% Start of user PostScript
3.5650862 -1.9650837 3.7970278 -1.2669809 MAarrowhead1
% End of user PostScript
1 .788 0 r
.54906 .6126 m
.52451 .62293 L
s
% Start of user PostScript
1.4718753 3.3779538 0.73527094 3.688011 MAarrowhead1
% End of user PostScript
.897 1 0 r
.37953 .56175 m
.37262 .53814 L
s
% Start of user PostScript
-3.6141106 1.8525729 -3.8215178 1.144143 MAarrowhead1
% End of user PostScript
.581 1 0 r
.45495 .38534 m
.47973 .3758 L
s
% Start of user PostScript
-1.3514988 -3.4396582 -0.6079862 -3.7261194 MAarrowhead1
% End of user PostScript
.266 1 0 r
.62197 .44207 m
.62806 .466 L
s
% Start of user PostScript
3.6591254 -1.7380069 3.8417682 -1.0200357 MAarrowhead1
% End of user PostScript
0 1 .049 r
.54099 .61658 m
.516 .62534 L
s
% Start of user PostScript
1.2296229 3.4975466 0.48002697 3.7600942 MAarrowhead1
% End of user PostScript
0 1 .364 r
.37666 .55405 m
.37141 .52983 L
s
% Start of user PostScript
-3.700081 1.6215128 -3.8577567 0.8947968 MAarrowhead1
% End of user PostScript
0 1 .679 r
.46312 .38161 m
.48828 .37367 L
s
% Start of user PostScript
-1.1063829 -3.551555 -0.3515352 -3.7898975 MAarrowhead1
% End of user PostScript
0 1 .995 r
.62456 .44989 m
.62898 .47438 L
s
% Start of user PostScript
3.7369317 -1.5032198 3.8694654 -0.76856525 MAarrowhead1
% End of user PostScript
0 .69 1 r
.53273 .62005 m
.50742 .62718 L
s
% Start of user PostScript
0.98191549 3.6016233 0.22265345 3.8154964 MAarrowhead1
% End of user PostScript
0 .375 1 r
.37435 .54611 m
.37077 .52138 L
s
% Start of user PostScript
-3.7696367 1.3832592 -3.8768814 0.64148106 MAarrowhead1
% End of user PostScript
0 .06 1 r
.47145 .37841 m
.49688 .3721 L
s
% Start of user PostScript
-0.85635877 -3.647696 -0.093524686 -3.8368624 MAarrowhead1
% End of user PostScript
1 .12 0 r
.57564 .30635 m
.61075 .32037 L
.64152 .34144 L
.66673 .36873 L
.6854 .40117 L
.69679 .43749 L
.70046 .47627 L
.69626 .51598 L
.68436 .55505 L
.66523 .59197 L
.63961 .62528 L
.60851 .65367 L
.57315 .67603 L
.53492 .69149 L
.49532 .69942 L
.45591 .69953 L
.41822 .69181 L
.38375 .67657 L
.35383 .65439 L
.32966 .62615 L
.31217 .59296 L
.30205 .55613 L
.2997 .51709 L
.30521 .47738 L
.31836 .43856 L
.33864 .40215 L
.36526 .36958 L
.39716 .34213 L
.4331 .32087 L
.47167 .30664 L
.51135 .30001 L
.55058 .30122 L
.58783 .31023 L
.62163 .32669 L
.65065 .34996 L
.67377 .37911 L
.69006 .413 L
.6989 .45031 L
.69993 .48957 L
.69311 .52924 L
.67871 .56776 L
.65731 .60363 L
.62972 .63542 L
.59705 .6619 L
.56056 .68203 L
.52171 .69501 L
.48199 .70034 L
.44299 .69781 L
.40622 .68751 L
.37313 .66985 L
Mistroke
.34503 .64553 L
.323 .6155 L
.30792 .58093 L
.30038 .54319 L
.30067 .50375 L
.30879 .46417 L
.32441 .42599 L
.34692 .39072 L
.37544 .35973 L
.40885 .33425 L
.44583 .31528 L
.48494 .30355 L
.52465 .29954 L
.56338 .30339 L
.59963 .31496 L
.63196 .33379 L
.65912 .35914 L
.68004 .39002 L
.69388 .42522 L
.70012 .46335 L
.69851 .50292 L
.6891 .54238 L
.67227 .58017 L
.64868 .61482 L
.61926 .64496 L
.58516 .66941 L
.54771 .68721 L
.50839 .69767 L
.46874 .70037 L
.43032 .6952 L
.39463 .68237 L
.36308 .66239 L
.33691 .63603 L
.31713 .60434 L
.30453 .56855 L
.2996 .53006 L
.30253 .4904 L
.31322 .45112 L
.33124 .41375 L
.35588 .37977 L
.38617 .35051 L
.42094 .32711 L
.4588 .3105 L
.49828 .30133 L
.53783 .29995 L
.5759 .30643 L
.61099 .3205 L
.64172 .34161 L
.66689 .36895 L
.68551 .40142 L
Mistroke
.69684 .43777 L
.70046 .47655 L
.69621 .51626 L
.68425 .55533 L
.66507 .59223 L
.6394 .6255 L
.60827 .65386 L
.57289 .67617 L
.53464 .69157 L
.49504 .69945 L
.45563 .69951 L
.41796 .69173 L
.38352 .67643 L
.35364 .65421 L
.32951 .62593 L
.31207 .59271 L
.302 .55585 L
.29971 .5168 L
.30527 .4771 L
.31848 .43829 L
.33881 .4019 L
.36547 .36936 L
.39741 .34195 L
.43337 .32074 L
.47195 .30657 L
.51163 .29999 L
.55086 .30126 L
.58808 .31033 L
.62185 .32684 L
.65084 .35015 L
.67391 .37934 L
.69015 .41326 L
.69893 .45059 L
.69991 .48986 L
.69303 .52952 L
.67859 .56803 L
.65713 .60387 L
.6295 .63563 L
.5968 .66207 L
.56029 .68215 L
.52142 .69508 L
.48171 .70035 L
.44272 .69776 L
.40597 .68741 L
.37291 .6697 L
.34485 .64534 L
.32287 .61527 L
.30784 .58067 L
.30035 .54291 L
.3007 .50347 L
Mistroke
.30887 .46389 L
.32455 .42573 L
.3471 .39048 L
.37566 .35953 L
.4091 .33409 L
.44611 .31517 L
.48523 .30349 L
.52493 .29953 L
.56365 .30344 L
.59987 .31506 L
.63218 .33394 L
.6593 .35934 L
.68016 .39026 L
.69396 .42548 L
.70014 .46363 L
.69847 .50321 L
.68901 .54266 L
.67213 .58043 L
.64849 .61505 L
.61903 .64516 L
.5849 .66956 L
.54743 .68732 L
.50811 .69772 L
.46846 .70036 L
.43005 .69514 L
.39439 .68226 L
.36288 .66222 L
.33674 .63582 L
.31701 .60409 L
.30446 .56828 L
.29959 .52978 L
.30258 .49012 L
.31332 .45084 L
.33139 .4135 L
.35607 .37954 L
.38641 .35032 L
.4212 .32697 L
.45908 .31041 L
.49857 .30129 L
.53811 .29997 L
.57616 .3065 L
.61122 .32063 L
.64192 .34179 L
.66704 .36916 L
.68561 .40167 L
.6969 .43804 L
.70046 .47684 L
.69615 .51654 L
.68414 .5556 L
.6649 .59248 L
Mistroke
.6392 .62573 L
Mfstroke
1 0 0 r
.57564 .30635 m
.61075 .32037 L
s
% Start of user PostScript
2.2690721 -5.8094173 3.3224645 -5.3888613 MAarrowhead1
% End of user PostScript
1 .158 0 r
.64152 .34144 m
.66673 .36873 L
s
% Start of user PostScript
4.2454635 -4.7568142 5.0018452 -3.9380813 MAarrowhead1
% End of user PostScript
1 .473 0 r
.63961 .62528 m
.60851 .65367 L
s
% Start of user PostScript
4.1882465 3.7584309 3.2552773 4.6101877 MAarrowhead1
% End of user PostScript
1 .788 0 r
.35383 .65439 m
.32966 .62615 L
s
% Start of user PostScript
-4.384963 4.6316307 -5.1102699 3.784528 MAarrowhead1
% End of user PostScript
.897 1 0 r
.36526 .36958 m
.39716 .34213 L
s
% Start of user PostScript
-4.0421949 -3.9126984 -3.0850676 -4.7362404 MAarrowhead1
% End of user PostScript
.581 1 0 r
.65065 .34996 m
.67377 .37911 L
s
% Start of user PostScript
4.5195979 -4.5013089 5.2130255 -3.6267762 MAarrowhead1
% End of user PostScript
.266 1 0 r
.62972 .63542 m
.59705 .6619 L
s
% Start of user PostScript
3.891659 4.0626252 2.9114354 4.8570388 MAarrowhead1
% End of user PostScript
0 1 .049 r
.34503 .64553 m
.323 .6155 L
s
% Start of user PostScript
-4.6492189 4.3659935 -5.3099977 3.465001 MAarrowhead1
% End of user PostScript
0 1 .364 r
.37544 .35973 m
.40885 .33425 L
s
% Start of user PostScript
-3.7368057 -4.208045 -2.7345733 -4.9724489 MAarrowhead1
% End of user PostScript
0 1 .679 r
.65912 .35914 m
.68004 .39002 L
s
% Start of user PostScript
4.7736821 -4.2258346 5.4010792 -3.2993817 MAarrowhead1
% End of user PostScript
0 1 .995 r
.61926 .64496 m
.58516 .66941 L
s
% Start of user PostScript
3.5778068 4.3487965 2.5546775 5.0823427 MAarrowhead1
% End of user PostScript
0 .69 1 r
.33691 .63603 m
.31713 .60434 L
s
% Start of user PostScript
-4.8928495 4.0809876 -5.4861688 3.1301022 MAarrowhead1
% End of user PostScript
0 .375 1 r
.38617 .35051 m
.42094 .32711 L
s
% Start of user PostScript
-3.4148388 -4.4847235 -2.3719476 -5.1865982 MAarrowhead1
% End of user PostScript
0 .06 1 r
.66689 .36895 m
.68551 .40142 L
s
% Start of user PostScript
5.0065888 -3.9316132 5.5651722 -2.9573502 MAarrowhead1
% End of user PostScript
1 .005 0 r
.30495 .54386 m
.30491 .50533 L
.31252 .46659 L
.32749 .42917 L
.34924 .39453 L
.3769 .36402 L
.40939 .33885 L
.44543 .32001 L
.48362 .30823 L
.52245 .30397 L
.5604 .30741 L
.59598 .31841 L
.6278 .33654 L
.65459 .36108 L
.67532 .39107 L
.68917 .42533 L
.6956 .46253 L
.69435 .5012 L
.68547 .53982 L
.66931 .57688 L
.64651 .61092 L
.61795 .64061 L
.58477 .66478 L
.54826 .68248 L
.50986 .69302 L
.47107 .69599 L
.43342 .69126 L
.39838 .67903 L
.36732 .65977 L
.34148 .63424 L
.32185 .60344 L
.30922 .56859 L
.30407 .53104 L
.30662 .49227 L
.31675 .45381 L
.33408 .41716 L
.35791 .38376 L
.38733 .35492 L
.42116 .33178 L
.45809 .31524 L
.49666 .30595 L
.53537 .30427 L
.57269 .31028 L
.60715 .32373 L
.63741 .3441 L
.66227 .37059 L
.68077 .40216 L
.69218 .43757 L
.69604 .47542 L
.6922 .51425 L
Mistroke
.68083 .55251 L
.66236 .58871 L
.63751 .62143 L
.60727 .64939 L
.57282 .67148 L
.53551 .68684 L
.49681 .69487 L
.45823 .69525 L
.42129 .68797 L
.38744 .67331 L
.35801 .65185 L
.33415 .62443 L
.3168 .59213 L
.30664 .55621 L
.30407 .51809 L
.30919 .47925 L
.32179 .44123 L
.34139 .40552 L
.36722 .37351 L
.39825 .34647 L
.43328 .32545 L
.47093 .31129 L
.50972 .30453 L
.54813 .30544 L
.58464 .31399 L
.61784 .32983 L
.64641 .35236 L
.66924 .38068 L
.68542 .41368 L
.69433 .45008 L
.69561 .48843 L
.68921 .52723 L
.67539 .56497 L
.65468 .60015 L
.6279 .63141 L
.59611 .65751 L
.56054 .67742 L
.5226 .69038 L
.48377 .69586 L
.44557 .69366 L
.40951 .68385 L
.37701 .66683 L
.34933 .64326 L
.32756 .61407 L
.31256 .58041 L
.30492 .54358 L
.30493 .50505 L
.3126 .46632 L
.32763 .42891 L
.34942 .39429 L
Mistroke
.37711 .36382 L
.40963 .33869 L
.4457 .3199 L
.4839 .30817 L
.52273 .30397 L
.56067 .30747 L
.59623 .31852 L
.62801 .33669 L
.65476 .36127 L
.67545 .3913 L
.68924 .42559 L
.69562 .46281 L
.69431 .50148 L
.68538 .54009 L
.66917 .57713 L
.64632 .61115 L
.61773 .6408 L
.58452 .66493 L
.54799 .68258 L
.50958 .69307 L
.4708 .69598 L
.43316 .6912 L
.39814 .67891 L
.36712 .65961 L
.34131 .63404 L
.32174 .60321 L
.30916 .56833 L
.30407 .53076 L
.30666 .49199 L
.31685 .45354 L
.33422 .41691 L
.3581 .38354 L
.38755 .35473 L
.42142 .33164 L
.45836 .31514 L
.49694 .30591 L
.53564 .30429 L
.57294 .31035 L
.60738 .32385 L
.63761 .34427 L
.66243 .3708 L
.68088 .4024 L
.69223 .43783 L
.69604 .4757 L
.69215 .51452 L
.68072 .55278 L
.6622 .58896 L
.63731 .62165 L
.60704 .64957 L
.57256 .67162 L
Mistroke
.53524 .68693 L
.49653 .6949 L
.45796 .69523 L
.42104 .68789 L
.38722 .67318 L
.35782 .65168 L
.334 .62422 L
.3167 .59188 L
.3066 .55594 L
.30408 .51781 L
.30925 .47897 L
.32191 .44096 L
.34156 .40527 L
.36742 .3733 L
.39849 .34629 L
.43355 .32532 L
.47121 .31121 L
.51 .3045 L
.5484 .30547 L
.58489 .31407 L
.61806 .32997 L
.6466 .35254 L
.66938 .3809 L
.68551 .41393 L
.69436 .45034 L
.69559 .4887 L
.68914 .52751 L
.67526 .56523 L
.65451 .60039 L
.62769 .63162 L
.59587 .65767 L
.56028 .67754 L
.52232 .69044 L
.48349 .69587 L
.4453 .69361 L
.40927 .68375 L
.37679 .66668 L
.34915 .64307 L
.32743 .61385 L
.31248 .58015 L
.30489 .54331 L
.30496 .50477 L
.31269 .46605 L
.32776 .42865 L
.34959 .39406 L
.37733 .36362 L
.40988 .33854 L
.44597 .31979 L
.48418 .30811 L
.52301 .30397 L
Mistroke
.56093 .30752 L
Mfstroke
1 0 0 r
.30495 .54386 m
.30491 .50533 L
s
% Start of user PostScript
-5.8515352 1.3156705 -5.8527911 0.15988744 MAarrowhead1
% End of user PostScript
1 .158 0 r
.31252 .46659 m
.32749 .42917 L
s
% Start of user PostScript
-5.6243484 -1.0021706 -5.1751728 -2.1248974 MAarrowhead1
% End of user PostScript
1 .473 0 r
.5604 .30741 m
.59598 .31841 L
s
% Start of user PostScript
1.8121221 -5.7775785 2.879504 -5.4476479 MAarrowhead1
% End of user PostScript
1 .788 0 r
.68547 .53982 m
.66931 .57688 L
s
% Start of user PostScript
5.5639914 1.1946066 5.0792641 2.3063443 MAarrowhead1
% End of user PostScript
.897 1 0 r
.43342 .69126 m
.39838 .67903 L
s
% Start of user PostScript
-1.9974441 5.7377893 -3.048681 5.3708296 MAarrowhead1
% End of user PostScript
.581 1 0 r
.31675 .45381 m
.33408 .41716 L
s
% Start of user PostScript
-5.4974618 -1.3857173 -4.9777205 -2.4852325 MAarrowhead1
% End of user PostScript
.266 1 0 r
.57269 .31028 m
.60715 .32373 L
s
% Start of user PostScript
2.1805501 -5.6916347 3.2144758 -5.288053 MAarrowhead1
% End of user PostScript
0 1 .049 r
.68083 .55251 m
.66236 .58871 L
s
% Start of user PostScript
5.4248334 1.5752907 4.8706547 2.6613637 MAarrowhead1
% End of user PostScript
0 1 .364 r
.42129 .68797 m
.38744 .67331 L
s
% Start of user PostScript
-2.3612371 5.6391659 -3.3767046 5.19941 MAarrowhead1
% End of user PostScript
0 1 .679 r
.32179 .44123 m
.34139 .40552 L
s
% Start of user PostScript
-5.3461867 -1.7631166 -4.7581855 -2.8345425 MAarrowhead1
% End of user PostScript
0 1 .995 r
.58464 .31399 m
.61784 .32983 L
s
% Start of user PostScript
2.5393046 -5.5804411 3.5351873 -5.1049988 MAarrowhead1
% End of user PostScript
0 .69 1 r
.67539 .56497 m
.65468 .60015 L
s
% Start of user PostScript
5.2616092 1.9489864 4.6404377 3.0045766 MAarrowhead1
% End of user PostScript
0 .375 1 r
.40951 .68385 m
.37701 .66683 L
s
% Start of user PostScript
-2.714555 5.5155254 -3.6897481 5.0049242 MAarrowhead1
% End of user PostScript
0 .06 1 r
.32763 .42891 m
.34942 .39429 L
s
% Start of user PostScript
-5.1711944 -2.1326941 -4.5175419 -3.1712775 MAarrowhead1
% End of user PostScript
.564 1 0 r
.22374 .58234 m
.21967 .52788 L
.22659 .47232 L
.24425 .41786 L
.27194 .36661 L
.30858 .3206 L
.35273 .28163 L
.40267 .25124 L
.45642 .2306 L
.51189 .22054 L
.56689 .22144 L
.61926 .23328 L
.66695 .25558 L
.70809 .28748 L
.74106 .32772 L
.76458 .37472 L
.77771 .42663 L
.77994 .48143 L
.77118 .53695 L
.75178 .59103 L
.7225 .64153 L
.68449 .68648 L
.63924 .7241 L
.58852 .75294 L
.53433 .77184 L
.47879 .78008 L
.42408 .77733 L
.37236 .76369 L
.32564 .7397 L
.28576 .70631 L
.2543 .66482 L
.23247 .61686 L
.22115 .56431 L
.22077 .50924 L
.23135 .45381 L
.25247 .40019 L
.28331 .35049 L
.32265 .30665 L
.36895 .27041 L
.42039 .24317 L
.47496 .22601 L
.53051 .21961 L
.58487 .22421 L
.63589 .23964 L
.68158 .26528 L
.72014 .30013 L
.75007 .34283 L
.77018 .3917 L
.77968 .44481 L
.77821 .5001 L
Mistroke
.76583 .55538 L
.743 .60848 L
.71065 .65733 L
.67002 .7 L
.62272 .73483 L
.57061 .76044 L
.51572 .77582 L
.46022 .78039 L
.40628 .77394 L
.35602 .75675 L
.3114 .72948 L
.27419 .69321 L
.24584 .64935 L
.22747 .59963 L
.21979 .546 L
.22311 .49056 L
.2373 .4355 L
.26179 .38297 L
.29563 .33503 L
.3375 .29356 L
.38574 .2602 L
.43847 .23625 L
.49361 .22264 L
.549 .21993 L
.60247 .2282 L
.65192 .24715 L
.6954 .27601 L
.73122 .31367 L
.75796 .35864 L
.77458 .40916 L
.78042 .46324 L
.77526 .51876 L
.75929 .57355 L
.73315 .62546 L
.69786 .67243 L
.6548 .71265 L
.60567 .74451 L
.55239 .76678 L
.49705 .77858 L
.44183 .77945 L
.38889 .76935 L
.34032 .74867 L
.29801 .71824 L
.26363 .67925 L
.23852 .63322 L
.22368 .58196 L
.21968 .52748 L
.22668 .47193 L
.24441 .41748 L
.27217 .36626 L
Mistroke
.30887 .3203 L
.35307 .28138 L
.40304 .25105 L
.45682 .23049 L
.51229 .2205 L
.56727 .22149 L
.61962 .2334 L
.66727 .25578 L
.70836 .28774 L
.74127 .32803 L
.76471 .37508 L
.77776 .42702 L
.77991 .48183 L
.77108 .53735 L
.75161 .5914 L
.72226 .64187 L
.68419 .68677 L
.63889 .72434 L
.58814 .75311 L
.53393 .77194 L
.47839 .7801 L
.4237 .77727 L
.372 .76355 L
.32533 .73949 L
.28551 .70604 L
.25411 .66449 L
.23235 .61649 L
.22111 .56392 L
.22081 .50884 L
.23146 .45342 L
.25266 .39982 L
.28356 .35015 L
.32296 .30636 L
.3693 .27018 L
.42077 .24301 L
.47536 .22593 L
.53091 .2196 L
.58525 .22428 L
.63624 .23978 L
.68188 .2655 L
.72039 .30041 L
.75025 .34316 L
.77028 .39207 L
.77971 .44521 L
.77816 .5005 L
.7657 .55577 L
.74281 .60885 L
.71038 .65766 L
.6697 .70028 L
.62237 .73505 L
Mistroke
.57022 .76058 L
.51533 .7759 L
.45983 .78038 L
.4059 .77386 L
.35567 .75659 L
.31111 .72925 L
.27396 .69292 L
.24568 .64901 L
.22738 .59926 L
.21978 .5456 L
.22317 .49017 L
.23744 .43511 L
.262 .3826 L
.29591 .3347 L
.33782 .29329 L
.38611 .25999 L
.43886 .23611 L
.49401 .22259 L
.54939 .21995 L
.60284 .2283 L
.65225 .24732 L
.69569 .27625 L
.73144 .31397 L
.75812 .35898 L
.77466 .40953 L
.78042 .46363 L
.77518 .51916 L
.75914 .57394 L
.73293 .62581 L
.69757 .67275 L
.65447 .71291 L
.6053 .74471 L
.55199 .7669 L
.49665 .77863 L
.44144 .77941 L
.38853 .76923 L
.33999 .74849 L
.29773 .71799 L
.26341 .67894 L
.23838 .63287 L
.22361 .58158 L
.21969 .52708 L
.22677 .47153 L
.24457 .41709 L
.2724 .36591 L
.30916 .31999 L
.35341 .28113 L
.40342 .25087 L
.45721 .23038 L
.51268 .22047 L
Mistroke
.56766 .22154 L
Mfstroke
1 0 0 r
.22374 .58234 m
.21967 .52788 L
s
% Start of user PostScript
-8.2876694 2.4701562 -8.4100014 0.83635612 MAarrowhead1
% End of user PostScript
1 .158 0 r
.22659 .47232 m
.24425 .41786 L
s
% Start of user PostScript
-8.2022748 -0.83026759 -7.6726419 -2.4643067 MAarrowhead1
% End of user PostScript
1 .473 0 r
.56689 .22144 m
.61926 .23328 L
s
% Start of user PostScript
2.0065593 -8.3567318 3.5777489 -8.0016143 MAarrowhead1
% End of user PostScript
1 .788 0 r
.77118 .53695 m
.75178 .59103 L
s
% Start of user PostScript
8.1354415 1.1086084 7.5534765 2.7308195 MAarrowhead1
% End of user PostScript
.897 1 0 r
.42408 .77733 m
.37236 .76369 L
s
% Start of user PostScript
-2.2775296 8.3198069 -3.8293355 7.9106578 MAarrowhead1
% End of user PostScript
.581 1 0 r
.23135 .45381 m
.25247 .40019 L
s
% Start of user PostScript
-8.059583 -1.3857194 -7.4259313 -2.9943027 MAarrowhead1
% End of user PostScript
.266 1 0 r
.58487 .22421 m
.63589 .23964 L
s
% Start of user PostScript
2.5459732 -8.2736522 4.0766738 -7.8109254 MAarrowhead1
% End of user PostScript
0 1 .049 r
.76583 .55538 m
.743 .60848 L
s
% Start of user PostScript
7.9747833 1.6612931 7.290148 3.2544642 MAarrowhead1
% End of user PostScript
0 1 .364 r
.40628 .77394 m
.35602 .75675 L
s
% Start of user PostScript
-2.8115923 8.2183189 -4.3194895 7.7025278 MAarrowhead1
% End of user PostScript
0 1 .679 r
.2373 .4355 m
.26179 .38297 L
s
% Start of user PostScript
-7.8811365 -1.9350238 -7.1462771 -3.5110152 MAarrowhead1
% End of user PostScript
0 1 .995 r
.60247 .2282 m
.65192 .24715 L
s
% Start of user PostScript
3.0740923 -8.1538684 4.5575133 -7.5855851 MAarrowhead1
% End of user PostScript
0 .69 1 r
.75929 .57355 m
.73315 .62546 L
s
% Start of user PostScript
7.7787466 2.2066077 6.9944783 3.7636712 MAarrowhead1
% End of user PostScript
0 .375 1 r
.38889 .76935 m
.34032 .74867 L
s
% Start of user PostScript
-3.333182 8.080372 -4.790481 7.460227 MAarrowhead1
% End of user PostScript
0 .06 1 r
.24441 .41748 m
.27217 .36626 L
s
% Start of user PostScript
-7.667727 -2.4757438 -6.8349199 -4.0121518 MAarrowhead1
% End of user PostScript
.973 1 0 r
.61743 .18709 m
.67438 .20879 L
.72449 .24191 L
.76578 .28517 L
.79665 .33686 L
.81588 .39495 L
.82271 .45717 L
.81687 .52106 L
.7986 .58413 L
.76861 .6439 L
.72807 .69802 L
.67859 .74436 L
.6221 .78112 L
.56081 .80685 L
.49714 .82053 L
.43358 .82163 L
.37263 .81011 L
.31668 .78642 L
.26792 .75149 L
.22827 .70669 L
.19928 .65378 L
.1821 .59483 L
.17739 .53216 L
.18534 .46823 L
.20565 .40554 L
.2375 .34656 L
.27966 .29361 L
.33046 .24875 L
.38792 .21376 L
.44978 .18999 L
.5136 .1784 L
.5769 .17943 L
.63717 .19303 L
.69207 .21869 L
.73942 .25538 L
.77738 .30168 L
.80445 .35576 L
.81958 .4155 L
.82216 .47855 L
.8121 .54245 L
.78979 .60468 L
.7561 .66281 L
.71237 .71454 L
.6603 .75785 L
.60194 .79105 L
.53958 .81282 L
.47566 .82231 L
.41271 .81916 L
.35317 .80348 L
.2994 .77589 L
Mistroke
.2535 .73747 L
.21728 .68973 L
.19215 .63455 L
.17911 .57408 L
.17865 .51071 L
.19081 .44692 L
.2151 .38521 L
.25058 .328 L
.29584 .27755 L
.34912 .23583 L
.40831 .20447 L
.47111 .18471 L
.53504 .17733 L
.59759 .18261 L
.65632 .20034 L
.7089 .22984 L
.7533 .26994 L
.78774 .31907 L
.8109 .3753 L
.82186 .43642 L
.82018 .50004 L
.80594 .56365 L
.77969 .62477 L
.74246 .68099 L
.69572 .73011 L
.6413 .7702 L
.58133 .79968 L
.51817 .81741 L
.4543 .82267 L
.39222 .81527 L
.33437 .7955 L
.28302 .76413 L
.24019 .7224 L
.20755 .67193 L
.18639 .61472 L
.17754 .55301 L
.18134 .48922 L
.19765 .42585 L
.22583 .36539 L
.26476 .31021 L
.31293 .26248 L
.36844 .22407 L
.42911 .1965 L
.49257 .18083 L
.55632 .17769 L
.61785 .1872 L
.67476 .20898 L
.72482 .24219 L
.76604 .28551 L
.79683 .33726 L
Mistroke
.81597 .39539 L
.82271 .45762 L
.81678 .52152 L
.79842 .58457 L
.76835 .64431 L
.72775 .69838 L
.67821 .74466 L
.62167 .78135 L
.56036 .80699 L
.49668 .82058 L
.43313 .82159 L
.37221 .80999 L
.3163 .78621 L
.2676 .7512 L
.22802 .70634 L
.19911 .65337 L
.18202 .59439 L
.1774 .5317 L
.18545 .46777 L
.20583 .4051 L
.23777 .34616 L
.27999 .29325 L
.33085 .24846 L
.38835 .21354 L
.45023 .18987 L
.51406 .17836 L
.57734 .17948 L
.63759 .19318 L
.69244 .21891 L
.73973 .25568 L
.77761 .30204 L
.8046 .35617 L
.81964 .41594 L
.82213 .47901 L
.81198 .54291 L
.78958 .60512 L
.75582 .6632 L
.71202 .71488 L
.6599 .75813 L
.6015 .79125 L
.53912 .81293 L
.47521 .82234 L
.41226 .81909 L
.35276 .80332 L
.29904 .77565 L
.25321 .73716 L
.21706 .68936 L
.19201 .63413 L
.17906 .57364 L
.1787 .51025 L
Mistroke
.19094 .44647 L
.21532 .38478 L
.25087 .32762 L
.2962 .27722 L
.34952 .23556 L
.40875 .20429 L
.47157 .18461 L
.53549 .17732 L
.59803 .18269 L
.65672 .20051 L
.70925 .23009 L
.75358 .27026 L
.78795 .31945 L
.81102 .37572 L
.82189 .43687 L
.82012 .5005 L
.80579 .5641 L
.77946 .6252 L
.74216 .68137 L
.69536 .73043 L
.64089 .77045 L
.58089 .79985 L
.51771 .81749 L
.45384 .82266 L
.39179 .81517 L
.33397 .79532 L
.28268 .76387 L
.23991 .72206 L
.20736 .67154 L
.18628 .61429 L
.17752 .55256 L
.18142 .48876 L
.19781 .4254 L
.22607 .36497 L
.26508 .30984 L
.31331 .26217 L
.36886 .22384 L
.42956 .19634 L
.49303 .18076 L
.55677 .17771 L
.61828 .18731 L
.67515 .20918 L
.72514 .24247 L
.7663 .28586 L
.79701 .33765 L
.81606 .39582 L
.82271 .45808 L
.81669 .52198 L
.79825 .58502 L
.7681 .64472 L
Mistroke
.72742 .69874 L
Mfstroke
1 0 0 r
.61743 .18709 m
.67438 .20879 L
s
% Start of user PostScript
3.5227542 -9.3874389 5.2313262 -8.7364419 MAarrowhead1
% End of user PostScript
1 .158 0 r
.72449 .24191 m
.76578 .28517 L
s
% Start of user PostScript
6.7345898 -7.7425747 7.9735478 -6.4448427 MAarrowhead1
% End of user PostScript
1 .473 0 r
.72807 .69802 m
.67859 .74436 L
s
% Start of user PostScript
6.8421829 5.9404921 5.3576678 7.3309354 MAarrowhead1
% End of user PostScript
1 .788 0 r
.26792 .75149 m
.22827 .70669 L
s
% Start of user PostScript
-6.9624849 7.5447125 -8.1519977 6.2006685 MAarrowhead1
% End of user PostScript
.897 1 0 r
.27966 .29361 m
.33046 .24875 L
s
% Start of user PostScript
-6.6102808 -6.1917867 -5.0861461 -7.5374634 MAarrowhead1
% End of user PostScript
.581 1 0 r
.73942 .25538 m
.77738 .30168 L
s
% Start of user PostScript
7.1826561 -7.3384803 8.3214039 -5.9496153 MAarrowhead1
% End of user PostScript
.266 1 0 r
.71237 .71454 m
.6603 .75785 L
s
% Start of user PostScript
6.3710453 6.4362122 4.8089819 7.7356295 MAarrowhead1
% End of user PostScript
0 1 .049 r
.2535 .73747 m
.21728 .68973 L
s
% Start of user PostScript
-7.3948589 7.1241069 -8.4815784 5.6919618 MAarrowhead1
% End of user PostScript
0 1 .364 r
.29584 .27755 m
.34912 .23583 L
s
% Start of user PostScript
-6.1247419 -6.6734976 -4.5264828 -7.9252138 MAarrowhead1
% End of user PostScript
0 1 .679 r
.7533 .26994 m
.78774 .31907 L
s
% Start of user PostScript
7.598858 -6.9018302 8.6323437 -5.4279936 MAarrowhead1
% End of user PostScript
0 1 .995 r
.69572 .73011 m
.6413 .7702 L
s
% Start of user PostScript
5.8716439 6.9033795 4.238962 8.1060061 MAarrowhead1
% End of user PostScript
0 .69 1 r
.24019 .7224 m
.20755 .67193 L
s
% Start of user PostScript
-7.7944271 6.6718967 -8.7735324 5.1580038 MAarrowhead1
% End of user PostScript
0 .375 1 r
.31293 .26248 m
.36844 .22407 L
s
% Start of user PostScript
-5.6120319 -7.1256029 -3.9467386 -8.2778057 MAarrowhead1
% End of user PostScript
0 .06 1 r
.76604 .28551 m
.79683 .33726 L
s
% Start of user PostScript
7.9813492 -6.4345616 8.904988 -4.8822918 MAarrowhead1
% End of user PostScript
1 0 .563 r
.46893 .82096 m
.40654 .81646 L
.34781 .79954 L
.29506 .77086 L
.25036 .73156 L
.21545 .68316 L
.19171 .62758 L
.18006 .56699 L
.18098 .50377 L
.19441 .44041 L
.21984 .37938 L
.25626 .32308 L
.30225 .27373 L
.356 .23326 L
.4154 .20326 L
.47812 .1849 L
.5417 .17891 L
.60364 .18552 L
.66152 .20448 L
.71305 .23503 L
.75623 .27598 L
.78935 .32572 L
.81111 .3823 L
.82066 .4435 L
.81763 .50692 L
.80214 .57007 L
.77478 .63047 L
.73664 .68574 L
.68922 .73373 L
.63436 .77254 L
.57424 .80066 L
.5112 .81698 L
.44772 .82086 L
.38629 .81214 L
.32933 .79118 L
.27906 .75878 L
.23747 .71624 L
.20618 .6652 L
.18642 .60768 L
.17896 .54594 L
.18411 .48239 L
.20165 .41953 L
.2309 .35984 L
.27072 .30564 L
.31953 .25907 L
.37542 .22195 L
.43621 .19575 L
.49949 .18149 L
.5628 .17973 L
.62364 .19054 L
Mistroke
.67963 .21349 L
.72857 .24769 L
.76854 .29179 L
.79797 .34406 L
.81571 .40245 L
.82105 .46467 L
.8138 .52828 L
.79423 .59077 L
.76311 .64971 L
.72167 .70277 L
.67153 .74787 L
.61465 .78324 L
.55328 .8075 L
.48981 .81969 L
.42675 .81933 L
.36656 .80644 L
.3116 .78152 L
.26404 .74556 L
.22574 .69996 L
.19821 .64651 L
.18252 .58731 L
.17928 .52468 L
.18864 .46109 L
.21021 .39902 L
.24316 .34092 L
.28619 .28906 L
.33761 .24547 L
.3954 .21188 L
.4573 .1896 L
.52087 .17949 L
.58362 .18197 L
.64309 .19693 L
.69695 .22378 L
.74308 .26147 L
.77966 .30852 L
.80528 .36309 L
.81891 .42303 L
.82002 .48599 L
.80858 .54951 L
.78502 .61107 L
.75028 .66828 L
.70571 .71889 L
.65308 .7609 L
.59443 .79268 L
.53208 .81297 L
.46847 .82097 L
.4061 .81638 L
.34741 .79938 L
.29471 .77062 L
.25007 .73124 L
Mistroke
.21524 .68279 L
.19158 .62716 L
.18003 .56654 L
.18103 .50332 L
.19455 .43996 L
.22006 .37895 L
.25656 .3227 L
.30261 .27341 L
.35641 .23301 L
.41584 .20309 L
.47858 .18482 L
.54215 .17892 L
.60407 .18562 L
.66191 .20466 L
.7134 .23529 L
.7565 .27631 L
.78955 .32611 L
.81122 .38273 L
.82069 .44395 L
.81757 .50738 L
.80198 .57051 L
.77454 .63088 L
.73633 .68611 L
.68885 .73404 L
.63395 .77278 L
.57379 .80082 L
.51074 .81705 L
.44727 .82084 L
.38587 .81203 L
.32894 .79098 L
.27873 .75851 L
.23721 .7159 L
.20599 .66481 L
.18632 .60725 L
.17895 .54549 L
.18419 .48193 L
.20182 .41909 L
.23115 .35942 L
.27104 .30527 L
.31991 .25877 L
.37584 .22173 L
.43665 .19561 L
.49995 .18143 L
.56325 .17976 L
.62406 .19066 L
.68001 .2137 L
.72889 .24797 L
.76879 .29214 L
.79814 .34446 L
.81579 .40289 L
Mistroke
.82105 .46512 L
.8137 .52873 L
.79405 .59121 L
.76285 .65011 L
.72134 .70312 L
.67114 .74816 L
.61423 .78345 L
.55283 .80763 L
.48936 .81973 L
.4263 .81928 L
.36614 .8063 L
.31123 .7813 L
.26373 .74526 L
.22551 .6996 L
.19805 .6461 L
.18245 .58687 L
.17931 .52423 L
.18875 .46063 L
.21041 .39859 L
.24344 .34052 L
.28653 .28871 L
.338 .2452 L
.39583 .21168 L
.45775 .18948 L
.52132 .17947 L
.58406 .18203 L
.6435 .19708 L
.69731 .22401 L
.74338 .26177 L
.77989 .30889 L
.80542 .3635 L
.81896 .42348 L
.81998 .48645 L
.80845 .54996 L
.78481 .6115 L
.74999 .66867 L
.70536 .71922 L
.65268 .76117 L
.594 .79287 L
.53163 .81307 L
.46802 .82099 L
.40566 .8163 L
.34701 .79921 L
.29436 .77037 L
.24978 .73092 L
.21503 .68241 L
.19145 .62674 L
.17999 .5661 L
.18108 .50286 L
.19469 .43951 L
Mistroke
.22029 .37853 L
Mfstroke
1 0 0 r
.46893 .82096 m
.40654 .81646 L
s
% Start of user PostScript
-0.93220179 9.6288419 -2.8039122 9.4938204 MAarrowhead1
% End of user PostScript
1 .158 0 r
.34781 .79954 m
.29506 .77086 L
s
% Start of user PostScript
-4.5655803 8.9862048 -6.1480678 8.1259168 MAarrowhead1
% End of user PostScript
1 .473 0 r
.21984 .37938 m
.25626 .32308 L
s
% Start of user PostScript
-8.4048239 -3.6186893 -7.3121541 -5.3075097 MAarrowhead1
% End of user PostScript
1 .788 0 r
.66152 .20448 m
.71305 .23503 L
s
% Start of user PostScript
4.845523 -8.8656757 6.3916165 -7.9491376 MAarrowhead1
% End of user PostScript
.897 1 0 r
.77478 .63047 m
.73664 .68574 L
s
% Start of user PostScript
8.2434323 3.9139818 7.0992661 5.5722747 MAarrowhead1
% End of user PostScript
.581 1 0 r
.32933 .79118 m
.27906 .75878 L
s
% Start of user PostScript
-5.1200901 8.7353112 -6.6280745 7.7635397 MAarrowhead1
% End of user PostScript
.266 1 0 r
.2309 .35984 m
.27072 .30564 L
s
% Start of user PostScript
-8.0728955 -4.2049321 -6.8785023 -5.8308578 MAarrowhead1
% End of user PostScript
0 1 .049 r
.67963 .21349 m
.72857 .24769 L
s
% Start of user PostScript
5.3889771 -8.595256 6.8571794 -7.5693291 MAarrowhead1
% End of user PostScript
0 1 .364 r
.76311 .64971 m
.72167 .70277 L
s
% Start of user PostScript
7.8934028 4.4912176 6.6501077 6.0829723 MAarrowhead1
% End of user PostScript
0 1 .679 r
.3116 .78152 m
.26404 .74556 L
s
% Start of user PostScript
-5.6518857 8.4456653 -7.078677 7.3667212 MAarrowhead1
% End of user PostScript
0 1 .995 r
.24316 .34092 m
.28619 .28906 L
s
% Start of user PostScript
-7.7051533 -4.7725205 -6.4143355 -6.3283385 MAarrowhead1
% End of user PostScript
0 .69 1 r
.69695 .22378 m
.74308 .26147 L
s
% Start of user PostScript
5.9085241 -8.2867051 7.2923217 -7.1559408 MAarrowhead1
% End of user PostScript
0 .375 1 r
.75028 .66828 m
.70571 .71889 L
s
% Start of user PostScript
7.5083558 5.048529 6.1714474 6.5666842 MAarrowhead1
% End of user PostScript
0 .06 1 r
.29471 .77062 m
.25007 .73124 L
s
% Start of user PostScript
-6.1586078 8.1185518 -7.4978765 6.9372218 MAarrowhead1
% End of user PostScript
1 .93 0 r
.43789 .30861 m
.47868 .29527 L
.52031 .28997 L
.56114 .29291 L
.59957 .30397 L
.63409 .32273 L
.66335 .34845 L
.6862 .38012 L
.70174 .41649 L
.70936 .45614 L
.70877 .4975 L
.69998 .53897 L
.68335 .57891 L
.65952 .61575 L
.62943 .64805 L
.59426 .67454 L
.55539 .69417 L
.51435 .70619 L
.47274 .71012 L
.4322 .7058 L
.39433 .6934 L
.3606 .67341 L
.33234 .64662 L
.31067 .61407 L
.29642 .57704 L
.29016 .537 L
.29214 .4955 L
.30228 .45417 L
.32017 .41465 L
.34513 .37847 L
.37616 .34707 L
.41205 .32166 L
.45139 .30326 L
.49264 .29258 L
.53418 .29003 L
.57438 .29573 L
.61166 .30945 L
.64456 .33064 L
.67178 .35848 L
.69226 .39187 L
.7052 .42951 L
.71008 .46991 L
.70672 .5115 L
.69525 .55263 L
.67611 .5917 L
.65006 .62717 L
.61812 .65765 L
.58155 .68194 L
.54177 .69909 L
.50036 .70843 L
Mistroke
.45893 .70958 L
.41911 .70252 L
.38247 .6875 L
.35044 .66513 L
.32428 .63627 L
.30502 .60207 L
.29341 .56386 L
.2899 .52315 L
.29465 .48152 L
.30745 .44062 L
.32781 .40206 L
.35492 .36733 L
.38773 .33782 L
.42495 .31466 L
.46511 .29879 L
.50664 .2908 L
.54791 .29103 L
.5873 .29946 L
.62326 .31576 L
.65439 .33929 L
.67946 .36913 L
.69748 .4041 L
.70775 .44284 L
.70987 .48382 L
.70376 .52544 L
.68964 .56605 L
.66809 .60408 L
.63994 .63802 L
.60629 .66654 L
.56848 .68853 L
.52797 .70312 L
.48637 .70974 L
.4453 .70812 L
.40638 .69834 L
.37114 .68077 L
.34095 .65611 L
.317 .62532 L
.30024 .58962 L
.29131 .55039 L
.29058 .50919 L
.29806 .46763 L
.31347 .42734 L
.3362 .3899 L
.36536 .35678 L
.3998 .32928 L
.43818 .30848 L
.47898 .2952 L
.5206 .28996 L
.56142 .29296 L
.59983 .30408 L
Mistroke
.63432 .3229 L
.66353 .34866 L
.68633 .38036 L
.70182 .41676 L
.70939 .45643 L
.70873 .4978 L
.69989 .53927 L
.6832 .57919 L
.65932 .616 L
.62919 .64826 L
.59399 .6747 L
.5551 .69429 L
.51405 .70625 L
.47244 .71011 L
.43192 .70573 L
.39407 .69328 L
.36038 .67324 L
.33216 .6464 L
.31054 .61382 L
.29634 .57677 L
.29015 .5367 L
.29218 .4952 L
.30238 .45388 L
.32033 .41438 L
.34533 .37823 L
.3764 .34686 L
.41232 .32151 L
.45168 .30316 L
.49294 .29253 L
.53448 .29005 L
.57466 .2958 L
.61191 .30957 L
.64478 .33082 L
.67195 .3587 L
.69238 .39213 L
.70526 .42979 L
.71009 .47021 L
.70667 .5118 L
.69514 .55292 L
.67595 .59197 L
.64985 .6274 L
.61787 .65784 L
.58127 .68209 L
.54148 .69918 L
.50006 .70846 L
.45864 .70956 L
.41884 .70244 L
.38222 .68737 L
.35023 .66494 L
.32412 .63604 L
Mistroke
.30491 .60181 L
.29335 .56358 L
.28991 .52285 L
.29471 .48123 L
.30757 .44034 L
.32798 .40179 L
.35514 .3671 L
.38798 .33763 L
.42523 .31452 L
.4654 .2987 L
.50694 .29078 L
.5482 .29106 L
.58757 .29955 L
.6235 .31591 L
.65459 .33949 L
.67961 .36936 L
.69758 .40437 L
.7078 .44313 L
.70986 .48412 L
.70368 .52573 L
.68952 .56634 L
.66791 .60434 L
.63971 .63824 L
.60603 .66673 L
.56819 .68866 L
.52768 .70319 L
.48607 .70975 L
.44502 .70808 L
.40612 .69824 L
.3709 .68062 L
.34076 .65591 L
.31686 .62508 L
.30015 .58935 L
.29128 .5501 L
.2906 .50889 L
.29815 .46734 L
.31361 .42706 L
.33639 .38964 L
.36559 .35656 L
.40007 .32911 L
.43846 .30836 L
.47928 .29514 L
.5209 .28995 L
.56171 .29301 L
.60009 .30419 L
.63455 .32306 L
.66372 .34887 L
.68647 .38061 L
.7019 .41704 L
.70941 .45672 L
Mistroke
.7087 .4981 L
Mfstroke
1 0 0 r
.43789 .30861 m
.47868 .29527 L
s
% Start of user PostScript
-1.8632186 -5.7417659 -0.63954934 -6.1419024 MAarrowhead1
% End of user PostScript
1 .158 0 r
.52031 .28997 m
.56114 .29291 L
s
% Start of user PostScript
0.60921962 -6.3009939 1.8340792 -6.2127968 MAarrowhead1
% End of user PostScript
1 .473 0 r
.70877 .4975 m
.69998 .53897 L
s
% Start of user PostScript
6.2630346 -0.074855214 5.9994578 1.1691574 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47274 .71012 m
.4322 .7058 L
s
% Start of user PostScript
-0.8178249 6.3034871 -2.0339054 6.1738553 MAarrowhead1
% End of user PostScript
.897 1 0 r
.29214 .4955 m
.30228 .45417 L
s
% Start of user PostScript
-6.235795 -0.13509743 -5.9317137 -1.3747923 MAarrowhead1
% End of user PostScript
.581 1 0 r
.53418 .29003 m
.57438 .29573 L
s
% Start of user PostScript
1.0255229 -6.2989874 2.2314752 -6.1280645 MAarrowhead1
% End of user PostScript
.266 1 0 r
.70672 .5115 m
.69525 .55263 L
s
% Start of user PostScript
6.2016375 0.34490019 5.8573891 1.5789021 MAarrowhead1
% End of user PostScript
0 1 .049 r
.45893 .70958 m
.41911 .70252 L
s
% Start of user PostScript
-1.2320832 6.2874997 -2.4265695 6.0754754 MAarrowhead1
% End of user PostScript
0 1 .364 r
.29465 .48152 m
.30745 .44062 L
s
% Start of user PostScript
-6.1606001 -0.55432033 -5.7765665 -1.7812603 MAarrowhead1
% End of user PostScript
0 1 .679 r
.54791 .29103 m
.5873 .29946 L
s
% Start of user PostScript
1.4372766 -6.2690367 2.6189718 -6.0161463 MAarrowhead1
% End of user PostScript
0 1 .995 r
.70376 .52544 m
.68964 .56605 L
s
% Start of user PostScript
6.1127281 0.76312552 5.6893354 1.9816424 MAarrowhead1
% End of user PostScript
0 .69 1 r
.4453 .70812 m
.40638 .69834 L
s
% Start of user PostScript
-1.6408756 6.243619 -2.8084687 5.950143 MAarrowhead1
% End of user PostScript
0 .375 1 r
.29806 .46763 m
.31347 .42734 L
s
% Start of user PostScript
-6.0580749 -0.97108411 -5.5957927 -2.179826 MAarrowhead1
% End of user PostScript
0 .06 1 r
.56142 .29296 m
.59983 .30408 L
s
% Start of user PostScript
1.8426542 -6.2112747 2.9948499 -5.8775387 MAarrowhead1
% End of user PostScript
0 .216 1 r
.42099 .28293 m
.46763 .2661 L
.51554 .25845 L
.56285 .26028 L
.60768 .27151 L
.64829 .29172 L
.68308 .3201 L
.71069 .35554 L
.73003 .39664 L
.74034 .44181 L
.74121 .48926 L
.73262 .53713 L
.7149 .58354 L
.68875 .62668 L
.65519 .66484 L
.61554 .69653 L
.57135 .72051 L
.52436 .73584 L
.47642 .74191 L
.42941 .73849 L
.38516 .7257 L
.34542 .70406 L
.31175 .67441 L
.28546 .63792 L
.2676 .59601 L
.25885 .55034 L
.25957 .50268 L
.26973 .45493 L
.28892 .40894 L
.3164 .36653 L
.35108 .32935 L
.39161 .29887 L
.43639 .27629 L
.48367 .26248 L
.53159 .258 L
.57826 .26301 L
.62187 .27733 L
.6607 .30038 L
.69321 .33127 L
.71815 .36878 L
.73452 .41144 L
.74169 .45758 L
.73937 .50538 L
.72766 .55297 L
.70702 .59848 L
.67825 .64012 L
.64248 .67627 L
.60113 .7055 L
.5558 .72666 L
.50828 .73893 L
Mistroke
.46044 .74182 L
.41415 .73522 L
.37123 .71939 L
.33337 .69495 L
.30204 .66286 L
.27848 .62437 L
.26362 .58101 L
.25803 .53447 L
.26194 .48657 L
.2752 .4392 L
.29727 .39422 L
.3273 .35338 L
.36411 .31831 L
.40625 .29036 L
.45207 .27064 L
.49978 .25992 L
.54749 .25863 L
.59333 .2668 L
.63552 .28413 L
.67238 .30993 L
.70249 .34319 L
.72464 .38261 L
.73798 .42663 L
.74197 .47353 L
.73648 .52147 L
.7217 .56857 L
.69822 .61297 L
.66696 .65295 L
.62914 .68692 L
.58626 .71355 L
.54 .7318 L
.49216 .74096 L
.44464 .74066 L
.39928 .73091 L
.35788 .71211 L
.32205 .68497 L
.29321 .65058 L
.27249 .61028 L
.26069 .56565 L
.25829 .51844 L
.26537 .47051 L
.28166 .42374 L
.30652 .37996 L
.33897 .34089 L
.37774 .30807 L
.42131 .28278 L
.46797 .26601 L
.51589 .25843 L
.56318 .26032 L
.60799 .27163 L
Mistroke
.64857 .29189 L
.68331 .32033 L
.71086 .35581 L
.73013 .39696 L
.74038 .44214 L
.74118 .4896 L
.73253 .53747 L
.71474 .58386 L
.68853 .62697 L
.65492 .66509 L
.61523 .69673 L
.57102 .72066 L
.52402 .73592 L
.47608 .74192 L
.42908 .73843 L
.38486 .72558 L
.34515 .70388 L
.31153 .67417 L
.2853 .63764 L
.2675 .59569 L
.25882 .55 L
.25961 .50234 L
.26984 .45459 L
.28909 .40862 L
.31662 .36624 L
.35135 .32911 L
.39192 .29868 L
.43672 .27616 L
.48401 .26242 L
.53193 .258 L
.57859 .26308 L
.62217 .27746 L
.66095 .30058 L
.69342 .33152 L
.7183 .36907 L
.73461 .41176 L
.74171 .45791 L
.73932 .50572 L
.72755 .5533 L
.70684 .59879 L
.67802 .6404 L
.6422 .6765 L
.60081 .70568 L
.55546 .72678 L
.50794 .73898 L
.4601 .74181 L
.41383 .73514 L
.37094 .71925 L
.33312 .69475 L
.30184 .6626 L
Mistroke
.27835 .62408 L
.26355 .58069 L
.25803 .53413 L
.26201 .48623 L
.27532 .43887 L
.29746 .39391 L
.32754 .35311 L
.3644 .31808 L
.40657 .29019 L
.45241 .27053 L
.50012 .25988 L
.54783 .25865 L
.59365 .2669 L
.6358 .28429 L
.67263 .31015 L
.70267 .34346 L
.72477 .38291 L
.73804 .42696 L
.74197 .47387 L
.7364 .52181 L
.72156 .5689 L
.69802 .61328 L
.66671 .65321 L
.62885 .68713 L
.58594 .71371 L
.53966 .7319 L
.49182 .74099 L
.4443 .74062 L
.39897 .73081 L
.3576 .71194 L
.32182 .68475 L
.29303 .65031 L
.27237 .60997 L
.26064 .56532 L
.2583 .5181 L
.26545 .47017 L
.28181 .42342 L
.30672 .37966 L
.33923 .34063 L
.37804 .30786 L
.42164 .28263 L
.46831 .26592 L
.51623 .25841 L
.56351 .26037 L
.6083 .27174 L
.64884 .29207 L
.68353 .32056 L
.71103 .35609 L
.73024 .39727 L
.74041 .44248 L
Mistroke
.74116 .48995 L
Mfstroke
1 0 0 r
.42099 .28293 m
.46763 .2661 L
s
% Start of user PostScript
-2.3703751 -6.5121446 -0.97109147 -7.0170642 MAarrowhead1
% End of user PostScript
1 .158 0 r
.51554 .25845 m
.56285 .26028 L
s
% Start of user PostScript
0.46630359 -7.2465924 1.8853981 -7.191721 MAarrowhead1
% End of user PostScript
1 .473 0 r
.74121 .48926 m
.73262 .53713 L
s
% Start of user PostScript
7.2363594 -0.32225104 6.9786644 1.1138618 MAarrowhead1
% End of user PostScript
1 .788 0 r
.47642 .74191 m
.42941 .73849 L
s
% Start of user PostScript
-0.70732776 7.2573257 -2.1178391 7.1546211 MAarrowhead1
% End of user PostScript
.897 1 0 r
.25957 .50268 m
.26973 .45493 L
s
% Start of user PostScript
-7.2128002 0.08052854 -6.9081247 -1.3521635 MAarrowhead1
% End of user PostScript
.581 1 0 r
.53159 .258 m
.57826 .26301 L
s
% Start of user PostScript
0.94756723 -7.2600079 2.3479307 -7.1095841 MAarrowhead1
% End of user PostScript
.266 1 0 r
.73937 .50538 m
.72766 .55297 L
s
% Start of user PostScript
7.1812392 0.1612833 6.8299213 1.5889651 MAarrowhead1
% End of user PostScript
0 1 .049 r
.46044 .74182 m
.41415 .73522 L
s
% Start of user PostScript
-1.1867555 7.254636 -2.5754175 7.0566598 MAarrowhead1
% End of user PostScript
0 1 .364 r
.26194 .48657 m
.2752 .4392 L
s
% Start of user PostScript
-7.1417115 -0.40291622 -6.7441409 -1.824004 MAarrowhead1
% End of user PostScript
0 1 .679 r
.54749 .25863 m
.59333 .2668 L
s
% Start of user PostScript
1.4246272 -7.2412159 2.8000471 -6.9959071 MAarrowhead1
% End of user PostScript
0 1 .995 r
.73648 .52147 m
.7217 .56857 L
s
% Start of user PostScript
7.0942609 0.64410215 6.6508787 2.0570193 MAarrowhead1
% End of user PostScript
0 .69 1 r
.44464 .74066 m
.39928 .73091 L
s
% Start of user PostScript
-1.6609184 7.2197625 -3.0215705 6.9273931 MAarrowhead1
% End of user PostScript
0 .375 1 r
.26537 .47051 m
.28166 .42374 L
s
% Start of user PostScript
-7.03894 -0.88457352 -6.5502381 -2.2877526 MAarrowhead1
% End of user PostScript
0 .06 1 r
.56318 .26032 m
.60799 .27163 L
s
% Start of user PostScript
1.8953671 -7.1902997 3.2397417 -6.8511941 MAarrowhead1
% End of user PostScript
0 1 .876 r
.50049 .23703 m
.55272 .23576 L
.60288 .24485 L
.649 .26396 L
.68927 .29234 L
.72212 .32886 L
.74625 .3721 L
.76071 .42036 L
.76494 .47175 L
.75878 .52424 L
.74245 .57579 L
.71662 .62435 L
.68228 .66804 L
.64079 .70513 L
.59377 .73418 L
.54307 .75403 L
.49068 .76391 L
.43866 .76344 L
.38905 .75262 L
.34379 .73189 L
.30466 .70206 L
.27319 .66431 L
.25063 .6201 L
.23786 .57118 L
.23537 .51946 L
.24327 .46698 L
.26124 .4158 L
.28859 .36792 L
.32423 .32523 L
.36677 .28939 L
.41454 .26182 L
.46566 .2436 L
.51813 .23544 L
.56989 .23766 L
.61891 .25018 L
.66326 .27251 L
.7012 .30376 L
.73125 .34271 L
.75222 .38784 L
.76329 .43736 L
.76403 .48935 L
.75441 .54175 L
.7348 .59252 L
.70598 .63965 L
.66907 .68131 L
.62553 .71585 L
.57706 .74191 L
.52557 .75849 L
.47308 .76491 L
.42164 .76095 L
Mistroke
.37327 .74674 L
.32988 .72284 L
.29317 .6902 L
.26457 .6501 L
.24522 .60411 L
.23586 .55403 L
.23687 .50183 L
.2482 .44955 L
.26942 .39926 L
.29969 .35292 L
.33782 .31236 L
.38231 .27915 L
.43142 .25462 L
.48323 .23971 L
.53569 .23502 L
.58675 .24073 L
.63441 .25662 L
.67679 .28206 L
.71223 .31605 L
.73935 .35725 L
.75707 .40407 L
.7647 .45464 L
.76194 .507 L
.74891 .55908 L
.7261 .60884 L
.69442 .65434 L
.65511 .69377 L
.60972 .7256 L
.56001 .74858 L
.50796 .7618 L
.45559 .76474 L
.40496 .7573 L
.35806 .73976 L
.31674 .7128 L
.2826 .6775 L
.257 .63523 L
.24093 .58765 L
.23504 .53664 L
.23954 .48418 L
.25426 .43235 L
.27863 .38317 L
.31168 .33858 L
.35213 .30032 L
.39838 .2699 L
.44861 .2485 L
.50087 .23698 L
.55309 .23578 L
.60323 .24496 L
.64931 .26414 L
.68954 .29257 L
Mistroke
.72232 .32915 L
.74639 .37243 L
.76078 .42072 L
.76494 .47212 L
.7587 .52462 L
.7423 .57615 L
.7164 .62469 L
.68201 .66833 L
.64047 .70537 L
.59342 .73435 L
.5427 .75414 L
.49031 .76395 L
.4383 .7634 L
.3887 .75251 L
.34348 .73171 L
.3044 .70182 L
.273 .66401 L
.2505 .61976 L
.2378 .57081 L
.23539 .51909 L
.24336 .46661 L
.2614 .41544 L
.28881 .3676 L
.32451 .32495 L
.36709 .28916 L
.41489 .26166 L
.46603 .24351 L
.51851 .23542 L
.57025 .23772 L
.61924 .25031 L
.66355 .2727 L
.70144 .30401 L
.73143 .34301 L
.75233 .38818 L
.76333 .43773 L
.764 .48973 L
.7543 .54213 L
.73462 .59287 L
.70574 .63997 L
.66878 .68158 L
.6252 .71606 L
.5767 .74207 L
.5252 .75857 L
.4727 .76492 L
.42128 .76088 L
.37294 .7466 L
.32959 .72264 L
.29293 .68994 L
.2644 .64979 L
.24511 .60376 L
Mistroke
.23583 .55366 L
.23691 .50145 L
.24832 .44918 L
.26961 .39891 L
.29994 .35261 L
.33812 .31209 L
.38265 .27895 L
.43179 .25448 L
.4836 .23964 L
.53606 .23503 L
.58711 .24081 L
.63473 .25677 L
.67707 .28227 L
.71246 .31632 L
.73951 .35757 L
.75716 .40442 L
.76472 .45501 L
.76189 .50738 L
.74878 .55945 L
.7259 .60919 L
.69417 .65464 L
.65481 .69403 L
.60937 .7258 L
.55965 .74871 L
.50758 .76185 L
.45522 .76473 L
.40461 .75721 L
.35774 .73959 L
.31646 .71258 L
.28239 .67722 L
.25685 .63491 L
.24086 .5873 L
.23503 .53626 L
.23961 .48381 L
.2544 .43198 L
.27883 .38283 L
.31195 .33828 L
.35244 .30007 L
.39872 .26971 L
.44898 .24839 L
.50125 .23694 L
.55346 .23581 L
.60357 .24506 L
.64962 .26431 L
.6898 .29281 L
.72253 .32944 L
.74652 .37276 L
.76084 .42108 L
.76493 .4725 L
.75861 .52499 L
Mistroke
.74215 .57651 L
Mfstroke
1 0 0 r
.50049 .23703 m
.55272 .23576 L
s
% Start of user PostScript
0.01474355 -7.8891141 1.5815768 -7.9273128 MAarrowhead1
% End of user PostScript
1 .158 0 r
.60288 .24485 m
.649 .26396 L
s
% Start of user PostScript
3.0863395 -7.6543964 4.4699758 -7.0810758 MAarrowhead1
% End of user PostScript
1 .473 0 r
.74245 .57579 m
.71662 .62435 L
s
% Start of user PostScript
7.2736493 2.2735508 6.4985363 3.7306054 MAarrowhead1
% End of user PostScript
1 .788 0 r
.38905 .75262 m
.34379 .73189 L
s
% Start of user PostScript
-3.3286057 7.5786704 -4.686425 6.9568192 MAarrowhead1
% End of user PostScript
.897 1 0 r
.26124 .4158 m
.28859 .36792 L
s
% Start of user PostScript
-7.1627821 -2.5259764 -6.3424438 -3.9623188 MAarrowhead1
% End of user PostScript
.581 1 0 r
.61891 .25018 m
.66326 .27251 L
s
% Start of user PostScript
3.5671792 -7.4945367 4.8976752 -6.8248447 MAarrowhead1
% End of user PostScript
.266 1 0 r
.7348 .59252 m
.70598 .63965 L
s
% Start of user PostScript
7.0439687 2.7755998 6.179315 4.1896365 MAarrowhead1
% End of user PostScript
0 1 .049 r
.37327 .74674 m
.32988 .72284 L
s
% Start of user PostScript
-3.8017953 7.4020888 -5.103492 6.6852989 MAarrowhead1
% End of user PostScript
0 1 .364 r
.26942 .39926 m
.29969 .35292 L
s
% Start of user PostScript
-6.9173409 -3.022144 -6.0093311 -4.4123063 MAarrowhead1
% End of user PostScript
0 1 .679 r
.63441 .25662 m
.67679 .28206 L
s
% Start of user PostScript
4.0321938 -7.3014291 5.3036471 -6.5383365 MAarrowhead1
% End of user PostScript
0 1 .995 r
.7261 .60884 m
.69442 .65434 L
s
% Start of user PostScript
6.7830391 3.2653355 5.8326805 4.6300812 MAarrowhead1
% End of user PostScript
0 .69 1 r
.35806 .73976 m
.31674 .7128 L
s
% Start of user PostScript
-4.2581191 7.1926693 -5.4979184 6.3841207 MAarrowhead1
% End of user PostScript
0 .375 1 r
.27863 .38317 m
.31168 .33858 L
s
% Start of user PostScript
-6.6412123 -3.5049044 -5.6495593 -4.8427195 MAarrowhead1
% End of user PostScript
0 .06 1 r
.64931 .26414 m
.68954 .29257 L
s
% Start of user PostScript
4.4793205 -7.0759301 5.6860904 -6.2228224 MAarrowhead1
% End of user PostScript
1 0 .244 r
.72155 .45527 m
.72058 .49905 L
.71097 .54288 L
.69307 .58502 L
.66759 .62382 L
.63554 .65777 L
.59817 .68552 L
.55694 .70599 L
.51348 .71838 L
.46949 .72219 L
.4267 .71729 L
.38679 .70386 L
.35131 .68243 L
.32168 .65384 L
.29904 .61921 L
.28429 .5799 L
.278 .53746 L
.28043 .49355 L
.29148 .44989 L
.3107 .40819 L
.33736 .3701 L
.3704 .33711 L
.40853 .31051 L
.45024 .29135 L
.49391 .28038 L
.53782 .27802 L
.58024 .28438 L
.61952 .2992 L
.6541 .3219 L
.68264 .35159 L
.70401 .3871 L
.71737 .42705 L
.7222 .46986 L
.71831 .51385 L
.70585 .5573 L
.68532 .5985 L
.65751 .63583 L
.62352 .66783 L
.58468 .69325 L
.54252 .71108 L
.49869 .72063 L
.45491 .72152 L
.4129 .71371 L
.37431 .69752 L
.34065 .67358 L
.31325 .64282 L
.29317 .60646 L
.28122 .56592 L
.27785 .52279 L
.28319 .47877 L
Mistroke
.29705 .43559 L
.31887 .39493 L
.3478 .35839 L
.3827 .32741 L
.42221 .30321 L
.46477 .28672 L
.50871 .27861 L
.55231 .27919 L
.59386 .28843 L
.63172 .30598 L
.66442 .33114 L
.69066 .36293 L
.70942 .40009 L
.71996 .44118 L
.72186 .48458 L
.71506 .52858 L
.69982 .57146 L
.67674 .61154 L
.64672 .64724 L
.61095 .67716 L
.57081 .70012 L
.5279 .71524 L
.4839 .7219 L
.44052 .71986 L
.39948 .70919 L
.36239 .69031 L
.3307 .66396 L
.30565 .63117 L
.28822 .59324 L
.27911 .55165 L
.27867 .50803 L
.28692 .4641 L
.30352 .42157 L
.32784 .38212 L
.35892 .3473 L
.39553 .31848 L
.43624 .29677 L
.47945 .28304 L
.52347 .27783 L
.56657 .28134 L
.60706 .29342 L
.64334 .31362 L
.674 .34113 L
.69783 .37487 L
.7139 .41353 L
.72157 .45558 L
.72055 .49937 L
.71087 .54319 L
.69291 .58531 L
.66738 .62408 L
Mistroke
.63529 .65799 L
.59788 .68569 L
.55664 .70611 L
.51317 .71844 L
.46918 .72219 L
.4264 .71722 L
.38651 .70373 L
.35108 .68225 L
.32149 .65361 L
.29891 .61894 L
.28421 .57961 L
.27799 .53715 L
.28048 .49323 L
.29159 .44958 L
.31087 .4079 L
.33758 .36985 L
.37066 .3369 L
.40882 .31035 L
.45055 .29124 L
.49423 .28033 L
.53813 .27804 L
.58054 .28445 L
.61979 .29933 L
.65433 .32209 L
.68282 .35182 L
.70413 .38738 L
.71743 .42735 L
.7222 .47017 L
.71825 .51416 L
.70573 .5576 L
.68514 .59878 L
.65728 .63608 L
.62325 .66804 L
.58439 .6934 L
.54221 .71118 L
.49837 .72067 L
.4546 .72149 L
.41261 .71363 L
.37405 .69738 L
.34043 .67338 L
.31308 .64258 L
.29306 .60618 L
.28116 .56562 L
.27785 .52248 L
.28326 .47846 L
.29718 .43528 L
.31905 .39465 L
.34803 .35815 L
.38297 .32721 L
.42251 .30306 L
Mistroke
.46508 .28663 L
.50903 .27858 L
.55262 .27922 L
.59415 .28853 L
.63198 .30613 L
.66463 .33134 L
.69082 .36318 L
.70952 .40038 L
.72 .44149 L
.72185 .48489 L
.71498 .52889 L
.69969 .57176 L
.67655 .61181 L
.64648 .64747 L
.61067 .67735 L
.57051 .70026 L
.52759 .71531 L
.48358 .72192 L
.44022 .71981 L
.3992 .70908 L
.36214 .69014 L
.33049 .66374 L
.30549 .63092 L
.28813 .59295 L
.27908 .55134 L
.2787 .50771 L
.28701 .46378 L
.30367 .42128 L
.32804 .38186 L
.35916 .34707 L
.39581 .31829 L
.43654 .29664 L
.47977 .28298 L
.52379 .27782 L
.56688 .28139 L
.60734 .29354 L
.64359 .31379 L
.6742 .34135 L
.69798 .37513 L
.71399 .41382 L
.72159 .45589 L
.72051 .49969 L
.71077 .5435 L
.69275 .5856 L
.66718 .62435 L
.63504 .65821 L
.5976 .68587 L
.55633 .70623 L
.51285 .71849 L
.46887 .72219 L
Mistroke
.4261 .71716 L
Mfstroke
1 0 0 r
.72155 .45527 m
.72058 .49905 L
s
% Start of user PostScript
6.6464025 -1.3419547 6.6175416 -0.028376402 MAarrowhead1
% End of user PostScript
1 .158 0 r
.71097 .54288 m
.69307 .58502 L
s
% Start of user PostScript
6.3289688 1.2863155 5.7920094 2.5505248 MAarrowhead1
% End of user PostScript
1 .473 0 r
.4267 .71729 m
.38679 .70386 L
s
% Start of user PostScript
-2.1989696 6.5187324 -3.3964126 6.1158029 MAarrowhead1
% End of user PostScript
1 .788 0 r
.29148 .44989 m
.3107 .40819 L
s
% Start of user PostScript
-6.2557268 -1.5034374 -5.6788838 -2.7542261 MAarrowhead1
% End of user PostScript
.897 1 0 r
.58024 .28438 m
.61952 .2992 L
s
% Start of user PostScript
2.4073315 -6.4686568 3.5855613 -6.0240668 MAarrowhead1
% End of user PostScript
.581 1 0 r
.70585 .5573 m
.68532 .5985 L
s
% Start of user PostScript
6.1755449 1.7188914 5.5594582 2.954872 MAarrowhead1
% End of user PostScript
.266 1 0 r
.4129 .71371 m
.37431 .69752 L
s
% Start of user PostScript
-2.6130227 6.4114051 -3.7707323 5.9256478 MAarrowhead1
% End of user PostScript
0 1 .049 r
.29705 .43559 m
.31887 .39493 L
s
% Start of user PostScript
-6.088512 -1.9324385 -5.433865 -3.1522398 MAarrowhead1
% End of user PostScript
0 1 .364 r
.59386 .28843 m
.63172 .30598 L
s
% Start of user PostScript
2.8158151 -6.3470406 3.9517201 -5.8206549 MAarrowhead1
% End of user PostScript
0 1 .679 r
.69982 .57146 m
.67674 .61154 L
s
% Start of user PostScript
5.9947246 2.1438418 5.3022435 3.3461106 MAarrowhead1
% End of user PostScript
0 1 .995 r
.39948 .70919 m
.36239 .69031 L
s
% Start of user PostScript
-3.0154837 6.2756349 -4.1283239 5.7092048 MAarrowhead1
% End of user PostScript
0 .69 1 r
.30352 .42157 m
.32784 .38212 L
s
% Start of user PostScript
-5.8942867 -2.3528668 -5.1647399 -3.5362692 MAarrowhead1
% End of user PostScript
0 .375 1 r
.60706 .29342 m
.64334 .31362 L
s
% Start of user PostScript
3.2118069 -6.197267 4.3003479 -5.5914209 MAarrowhead1
% End of user PostScript
0 .06 1 r
.69291 .58531 m
.66738 .62408 L
s
% Start of user PostScript
5.7873098 2.5592815 5.0215066 3.7225048 MAarrowhead1
% End of user PostScript
.751 0 1 r
.33677 .35586 m
.37266 .32267 L
.41356 .29645 L
.45785 .27821 L
.50379 .26868 L
.54958 .26823 L
.59343 .27687 L
.63361 .29427 L
.66854 .31974 L
.69686 .35229 L
.71746 .39064 L
.72952 .43327 L
.73257 .47853 L
.7265 .52463 L
.71154 .56976 L
.68827 .61215 L
.65762 .65015 L
.62078 .68225 L
.5792 .70719 L
.53451 .72401 L
.48847 .73203 L
.44288 .73095 L
.39953 .72081 L
.36012 .70199 L
.32621 .67526 L
.29911 .64164 L
.2799 .60246 L
.26933 .55927 L
.26781 .51374 L
.2754 .46768 L
.29181 .42289 L
.31639 .38112 L
.34817 .34402 L
.38591 .31304 L
.42813 .28939 L
.47317 .27402 L
.51927 .26751 L
.5646 .27012 L
.60741 .28176 L
.64599 .30197 L
.67885 .32994 L
.70469 .36459 L
.72249 .40455 L
.73156 .44826 L
.73155 .494 L
.72245 .53998 L
.70461 .58438 L
.67875 .62548 L
.64587 .66165 L
.60727 .69147 L
Mistroke
.56446 .71378 L
.51911 .72771 L
.47302 .73269 L
.42799 .72854 L
.38578 .71543 L
.34805 .69386 L
.31629 .66468 L
.29174 .62903 L
.27536 .58833 L
.2678 .54415 L
.26935 .49825 L
.27995 .45241 L
.29919 .40844 L
.32631 .36807 L
.36025 .33287 L
.39967 .30423 L
.44303 .28327 L
.48862 .27082 L
.53466 .26737 L
.57934 .27304 L
.62091 .28762 L
.65773 .31054 L
.68836 .34089 L
.7116 .37749 L
.72654 .41889 L
.73258 .46348 L
.7295 .5095 L
.71741 .55515 L
.69678 .59863 L
.66844 .63824 L
.63348 .67243 L
.59329 .69985 L
.54943 .71943 L
.50363 .73039 L
.4577 .73232 L
.41342 .72512 L
.37254 .70909 L
.33666 .68486 L
.30719 .65337 L
.28529 .61586 L
.27182 .5738 L
.2673 .52885 L
.27191 .48276 L
.28548 .43735 L
.30746 .3944 L
.337 .3556 L
.37294 .32246 L
.41387 .29629 L
.45817 .27811 L
.50412 .26865 L
Mistroke
.5499 .26826 L
.59373 .27696 L
.63388 .29442 L
.66877 .31995 L
.69704 .35255 L
.71758 .39093 L
.72958 .43359 L
.73256 .47886 L
.72642 .52496 L
.7114 .57007 L
.68808 .61244 L
.65737 .6504 L
.6205 .68245 L
.57889 .70734 L
.53418 .7241 L
.48814 .73206 L
.44256 .73091 L
.39923 .7207 L
.35986 .70183 L
.32599 .67504 L
.29895 .64138 L
.2798 .60217 L
.26929 .55895 L
.26783 .51341 L
.27549 .46735 L
.29196 .42257 L
.31659 .38083 L
.34842 .34377 L
.3862 .31284 L
.42845 .28925 L
.4735 .27394 L
.5196 .26749 L
.56492 .27018 L
.6077 .28188 L
.64625 .30214 L
.67906 .33017 L
.70484 .36486 L
.72259 .40485 L
.7316 .44858 L
.73152 .49433 L
.72235 .5403 L
.70446 .58469 L
.67854 .62576 L
.64561 .66188 L
.60698 .69166 L
.56414 .71392 L
.51878 .72777 L
.47269 .73269 L
.42767 .72848 L
.38549 .7153 L
Mistroke
.3478 .69367 L
.31609 .66444 L
.29159 .62876 L
.27528 .58802 L
.26778 .54383 L
.26939 .49792 L
.28006 .45209 L
.29936 .40814 L
.32653 .36779 L
.36051 .33264 L
.39997 .30405 L
.44335 .28315 L
.48895 .27077 L
.53499 .26738 L
.57965 .27311 L
.62119 .28776 L
.65797 .31073 L
.68856 .34113 L
.71174 .37777 L
.72661 .4192 L
.73259 .46381 L
.72944 .50983 L
.71729 .55547 L
.69661 .59893 L
.66821 .63851 L
.63321 .67265 L
.59298 .70002 L
.54911 .71954 L
.5033 .73044 L
.45737 .7323 L
.41311 .72504 L
.37226 .70895 L
.33642 .68466 L
.30701 .65312 L
.28516 .61557 L
.27175 .57349 L
.2673 .52852 L
.27198 .48243 L
.28561 .43704 L
.30765 .39411 L
.33724 .35534 L
.37322 .32225 L
.41417 .29613 L
.4585 .27801 L
.50445 .26861 L
.55022 .26829 L
.59403 .27706 L
.63415 .29458 L
.669 .32016 L
.69722 .3528 L
Mistroke
.71769 .39122 L
Mfstroke
1 0 0 r
.33677 .35586 m
.37266 .32267 L
s
% Start of user PostScript
-4.8969586 -4.3242428 -3.8200593 -5.3197634 MAarrowhead1
% End of user PostScript
1 .158 0 r
.41356 .29645 m
.45785 .27821 L
s
% Start of user PostScript
-2.5932381 -6.1065047 -1.2646428 -6.6535903 MAarrowhead1
% End of user PostScript
1 .473 0 r
.71746 .39064 m
.72952 .43327 L
s
% Start of user PostScript
6.5237836 -3.2809206 6.8856275 -2.0018139 MAarrowhead1
% End of user PostScript
1 .788 0 r
.5792 .70719 m
.53451 .72401 L
s
% Start of user PostScript
2.375948 6.2157835 1.0353006 6.7202654 MAarrowhead1
% End of user PostScript
.897 1 0 r
.2799 .60246 m
.26933 .55927 L
s
% Start of user PostScript
-6.6029202 3.0738892 -6.9201106 1.7779794 MAarrowhead1
% End of user PostScript
.581 1 0 r
.42813 .28939 m
.47317 .27402 L
s
% Start of user PostScript
-2.156022 -6.3181667 -0.80480985 -6.7794853 MAarrowhead1
% End of user PostScript
.266 1 0 r
.72249 .40455 m
.73156 .44826 L
s
% Start of user PostScript
6.6747316 -2.8634476 6.9469167 -1.5521725 MAarrowhead1
% End of user PostScript
0 1 .049 r
.56446 .71378 m
.51911 .72771 L
s
% Start of user PostScript
1.9337042 6.4135407 0.57342626 6.8311841 MAarrowhead1
% End of user PostScript
0 1 .364 r
.27536 .58833 m
.2678 .54415 L
s
% Start of user PostScript
-6.7391383 2.6498293 -6.9660161 1.3246437 MAarrowhead1
% End of user PostScript
0 1 .679 r
.44303 .28327 m
.48862 .27082 L
s
% Start of user PostScript
-1.7092412 -6.5017995 -0.34140651 -6.8753045 MAarrowhead1
% End of user PostScript
0 1 .995 r
.72654 .41889 m
.73258 .46348 L
s
% Start of user PostScript
6.7960686 -2.4332714 6.9773874 -1.0956453 MAarrowhead1
% End of user PostScript
0 .69 1 r
.54943 .71943 m
.50363 .73039 L
s
% Start of user PostScript
1.4828819 6.5828454 0.10900802 6.9117976 MAarrowhead1
% End of user PostScript
0 .375 1 r
.27182 .5738 m
.2673 .52885 L
s
% Start of user PostScript
-6.8454595 2.2140141 -6.9810182 0.86543146 MAarrowhead1
% End of user PostScript
0 .06 1 r
.45817 .27811 m
.50412 .26865 L
s
% Start of user PostScript
-1.2548776 -6.6565884 0.12351141 -6.9406228 MAarrowhead1
% End of user PostScript
0 .266 1 r
.69314 .48583 m
.68737 .52413 L
.67424 .56148 L
.65428 .59642 L
.62826 .62758 L
.59721 .65373 L
.56234 .67385 L
.52503 .68714 L
.48673 .69309 L
.44896 .69146 L
.41319 .68232 L
.38082 .66602 L
.35314 .6432 L
.33121 .61477 L
.31591 .58183 L
.30784 .54568 L
.30731 .50774 L
.31433 .46949 L
.32865 .43244 L
.34969 .39805 L
.37663 .36765 L
.40841 .34245 L
.44379 .32343 L
.48137 .31134 L
.51968 .30665 L
.55722 .30956 L
.59252 .31993 L
.62418 .33738 L
.65097 .3612 L
.67184 .39048 L
.68596 .42405 L
.69278 .4606 L
.69204 .4987 L
.68376 .53685 L
.66827 .57355 L
.64617 .60737 L
.61834 .63697 L
.58586 .6612 L
.55002 .6791 L
.51221 .68997 L
.47392 .69339 L
.43666 .68921 L
.40188 .67762 L
.37095 .65904 L
.34509 .63423 L
.3253 .60415 L
.31237 .56998 L
.30681 .53307 L
.30883 .49486 L
.31835 .45685 L
Mistroke
.335 .42053 L
.35813 .38733 L
.38682 .35856 L
.41995 .33533 L
.45623 .31857 L
.49423 .30893 L
.53245 .30678 L
.5694 .31222 L
.60362 .32503 L
.63378 .34471 L
.65868 .37048 L
.67736 .40133 L
.68908 .43606 L
.69338 .47329 L
.69009 .51158 L
.67934 .54941 L
.66155 .5853 L
.63742 .61784 L
.6079 .64576 L
.57414 .66796 L
.53747 .68356 L
.49933 .69196 L
.46122 .69283 L
.42463 .68613 L
.391 .67213 L
.36165 .65137 L
.33772 .62467 L
.32017 .59307 L
.30967 .55783 L
.30664 .52031 L
.3112 .482 L
.32317 .44439 L
.34208 .40897 L
.36719 .37712 L
.39751 .35009 L
.43185 .32894 L
.46887 .31451 L
.50711 .30736 L
.54507 .30777 L
.58126 .31572 L
.61426 .3309 L
.64278 .35273 L
.66569 .38033 L
.6821 .41262 L
.69137 .44835 L
.69312 .4861 L
.6873 .5244 L
.67412 .56174 L
.65411 .59666 L
.62805 .62779 L
Mistroke
.59697 .6539 L
.56208 .67397 L
.52476 .68721 L
.48646 .6931 L
.44869 .69142 L
.41294 .68222 L
.38061 .66588 L
.35296 .64302 L
.33108 .61455 L
.31583 .58158 L
.30781 .54541 L
.30733 .50746 L
.31441 .46922 L
.32878 .43219 L
.34986 .39781 L
.37684 .36745 L
.40865 .34229 L
.44405 .32332 L
.48164 .31128 L
.51996 .30665 L
.55749 .30961 L
.59276 .32004 L
.62439 .33753 L
.65114 .3614 L
.67196 .39071 L
.68603 .4243 L
.6928 .46087 L
.69201 .49898 L
.68367 .53712 L
.66813 .57381 L
.64599 .6076 L
.61812 .63717 L
.58562 .66135 L
.54975 .6792 L
.51193 .69002 L
.47365 .69339 L
.4364 .68916 L
.40164 .67751 L
.37074 .65889 L
.34492 .63403 L
.32518 .60392 L
.31231 .56973 L
.3068 .5328 L
.30887 .49458 L
.31844 .45658 L
.33514 .42028 L
.35831 .38711 L
.38704 .35837 L
.42021 .33519 L
.4565 .31847 L
Mistroke
.4945 .30888 L
.53272 .30679 L
.56965 .31229 L
.60385 .32515 L
.63398 .34487 L
.65884 .37068 L
.67747 .40157 L
.68914 .43632 L
.69338 .47357 L
.69004 .51185 L
.67924 .54967 L
.6614 .58554 L
.63722 .61806 L
.60767 .64594 L
.57388 .66809 L
.5372 .68365 L
.49906 .692 L
.46095 .69281 L
.42438 .68606 L
.39077 .672 L
.36145 .6512 L
.33757 .62446 L
.32007 .59283 L
.30962 .55757 L
.30665 .52004 L
.31126 .48173 L
.32328 .44413 L
.34224 .40873 L
.36739 .37691 L
.39774 .34992 L
.43211 .32882 L
.46914 .31443 L
.50738 .30734 L
.54533 .3078 L
.58151 .3158 L
.61448 .33104 L
.64296 .3529 L
.66583 .38054 L
.6822 .41287 L
.69141 .44862 L
.69311 .48638 L
.68723 .52468 L
.674 .562 L
.65395 .5969 L
.62785 .62799 L
.59673 .65406 L
.56182 .67409 L
.52448 .68728 L
.48619 .69312 L
.44843 .69138 L
Mistroke
.4127 .68213 L
Mfstroke
1 0 0 r
.69314 .48583 m
.68737 .52413 L
s
% Start of user PostScript
5.7940985 -0.42511488 5.6209634 0.72389878 MAarrowhead1
% End of user PostScript
1 .158 0 r
.67424 .56148 m
.65428 .59642 L
s
% Start of user PostScript
5.2272281 1.8445023 4.6283452 2.8927166 MAarrowhead1
% End of user PostScript
1 .473 0 r
.41319 .68232 m
.38082 .66602 L
s
% Start of user PostScript
-2.6043559 5.4694555 -3.5752948 4.9805096 MAarrowhead1
% End of user PostScript
1 .788 0 r
.32865 .43244 m
.34969 .39805 L
s
% Start of user PostScript
-5.1404838 -2.0266756 -4.5092615 -3.0586043 MAarrowhead1
% End of user PostScript
.897 1 0 r
.59252 .31993 m
.62418 .33738 L
s
% Start of user PostScript
2.775572 -5.4019522 3.7254865 -4.8786355 MAarrowhead1
% End of user PostScript
.581 1 0 r
.66827 .57355 m
.64617 .60737 L
s
% Start of user PostScript
5.0480368 2.2066004 4.3851753 3.2210989 MAarrowhead1
% End of user PostScript
.266 1 0 r
.40188 .67762 m
.37095 .65904 L
s
% Start of user PostScript
-2.9437089 5.3284562 -3.8715452 4.7713491 MAarrowhead1
% End of user PostScript
0 1 .049 r
.335 .42053 m
.35813 .38733 L
s
% Start of user PostScript
-4.9499896 -2.3840774 -4.2562242 -3.38002 MAarrowhead1
% End of user PostScript
0 1 .364 r
.60362 .32503 m
.63378 .34471 L
s
% Start of user PostScript
3.10858 -5.2490488 4.0133089 -4.6587695 MAarrowhead1
% End of user PostScript
0 1 .679 r
.66155 .5853 m
.63742 .61784 L
s
% Start of user PostScript
4.8464509 2.5589094 4.1225514 3.5351914 MAarrowhead1
% End of user PostScript
0 1 .995 r
.391 .67213 m
.36165 .65137 L
s
% Start of user PostScript
-3.2700026 5.1638182 -4.1506202 4.5410215 MAarrowhead1
% End of user PostScript
0 .69 1 r
.34208 .40897 m
.36719 .37712 L
s
% Start of user PostScript
-4.7375357 -2.7309027 -3.9843051 -3.686441 MAarrowhead1
% End of user PostScript
0 .375 1 r
.61426 .3309 m
.64278 .35273 L
s
% Start of user PostScript
3.4277975 -5.072859 4.283327 -4.4182358 MAarrowhead1
% End of user PostScript
0 .06 1 r
.65411 .59666 m
.62805 .62779 L
s
% Start of user PostScript
4.6233647 2.8998663 3.8416387 3.8336008 MAarrowhead1
% End of user PostScript
.335 0 1 r
.73278 .28632 m
.76489 .33146 L
.7866 .38321 L
.79706 .43955 L
.79586 .49826 L
.78306 .55703 L
.75914 .61357 L
.72505 .66565 L
.68213 .71123 L
.63207 .74852 L
.57682 .77606 L
.51855 .79276 L
.45956 .79797 L
.40215 .79149 L
.34859 .77357 L
.30097 .74491 L
.26115 .70664 L
.23071 .66026 L
.21084 .60759 L
.20232 .5507 L
.20548 .49182 L
.2202 .43326 L
.2459 .37732 L
.28158 .32619 L
.32582 .28189 L
.3769 .24614 L
.43281 .22036 L
.49136 .20555 L
.55025 .2023 L
.60716 .21073 L
.65987 .23052 L
.70631 .26088 L
.74465 .30062 L
.77339 .34819 L
.79139 .40172 L
.79796 .45911 L
.79284 .5181 L
.77623 .57638 L
.74877 .63166 L
.71155 .68177 L
.66603 .72475 L
.61399 .75891 L
.55748 .78291 L
.49871 .79581 L
.44 .79709 L
.38363 .78672 L
.33184 .7651 L
.28664 .73307 L
.24982 .69189 L
.22282 .64318 L
Mistroke
.20669 .58886 L
.20208 .53104 L
.20916 .47201 L
.22765 .41407 L
.25683 .35951 L
.29555 .31047 L
.3423 .26886 L
.39524 .23632 L
.45229 .21413 L
.51121 .20316 L
.56969 .20384 L
.62544 .21614 L
.67626 .23958 L
.72017 .27325 L
.75543 .31581 L
.78067 .3656 L
.7949 .42067 L
.79755 .47885 L
.78852 .53786 L
.76817 .59538 L
.7373 .64916 L
.69711 .69709 L
.64919 .73728 L
.59541 .76816 L
.53789 .78851 L
.47888 .79755 L
.4207 .7949 L
.36563 .78068 L
.31584 .75545 L
.27327 .72019 L
.2396 .67629 L
.21615 .62547 L
.20384 .56972 L
.20315 .51124 L
.21412 .45232 L
.2363 .39527 L
.26883 .34233 L
.31044 .29558 L
.35948 .25685 L
.41404 .22766 L
.47197 .20916 L
.53101 .20208 L
.58882 .20669 L
.64315 .22281 L
.69186 .2498 L
.73304 .28662 L
.76508 .33181 L
.78671 .3836 L
.79709 .43996 L
.79581 .49868 L
Mistroke
.78292 .55745 L
.75893 .61396 L
.72478 .666 L
.6818 .71153 L
.63169 .74875 L
.57641 .77621 L
.51813 .79284 L
.45914 .79797 L
.40175 .7914 L
.34822 .7734 L
.30065 .74467 L
.2609 .70633 L
.23053 .6599 L
.21074 .6072 L
.2023 .55028 L
.20555 .4914 L
.22035 .43285 L
.24612 .37693 L
.28186 .32585 L
.32616 .2816 L
.37729 .24592 L
.43323 .22021 L
.49179 .20549 L
.55067 .20232 L
.60756 .21084 L
.66023 .2307 L
.70662 .26113 L
.74489 .30094 L
.77355 .34856 L
.79148 .40212 L
.79797 .45953 L
.79276 .51852 L
.77607 .57678 L
.74854 .63204 L
.71125 .68211 L
.66568 .72503 L
.6136 .75912 L
.55707 .78305 L
.49829 .79586 L
.43958 .79706 L
.38324 .78661 L
.33149 .7649 L
.28635 .7328 L
.24959 .69157 L
.22266 .64281 L
.20662 .58845 L
.20209 .53062 L
.20925 .47159 L
.22782 .41367 L
.25707 .35914 L
Mistroke
.29586 .31014 L
.34266 .26859 L
.39564 .23612 L
.45271 .21401 L
.51163 .20312 L
.5701 .20388 L
.62582 .21627 L
.6766 .23979 L
.72045 .27352 L
.75565 .31614 L
.78081 .36598 L
.79496 .42108 L
.79753 .47927 L
.78842 .53828 L
.76799 .59578 L
.73704 .64953 L
.6968 .6974 L
.64882 .73754 L
.59501 .76834 L
.53747 .78862 L
.47846 .79757 L
.42029 .79484 L
.36525 .78054 L
.3155 .75523 L
.27299 .7199 L
.23939 .67595 L
.21602 .62508 L
.20379 .56931 L
.20319 .51082 L
.21424 .4519 L
.2365 .39487 L
.2691 .34197 L
.31077 .29527 L
.35986 .2566 L
.41445 .22749 L
.4724 .20907 L
.53143 .20207 L
.58923 .20676 L
.64352 .22296 L
.69219 .25003 L
.73331 .28692 L
.76527 .33216 L
.78683 .38399 L
.79712 .44038 L
.79576 .4991 L
.78279 .55786 L
.75872 .61435 L
.7245 .66635 L
.68146 .71183 L
.63131 .74899 L
Mistroke
.576 .77637 L
Mfstroke
1 0 0 r
.73278 .28632 m
.76489 .33146 L
s
% Start of user PostScript
6.98341 -6.4102699 7.9465899 -5.056154 MAarrowhead1
% End of user PostScript
1 .158 0 r
.7866 .38321 m
.79706 .43955 L
s
% Start of user PostScript
8.5978982 -3.5036046 8.9117736 -1.8135527 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57682 .77606 m
.51855 .79276 L
s
% Start of user PostScript
2.3045419 8.2816615 0.55659968 8.7827257 MAarrowhead1
% End of user PostScript
1 .788 0 r
.21084 .60759 m
.20232 .5507 L
s
% Start of user PostScript
-8.6746565 3.2277641 -8.9303125 1.5210231 MAarrowhead1
% End of user PostScript
.897 1 0 r
.43281 .22036 m
.49136 .20555 L
s
% Start of user PostScript
-2.0156118 -8.3891699 -0.25915437 -8.833387 MAarrowhead1
% End of user PostScript
.581 1 0 r
.79139 .40172 m
.79796 .45911 L
s
% Start of user PostScript
8.7417912 -2.9483428 8.9389443 -1.2268062 MAarrowhead1
% End of user PostScript
.266 1 0 r
.55748 .78291 m
.49871 .79581 L
s
% Start of user PostScript
1.7244456 8.4873715 -0.038578443 8.8742487 MAarrowhead1
% End of user PostScript
0 1 .049 r
.20669 .58886 m
.20208 .53104 L
s
% Start of user PostScript
-8.799228 2.6656507 -8.9376593 0.93122818 MAarrowhead1
% End of user PostScript
0 1 .364 r
.45229 .21413 m
.51121 .20316 L
s
% Start of user PostScript
-1.4313664 -8.5761573 0.33626846 -8.9052655 MAarrowhead1
% End of user PostScript
0 1 .679 r
.7949 .42067 m
.79755 .47885 L
s
% Start of user PostScript
8.846903 -2.3800014 8.9264591 -0.63461712 MAarrowhead1
% End of user PostScript
0 1 .995 r
.53789 .78851 m
.47888 .79755 L
s
% Start of user PostScript
1.1366992 8.6554289 -0.63358542 8.9264029 MAarrowhead1
% End of user PostScript
0 .69 1 r
.20384 .56972 m
.20315 .51124 L
s
% Start of user PostScript
-8.8847635 2.0917117 -8.905356 0.33730203 MAarrowhead1
% End of user PostScript
0 .375 1 r
.47197 .20916 m
.53101 .20208 L
s
% Start of user PostScript
-0.84077105 -8.7250984 0.9301995 -8.9376376 MAarrowhead1
% End of user PostScript
0 .06 1 r
.79709 .43996 m
.79581 .49868 L
s
% Start of user PostScript
8.9127674 -1.8011016 8.8743735 -0.039612739 MAarrowhead1
% End of user PostScript
0 .8 1 r
.48144 .44265 m
.49366 .43867 L
.50613 .43709 L
.51836 .43798 L
.52986 .4413 L
.5402 .44693 L
.54896 .45464 L
.55579 .46413 L
.56044 .47503 L
.56271 .48691 L
.56253 .4993 L
.55989 .51172 L
.5549 .52368 L
.54775 .53471 L
.53873 .54438 L
.52819 .55231 L
.51654 .55818 L
.50425 .56177 L
.49179 .56294 L
.47965 .56163 L
.46831 .55791 L
.45821 .55192 L
.44975 .54388 L
.44327 .53413 L
.43901 .52303 L
.43714 .51104 L
.43775 .4986 L
.44079 .48623 L
.44616 .47439 L
.45364 .46356 L
.46294 .45416 L
.4737 .44656 L
.48549 .44105 L
.49784 .43786 L
.51029 .43711 L
.52232 .43883 L
.53349 .44294 L
.54333 .4493 L
.55148 .45764 L
.55761 .46765 L
.56147 .47893 L
.56293 .49103 L
.56191 .50349 L
.55847 .51581 L
.55272 .52751 L
.54491 .53813 L
.53534 .54725 L
.52438 .55452 L
.51247 .55965 L
.50006 .56244 L
Mistroke
.48765 .56277 L
.47573 .56065 L
.46476 .55614 L
.45517 .54943 L
.44734 .54078 L
.44158 .53053 L
.43811 .51908 L
.43707 .50689 L
.4385 .49442 L
.44234 .48217 L
.44845 .47062 L
.45658 .46023 L
.46641 .45139 L
.47756 .44446 L
.4896 .43972 L
.50204 .43733 L
.5144 .43741 L
.52619 .43995 L
.53696 .44484 L
.54628 .45189 L
.55378 .46084 L
.55917 .47132 L
.56224 .48292 L
.56286 .4952 L
.56102 .50767 L
.55678 .51983 L
.55032 .53122 L
.54188 .54138 L
.5318 .54991 L
.52047 .55649 L
.50833 .56085 L
.49587 .56283 L
.48357 .56233 L
.47192 .55939 L
.46136 .55412 L
.45233 .54673 L
.44516 .5375 L
.44015 .5268 L
.43749 .51505 L
.43728 .50271 L
.43953 .49026 L
.44415 .47819 L
.45097 .46698 L
.45971 .45707 L
.47003 .44884 L
.48153 .44262 L
.49375 .43865 L
.50622 .43708 L
.51844 .43799 L
.52994 .44133 L
Mistroke
.54027 .44698 L
.54901 .4547 L
.55583 .4642 L
.56046 .47511 L
.56272 .48699 L
.56252 .49939 L
.55986 .51181 L
.55485 .52376 L
.54769 .53478 L
.53866 .54444 L
.52811 .55236 L
.51646 .55821 L
.50416 .56179 L
.4917 .56294 L
.47956 .56161 L
.46823 .55788 L
.45814 .55186 L
.4497 .54382 L
.44323 .53405 L
.43899 .52295 L
.43714 .51095 L
.43776 .49851 L
.44082 .48614 L
.44621 .47431 L
.4537 .46349 L
.46302 .4541 L
.47378 .44651 L
.48557 .44102 L
.49793 .43785 L
.51037 .43711 L
.52241 .43885 L
.53356 .44298 L
.5434 .44935 L
.55153 .45771 L
.55764 .46773 L
.56149 .47901 L
.56293 .49112 L
.5619 .50358 L
.55843 .5159 L
.55268 .52759 L
.54485 .5382 L
.53527 .54731 L
.5243 .55456 L
.51238 .55968 L
.49997 .56245 L
.48756 .56277 L
.47565 .56062 L
.46468 .5561 L
.45511 .54938 L
.44729 .54071 L
Mistroke
.44155 .53045 L
.43809 .519 L
.43707 .5068 L
.43852 .49433 L
.44238 .48208 L
.4485 .47054 L
.45664 .46016 L
.46649 .45133 L
.47765 .44442 L
.48968 .43969 L
.50213 .43733 L
.51448 .43742 L
.52627 .43997 L
.53703 .44488 L
.54634 .45195 L
.55382 .46091 L
.5592 .4714 L
.56225 .48301 L
.56286 .49529 L
.561 .50776 L
.55675 .51992 L
.55027 .53129 L
.54181 .54144 L
.53172 .54997 L
.52038 .55653 L
.50824 .56088 L
.49578 .56283 L
.48348 .56232 L
.47184 .55936 L
.46129 .55408 L
.45227 .54667 L
.44512 .53743 L
.44012 .52672 L
.43748 .51496 L
.43728 .50262 L
.43955 .49017 L
.44419 .47811 L
.45102 .4669 L
.45978 .457 L
.47011 .44879 L
.48161 .44258 L
.49384 .43863 L
.50631 .43708 L
.51853 .43801 L
.53002 .44137 L
.54034 .44703 L
.54907 .45476 L
.55588 .46428 L
.56049 .47519 L
.56273 .48708 L
Mistroke
.56251 .49948 L
Mfstroke
1 0 0 r
.48144 .44265 m
.49366 .43867 L
s
% Start of user PostScript
-0.55674152 -1.7204265 -0.19015754 -1.8400145 MAarrowhead1
% End of user PostScript
1 .158 0 r
.50613 .43709 m
.51836 .43798 L
s
% Start of user PostScript
0.18388936 -1.8873894 0.55071934 -1.8606919 MAarrowhead1
% End of user PostScript
1 .473 0 r
.56253 .4993 m
.55989 .51172 L
s
% Start of user PostScript
1.8758188 -0.021006397 1.7965951 0.35159069 MAarrowhead1
% End of user PostScript
1 .788 0 r
.49179 .56294 m
.47965 .56163 L
s
% Start of user PostScript
-0.24636797 1.8880891 -0.61055921 1.8489814 MAarrowhead1
% End of user PostScript
.897 1 0 r
.43775 .4986 m
.44079 .48623 L
s
% Start of user PostScript
-1.867613 -0.041880904 -1.776259 -0.41317541 MAarrowhead1
% End of user PostScript
.581 1 0 r
.51029 .43711 m
.52232 .43883 L
s
% Start of user PostScript
0.30857326 -1.8866942 0.66972175 -1.8352196 MAarrowhead1
% End of user PostScript
.266 1 0 r
.56191 .50349 m
.55847 .51581 L
s
% Start of user PostScript
1.8573352 0.10472174 1.7539523 0.47430177 MAarrowhead1
% End of user PostScript
0 1 .049 r
.48765 .56277 m
.47573 .56065 L
s
% Start of user PostScript
-0.37043623 1.8832062 -0.7281413 1.8194218 MAarrowhead1
% End of user PostScript
0 1 .364 r
.4385 .49442 m
.44234 .48217 L
s
% Start of user PostScript
-1.8449969 -0.16744641 -1.7296998 -0.53490194 MAarrowhead1
% End of user PostScript
0 1 .679 r
.5144 .43741 m
.52619 .43995 L
s
% Start of user PostScript
0.43188824 -1.877629 0.78575307 -1.8016056 MAarrowhead1
% End of user PostScript
0 1 .995 r
.56102 .50767 m
.55678 .51983 L
s
% Start of user PostScript
1.8306119 0.22998531 1.7035284 0.59490871 MAarrowhead1
% End of user PostScript
0 .69 1 r
.48357 .56233 m
.47192 .55939 L
s
% Start of user PostScript
-0.49286113 1.8699688 -0.84249314 1.7817908 MAarrowhead1
% End of user PostScript
0 .375 1 r
.43953 .49026 m
.44415 .47819 L
s
% Start of user PostScript
-1.814196 -0.29226907 -1.6754672 -0.65425549 MAarrowhead1
% End of user PostScript
0 .06 1 r
.51844 .43799 m
.52994 .44133 L
s
% Start of user PostScript
0.55328724 -1.860234 0.89829856 -1.7599993 MAarrowhead1
% End of user PostScript
1 0 .096 r
.47914 .47656 m
.48473 .4723 L
.49091 .46912 L
.49745 .46715 L
.50409 .46647 L
.51057 .46711 L
.51664 .46904 L
.52205 .47218 L
.52659 .47642 L
.5301 .48158 L
.53242 .48746 L
.53347 .49384 L
.5332 .50046 L
.53164 .50706 L
.52883 .51338 L
.52489 .51918 L
.51997 .52422 L
.51427 .52832 L
.50801 .5313 L
.50143 .53305 L
.4948 .53351 L
.48838 .53265 L
.4824 .53051 L
.47712 .52718 L
.47274 .52277 L
.46943 .51748 L
.46731 .51149 L
.46648 .50506 L
.46697 .49843 L
.46875 .49186 L
.47176 .4856 L
.47587 .47992 L
.48094 .47502 L
.48675 .4711 L
.49308 .46832 L
.49968 .46678 L
.5063 .46654 L
.51266 .46762 L
.51854 .46996 L
.52368 .47349 L
.52789 .47806 L
.53101 .48349 L
.53292 .48956 L
.53353 .49605 L
.53282 .50269 L
.53083 .50922 L
.52762 .5154 L
.52334 .52097 L
.51813 .52571 L
.51222 .52945 L
Mistroke
.50582 .53203 L
.4992 .53335 L
.49261 .53337 L
.48631 .53208 L
.48054 .52952 L
.47554 .52581 L
.4715 .52109 L
.46858 .51553 L
.46689 .50937 L
.4665 .50284 L
.46742 .4962 L
.46963 .48971 L
.47302 .48362 L
.47748 .47817 L
.48281 .47359 L
.48883 .47003 L
.49528 .46766 L
.50191 .46655 L
.50847 .46676 L
.5147 .46827 L
.52035 .47102 L
.52521 .47492 L
.52907 .47979 L
.53179 .48546 L
.53327 .49171 L
.53344 .49827 L
.53229 .50491 L
.52988 .51135 L
.5263 .51734 L
.52168 .52266 L
.51622 .52709 L
.51011 .53045 L
.50361 .53262 L
.49697 .53351 L
.49045 .53308 L
.4843 .53135 L
.47877 .5284 L
.47407 .52433 L
.47039 .5193 L
.46787 .51352 L
.46661 .50721 L
.46666 .50061 L
.46803 .49399 L
.47064 .48761 L
.47441 .48171 L
.47918 .47653 L
.48477 .47227 L
.49096 .4691 L
.4975 .46714 L
.50414 .46647 L
Mistroke
.51062 .46712 L
.51668 .46906 L
.52208 .47221 L
.52662 .47645 L
.53012 .48162 L
.53243 .48751 L
.53347 .49389 L
.5332 .50051 L
.53162 .5071 L
.5288 .51342 L
.52486 .51922 L
.51993 .52426 L
.51423 .52834 L
.50796 .53132 L
.50139 .53306 L
.49476 .53351 L
.48833 .53264 L
.48236 .53049 L
.47709 .52715 L
.47271 .52274 L
.46941 .51744 L
.4673 .51145 L
.46648 .50501 L
.46698 .49838 L
.46877 .49181 L
.47178 .48556 L
.47591 .47988 L
.48098 .47499 L
.48679 .47108 L
.49313 .4683 L
.49973 .46677 L
.50634 .46654 L
.51271 .46763 L
.51858 .46999 L
.52371 .47352 L
.52792 .47809 L
.53103 .48353 L
.53292 .48961 L
.53353 .49609 L
.53281 .50274 L
.53081 .50927 L
.5276 .51544 L
.5233 .521 L
.51809 .52574 L
.51217 .52947 L
.50578 .53204 L
.49915 .53336 L
.49256 .53337 L
.48626 .53206 L
.48051 .5295 L
Mistroke
.47551 .52578 L
.47148 .52105 L
.46856 .51549 L
.46688 .50933 L
.4665 .50279 L
.46744 .49615 L
.46965 .48966 L
.47305 .48358 L
.47751 .47814 L
.48286 .47356 L
.48887 .47001 L
.49533 .46765 L
.50196 .46655 L
.50852 .46676 L
.51475 .46828 L
.52039 .47105 L
.52524 .47495 L
.52909 .47983 L
.53181 .48551 L
.53327 .49175 L
.53343 .49832 L
.53228 .50495 L
.52986 .51139 L
.52627 .51739 L
.52165 .5227 L
.51618 .52712 L
.51007 .53047 L
.50357 .53263 L
.49692 .53351 L
.4904 .53307 L
.48426 .53134 L
.47873 .52837 L
.47404 .5243 L
.47037 .51926 L
.46786 .51348 L
.46661 .50716 L
.46667 .50056 L
.46804 .49394 L
.47066 .48756 L
.47444 .48167 L
.47922 .47649 L
.48481 .47224 L
.491 .46908 L
.49755 .46713 L
.50419 .46647 L
.51066 .46713 L
.51672 .46908 L
.52212 .47224 L
.52665 .47649 L
.53014 .48166 L
Mistroke
.53244 .48755 L
Mfstroke
1 0 0 r
.47914 .47656 m
.48473 .4723 L
s
% Start of user PostScript
-0.62571057 -0.7031094 -0.45819108 -0.83109738 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49091 .46912 m
.49745 .46715 L
s
% Start of user PostScript
-0.27268945 -0.92646815 -0.076485848 -0.98547877 MAarrowhead1
% End of user PostScript
1 .473 0 r
.53242 .48746 m
.53347 .49384 L
s
% Start of user PostScript
0.97255478 -0.37608573 1.0040402 -0.18480938 MAarrowhead1
% End of user PostScript
1 .788 0 r
.50801 .5313 m
.50143 .53305 L
s
% Start of user PostScript
0.24029619 0.93899458 0.043043898 0.99163428 MAarrowhead1
% End of user PostScript
.897 1 0 r
.46731 .51149 m
.46648 .50506 L
s
% Start of user PostScript
-0.98055842 0.34481028 -1.0054739 0.15178064 MAarrowhead1
% End of user PostScript
.581 1 0 r
.49308 .46832 m
.49968 .46678 L
s
% Start of user PostScript
-0.20763636 -0.9504793 -0.0095541966 -0.9966897 MAarrowhead1
% End of user PostScript
.266 1 0 r
.53292 .48956 m
.53353 .49605 L
s
% Start of user PostScript
0.98747424 -0.3131523 1.0057921 -0.11858351 MAarrowhead1
% End of user PostScript
0 1 .049 r
.50582 .53203 m
.4992 .53335 L
s
% Start of user PostScript
0.17474618 0.96090959 -0.023946104 1.0006394 MAarrowhead1
% End of user PostScript
0 1 .364 r
.46689 .50937 m
.4665 .50284 L
s
% Start of user PostScript
-0.99329458 0.28114692 -1.0049946 0.085254836 MAarrowhead1
% End of user PostScript
0 1 .679 r
.49528 .46766 m
.50191 .46655 L
s
% Start of user PostScript
-0.14166214 -0.97027385 0.05741984 -1.003479 MAarrowhead1
% End of user PostScript
0 1 .995 r
.53327 .49171 m
.53344 .49827 L
s
% Start of user PostScript
0.99801297 -0.24882964 1.0030821 -0.051831579 MAarrowhead1
% End of user PostScript
0 .69 1 r
.50361 .53262 m
.49697 .53351 L
s
% Start of user PostScript
0.10842095 0.97856172 -0.090829875 1.0052054 MAarrowhead1
% End of user PostScript
0 .375 1 r
.46661 .50721 m
.46666 .50061 L
s
% Start of user PostScript
-1.0016242 0.21623631 -1.0000567 0.018350821 MAarrowhead1
% End of user PostScript
0 .06 1 r
.4975 .46714 m
.50414 .46647 L
s
% Start of user PostScript
-0.075059469 -0.98576398 0.12413914 -1.0058166 MAarrowhead1
% End of user PostScript
1 0 .785 r
.41185 .40529 m
.43459 .38728 L
.45989 .3737 L
.48677 .36507 L
.51417 .36174 L
.54101 .36383 L
.56624 .37127 L
.58887 .38376 L
.60802 .40081 L
.62292 .42176 L
.63301 .44577 L
.63787 .47192 L
.63732 .49916 L
.63138 .52644 L
.62028 .55268 L
.60447 .57686 L
.58455 .59801 L
.56132 .61533 L
.53568 .62811 L
.50864 .63587 L
.48126 .63829 L
.45462 .63529 L
.42975 .62698 L
.40765 .61368 L
.38917 .59592 L
.37503 .5744 L
.36581 .54996 L
.36185 .52356 L
.36331 .49623 L
.37013 .46905 L
.38206 .44309 L
.39861 .41936 L
.41914 .39879 L
.44284 .3822 L
.46879 .37023 L
.49596 .36335 L
.52329 .36183 L
.54971 .36574 L
.57418 .37492 L
.59573 .389 L
.61353 .40745 L
.62687 .42952 L
.63523 .45436 L
.63829 .48099 L
.63592 .50837 L
.62821 .53542 L
.61547 .56108 L
.5982 .58434 L
.57708 .60429 L
.55293 .62015 L
Mistroke
.52671 .63129 L
.49943 .63728 L
.47218 .63789 L
.44602 .63308 L
.42198 .62305 L
.401 .60819 L
.3839 .58908 L
.37137 .56648 L
.36388 .54127 L
.36173 .51443 L
.36501 .48704 L
.37359 .46015 L
.38713 .43482 L
.40509 .41206 L
.42679 .39274 L
.45135 .37764 L
.47783 .36733 L
.50517 .36223 L
.53232 .36254 L
.55819 .36825 L
.58178 .37912 L
.60216 .39474 L
.61853 .41449 L
.63025 .4376 L
.63686 .46315 L
.6381 .49015 L
.63391 .51754 L
.62447 .54424 L
.61015 .5692 L
.5915 .59145 L
.56927 .61011 L
.54431 .62444 L
.51761 .6339 L
.49023 .63809 L
.46322 .63687 L
.43766 .63028 L
.41455 .61857 L
.39479 .60221 L
.37916 .58184 L
.36827 .55826 L
.36255 .53239 L
.36223 .50525 L
.36731 .4779 L
.3776 .45142 L
.3927 .42685 L
.412 .40515 L
.43476 .38717 L
.46008 .37362 L
.48696 .36503 L
.51436 .36173 L
Mistroke
.5412 .36386 L
.56641 .37134 L
.58902 .38387 L
.60814 .40095 L
.62301 .42192 L
.63306 .44595 L
.63788 .47211 L
.63729 .49936 L
.63132 .52663 L
.62019 .55286 L
.60434 .57702 L
.5844 .59815 L
.56114 .61543 L
.53549 .62818 L
.50844 .6359 L
.48106 .63829 L
.45443 .63525 L
.42958 .6269 L
.4075 .61357 L
.38905 .59578 L
.37495 .57424 L
.36576 .54978 L
.36184 .52336 L
.36334 .49604 L
.3702 .46886 L
.38216 .44291 L
.39874 .4192 L
.4193 .39866 L
.44302 .38209 L
.46898 .37016 L
.49616 .36332 L
.52349 .36184 L
.54989 .36579 L
.57434 .375 L
.59587 .38912 L
.61364 .40759 L
.62695 .42969 L
.63527 .45455 L
.63829 .48119 L
.63588 .50857 L
.62814 .53561 L
.61537 .56125 L
.59807 .5845 L
.57692 .60442 L
.55275 .62025 L
.52651 .63136 L
.49923 .63731 L
.47199 .63787 L
.44584 .63302 L
.42182 .62296 L
Mistroke
.40086 .60806 L
.3838 .58893 L
.37129 .5663 L
.36384 .54108 L
.36173 .51424 L
.36505 .48684 L
.37367 .45996 L
.38724 .43465 L
.40524 .4119 L
.42695 .39262 L
.45154 .37754 L
.47802 .36728 L
.50537 .36222 L
.53251 .36257 L
.55837 .36831 L
.58194 .37922 L
.60229 .39487 L
.61864 .41465 L
.63032 .43777 L
.63689 .46334 L
.63809 .49035 L
.63386 .51774 L
.62439 .54443 L
.61003 .56937 L
.59136 .5916 L
.5691 .61023 L
.54412 .62453 L
.51742 .63394 L
.49003 .6381 L
.46303 .63684 L
.43749 .63021 L
.4144 .61847 L
.39466 .60208 L
.37906 .58168 L
.36821 .55808 L
.36253 .5322 L
.36225 .50505 L
.36737 .47771 L
.37769 .45124 L
.39282 .42668 L
.41215 .405 L
.43493 .38705 L
.46027 .37354 L
.48716 .36498 L
.51456 .36173 L
.54138 .3639 L
.56659 .37141 L
.58917 .38397 L
.60826 .40109 L
.6231 .42208 L
Mistroke
.63311 .44613 L
Mfstroke
1 0 0 r
.41185 .40529 m
.43459 .38728 L
s
% Start of user PostScript
-2.6445324 -2.8413144 -1.9624175 -3.3815693 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45989 .3737 m
.48677 .36507 L
s
% Start of user PostScript
-1.2032856 -3.7891112 -0.39692961 -4.0479458 MAarrowhead1
% End of user PostScript
1 .473 0 r
.63301 .44577 m
.63787 .47192 L
s
% Start of user PostScript
3.9901534 -1.6268439 4.1359919 -0.84252124 MAarrowhead1
% End of user PostScript
1 .788 0 r
.53568 .62811 m
.50864 .63587 L
s
% Start of user PostScript
1.070384 3.8432971 0.25917056 4.076008 MAarrowhead1
% End of user PostScript
.897 1 0 r
.36581 .54996 m
.36185 .52356 L
s
% Start of user PostScript
-4.025805 1.4988338 -4.1446242 0.70676009 MAarrowhead1
% End of user PostScript
.581 1 0 r
.46879 .37023 m
.49596 .36335 L
s
% Start of user PostScript
-0.93629503 -3.8932194 -0.12112399 -4.0995483 MAarrowhead1
% End of user PostScript
.266 1 0 r
.63523 .45436 m
.63829 .48099 L
s
% Start of user PostScript
4.0569906 -1.3691609 4.1486585 -0.57021488 MAarrowhead1
% End of user PostScript
0 1 .049 r
.52671 .63129 m
.49943 .63728 L
s
% Start of user PostScript
0.8011673 3.9388225 -0.017056958 4.1185407 MAarrowhead1
% End of user PostScript
0 1 .364 r
.36388 .54127 m
.36173 .51443 L
s
% Start of user PostScript
-4.0836754 1.237969 -4.1480904 0.43303708 MAarrowhead1
% End of user PostScript
0 1 .679 r
.47783 .36733 m
.50517 .36223 L
s
% Start of user PostScript
-0.66515078 -3.980056 0.15521898 -4.132964 MAarrowhead1
% End of user PostScript
0 1 .995 r
.63686 .46315 m
.6381 .49015 L
s
% Start of user PostScript
4.1058298 -1.1054038 4.1429205 -0.29537888 MAarrowhead1
% End of user PostScript
0 .69 1 r
.51761 .6339 m
.49023 .63809 L
s
% Start of user PostScript
0.52839634 4.0168741 -0.29320881 4.1428023 MAarrowhead1
% End of user PostScript
0 .375 1 r
.36255 .53239 m
.36223 .50525 L
s
% Start of user PostScript
-4.1234293 0.97161221 -4.1331544 0.15739299 MAarrowhead1
% End of user PostScript
0 .06 1 r
.48696 .36503 m
.51436 .36173 L
s
% Start of user PostScript
-0.39105572 -4.049236 0.43087335 -4.1480447 MAarrowhead1
% End of user PostScript
1 0 .452 r
.6538 .28819 m
.68905 .31764 L
.71688 .35425 L
.73619 .39659 L
.74624 .44298 L
.74662 .4916 L
.73732 .54056 L
.71871 .58793 L
.69152 .63184 L
.65681 .67058 L
.61595 .70263 L
.57053 .72672 L
.52235 .74192 L
.47329 .74762 L
.42528 .7436 L
.3802 .73002 L
.33982 .70742 L
.30573 .67667 L
.27926 .639 L
.26146 .59586 L
.25302 .54897 L
.25427 .50015 L
.26516 .45133 L
.28528 .40441 L
.31382 .36125 L
.34966 .32353 L
.39141 .29274 L
.43741 .27009 L
.48588 .25645 L
.5349 .25238 L
.58255 .25802 L
.62695 .27316 L
.66638 .2972 L
.69928 .3292 L
.72435 .36791 L
.74062 .4118 L
.74745 .45915 L
.74457 .5081 L
.73209 .55673 L
.7105 .60314 L
.68064 .6455 L
.6437 .68215 L
.60112 .71166 L
.55457 .73285 L
.50588 .74491 L
.45696 .74735 L
.40972 .74009 L
.36603 .7234 L
.3276 .69795 L
.29594 .66473 L
Mistroke
.27228 .62504 L
.25756 .58045 L
.25235 .5327 L
.25687 .48366 L
.27092 .43527 L
.29397 .38942 L
.3251 .3479 L
.3631 .31236 L
.40646 .28418 L
.4535 .26447 L
.50237 .254 L
.55114 .25319 L
.59791 .26207 L
.64083 .28028 L
.67822 .30711 L
.70862 .34152 L
.73084 .38215 L
.74399 .4274 L
.74757 .4755 L
.74143 .52456 L
.72582 .57266 L
.70134 .6179 L
.66896 .65852 L
.62996 .69292 L
.58585 .71975 L
.53837 .73795 L
.48938 .74681 L
.44082 .74599 L
.39457 .73551 L
.35247 .71579 L
.31615 .68761 L
.28705 .65205 L
.2663 .61054 L
.25473 .56468 L
.25278 .51628 L
.26054 .46725 L
.27769 .4195 L
.30357 .37491 L
.33716 .33523 L
.37714 .30202 L
.42194 .27657 L
.4698 .2599 L
.51885 .25264 L
.56716 .2551 L
.61283 .26717 L
.65408 .28837 L
.68928 .31788 L
.71705 .35454 L
.7363 .39691 L
.74628 .44332 L
Mistroke
.74659 .49196 L
.73722 .54091 L
.71855 .58826 L
.6913 .63214 L
.65654 .67084 L
.61563 .70283 L
.57019 .72686 L
.522 .74199 L
.47294 .74762 L
.42494 .74354 L
.37989 .72989 L
.33955 .70723 L
.30551 .67643 L
.2791 .6387 L
.26137 .59554 L
.25299 .54862 L
.25431 .4998 L
.26528 .45098 L
.28545 .40409 L
.31405 .36096 L
.34994 .32329 L
.39172 .29255 L
.43776 .26996 L
.48623 .25639 L
.53525 .25238 L
.58288 .2581 L
.62726 .2733 L
.66664 .2974 L
.69949 .32946 L
.7245 .36821 L
.74071 .41212 L
.74747 .45949 L
.74451 .50845 L
.73196 .55708 L
.71031 .60346 L
.6804 .64579 L
.64341 .68239 L
.6008 .71184 L
.55423 .73297 L
.50553 .74496 L
.45661 .74734 L
.4094 .74 L
.36574 .72325 L
.32735 .69774 L
.29574 .66447 L
.27214 .62474 L
.25749 .58012 L
.25235 .53235 L
.25693 .48331 L
.27106 .43493 L
Mistroke
.29416 .3891 L
.32535 .34762 L
.36339 .31213 L
.40679 .28401 L
.45385 .26436 L
.50272 .25396 L
.55149 .25322 L
.59823 .26216 L
.64112 .28044 L
.67847 .30734 L
.70881 .34179 L
.73096 .38246 L
.74405 .42773 L
.74756 .47585 L
.74135 .52491 L
.72567 .57299 L
.70114 .61821 L
.66871 .65879 L
.62966 .69314 L
.58552 .71991 L
.53802 .73805 L
.48903 .74684 L
.44048 .74595 L
.39425 .7354 L
.35218 .71562 L
.31591 .68738 L
.28687 .65178 L
.26619 .61022 L
.25468 .56434 L
.25281 .51593 L
.26063 .4669 L
.27785 .41917 L
.30379 .37461 L
.33742 .33497 L
.37744 .3018 L
.42227 .27642 L
.47015 .25981 L
.5192 .25263 L
.5675 .25515 L
.61315 .26729 L
.65435 .28855 L
.6895 .31812 L
.71721 .35482 L
.7364 .39723 L
.74631 .44366 L
.74656 .49231 L
.73712 .54126 L
.71838 .58858 L
.69107 .63244 L
.65626 .67109 L
Mistroke
.61532 .70303 L
Mfstroke
1 0 0 r
.6538 .28819 m
.68905 .31764 L
s
% Start of user PostScript
4.6140272 -6.354327 5.6714328 -5.4706924 MAarrowhead1
% End of user PostScript
1 .158 0 r
.71688 .35425 m
.73619 .39659 L
s
% Start of user PostScript
6.5062575 -4.3723552 7.0857378 -3.1024207 MAarrowhead1
% End of user PostScript
1 .473 0 r
.61595 .70263 m
.57053 .72672 L
s
% Start of user PostScript
3.4783577 6.078809 2.1159135 6.8016147 MAarrowhead1
% End of user PostScript
1 .788 0 r
.27926 .639 m
.26146 .59586 L
s
% Start of user PostScript
-6.6221125 4.169886 -7.1562134 2.8758767 MAarrowhead1
% End of user PostScript
.897 1 0 r
.39141 .29274 m
.43741 .27009 L
s
% Start of user PostScript
-3.2577925 -6.217697 -1.8775588 -6.8974026 MAarrowhead1
% End of user PostScript
.581 1 0 r
.72435 .36791 m
.74062 .4118 L
s
% Start of user PostScript
6.730621 -3.9627908 7.2187499 -2.6461423 MAarrowhead1
% End of user PostScript
.266 1 0 r
.60112 .71166 m
.55457 .73285 L
s
% Start of user PostScript
3.0336132 6.3496872 1.6371212 6.9855387 MAarrowhead1
% End of user PostScript
0 1 .049 r
.27228 .62504 m
.25756 .58045 L
s
% Start of user PostScript
-6.8316627 3.7512994 -7.2732781 2.4134723 MAarrowhead1
% End of user PostScript
0 1 .364 r
.40646 .28418 m
.4535 .26447 L
s
% Start of user PostScript
-2.8060684 -6.4746331 -1.3948673 -7.0659251 MAarrowhead1
% End of user PostScript
0 1 .679 r
.73084 .38215 m
.74399 .4274 L
s
% Start of user PostScript
6.9251255 -3.5356463 7.3197375 -2.1781248 MAarrowhead1
% End of user PostScript
0 1 .995 r
.58585 .71975 m
.53837 .73795 L
s
% Start of user PostScript
2.5754106 6.5923962 1.151066 7.1384727 MAarrowhead1
% End of user PostScript
0 .69 1 r
.2663 .61054 m
.25473 .56468 L
s
% Start of user PostScript
-7.0109057 3.3160709 -7.3580765 1.940361 MAarrowhead1
% End of user PostScript
0 .375 1 r
.42194 .27657 m
.4698 .2599 L
s
% Start of user PostScript
-2.3418957 -6.7028459 -0.9059878 -7.2031011 MAarrowhead1
% End of user PostScript
0 .06 1 r
.7363 .39691 m
.74628 .44332 L
s
% Start of user PostScript
7.0889081 -3.0928166 7.3882526 -1.7004446 MAarrowhead1
% End of user PostScript
1 .456 0 r
.78539 .2953 m
.81338 .35094 L
.82906 .41243 L
.83183 .47735 L
.82158 .54316 L
.79871 .60728 L
.76411 .66719 L
.71915 .72054 L
.66558 .76523 L
.60552 .79952 L
.54132 .82204 L
.4755 .83193 L
.41063 .8288 L
.34928 .81275 L
.29384 .78444 L
.24649 .74496 L
.20909 .69587 L
.18311 .63909 L
.16956 .57685 L
.16898 .51159 L
.1814 .44588 L
.20631 .3823 L
.24276 .32333 L
.2893 .2713 L
.3441 .22824 L
.40503 .19585 L
.46968 .1754 L
.53553 .16768 L
.59998 .17301 L
.6605 .19117 L
.71473 .22145 L
.76053 .26266 L
.7961 .31319 L
.82006 .37104 L
.83145 .43396 L
.82983 .49948 L
.81527 .56501 L
.78834 .62799 L
.75009 .68595 L
.70203 .73661 L
.64603 .77798 L
.58431 .80844 L
.51928 .8268 L
.45349 .83234 L
.38952 .82483 L
.32989 .80457 L
.27694 .77236 L
.23274 .72946 L
.19903 .67756 L
.17714 .61868 L
Mistroke
.16791 .55515 L
.17172 .48946 L
.18841 .42417 L
.21733 .36187 L
.25734 .30498 L
.30688 .25575 L
.36399 .21611 L
.42644 .1876 L
.49179 .17136 L
.55745 .16801 L
.62086 .1777 L
.67952 .20003 L
.73114 .23414 L
.77369 .27868 L
.8055 .3319 L
.82531 .39172 L
.83236 .4558 L
.82637 .5216 L
.80757 .58656 L
.77669 .64812 L
.73496 .70387 L
.68401 .75162 L
.62583 .78949 L
.56272 .816 L
.49714 .83011 L
.43168 .83127 L
.3689 .81942 L
.31126 .79504 L
.26103 .75907 L
.22018 .71294 L
.19031 .65846 L
.1726 .59775 L
.16773 .53321 L
.17591 .46736 L
.1968 .4028 L
.22959 .34205 L
.273 .2875 L
.32531 .24129 L
.38448 .20523 L
.44819 .18074 L
.51392 .16878 L
.57911 .16982 L
.6412 .18382 L
.69774 .21023 L
.74653 .248 L
.78564 .29567 L
.81353 .35136 L
.82913 .41288 L
.8318 .47782 L
.82146 .54363 L
Mistroke
.7985 .60773 L
.76382 .6676 L
.71879 .72089 L
.66517 .76552 L
.60508 .79972 L
.54085 .82216 L
.47503 .83196 L
.41018 .82873 L
.34886 .81259 L
.29347 .78419 L
.24619 .74464 L
.20886 .69548 L
.18297 .63866 L
.16951 .57639 L
.16903 .51112 L
.18153 .44542 L
.20654 .38186 L
.24306 .32293 L
.28966 .27096 L
.34452 .22797 L
.40548 .19566 L
.47016 .17529 L
.536 .16767 L
.60043 .17309 L
.66092 .19134 L
.71509 .22171 L
.76082 .26299 L
.79632 .31358 L
.82018 .37148 L
.83148 .43443 L
.82977 .49995 L
.81512 .56547 L
.7881 .62842 L
.74978 .68634 L
.70165 .73694 L
.64561 .77824 L
.58385 .80862 L
.5188 .82689 L
.45302 .83233 L
.38908 .82473 L
.32949 .80438 L
.27659 .77209 L
.23246 .72912 L
.19883 .67716 L
.17702 .61824 L
.16789 .55468 L
.17179 .48898 L
.18857 .42371 L
.21757 .36144 L
.25766 .3046 L
Mistroke
.30726 .25543 L
.36442 .21586 L
.42691 .18744 L
.49226 .17129 L
.55791 .16804 L
.6213 .17781 L
.67992 .20023 L
.73148 .23442 L
.77396 .27903 L
.80568 .33231 L
.82541 .39217 L
.83237 .45626 L
.82628 .52207 L
.80739 .58702 L
.77643 .64855 L
.73463 .70425 L
.68361 .75193 L
.6254 .78972 L
.56226 .81615 L
.49667 .83017 L
.43122 .83123 L
.36847 .81929 L
.31087 .79482 L
.2607 .75878 L
.21993 .71258 L
.19014 .65804 L
.17252 .5973 L
.16774 .53274 L
.17601 .46689 L
.19699 .40235 L
.22987 .34163 L
.27334 .28714 L
.32571 .24099 L
.38492 .20501 L
.44865 .18061 L
.51439 .16874 L
.57957 .16988 L
.64163 .18396 L
.69812 .21046 L
.74684 .24831 L
.78588 .29605 L
.81369 .35178 L
.82919 .41334 L
.83178 .47829 L
.82134 .5441 L
.79829 .60818 L
.76353 .66801 L
.71844 .72125 L
.66476 .7658 L
.60463 .79992 L
Mistroke
.54038 .82228 L
Mfstroke
1 0 0 r
.78539 .2953 m
.81338 .35094 L
s
% Start of user PostScript
8.5618267 -6.1409865 9.4013274 -4.4718511 MAarrowhead1
% End of user PostScript
1 .158 0 r
.82906 .41243 m
.83183 .47735 L
s
% Start of user PostScript
9.871864 -2.6272136 9.9549696 -0.67946849 MAarrowhead1
% End of user PostScript
1 .473 0 r
.54132 .82204 m
.4755 .83193 L
s
% Start of user PostScript
1.2396467 9.6613247 -0.73507644 9.9579973 MAarrowhead1
% End of user PostScript
1 .788 0 r
.16956 .57685 m
.16898 .51159 L
s
% Start of user PostScript
-9.9131534 2.3054201 -9.9304862 0.34779369 MAarrowhead1
% End of user PostScript
.897 1 0 r
.46968 .1754 m
.53553 .16768 L
s
% Start of user PostScript
-0.90946554 -9.7381122 1.0658349 -9.9695814 MAarrowhead1
% End of user PostScript
.581 1 0 r
.83145 .43396 m
.82983 .49948 L
s
% Start of user PostScript
9.9434453 -1.9810691 9.894986 -0.015733051 MAarrowhead1
% End of user PostScript
.266 1 0 r
.51928 .8268 m
.45349 .83234 L
s
% Start of user PostScript
0.57827543 9.8040964 -1.395411 9.9701054 MAarrowhead1
% End of user PostScript
0 1 .049 r
.16791 .55515 m
.17172 .48946 L
s
% Start of user PostScript
-9.9627061 1.6545204 -9.8485085 -0.31634504 MAarrowhead1
% End of user PostScript
0 1 .364 r
.49179 .17136 m
.55745 .16801 L
s
% Start of user PostScript
-0.2464438 -9.8592041 1.723439 -9.9595688 MAarrowhead1
% End of user PostScript
0 1 .679 r
.83236 .4558 m
.82637 .5216 L
s
% Start of user PostScript
9.9709145 -1.3261361 9.7911053 0.64807218 MAarrowhead1
% End of user PostScript
0 1 .995 r
.49714 .83011 m
.43168 .83127 L
s
% Start of user PostScript
-0.085661242 9.9033743 -2.049555 9.9379832 MAarrowhead1
% End of user PostScript
0 .69 1 r
.16773 .53321 m
.17591 .46736 L
s
% Start of user PostScript
-9.9680614 0.99628068 -9.72284 -0.97908036 MAarrowhead1
% End of user PostScript
0 .375 1 r
.51392 .16878 m
.57911 .16982 L
s
% Start of user PostScript
0.41767125 -9.9365578 2.3733974 -9.9053726 MAarrowhead1
% End of user PostScript
0 .06 1 r
.8318 .47782 m
.82146 .54363 L
s
% Start of user PostScript
9.9541498 -0.66531997 9.6437883 1.3090024 MAarrowhead1
% End of user PostScript
.335 1 0 r
.22927 .76176 m
.18929 .70933 L
.16152 .64868 L
.14702 .58221 L
.14638 .5125 L
.15962 .44231 L
.18622 .37438 L
.22513 .31138 L
.27483 .25578 L
.33336 .20976 L
.39844 .17514 L
.4675 .15327 L
.53784 .145 L
.60669 .15067 L
.67135 .17005 L
.72929 .20237 L
.77823 .24638 L
.81626 .30034 L
.84187 .36214 L
.85406 .42934 L
.85236 .49932 L
.83683 .56933 L
.80808 .63661 L
.76724 .69854 L
.71591 .75267 L
.6561 .79689 L
.59018 .82945 L
.52071 .84908 L
.45043 .85502 L
.38209 .84702 L
.31839 .8254 L
.26181 .79101 L
.21457 .7452 L
.17854 .68977 L
.15513 .62689 L
.14525 .55903 L
.14929 .48885 L
.1671 .41911 L
.19797 .35255 L
.2407 .29177 L
.2936 .23916 L
.3546 .19679 L
.42131 .16632 L
.49111 .14895 L
.56125 .14535 L
.62899 .15567 L
.69167 .17951 L
.74683 .21592 L
.7923 .26348 L
.8263 .32033 L
Mistroke
.84749 .38422 L
.85505 .45266 L
.84867 .52296 L
.8286 .59236 L
.79564 .65813 L
.75108 .71769 L
.69666 .76872 L
.63453 .80919 L
.56712 .83753 L
.49707 .85263 L
.42713 .85388 L
.36006 .84125 L
.29848 .81522 L
.24481 .77683 L
.20115 .72757 L
.16922 .66937 L
.15027 .60453 L
.14505 .53559 L
.15376 .46525 L
.17606 .39628 L
.21107 .33137 L
.25742 .27309 L
.31329 .22371 L
.37649 .18517 L
.44453 .15899 L
.51476 .14619 L
.5844 .14727 L
.65073 .1622 L
.71114 .19039 L
.76327 .23073 L
.80507 .28164 L
.83489 .34111 L
.85157 .40682 L
.85446 .47619 L
.84343 .54649 L
.81892 .61497 L
.7819 .67894 L
.73381 .73588 L
.67655 .78357 L
.61236 .82012 L
.54376 .84412 L
.47344 .85461 L
.40416 .85118 L
.33865 .83397 L
.27947 .80365 L
.22894 .76141 L
.18905 .70892 L
.16136 .64823 L
.14697 .58171 L
.14643 .512 L
Mistroke
.15976 .44181 L
.18645 .3739 L
.22545 .31095 L
.27522 .25541 L
.33381 .20947 L
.39892 .17494 L
.468 .15316 L
.53834 .14499 L
.60717 .15076 L
.6718 .17023 L
.72968 .20265 L
.77855 .24673 L
.81649 .30076 L
.842 .3626 L
.8541 .42984 L
.85229 .49983 L
.83667 .56982 L
.80783 .63708 L
.7669 .69896 L
.71551 .75302 L
.65565 .79716 L
.58969 .82964 L
.5202 .84918 L
.44993 .85501 L
.38162 .84691 L
.31795 .8252 L
.26143 .79072 L
.21427 .74484 L
.17833 .68934 L
.15501 .62642 L
.14523 .55853 L
.14937 .48835 L
.16728 .41862 L
.19824 .35209 L
.24104 .29136 L
.29401 .23882 L
.35506 .19653 L
.4218 .16615 L
.49161 .14887 L
.56175 .14538 L
.62946 .1558 L
.6921 .17973 L
.74719 .21622 L
.79259 .26386 L
.8265 .32076 L
.84759 .3847 L
.85505 .45316 L
.84857 .52346 L
.82841 .59284 L
.79536 .65858 L
Mistroke
.75072 .71809 L
.69624 .76904 L
.63406 .80944 L
.56662 .83769 L
.49656 .85269 L
.42664 .85384 L
.3596 .84111 L
.29806 .81499 L
.24446 .77651 L
.20088 .72718 L
.16904 .66893 L
.15019 .60405 L
.14507 .53509 L
.15387 .46475 L
.17627 .3958 L
.21136 .33093 L
.25779 .2727 L
.31372 .22339 L
.37696 .18493 L
.44503 .15885 L
.51526 .14614 L
.58489 .14733 L
.65119 .16236 L
.71155 .19064 L
.76361 .23106 L
.80533 .28203 L
.83506 .34156 L
.85164 .40731 L
.85443 .4767 L
.8433 .547 L
.8187 .61545 L
.78159 .67937 L
.73343 .73626 L
.67611 .78387 L
.61188 .82034 L
.54326 .84424 L
.47294 .85463 L
.40368 .8511 L
.3382 .83379 L
.27907 .80339 L
.22861 .76107 L
.18881 .70851 L
.16121 .64777 L
.14692 .58122 L
.14647 .51149 L
.15991 .44131 L
.18669 .37343 L
.22577 .31052 L
.27561 .25505 L
.33425 .20918 L
Mistroke
.39941 .17474 L
Mfstroke
1 0 0 r
.22927 .76176 m
.18929 .70933 L
s
% Start of user PostScript
-8.1220379 7.8526519 -9.3211822 6.2798215 MAarrowhead1
% End of user PostScript
1 .158 0 r
.16152 .64868 m
.14702 .58221 L
s
% Start of user PostScript
-10.154508 4.4605335 -10.58931 2.4661875 MAarrowhead1
% End of user PostScript
1 .473 0 r
.39844 .17514 m
.4675 .15327 L
s
% Start of user PostScript
-3.0468914 -9.7457503 -0.97504496 -10.401945 MAarrowhead1
% End of user PostScript
1 .788 0 r
.84187 .36214 m
.85406 .42934 L
s
% Start of user PostScript
10.255992 -4.1359281 10.621786 -2.119726 MAarrowhead1
% End of user PostScript
.897 1 0 r
.59018 .82945 m
.52071 .84908 L
s
% Start of user PostScript
2.7052912 9.8835072 0.6212611 10.472547 MAarrowhead1
% End of user PostScript
.581 1 0 r
.15513 .62689 m
.14525 .55903 L
s
% Start of user PostScript
-10.346098 3.8067344 -10.642479 1.7709129 MAarrowhead1
% End of user PostScript
.266 1 0 r
.42131 .16632 m
.49111 .14895 L
s
% Start of user PostScript
-2.3606898 -10.0103 -0.26678803 -10.531532 MAarrowhead1
% End of user PostScript
0 1 .049 r
.84749 .38422 m
.85505 .45266 L
s
% Start of user PostScript
10.424726 -3.4733175 10.651365 -1.4201352 MAarrowhead1
% End of user PostScript
0 1 .364 r
.56712 .83753 m
.49707 .85263 L
s
% Start of user PostScript
2.0134694 10.125987 -0.087981018 10.578833 MAarrowhead1
% End of user PostScript
0 1 .679 r
.15027 .60453 m
.14505 .53559 L
s
% Start of user PostScript
-10.49179 3.1360474 -10.648434 1.067782 MAarrowhead1
% End of user PostScript
0 1 .995 r
.44453 .15899 m
.51476 .14619 L
s
% Start of user PostScript
-1.6640154 -10.23044 0.44265246 -10.614398 MAarrowhead1
% End of user PostScript
0 .69 1 r
.85157 .40682 m
.85446 .47619 L
s
% Start of user PostScript
10.547214 -2.7952983 10.633691 -0.71424419 MAarrowhead1
% End of user PostScript
0 .375 1 r
.54376 .84412 m
.47344 .85461 L
s
% Start of user PostScript
1.3127154 10.323544 -0.79683283 10.638187 MAarrowhead1
% End of user PostScript
0 .06 1 r
.14697 .58171 m
.14643 .512 L
s
% Start of user PostScript
-10.590937 2.4514481 -10.60715 0.35991405 MAarrowhead1
% End of user PostScript
1 .219 0 r
.46723 .33901 m
.50067 .33166 L
.53409 .33091 L
.56617 .3368 L
.59565 .3491 L
.62138 .36732 L
.64235 .39074 L
.65773 .41846 L
.66692 .44937 L
.66956 .48227 L
.66554 .51587 L
.65503 .54884 L
.63843 .5799 L
.6164 .60782 L
.5898 .63151 L
.55968 .65004 L
.52721 .66268 L
.49368 .66894 L
.4604 .66856 L
.42867 .66157 L
.39974 .64824 L
.37474 .62909 L
.35466 .60488 L
.34028 .57654 L
.33218 .54521 L
.33065 .5121 L
.33578 .47852 L
.34735 .44577 L
.36491 .41516 L
.38777 .38788 L
.41504 .365 L
.44564 .34741 L
.47838 .33581 L
.51196 .33066 L
.54507 .33215 L
.57642 .34024 L
.60476 .35459 L
.629 .37464 L
.64817 .39962 L
.66153 .42854 L
.66854 .46026 L
.66895 .49354 L
.66272 .52707 L
.65011 .55955 L
.6316 .58968 L
.60793 .6163 L
.58003 .63835 L
.54898 .65497 L
.51601 .66551 L
.48241 .66955 L
Mistroke
.44951 .66694 L
.41858 .65778 L
.39085 .64243 L
.36741 .62148 L
.34916 .59577 L
.33684 .5663 L
.33092 .53423 L
.33164 .50081 L
.33896 .46736 L
.35261 .4352 L
.37203 .40557 L
.39648 .37966 L
.425 .35846 L
.45645 .34282 L
.48962 .33335 L
.52319 .33042 L
.55586 .33414 L
.58633 .34438 L
.61341 .36072 L
.63604 .38253 L
.65333 .40894 L
.66461 .43893 L
.66942 .47132 L
.66759 .50484 L
.65918 .53816 L
.64452 .56999 L
.62419 .59906 L
.59898 .62426 L
.56989 .64457 L
.53806 .65921 L
.50474 .6676 L
.47122 .66942 L
.43884 .66459 L
.40886 .65329 L
.38245 .63598 L
.36066 .61334 L
.34434 .58624 L
.33412 .55576 L
.33042 .5231 L
.33337 .48952 L
.34286 .45636 L
.35852 .42491 L
.37973 .39641 L
.40566 .37197 L
.43529 .35256 L
.46746 .33893 L
.50091 .33163 L
.53433 .33093 L
.56639 .33687 L
.59585 .34921 L
Mistroke
.62155 .36747 L
.64248 .39093 L
.65782 .41867 L
.66696 .4496 L
.66955 .48251 L
.66549 .51611 L
.65493 .54907 L
.63829 .58011 L
.61622 .60801 L
.5896 .63166 L
.55945 .65015 L
.52698 .66275 L
.49344 .66896 L
.46016 .66853 L
.42845 .6615 L
.39954 .64812 L
.37458 .62893 L
.35453 .60469 L
.3402 .57633 L
.33214 .54498 L
.33067 .51186 L
.33584 .47828 L
.34745 .44555 L
.36506 .41495 L
.38795 .3877 L
.41525 .36485 L
.44587 .34731 L
.47861 .33575 L
.5122 .33065 L
.54531 .33219 L
.57663 .34032 L
.60495 .35471 L
.62916 .37481 L
.64829 .39982 L
.6616 .42876 L
.66857 .46049 L
.66893 .49378 L
.66265 .52731 L
.64999 .55977 L
.63145 .58989 L
.60775 .61647 L
.57981 .63849 L
.54875 .65507 L
.51577 .66556 L
.48217 .66956 L
.44928 .6669 L
.41837 .65769 L
.39067 .6423 L
.36726 .62131 L
.34905 .59557 L
Mistroke
.33678 .56608 L
.3309 .53399 L
.33167 .50057 L
.33904 .46713 L
.35273 .43498 L
.37219 .40537 L
.39668 .37949 L
.42521 .35833 L
.45669 .34273 L
.48986 .33331 L
.52343 .33042 L
.55608 .33419 L
.58653 .34447 L
.61359 .36086 L
.63619 .3827 L
.65344 .40915 L
.66467 .43916 L
.66943 .47156 L
.66755 .50508 L
.65909 .53839 L
.64439 .5702 L
.62402 .59926 L
.59879 .62442 L
.56967 .6447 L
.53783 .65929 L
.5045 .66764 L
.47099 .66941 L
.43862 .66453 L
.40866 .65319 L
.38228 .63584 L
.36052 .61316 L
.34424 .58603 L
.33407 .55553 L
.33042 .52286 L
.33341 .48928 L
.34295 .45613 L
.35865 .42469 L
.3799 .39622 L
.40586 .37181 L
.43551 .35244 L
.4677 .33886 L
.50115 .3316 L
.53456 .33095 L
.56661 .33693 L
.59605 .34932 L
.62172 .36762 L
.64261 .39111 L
.65791 .41888 L
.667 .44983 L
.66955 .48275 L
Mistroke
.66543 .51635 L
Mfstroke
1 0 0 r
.46723 .33901 m
.50067 .33166 L
s
% Start of user PostScript
-0.98322239 -4.8298101 0.020126293 -5.0503457 MAarrowhead1
% End of user PostScript
1 .158 0 r
.53409 .33091 m
.56617 .3368 L
s
% Start of user PostScript
1.0226851 -5.0726757 1.9851076 -4.8959235 MAarrowhead1
% End of user PostScript
1 .473 0 r
.66554 .51587 m
.65503 .54884 L
s
% Start of user PostScript
4.9662076 0.47609708 4.650818 1.4653153 MAarrowhead1
% End of user PostScript
1 .788 0 r
.4604 .66856 m
.42867 .66157 L
s
% Start of user PostScript
-1.1880965 5.0568181 -2.1400142 4.8471177 MAarrowhead1
% End of user PostScript
.897 1 0 r
.33578 .47852 m
.34735 .44577 L
s
% Start of user PostScript
-4.9266352 -0.64452644 -4.5795398 -1.6267601 MAarrowhead1
% End of user PostScript
.581 1 0 r
.54507 .33215 m
.57642 .34024 L
s
% Start of user PostScript
1.3521898 -5.0353506 2.2925467 -4.7929346 MAarrowhead1
% End of user PostScript
.266 1 0 r
.66272 .52707 m
.65011 .55955 L
s
% Start of user PostScript
4.8815973 0.81224078 4.503181 1.7864002 MAarrowhead1
% End of user PostScript
0 1 .049 r
.44951 .66694 m
.41858 .65778 L
s
% Start of user PostScript
-1.514783 5.008297 -2.4425358 4.7334343 MAarrowhead1
% End of user PostScript
0 1 .364 r
.33896 .46736 m
.35261 .4352 L
s
% Start of user PostScript
-4.8311439 -0.97905403 -4.4218266 -1.9440585 MAarrowhead1
% End of user PostScript
0 1 .679 r
.55586 .33414 m
.58633 .34438 L
s
% Start of user PostScript
1.6756957 -4.9756873 2.5898153 -4.6686828 MAarrowhead1
% End of user PostScript
0 1 .995 r
.65918 .53816 m
.64452 .56999 L
s
% Start of user PostScript
4.7753309 1.1447811 4.3355666 2.0995601 MAarrowhead1
% End of user PostScript
0 .69 1 r
.43884 .66459 m
.40886 .65329 L
s
% Start of user PostScript
-1.8347495 4.9375576 -2.7342216 4.598752 MAarrowhead1
% End of user PostScript
0 .375 1 r
.34286 .45636 m
.35852 .42491 L
s
% Start of user PostScript
-4.7142202 -1.3092382 -4.2444968 -2.2527325 MAarrowhead1
% End of user PostScript
0 .06 1 r
.56639 .33687 m
.59585 .34921 L
s
% Start of user PostScript
1.9917678 -4.8939504 2.8755947 -4.5237194 MAarrowhead1
% End of user PostScript
.952 0 1 r
.66961 .2855 m
.70469 .31808 L
.73174 .3578 L
.74969 .4031 L
.75784 .45221 L
.75587 .50319 L
.74386 .55404 L
.72228 .60278 L
.69198 .64748 L
.65414 .68639 L
.61025 .71799 L
.56204 .74103 L
.51139 .75462 L
.4603 .75821 L
.41076 .75166 L
.36472 .73524 L
.324 .70959 L
.29018 .67571 L
.26459 .63494 L
.24825 .58887 L
.24178 .53931 L
.24545 .48821 L
.25911 .43758 L
.28222 .38939 L
.31388 .34554 L
.35285 .30776 L
.39759 .27752 L
.44634 .25601 L
.49721 .24407 L
.54818 .24219 L
.59727 .25042 L
.64253 .26844 L
.6822 .29555 L
.71472 .33069 L
.73882 .37247 L
.75354 .41926 L
.75831 .46921 L
.75294 .52037 L
.73765 .57074 L
.71303 .61832 L
.68005 .66127 L
.64 .69788 L
.59446 .72673 L
.54521 .74668 L
.49419 .75695 L
.44339 .75714 L
.39482 .74723 L
.35037 .72762 L
.3118 .69908 L
.28061 .66272 L
Mistroke
.25804 .61998 L
.24495 .57253 L
.24188 .52223 L
.24894 .47106 L
.26585 .42103 L
.29195 .37409 L
.32622 .3321 L
.36731 .2967 L
.4136 .26927 L
.46328 .2509 L
.51441 .24231 L
.56497 .24383 L
.61298 .2554 L
.65656 .27657 L
.69399 .30652 L
.72381 .34405 L
.74484 .38771 L
.75627 .43577 L
.75764 .48635 L
.74889 .53747 L
.73038 .58712 L
.70283 .63335 L
.66732 .67434 L
.62524 .7085 L
.57825 .73447 L
.52818 .75124 L
.47701 .75815 L
.42674 .75492 L
.37935 .7417 L
.33669 .71898 L
.30044 .68768 L
.27202 .649 L
.25255 .60448 L
.24279 .55586 L
.24313 .50505 L
.25355 .45404 L
.27363 .40483 L
.30261 .35936 L
.33933 .31941 L
.38235 .28654 L
.43 .26205 L
.48039 .2469 L
.53155 .24169 L
.58147 .24661 L
.62819 .26147 L
.66989 .2857 L
.70491 .31834 L
.7319 .35811 L
.74978 .40344 L
.75786 .45257 L
Mistroke
.75582 .50355 L
.74374 .5544 L
.7221 .60311 L
.69173 .64778 L
.65385 .68665 L
.60992 .71819 L
.56168 .74116 L
.51102 .75468 L
.45993 .7582 L
.41041 .75158 L
.36441 .73509 L
.32373 .70938 L
.28996 .67545 L
.26444 .63463 L
.24817 .58853 L
.24177 .53895 L
.24551 .48785 L
.25924 .43722 L
.28242 .38906 L
.31414 .34525 L
.35315 .30751 L
.39792 .27733 L
.4467 .25589 L
.49758 .24403 L
.54854 .24221 L
.59761 .25051 L
.64284 .2686 L
.68246 .29578 L
.71493 .33097 L
.73896 .37279 L
.75361 .4196 L
.75831 .46958 L
.75287 .52074 L
.73751 .57109 L
.71282 .61865 L
.67978 .66156 L
.63969 .69812 L
.59412 .72691 L
.54485 .74679 L
.49382 .75699 L
.44303 .7571 L
.39448 .74712 L
.35007 .72744 L
.31155 .69884 L
.28042 .66243 L
.25791 .61965 L
.2449 .57218 L
.2419 .52187 L
.24903 .4707 L
.26601 .42068 L
Mistroke
.29217 .37377 L
.32649 .33182 L
.36762 .29647 L
.41395 .26911 L
.46365 .25081 L
.51478 .24228 L
.56533 .24388 L
.61331 .25552 L
.65685 .27676 L
.69423 .30676 L
.72399 .34434 L
.74496 .38804 L
.75631 .43612 L
.75761 .48672 L
.7488 .53783 L
.73022 .58746 L
.7026 .63366 L
.66704 .67461 L
.62492 .70871 L
.5779 .73462 L
.52781 .75132 L
.47664 .75816 L
.42639 .75486 L
.37902 .74157 L
.3364 .71879 L
.30021 .68742 L
.27185 .6487 L
.25245 .60415 L
.24276 .5555 L
.24317 .50468 L
.25366 .45368 L
.27381 .40449 L
.30285 .35905 L
.33962 .31914 L
.38268 .28633 L
.43035 .26191 L
.48075 .24683 L
.53191 .24169 L
.58182 .24668 L
.62851 .26161 L
.67016 .28591 L
.70514 .3186 L
.73206 .35841 L
.74987 .40378 L
.75788 .45293 L
.75577 .50392 L
.74362 .55476 L
.72191 .60345 L
.69149 .64808 L
.65355 .6869 L
Mistroke
.60959 .71838 L
Mfstroke
1 0 0 r
.66961 .2855 m
.70469 .31808 L
s
% Start of user PostScript
5.0882979 -6.4351288 6.1406723 -5.4576825 MAarrowhead1
% End of user PostScript
1 .158 0 r
.73174 .3578 m
.74969 .4031 L
s
% Start of user PostScript
6.95205 -4.2660443 7.4905878 -2.9069809 MAarrowhead1
% End of user PostScript
1 .473 0 r
.61025 .71799 m
.56204 .74103 L
s
% Start of user PostScript
3.3076404 6.5396849 1.8612147 7.2309734 MAarrowhead1
% End of user PostScript
1 .788 0 r
.26459 .63494 m
.24825 .58887 L
s
% Start of user PostScript
-7.0622188 4.0482245 -7.55258 2.6661362 MAarrowhead1
% End of user PostScript
.897 1 0 r
.39759 .27752 m
.44634 .25601 L
s
% Start of user PostScript
-3.0724164 -6.6745206 -1.609658 -7.3197754 MAarrowhead1
% End of user PostScript
.581 1 0 r
.73882 .37247 m
.75354 .41926 L
s
% Start of user PostScript
7.164553 -3.8259137 7.6061935 -2.4223336 MAarrowhead1
% End of user PostScript
.266 1 0 r
.59446 .72673 m
.54521 .74668 L
s
% Start of user PostScript
2.8337839 6.8019518 1.3563156 7.400457 MAarrowhead1
% End of user PostScript
0 1 .049 r
.25804 .61998 m
.24495 .57253 L
s
% Start of user PostScript
-7.2589389 3.5993585 -7.6513688 2.1758438 MAarrowhead1
% End of user PostScript
0 1 .364 r
.4136 .26927 m
.46328 .2509 L
s
% Start of user PostScript
-2.5920076 -6.921837 -1.1014686 -7.4729287 MAarrowhead1
% End of user PostScript
0 1 .679 r
.74484 .38771 m
.75627 .43577 L
s
% Start of user PostScript
7.3452719 -3.3688103 7.6880558 -1.9269401 MAarrowhead1
% End of user PostScript
0 1 .995 r
.57825 .73447 m
.52818 .75124 L
s
% Start of user PostScript
2.3473559 7.0340432 0.84539958 7.53711 MAarrowhead1
% End of user PostScript
0 .69 1 r
.25255 .60448 m
.24279 .55586 L
s
% Start of user PostScript
-7.4234562 3.1345247 -7.7162139 1.6758987 MAarrowhead1
% End of user PostScript
0 .375 1 r
.43 .26205 m
.48039 .2469 L
s
% Start of user PostScript
-2.1001 -7.1384461 -0.58839271 -7.5929298 MAarrowhead1
% End of user PostScript
0 .06 1 r
.74978 .40344 m
.75786 .45257 L
s
% Start of user PostScript
7.493405 -2.8967618 7.7358117 -1.4229981 MAarrowhead1
% End of user PostScript
0 1 .378 r
.80492 .19723 m
.85152 .25623 L
.88433 .32481 L
.90205 .40026 L
.90399 .47962 L
.89008 .55978 L
.86086 .6376 L
.81748 .71002 L
.76163 .77419 L
.69552 .82761 L
.62174 .86816 L
.54317 .89427 L
.46292 .9049 L
.38412 .89965 L
.30986 .87871 L
.24307 .8429 L
.18636 .79364 L
.14196 .73285 L
.11162 .66293 L
.09651 .58661 L
.09724 .50689 L
.11378 .4269 L
.14547 .34978 L
.19108 .27856 L
.24881 .21603 L
.3164 .16464 L
.3912 .12641 L
.47026 .10285 L
.5505 .09487 L
.62875 .10279 L
.70195 .1263 L
.76722 .16447 L
.822 .21582 L
.86415 .27832 L
.89201 .34951 L
.90448 .42662 L
.90108 .5066 L
.88193 .58633 L
.8478 .66266 L
.80002 .73262 L
.74046 .79344 L
.67147 .84275 L
.59574 .8786 L
.51626 .8996 L
.43614 .90491 L
.35853 .89434 L
.28647 .86828 L
.22279 .82778 L
.16999 .77441 L
.13014 .71027 L
Mistroke
.1048 .63788 L
.09498 .56007 L
.10105 .47991 L
.12278 .40054 L
.15931 .32507 L
.20921 .25647 L
.27053 .19742 L
.34085 .15025 L
.41742 .11681 L
.49723 .0984 L
.57714 .09576 L
.65403 .10898 L
.72488 .13754 L
.7869 .18033 L
.83766 .23567 L
.87516 .30138 L
.89795 .37489 L
.90511 .4533 L
.89638 .53355 L
.87209 .61248 L
.8332 .687 L
.78123 .75418 L
.71822 .81138 L
.64665 .85636 L
.56933 .88736 L
.48928 .90316 L
.40965 .90313 L
.33357 .88728 L
.26402 .85623 L
.20374 .8112 L
.15508 .75396 L
.11995 .68675 L
.09974 .61221 L
.09524 .53327 L
.10663 .45302 L
.13345 .37462 L
.17466 .30113 L
.22864 .23545 L
.29326 .18016 L
.36601 .13742 L
.444 .1089 L
.5242 .09574 L
.60345 .09844 L
.67864 .1169 L
.74681 .15039 L
.8053 .19761 L
.85181 .2567 L
.88451 .32533 L
.90212 .40082 L
.90395 .4802 L
Mistroke
.88993 .56035 L
.8606 .63814 L
.81712 .71051 L
.76119 .77462 L
.69502 .82795 L
.62119 .8684 L
.5426 .8944 L
.46234 .90492 L
.38356 .89955 L
.30935 .8785 L
.24263 .84259 L
.186 .79324 L
.14169 .73238 L
.11145 .6624 L
.09646 .58605 L
.0973 .50632 L
.11395 .42634 L
.14575 .34925 L
.19145 .27808 L
.24927 .21562 L
.31692 .16431 L
.39175 .12619 L
.47084 .10273 L
.55107 .09487 L
.62929 .1029 L
.70245 .12652 L
.76765 .1648 L
.82235 .21623 L
.8644 .2788 L
.89215 .35005 L
.90451 .42718 L
.901 .50718 L
.88174 .58689 L
.84751 .66319 L
.79963 .73309 L
.74 .79384 L
.67095 .84305 L
.59518 .87881 L
.51569 .89969 L
.43558 .90489 L
.35799 .8942 L
.28598 .86804 L
.22237 .82744 L
.16965 .77398 L
.1299 .70977 L
.10468 .63733 L
.09497 .5595 L
.10115 .47934 L
.12299 .39998 L
.15962 .32455 L
Mistroke
.20962 .25601 L
.271 .19704 L
.34138 .14996 L
.41798 .11662 L
.4978 .09832 L
.57771 .09579 L
.65457 .10913 L
.72536 .1378 L
.7873 .18069 L
.83797 .23611 L
.87538 .30188 L
.89806 .37544 L
.90511 .45388 L
.89626 .53413 L
.87186 .61304 L
.83287 .68751 L
.78082 .75463 L
.71774 .81175 L
.64612 .85664 L
.56876 .88753 L
.4887 .90321 L
.40909 .90307 L
.33305 .88711 L
.26356 .85595 L
.20334 .81083 L
.15477 .75351 L
.11975 .68624 L
.09965 .61166 L
.09527 .53269 L
.10677 .45245 L
.1337 .37407 L
.175 .30063 L
.22907 .23502 L
.29376 .17981 L
.36655 .13716 L
.44458 .10875 L
.52478 .0957 L
.60401 .09851 L
.67915 .11709 L
.74727 .15069 L
.80568 .19799 L
.8521 .25716 L
.88469 .32585 L
.90219 .40137 L
.90391 .48077 L
.88977 .56092 L
.86034 .63868 L
.81676 .711 L
.76075 .77504 L
.69451 .82828 L
Mistroke
.62064 .86864 L
Mfstroke
1 0 0 r
.80492 .19723 m
.85152 .25623 L
s
% Start of user PostScript
9.147696 -9.0831602 10.54573 -7.3129567 MAarrowhead1
% End of user PostScript
1 .158 0 r
.88433 .32481 m
.90205 .40026 L
s
% Start of user PostScript
11.529887 -5.2557492 12.061542 -2.9922747 MAarrowhead1
% End of user PostScript
1 .473 0 r
.62174 .86816 m
.54317 .89427 L
s
% Start of user PostScript
3.6521197 11.044879 1.2952412 11.828099 MAarrowhead1
% End of user PostScript
1 .788 0 r
.11162 .66293 m
.09651 .58661 L
s
% Start of user PostScript
-11.65153 4.8878732 -12.104683 2.5983117 MAarrowhead1
% End of user PostScript
.897 1 0 r
.3912 .12641 m
.47026 .10285 L
s
% Start of user PostScript
-3.2640378 -11.207682 -0.89206596 -11.914642 MAarrowhead1
% End of user PostScript
.581 1 0 r
.89201 .34951 m
.90448 .42662 L
s
% Start of user PostScript
11.760246 -4.5145747 12.134396 -2.2014662 MAarrowhead1
% End of user PostScript
.266 1 0 r
.59574 .8786 m
.51626 .8996 L
s
% Start of user PostScript
2.8723348 11.35805 0.48790103 11.987967 MAarrowhead1
% End of user PostScript
0 1 .049 r
.1048 .63788 m
.09498 .56007 L
s
% Start of user PostScript
-11.855916 4.1362678 -12.150646 1.8021784 MAarrowhead1
% End of user PostScript
0 1 .364 r
.41742 .11681 m
.49723 .0984 L
s
% Start of user PostScript
-2.4774453 -11.495819 -0.083194842 -12.047993 MAarrowhead1
% End of user PostScript
0 1 .679 r
.89795 .37489 m
.90511 .4533 L
s
% Start of user PostScript
11.938433 -3.7533722 12.153417 -1.4008913 MAarrowhead1
% End of user PostScript
0 1 .995 r
.56933 .88736 m
.48928 .90316 L
s
% Start of user PostScript
2.0798074 11.620834 -0.32160365 12.094653 MAarrowhead1
% End of user PostScript
0 .69 1 r
.09974 .61221 m
.09524 .53327 L
s
% Start of user PostScript
-12.007706 3.3663127 -12.142706 0.9980501 MAarrowhead1
% End of user PostScript
0 .375 1 r
.444 .1089 m
.5242 .09574 L
s
% Start of user PostScript
-1.6798622 -11.732957 0.72604535 -12.127896 MAarrowhead1
% End of user PostScript
0 .06 1 r
.90212 .40082 m
.90395 .4802 L
s
% Start of user PostScript
12.063658 -2.9755187 12.118523 -0.59410167 MAarrowhead1
% End of user PostScript
1 0 .722 r
.56268 .7638 m
.50748 .77763 L
.45198 .78056 L
.39837 .77248 L
.34875 .75371 L
.30507 .72498 L
.26903 .68742 L
.24206 .64251 L
.22521 .592 L
.21915 .53789 L
.22411 .48228 L
.23989 .42737 L
.26589 .37531 L
.30107 .32815 L
.34406 .28773 L
.39317 .25564 L
.44647 .23314 L
.50188 .22111 L
.55721 .22003 L
.61029 .22994 L
.65905 .25044 L
.70156 .28074 L
.73616 .31965 L
.7615 .36563 L
.77657 .41689 L
.78079 .4714 L
.77399 .52704 L
.75643 .58162 L
.72881 .633 L
.69221 .67916 L
.64807 .71828 L
.59812 .74884 L
.54431 .76963 L
.48877 .77984 L
.43367 .77907 L
.38117 .76735 L
.33333 .74513 L
.29204 .71329 L
.25891 .67308 L
.23523 .62608 L
.22195 .57413 L
.21959 .51928 L
.22822 .46366 L
.24753 .40947 L
.27674 .35884 L
.31471 .31374 L
.35996 .27595 L
.4107 .24696 L
.46495 .2279 L
.52057 .21952 L
Mistroke
.57538 .22214 L
.62724 .23567 L
.6741 .25957 L
.71413 .29291 L
.74576 .33438 L
.76774 .38234 L
.77921 .43493 L
.77973 .49007 L
.76927 .54559 L
.74824 .59933 L
.71746 .64917 L
.67816 .69316 L
.63186 .72956 L
.58038 .75696 L
.52575 .77427 L
.47011 .78082 L
.41565 .77634 L
.36449 .76102 L
.31865 .73546 L
.27993 .70065 L
.24985 .65798 L
.22958 .6091 L
.21993 .55594 L
.22127 .50058 L
.23354 .4452 L
.25628 .39197 L
.28858 .34299 L
.32917 .30016 L
.37648 .26518 L
.42862 .23941 L
.48357 .22387 L
.53917 .21917 L
.59323 .22548 L
.64363 .24258 L
.68839 .26977 L
.72576 .306 L
.75427 .34985 L
.77279 .39958 L
.78062 .45326 L
.77743 .50877 L
.76335 .56394 L
.73894 .6166 L
.70515 .66468 L
.66331 .7063 L
.61506 .73983 L
.56229 .76394 L
.50708 .77769 L
.45159 .78054 L
.398 .77239 L
.34842 .75354 L
Mistroke
.30478 .72474 L
.2688 .68713 L
.2419 .64217 L
.22513 .59163 L
.21915 .53749 L
.22418 .48188 L
.24005 .42699 L
.26611 .37495 L
.30135 .32783 L
.34439 .28746 L
.39354 .25544 L
.44687 .23301 L
.50228 .22106 L
.5576 .22006 L
.61066 .23005 L
.65937 .25062 L
.70184 .28099 L
.73638 .31995 L
.76164 .36598 L
.77664 .41727 L
.78078 .4718 L
.7739 .52744 L
.75627 .58201 L
.72858 .63335 L
.69192 .67946 L
.64773 .71853 L
.59774 .74902 L
.54392 .76974 L
.48837 .77988 L
.43328 .77902 L
.38081 .76722 L
.33301 .74493 L
.29177 .71303 L
.2587 .67277 L
.2351 .62573 L
.2219 .57375 L
.21961 .51888 L
.22832 .46326 L
.2477 .40909 L
.27698 .35849 L
.31501 .31344 L
.3603 .27571 L
.41108 .24679 L
.46534 .2278 L
.52097 .2195 L
.57577 .2222 L
.6276 .2358 L
.67442 .25978 L
.71439 .29318 L
.74595 .3347 L
Mistroke
.76786 .38271 L
.77926 .43532 L
.77969 .49047 L
.76915 .54599 L
.74805 .59971 L
.71721 .64951 L
.67785 .69345 L
.6315 .72979 L
.58 .75712 L
.52536 .77435 L
.46972 .78082 L
.41527 .77627 L
.36414 .76087 L
.31835 .73524 L
.27969 .70037 L
.24967 .65765 L
.22947 .60873 L
.2199 .55554 L
.22132 .50018 L
.23367 .44481 L
.25648 .39161 L
.28884 .34265 L
.32949 .29988 L
.37683 .26496 L
.42901 .23926 L
.48397 .2238 L
.53956 .21917 L
.5936 .22557 L
.64397 .24274 L
.68868 .27 L
.72599 .30629 L
.75443 .35018 L
.77289 .39996 L
.78063 .45366 L
.77737 .50917 L
.76321 .56433 L
.73873 .61696 L
.70487 .66501 L
.66298 .70657 L
.61469 .74003 L
.5619 .76407 L
.50668 .77775 L
.4512 .78052 L
.39763 .77229 L
.34808 .75337 L
.30449 .7245 L
.26858 .68683 L
.24175 .64182 L
.22505 .59125 L
.21914 .53709 L
Mistroke
.22426 .48148 L
Mfstroke
1 0 0 r
.56268 .7638 m
.50748 .77763 L
s
% Start of user PostScript
1.8803686 7.913973 0.22434089 8.3288413 MAarrowhead1
% End of user PostScript
1 .158 0 r
.45198 .78056 m
.39837 .77248 L
s
% Start of user PostScript
-1.4404913 8.4168361 -3.04879 8.1745041 MAarrowhead1
% End of user PostScript
1 .473 0 r
.22411 .48228 m
.23989 .42737 L
s
% Start of user PostScript
-8.2767478 -0.53157416 -7.8031513 -2.1788531 MAarrowhead1
% End of user PostScript
1 .788 0 r
.55721 .22003 m
.61029 .22994 L
s
% Start of user PostScript
1.7161681 -8.3991308 3.3086925 -8.1019322 MAarrowhead1
% End of user PostScript
.897 1 0 r
.77399 .52704 m
.75643 .58162 L
s
% Start of user PostScript
8.2195867 0.8113272 7.6929474 2.4487072 MAarrowhead1
% End of user PostScript
.581 1 0 r
.43367 .77907 m
.38117 .76735 L
s
% Start of user PostScript
-1.989941 8.3721076 -3.5649244 8.0203722 MAarrowhead1
% End of user PostScript
.266 1 0 r
.22822 .46366 m
.24753 .40947 L
s
% Start of user PostScript
-8.153307 -1.0901802 -7.5742091 -2.7158448 MAarrowhead1
% End of user PostScript
0 1 .049 r
.57538 .22214 m
.62724 .23567 L
s
% Start of user PostScript
2.2615063 -8.3357966 3.8172015 -7.9299145 MAarrowhead1
% End of user PostScript
0 1 .364 r
.76927 .54559 m
.74824 .59933 L
s
% Start of user PostScript
8.0779821 1.3678237 7.4470681 2.9799695 MAarrowhead1
% End of user PostScript
0 1 .679 r
.41565 .77634 m
.36449 .76102 L
s
% Start of user PostScript
-2.5305627 8.2902379 -4.0652438 7.8306595 MAarrowhead1
% End of user PostScript
0 1 .995 r
.23354 .4452 m
.25628 .39197 L
s
% Start of user PostScript
-7.9936957 -1.6439498 -7.3116655 -3.2407882 MAarrowhead1
% End of user PostScript
0 .69 1 r
.59323 .22548 m
.64363 .24258 L
s
% Start of user PostScript
2.7968117 -8.2354823 4.3087762 -7.7227174 MAarrowhead1
% End of user PostScript
0 .375 1 r
.76335 .56394 m
.73894 .6166 L
s
% Start of user PostScript
7.9005412 1.9182522 7.1681515 3.4980117 MAarrowhead1
% End of user PostScript
0 .06 1 r
.398 .77239 m
.34842 .75354 L
s
% Start of user PostScript
-3.0599581 8.1715903 -4.5475286 7.6062078 MAarrowhead1
% End of user PostScript
1 .889 0 r
.62164 .79016 m
.55858 .81584 L
.49322 .82912 L
.42813 .82949 L
.36586 .81693 L
.30885 .79193 L
.25935 .75547 L
.21929 .70899 L
.19024 .6543 L
.17336 .59356 L
.16929 .52915 L
.1782 .46359 L
.19974 .39946 L
.23307 .33928 L
.27687 .2854 L
.32943 .23995 L
.38868 .2047 L
.4523 .18105 L
.51779 .16991 L
.58259 .17172 L
.64414 .18642 L
.70004 .21342 L
.74809 .25168 L
.7864 .29967 L
.81347 .35553 L
.82823 .41706 L
.83012 .48185 L
.81905 .54734 L
.79546 .61098 L
.76027 .67027 L
.71487 .72287 L
.66104 .76672 L
.60088 .80011 L
.53677 .82172 L
.47121 .8307 L
.40678 .8267 L
.34602 .80988 L
.29129 .7809 L
.24476 .7409 L
.20824 .69144 L
.18317 .63447 L
.17054 .57222 L
.17084 .50714 L
.18406 .44177 L
.20967 .3787 L
.24668 .32038 L
.29363 .26911 L
.34868 .2269 L
.40967 .19541 L
.47421 .17588 L
Mistroke
.53975 .16906 L
.60374 .17524 L
.66365 .19416 L
.71715 .22508 L
.76212 .26679 L
.7968 .31765 L
.81983 .37567 L
.83032 .43857 L
.82784 .50388 L
.81249 .56904 L
.78488 .63149 L
.74609 .68878 L
.69764 .73866 L
.64143 .77917 L
.57968 .80873 L
.51479 .82617 L
.44933 .83081 L
.38585 .82246 L
.32686 .80146 L
.27466 .76863 L
.2313 .72526 L
.19849 .67305 L
.17751 .61404 L
.16919 .55056 L
.17385 .4851 L
.19131 .42022 L
.22089 .35847 L
.26142 .30227 L
.31131 .25384 L
.36861 .21507 L
.43107 .18747 L
.49623 .17215 L
.56154 .16969 L
.62443 .18019 L
.68244 .20325 L
.73329 .23795 L
.77498 .28294 L
.80589 .33644 L
.82478 .39637 L
.83094 .46036 L
.8241 .5259 L
.80454 .59043 L
.77303 .65142 L
.73081 .70645 L
.67953 .75339 L
.6212 .79038 L
.55812 .81598 L
.49275 .82917 L
.42767 .82945 L
.36543 .81679 L
Mistroke
.30847 .79171 L
.25902 .75517 L
.21904 .70862 L
.19008 .65389 L
.17328 .59311 L
.16931 .52868 L
.17831 .46312 L
.19994 .39901 L
.23334 .33887 L
.27722 .28505 L
.32983 .23966 L
.38912 .20449 L
.45277 .18092 L
.51826 .16987 L
.58304 .17178 L
.64457 .18657 L
.70041 .21366 L
.7484 .25199 L
.78663 .30005 L
.81362 .35596 L
.82829 .41752 L
.83009 .48232 L
.81892 .54781 L
.79525 .61143 L
.75998 .67067 L
.71451 .72321 L
.66062 .767 L
.60043 .80031 L
.5363 .82183 L
.47074 .83072 L
.40633 .82663 L
.3456 .80972 L
.29093 .78066 L
.24446 .74058 L
.20802 .69106 L
.18304 .63404 L
.1705 .57176 L
.17089 .50667 L
.1842 .44131 L
.2099 .37826 L
.24698 .31998 L
.294 .26877 L
.3491 .22664 L
.41012 .19523 L
.47468 .17578 L
.54022 .16906 L
.60419 .17533 L
.66406 .19434 L
.7175 .22534 L
.7624 .26712 L
Mistroke
.79701 .31805 L
.81996 .37611 L
.83035 .43904 L
.82777 .50436 L
.81233 .5695 L
.78464 .63192 L
.74577 .68917 L
.69726 .73898 L
.64101 .77942 L
.57922 .8089 L
.51432 .82625 L
.44886 .83079 L
.38541 .82236 L
.32646 .80127 L
.27431 .76836 L
.23103 .72492 L
.1983 .67265 L
.17741 .6136 L
.16918 .5501 L
.17393 .48463 L
.19148 .41976 L
.22114 .35804 L
.26175 .3019 L
.3117 .25352 L
.36904 .21483 L
.43153 .18732 L
.4967 .17208 L
.562 .16972 L
.62486 .18032 L
.68283 .20346 L
.73362 .23824 L
.77525 .28329 L
.80607 .33685 L
.82487 .39681 L
.83093 .46082 L
.824 .52637 L
.80436 .59089 L
.77277 .65183 L
.73047 .70682 L
.67913 .75369 L
.62076 .79061 L
.55765 .81612 L
.49228 .82922 L
.42721 .8294 L
.365 .81666 L
.30808 .79148 L
.2587 .75487 L
.21879 .70826 L
.18991 .65347 L
.17321 .59266 L
Mistroke
.16932 .52821 L
Mfstroke
1 0 0 r
.62164 .79016 m
.55858 .81584 L
s
% Start of user PostScript
3.64916 8.7046884 1.7573858 9.4751203 MAarrowhead1
% End of user PostScript
1 .158 0 r
.49322 .82912 m
.42813 .82949 L
s
% Start of user PostScript
-0.20335866 9.8736918 -2.1561221 9.8847607 MAarrowhead1
% End of user PostScript
1 .473 0 r
.16929 .52915 m
.1782 .46359 L
s
% Start of user PostScript
-9.9213619 0.87442448 -9.6540051 -1.0922931 MAarrowhead1
% End of user PostScript
1 .788 0 r
.51779 .16991 m
.58259 .17172 L
s
% Start of user PostScript
0.53381323 -9.9028166 2.4776717 -9.8483793 MAarrowhead1
% End of user PostScript
.897 1 0 r
.83012 .48185 m
.81905 .54734 L
s
% Start of user PostScript
9.903582 -0.54458761 9.5714803 1.4203168 MAarrowhead1
% End of user PostScript
.581 1 0 r
.47121 .8307 m
.40678 .8267 L
s
% Start of user PostScript
-0.8636756 9.9209554 -2.7964727 9.8010723 MAarrowhead1
% End of user PostScript
.266 1 0 r
.17084 .50714 m
.18406 .44177 L
s
% Start of user PostScript
-9.8748152 0.21414658 -9.4783372 -1.7467649 MAarrowhead1
% End of user PostScript
0 1 .049 r
.53975 .16906 m
.60374 .17524 L
s
% Start of user PostScript
1.1925798 -9.928088 3.1121712 -9.7428921 MAarrowhead1
% End of user PostScript
0 1 .364 r
.82784 .50388 m
.81249 .56904 L
s
% Start of user PostScript
9.8350935 0.11653202 9.3746789 2.0712751 MAarrowhead1
% End of user PostScript
0 1 .679 r
.44933 .83081 m
.38585 .82246 L
s
% Start of user PostScript
-1.520161 9.9242067 -3.4244172 9.6739034 MAarrowhead1
% End of user PostScript
0 1 .995 r
.17385 .4851 m
.19131 .42022 L
s
% Start of user PostScript
-9.7844609 -0.44708134 -9.2606205 -2.3934874 MAarrowhead1
% End of user PostScript
0 .69 1 r
.56154 .16969 m
.62443 .18019 L
s
% Start of user PostScript
1.8460558 -9.9093155 3.7328642 -9.5941826 MAarrowhead1
% End of user PostScript
0 .375 1 r
.8241 .5259 m
.80454 .59043 L
s
% Start of user PostScript
9.7229736 0.77713468 9.1362886 2.7130445 MAarrowhead1
% End of user PostScript
0 .06 1 r
.42767 .82945 m
.36543 .81679 L
s
% Start of user PostScript
-2.1699025 9.8834312 -4.0371701 9.5038182 MAarrowhead1
% End of user PostScript
1 0 .859 r
.5797 .35691 m
.60458 .37199 L
.62537 .39211 L
.64123 .41645 L
.65155 .44408 L
.65593 .4739 L
.65418 .50474 L
.64638 .5354 L
.63284 .56467 L
.61408 .5914 L
.59085 .61455 L
.56405 .6332 L
.53474 .64662 L
.50406 .65428 L
.47323 .65589 L
.44344 .65139 L
.41588 .64094 L
.39162 .62496 L
.37161 .60408 L
.35664 .57911 L
.34729 .55104 L
.34394 .52096 L
.34671 .49006 L
.3555 .45955 L
.36996 .43063 L
.38953 .40443 L
.41343 .38199 L
.44072 .36417 L
.47035 .35168 L
.50113 .34502 L
.53188 .34444 L
.56137 .34996 L
.58845 .36137 L
.61206 .37822 L
.63128 .39985 L
.64534 .42541 L
.6537 .4539 L
.65602 .4842 L
.65223 .51512 L
.64245 .54544 L
.62709 .57398 L
.60674 .59962 L
.5822 .62135 L
.55444 .63831 L
.52453 .64985 L
.49367 .65551 L
.46305 .65506 L
.43389 .64853 L
.40732 .63617 L
.38438 .61846 L
Mistroke
.36598 .59611 L
.35285 .56998 L
.34549 .54111 L
.34419 .51062 L
.34901 .47972 L
.35975 .44961 L
.376 .42148 L
.39711 .39643 L
.42226 .37545 L
.45047 .35935 L
.48061 .34878 L
.51152 .34414 L
.54198 .34562 L
.57078 .35315 L
.59682 .36645 L
.61905 .38499 L
.6366 .40804 L
.6488 .43471 L
.65516 .46393 L
.65543 .49457 L
.6496 .52543 L
.63789 .55528 L
.62078 .58297 L
.59892 .6074 L
.57319 .62761 L
.54458 .64282 L
.51422 .65242 L
.4833 .65604 L
.45304 .65354 L
.42462 .64501 L
.39916 .63079 L
.37766 .61143 L
.36096 .58771 L
.34971 .56054 L
.34437 .53099 L
.34513 .50023 L
.35197 .46946 L
.36462 .43989 L
.38258 .41268 L
.40515 .38889 L
.43144 .36947 L
.46043 .35516 L
.49096 .34655 L
.52186 .34395 L
.55189 .34748 L
.57989 .35699 L
.60475 .37212 L
.6255 .39227 L
.64133 .41664 L
.65161 .44429 L
Mistroke
.65593 .47412 L
.65414 .50497 L
.6463 .53562 L
.63272 .56487 L
.61393 .59158 L
.59067 .6147 L
.56385 .63331 L
.53452 .64669 L
.50384 .65432 L
.47301 .65588 L
.44324 .65133 L
.41569 .64085 L
.39146 .62483 L
.37148 .60391 L
.35655 .57892 L
.34724 .55083 L
.34394 .52074 L
.34675 .48984 L
.35559 .45934 L
.37009 .43043 L
.38968 .40426 L
.41361 .38184 L
.44093 .36406 L
.47056 .35161 L
.50136 .34499 L
.53209 .34445 L
.56157 .35002 L
.58863 .36147 L
.61222 .37836 L
.6314 .40002 L
.64542 .42561 L
.65374 .45411 L
.65602 .48442 L
.65218 .51534 L
.64236 .54566 L
.62696 .57418 L
.60658 .59979 L
.58201 .62149 L
.55423 .63842 L
.52432 .64991 L
.49345 .65553 L
.46284 .65503 L
.43369 .64846 L
.40714 .63606 L
.38423 .61832 L
.36587 .59593 L
.35277 .56978 L
.34545 .54089 L
.3442 .5104 L
.34906 .4795 L
Mistroke
.35985 .4494 L
.37613 .42129 L
.39728 .39627 L
.42245 .37532 L
.45068 .35926 L
.48083 .34872 L
.51174 .34413 L
.54219 .34565 L
.57098 .35323 L
.59699 .36656 L
.61919 .38514 L
.63671 .40822 L
.64887 .43491 L
.65518 .46415 L
.65541 .49479 L
.64953 .52564 L
.63779 .55549 L
.62064 .58316 L
.59875 .60756 L
.57299 .62774 L
.54437 .64291 L
.514 .65247 L
.48308 .65605 L
.45283 .6535 L
.42443 .64493 L
.39899 .63067 L
.37752 .61128 L
.36086 .58752 L
.34965 .56033 L
.34435 .53077 L
.34516 .50001 L
.35204 .46924 L
.36473 .43968 L
.38273 .41249 L
.40533 .38873 L
.43164 .36934 L
.46064 .35508 L
.49119 .34651 L
.52208 .34395 L
.5521 .34753 L
.58008 .35708 L
.60491 .37225 L
.62563 .39243 L
.64142 .41683 L
.65166 .44449 L
.65594 .47434 L
.65411 .50519 L
.64623 .53584 L
.63261 .56508 L
.61378 .59176 L
Mistroke
.59049 .61485 L
Mfstroke
1 0 0 r
.5797 .35691 m
.60458 .37199 L
s
% Start of user PostScript
2.3908794 -4.2928395 3.1375273 -3.8401753 MAarrowhead1
% End of user PostScript
1 .158 0 r
.62537 .39211 m
.64123 .41645 L
s
% Start of user PostScript
3.76104 -3.2367996 4.236947 -2.5063926 MAarrowhead1
% End of user PostScript
1 .473 0 r
.59085 .61455 m
.56405 .6332 L
s
% Start of user PostScript
2.7255189 3.4364091 1.921564 3.9958576 MAarrowhead1
% End of user PostScript
1 .788 0 r
.37161 .60408 m
.35664 .57911 L
s
% Start of user PostScript
-3.8518199 3.1223418 -4.3009492 2.373301 MAarrowhead1
% End of user PostScript
.897 1 0 r
.41343 .38199 m
.44072 .36417 L
s
% Start of user PostScript
-2.5972249 -3.5404061 -1.7783107 -4.074906 MAarrowhead1
% End of user PostScript
.581 1 0 r
.63128 .39985 m
.64534 .42541 L
s
% Start of user PostScript
3.9383266 -3.0044202 4.3601801 -2.2375766 MAarrowhead1
% End of user PostScript
.266 1 0 r
.5822 .62135 m
.55444 .63831 L
s
% Start of user PostScript
2.4660496 3.6404754 1.6330845 4.1494338 MAarrowhead1
% End of user PostScript
0 1 .049 r
.36598 .59611 m
.35285 .56998 L
s
% Start of user PostScript
-4.0204643 2.8831655 -4.4145739 2.0993698 MAarrowhead1
% End of user PostScript
0 1 .364 r
.42226 .37545 m
.45047 .35935 L
s
% Start of user PostScript
-2.3321384 -3.7365061 -1.4860466 -4.2193583 MAarrowhead1
% End of user PostScript
0 1 .679 r
.6366 .40804 m
.6488 .43471 L
s
% Start of user PostScript
4.0981417 -2.7587122 4.4640702 -1.9588341 MAarrowhead1
% End of user PostScript
0 1 .995 r
.57319 .62761 m
.54458 .64282 L
s
% Start of user PostScript
2.1956401 3.8283916 1.3373601 4.284602 MAarrowhead1
% End of user PostScript
0 .69 1 r
.36096 .58771 m
.34971 .56054 L
s
% Start of user PostScript
-4.1712727 2.6311986 -4.5086141 1.8161252 MAarrowhead1
% End of user PostScript
0 .375 1 r
.43144 .36947 m
.46043 .35516 L
s
% Start of user PostScript
-2.0567059 -3.9160299 -1.18719 -4.3450923 MAarrowhead1
% End of user PostScript
0 .06 1 r
.64133 .41664 m
.65161 .44429 L
s
% Start of user PostScript
4.2397762 -2.5007659 4.5481563 -1.6714016 MAarrowhead1
% End of user PostScript
1 0 .684 r
.76374 .79597 m
.69321 .84992 L
.61509 .89013 L
.53246 .91503 L
.44856 .92364 L
.36667 .91563 L
.29002 .89131 L
.2216 .85162 L
.16412 .79814 L
.11981 .73296 L
.09043 .65863 L
.07712 .57808 L
.0804 .49447 L
.10016 .41107 L
.1356 .33116 L
.18535 .25788 L
.24745 .1941 L
.31945 .14232 L
.39855 .10459 L
.48162 .08237 L
.56542 .07654 L
.64665 .08733 L
.72212 .11432 L
.78888 .15644 L
.8443 .21205 L
.8862 .27895 L
.91295 .35454 L
.9235 .43583 L
.91742 .51964 L
.89496 .60268 L
.857 .68168 L
.80503 .75356 L
.74109 .81549 L
.66768 .86504 L
.5877 .90026 L
.50427 .91977 L
.42068 .92281 L
.3402 .90925 L
.26599 .87963 L
.20096 .83511 L
.14767 .77745 L
.10821 .70889 L
.08413 .63213 L
.07636 .55019 L
.08522 .46628 L
.11036 .38369 L
.1508 .30567 L
.20493 .23527 L
.27065 .17527 L
.34537 .128 L
Mistroke
.42615 .09534 L
.50984 .07856 L
.59314 .07832 L
.67278 .09462 L
.74564 .12684 L
.80887 .1737 L
.85997 .23337 L
.89694 .3035 L
.91833 .38134 L
.92331 .46384 L
.91167 .54776 L
.88388 .62981 L
.84102 .70676 L
.78478 .77559 L
.71736 .83361 L
.64141 .87854 L
.55991 .90861 L
.47606 .92264 L
.39315 .92009 L
.31443 .90105 L
.243 .86627 L
.18165 .81712 L
.13279 .75552 L
.09835 .68389 L
.07967 .60505 L
.07749 .52208 L
.09189 .43824 L
.1223 .35683 L
.16754 .28104 L
.22582 .21384 L
.29487 .15788 L
.37197 .11533 L
.45409 .08789 L
.53801 .07662 L
.62044 .08197 L
.69815 .10372 L
.76808 .14102 L
.82748 .19241 L
.87404 .25588 L
.90591 .32892 L
.92186 .40868 L
.92125 .49202 L
.9041 .57568 L
.8711 .65637 L
.82353 .73091 L
.76327 .7964 L
.69267 .85026 L
.61451 .89036 L
.53186 .91515 L
.44796 .92365 L
Mistroke
.3661 .91551 L
.28949 .89108 L
.22115 .85129 L
.16375 .79771 L
.11955 .73246 L
.09027 .65808 L
.07708 .57749 L
.08049 .49387 L
.10036 .41048 L
.13591 .33061 L
.18575 .25738 L
.24793 .19368 L
.32 .142 L
.39913 .10437 L
.48223 .08227 L
.56601 .07656 L
.64721 .08747 L
.72263 .11457 L
.78932 .15679 L
.84465 .21249 L
.88645 .27947 L
.91309 .3551 L
.92351 .43642 L
.91731 .52024 L
.89474 .60326 L
.85667 .68223 L
.80461 .75405 L
.74059 .81589 L
.66713 .86534 L
.58711 .90045 L
.50367 .91985 L
.42009 .92277 L
.33964 .90909 L
.26549 .87936 L
.20054 .83475 L
.14734 .77699 L
.10798 .70836 L
.08401 .63156 L
.07637 .54959 L
.08535 .46568 L
.1106 .38311 L
.15114 .30514 L
.20537 .2348 L
.27116 .17488 L
.34593 .12772 L
.42675 .09516 L
.51044 .0785 L
.59373 .07838 L
.67333 .0948 L
.74613 .12713 L
Mistroke
.80928 .17409 L
.86028 .23384 L
.89715 .30404 L
.91843 .38192 L
.92329 .46445 L
.91153 .54836 L
.88363 .63038 L
.84066 .70728 L
.78433 .77605 L
.71684 .83398 L
.64084 .87881 L
.55932 .90877 L
.47546 .92269 L
.39257 .92001 L
.31389 .90086 L
.24252 .86597 L
.18125 .81672 L
.13249 .75504 L
.09816 .68335 L
.0796 .60446 L
.07753 .52148 L
.09205 .43765 L
.12257 .35627 L
.16791 .28053 L
.22628 .2134 L
.2954 .15752 L
.37254 .11508 L
.45469 .08775 L
.53861 .0766 L
.62102 .08206 L
.69868 .10393 L
.76854 .14134 L
.82786 .19283 L
.87432 .25637 L
.90608 .32947 L
.92191 .40927 L
.92118 .49263 L
.90392 .57627 L
.87081 .65693 L
.82314 .73142 L
.7628 .79683 L
.69214 .85059 L
.61393 .8906 L
.53126 .91527 L
.44736 .92365 L
.36553 .9154 L
.28897 .89084 L
.2207 .85095 L
.16338 .79729 L
.11928 .73195 L
Mistroke
.09012 .65752 L
Mfstroke
1 0 0 r
.76374 .79597 m
.69321 .84992 L
s
% Start of user PostScript
7.9122091 8.8791121 5.7962468 10.497479 MAarrowhead1
% End of user PostScript
1 .158 0 r
.61509 .89013 m
.53246 .91503 L
s
% Start of user PostScript
3.4528051 11.703862 0.97385475 12.450915 MAarrowhead1
% End of user PostScript
1 .473 0 r
.09043 .65863 m
.07712 .57808 L
s
% Start of user PostScript
-12.287202 4.7590488 -12.686498 2.3425139 MAarrowhead1
% End of user PostScript
1 .788 0 r
.39855 .10459 m
.48162 .08237 L
s
% Start of user PostScript
-3.0435506 -11.862373 -0.55130074 -12.528938 MAarrowhead1
% End of user PostScript
.897 1 0 r
.91295 .35454 m
.9235 .43583 L
s
% Start of user PostScript
12.388575 -4.3639442 12.704861 -1.9252078 MAarrowhead1
% End of user PostScript
.581 1 0 r
.5877 .90026 m
.50427 .91977 L
s
% Start of user PostScript
2.6309196 12.007725 0.12813512 12.593062 MAarrowhead1
% End of user PostScript
.266 1 0 r
.08413 .63213 m
.07636 .55019 L
s
% Start of user PostScript
-12.476204 3.9639984 -12.709128 1.5057659 MAarrowhead1
% End of user PostScript
0 1 .049 r
.42615 .09534 m
.50984 .07856 L
s
% Start of user PostScript
-2.21537 -12.139755 0.29517265 -12.643215 MAarrowhead1
% End of user PostScript
0 1 .364 r
.91833 .38134 m
.92331 .46384 L
s
% Start of user PostScript
12.549992 -3.559655 12.699297 -1.0846535 MAarrowhead1
% End of user PostScript
0 1 .679 r
.55991 .90861 m
.47606 .92264 L
s
% Start of user PostScript
1.7973626 12.258318 -0.71815296 12.679342 MAarrowhead1
% End of user PostScript
0 1 .995 r
.07967 .60505 m
.07749 .52208 L
s
% Start of user PostScript
-12.609857 3.1513625 -12.675377 0.66233782 MAarrowhead1
% End of user PostScript
0 .69 1 r
.45409 .08789 m
.53801 .07662 L
s
% Start of user PostScript
-1.3773613 -12.363282 1.1403366 -12.701403 MAarrowhead1
% End of user PostScript
0 .375 1 r
.92186 .40868 m
.92125 .49202 L
s
% Start of user PostScript
12.655734 -2.739574 12.637396 -0.23928737 MAarrowhead1
% End of user PostScript
0 .06 1 r
.53186 .91515 m
.44796 .92365 L
s
% Start of user PostScript
0.95583198 12.45453 -1.5612551 12.709373 MAarrowhead1
% End of user PostScript
1 .925 0 r
.34132 .64496 m
.31958 .61419 L
.30491 .57893 L
.2979 .54058 L
.29882 .50064 L
.30764 .46067 L
.32401 .42225 L
.34728 .38687 L
.37655 .35594 L
.41066 .33066 L
.44828 .31202 L
.48792 .30077 L
.52805 .29733 L
.56707 .30185 L
.60346 .31414 L
.63579 .33373 L
.66279 .35984 L
.6834 .39145 L
.69681 .42733 L
.7025 .46605 L
.70024 .50611 L
.69013 .54593 L
.67255 .58394 L
.6482 .61867 L
.61803 .64873 L
.58323 .67296 L
.54517 .6904 L
.50533 .70036 L
.46528 .70247 L
.4266 .69662 L
.39079 .68307 L
.35928 .66232 L
.33328 .63521 L
.31383 .60279 L
.30168 .56633 L
.29732 .52727 L
.30091 .48715 L
.31232 .44752 L
.33109 .40996 L
.35649 .37593 L
.38752 .34677 L
.42297 .32362 L
.46144 .30739 L
.50142 .29873 L
.54135 .29796 L
.57965 .30512 L
.61483 .31993 L
.6455 .34181 L
.67047 .3699 L
.68874 .40309 L
Mistroke
.6996 .44008 L
.70263 .47943 L
.69771 .51958 L
.68503 .55897 L
.66509 .59604 L
.63867 .62934 L
.6068 .65757 L
.57075 .67961 L
.53191 .6946 L
.49183 .70196 L
.45207 .70139 L
.41418 .69291 L
.37967 .67687 L
.34988 .65388 L
.32598 .62486 L
.30891 .59093 L
.29934 .55344 L
.29764 .51384 L
.30389 .47371 L
.31783 .43461 L
.33892 .39807 L
.36634 .36553 L
.39899 .33828 L
.43562 .31736 L
.47477 .30362 L
.51491 .29758 L
.55447 .29949 L
.59188 .30927 L
.6257 .32653 L
.65457 .3506 L
.67739 .38053 L
.69324 .41515 L
.7015 .45311 L
.70186 .4929 L
.6943 .53297 L
.67911 .57175 L
.65689 .60771 L
.62852 .63944 L
.5951 .6657 L
.55795 .68546 L
.51852 .69794 L
.47837 .70265 L
.43906 .69941 L
.40215 .68834 L
.36908 .66988 L
.34115 .64476 L
.31945 .61395 L
.30483 .57867 L
.29788 .5403 L
.29886 .50035 L
Mistroke
.30773 .46039 L
.32415 .42198 L
.34747 .38663 L
.37677 .35574 L
.41092 .3305 L
.44856 .31192 L
.48821 .30071 L
.52833 .29733 L
.56734 .30191 L
.60371 .31425 L
.636 .33389 L
.66296 .36005 L
.68352 .3917 L
.69688 .4276 L
.70251 .46634 L
.7002 .5064 L
.69003 .54621 L
.6724 .58421 L
.648 .6189 L
.6178 .64893 L
.58297 .67311 L
.54489 .69049 L
.50504 .70041 L
.465 .70245 L
.42633 .69655 L
.39055 .68294 L
.35907 .66215 L
.33312 .63499 L
.31372 .60254 L
.30162 .56606 L
.29732 .52699 L
.30097 .48686 L
.31243 .44724 L
.33125 .4097 L
.35669 .3757 L
.38776 .34658 L
.42323 .32348 L
.46172 .30731 L
.50171 .29869 L
.54163 .29798 L
.57992 .3052 L
.61507 .32007 L
.6457 .34199 L
.67062 .37012 L
.68884 .40334 L
.69965 .44036 L
.70262 .47972 L
.69765 .51987 L
.68491 .55924 L
.66492 .59629 L
Mistroke
.63845 .62956 L
.60656 .65775 L
.57048 .67974 L
.53163 .69468 L
.49154 .70198 L
.45179 .70135 L
.41392 .69282 L
.37944 .67673 L
.34968 .65369 L
.32583 .62463 L
.30881 .59067 L
.2993 .55316 L
.29766 .51356 L
.30396 .47342 L
.31796 .43433 L
.3391 .39782 L
.36655 .36532 L
.39924 .3381 L
.43589 .31724 L
.47506 .30355 L
.5152 .29757 L
.55474 .29953 L
.59214 .30936 L
.62592 .32668 L
.65476 .35079 L
.67753 .38076 L
.69332 .41542 L
.70154 .45339 L
.70184 .49319 L
.69422 .53325 L
.67898 .57202 L
.65671 .60795 L
.62829 .63965 L
.59484 .66587 L
.55767 .68558 L
.51823 .698 L
.47808 .70266 L
.43879 .69936 L
.4019 .68824 L
.36886 .66973 L
.34097 .64456 L
.31932 .61371 L
.30476 .5784 L
.29786 .54002 L
.29889 .50006 L
.30782 .46011 L
.32429 .42171 L
.34766 .38639 L
.377 .35553 L
.41118 .33034 L
Mistroke
.44883 .31181 L
Mfstroke
1 0 0 r
.34132 .64496 m
.31958 .61419 L
s
% Start of user PostScript
-4.7602622 4.3487824 -5.4126845 3.4256369 MAarrowhead1
% End of user PostScript
1 .158 0 r
.30491 .57893 m
.2979 .54058 L
s
% Start of user PostScript
-5.8526807 2.368049 -6.0629828 1.2175246 MAarrowhead1
% End of user PostScript
1 .473 0 r
.44828 .31202 m
.48792 .30077 L
s
% Start of user PostScript
-1.5517031 -5.6392616 -0.36225019 -5.9769686 MAarrowhead1
% End of user PostScript
1 .788 0 r
.69681 .42733 m
.7025 .46605 L
s
% Start of user PostScript
5.9043639 -2.1802199 6.0750484 -1.0184475 MAarrowhead1
% End of user PostScript
.897 1 0 r
.54517 .6904 m
.50533 .70036 L
s
% Start of user PostScript
1.3550442 5.711879 0.15990624 6.0108904 MAarrowhead1
% End of user PostScript
.581 1 0 r
.30168 .56633 m
.29732 .52727 L
s
% Start of user PostScript
-5.9494968 1.9899722 -6.0803744 0.81824047 MAarrowhead1
% End of user PostScript
.266 1 0 r
.46144 .30739 m
.50142 .29873 L
s
% Start of user PostScript
-1.156882 -5.7781598 0.042615099 -6.0381439 MAarrowhead1
% End of user PostScript
0 1 .049 r
.6996 .44008 m
.70263 .47943 L
s
% Start of user PostScript
5.9880295 -1.7975168 6.078955 -0.61712572 MAarrowhead1
% End of user PostScript
0 1 .364 r
.53191 .6946 m
.49183 .70196 L
s
% Start of user PostScript
0.95743646 5.8380303 -0.24508916 6.0586987 MAarrowhead1
% End of user PostScript
0 1 .679 r
.29934 .55344 m
.29764 .51384 L
s
% Start of user PostScript
-6.0199192 1.6030674 -6.0707917 0.41532634 MAarrowhead1
% End of user PostScript
0 1 .995 r
.47477 .30362 m
.51491 .29758 L
s
% Start of user PostScript
-0.75692872 -5.8914243 0.44729133 -6.0725321 MAarrowhead1
% End of user PostScript
0 .69 1 r
.7015 .45311 m
.70186 .4929 L
s
% Start of user PostScript
6.0451305 -1.4068394 6.0558936 -0.21306621 MAarrowhead1
% End of user PostScript
0 .375 1 r
.51852 .69794 m
.47837 .70265 L
s
% Start of user PostScript
0.55558127 5.9382824 -0.64899728 6.0796288 MAarrowhead1
% End of user PostScript
0 .06 1 r
.29788 .5403 m
.29886 .50035 L
s
% Start of user PostScript
-6.0636355 1.2090508 -6.0342772 0.010569699 MAarrowhead1
% End of user PostScript
0 1 .348 r
.54021 .72334 m
.49405 .7325 L
.44812 .73253 L
.40422 .72343 L
.36409 .70557 L
.32929 .67963 L
.30118 .64665 L
.28089 .60791 L
.26919 .56494 L
.26655 .51942 L
.27307 .47313 L
.28849 .4279 L
.31222 .3855 L
.34332 .3476 L
.38057 .31567 L
.4225 .29098 L
.46748 .27449 L
.51373 .26685 L
.55944 .26837 L
.60282 .27897 L
.64217 .29825 L
.67593 .32544 L
.70279 .35949 L
.7217 .39905 L
.7319 .44257 L
.733 .48835 L
.72495 .53458 L
.70808 .57946 L
.68304 .62122 L
.65082 .65822 L
.61268 .68901 L
.57012 .71238 L
.5248 .72742 L
.47851 .73353 L
.43307 .73048 L
.39025 .71838 L
.35174 .69772 L
.31904 .66929 L
.29345 .63422 L
.27597 .59388 L
.26728 .54985 L
.26772 .50387 L
.27728 .45774 L
.29557 .41327 L
.3219 .3722 L
.35521 .33614 L
.3942 .30652 L
.43735 .28449 L
.48295 .27092 L
.52923 .26634 L
Mistroke
.57435 .27093 L
.61656 .28451 L
.6542 .30654 L
.68578 .33617 L
.71007 .37223 L
.72612 .4133 L
.73329 .45778 L
.73131 .50391 L
.72025 .54989 L
.70054 .59391 L
.67297 .63424 L
.63861 .66931 L
.5988 .69773 L
.55512 .7184 L
.50928 .73049 L
.46307 .73353 L
.41831 .72741 L
.37676 .71237 L
.34004 .68899 L
.3096 .65819 L
.28664 .62119 L
.27205 .57942 L
.2664 .53455 L
.26992 .48831 L
.28247 .44254 L
.30356 .39902 L
.33236 .35946 L
.36774 .32542 L
.4083 .29823 L
.45247 .27896 L
.4985 .26836 L
.54459 .26686 L
.58893 .2745 L
.62978 .291 L
.66554 .31569 L
.6948 .34762 L
.71642 .38553 L
.72954 .42794 L
.73365 .47317 L
.72859 .51945 L
.71457 .56497 L
.69212 .60794 L
.66213 .64668 L
.62578 .67966 L
.58449 .70558 L
.53988 .72344 L
.49372 .73253 L
.44779 .73249 L
.40392 .72333 L
.36382 .70541 L
Mistroke
.32906 .67942 L
.30101 .64639 L
.28077 .60762 L
.26913 .56462 L
.26656 .51909 L
.27315 .4728 L
.28864 .42759 L
.31242 .38521 L
.34357 .34735 L
.38085 .31547 L
.42281 .29083 L
.4678 .27441 L
.51406 .26683 L
.55976 .26841 L
.60312 .27908 L
.64243 .29842 L
.67615 .32566 L
.70296 .35975 L
.7218 .39935 L
.73194 .44289 L
.73297 .48868 L
.72486 .53491 L
.70793 .57977 L
.68284 .6215 L
.65057 .65846 L
.61239 .6892 L
.5698 .71252 L
.52447 .7275 L
.47818 .73354 L
.43275 .73043 L
.38995 .71827 L
.35148 .69754 L
.31883 .66906 L
.2933 .63394 L
.27587 .59357 L
.26725 .54953 L
.26775 .50354 L
.27738 .45742 L
.29574 .41296 L
.32211 .37192 L
.35547 .33591 L
.3945 .30634 L
.43767 .28436 L
.48328 .27085 L
.52955 .26634 L
.57467 .27099 L
.61685 .28463 L
.65445 .30673 L
.68598 .33641 L
.71022 .37251 L
Mistroke
.7262 .41361 L
.73331 .4581 L
.73126 .50424 L
.72014 .55021 L
.70037 .59421 L
.67275 .63452 L
.63834 .66954 L
.5985 .69791 L
.5548 .71851 L
.50895 .73054 L
.46274 .73352 L
.418 .72734 L
.37648 .71223 L
.3398 .68879 L
.30941 .65795 L
.2865 .6209 L
.27197 .57911 L
.26639 .53422 L
.26998 .48798 L
.28259 .44222 L
.30374 .39872 L
.33259 .3592 L
.36801 .3252 L
.40861 .29806 L
.4528 .27885 L
.49883 .26832 L
.54492 .26688 L
.58924 .27459 L
.63006 .29115 L
.66577 .3159 L
.69498 .34788 L
.71654 .38582 L
.7296 .42825 L
.73365 .4735 L
.72852 .51978 L
.71443 .56529 L
.69193 .60824 L
.66189 .64694 L
.6255 .67987 L
.58418 .70574 L
.53956 .72354 L
.49338 .73256 L
.44747 .73246 L
.40362 .72324 L
.36355 .70525 L
.32883 .67921 L
.30084 .64613 L
.28066 .60732 L
.26908 .5643 L
.26657 .51876 L
Mistroke
.27323 .47247 L
Mfstroke
1 0 0 r
.54021 .72334 m
.49405 .7325 L
s
% Start of user PostScript
1.2063591 6.7003279 -0.17856345 6.9749501 MAarrowhead1
% End of user PostScript
1 .158 0 r
.44812 .73253 m
.40422 .72343 L
s
% Start of user PostScript
-1.5564781 6.9758337 -2.8733072 6.7029439 MAarrowhead1
% End of user PostScript
1 .473 0 r
.27307 .47313 m
.28849 .4279 L
s
% Start of user PostScript
-6.8080127 -0.80598769 -6.3451918 -2.1628741 MAarrowhead1
% End of user PostScript
1 .788 0 r
.55944 .26837 m
.60282 .27897 L
s
% Start of user PostScript
1.7832351 -6.9489883 3.0846489 -6.6309042 MAarrowhead1
% End of user PostScript
.897 1 0 r
.72495 .53458 m
.70808 .57946 L
s
% Start of user PostScript
6.7486178 1.0374403 6.2424502 2.3837322 MAarrowhead1
% End of user PostScript
.581 1 0 r
.43307 .73048 m
.39025 .71838 L
s
% Start of user PostScript
-2.0080139 6.9144339 -3.2925686 6.5515083 MAarrowhead1
% End of user PostScript
.266 1 0 r
.27728 .45774 m
.29557 .41327 L
s
% Start of user PostScript
-6.6817361 -1.267742 -6.1327834 -2.6019457 MAarrowhead1
% End of user PostScript
0 1 .049 r
.57435 .27093 m
.61656 .28451 L
s
% Start of user PostScript
2.230565 -6.8722088 3.4968355 -6.4648443 MAarrowhead1
% End of user PostScript
0 1 .364 r
.72025 .54989 m
.70054 .59391 L
s
% Start of user PostScript
6.6074418 1.4966372 6.016313 2.8172728 MAarrowhead1
% End of user PostScript
0 1 .679 r
.41831 .72741 m
.37676 .71237 L
s
% Start of user PostScript
-2.4506416 6.8223597 -3.6972231 6.3710084 MAarrowhead1
% End of user PostScript
0 1 .995 r
.28247 .44254 m
.30356 .39902 L
s
% Start of user PostScript
-6.5258174 -1.7238722 -5.8931682 -3.0294744 MAarrowhead1
% End of user PostScript
0 .69 1 r
.58893 .2745 m
.62978 .291 L
s
% Start of user PostScript
2.6679995 -6.764942 3.8935091 -6.2701045 MAarrowhead1
% End of user PostScript
0 .375 1 r
.71457 .56497 m
.69212 .60794 L
s
% Start of user PostScript
6.4369533 1.9491946 5.7634856 3.2383151 MAarrowhead1
% End of user PostScript
0 .06 1 r
.40392 .72333 m
.36382 .70541 L
s
% Start of user PostScript
-2.8823975 6.7000195 -4.0854757 6.1622447 MAarrowhead1
% End of user PostScript
.151 1 0 r
.4088 .64023 m
.38499 .62284 L
.3657 .60063 L
.35167 .57447 L
.34347 .54539 L
.34141 .51452 L
.34558 .48309 L
.3558 .45232 L
.37169 .42342 L
.39261 .39753 L
.41774 .37565 L
.44611 .35866 L
.47658 .34722 L
.50798 .34177 L
.53907 .34253 L
.56862 .34947 L
.59548 .36232 L
.61859 .38057 L
.63704 .40351 L
.65012 .43024 L
.65731 .4597 L
.65832 .49075 L
.65312 .52216 L
.64191 .55269 L
.62513 .58117 L
.60344 .60645 L
.57769 .62756 L
.54889 .64366 L
.51818 .65413 L
.48674 .65854 L
.45583 .65673 L
.42666 .64878 L
.40036 .63498 L
.37797 .61588 L
.36037 .59224 L
.34825 .56498 L
.34208 .53517 L
.34212 .50397 L
.34835 .47262 L
.36053 .44235 L
.37818 .41434 L
.40062 .38969 L
.42696 .36937 L
.45616 .35417 L
.48708 .3447 L
.51851 .34133 L
.54922 .34418 L
.57799 .35314 L
.6037 .36787 L
.62534 .38779 L
Mistroke
.64207 .41211 L
.65321 .43988 L
.65835 .47001 L
.65727 .50131 L
.65001 .53257 L
.63687 .56254 L
.61836 .59006 L
.5952 .61405 L
.56831 .63356 L
.53874 .64783 L
.50764 .6563 L
.47625 .65863 L
.44579 .65474 L
.41745 .64477 L
.39236 .62913 L
.37149 .60841 L
.35566 .58344 L
.3455 .5552 L
.3414 .52479 L
.34353 .4934 L
.35179 .46228 L
.36588 .43264 L
.38522 .40564 L
.40908 .38234 L
.4365 .36366 L
.46641 .35033 L
.49764 .34288 L
.52896 .34159 L
.55915 .34652 L
.58702 .35747 L
.61147 .37402 L
.63154 .39551 L
.64646 .4211 L
.65562 .44979 L
.65868 .48045 L
.65551 .51187 L
.64624 .54283 L
.63122 .57211 L
.61106 .59856 L
.58654 .62114 L
.55863 .63897 L
.52841 .65134 L
.49707 .65777 L
.46586 .65801 L
.43598 .65205 L
.40861 .64013 L
.38483 .6227 L
.36558 .60046 L
.35159 .57427 L
.34343 .54517 L
Mistroke
.34142 .5143 L
.34563 .48287 L
.3559 .4521 L
.37182 .42322 L
.39277 .39735 L
.41793 .37551 L
.44632 .35856 L
.47681 .34716 L
.50821 .34175 L
.53929 .34256 L
.56882 .34954 L
.59566 .36243 L
.61874 .38072 L
.63716 .40369 L
.6502 .43044 L
.65734 .45992 L
.65831 .49097 L
.65306 .52238 L
.64181 .55291 L
.625 .58136 L
.60327 .60662 L
.5775 .62769 L
.54868 .64376 L
.51795 .65418 L
.48652 .65855 L
.45562 .6567 L
.42646 .6487 L
.40018 .63486 L
.37782 .61573 L
.36026 .59206 L
.34818 .56477 L
.34206 .53495 L
.34214 .50375 L
.34841 .4724 L
.36064 .44214 L
.37833 .41415 L
.4008 .38953 L
.42716 .36924 L
.45638 .35408 L
.48731 .34466 L
.51874 .34132 L
.54943 .34422 L
.57819 .35323 L
.60387 .368 L
.62548 .38795 L
.64217 .4123 L
.65327 .44009 L
.65836 .47023 L
.65723 .50154 L
.64994 .53279 L
Mistroke
.63676 .56275 L
.61821 .59025 L
.59502 .61421 L
.56811 .63368 L
.53852 .64791 L
.50742 .65634 L
.47602 .65862 L
.44557 .65469 L
.41726 .64468 L
.39219 .62899 L
.37135 .60825 L
.35557 .58325 L
.34545 .55499 L
.34139 .52456 L
.34356 .49318 L
.35187 .46206 L
.366 .43243 L
.38538 .40545 L
.40926 .38219 L
.4367 .36355 L
.46663 .35026 L
.49787 .34285 L
.52919 .3416 L
.55936 .34658 L
.5872 .35757 L
.61163 .37415 L
.63167 .39568 L
.64654 .4213 L
.65566 .45 L
.65868 .48067 L
.65546 .5121 L
.64615 .54305 L
.6311 .57231 L
.6109 .59874 L
.58635 .62129 L
.55842 .63908 L
.52819 .65141 L
.49685 .6578 L
.46564 .65799 L
.43577 .65199 L
.40843 .64002 L
.38468 .62256 L
.36546 .60028 L
.35151 .57407 L
.3434 .54496 L
.34143 .51407 L
.34568 .48264 L
.35599 .45189 L
.37195 .42302 L
.39294 .39718 L
Mistroke
.41813 .37537 L
Mfstroke
1 0 0 r
.4088 .64023 m
.38499 .62284 L
s
% Start of user PostScript
-2.7360651 4.2069789 -3.4503067 3.685282 MAarrowhead1
% End of user PostScript
1 .158 0 r
.3657 .60063 m
.35167 .57447 L
s
% Start of user PostScript
-4.0291376 3.0189527 -4.4498412 2.2341416 MAarrowhead1
% End of user PostScript
1 .473 0 r
.41774 .37565 m
.44611 .35866 L
s
% Start of user PostScript
-2.4677431 -3.730403 -1.616835 -4.2401667 MAarrowhead1
% End of user PostScript
1 .788 0 r
.63704 .40351 m
.65012 .43024 L
s
% Start of user PostScript
4.1113317 -2.8947027 4.5036937 -2.0929128 MAarrowhead1
% End of user PostScript
.897 1 0 r
.57769 .62756 m
.54889 .64366 L
s
% Start of user PostScript
2.3308054 3.826818 1.4668288 4.3098761 MAarrowhead1
% End of user PostScript
.581 1 0 r
.36037 .59224 m
.34825 .56498 L
s
% Start of user PostScript
-4.1889647 2.7672415 -4.5525499 1.9493621 MAarrowhead1
% End of user PostScript
.266 1 0 r
.42696 .36937 m
.45616 .35417 L
s
% Start of user PostScript
-2.191282 -3.9189875 -1.3151953 -4.3748043 MAarrowhead1
% End of user PostScript
0 1 .049 r
.64207 .41211 m
.65321 .43988 L
s
% Start of user PostScript
4.2619506 -2.6367103 4.5963556 -1.8036488 MAarrowhead1
% End of user PostScript
0 1 .364 r
.56831 .63356 m
.53874 .64783 L
s
% Start of user PostScript
2.0493276 4.0068094 1.1621027 4.4348791 MAarrowhead1
% End of user PostScript
0 1 .679 r
.35566 .58344 m
.3455 .5552 L
s
% Start of user PostScript
-4.3302083 2.5032539 -4.6350622 1.6559346 MAarrowhead1
% End of user PostScript
0 1 .995 r
.4365 .36366 m
.46641 .35033 L
s
% Start of user PostScript
-1.9050997 -4.0901863 -1.0077209 -4.4900339 MAarrowhead1
% End of user PostScript
0 .69 1 r
.64646 .4211 m
.65562 .44979 L
s
% Start of user PostScript
4.3936622 -2.3670205 4.6686268 -1.5063834 MAarrowhead1
% End of user PostScript
0 .375 1 r
.55863 .63897 m
.52841 .65134 L
s
% Start of user PostScript
1.7587583 4.1690255 0.8522212 4.5402076 MAarrowhead1
% End of user PostScript
0 .06 1 r
.35159 .57427 m
.34343 .54517 L
s
% Start of user PostScript
-4.4522418 2.2281612 -4.697012 1.355161 MAarrowhead1
% End of user PostScript
1 .319 0 r
.51517 .21037 m
.57204 .21188 L
.62608 .22469 L
.67518 .2483 L
.7174 .2818 L
.75109 .32385 L
.77492 .37282 L
.78797 .42679 L
.78971 .48362 L
.78009 .5411 L
.75947 .59696 L
.72867 .64902 L
.68889 .69523 L
.6417 .73378 L
.58895 .76316 L
.53271 .7822 L
.47519 .79017 L
.41863 .78676 L
.36528 .77208 L
.31721 .74673 L
.27631 .7117 L
.24419 .66836 L
.22211 .61841 L
.21094 .56381 L
.21111 .50671 L
.22262 .44935 L
.24502 .39397 L
.27742 .34276 L
.31856 .29771 L
.36682 .26061 L
.4203 .2329 L
.47692 .21567 L
.53444 .2096 L
.5906 .21493 L
.64322 .23145 L
.69021 .2585 L
.72973 .29504 L
.76024 .33961 L
.78054 .39049 L
.78983 .44566 L
.78774 .50296 L
.77436 .56015 L
.75021 .61497 L
.71624 .66529 L
.67379 .70911 L
.62451 .74473 L
.57035 .77075 L
.51343 .78614 L
.45598 .7903 L
.40026 .78306 L
Mistroke
.34845 .76472 L
.30259 .73599 L
.26448 .698 L
.23561 .65223 L
.21712 .6005 L
.20972 .54481 L
.21373 .48737 L
.22896 .43043 L
.25484 .37621 L
.29033 .32685 L
.33406 .28429 L
.38429 .2502 L
.43907 .2259 L
.49624 .21237 L
.55356 .21012 L
.60877 .21925 L
.65972 .2394 L
.70439 .26978 L
.74105 .30919 L
.76825 .35609 L
.78491 .40863 L
.7904 .46477 L
.78449 .52228 L
.76741 .57892 L
.73984 .63247 L
.70286 .68081 L
.65792 .72206 L
.60677 .7546 L
.55144 .77714 L
.49409 .7888 L
.43697 .78914 L
.38232 .77812 L
.3323 .75619 L
.28885 .7242 L
.25369 .68342 L
.2282 .63543 L
.21337 .58214 L
.2098 .52561 L
.21761 .46809 L
.23651 .41181 L
.26574 .359 L
.30417 .31172 L
.35029 .27183 L
.40228 .24089 L
.45811 .22013 L
.51558 .21034 L
.57244 .21193 L
.62645 .22482 L
.67551 .24851 L
.71767 .28207 L
Mistroke
.7513 .32418 L
.77506 .3732 L
.78802 .42719 L
.78968 .48403 L
.77998 .54151 L
.75928 .59735 L
.72841 .64938 L
.68858 .69554 L
.64134 .73403 L
.58856 .76333 L
.5323 .7823 L
.47477 .79019 L
.41824 .78669 L
.36491 .77194 L
.31688 .74652 L
.27605 .71142 L
.244 .66802 L
.22199 .61803 L
.2109 .56341 L
.21116 .5063 L
.22275 .44894 L
.24522 .39359 L
.27769 .34241 L
.31888 .29742 L
.36719 .26038 L
.4207 .23274 L
.47733 .21559 L
.53485 .2096 L
.591 .21501 L
.64358 .23161 L
.69052 .25873 L
.72999 .29533 L
.76043 .33996 L
.78065 .39087 L
.78985 .44606 L
.78768 .50337 L
.77422 .56055 L
.75 .61535 L
.71597 .66562 L
.67346 .7094 L
.62414 .74495 L
.56995 .7709 L
.51302 .78621 L
.45557 .79029 L
.39987 .78297 L
.3481 .76455 L
.30229 .73575 L
.26424 .6977 L
.23544 .65188 L
.21702 .60011 L
Mistroke
.20971 .54441 L
.2138 .48696 L
.22911 .43003 L
.25506 .37584 L
.29062 .32652 L
.33439 .28402 L
.38467 .24999 L
.43947 .22577 L
.49665 .21231 L
.55396 .21015 L
.60915 .21936 L
.66006 .23958 L
.70469 .27003 L
.74128 .3095 L
.7684 .35644 L
.78499 .40903 L
.7904 .46518 L
.78441 .52269 L
.76725 .57932 L
.73961 .63284 L
.70256 .68114 L
.65757 .72233 L
.60639 .7548 L
.55103 .77726 L
.49368 .78885 L
.43657 .7891 L
.38195 .778 L
.33196 .75599 L
.28857 .72394 L
.25347 .6831 L
.22805 .63507 L
.21331 .58174 L
.20981 .5252 L
.21771 .46768 L
.23668 .41142 L
.26599 .35864 L
.30448 .3114 L
.35064 .27157 L
.40267 .24071 L
.45852 .22002 L
.51599 .21031 L
.57284 .21198 L
.62683 .22495 L
.67584 .24872 L
.71795 .28234 L
.7515 .32451 L
.77519 .37357 L
.78808 .42759 L
.78966 .48445 L
.77987 .54192 L
Mistroke
.7591 .59774 L
Mfstroke
1 0 0 r
.51517 .21037 m
.57204 .21188 L
s
% Start of user PostScript
0.45495092 -8.6888236 2.1611072 -8.6437266 MAarrowhead1
% End of user PostScript
1 .158 0 r
.62608 .22469 m
.67518 .2483 L
s
% Start of user PostScript
3.7824488 -8.2593981 5.2553444 -7.5509216 MAarrowhead1
% End of user PostScript
1 .473 0 r
.75947 .59696 m
.72867 .64902 L
s
% Start of user PostScript
7.784067 2.9089287 6.8600179 4.4707107 MAarrowhead1
% End of user PostScript
1 .788 0 r
.36528 .77208 m
.31721 .74673 L
s
% Start of user PostScript
-4.0417156 8.1625093 -5.4838337 7.4020139 MAarrowhead1
% End of user PostScript
.897 1 0 r
.24502 .39397 m
.27742 .34276 L
s
% Start of user PostScript
-7.649448 -3.1808005 -6.6773658 -4.7172523 MAarrowhead1
% End of user PostScript
.581 1 0 r
.64322 .23145 m
.69021 .2585 L
s
% Start of user PostScript
4.2964987 -8.0565652 5.7062392 -7.2448946 MAarrowhead1
% End of user PostScript
.266 1 0 r
.75021 .61497 m
.71624 .66529 L
s
% Start of user PostScript
7.5063429 3.4491436 6.4873059 4.9585608 MAarrowhead1
% End of user PostScript
0 1 .049 r
.34845 .76472 m
.30259 .73599 L
s
% Start of user PostScript
-4.5465153 7.9416833 -5.9223144 7.079738 MAarrowhead1
% End of user PostScript
0 1 .364 r
.25484 .37621 m
.29033 .32685 L
s
% Start of user PostScript
-7.3549104 -3.7136603 -6.2900492 -5.1943683 MAarrowhead1
% End of user PostScript
0 1 .679 r
.65972 .2394 m
.70439 .26978 L
s
% Start of user PostScript
4.7914881 -7.817991 6.1318194 -6.9067272 MAarrowhead1
% End of user PostScript
0 1 .995 r
.73984 .63247 m
.70286 .68081 L
s
% Start of user PostScript
7.1953185 3.974057 6.0858143 5.4244133 MAarrowhead1
% End of user PostScript
0 .69 1 r
.3323 .75619 m
.28885 .7242 L
s
% Start of user PostScript
-5.0311453 7.6856256 -6.334522 6.7260542 MAarrowhead1
% End of user PostScript
0 .375 1 r
.26574 .359 m
.30417 .31172 L
s
% Start of user PostScript
-7.0277442 -4.2300451 -5.874828 -5.6484406 MAarrowhead1
% End of user PostScript
0 .06 1 r
.67551 .24851 m
.71767 .28207 L
s
% Start of user PostScript
5.2652211 -7.5447338 6.5301971 -6.5379194 MAarrowhead1
% End of user PostScript
0 .179 1 r
.60701 .35707 m
.63065 .37759 L
.64916 .40291 L
.66182 .43204 L
.66813 .46384 L
.66784 .49706 L
.66096 .53039 L
.64777 .56253 L
.62877 .59222 L
.60473 .61828 L
.57657 .63971 L
.5454 .65565 L
.51246 .66548 L
.47903 .66882 L
.44641 .66553 L
.41591 .65575 L
.3887 .63985 L
.36586 .61847 L
.34829 .59243 L
.33666 .56277 L
.33145 .53065 L
.33286 .49732 L
.34082 .46409 L
.35503 .43228 L
.37493 .40312 L
.39974 .37777 L
.42849 .35721 L
.46004 .34226 L
.49315 .3335 L
.52654 .33127 L
.55889 .33566 L
.58892 .3465 L
.61547 .36337 L
.63748 .3856 L
.6541 .41232 L
.66467 .44248 L
.66877 .4749 L
.66626 .5083 L
.65722 .54138 L
.642 .57283 L
.62122 .60143 L
.59568 .62604 L
.56638 .64571 L
.53448 .65966 L
.50122 .66734 L
.46792 .66846 L
.43588 .66296 L
.40635 .65107 L
.3805 .63325 L
.35933 .6102 L
Mistroke
.34369 .58283 L
.33419 .5522 L
.33119 .51953 L
.33481 .48609 L
.34492 .45319 L
.36111 .42214 L
.38276 .39413 L
.40901 .37029 L
.43882 .35153 L
.47104 .3386 L
.5044 .33201 L
.53758 .33201 L
.56929 .3386 L
.59828 .35152 L
.62341 .37028 L
.6437 .39412 L
.65835 .42212 L
.66678 .45318 L
.66867 .48607 L
.66394 .51951 L
.65277 .55218 L
.63561 .58281 L
.61313 .61019 L
.58621 .63324 L
.5559 .65106 L
.5234 .66296 L
.48998 .66845 L
.45696 .66734 L
.42562 .65966 L
.39721 .64572 L
.37282 .62605 L
.35343 .60144 L
.33979 .57285 L
.33244 .5414 L
.33167 .50832 L
.3375 .47492 L
.3497 .4425 L
.36781 .41234 L
.39111 .38562 L
.41867 .36338 L
.44943 .34651 L
.48218 .33567 L
.51562 .33127 L
.54845 .33349 L
.57938 .34225 L
.6072 .3572 L
.6308 .37776 L
.64928 .40311 L
.66189 .43226 L
.66815 .46408 L
Mistroke
.66781 .4973 L
.66089 .53063 L
.64765 .56275 L
.62862 .59242 L
.60454 .61846 L
.57635 .63984 L
.54517 .65574 L
.51222 .66553 L
.47879 .66882 L
.44619 .66549 L
.4157 .65566 L
.38852 .63972 L
.36571 .6183 L
.34818 .59223 L
.3366 .56255 L
.33144 .53041 L
.33289 .49708 L
.3409 .46386 L
.35516 .43206 L
.3751 .40293 L
.39994 .3776 L
.4287 .35708 L
.46027 .34217 L
.49339 .33346 L
.52678 .33128 L
.55911 .33572 L
.58913 .3466 L
.61564 .36351 L
.63762 .38578 L
.65419 .41253 L
.66472 .44271 L
.66878 .47514 L
.66622 .50854 L
.65713 .54161 L
.64187 .57305 L
.62105 .60162 L
.59548 .6262 L
.56616 .64583 L
.53424 .65974 L
.50098 .66737 L
.46769 .66844 L
.43565 .6629 L
.40615 .65096 L
.38033 .6331 L
.3592 .61002 L
.3436 .58262 L
.33414 .55197 L
.33119 .51929 L
.33486 .48585 L
.34501 .45296 L
Mistroke
.36125 .42192 L
.38293 .39395 L
.40921 .37014 L
.43905 .35142 L
.47128 .33853 L
.50464 .33199 L
.53782 .33203 L
.56951 .33867 L
.59847 .35164 L
.62357 .37043 L
.64382 .39431 L
.65843 .42233 L
.66682 .45341 L
.66866 .48631 L
.66388 .51975 L
.65267 .55241 L
.63547 .58302 L
.61295 .61037 L
.586 .63339 L
.55567 .65117 L
.52316 .66302 L
.48974 .66847 L
.45673 .66731 L
.42541 .65959 L
.39702 .6456 L
.37267 .62589 L
.35331 .60125 L
.33972 .57263 L
.33241 .54116 L
.33168 .50808 L
.33756 .47468 L
.34981 .44227 L
.36796 .41213 L
.39129 .38544 L
.41889 .36324 L
.44966 .34641 L
.48242 .33561 L
.51586 .33126 L
.54868 .33353 L
.57959 .34234 L
.60738 .35733 L
.63096 .37792 L
.64939 .40331 L
.66196 .43248 L
.66817 .46431 L
.66779 .49754 L
.66082 .53086 L
.64753 .56298 L
.62846 .59262 L
.60435 .61863 L
Mistroke
.57614 .63998 L
Mfstroke
1 0 0 r
.60701 .35707 m
.63065 .37759 L
s
% Start of user PostScript
3.2103358 -4.2877806 3.9195462 -3.6722721 MAarrowhead1
% End of user PostScript
1 .158 0 r
.64916 .40291 m
.66182 .43204 L
s
% Start of user PostScript
4.4749301 -2.9126418 4.8546912 -2.0387019 MAarrowhead1
% End of user PostScript
1 .473 0 r
.57657 .63971 m
.5454 .65565 L
s
% Start of user PostScript
2.2970257 4.1912789 1.3621361 4.6695254 MAarrowhead1
% End of user PostScript
1 .788 0 r
.34829 .59243 m
.33666 .56277 L
s
% Start of user PostScript
-4.5514381 2.7730412 -4.9000603 1.8831723 MAarrowhead1
% End of user PostScript
.897 1 0 r
.42849 .35721 m
.46004 .34226 L
s
% Start of user PostScript
-2.1454292 -4.2836416 -1.198928 -4.7322489 MAarrowhead1
% End of user PostScript
.581 1 0 r
.6541 .41232 m
.66467 .44248 L
s
% Start of user PostScript
4.6228967 -2.6303644 4.9399935 -1.7255535 MAarrowhead1
% End of user PostScript
.266 1 0 r
.56638 .64571 m
.53448 .65966 L
s
% Start of user PostScript
1.9914527 4.3712522 1.0343897 4.7897226 MAarrowhead1
% End of user PostScript
0 1 .049 r
.34369 .58283 m
.33419 .5522 L
s
% Start of user PostScript
-4.6892267 2.4847694 -4.9744463 1.5660203 MAarrowhead1
% End of user PostScript
0 1 .364 r
.43882 .35153 m
.47104 .3386 L
s
% Start of user PostScript
-1.8352668 -4.4540133 -0.86870395 -4.8418826 MAarrowhead1
% End of user PostScript
0 1 .679 r
.65835 .42212 m
.66678 .45318 L
s
% Start of user PostScript
4.7503547 -2.3364179 5.0033806 -1.4047499 MAarrowhead1
% End of user PostScript
0 1 .995 r
.5559 .65106 m
.5234 .66296 L
s
% Start of user PostScript
1.6770449 4.5318333 0.70205446 4.8886712 MAarrowhead1
% End of user PostScript
0 .69 1 r
.33979 .57285 m
.33244 .5414 L
s
% Start of user PostScript
-4.8062126 2.1854744 -5.0267641 1.2419211 MAarrowhead1
% End of user PostScript
0 .375 1 r
.44943 .34651 m
.48218 .33567 L
s
% Start of user PostScript
-1.5169626 -4.6046257 -0.53462611 -4.9300363 MAarrowhead1
% End of user PostScript
0 .06 1 r
.66189 .43226 m
.66815 .46408 L
s
% Start of user PostScript
4.8567387 -2.0321064 5.0445711 -1.0777145 MAarrowhead1
% End of user PostScript
1 0 .05 r
.50436 .69155 m
.46611 .69342 L
.42919 .6877 L
.39504 .6746 L
.36502 .65466 L
.34029 .62865 L
.32183 .59758 L
.31036 .56269 L
.30634 .52534 L
.30991 .48699 L
.32095 .44915 L
.33901 .41331 L
.36339 .38087 L
.39313 .35311 L
.42707 .33111 L
.46387 .31574 L
.50209 .3076 L
.54022 .30701 L
.57678 .314 L
.61032 .32828 L
.63953 .34931 L
.66327 .37625 L
.6806 .40804 L
.69084 .44345 L
.6936 .48107 L
.68875 .51944 L
.6765 .55704 L
.65732 .59241 L
.63196 .62415 L
.60143 .65101 L
.56691 .67195 L
.52977 .68614 L
.49147 .69303 L
.45349 .69234 L
.41734 .6841 L
.38444 .66864 L
.35607 .64656 L
.33335 .61872 L
.31717 .58623 L
.30816 .55035 L
.30669 .5125 L
.3128 .47416 L
.32626 .43683 L
.34653 .40198 L
.37283 .37097 L
.40412 .34503 L
.43918 .32518 L
.47662 .31218 L
.51497 .30655 L
.55274 .30852 L
Mistroke
.58844 .318 L
.62067 .33463 L
.64817 .35774 L
.66984 .38644 L
.68486 .41959 L
.69261 .4559 L
.69281 .49394 L
.68544 .53222 L
.6708 .56923 L
.64945 .60353 L
.62223 .63376 L
.59022 .65875 L
.55467 .6775 L
.51697 .68929 L
.4786 .69365 L
.44108 .69041 L
.40587 .67969 L
.37435 .66193 L
.34776 .6378 L
.32715 .60827 L
.31332 .5745 L
.30682 .53779 L
.3079 .49961 L
.31652 .46144 L
.33234 .42478 L
.35474 .39108 L
.38284 .36165 L
.41554 .33765 L
.45155 .32002 L
.48947 .30945 L
.52779 .30637 L
.56503 .31088 L
.59972 .32281 L
.63049 .3417 L
.65614 .3668 L
.67566 .39713 L
.68829 .4315 L
.69353 .46855 L
.69117 .50684 L
.68132 .54486 L
.66434 .58112 L
.64092 .6142 L
.61196 .64279 L
.57861 .66578 L
.54218 .68226 L
.50409 .6916 L
.46584 .69341 L
.42893 .68763 L
.39481 .67448 L
.36482 .65449 L
Mistroke
.34013 .62844 L
.32172 .59735 L
.3103 .56243 L
.30633 .52506 L
.30996 .48672 L
.32105 .44889 L
.33916 .41307 L
.36359 .38066 L
.39336 .35293 L
.42733 .33098 L
.46414 .31566 L
.50236 .30757 L
.54049 .30704 L
.57703 .31408 L
.61055 .32841 L
.63973 .34948 L
.66342 .37646 L
.6807 .40828 L
.69089 .44371 L
.69359 .48134 L
.68869 .51971 L
.67638 .5573 L
.65715 .59265 L
.63176 .62436 L
.60119 .65118 L
.56666 .67208 L
.5295 .68622 L
.49119 .69305 L
.45322 .69231 L
.41709 .68402 L
.38422 .6685 L
.35589 .64638 L
.33321 .61851 L
.31708 .58598 L
.30813 .55009 L
.30671 .51223 L
.31287 .47388 L
.32638 .43657 L
.3467 .40174 L
.37304 .37077 L
.40436 .34487 L
.43944 .32506 L
.47689 .31211 L
.51525 .30654 L
.55301 .30856 L
.58869 .3181 L
.62089 .33477 L
.64834 .35793 L
.66998 .38666 L
.68494 .41984 L
Mistroke
.69264 .45617 L
.69279 .49422 L
.68536 .53249 L
.67067 .56949 L
.64927 .60376 L
.62202 .63396 L
.58998 .65891 L
.5544 .67761 L
.51669 .68935 L
.47833 .69365 L
.44082 .69036 L
.40563 .67959 L
.37414 .66177 L
.34759 .63761 L
.32703 .60805 L
.31325 .57424 L
.3068 .53752 L
.30794 .49933 L
.31661 .46117 L
.33248 .42453 L
.35492 .39085 L
.38306 .36145 L
.41578 .3375 L
.45182 .31992 L
.48974 .3094 L
.52807 .30637 L
.56529 .31094 L
.59995 .32292 L
.63069 .34186 L
.6563 .367 L
.67578 .39737 L
.68836 .43176 L
.69354 .46883 L
.69113 .50712 L
.68122 .54513 L
.66419 .58137 L
.64073 .61442 L
.61174 .64298 L
.57836 .66592 L
.54191 .68236 L
.50381 .69164 L
.46557 .69339 L
.42867 .68756 L
.39458 .67436 L
.36462 .65433 L
.33998 .62823 L
.32161 .59711 L
.31025 .56217 L
.30633 .52479 L
.31002 .48644 L
Mistroke
.32116 .44862 L
Mfstroke
1 0 0 r
.50436 .69155 m
.46611 .69342 L
s
% Start of user PostScript
0.13091841 5.7466499 -1.0167045 5.8026209 MAarrowhead1
% End of user PostScript
1 .158 0 r
.42919 .6877 m
.39504 .6746 L
s
% Start of user PostScript
-2.1244258 5.6308625 -3.1487719 5.2381154 MAarrowhead1
% End of user PostScript
1 .473 0 r
.32095 .44915 m
.33901 .41331 L
s
% Start of user PostScript
-5.371594 -1.525374 -4.8297003 -2.6006086 MAarrowhead1
% End of user PostScript
1 .788 0 r
.57678 .314 m
.61032 .32828 L
s
% Start of user PostScript
2.3033395 -5.5800563 3.3096366 -5.1514959 MAarrowhead1
% End of user PostScript
.897 1 0 r
.6765 .55704 m
.65732 .59241 L
s
% Start of user PostScript
5.2948757 1.711231 4.7194649 2.7721915 MAarrowhead1
% End of user PostScript
.581 1 0 r
.41734 .6841 m
.38444 .66864 L
s
% Start of user PostScript
-2.4796979 5.5230597 -3.4668296 5.0591615 MAarrowhead1
% End of user PostScript
.266 1 0 r
.32626 .43683 m
.34653 .40198 L
s
% Start of user PostScript
-5.2122835 -1.8951897 -4.6039939 -2.9406989 MAarrowhead1
% End of user PostScript
0 1 .049 r
.58844 .318 m
.62067 .33463 L
s
% Start of user PostScript
2.6533054 -5.4599358 3.6201766 -4.9612145 MAarrowhead1
% End of user PostScript
0 1 .364 r
.6708 .56923 m
.64945 .60353 L
s
% Start of user PostScript
5.1239089 2.0770458 4.4834153 3.1059439 MAarrowhead1
% End of user PostScript
0 1 .679 r
.40587 .67969 m
.37435 .66193 L
s
% Start of user PostScript
-2.8239694 5.3907549 -3.7695074 4.8577637 MAarrowhead1
% End of user PostScript
0 1 .995 r
.33234 .42478 m
.35474 .39108 L
s
% Start of user PostScript
-5.0298498 -2.2565978 -4.3578629 -3.2677433 MAarrowhead1
% End of user PostScript
0 .69 1 r
.59972 .32281 m
.63049 .3417 L
s
% Start of user PostScript
2.9915005 -5.3155935 3.9146564 -4.7489237 MAarrowhead1
% End of user PostScript
0 .375 1 r
.66434 .58112 m
.64092 .6142 L
s
% Start of user PostScript
4.9302108 2.4336463 4.227476 3.4259175 MAarrowhead1
% End of user PostScript
0 .06 1 r
.39481 .67448 m
.36482 .65449 L
s
% Start of user PostScript
-3.1557129 5.2345352 -4.0554625 4.6348154 MAarrowhead1
% End of user PostScript
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0333333 0.5 0.0333333 [
[0 .4875 -18.4688 -20 ]
[0 .4875 18.4688 0 ]
[.16667 .4875 -18.4688 -20 ]
[.16667 .4875 18.4688 0 ]
[.33333 .4875 -13.4688 -20 ]
[.33333 .4875 13.4688 0 ]
[.66667 .4875 -7 -20 ]
[.66667 .4875 7 0 ]
[.83333 .4875 -12 -20 ]
[.83333 .4875 12 0 ]
[1 .4875 -12 -20 ]
[1 .4875 12 0 ]
[.4875 0 -36.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .16667 -36.9375 -10 ]
[.4875 .16667 0 10 ]
[.4875 .33333 -26.9375 -10 ]
[.4875 .33333 0 10 ]
[.4875 .66667 -14 -10 ]
[.4875 .66667 0 10 ]
[.4875 .83333 -24 -10 ]
[.4875 .83333 0 10 ]
[.4875 1 -24 -10 ]
[.4875 1 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.16667 .5 m
.16667 .50625 L
s
gsave
.16667 .4875 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.33333 .5 m
.33333 .50625 L
s
gsave
.33333 .4875 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.66667 .5 m
.66667 .50625 L
s
gsave
.66667 .4875 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.83333 .5 m
.83333 .50625 L
s
gsave
.83333 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.5 .16667 m
.50625 .16667 L
s
gsave
.4875 .16667 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 .33333 m
.50625 .33333 L
s
gsave
.4875 .33333 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .66667 m
.50625 .66667 L
s
gsave
.4875 .66667 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .83333 m
.50625 .83333 L
s
gsave
.4875 .83333 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.01 w
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.141 1 0 r
.5 Mabswid
.54938 .32879 m
.5812 .33771 L
.60984 .35299 L
.63416 .37405 L
.65322 .40005 L
.66627 .42997 L
.67279 .46264 L
.67253 .49678 L
.6655 .53104 L
.65197 .56409 L
.63248 .59462 L
.60779 .62144 L
.57887 .64349 L
.54686 .65991 L
.513 .67005 L
.47864 .67352 L
.44511 .67018 L
.41374 .66016 L
.38575 .64386 L
.36225 .6219 L
.34415 .59517 L
.33217 .5647 L
.32678 .53169 L
.32818 .49744 L
.33633 .46329 L
.3509 .43058 L
.37132 .40059 L
.3968 .3745 L
.42632 .35334 L
.45873 .33794 L
.49277 .3289 L
.52709 .32657 L
.56034 .33104 L
.59123 .34215 L
.61854 .35946 L
.64119 .38228 L
.6583 .40971 L
.6692 .4407 L
.67346 .47401 L
.67092 .50834 L
.66166 .54234 L
.64606 .57468 L
.62473 .60409 L
.5985 .62942 L
.56841 .64966 L
.53563 .66404 L
.50145 .67197 L
.46722 .67316 L
.43427 .66755 L
.40391 .65536 L
Mistroke
.37731 .63708 L
.35553 .61341 L
.33942 .5853 L
.32961 .55384 L
.32649 .52026 L
.33017 .4859 L
.34053 .45208 L
.35714 .42014 L
.37936 .39134 L
.40631 .36681 L
.43694 .3475 L
.47004 .33417 L
.50432 .32735 L
.53844 .32731 L
.57104 .33405 L
.60085 .3473 L
.62671 .36654 L
.64759 .39102 L
.66268 .41978 L
.67139 .45168 L
.67337 .48549 L
.66854 .51986 L
.65711 .55345 L
.6395 .58494 L
.61642 .6131 L
.58877 .63682 L
.55764 .65518 L
.52425 .66744 L
.4899 .67313 L
.45595 .67202 L
.42373 .66417 L
.3945 .64987 L
.36941 .62969 L
.34945 .60442 L
.3354 .57505 L
.3278 .54274 L
.32697 .50875 L
.33292 .47441 L
.34543 .44108 L
.36401 .41007 L
.38793 .38258 L
.41624 .3597 L
.44784 .34232 L
.48149 .33114 L
.51586 .32658 L
.54961 .32883 L
.58142 .33779 L
.61003 .35312 L
.63432 .37422 L
.65334 .40025 L
Mistroke
.66634 .4302 L
.67281 .46289 L
.6725 .49703 L
.66543 .53129 L
.65185 .56432 L
.63232 .59483 L
.6076 .62161 L
.57865 .64362 L
.54662 .66 L
.51276 .6701 L
.47839 .67352 L
.44488 .67013 L
.41352 .66006 L
.38556 .64372 L
.3621 .62173 L
.34404 .59496 L
.33211 .56447 L
.32676 .53145 L
.32822 .49719 L
.33641 .46305 L
.35103 .43035 L
.37149 .40039 L
.39699 .37433 L
.42654 .35321 L
.45897 .33785 L
.49301 .32885 L
.52733 .32657 L
.56057 .3311 L
.59144 .34226 L
.61872 .3596 L
.64133 .38246 L
.6584 .40993 L
.66926 .44093 L
.67347 .47425 L
.67087 .50858 L
.66157 .54258 L
.64593 .5749 L
.62456 .60429 L
.5983 .62958 L
.56818 .64979 L
.53539 .66412 L
.50121 .672 L
.46698 .67314 L
.43405 .66748 L
.4037 .65525 L
.37714 .63693 L
.35539 .61323 L
.33932 .58509 L
.32956 .5536 L
.32649 .52002 L
Mistroke
.33023 .48565 L
.34063 .45184 L
.35728 .41992 L
.37953 .39115 L
.40652 .36665 L
.43717 .34738 L
.47029 .3341 L
.50457 .32733 L
.53868 .32734 L
.57126 .33412 L
.60105 .34742 L
.62688 .3667 L
.64772 .39121 L
.66277 .42 L
.67143 .45192 L
.67336 .48573 L
.66849 .5201 L
.657 .55368 L
.63935 .58516 L
.61624 .61329 L
.58856 .63698 L
.55741 .65529 L
.524 .6675 L
.48965 .67314 L
.45571 .67199 L
.42351 .66409 L
.39431 .64975 L
.36925 .62953 L
.34933 .60422 L
.33532 .57483 L
.32777 .5425 L
.32699 .5085 L
.33299 .47417 L
.34555 .44085 L
.36417 .40985 L
.38812 .3824 L
.41646 .35955 L
.44808 .34222 L
.48173 .33108 L
.51611 .32657 L
.54985 .32887 L
.58164 .33788 L
.61022 .35326 L
.63447 .37439 L
.65345 .40045 L
.66641 .43043 L
.67284 .46313 L
.67248 .49727 L
.66535 .53153 L
.65173 .56455 L
Mistroke
.63216 .59503 L
Mfstroke
0 .535 1 r
.33117 .29476 m
.37946 .26014 L
.43247 .23494 L
.48814 .22014 L
.54427 .21633 L
.59867 .22365 L
.64919 .24181 L
.69386 .27011 L
.73091 .30743 L
.75891 .3523 L
.77675 .40297 L
.78372 .45746 L
.77956 .51361 L
.76443 .56922 L
.73892 .62212 L
.70403 .67023 L
.66114 .71166 L
.61192 .74478 L
.55831 .76829 L
.50241 .78127 L
.44642 .78322 L
.39253 .77405 L
.34285 .75412 L
.29935 .72422 L
.26372 .68552 L
.23736 .63955 L
.22131 .58809 L
.2162 .53318 L
.22223 .47696 L
.23915 .42165 L
.26632 .36941 L
.30265 .3223 L
.34673 .28216 L
.39683 .25058 L
.45097 .22878 L
.50704 .21762 L
.56284 .21755 L
.61616 .22856 L
.66493 .25023 L
.70722 .2817 L
.74139 .32173 L
.76608 .36876 L
.78032 .42094 L
.78357 .47623 L
.77568 .53245 L
.75698 .58739 L
.72819 .63891 L
.69044 .68497 L
.64523 .72377 L
.59431 .75379 L
Mistroke
.53969 .77386 L
.48351 .78317 L
.42798 .78137 L
.37528 .76853 L
.32747 .74515 L
.28643 .71214 L
.25378 .67082 L
.23078 .62278 L
.21836 .56993 L
.21698 .51434 L
.22672 .45818 L
.24718 .40366 L
.27756 .35293 L
.31667 .30796 L
.36297 .27054 L
.41466 .24212 L
.46969 .22381 L
.52591 .21635 L
.58112 .22002 L
.63314 .23468 L
.67994 .25975 L
.71967 .29425 L
.75079 .33683 L
.77206 .38581 L
.78265 .43927 L
.78215 .49511 L
.77058 .55114 L
.74839 .60517 L
.71645 .65507 L
.67601 .69889 L
.62867 .7349 L
.57628 .76169 L
.52089 .77821 L
.46469 .78381 L
.40987 .77827 L
.35858 .76182 L
.31285 .73508 L
.27446 .69912 L
.24493 .65535 L
.2254 .60548 L
.21665 .55147 L
.21902 .49544 L
.23242 .43959 L
.25632 .38611 L
.28978 .3371 L
.3315 .29448 L
.37982 .25993 L
.43287 .2348 L
.48854 .22008 L
.54467 .21634 L
Mistroke
.59905 .22374 L
.64953 .24198 L
.69415 .27034 L
.73115 .30772 L
.75908 .35265 L
.77684 .40335 L
.78373 .45786 L
.77949 .51401 L
.76428 .56961 L
.7387 .62249 L
.70375 .67055 L
.6608 .71192 L
.61155 .74498 L
.55791 .76842 L
.50201 .78133 L
.44602 .78319 L
.39215 .77394 L
.34252 .75394 L
.29906 .72398 L
.26349 .68522 L
.23721 .63919 L
.22124 .58771 L
.2162 .53277 L
.22231 .47656 L
.23931 .42126 L
.26655 .36905 L
.30294 .32199 L
.34707 .28191 L
.39721 .25038 L
.45137 .22866 L
.50745 .21758 L
.56323 .21759 L
.61653 .22868 L
.66526 .25042 L
.7075 .28195 L
.7416 .32204 L
.76622 .36912 L
.78038 .42133 L
.78355 .47663 L
.77559 .53285 L
.75681 .58778 L
.72795 .63926 L
.69015 .68528 L
.64488 .72402 L
.59393 .75398 L
.53929 .77396 L
.48311 .7832 L
.42759 .78132 L
.37492 .7684 L
.32715 .74494 L
Mistroke
.28617 .71188 L
.25358 .67049 L
.23066 .62242 L
.21831 .56954 L
.21701 .51394 L
.22683 .45778 L
.24736 .40328 L
.27781 .35258 L
.31698 .30767 L
.36333 .2703 L
.41504 .24195 L
.47009 .22372 L
.52632 .21634 L
.58151 .22009 L
.6335 .23483 L
.68025 .25997 L
.71993 .29453 L
.75098 .33716 L
.77217 .38617 L
.78269 .43966 L
.78211 .49551 L
.77046 .55154 L
.74819 .60555 L
.71619 .65541 L
.6757 .69918 L
.62831 .73512 L
.57589 .76184 L
.52049 .77829 L
.46429 .78381 L
.40948 .77819 L
.35823 .76166 L
.31255 .73486 L
.27422 .69884 L
.24475 .65501 L
.2253 .6051 L
.21663 .55107 L
.21908 .49503 L
.23256 .43919 L
.25653 .38574 L
.29006 .33677 L
.33182 .2942 L
.38019 .25971 L
.43326 .23466 L
.48895 .22001 L
.54507 .21636 L
.59942 .22383 L
.64988 .24215 L
.69444 .27058 L
.73138 .30802 L
.75924 .35299 L
Mistroke
.77692 .40373 L
Mfstroke
.544 1 0 r
.52845 .3014 m
.56665 .30602 L
.60223 .31825 L
.63379 .33762 L
.66011 .36335 L
.68014 .39445 L
.69311 .42969 L
.69849 .4677 L
.69608 .50697 L
.68598 .54596 L
.66858 .58315 L
.64456 .61708 L
.61487 .64642 L
.58067 .67 L
.54331 .68692 L
.50425 .6965 L
.46501 .69837 L
.42716 .69245 L
.39216 .67898 L
.36139 .65849 L
.33606 .63177 L
.31717 .59989 L
.30545 .56408 L
.30137 .52576 L
.30508 .48643 L
.31645 .44763 L
.33501 .41089 L
.36005 .37764 L
.39059 .3492 L
.42541 .32667 L
.46317 .31095 L
.50237 .30264 L
.54148 .30209 L
.57896 .30929 L
.61334 .32399 L
.64327 .34559 L
.66758 .37325 L
.68531 .40589 L
.69577 .44222 L
.69855 .48081 L
.69354 .52016 L
.68092 .55872 L
.66121 .59498 L
.63517 .6275 L
.60383 .65503 L
.56841 .67647 L
.53031 .69098 L
.49102 .698 L
.45208 .69724 L
.41502 .68875 L
Mistroke
.38129 .67285 L
.35223 .65016 L
.32896 .62158 L
.31241 .58823 L
.30322 .55142 L
.30175 .51259 L
.30806 .47327 L
.32191 .43499 L
.34274 .39927 L
.36975 .36749 L
.40187 .34092 L
.43784 .3206 L
.47625 .30731 L
.51559 .30158 L
.55432 .30365 L
.59092 .31342 L
.62395 .33051 L
.65211 .35425 L
.67431 .38371 L
.68966 .41774 L
.69758 .455 L
.69773 .49402 L
.69013 .53327 L
.67507 .57122 L
.65313 .60638 L
.62519 .63736 L
.59233 .66295 L
.55585 .68214 L
.51717 .69419 L
.47783 .69861 L
.43935 .69524 L
.40325 .68421 L
.37095 .66595 L
.34372 .64117 L
.32262 .61086 L
.30848 .57619 L
.30185 .53854 L
.30301 .49937 L
.31189 .46022 L
.32816 .42264 L
.35117 .38809 L
.38002 .35794 L
.41358 .33336 L
.45053 .31532 L
.48943 .30453 L
.52873 .30141 L
.56692 .30608 L
.60247 .31837 L
.634 .33778 L
.66028 .36356 L
Mistroke
.68026 .39469 L
.69317 .42996 L
.6985 .46797 L
.69604 .50725 L
.68588 .54624 L
.66843 .58341 L
.64437 .61731 L
.61464 .64661 L
.58042 .67015 L
.54303 .68701 L
.50396 .69654 L
.46474 .69835 L
.42689 .69238 L
.39192 .67886 L
.36119 .65831 L
.3359 .63156 L
.31706 .59964 L
.3054 .56381 L
.30137 .52548 L
.30514 .48615 L
.31655 .44736 L
.33517 .41063 L
.36025 .37742 L
.39082 .34901 L
.42568 .32653 L
.46345 .31086 L
.50265 .30261 L
.54175 .30211 L
.57922 .30937 L
.61357 .32412 L
.64347 .34577 L
.66773 .37347 L
.68542 .40614 L
.69582 .44249 L
.69854 .4811 L
.69347 .52045 L
.68081 .55899 L
.66105 .59523 L
.63497 .62772 L
.60359 .6552 L
.56815 .67659 L
.53003 .69106 L
.49073 .69802 L
.4518 .69721 L
.41476 .68866 L
.38107 .67271 L
.35204 .64998 L
.32882 .62136 L
.31231 .58798 L
.30318 .55115 L
Mistroke
.30177 .51231 L
.30813 .47299 L
.32203 .43472 L
.34291 .39902 L
.36996 .36728 L
.40211 .34075 L
.4381 .32048 L
.47653 .30724 L
.51587 .30157 L
.55459 .30369 L
.59117 .31351 L
.62417 .33065 L
.65229 .35444 L
.67444 .38394 L
.68975 .418 L
.6976 .45527 L
.69771 .4943 L
.69005 .53355 L
.67493 .57149 L
.65295 .60662 L
.62497 .63756 L
.59208 .66311 L
.55558 .68226 L
.51689 .69425 L
.47755 .69862 L
.43908 .69519 L
.40301 .68411 L
.37074 .66579 L
.34354 .64098 L
.32249 .61062 L
.3084 .57593 L
.30183 .53826 L
.30304 .49908 L
.31198 .45995 L
.3283 .42238 L
.35135 .38786 L
.38024 .35774 L
.41383 .3332 L
.45081 .31521 L
.48971 .30448 L
.52901 .30141 L
.56718 .30614 L
.60271 .31848 L
.63421 .33794 L
.66044 .36376 L
.68038 .39493 L
.69324 .43022 L
.69851 .46825 L
.69599 .50753 L
.68578 .54651 L
Mistroke
.66828 .58367 L
Mfstroke
1 0 .015 r
.27822 .36243 m
.31541 .31765 L
.35985 .28002 L
.40979 .25103 L
.46327 .2318 L
.51819 .22311 L
.5724 .22528 L
.62376 .23823 L
.67027 .26146 L
.7101 .29404 L
.74168 .33471 L
.76377 .38187 L
.77552 .43366 L
.77645 .48806 L
.76653 .54293 L
.74615 .59611 L
.71611 .64552 L
.67759 .68921 L
.6321 .72549 L
.58143 .75291 L
.52755 .7704 L
.4726 .77729 L
.41873 .77329 L
.36804 .75857 L
.32253 .7337 L
.28399 .69965 L
.25392 .65778 L
.23351 .6097 L
.22357 .55733 L
.22446 .5027 L
.23618 .44797 L
.25825 .39528 L
.2898 .3467 L
.3296 .30414 L
.3761 .26926 L
.42745 .24344 L
.48165 .22769 L
.53657 .22262 L
.59006 .22844 L
.64001 .24492 L
.68447 .27141 L
.72169 .30687 L
.7502 .34991 L
.7689 .39884 L
.77705 .45174 L
.77432 .50654 L
.76082 .56107 L
.73709 .61322 L
.70406 .66091 L
.66301 .7023 L
Mistroke
.61557 .73574 L
.56359 .75993 L
.50912 .77392 L
.45429 .77716 L
.40125 .76952 L
.35209 .75131 L
.30873 .72323 L
.27288 .68639 L
.24595 .64224 L
.22898 .5925 L
.22265 .53913 L
.22721 .48423 L
.24247 .42995 L
.26783 .37841 L
.30231 .33165 L
.34455 .2915 L
.39289 .25952 L
.44543 .23699 L
.50012 .22477 L
.5548 .22336 L
.60733 .23281 L
.65564 .25274 L
.69785 .28238 L
.73229 .32055 L
.75762 .36577 L
.77284 .41626 L
.77735 .47003 L
.77097 .52498 L
.75396 .57895 L
.72698 .62982 L
.6911 .6756 L
.64771 .71448 L
.59853 .74495 L
.54548 .7658 L
.49064 .77622 L
.43618 .7758 L
.38422 .76456 L
.3368 .74294 L
.29578 .71178 L
.26279 .6723 L
.2391 .62607 L
.22565 .57489 L
.22297 .52077 L
.23116 .46583 L
.2499 .41224 L
.27845 .36209 L
.31571 .31735 L
.36019 .27978 L
.41016 .25085 L
.46366 .2317 L
Mistroke
.51858 .22308 L
.57278 .22533 L
.62411 .23836 L
.67058 .26166 L
.71035 .29431 L
.74187 .33503 L
.76389 .38223 L
.77556 .43405 L
.77641 .48846 L
.76642 .54332 L
.74597 .59648 L
.71586 .64585 L
.67729 .6895 L
.63175 .72572 L
.58105 .75307 L
.52716 .77049 L
.47221 .7773 L
.41835 .77322 L
.36769 .75842 L
.32223 .73348 L
.28374 .69938 L
.25374 .65745 L
.23341 .60934 L
.22353 .55694 L
.22451 .50231 L
.2363 .44758 L
.25844 .39492 L
.29006 .34637 L
.32992 .30386 L
.37645 .26904 L
.42783 .24329 L
.48205 .22761 L
.53697 .22262 L
.59043 .22852 L
.64035 .24508 L
.68476 .27163 L
.72192 .30715 L
.75037 .35024 L
.769 .39921 L
.77706 .45213 L
.77426 .50693 L
.76069 .56146 L
.73689 .61358 L
.70379 .66123 L
.66269 .70257 L
.61521 .73595 L
.56321 .76007 L
.50873 .77398 L
.4539 .77715 L
.40088 .76943 L
Mistroke
.35176 .75114 L
.30845 .723 L
.27266 .6861 L
.24579 .6419 L
.2289 .59213 L
.22264 .53874 L
.22728 .48384 L
.24261 .42957 L
.26805 .37806 L
.30259 .33134 L
.34488 .29124 L
.39326 .25933 L
.44582 .23686 L
.50051 .22473 L
.55518 .22339 L
.60769 .23292 L
.65597 .25292 L
.69813 .28262 L
.73251 .32085 L
.75777 .36612 L
.77291 .41663 L
.77734 .47042 L
.77088 .52537 L
.7538 .57933 L
.72675 .63017 L
.69081 .6759 L
.64738 .71473 L
.59816 .74513 L
.54509 .76591 L
.49025 .77626 L
.43579 .77576 L
.38386 .76444 L
.33648 .74274 L
.29552 .71152 L
.26258 .67199 L
.23896 .62572 L
.22559 .57451 L
.22299 .52037 L
.23125 .46544 L
.25007 .41186 L
.27869 .36174 L
.316 .31705 L
.36053 .27954 L
.41054 .25068 L
.46405 .2316 L
.51898 .22306 L
.57316 .22539 L
.62447 .23849 L
.67089 .26186 L
.71061 .29457 L
Mistroke
.74206 .33535 L
Mfstroke
.428 0 1 r
.38022 .76714 m
.33246 .74473 L
.29129 .71272 L
.2583 .67236 L
.2348 .62524 L
.22171 .5732 L
.21954 .51828 L
.22837 .46265 L
.24787 .40849 L
.27726 .35792 L
.31539 .31292 L
.36077 .27526 L
.41161 .24643 L
.46593 .22755 L
.52157 .21936 L
.57638 .22218 L
.62818 .23591 L
.67495 .26 L
.71486 .29351 L
.74634 .33512 L
.76815 .38321 L
.77943 .43588 L
.77975 .49106 L
.76908 .5466 L
.74786 .60031 L
.71691 .65008 L
.67745 .69396 L
.63102 .73023 L
.57945 .75746 L
.52477 .77459 L
.46911 .78094 L
.41466 .77627 L
.36356 .76075 L
.31782 .735 L
.27923 .70003 L
.2493 .65721 L
.22921 .60822 L
.21975 .55498 L
.22128 .49958 L
.23376 .4442 L
.25668 .39101 L
.28915 .3421 L
.3299 .29938 L
.37733 .26454 L
.42956 .23894 L
.48457 .22358 L
.54018 .21907 L
.59421 .22559 L
.64454 .24288 L
.6892 .27026 L
Mistroke
.72644 .30665 L
.75479 .35063 L
.77314 .40048 L
.78077 .45423 L
.77738 .50978 L
.7631 .56494 L
.7385 .61756 L
.70454 .66556 L
.66256 .70706 L
.61419 .74044 L
.56134 .76438 L
.50608 .77794 L
.45059 .7806 L
.39703 .77225 L
.34752 .75321 L
.30399 .72423 L
.26815 .68645 L
.24141 .64136 L
.22482 .59072 L
.21903 .53651 L
.22427 .48088 L
.24033 .42599 L
.26657 .37401 L
.30199 .32698 L
.34517 .28673 L
.39443 .25485 L
.44783 .2326 L
.50328 .22084 L
.5586 .22003 L
.61162 .23022 L
.66026 .25099 L
.70261 .28153 L
.73701 .32065 L
.76211 .36681 L
.77692 .41819 L
.78086 .47279 L
.77378 .52845 L
.75596 .58299 L
.72809 .63428 L
.69127 .6803 L
.64694 .71924 L
.59684 .74958 L
.54295 .77013 L
.48737 .78007 L
.43228 .77902 L
.37986 .76702 L
.33214 .74454 L
.29102 .71246 L
.2581 .67205 L
.23467 .62488 L
Mistroke
.22165 .57281 L
.21956 .51789 L
.22847 .46226 L
.24804 .40811 L
.2775 .35757 L
.31569 .31262 L
.36112 .27503 L
.41199 .24626 L
.46632 .22745 L
.52197 .21934 L
.57676 .22224 L
.62854 .23604 L
.67527 .26021 L
.71512 .29378 L
.74653 .33545 L
.76826 .38357 L
.77947 .43627 L
.77971 .49146 L
.76897 .54699 L
.74767 .60068 L
.71666 .65041 L
.67714 .69425 L
.63067 .73046 L
.57907 .75762 L
.52437 .77467 L
.46871 .78095 L
.41428 .7762 L
.36321 .7606 L
.31752 .73478 L
.27898 .69975 L
.24912 .65688 L
.2291 .60785 L
.21972 .55459 L
.22133 .49918 L
.23389 .44381 L
.25688 .39064 L
.28942 .34177 L
.33022 .2991 L
.37769 .26432 L
.42995 .23879 L
.48497 .22351 L
.54057 .21908 L
.59458 .22568 L
.64488 .24304 L
.6895 .27049 L
.72667 .30694 L
.75496 .35097 L
.77323 .40085 L
.78078 .45462 L
.77732 .51018 L
Mistroke
.76296 .56533 L
.73829 .61792 L
.70427 .66588 L
.66223 .70733 L
.61382 .74064 L
.56095 .76451 L
.50568 .778 L
.45019 .78058 L
.39666 .77215 L
.34718 .75303 L
.3037 .72399 L
.26792 .68615 L
.24125 .64101 L
.22474 .59034 L
.21903 .53612 L
.22434 .48048 L
.24048 .42561 L
.2668 .37365 L
.30227 .32666 L
.3455 .28647 L
.3948 .25466 L
.44822 .23248 L
.50368 .22079 L
.55899 .22007 L
.61199 .23033 L
.66059 .25117 L
.70289 .28178 L
.73722 .32096 L
.76225 .36716 L
.77699 .41857 L
.78085 .47318 L
.77369 .52885 L
.75579 .58338 L
.72785 .63463 L
.69097 .68061 L
.6466 .71949 L
.59647 .74977 L
.54255 .77024 L
.48697 .7801 L
.4319 .77897 L
.37949 .76689 L
.33182 .74434 L
.29075 .7122 L
.25789 .67173 L
.23454 .62452 L
.2216 .57243 L
.21958 .51749 L
.22858 .46186 L
.24822 .40773 L
.27775 .35723 L
Mistroke
.316 .31232 L
Mfstroke
.101 1 0 r
.24115 .56806 m
.23913 .51698 L
.24736 .46524 L
.2655 .41486 L
.29284 .36782 L
.32831 .32597 L
.37052 .29095 L
.41782 .26413 L
.46833 .24658 L
.5201 .23896 L
.57107 .24159 L
.61925 .25437 L
.66275 .27678 L
.69987 .30796 L
.72914 .34667 L
.74942 .39139 L
.75991 .44039 L
.7602 .49172 L
.75028 .54337 L
.73053 .59332 L
.70174 .63962 L
.66503 .68043 L
.62184 .71416 L
.57388 .73948 L
.52301 .75541 L
.47124 .76131 L
.4206 .75696 L
.37307 .74252 L
.33053 .71857 L
.29463 .68604 L
.2668 .6462 L
.24812 .60063 L
.23933 .55111 L
.24076 .49958 L
.25237 .44807 L
.2737 .3986 L
.30391 .3531 L
.34181 .31338 L
.38592 .28097 L
.43451 .25717 L
.48567 .24289 L
.5374 .2387 L
.58765 .24477 L
.63447 .26085 L
.676 .28632 L
.71063 .32018 L
.737 .36109 L
.75406 .40746 L
.76115 .45746 L
.75799 .50912 L
Mistroke
.74471 .56043 L
.72182 .60937 L
.69023 .65401 L
.65117 .69261 L
.60618 .72365 L
.55702 .74592 L
.50563 .75853 L
.45401 .761 L
.4042 .75322 L
.35814 .7355 L
.31766 .70855 L
.28433 .6734 L
.25947 .63146 L
.24404 .58435 L
.23866 .53393 L
.24354 .48218 L
.25848 .43113 L
.2829 .38279 L
.31584 .33904 L
.35601 .30161 L
.40183 .27197 L
.4515 .25127 L
.50308 .24034 L
.55453 .2396 L
.60385 .24908 L
.64909 .2684 L
.68847 .29682 L
.72047 .3332 L
.7438 .37614 L
.75758 .42393 L
.76124 .47472 L
.75465 .52649 L
.73806 .57722 L
.71213 .62493 L
.67788 .66773 L
.63665 .70394 L
.59005 .73216 L
.53992 .75126 L
.48822 .7605 L
.43699 .75952 L
.38822 .74835 L
.34385 .72744 L
.3056 .6976 L
.27498 .66 L
.2532 .61613 L
.2411 .5677 L
.23916 .51661 L
.24745 .46487 L
.26566 .41451 L
.29307 .3675 L
Mistroke
.32859 .32569 L
.37085 .29073 L
.41817 .26397 L
.4687 .24649 L
.52047 .23895 L
.57143 .24165 L
.61958 .2545 L
.66304 .27698 L
.70011 .30821 L
.72932 .34697 L
.74953 .39173 L
.75995 .44075 L
.76016 .49209 L
.75017 .54374 L
.73036 .59367 L
.7015 .63993 L
.66474 .6807 L
.62151 .71437 L
.57352 .73963 L
.52264 .75549 L
.47087 .76132 L
.42024 .75689 L
.37275 .74238 L
.33024 .71836 L
.2944 .68577 L
.26663 .64589 L
.24802 .60029 L
.2393 .55074 L
.24081 .49921 L
.25249 .44771 L
.27388 .39825 L
.30415 .3528 L
.34211 .31312 L
.38626 .28077 L
.43487 .25703 L
.48605 .24282 L
.53776 .23871 L
.588 .24485 L
.63479 .261 L
.67628 .28654 L
.71085 .32045 L
.73715 .36141 L
.75415 .40781 L
.76117 .45782 L
.75793 .50949 L
.74458 .56079 L
.72163 .60971 L
.68998 .65431 L
.65087 .69286 L
.60584 .72385 L
Mistroke
.55666 .74604 L
.50526 .75858 L
.45364 .76098 L
.40385 .75313 L
.35783 .73534 L
.31739 .70832 L
.28412 .67313 L
.25932 .63113 L
.24397 .584 L
.23866 .53356 L
.24361 .48181 L
.25862 .43078 L
.28311 .38246 L
.3161 .33875 L
.35632 .30137 L
.40217 .27179 L
.45187 .25116 L
.50345 .2403 L
.5549 .23963 L
.60419 .24918 L
.64939 .26857 L
.68873 .29705 L
.72067 .33349 L
.74394 .37647 L
.75764 .42429 L
.76123 .47509 L
.75456 .52686 L
.73791 .57758 L
.71192 .62525 L
.67761 .66801 L
.63633 .70418 L
.5897 .73233 L
.53955 .75136 L
.48785 .76053 L
.43663 .75948 L
.38789 .74824 L
.34355 .72725 L
.30535 .69735 L
.27479 .65971 L
.25307 .6158 L
.24104 .56734 L
.23918 .51624 L
.24755 .4645 L
.26583 .41415 L
.29329 .36718 L
.32887 .32542 L
.37117 .2905 L
.41852 .26381 L
.46907 .24639 L
.52084 .23893 L
Mistroke
.57178 .24171 L
Mfstroke
0 1 .096 r
.49316 .18767 m
.55552 .18468 L
.61571 .19407 L
.67135 .21546 L
.72026 .24803 L
.76054 .29048 L
.79058 .34115 L
.80923 .39806 L
.81573 .45897 L
.80985 .52149 L
.7918 .58316 L
.76231 .64157 L
.72252 .69443 L
.67399 .73965 L
.61864 .77547 L
.55863 .80048 L
.49632 .8137 L
.43416 .8146 L
.37457 .80316 L
.31992 .77982 L
.27232 .7455 L
.23367 .70154 L
.20547 .64967 L
.18882 .59193 L
.18439 .53058 L
.19235 .46804 L
.21237 .40674 L
.24369 .34911 L
.28507 .29739 L
.33488 .25363 L
.39117 .21954 L
.45173 .19646 L
.51419 .18528 L
.57609 .18646 L
.63501 .19995 L
.68862 .22521 L
.73483 .26125 L
.77183 .30667 L
.79816 .35967 L
.81279 .41818 L
.81514 .4799 L
.80512 .54241 L
.78313 .60325 L
.75003 .66005 L
.70711 .71056 L
.65607 .75281 L
.5989 .78513 L
.53785 .80627 L
.47531 .81539 L
.41375 .81213 L
Mistroke
.35556 .79661 L
.30305 .76946 L
.25827 .73174 L
.22297 .68491 L
.19855 .63084 L
.18595 .57162 L
.18569 .5096 L
.19775 .4472 L
.22168 .38687 L
.25653 .33098 L
.30094 .28172 L
.35316 .24103 L
.41114 .21051 L
.47261 .19134 L
.53516 .18429 L
.59632 .18963 L
.65371 .20715 L
.70506 .23617 L
.74836 .27553 L
.78192 .32371 L
.80441 .37881 L
.81496 .43866 L
.81314 .50092 L
.79904 .56314 L
.7732 .62289 L
.73664 .67781 L
.69079 .72575 L
.63745 .76484 L
.57872 .79353 L
.5169 .8107 L
.45441 .81568 L
.39372 .80826 L
.33719 .78875 L
.28706 .75791 L
.24528 .71695 L
.2135 .66747 L
.19297 .61142 L
.18448 .55099 L
.18837 .48857 L
.2045 .42659 L
.23222 .3675 L
.27046 .3136 L
.3177 .26702 L
.37209 .22958 L
.43151 .20276 L
.49361 .1876 L
.55597 .18471 L
.61612 .19418 L
.67172 .21566 L
.72059 .2483 L
Mistroke
.76079 .29081 L
.79076 .34154 L
.80932 .39848 L
.81573 .45941 L
.80976 .52193 L
.79163 .58359 L
.76206 .64197 L
.7222 .69478 L
.67362 .73995 L
.61822 .77569 L
.55819 .80062 L
.49587 .81375 L
.43372 .81456 L
.37416 .80303 L
.31955 .77961 L
.27201 .74521 L
.23343 .70119 L
.2053 .64928 L
.18875 .5915 L
.1844 .53014 L
.19245 .46759 L
.21256 .40631 L
.24395 .34871 L
.2854 .29705 L
.33526 .25335 L
.39159 .21933 L
.45218 .19633 L
.51464 .18525 L
.57653 .18652 L
.63541 .20009 L
.68898 .22543 L
.73513 .26154 L
.77206 .30702 L
.79831 .36007 L
.81285 .41861 L
.81511 .48035 L
.805 .54285 L
.78293 .60368 L
.74975 .66043 L
.70677 .71089 L
.65568 .75308 L
.59847 .78533 L
.5374 .80638 L
.47486 .81541 L
.41331 .81206 L
.35516 .79646 L
.3027 .76923 L
.25798 .73143 L
.22276 .68455 L
.19841 .63043 L
Mistroke
.18591 .57118 L
.18573 .50915 L
.19788 .44675 L
.22189 .38645 L
.25682 .3306 L
.30129 .2814 L
.35356 .24078 L
.41157 .21033 L
.47306 .19125 L
.5356 .18429 L
.59675 .18972 L
.6541 .20732 L
.7054 .23641 L
.74864 .27585 L
.78212 .32408 L
.80453 .37922 L
.81499 .4391 L
.81309 .50137 L
.79889 .56358 L
.77297 .6233 L
.73634 .67818 L
.69043 .72607 L
.63704 .76508 L
.57828 .79369 L
.51645 .81078 L
.45397 .81567 L
.3933 .80817 L
.33681 .78857 L
.28673 .75765 L
.24502 .71662 L
.21331 .66709 L
.19286 .611 L
.18446 .55055 L
.18845 .48812 L
.20466 .42615 L
.23246 .36709 L
.27077 .31324 L
.31806 .26672 L
.3725 .22935 L
.43195 .20261 L
.49406 .18754 L
.55641 .18473 L
.61654 .19429 L
.6721 .21586 L
.72091 .24857 L
.76104 .29115 L
.79093 .34193 L
.80941 .39891 L
.81574 .45986 L
.80967 .52238 L
Mistroke
.79146 .58403 L
Mfstroke
1 0 .819 r
.32873 .34965 m
.36622 .31484 L
.40896 .28729 L
.45527 .2681 L
.50333 .258 L
.55127 .2574 L
.59719 .26632 L
.6393 .28441 L
.67594 .31097 L
.70568 .34494 L
.72734 .385 L
.74009 .42957 L
.74341 .4769 L
.73717 .52514 L
.72163 .5724 L
.69739 .61681 L
.66541 .65664 L
.62693 .69032 L
.58347 .71654 L
.53674 .73425 L
.48856 .74277 L
.44083 .74176 L
.39543 .73127 L
.35413 .7117 L
.31855 .68382 L
.29009 .64872 L
.26988 .60779 L
.25869 .56263 L
.25698 .51501 L
.2648 .4668 L
.28185 .4199 L
.30746 .37614 L
.34064 .33724 L
.38006 .30472 L
.42419 .27987 L
.4713 .26366 L
.51953 .25673 L
.567 .25934 L
.61184 .2714 L
.65229 .29243 L
.68676 .3216 L
.7139 .35778 L
.73265 .39954 L
.74226 .44524 L
.74237 .49309 L
.73297 .54121 L
.71442 .58772 L
.68746 .63078 L
.65314 .66871 L
.61282 .70001 L
Mistroke
.56806 .72347 L
.52063 .73816 L
.47239 .7435 L
.42524 .73929 L
.38102 .72568 L
.34147 .70321 L
.30814 .67278 L
.28234 .63556 L
.26509 .59302 L
.25705 .54683 L
.25855 .4988 L
.26952 .45082 L
.28954 .40477 L
.31782 .36245 L
.35325 .32554 L
.39443 .29547 L
.43977 .27343 L
.48746 .26028 L
.53565 .25654 L
.58244 .26235 L
.62599 .27749 L
.6646 .30137 L
.69675 .33303 L
.72117 .37126 L
.73692 .41453 L
.74337 .46116 L
.74027 .50931 L
.72773 .5571 L
.70627 .60264 L
.6767 .64416 L
.6402 .68002 L
.5982 .70882 L
.55234 .72942 L
.50443 .74101 L
.45635 .74315 L
.40998 .73575 L
.36714 .71909 L
.32952 .69383 L
.29858 .66097 L
.27556 .62179 L
.26134 .57783 L
.25648 .53081 L
.26119 .48259 L
.27526 .43505 L
.29816 .39006 L
.32898 .34938 L
.36651 .31462 L
.40928 .28713 L
.45561 .26799 L
.50368 .25796 L
Mistroke
.55161 .25743 L
.59751 .26642 L
.63958 .28457 L
.67618 .31118 L
.70586 .34521 L
.72747 .3853 L
.74014 .4299 L
.74339 .47725 L
.73709 .52549 L
.72149 .57273 L
.69719 .61712 L
.66515 .65691 L
.62664 .69054 L
.58315 .71669 L
.5364 .73434 L
.48822 .7428 L
.4405 .74172 L
.39512 .73116 L
.35385 .71152 L
.31832 .68359 L
.28992 .64845 L
.26976 .60748 L
.25865 .5623 L
.257 .51467 L
.26489 .46646 L
.282 .41957 L
.30768 .37584 L
.3409 .33698 L
.38036 .30452 L
.42452 .27973 L
.47164 .26358 L
.51988 .25671 L
.56733 .2594 L
.61215 .27152 L
.65256 .29261 L
.68698 .32184 L
.71407 .35806 L
.73275 .39986 L
.7423 .44558 L
.74234 .49344 L
.73287 .54155 L
.71426 .58804 L
.68724 .63107 L
.65287 .66896 L
.61251 .70021 L
.56773 .72361 L
.52029 .73823 L
.47205 .7435 L
.42491 .73922 L
.38072 .72555 L
Mistroke
.34121 .70302 L
.30793 .67253 L
.28219 .63527 L
.26499 .5927 L
.25702 .54649 L
.25859 .49845 L
.26963 .45048 L
.28971 .40445 L
.31805 .36217 L
.35352 .3253 L
.39475 .29528 L
.4401 .2733 L
.48781 .26022 L
.53599 .25655 L
.58276 .26243 L
.62629 .27763 L
.66485 .30157 L
.69695 .33329 L
.72132 .37155 L
.737 .41485 L
.74338 .4615 L
.74021 .50966 L
.72761 .55743 L
.70608 .60296 L
.67646 .64444 L
.63992 .68026 L
.59788 .709 L
.552 .72953 L
.50409 .74106 L
.45601 .74313 L
.40966 .73566 L
.36685 .71894 L
.32927 .69362 L
.29839 .66071 L
.27542 .62149 L
.26127 .5775 L
.25648 .53047 L
.26126 .48225 L
.2754 .43472 L
.29835 .38975 L
.32922 .34911 L
.3668 .31439 L
.4096 .28696 L
.45595 .26789 L
.50402 .25792 L
.55194 .25746 L
.59782 .26652 L
.63987 .28474 L
.67642 .3114 L
.70605 .34547 L
Mistroke
.72759 .38561 L
Mfstroke
0 1 .146 r
.27801 .46757 m
.29433 .42329 L
.31871 .38203 L
.35021 .34539 L
.38759 .31483 L
.42938 .29153 L
.47394 .27641 L
.51952 .27007 L
.56434 .27275 L
.60663 .28435 L
.64474 .30441 L
.67717 .33215 L
.70264 .36647 L
.72016 .40604 L
.72904 .4493 L
.72894 .49454 L
.71984 .54 L
.70212 .58389 L
.67647 .62448 L
.64389 .6602 L
.60566 .68962 L
.56329 .7116 L
.51843 .72528 L
.47285 .73012 L
.42834 .72592 L
.38663 .71286 L
.34938 .69145 L
.31804 .66252 L
.29384 .62721 L
.27773 .58691 L
.27034 .5432 L
.27197 .4978 L
.28254 .45248 L
.30166 .40902 L
.32855 .36914 L
.36217 .33439 L
.40121 .30614 L
.44412 .2855 L
.48922 .27328 L
.53474 .26996 L
.57891 .27566 L
.61997 .29017 L
.65633 .31291 L
.68655 .343 L
.70945 .37925 L
.72413 .42023 L
.73002 .46435 L
.72687 .50987 L
.71483 .555 L
.69435 .59797 L
Mistroke
.66624 .63709 L
.63161 .67084 L
.59182 .69788 L
.54842 .71715 L
.50312 .72791 L
.4577 .72971 L
.41394 .72251 L
.37355 .70657 L
.33813 .68252 L
.30906 .65131 L
.28749 .61416 L
.27425 .57253 L
.26988 .52806 L
.27453 .48248 L
.28804 .43759 L
.30986 .39515 L
.33915 .35683 L
.37475 .32412 L
.41526 .29832 L
.4591 .28043 L
.50454 .27116 L
.54981 .27087 L
.59312 .27957 L
.63278 .29692 L
.66723 .32225 L
.69511 .35455 L
.71533 .39255 L
.72711 .43478 L
.72997 .47956 L
.72381 .52515 L
.70886 .56975 L
.68571 .61161 L
.65528 .64909 L
.61876 .68072 L
.57757 .70526 L
.53334 .72174 L
.4878 .72952 L
.44273 .72829 L
.39992 .71811 L
.36104 .69936 L
.3276 .67279 L
.30094 .63943 L
.28208 .60061 L
.27178 .55783 L
.27044 .51279 L
.2781 .46725 L
.29447 .42299 L
.31891 .38175 L
.35046 .34515 L
.38788 .31463 L
Mistroke
.42969 .29139 L
.47427 .27633 L
.51985 .27005 L
.56466 .2728 L
.60692 .28446 L
.645 .30458 L
.67738 .33237 L
.7028 .36674 L
.72026 .40634 L
.72908 .44961 L
.7289 .49487 L
.71975 .54032 L
.70196 .58419 L
.67626 .62476 L
.64363 .66043 L
.60537 .68981 L
.56297 .71173 L
.5181 .72535 L
.47253 .73012 L
.42802 .72586 L
.38635 .71274 L
.34913 .69126 L
.31784 .66229 L
.29369 .62694 L
.27764 .58661 L
.27032 .54288 L
.27201 .49747 L
.28265 .45216 L
.30182 .40872 L
.32877 .36887 L
.36244 .33416 L
.4015 .30597 L
.44443 .28538 L
.48955 .27323 L
.53507 .26997 L
.57921 .27573 L
.62025 .2903 L
.65657 .3131 L
.68674 .34324 L
.70959 .37953 L
.72421 .42054 L
.73003 .46467 L
.72682 .51019 L
.71471 .55531 L
.69417 .59826 L
.66602 .63736 L
.63134 .67106 L
.59152 .69805 L
.5481 .71726 L
.50279 .72795 L
Mistroke
.45738 .72969 L
.41363 .72242 L
.37328 .70642 L
.3379 .68232 L
.30888 .65106 L
.28736 .61388 L
.27419 .57222 L
.26988 .52773 L
.2746 .48216 L
.28817 .43728 L
.31005 .39486 L
.33938 .35657 L
.37502 .32391 L
.41556 .29816 L
.45942 .28033 L
.50487 .27112 L
.55013 .2709 L
.59342 .27967 L
.63305 .29708 L
.66745 .32246 L
.69528 .3548 L
.71545 .39284 L
.72716 .43509 L
.72996 .47989 L
.72373 .52548 L
.70872 .57006 L
.68552 .6119 L
.65504 .64934 L
.61847 .68092 L
.57726 .70541 L
.53301 .72183 L
.48747 .72955 L
.44242 .72825 L
.39963 .718 L
.36077 .69919 L
.32739 .67257 L
.30077 .63917 L
.28198 .60031 L
.27174 .55752 L
.27046 .51246 L
.27819 .46692 L
.29462 .42268 L
.31912 .38147 L
.35071 .34491 L
.38816 .31444 L
.43 .29125 L
.47459 .27625 L
.52018 .27004 L
.56497 .27285 L
.60721 .28457 L
Mistroke
.64525 .30475 L
Mfstroke
.774 1 0 r
.56695 .48845 m
.56627 .50169 L
.56299 .51487 L
.55723 .52746 L
.54923 .53897 L
.5393 .54896 L
.52783 .55702 L
.51526 .56285 L
.50209 .56621 L
.48885 .56697 L
.47604 .5651 L
.46417 .56068 L
.4537 .55388 L
.44506 .54496 L
.43857 .53428 L
.43449 .52225 L
.43298 .50935 L
.4341 .49608 L
.43781 .48297 L
.44396 .47052 L
.45231 .45923 L
.46253 .44954 L
.47422 .44184 L
.48692 .43641 L
.50014 .43348 L
.51335 .43316 L
.52604 .43546 L
.5377 .4403 L
.54789 .44748 L
.55619 .45672 L
.56229 .46766 L
.56595 .47987 L
.56702 .49287 L
.56545 .50615 L
.56132 .51918 L
.55479 .53147 L
.5461 .54252 L
.5356 .5519 L
.52371 .55924 L
.51088 .56426 L
.49763 .56676 L
.48447 .56663 L
.47192 .5639 L
.46047 .55865 L
.45058 .5511 L
.44262 .54155 L
.43692 .53037 L
.43369 .51799 L
.43306 .50491 L
.43506 .49163 L
Mistroke
.43961 .47869 L
.44653 .46658 L
.45555 .45578 L
.46631 .44672 L
.4784 .43975 L
.49133 .43514 L
.5046 .43308 L
.51769 .43364 L
.53009 .43681 L
.54131 .44246 L
.5509 .45037 L
.5585 .46022 L
.5638 .47164 L
.5666 .48417 L
.56678 .49732 L
.56435 .51058 L
.55939 .52342 L
.55209 .53534 L
.54276 .54587 L
.53174 .55461 L
.51948 .5612 L
.50645 .56539 L
.49318 .56701 L
.48016 .566 L
.46793 .56241 L
.45696 .55636 L
.44767 .5481 L
.44044 .53796 L
.43555 .52632 L
.43318 .51365 L
.43344 .50045 L
.43631 .48723 L
.44168 .47451 L
.44934 .46279 L
.45899 .45253 L
.47024 .44413 L
.48267 .43793 L
.49577 .43416 L
.50904 .43297 L
.52196 .43442 L
.53401 .43844 L
.54473 .44488 L
.55369 .45348 L
.56055 .4639 L
.56503 .47575 L
.56696 .48854 L
.56626 .50178 L
.56296 .51496 L
.55719 .52754 L
.54917 .53905 L
Mistroke
.53922 .54902 L
.52774 .55707 L
.51517 .56288 L
.502 .56622 L
.48875 .56697 L
.47595 .56508 L
.46409 .56064 L
.45363 .55382 L
.445 .54489 L
.43853 .53419 L
.43447 .52216 L
.43298 .50925 L
.43412 .49599 L
.43785 .48287 L
.44401 .47044 L
.45237 .45916 L
.46261 .44948 L
.47431 .44179 L
.48702 .43638 L
.50023 .43347 L
.51344 .43317 L
.52612 .43549 L
.53778 .44034 L
.54795 .44754 L
.55624 .45679 L
.56233 .46774 L
.56597 .47996 L
.56702 .49296 L
.56543 .50624 L
.56128 .51927 L
.55473 .53155 L
.54603 .54259 L
.53552 .55196 L
.52362 .55929 L
.51079 .56429 L
.49753 .56677 L
.48438 .56662 L
.47184 .56387 L
.4604 .5586 L
.45051 .55104 L
.44257 .54148 L
.43689 .53028 L
.43367 .5179 L
.43307 .50481 L
.43509 .49154 L
.43965 .4786 L
.44659 .4665 L
.45562 .45571 L
.46639 .44666 L
.47849 .43971 L
Mistroke
.49142 .43512 L
.50469 .43307 L
.51778 .43366 L
.53017 .43685 L
.54138 .44251 L
.55096 .45043 L
.55855 .4603 L
.56383 .47173 L
.56661 .48426 L
.56678 .49742 L
.56432 .51067 L
.55934 .52351 L
.55203 .53542 L
.54268 .54594 L
.53166 .55466 L
.51939 .56124 L
.50636 .56541 L
.49308 .56701 L
.48007 .56599 L
.46785 .56237 L
.45689 .55631 L
.44761 .54804 L
.4404 .53788 L
.43552 .52623 L
.43318 .51356 L
.43345 .50035 L
.43634 .48713 L
.44173 .47442 L
.4494 .46271 L
.45906 .45246 L
.47033 .44408 L
.48276 .43789 L
.49587 .43414 L
.50914 .43298 L
.52205 .43444 L
.53409 .43848 L
.5448 .44493 L
.55375 .45355 L
.56059 .46398 L
.56505 .47584 L
.56696 .48863 L
.56624 .50188 L
.56292 .51505 L
.55714 .52763 L
.5491 .53913 L
.53915 .54909 L
.52765 .55712 L
.51507 .56292 L
.5019 .56624 L
.48866 .56696 L
Mistroke
.47586 .56506 L
Mfstroke
0 1 .213 r
.51397 .78998 m
.45574 .79427 L
.39924 .78701 L
.34669 .76848 L
.30016 .73942 L
.26148 .70097 L
.23215 .65462 L
.21334 .60221 L
.20577 .54578 L
.20976 .48756 L
.22513 .42983 L
.2513 .37485 L
.28722 .32478 L
.33149 .28159 L
.38238 .24697 L
.43788 .22228 L
.49583 .20849 L
.55393 .20615 L
.60992 .21533 L
.66159 .23568 L
.70693 .26641 L
.74414 .30631 L
.77177 .35381 L
.78873 .40704 L
.79436 .46393 L
.78845 .52223 L
.77121 .57965 L
.74332 .63395 L
.70589 .683 L
.66037 .72486 L
.60857 .7579 L
.5525 .78081 L
.49437 .79271 L
.43646 .79311 L
.38105 .78202 L
.3303 .75985 L
.28622 .72749 L
.25052 .6862 L
.22462 .6376 L
.20952 .5836 L
.20582 .52632 L
.21367 .46801 L
.23276 .41095 L
.26233 .35739 L
.30123 .30943 L
.34793 .26894 L
.40061 .23752 L
.45718 .2164 L
.51543 .20642 L
.57307 .20795 L
Mistroke
.62785 .22095 L
.67761 .2449 L
.7204 .27886 L
.75454 .3215 L
.77869 .37114 L
.79191 .42584 L
.79366 .48345 L
.78389 .54172 L
.76298 .59834 L
.73175 .65111 L
.69143 .69794 L
.64359 .73701 L
.59011 .76677 L
.5331 .78607 L
.47479 .79414 L
.41747 .79066 L
.36339 .77578 L
.31467 .75007 L
.27322 .71455 L
.24067 .67061 L
.2183 .61997 L
.20699 .56463 L
.20718 .50675 L
.21885 .4486 L
.24157 .39247 L
.27442 .34057 L
.31613 .29491 L
.36505 .25731 L
.41927 .22923 L
.47666 .21178 L
.53496 .20564 L
.59189 .21105 L
.64522 .2278 L
.69285 .25524 L
.7329 .29228 L
.76382 .33747 L
.78438 .38904 L
.79379 .44497 L
.79166 .50306 L
.77809 .56102 L
.7536 .61659 L
.71916 .66759 L
.67612 .71201 L
.62616 .7481 L
.57126 .77446 L
.51356 .79005 L
.45532 .79426 L
.39884 .78692 L
.34633 .76831 L
.29985 .73918 L
Mistroke
.26123 .70066 L
.23198 .65426 L
.21324 .60181 L
.20576 .54537 L
.20983 .48714 L
.22528 .42942 L
.25152 .37447 L
.28751 .32445 L
.33184 .28131 L
.38276 .24676 L
.43829 .22215 L
.49624 .20844 L
.55434 .20617 L
.61031 .21544 L
.66194 .23587 L
.70722 .26667 L
.74437 .30662 L
.77193 .35417 L
.78881 .40744 L
.79436 .46434 L
.78836 .52264 L
.77104 .58006 L
.74309 .63433 L
.70559 .68333 L
.66002 .72513 L
.60818 .7581 L
.55209 .78094 L
.49395 .79275 L
.43605 .79308 L
.38067 .7819 L
.32996 .75966 L
.28593 .72723 L
.2503 .68588 L
.22447 .63723 L
.20945 .5832 L
.20584 .52591 L
.21377 .4676 L
.23293 .41056 L
.26258 .35703 L
.30154 .30911 L
.34829 .26868 L
.401 .23733 L
.45759 .21629 L
.51585 .20639 L
.57348 .208 L
.62823 .22108 L
.67795 .2451 L
.72068 .27913 L
.75475 .32183 L
.77883 .37152 L
Mistroke
.79196 .42625 L
.79363 .48387 L
.78378 .54213 L
.7628 .59874 L
.73149 .65146 L
.69111 .69825 L
.64322 .73725 L
.58971 .76695 L
.53269 .78617 L
.47437 .79415 L
.41707 .79059 L
.36302 .77563 L
.31434 .74985 L
.27295 .71426 L
.24048 .67027 L
.21818 .61959 L
.20695 .56422 L
.20722 .50633 L
.21898 .44819 L
.24177 .39208 L
.27469 .34021 L
.31645 .29461 L
.36542 .25707 L
.41967 .22907 L
.47708 .2117 L
.53538 .20564 L
.59229 .21113 L
.64558 .22796 L
.69316 .25547 L
.73316 .29258 L
.76401 .33782 L
.78449 .38943 L
.79381 .44538 L
.7916 .50347 L
.77795 .56143 L
.75338 .61698 L
.71888 .66793 L
.67578 .7123 L
.62578 .74833 L
.57085 .77461 L
.51314 .79012 L
.45491 .79425 L
.39845 .78682 L
.34598 .76814 L
.29955 .73893 L
.26099 .70035 L
.2318 .65391 L
.21315 .60142 L
.20575 .54496 L
.2099 .48673 L
Mistroke
.22543 .42902 L
Mfstroke
0 .028 1 r
.33669 .53689 m
.33662 .50464 L
.34297 .4722 L
.35547 .44085 L
.37365 .41183 L
.39679 .38626 L
.42397 .36516 L
.45414 .34935 L
.48611 .33946 L
.51863 .33586 L
.55042 .33871 L
.58022 .34788 L
.60688 .36303 L
.62934 .38355 L
.64673 .40864 L
.65836 .43732 L
.66377 .46846 L
.66276 .50083 L
.65536 .53317 L
.64186 .56422 L
.62279 .59274 L
.59891 .61762 L
.57114 .63788 L
.54058 .65273 L
.50843 .66159 L
.47595 .66411 L
.44441 .66019 L
.41505 .64998 L
.38903 .63388 L
.36736 .61253 L
.3509 .58677 L
.34029 .55759 L
.33595 .52616 L
.33804 .4937 L
.3465 .46149 L
.36097 .43079 L
.3809 .40281 L
.40551 .37864 L
.43383 .35923 L
.46474 .34535 L
.49703 .33753 L
.52945 .3361 L
.5607 .34109 L
.58958 .35233 L
.61494 .36936 L
.63578 .39151 L
.6513 .41792 L
.66088 .44756 L
.66415 .47925 L
.66097 .51176 L
Mistroke
.65148 .5438 L
.63604 .57413 L
.61527 .60155 L
.58997 .62498 L
.56113 .6435 L
.5299 .6564 L
.4975 .66316 L
.46519 .66351 L
.43425 .65745 L
.40589 .6452 L
.38123 .62726 L
.36122 .60433 L
.34666 .5773 L
.33812 .54723 L
.33593 .51532 L
.34018 .4828 L
.35071 .45095 L
.36709 .42103 L
.38869 .39422 L
.41466 .37155 L
.44397 .35392 L
.47549 .34203 L
.50797 .33633 L
.54013 .33706 L
.57072 .34419 L
.59853 .35743 L
.62248 .37626 L
.64162 .39995 L
.6552 .42757 L
.6627 .45803 L
.6638 .49014 L
.65848 .52263 L
.64694 .55424 L
.62963 .58371 L
.60723 .60991 L
.58063 .63179 L
.55086 .64849 L
.51909 .65937 L
.48658 .664 L
.45459 .66218 L
.42439 .65401 L
.39715 .63979 L
.37395 .62008 L
.35569 .59566 L
.3431 .56749 L
.33667 .53666 L
.33665 .5044 L
.34303 .47197 L
.35558 .44063 L
.3738 .41163 L
Mistroke
.39697 .38609 L
.42418 .36503 L
.45437 .34926 L
.48635 .33941 L
.51886 .33586 L
.55064 .33875 L
.58042 .34797 L
.60706 .36316 L
.62949 .38372 L
.64683 .40884 L
.65842 .43754 L
.66379 .46869 L
.66273 .50107 L
.65528 .5334 L
.64174 .56443 L
.62264 .59293 L
.59872 .61778 L
.57093 .63801 L
.54036 .65282 L
.5082 .66163 L
.47572 .66411 L
.44419 .66014 L
.41485 .64988 L
.38886 .63375 L
.36723 .61236 L
.3508 .58657 L
.34024 .55737 L
.33594 .52593 L
.33808 .49347 L
.34658 .46126 L
.3611 .43058 L
.38107 .40262 L
.4057 .37848 L
.43404 .35911 L
.46497 .34527 L
.49727 .3375 L
.52968 .33611 L
.56092 .34115 L
.58977 .35243 L
.6151 .3695 L
.63591 .39169 L
.65139 .41813 L
.66093 .44778 L
.66415 .47948 L
.66093 .51199 L
.65139 .54403 L
.63591 .57434 L
.6151 .60173 L
.58977 .62513 L
.56092 .64362 L
Mistroke
.52967 .65647 L
.49727 .66318 L
.46496 .66349 L
.43404 .65738 L
.4057 .64509 L
.38106 .62712 L
.3611 .60415 L
.34658 .57709 L
.33808 .54701 L
.33594 .51508 L
.34024 .48256 L
.35081 .45073 L
.36723 .42083 L
.38886 .39404 L
.41486 .3714 L
.44419 .35381 L
.47572 .34196 L
.5082 .33632 L
.54036 .33709 L
.57093 .34426 L
.59872 .35754 L
.62264 .37641 L
.64174 .40014 L
.65528 .42778 L
.66273 .45825 L
.66379 .49037 L
.65842 .52286 L
.64683 .55446 L
.62948 .58391 L
.60705 .61008 L
.58042 .63192 L
.55064 .64859 L
.51886 .65943 L
.48635 .66401 L
.45437 .66215 L
.42418 .65393 L
.39697 .63966 L
.3738 .61992 L
.35558 .59547 L
.34303 .56727 L
.33665 .53644 L
.33667 .50417 L
.3431 .47174 L
.35569 .44042 L
.37395 .41143 L
.39715 .38593 L
.42439 .3649 L
.45459 .34917 L
.48658 .33936 L
.51909 .33586 L
Mistroke
.55086 .33879 L
Mfstroke
0 1 .037 r
.81241 .80595 m
.73773 .86962 L
.65372 .91878 L
.56368 .9515 L
.47114 .96651 L
.37973 .96321 L
.29305 .94173 L
.21448 .90291 L
.14712 .84828 L
.09361 .77998 L
.05605 .7007 L
.03591 .61353 L
.03398 .52192 L
.05035 .42944 L
.08436 .33973 L
.13468 .25631 L
.19934 .18245 L
.2758 .12106 L
.36106 .07454 L
.45178 .04471 L
.54438 .03276 L
.63524 .03914 L
.7208 .06361 L
.79769 .10521 L
.86289 .1623 L
.91386 .23264 L
.94858 .31347 L
.9657 .40163 L
.96454 .49365 L
.94515 .58591 L
.90829 .67481 L
.8554 .75684 L
.78857 .8288 L
.71041 .88785 L
.624 .93167 L
.53271 .95856 L
.44015 .96745 L
.34993 .958 L
.2656 .93057 L
.19047 .88624 L
.12749 .82675 L
.07913 .75444 L
.04729 .67215 L
.03321 .5831 L
.03745 .49078 L
.05985 .39883 L
.09952 .31085 L
.15491 .23029 L
.22384 .16032 L
.30361 .10368 L
Mistroke
.39108 .06259 L
.48283 .03867 L
.57526 .03286 L
.66473 .04537 L
.74774 .07573 L
.82102 .12274 L
.8817 .18456 L
.92741 .25876 L
.95634 .34242 L
.96736 .43227 L
.96004 .52478 L
.93466 .61631 L
.89223 .70328 L
.8344 .78227 L
.76345 .85019 L
.68216 .90436 L
.59372 .94266 L
.5016 .96359 L
.40942 .96632 L
.32079 .95075 L
.2392 .9175 L
.16784 .86785 L
.10952 .80378 L
.06652 .72778 L
.04054 .64284 L
.03259 .55229 L
.04298 .45969 L
.07131 .36868 L
.11646 .28281 L
.17666 .20548 L
.24956 .1397 L
.33228 .08806 L
.42159 .05259 L
.51397 .03467 L
.6058 .03502 L
.69349 .05362 L
.77357 .08974 L
.84293 .14196 L
.89882 .20822 L
.93906 .28595 L
.96207 .37207 L
.96695 .46321 L
.9535 .5558 L
.92225 .64619 L
.87443 .73085 L
.81192 .80645 L
.73716 .87002 L
.6531 .91907 L
.56302 .95168 L
.47048 .96655 L
Mistroke
.37909 .96312 L
.29245 .94151 L
.21395 .90257 L
.14668 .84784 L
.09328 .77945 L
.05584 .7001 L
.03583 .61289 L
.03404 .52125 L
.05053 .42878 L
.08466 .3391 L
.1351 .25574 L
.19985 .18196 L
.27639 .12067 L
.3617 .07426 L
.45244 .04456 L
.54504 .03274 L
.63588 .03925 L
.72138 .06385 L
.7982 .10556 L
.86331 .16276 L
.91417 .23318 L
.94877 .31408 L
.96576 .40228 L
.96446 .49431 L
.94494 .58657 L
.90796 .67542 L
.85497 .7574 L
.78805 .82927 L
.70982 .88822 L
.62335 .93193 L
.53205 .95869 L
.43949 .96745 L
.3493 .95786 L
.26503 .93031 L
.18998 .88586 L
.12709 .82628 L
.07884 .75389 L
.04712 .67153 L
.03318 .58244 L
.03755 .49012 L
.06007 .39818 L
.09986 .31024 L
.15536 .22975 L
.22437 .15986 L
.30421 .10333 L
.39173 .06236 L
.4835 .03856 L
.57591 .03288 L
.66535 .04553 L
.7483 .07601 L
Mistroke
.8215 .12314 L
.88209 .18505 L
.92768 .25933 L
.95648 .34305 L
.96737 .43293 L
.95992 .52544 L
.93442 .61695 L
.89187 .70388 L
.83394 .7828 L
.7629 .85063 L
.68155 .90469 L
.59307 .94287 L
.50093 .96367 L
.40877 .96627 L
.32018 .95058 L
.23865 .9172 L
.16738 .86744 L
.10916 .80327 L
.06628 .72719 L
.04042 .6422 L
.0326 .55163 L
.04312 .45903 L
.07157 .36804 L
.11684 .28223 L
.17714 .20496 L
.25012 .13927 L
.3329 .08774 L
.42224 .05239 L
.51463 .03461 L
.60645 .03509 L
.69409 .05382 L
.77411 .09006 L
.84338 .14238 L
.89917 .20874 L
.93929 .28654 L
.96217 .37271 L
.96692 .46387 L
.95334 .55646 L
.92196 .64682 L
.87403 .73143 L
.81142 .80695 L
.73659 .87043 L
.65247 .91937 L
.56237 .95185 L
.46982 .96659 L
.37845 .96303 L
.29185 .94129 L
.21343 .90224 L
.14625 .84739 L
.09295 .77892 L
Mistroke
.05563 .6995 L
Mfstroke
1 .885 0 r
.78038 .23434 m
.8207 .28866 L
.84843 .35128 L
.86249 .41973 L
.86232 .49134 L
.84793 .56328 L
.81989 .63274 L
.77929 .69699 L
.72774 .75351 L
.66724 .80008 L
.60018 .83488 L
.52919 .85653 L
.45705 .86419 L
.3866 .85755 L
.3206 .83689 L
.26164 .803 L
.21204 .75722 L
.17373 .70134 L
.14823 .63757 L
.13654 .56839 L
.13911 .49653 L
.15584 .42481 L
.18608 .35604 L
.22864 .29291 L
.28186 .23792 L
.34363 .19321 L
.41154 .16054 L
.48292 .14119 L
.55497 .13593 L
.62486 .14495 L
.68985 .16791 L
.7474 .2039 L
.79523 .25151 L
.83148 .30887 L
.85471 .37374 L
.86403 .44356 L
.85906 .51559 L
.84 .58702 L
.80759 .65502 L
.76312 .71695 L
.70831 .77036 L
.64533 .81316 L
.57665 .84367 L
.50496 .86069 L
.43307 .86355 L
.36382 .85215 L
.2999 .82693 L
.24384 .78887 L
.19783 .73948 L
.16368 .68069 L
Mistroke
.14273 .61481 L
.1358 .54443 L
.14317 .4723 L
.16454 .40125 L
.19907 .33409 L
.24542 .27343 L
.30175 .22167 L
.36587 .18082 L
.43525 .15251 L
.50717 .13783 L
.57881 .13737 L
.64736 .15114 L
.71012 .1786 L
.76464 .21867 L
.80877 .26979 L
.84078 .32994 L
.85942 .39676 L
.86396 .46764 L
.85421 .53978 L
.83055 .61037 L
.79393 .67662 L
.74577 .73594 L
.68796 .786 L
.62278 .82484 L
.55278 .85093 L
.48071 .86324 L
.40939 .8613 L
.34163 .84519 L
.28009 .81552 L
.22717 .77347 L
.18497 .72069 L
.15513 .65924 L
.13882 .59155 L
.13669 .52027 L
.14881 .44818 L
.17472 .37814 L
.2134 .31287 L
.26332 .25495 L
.32253 .20665 L
.38871 .16986 L
.45925 .14602 L
.53139 .13608 L
.60231 .14042 L
.6692 .15887 L
.72946 .19071 L
.78071 .23469 L
.82094 .28908 L
.84858 .35175 L
.86254 .42024 L
.86227 .49186 L
Mistroke
.84778 .56379 L
.81964 .63323 L
.77896 .69743 L
.72733 .75389 L
.66678 .80038 L
.59968 .83508 L
.52867 .85663 L
.45654 .86419 L
.38611 .85745 L
.32015 .83669 L
.26125 .80271 L
.21172 .75685 L
.1735 .70091 L
.1481 .63709 L
.13651 .56788 L
.13918 .49601 L
.15601 .4243 L
.18635 .35556 L
.22899 .29249 L
.28227 .23756 L
.34409 .19293 L
.41204 .16035 L
.48343 .1411 L
.55548 .13594 L
.62535 .14507 L
.6903 .16812 L
.74778 .2042 L
.79553 .25189 L
.83169 .30932 L
.85483 .37423 L
.86405 .44407 L
.85897 .51611 L
.83981 .58752 L
.80731 .65549 L
.76276 .71736 L
.70789 .7707 L
.64486 .81342 L
.57614 .84384 L
.50444 .86076 L
.43257 .86352 L
.36334 .85202 L
.29947 .8267 L
.24347 .78856 L
.19754 .73909 L
.16349 .68024 L
.14263 .61432 L
.13581 .54391 L
.14327 .47178 L
.16474 .40076 L
.19936 .33363 L
Mistroke
.24579 .27302 L
.30219 .22133 L
.36635 .18058 L
.43576 .15236 L
.50769 .13778 L
.57932 .13742 L
.64783 .15129 L
.71054 .17884 L
.76499 .219 L
.80905 .27019 L
.84097 .33039 L
.85951 .39726 L
.86394 .46815 L
.85408 .5403 L
.83034 .61086 L
.79362 .67707 L
.74539 .73633 L
.68752 .78632 L
.62229 .82507 L
.55227 .85107 L
.48019 .86328 L
.40889 .86124 L
.34117 .84502 L
.27968 .81526 L
.22683 .77313 L
.18471 .72028 L
.15496 .65878 L
.13875 .59105 L
.13672 .51975 L
.14895 .44767 L
.17495 .37765 L
.21372 .31243 L
.26371 .25457 L
.32298 .20634 L
.3892 .16964 L
.45977 .1459 L
.53191 .13606 L
.6028 .1405 L
.66966 .15906 L
.72986 .19099 L
.78104 .23505 L
.82119 .28951 L
.84873 .35223 L
.86259 .42074 L
.86221 .49237 L
.84763 .5643 L
.81939 .63371 L
.77863 .69786 L
.72693 .75426 L
.66632 .80067 L
Mistroke
.59918 .83528 L
Mfstroke
0 1 .739 r
.6851 .63241 m
.65056 .66987 L
.61011 .70067 L
.56535 .7236 L
.51801 .73775 L
.46997 .74257 L
.42311 .73786 L
.37927 .72383 L
.34017 .70101 L
.30733 .6703 L
.28206 .6329 L
.26535 .5903 L
.25784 .54414 L
.25983 .49626 L
.27125 .44852 L
.29165 .4028 L
.32023 .3609 L
.35586 .32445 L
.39715 .2949 L
.44247 .27339 L
.49005 .26078 L
.53802 .25756 L
.58451 .26385 L
.62767 .27941 L
.66582 .30363 L
.69747 .33555 L
.72136 .37393 L
.73657 .41725 L
.74249 .46382 L
.7389 .51182 L
.72593 .55935 L
.7041 .60455 L
.67425 .64564 L
.63756 .68102 L
.59548 .7093 L
.54965 .72936 L
.50187 .74042 L
.45402 .74205 L
.40797 .73417 L
.36553 .71711 L
.32837 .69152 L
.29795 .65842 L
.27546 .6191 L
.26178 .57511 L
.25744 .52817 L
.26263 .48012 L
.27713 .43285 L
.30038 .38822 L
.33147 .34798 L
.36917 .3137 L
Mistroke
.412 .28673 L
.45828 .26814 L
.50621 .25864 L
.55389 .25861 L
.59945 .26806 L
.64112 .28661 L
.67724 .31354 L
.70641 .34778 L
.72747 .388 L
.73961 .43261 L
.74235 .47987 L
.73557 .52792 L
.71955 .57487 L
.69492 .61888 L
.66263 .65823 L
.62396 .69137 L
.58043 .717 L
.53373 .73411 L
.48572 .74203 L
.43827 .74046 L
.39323 .72944 L
.35239 .70943 L
.31734 .68119 L
.28946 .64584 L
.26985 .60477 L
.25926 .55959 L
.25813 .51207 L
.26648 .46407 L
.284 .41749 L
.31 .37414 L
.34345 .33573 L
.38305 .30377 L
.42724 .27951 L
.47428 .26391 L
.52234 .25757 L
.56951 .26074 L
.61396 .27331 L
.65394 .29477 L
.68787 .32428 L
.71443 .36069 L
.73258 .40257 L
.74159 .44828 L
.74113 .49601 L
.7312 .5439 L
.7122 .59006 L
.68487 .6327 L
.65029 .67012 L
.60981 .70087 L
.56501 .72373 L
.51767 .73782 L
Mistroke
.46963 .74257 L
.42279 .7378 L
.37897 .7237 L
.33991 .70081 L
.30712 .67005 L
.28191 .63262 L
.26526 .58998 L
.25782 .5438 L
.25988 .49591 L
.27137 .44818 L
.29183 .40249 L
.32046 .36062 L
.35614 .32422 L
.39746 .29472 L
.44281 .27327 L
.4904 .26073 L
.53837 .25757 L
.58483 .26393 L
.62796 .27955 L
.66607 .30383 L
.69767 .3358 L
.7215 .37422 L
.73665 .41758 L
.7425 .46417 L
.73884 .51216 L
.72581 .55968 L
.70391 .60486 L
.67401 .64592 L
.63728 .68125 L
.59516 .70947 L
.54931 .72947 L
.50153 .74047 L
.45368 .74203 L
.40765 .73408 L
.36525 .71695 L
.32813 .69131 L
.29776 .65816 L
.27533 .6188 L
.26171 .57478 L
.25745 .52782 L
.2627 .47978 L
.27727 .43252 L
.30058 .38792 L
.33172 .34771 L
.36946 .31348 L
.41232 .28657 L
.45862 .26804 L
.50655 .2586 L
.55422 .25865 L
.59977 .26816 L
Mistroke
.6414 .28678 L
.67747 .31376 L
.70659 .34805 L
.72759 .38831 L
.73967 .43295 L
.74233 .48022 L
.73549 .52826 L
.71941 .5752 L
.69471 .61919 L
.66237 .65849 L
.62366 .69158 L
.5801 .71715 L
.53339 .7342 L
.48538 .74205 L
.43793 .74041 L
.39292 .72933 L
.35212 .70925 L
.31712 .68096 L
.28929 .64557 L
.26974 .60446 L
.25922 .55925 L
.25815 .51172 L
.26658 .46373 L
.28416 .41716 L
.31021 .37385 L
.34372 .33548 L
.38335 .30357 L
.42757 .27937 L
.47463 .26383 L
.52268 .25756 L
.56984 .2608 L
.61426 .27343 L
.6542 .29495 L
.68809 .32452 L
.71459 .36098 L
.73267 .40289 L
.74162 .44861 L
.74109 .49635 L
.7311 .54424 L
.71203 .59038 L
.68465 .63298 L
.65002 .67037 L
.6095 .70106 L
.56468 .72386 L
.51733 .73788 L
.46929 .74257 L
.42246 .73773 L
.37867 .72356 L
.33965 .70062 L
.30692 .66981 L
Mistroke
.28176 .63233 L
Mfstroke
1 .142 0 r
.79626 .37229 m
.80846 .43049 L
.80856 .49142 L
.79655 .55268 L
.7729 .61188 L
.73853 .66668 L
.69481 .71495 L
.64344 .75477 L
.58644 .7846 L
.52605 .80326 L
.46464 .81002 L
.40462 .80461 L
.34833 .78725 L
.298 .75861 L
.2556 .71982 L
.22279 .67241 L
.20086 .61823 L
.19067 .55941 L
.19262 .49826 L
.20663 .43717 L
.23216 .37856 L
.26819 .3247 L
.31333 .27773 L
.36579 .23948 L
.42352 .21146 L
.48425 .19476 L
.5456 .19004 L
.60516 .19748 L
.66059 .2168 L
.70972 .24723 L
.75062 .28758 L
.78168 .33627 L
.80169 .39138 L
.80986 .45076 L
.80586 .51207 L
.78987 .5729 L
.7625 .63088 L
.72482 .68371 L
.67832 .72934 L
.62483 .76597 L
.56643 .79216 L
.50543 .80688 L
.44421 .80956 L
.38519 .80009 L
.33067 .77884 L
.28279 .74665 L
.24344 .70478 L
.21416 .65487 L
.1961 .59889 L
.18996 .53902 L
Mistroke
.19599 .47762 L
.21396 .4171 L
.24314 .35984 L
.28241 .30807 L
.33022 .26384 L
.38469 .22887 L
.44369 .20455 L
.5049 .19182 L
.56591 .19119 L
.62434 .20267 L
.67789 .22583 L
.72445 .25974 L
.76221 .30309 L
.78968 .35416 L
.80578 .41095 L
.80987 .47124 L
.80181 .53266 L
.7819 .5928 L
.75093 .6493 L
.71011 .69993 L
.66105 .74272 L
.60566 .77598 L
.54613 .79842 L
.48478 .80914 L
.42404 .80773 L
.36627 .79424 L
.31376 .7692 L
.26855 .7336 L
.23242 .68883 L
.2068 .63665 L
.19269 .57911 L
.19063 .51846 L
.20072 .45709 L
.22255 .3974 L
.25527 .34174 L
.2976 .29229 L
.34787 .25099 L
.40411 .21946 L
.46411 .19895 L
.52552 .19025 L
.58593 .1937 L
.64297 .20918 L
.6944 .23607 L
.73819 .27332 L
.77264 .31946 L
.79639 .37269 L
.80851 .43092 L
.80852 .49186 L
.79642 .55312 L
.77269 .61229 L
Mistroke
.73825 .66705 L
.69447 .71526 L
.64305 .75502 L
.58602 .78478 L
.52561 .80335 L
.4642 .81002 L
.4042 .80453 L
.34795 .78708 L
.29767 .75836 L
.25533 .71951 L
.22259 .67204 L
.20074 .61782 L
.19064 .55898 L
.19267 .49782 L
.20677 .43674 L
.23238 .37815 L
.26849 .32434 L
.31368 .27743 L
.36619 .23925 L
.42395 .2113 L
.48469 .19468 L
.54603 .19005 L
.60557 .19758 L
.66097 .21698 L
.71004 .24749 L
.75088 .2879 L
.78186 .33664 L
.80179 .3918 L
.80987 .45119 L
.80579 .51251 L
.78971 .57333 L
.76226 .63128 L
.72452 .68407 L
.67796 .72964 L
.62442 .7662 L
.566 .7923 L
.50499 .80694 L
.44378 .80953 L
.38478 .79998 L
.3303 .77865 L
.28248 .74638 L
.2432 .70445 L
.21399 .65449 L
.19601 .59847 L
.18996 .53858 L
.19608 .47718 L
.21413 .41668 L
.24339 .35944 L
.28273 .30772 L
.33059 .26355 L
Mistroke
.3851 .22866 L
.44412 .20442 L
.50534 .19177 L
.56634 .19123 L
.62474 .2028 L
.67825 .22603 L
.72476 .26002 L
.76245 .30343 L
.78984 .35455 L
.80585 .41138 L
.80986 .47168 L
.80171 .5331 L
.78172 .59322 L
.75067 .64968 L
.70979 .70027 L
.66067 .743 L
.60524 .77619 L
.54569 .79854 L
.48434 .80917 L
.42361 .80767 L
.36587 .7941 L
.3134 .76898 L
.26826 .73331 L
.2322 .68848 L
.20666 .63625 L
.19263 .57868 L
.19066 .51802 L
.20083 .45665 L
.22275 .39698 L
.25554 .34136 L
.29793 .29196 L
.34825 .25073 L
.40453 .21928 L
.46455 .19884 L
.52596 .19023 L
.58636 .19377 L
.64336 .20933 L
.69474 .2363 L
.73848 .27362 L
.77285 .31982 L
.79652 .3731 L
.80855 .43135 L
.80847 .4923 L
.79629 .55355 L
.77248 .6127 L
.73797 .66742 L
.69412 .71558 L
.64266 .75527 L
.5856 .78495 L
.52518 .80344 L
Mistroke
.46376 .81003 L
Mfstroke
1 .98 0 r
.27961 .25386 m
.33832 .20879 L
.40337 .17515 L
.47221 .15425 L
.54214 .14693 L
.61042 .15346 L
.67436 .17359 L
.73147 .20653 L
.77948 .25099 L
.81653 .30523 L
.84116 .3671 L
.8524 .4342 L
.8498 .50387 L
.83348 .57339 L
.80407 .64004 L
.76273 .70118 L
.71108 .75443 L
.65114 .7977 L
.58527 .82928 L
.51605 .84794 L
.44621 .85294 L
.37847 .8441 L
.31551 .82174 L
.25978 .78677 L
.21349 .74053 L
.17843 .68486 L
.156 .62193 L
.14707 .55422 L
.15199 .48437 L
.17056 .41515 L
.20207 .34925 L
.24527 .28927 L
.29846 .23755 L
.35957 .19614 L
.42619 .16666 L
.4957 .15025 L
.56538 .14758 L
.6325 .15873 L
.69442 .18328 L
.7487 .22025 L
.79323 .26821 L
.82624 .32526 L
.84646 .38917 L
.85308 .45743 L
.84584 .52736 L
.82502 .59622 L
.79145 .6613 L
.74645 .72005 L
.69177 .77017 L
.62956 .80968 L
Mistroke
.56227 .83703 L
.49254 .85116 L
.4231 .85151 L
.35668 .83807 L
.29588 .81135 L
.24309 .77242 L
.20039 .72279 L
.16944 .66442 L
.15147 .5996 L
.14717 .53087 L
.15673 .46093 L
.17975 .39252 L
.21534 .32833 L
.26211 .27087 L
.31821 .22241 L
.38145 .18485 L
.44934 .15965 L
.51921 .14781 L
.58833 .14979 L
.65399 .16551 L
.7136 .19437 L
.76483 .23521 L
.80567 .28645 L
.83451 .34607 L
.85022 .41174 L
.85219 .48086 L
.84033 .55074 L
.81512 .61862 L
.77754 .68185 L
.72907 .73794 L
.67161 .7847 L
.60741 .82028 L
.539 .84329 L
.46906 .85283 L
.40033 .84852 L
.33551 .83053 L
.27715 .79958 L
.22754 .75686 L
.18862 .70406 L
.16191 .64326 L
.14848 .57683 L
.14884 .50739 L
.16299 .43765 L
.19036 .37037 L
.22988 .30817 L
.28001 .2535 L
.33876 .2085 L
.40385 .17495 L
.47271 .15415 L
.54264 .14692 L
Mistroke
.6109 .15356 L
.6748 .17378 L
.73184 .20681 L
.77979 .25135 L
.81676 .30565 L
.84129 .36757 L
.85243 .43469 L
.84974 .50437 L
.83332 .57388 L
.80382 .6405 L
.7624 .70159 L
.71068 .75478 L
.65069 .79797 L
.58478 .82946 L
.51555 .84803 L
.44571 .85293 L
.378 .84398 L
.31508 .82154 L
.25942 .78647 L
.21319 .74016 L
.17823 .68443 L
.15589 .62146 L
.14705 .55372 L
.15207 .48387 L
.17074 .41466 L
.20234 .34879 L
.24562 .28886 L
.29888 .23722 L
.36003 .19589 L
.42668 .16649 L
.4962 .15019 L
.56588 .14761 L
.63296 .15886 L
.69483 .1835 L
.74906 .22056 L
.79351 .26859 L
.82644 .3257 L
.84656 .38965 L
.85307 .45793 L
.84573 .52786 L
.82483 .5967 L
.79117 .66175 L
.74609 .72044 L
.69135 .77049 L
.6291 .80992 L
.56178 .83718 L
.49204 .85122 L
.42261 .85146 L
.35622 .83792 L
.29547 .81111 L
Mistroke
.24275 .7721 L
.20012 .7224 L
.16926 .66398 L
.15139 .59912 L
.14719 .53037 L
.15684 .46043 L
.17996 .39204 L
.21564 .32789 L
.26248 .27049 L
.31864 .2221 L
.38192 .18462 L
.44983 .15952 L
.51971 .14777 L
.58882 .14985 L
.65444 .16568 L
.714 .19462 L
.76517 .23555 L
.80592 .28685 L
.83467 .34653 L
.85028 .41222 L
.85215 .48136 L
.8402 .55123 L
.81489 .61909 L
.77723 .68228 L
.72869 .73832 L
.67117 .785 L
.60693 .82049 L
.5385 .84341 L
.46856 .85285 L
.39985 .84844 L
.33507 .83036 L
.27676 .79931 L
.22722 .75652 L
.18838 .70365 L
.16177 .6428 L
.14843 .57634 L
.1489 .50689 L
.16314 .43716 L
.1906 .3699 L
.23021 .30775 L
.2804 .25314 L
.33921 .20822 L
.40433 .17475 L
.47321 .15405 L
.54314 .14692 L
.61137 .15365 L
.67524 .17398 L
.73222 .20709 L
.7801 .25171 L
.81698 .30607 L
Mistroke
.84142 .36803 L
Mfstroke
1 .629 0 r
.25425 .61493 m
.24234 .5667 L
.24054 .51586 L
.24893 .46439 L
.26717 .41432 L
.29454 .36761 L
.32998 .3261 L
.37209 .29141 L
.41923 .26491 L
.46953 .24763 L
.52102 .24026 L
.5717 .24309 L
.61956 .25599 L
.66272 .27847 L
.6995 .30965 L
.72845 .3483 L
.74844 .3929 L
.75867 .4417 L
.75876 .49279 L
.74868 .54417 L
.72885 .59381 L
.70004 .63977 L
.66337 .68024 L
.6203 .71364 L
.5725 .73866 L
.52186 .75431 L
.47036 .75998 L
.42002 .75544 L
.37282 .74088 L
.33062 .71687 L
.29506 .68435 L
.26754 .64459 L
.24915 .59915 L
.2406 .54983 L
.24223 .49855 L
.25398 .44732 L
.27538 .39817 L
.3056 .35301 L
.34345 .31362 L
.38745 .28154 L
.43586 .25804 L
.48678 .24403 L
.53823 .24007 L
.58817 .24631 L
.63466 .26251 L
.67586 .28803 L
.71016 .32186 L
.73621 .36269 L
.75299 .40891 L
.75984 .4587 L
Mistroke
.75649 .51011 L
.74308 .56113 L
.72013 .60974 L
.68854 .65405 L
.64955 .69232 L
.60469 .72303 L
.55572 .745 L
.50456 .75734 L
.45323 .75959 L
.40373 .75165 L
.35801 .73384 L
.31786 .70684 L
.28486 .67173 L
.2603 .62988 L
.24515 .58293 L
.24001 .53273 L
.24506 .48124 L
.26012 .43049 L
.2846 .38247 L
.31753 .33906 L
.35762 .30196 L
.4033 .27264 L
.45277 .25224 L
.5041 .24157 L
.55526 .24103 L
.60426 .25066 L
.64917 .27008 L
.68822 .29852 L
.71988 .33486 L
.74292 .37769 L
.75642 .42532 L
.75986 .47588 L
.7531 .52738 L
.7364 .57781 L
.71043 .62519 L
.6762 .66765 L
.63506 .70354 L
.58861 .73143 L
.53869 .75025 L
.48725 .75924 L
.43631 .75806 L
.38787 .74675 L
.34383 .72575 L
.30591 .6959 L
.27562 .65836 L
.25413 .6146 L
.24229 .56635 L
.24057 .51549 L
.24902 .46402 L
.26733 .41397 L
Mistroke
.29477 .36729 L
.33026 .32582 L
.37242 .29119 L
.41958 .26475 L
.46989 .24754 L
.52139 .24025 L
.57205 .24314 L
.61988 .25612 L
.66301 .27867 L
.69974 .3099 L
.72863 .3486 L
.74855 .39324 L
.75871 .44206 L
.75872 .49316 L
.74858 .54453 L
.72868 .59415 L
.6998 .64008 L
.66309 .68051 L
.61997 .71385 L
.57214 .73881 L
.52149 .75439 L
.46999 .75998 L
.41967 .75537 L
.3725 .74074 L
.33033 .71667 L
.29483 .68408 L
.26737 .64428 L
.24905 .59881 L
.24057 .54946 L
.24228 .49818 L
.2541 .44696 L
.27557 .39783 L
.30585 .3527 L
.34375 .31336 L
.38778 .28134 L
.43621 .2579 L
.48715 .24397 L
.53859 .24008 L
.58852 .24639 L
.63498 .26266 L
.67613 .28824 L
.71038 .32213 L
.73636 .363 L
.75307 .40925 L
.75985 .45906 L
.75643 .51048 L
.74295 .56149 L
.71993 .61008 L
.68828 .65435 L
.64924 .69257 L
Mistroke
.60435 .72322 L
.55536 .74512 L
.50419 .7574 L
.45286 .75957 L
.40339 .75156 L
.3577 .73367 L
.3176 .70662 L
.28465 .67145 L
.26016 .62956 L
.24508 .58258 L
.24001 .53236 L
.24514 .48087 L
.26027 .43014 L
.28481 .38214 L
.31779 .33877 L
.35793 .30172 L
.40364 .27246 L
.45313 .25213 L
.50447 .24153 L
.55562 .24107 L
.6046 .25077 L
.64947 .27025 L
.68847 .29875 L
.72008 .33515 L
.74305 .37802 L
.75648 .42567 L
.75984 .47625 L
.75301 .52775 L
.73625 .57817 L
.71021 .62551 L
.67593 .66794 L
.63474 .70377 L
.58826 .7316 L
.53832 .75035 L
.48688 .75927 L
.43595 .75801 L
.38753 .74663 L
.34353 .72557 L
.30567 .69566 L
.27543 .65806 L
.25401 .61427 L
.24224 .56599 L
.24059 .51512 L
.24912 .46366 L
.2675 .41362 L
.295 .36697 L
.33054 .32555 L
.37274 .29097 L
.41993 .26459 L
.47026 .24746 L
Mistroke
.52176 .24023 L
Mfstroke
0 1 .422 r
.61818 .44657 m
.62355 .46977 L
.62406 .49416 L
.6197 .51878 L
.61065 .54266 L
.59725 .56487 L
.58004 .58453 L
.55969 .60088 L
.53699 .61326 L
.51284 .6212 L
.48819 .62439 L
.464 .62269 L
.44122 .61617 L
.42075 .6051 L
.4034 .5899 L
.38983 .57118 L
.38058 .54966 L
.37603 .52619 L
.37633 .50169 L
.38149 .47713 L
.39131 .45347 L
.40539 .43163 L
.42318 .41247 L
.44398 .39675 L
.46699 .38508 L
.49129 .37793 L
.51593 .37556 L
.53995 .37807 L
.5624 .38538 L
.5824 .39718 L
.59916 .41301 L
.61204 .43226 L
.62052 .45417 L
.62426 .47788 L
.62314 .50245 L
.61717 .52693 L
.60661 .55035 L
.59187 .5718 L
.57352 .59042 L
.55229 .6055 L
.529 .61644 L
.50457 .62281 L
.47997 .62436 L
.45615 .62103 L
.43405 .61295 L
.41454 .60043 L
.39839 .58398 L
.38622 .56423 L
.37852 .54195 L
.37558 .51803 L
Mistroke
.37753 .49341 L
.38429 .46904 L
.39558 .44589 L
.41098 .42486 L
.42986 .40678 L
.4515 .39236 L
.47505 .38216 L
.49957 .37659 L
.52411 .37586 L
.5477 .38 L
.56943 .38886 L
.58842 .40207 L
.60395 .41913 L
.6154 .43936 L
.62231 .46197 L
.62443 .48608 L
.62167 .51073 L
.61413 .53496 L
.60211 .55781 L
.58608 .5784 L
.56667 .59591 L
.54465 .60966 L
.52088 .61911 L
.49629 .62388 L
.47184 .62378 L
.4485 .61883 L
.42717 .60922 L
.40871 .59532 L
.39383 .57768 L
.38312 .55699 L
.37699 .53406 L
.37569 .5098 L
.37927 .48515 L
.38759 .46109 L
.40032 .43855 L
.41696 .41842 L
.43686 .4015 L
.45924 .38844 L
.48322 .37976 L
.50786 .3758 L
.53218 .37671 L
.55525 .38246 L
.57615 .39283 L
.59405 .4074 L
.60827 .4256 L
.61824 .44673 L
.62357 .46994 L
.62405 .49434 L
.61966 .51896 L
.61057 .54283 L
Mistroke
.59714 .56502 L
.57991 .58466 L
.55953 .60098 L
.53682 .61333 L
.51267 .62124 L
.48801 .62439 L
.46383 .62266 L
.44107 .61611 L
.42062 .60501 L
.40328 .58978 L
.38975 .57103 L
.38053 .5495 L
.37601 .52602 L
.37635 .50152 L
.38155 .47696 L
.39139 .4533 L
.4055 .43148 L
.42332 .41235 L
.44414 .39665 L
.46716 .38502 L
.49146 .37789 L
.51611 .37556 L
.54011 .37811 L
.56255 .38545 L
.58253 .39728 L
.59927 .41314 L
.61212 .43241 L
.62056 .45433 L
.62427 .47805 L
.62311 .50263 L
.61711 .5271 L
.60652 .55051 L
.59175 .57194 L
.57338 .59055 L
.55213 .6056 L
.52883 .6165 L
.5044 .62284 L
.47979 .62435 L
.45598 .62099 L
.4339 .61287 L
.41441 .60033 L
.39829 .58385 L
.38615 .56407 L
.37848 .54179 L
.37558 .51786 L
.37756 .49323 L
.38435 .46887 L
.39568 .44573 L
.4111 .42472 L
.43001 .40666 L
Mistroke
.45167 .39227 L
.47522 .3821 L
.49975 .37657 L
.52428 .37587 L
.54787 .38005 L
.56957 .38894 L
.58855 .40218 L
.60405 .41926 L
.61546 .43951 L
.62235 .46214 L
.62443 .48625 L
.62163 .5109 L
.61405 .53513 L
.602 .55797 L
.58595 .57854 L
.56652 .59603 L
.54449 .60975 L
.5207 .61916 L
.49611 .62389 L
.47167 .62376 L
.44833 .61878 L
.42703 .60913 L
.40859 .5952 L
.39374 .57754 L
.38306 .55683 L
.37696 .53389 L
.3757 .50962 L
.37932 .48497 L
.38767 .46092 L
.40043 .43839 L
.41709 .41829 L
.43701 .40139 L
.45941 .38836 L
.48339 .37971 L
.50803 .37579 L
.53235 .37674 L
.55541 .38252 L
.57629 .39292 L
.59417 .40752 L
.60836 .42575 L
.6183 .44689 L
.62359 .47012 L
.62403 .49452 L
.61961 .51913 L
.61049 .543 L
.59703 .56517 L
.57977 .58479 L
.55938 .60108 L
.53665 .61341 L
.51249 .62128 L
Mistroke
.48784 .6244 L
Mfstroke
0 .574 1 r
.40489 .30546 m
.44777 .28555 L
.4927 .27405 L
.53792 .27142 L
.58165 .27777 L
.62217 .29283 L
.65791 .31602 L
.68744 .34644 L
.70962 .38288 L
.72357 .42392 L
.72874 .46794 L
.72494 .51323 L
.71232 .55799 L
.69135 .60048 L
.66288 .63902 L
.62802 .67211 L
.58813 .69844 L
.54478 .71699 L
.49968 .72702 L
.45459 .72814 L
.41128 .7203 L
.37145 .70382 L
.33667 .67935 L
.3083 .64783 L
.28745 .61051 L
.27494 .56885 L
.27127 .52449 L
.27657 .47918 L
.29064 .43467 L
.31293 .39273 L
.34256 .35501 L
.37837 .32297 L
.41895 .29788 L
.46271 .28072 L
.50794 .27217 L
.55285 .27256 L
.59569 .28187 L
.63478 .29975 L
.66857 .32548 L
.69575 .35807 L
.71525 .39622 L
.7263 .43845 L
.72847 .48309 L
.72167 .5284 L
.70617 .57259 L
.68258 .61393 L
.65183 .65081 L
.61511 .68176 L
.57388 .70558 L
.52975 .72133 L
Mistroke
.48445 .7284 L
.43976 .7265 L
.39744 .71571 L
.35914 .69646 L
.32637 .66949 L
.30041 .63588 L
.28229 .59693 L
.27271 .55418 L
.27205 .5093 L
.28034 .46406 L
.29724 .42022 L
.32211 .37952 L
.35396 .34355 L
.39153 .31371 L
.43337 .29119 L
.47782 .27687 L
.52314 .27129 L
.56755 .2747 L
.60931 .28695 L
.64679 .30756 L
.6785 .33572 L
.7032 .37033 L
.71993 .41003 L
.72803 .45325 L
.72718 .49832 L
.71741 .54345 L
.69912 .58687 L
.673 .62689 L
.6401 .66192 L
.6017 .6906 L
.55931 .7118 L
.51459 .72469 L
.46929 .72876 L
.42521 .72385 L
.38405 .71016 L
.34745 .68822 L
.31684 .65889 L
.29341 .62332 L
.27809 .58292 L
.27148 .53926 L
.27384 .49406 L
.28508 .4491 L
.30475 .40613 L
.33208 .36684 L
.366 .33278 L
.40518 .30529 L
.44809 .28543 L
.49303 .274 L
.53824 .27144 L
.58195 .27784 L
Mistroke
.62245 .29297 L
.65814 .31622 L
.68763 .34668 L
.70975 .38316 L
.72364 .42423 L
.72875 .46827 L
.72488 .51355 L
.71219 .5583 L
.69118 .60077 L
.66265 .63928 L
.62775 .67232 L
.58783 .6986 L
.54447 .71709 L
.49936 .72706 L
.45427 .72811 L
.41098 .72022 L
.37118 .70368 L
.33644 .67914 L
.30812 .64758 L
.28733 .61022 L
.27488 .56854 L
.27127 .52417 L
.27664 .47885 L
.29077 .43436 L
.31312 .39245 L
.34279 .35475 L
.37864 .32276 L
.41925 .29773 L
.46303 .28063 L
.50826 .27214 L
.55317 .27259 L
.59599 .28197 L
.63504 .29991 L
.66879 .32569 L
.69592 .35832 L
.71536 .39651 L
.72635 .43876 L
.72845 .48342 L
.72159 .52872 L
.70603 .5729 L
.68239 .61422 L
.65158 .65105 L
.61483 .68196 L
.57357 .70572 L
.52943 .72141 L
.48413 .72841 L
.43945 .72645 L
.39715 .7156 L
.35888 .69629 L
.32616 .66927 L
Mistroke
.30025 .63562 L
.28219 .59663 L
.27267 .55386 L
.27208 .50897 L
.28043 .46373 L
.29739 .41992 L
.32231 .37925 L
.35421 .34331 L
.39182 .31353 L
.43368 .29106 L
.47814 .27679 L
.52346 .27129 L
.56786 .27476 L
.6096 .28707 L
.64704 .30773 L
.6787 .33594 L
.70335 .3706 L
.72002 .41032 L
.72806 .45357 L
.72714 .49864 L
.71731 .54377 L
.69896 .58717 L
.67279 .62716 L
.63984 .66215 L
.60141 .69078 L
.55899 .71193 L
.51426 .72475 L
.46897 .72876 L
.4249 .72379 L
.38377 .71003 L
.34721 .68803 L
.31664 .65865 L
.29327 .62305 L
.27801 .58262 L
.27147 .53894 L
.27389 .49374 L
.28519 .44878 L
.30492 .40583 L
.3323 .36658 L
.36626 .33256 L
.40548 .30512 L
.4484 .28532 L
.49335 .27395 L
.53856 .27145 L
.58226 .27792 L
.62272 .29311 L
.65838 .31641 L
.68781 .34692 L
.70988 .38344 L
.7237 .42453 L
Mistroke
.72875 .46859 L
Mfstroke
0 .692 1 r
.40263 .48908 m
.40913 .46967 L
.41919 .45146 L
.43243 .43515 L
.44832 .42139 L
.46624 .41071 L
.48548 .40353 L
.50529 .40015 L
.5249 .40068 L
.54352 .4051 L
.56044 .41326 L
.57499 .42482 L
.58659 .43932 L
.5948 .45621 L
.59929 .47482 L
.59988 .49442 L
.59654 .51423 L
.58942 .53349 L
.5788 .55143 L
.56507 .56735 L
.5488 .58063 L
.53061 .59075 L
.51121 .5973 L
.49138 .60004 L
.47189 .59885 L
.4535 .59378 L
.43693 .58503 L
.42284 .57294 L
.41178 .55799 L
.40418 .54077 L
.40034 .52194 L
.40041 .50225 L
.40439 .48248 L
.41212 .46339 L
.42331 .44574 L
.4375 .43022 L
.45414 .41743 L
.47258 .40789 L
.4921 .40196 L
.51193 .39988 L
.5313 .40173 L
.54943 .40744 L
.56562 .41678 L
.57924 .42938 L
.58975 .44476 L
.59673 .4623 L
.59992 .48133 L
.59919 .50108 L
.59457 .5208 L
.58623 .53969 L
Mistroke
.57451 .55703 L
.55986 .57214 L
.54287 .58441 L
.52419 .59336 L
.50457 .59866 L
.48476 .60008 L
.46555 .59757 L
.4477 .59124 L
.4319 .58132 L
.41877 .56821 L
.40882 .55243 L
.40246 .53459 L
.39993 .51539 L
.40132 .49558 L
.40658 .47595 L
.41551 .45727 L
.42776 .44026 L
.44284 .42559 L
.46017 .41385 L
.47906 .40548 L
.49877 .40083 L
.51852 .40007 L
.53756 .40323 L
.55511 .41019 L
.57051 .42067 L
.58314 .43426 L
.5925 .45044 L
.59824 .46856 L
.60012 .48792 L
.59807 .50774 L
.59217 .52727 L
.58265 .54572 L
.56989 .56238 L
.55439 .5766 L
.53675 .5878 L
.51767 .59556 L
.4979 .59957 L
.47821 .59967 L
.45937 .59586 L
.44213 .58829 L
.42716 .57725 L
.41505 .56319 L
.40627 .54664 L
.40117 .52826 L
.39995 .50877 L
.40266 .48894 L
.40919 .46954 L
.41928 .45133 L
.43253 .43504 L
.44844 .4213 L
Mistroke
.46637 .41064 L
.48562 .4035 L
.50543 .40014 L
.52503 .40069 L
.54365 .40515 L
.56056 .41333 L
.57508 .42491 L
.58667 .43944 L
.59485 .45634 L
.5993 .47496 L
.59987 .49456 L
.59651 .51437 L
.58936 .53362 L
.57871 .55155 L
.56497 .56746 L
.54867 .58072 L
.53047 .59081 L
.51107 .59734 L
.49124 .60005 L
.47175 .59883 L
.45337 .59373 L
.43682 .58495 L
.42275 .57284 L
.41171 .55788 L
.40414 .54064 L
.40033 .5218 L
.40043 .50211 L
.40443 .48234 L
.41219 .46326 L
.4234 .44562 L
.43761 .43011 L
.45427 .41735 L
.47272 .40784 L
.49225 .40194 L
.51208 .39988 L
.53143 .40176 L
.54955 .40749 L
.56573 .41686 L
.57933 .42948 L
.58981 .44488 L
.59677 .46243 L
.59993 .48147 L
.59917 .50122 L
.59452 .52094 L
.58616 .53982 L
.57441 .55715 L
.55975 .57223 L
.54274 .58448 L
.52406 .59342 L
.50443 .59868 L
Mistroke
.48462 .60008 L
.46542 .59754 L
.44758 .59118 L
.43179 .58124 L
.41868 .56811 L
.40877 .55231 L
.40243 .53445 L
.39992 .51525 L
.40134 .49544 L
.40663 .47582 L
.41559 .45714 L
.42786 .44014 L
.44296 .4255 L
.4603 .41378 L
.47919 .40544 L
.49891 .40081 L
.51866 .40008 L
.53769 .40326 L
.55523 .41025 L
.57061 .42075 L
.58322 .43437 L
.59256 .45056 L
.59826 .4687 L
.60012 .48806 L
.59804 .50789 L
.59211 .52741 L
.58257 .54585 L
.56979 .5625 L
.55427 .57669 L
.53662 .58787 L
.51753 .59561 L
.49776 .59959 L
.47807 .59966 L
.45924 .59582 L
.44202 .58822 L
.42706 .57716 L
.41498 .56307 L
.40622 .54651 L
.40115 .52812 L
.39996 .50863 L
.40269 .48879 L
.40925 .4694 L
.41936 .45121 L
.43264 .43493 L
.44856 .42121 L
.4665 .41058 L
.48576 .40346 L
.50557 .40013 L
.52517 .40071 L
.54378 .4052 L
Mistroke
.56067 .4134 L
Mfstroke
0 .34 1 r
.60307 .21511 m
.6551 .2341 L
.70103 .26353 L
.73908 .30224 L
.76774 .34872 L
.78589 .40112 L
.79283 .45741 L
.78827 .51537 L
.7724 .57273 L
.74584 .62723 L
.70963 .67674 L
.66519 .71932 L
.61427 .75328 L
.55887 .77731 L
.50115 .79045 L
.44339 .79219 L
.38785 .78247 L
.33672 .76166 L
.29199 .73058 L
.25542 .69045 L
.22845 .64285 L
.21214 .58964 L
.20713 .53291 L
.21361 .47489 L
.23133 .41786 L
.2596 .36405 L
.2973 .31558 L
.34295 .27434 L
.39477 .24196 L
.45072 .21971 L
.5086 .20846 L
.56615 .20864 L
.6211 .22027 L
.67129 .24287 L
.71476 .27556 L
.74981 .31707 L
.77505 .36575 L
.7895 .4197 L
.79258 .4768 L
.78418 .53481 L
.76463 .59146 L
.7347 .64451 L
.69555 .6919 L
.64873 .73175 L
.59607 .76251 L
.53964 .78297 L
.48165 .79232 L
.42439 .7902 L
.37009 .77669 L
.32089 .75232 L
Mistroke
.27872 .71804 L
.24524 .67522 L
.22175 .62551 L
.20918 .57088 L
.20803 .51347 L
.21834 .45552 L
.23969 .39933 L
.27127 .34708 L
.31182 .30084 L
.35976 .26241 L
.4132 .23331 L
.47005 .21467 L
.52807 .20723 L
.58499 .21129 L
.63858 .22667 L
.68673 .25278 L
.72755 .28859 L
.75943 .3327 L
.78114 .38337 L
.79181 .43862 L
.79104 .49629 L
.77883 .55409 L
.75569 .60978 L
.72251 .66115 L
.6806 .7062 L
.6316 .74316 L
.57744 .77058 L
.52023 .78737 L
.46223 .79289 L
.40572 .78691 L
.3529 .76968 L
.30586 .74186 L
.26644 .70454 L
.23618 .6592 L
.21628 .60761 L
.20751 .5518 L
.21022 .49396 L
.22431 .43635 L
.24921 .38124 L
.28396 .33079 L
.32718 .28699 L
.37719 .25154 L
.43201 .22584 L
.48951 .2109 L
.54742 .20731 L
.60346 .21521 L
.65545 .23428 L
.70133 .26378 L
.73932 .30255 L
.76791 .34907 L
Mistroke
.78598 .40152 L
.79284 .45783 L
.7882 .51579 L
.77225 .57313 L
.74561 .62761 L
.70934 .67707 L
.66485 .71959 L
.61389 .75349 L
.55846 .77744 L
.50074 .7905 L
.44298 .79216 L
.38747 .78236 L
.33637 .76147 L
.29169 .73032 L
.25519 .69013 L
.2283 .64248 L
.21207 .58924 L
.20714 .5325 L
.2137 .47448 L
.2315 .41746 L
.25984 .36368 L
.2976 .31525 L
.34331 .27408 L
.39516 .24176 L
.45113 .21959 L
.50902 .20842 L
.56655 .20869 L
.62147 .22039 L
.67163 .24307 L
.71505 .27583 L
.75003 .31739 L
.77519 .36612 L
.78956 .4201 L
.79256 .47721 L
.78408 .53522 L
.76445 .59185 L
.73445 .64487 L
.69524 .69221 L
.64837 .73201 L
.59567 .76269 L
.53922 .78307 L
.48124 .79234 L
.42399 .79014 L
.36972 .77655 L
.32056 .7521 L
.27845 .71777 L
.24503 .67488 L
.22162 .62513 L
.20913 .57047 L
.20806 .51305 L
Mistroke
.21845 .45511 L
.23989 .39894 L
.27153 .34673 L
.31214 .30053 L
.36013 .26217 L
.4136 .23314 L
.47046 .21458 L
.52849 .20722 L
.58539 .21136 L
.63895 .22682 L
.68705 .253 L
.72781 .28888 L
.75963 .33304 L
.78126 .38376 L
.79185 .43903 L
.79099 .4967 L
.77871 .5545 L
.75549 .61016 L
.72224 .6615 L
.68027 .7065 L
.63123 .74339 L
.57703 .77073 L
.51982 .78745 L
.46182 .79289 L
.40532 .78683 L
.35254 .76951 L
.30555 .74162 L
.26619 .70424 L
.236 .65885 L
.21618 .60723 L
.20749 .55139 L
.21028 .49354 L
.22445 .43595 L
.24943 .38086 L
.28424 .33045 L
.32752 .2867 L
.37757 .25132 L
.43242 .22569 L
.48993 .21084 L
.54783 .20733 L
.60385 .2153 L
.6558 .23446 L
.70164 .26403 L
.73956 .30286 L
.76808 .34943 L
.78607 .40191 L
.79285 .45824 L
.78812 .51621 L
.77209 .57354 L
.74539 .62798 L
Mistroke
.70905 .67741 L
Mfstroke
.833 1 0 r
.4651 .18263 m
.52971 .17404 L
.59315 .17825 L
.65294 .19508 L
.70673 .22388 L
.7524 .26351 L
.78816 .31243 L
.81262 .36871 L
.82481 .43014 L
.82425 .49431 L
.81096 .55871 L
.78547 .6208 L
.74878 .67815 L
.70232 .72851 L
.64793 .7699 L
.58772 .8007 L
.52408 .81969 L
.45949 .82614 L
.39649 .8198 L
.33755 .8009 L
.28499 .77019 L
.24086 .72888 L
.20691 .67858 L
.18446 .62128 L
.17439 .55921 L
.1771 .49483 L
.19248 .43064 L
.21994 .36918 L
.25838 .31285 L
.30631 .26387 L
.36183 .22415 L
.42279 .19526 L
.48677 .17833 L
.55127 .17403 L
.61375 .18251 L
.67178 .20346 L
.72306 .23605 L
.76559 .27899 L
.79769 .33061 L
.81811 .38887 L
.82605 .4515 L
.82119 .51603 L
.80373 .57993 L
.77434 .6407 L
.73419 .69594 L
.68485 .74349 L
.62825 .78149 L
.56662 .80844 L
.50237 .82328 L
.43804 .82544 L
Mistroke
.37613 .81482 L
.31908 .79185 L
.26914 .75743 L
.22825 .7129 L
.19803 .66002 L
.17967 .60085 L
.17387 .53773 L
.18087 .47313 L
.2004 .40958 L
.23168 .34958 L
.2735 .29549 L
.3242 .24942 L
.38181 .21318 L
.44405 .1882 L
.50849 .17546 L
.57259 .17546 L
.63385 .18819 L
.68985 .21316 L
.73841 .24938 L
.7776 .29545 L
.8059 .34954 L
.8222 .40953 L
.82585 .47308 L
.81671 .53768 L
.79514 .6008 L
.76199 .65997 L
.71856 .71286 L
.66655 .7574 L
.608 .79183 L
.54522 .81481 L
.48066 .82544 L
.41686 .82329 L
.35632 .80845 L
.30142 .78151 L
.25432 .74353 L
.21685 .69598 L
.1905 .64074 L
.1763 .57998 L
.1748 .51608 L
.18606 .45155 L
.20964 .38892 L
.24462 .33065 L
.28962 .27903 L
.34288 .23608 L
.40231 .20348 L
.46556 .18253 L
.53017 .17403 L
.5936 .17832 L
.65335 .19525 L
.70709 .22413 L
Mistroke
.75269 .26383 L
.78838 .31281 L
.81275 .36913 L
.82485 .43059 L
.8242 .49477 L
.81082 .55916 L
.78525 .62123 L
.74848 .67854 L
.70196 .72884 L
.64751 .77016 L
.58728 .80088 L
.52362 .81979 L
.45903 .82614 L
.39605 .8197 L
.33715 .80072 L
.28464 .76993 L
.24058 .72854 L
.20671 .67819 L
.18434 .62085 L
.17436 .55876 L
.17717 .49436 L
.19264 .43019 L
.22017 .36876 L
.25869 .31247 L
.30668 .26355 L
.36226 .22391 L
.42324 .1951 L
.48723 .17826 L
.55172 .17404 L
.61419 .18262 L
.67217 .20365 L
.7234 .23632 L
.76586 .27933 L
.79788 .331 L
.81822 .38931 L
.82606 .45196 L
.82111 .51649 L
.80356 .58038 L
.77409 .64111 L
.73387 .69631 L
.68446 .7438 L
.62782 .78172 L
.56617 .80859 L
.50191 .82334 L
.43758 .82541 L
.3757 .8147 L
.3187 .79165 L
.26881 .75714 L
.228 .71255 L
.19786 .65961 L
Mistroke
.17958 .60041 L
.17387 .53727 L
.18097 .47267 L
.20058 .40914 L
.23195 .34917 L
.27383 .29513 L
.32459 .24912 L
.38224 .21296 L
.44451 .18807 L
.50895 .17542 L
.57305 .1755 L
.63427 .18832 L
.69023 .21338 L
.73872 .24968 L
.77784 .29581 L
.80606 .34995 L
.82227 .40998 L
.82583 .47354 L
.8166 .53814 L
.79495 .60124 L
.76172 .66037 L
.71822 .71321 L
.66615 .75768 L
.60757 .79204 L
.54476 .81493 L
.4802 .82547 L
.41641 .82323 L
.3559 .8083 L
.30105 .78128 L
.25401 .74322 L
.21662 .69561 L
.19036 .64033 L
.17624 .57953 L
.17483 .51562 L
.18618 .45109 L
.20985 .38849 L
.24491 .33026 L
.28998 .27869 L
.34329 .2358 L
.40275 .20329 L
.46602 .18242 L
.53064 .17401 L
.59404 .1784 L
.65376 .19541 L
.70744 .22437 L
.75298 .26415 L
.7886 .31319 L
.81288 .36956 L
.82489 .43104 L
.82415 .49524 L
Mistroke
.81068 .55962 L
Mfstroke
.963 1 0 r
.61035 .53078 m
.59933 .55287 L
.58441 .57288 L
.56618 .59003 L
.54535 .60365 L
.52274 .6132 L
.49923 .61831 L
.47576 .61877 L
.45324 .61457 L
.43256 .60588 L
.41452 .59303 L
.39983 .57653 L
.38908 .55703 L
.38268 .53529 L
.38088 .51216 L
.38376 .48856 L
.3912 .4654 L
.40292 .44361 L
.41844 .42402 L
.43716 .40742 L
.45835 .39445 L
.48117 .38563 L
.50473 .38129 L
.52811 .38161 L
.55038 .38658 L
.57068 .396 L
.5882 .4095 L
.60226 .42655 L
.61231 .44649 L
.61795 .46852 L
.61896 .49179 L
.6153 .51539 L
.60712 .53837 L
.59473 .55986 L
.57863 .57899 L
.55943 .59503 L
.53791 .60733 L
.5149 .61542 L
.4913 .61899 L
.46805 .61788 L
.44605 .61214 L
.42617 .60201 L
.40918 .58787 L
.39576 .57028 L
.38643 .54994 L
.38156 .52763 L
.38133 .50424 L
.38576 .48069 L
.39468 .45789 L
.40773 .43674 L
Mistroke
.4244 .41808 L
.44404 .40263 L
.46587 .39101 L
.48904 .38366 L
.51265 .38087 L
.53575 .38277 L
.55746 .38926 L
.57691 .4001 L
.59334 .41486 L
.6061 .43296 L
.61471 .45369 L
.61881 .47624 L
.61825 .49972 L
.61305 .52322 L
.60341 .5458 L
.58971 .56658 L
.57249 .58475 L
.55243 .5996 L
.53031 .61054 L
.507 .61713 L
.48341 .61914 L
.46048 .61646 L
.4391 .60922 L
.4201 .59768 L
.40425 .58232 L
.39215 .56372 L
.38428 .54263 L
.38096 .51986 L
.3823 .49631 L
.38827 .4729 L
.39862 .45056 L
.41295 .43016 L
.4307 .4125 L
.45116 .39828 L
.47355 .38804 L
.49697 .3822 L
.52051 .38099 L
.54324 .38444 L
.56428 .39243 L
.58279 .40464 L
.59806 .42059 L
.60948 .43966 L
.6166 .4611 L
.61914 .48407 L
.61701 .50766 L
.61029 .53094 L
.59924 .55302 L
.58429 .57301 L
.56604 .59014 L
.54519 .60373 L
Mistroke
.52257 .61325 L
.49906 .61833 L
.4756 .61876 L
.45309 .61453 L
.43242 .6058 L
.4144 .59293 L
.39974 .5764 L
.38902 .55688 L
.38265 .53513 L
.38089 .51199 L
.3838 .48839 L
.39127 .46524 L
.40301 .44346 L
.41856 .42389 L
.4373 .40731 L
.45851 .39437 L
.48134 .38558 L
.5049 .38127 L
.52827 .38163 L
.55054 .38663 L
.57081 .39608 L
.58831 .40961 L
.60235 .42668 L
.61236 .44664 L
.61797 .46869 L
.61895 .49196 L
.61526 .51555 L
.60704 .53854 L
.59463 .56 L
.5785 .57912 L
.55929 .59513 L
.53775 .6074 L
.51473 .61546 L
.49114 .61899 L
.46789 .61785 L
.4459 .61209 L
.42603 .60192 L
.40907 .58776 L
.39568 .57015 L
.38638 .54979 L
.38154 .52747 L
.38135 .50408 L
.38581 .48052 L
.39476 .45773 L
.40784 .4366 L
.42453 .41796 L
.44419 .40254 L
.46603 .39094 L
.48921 .38362 L
.51282 .38087 L
Mistroke
.53592 .3828 L
.55761 .38932 L
.57704 .40019 L
.59344 .41498 L
.60618 .4331 L
.61475 .45385 L
.61882 .47641 L
.61823 .49989 L
.61299 .52338 L
.60332 .54596 L
.5896 .56672 L
.57236 .58487 L
.55228 .59969 L
.53014 .6106 L
.50683 .61717 L
.48325 .61913 L
.46032 .61643 L
.43895 .60915 L
.41998 .59759 L
.40415 .5822 L
.39208 .56358 L
.38424 .54247 L
.38095 .51969 L
.38233 .49614 L
.38833 .47274 L
.39871 .45041 L
.41307 .43003 L
.43084 .41239 L
.45132 .39819 L
.47371 .38799 L
.49714 .38218 L
.52067 .381 L
.5434 .38448 L
.56442 .3925 L
.58292 .40474 L
.59816 .42072 L
.60954 .43981 L
.61663 .46126 L
.61914 .48423 L
.61698 .50782 L
.61022 .53111 L
.59914 .55317 L
.58417 .57315 L
.5659 .59025 L
.54503 .60382 L
.5224 .6133 L
.4989 .61835 L
.47543 .61874 L
.45293 .61448 L
.43228 .60573 L
Mistroke
.41428 .59282 L
Mfstroke
0 1 .57 r
.70602 .65979 m
.66511 .70156 L
.61772 .73542 L
.56571 .76003 L
.51113 .77445 L
.4561 .77809 L
.4028 .77081 L
.35331 .75291 L
.30958 .72509 L
.27333 .68843 L
.24597 .64437 L
.22857 .59465 L
.22184 .54121 L
.22601 .48616 L
.24095 .43165 L
.26604 .37982 L
.30032 .33271 L
.34244 .29216 L
.39074 .25977 L
.44333 .23681 L
.49814 .22418 L
.55302 .22237 L
.60583 .23146 L
.65448 .25109 L
.69707 .28049 L
.73192 .3185 L
.75767 .36363 L
.77331 .41412 L
.77823 .46797 L
.77222 .52309 L
.75553 .5773 L
.72881 .62847 L
.69311 .6746 L
.64984 .71388 L
.60068 .74477 L
.54757 .76605 L
.49259 .77689 L
.43791 .77686 L
.38566 .76596 L
.3379 .74463 L
.2965 .7137 L
.26309 .67438 L
.23897 .62822 L
.2251 .57702 L
.22202 .5228 L
.22985 .46769 L
.24828 .41385 L
.27659 .36338 L
.31367 .31828 L
.35806 .28031 L
Mistroke
.40802 .25096 L
.46159 .23139 L
.51667 .22236 L
.57109 .22422 L
.62272 .23691 L
.66954 .25992 L
.70971 .29235 L
.74164 .33294 L
.76409 .38008 L
.77618 .43192 L
.77742 .48644 L
.76778 .54149 L
.74763 .59492 L
.71777 .64461 L
.67935 .68864 L
.6339 .72525 L
.58319 .75303 L
.52921 .77088 L
.47409 .7781 L
.41999 .7744 L
.36903 .75993 L
.3232 .73526 L
.28432 .70136 L
.2539 .65956 L
.23314 .61149 L
.22285 .55905 L
.22344 .50429 L
.23488 .44937 L
.25673 .39643 L
.28812 .34755 L
.32783 .30466 L
.3743 .26943 L
.4257 .24325 L
.48002 .22715 L
.53512 .22176 L
.58884 .22729 L
.63907 .24352 L
.68385 .26981 L
.72141 .30514 L
.75029 .34812 L
.76934 .39706 L
.77782 .45003 L
.77539 .50497 L
.76216 .55972 L
.73864 .61212 L
.70575 .66012 L
.66479 .70183 L
.61736 .73563 L
.56533 .76017 L
.51073 .77451 L
Mistroke
.45571 .77807 L
.40243 .77072 L
.35298 .75275 L
.30929 .72485 L
.2731 .68813 L
.2458 .64403 L
.22849 .59428 L
.22183 .54082 L
.22608 .48576 L
.24109 .43127 L
.26626 .37946 L
.3006 .33239 L
.34277 .2919 L
.3911 .25958 L
.44372 .23669 L
.49854 .22413 L
.55341 .2224 L
.60619 .23157 L
.65481 .25127 L
.69735 .28073 L
.73214 .3188 L
.75782 .36398 L
.77339 .41449 L
.77822 .46837 L
.77214 .52348 L
.75537 .57768 L
.72859 .62882 L
.69283 .67491 L
.6495 .71413 L
.60031 .74496 L
.54718 .76616 L
.4922 .77692 L
.43752 .77682 L
.3853 .76585 L
.33758 .74444 L
.29623 .71345 L
.26288 .67407 L
.23884 .62787 L
.22504 .57664 L
.22204 .52241 L
.22994 .4673 L
.24845 .41347 L
.27682 .36304 L
.31396 .31798 L
.3584 .28007 L
.40839 .25079 L
.46198 .23128 L
.51706 .22233 L
.57147 .22427 L
.62308 .23704 L
Mistroke
.66986 .26012 L
.70997 .29262 L
.74184 .33325 L
.76422 .38043 L
.77622 .43231 L
.77739 .48684 L
.76768 .54189 L
.74745 .59529 L
.71752 .64495 L
.67905 .68893 L
.63355 .72549 L
.58281 .7532 L
.52882 .77097 L
.4737 .77811 L
.41961 .77433 L
.36868 .75979 L
.3229 .73505 L
.28407 .70109 L
.25372 .65924 L
.23303 .61113 L
.22282 .55867 L
.22348 .5039 L
.235 .44898 L
.25692 .39606 L
.28838 .34722 L
.32814 .30438 L
.37465 .26921 L
.42608 .2431 L
.48041 .22708 L
.53551 .22176 L
.58921 .22737 L
.63942 .24367 L
.68415 .27004 L
.72165 .30543 L
.75046 .34845 L
.76944 .39742 L
.77784 .45042 L
.77533 .50537 L
.76203 .5601 L
.73844 .61248 L
.70549 .66044 L
.66447 .7021 L
.617 .73584 L
.56494 .76031 L
.51033 .77458 L
.45532 .77806 L
.40206 .77063 L
.35264 .75258 L
.30901 .72462 L
.27287 .68784 L
Mistroke
.24564 .64369 L
Mfstroke
.434 0 1 r
.18255 .30462 m
.23548 .24053 L
.2988 .18662 L
.37001 .14501 L
.44632 .11733 L
.52474 .10467 L
.60219 .10752 L
.67563 .12578 L
.74217 .15873 L
.79921 .20506 L
.84451 .26298 L
.87629 .33019 L
.8933 .40407 L
.89487 .48172 L
.88095 .56008 L
.85207 .63608 L
.80938 .70675 L
.75455 .76929 L
.68973 .82128 L
.61746 .86065 L
.54058 .88586 L
.46211 .89594 L
.38512 .89047 L
.31265 .86968 L
.24752 .83439 L
.19231 .78597 L
.14917 .72632 L
.1198 .65779 L
.10535 .58308 L
.10639 .5051 L
.12288 .42692 L
.15417 .3516 L
.19903 .28212 L
.2557 .22118 L
.32196 .17119 L
.39521 .1341 L
.47257 .11137 L
.551 .10389 L
.62744 .11196 L
.69887 .13526 L
.7625 .17287 L
.81583 .22332 L
.85676 .28463 L
.88369 .35439 L
.89556 .42987 L
.89191 .5081 L
.87288 .58601 L
.83921 .66054 L
.79223 .72878 L
.73378 .78803 L
Mistroke
.66616 .83599 L
.59201 .87075 L
.51426 .89097 L
.43594 .89584 L
.36014 .88518 L
.28983 .8594 L
.22777 .81951 L
.17639 .76709 L
.13771 .70418 L
.11324 .63326 L
.10396 .55711 L
.11022 .47872 L
.13178 .40116 L
.16779 .32749 L
.21684 .26058 L
.277 .20307 L
.34591 .15721 L
.42087 .12481 L
.49893 .10713 L
.57704 .10487 L
.65212 .11812 L
.72124 .14635 L
.78167 .18846 L
.83104 .2428 L
.86743 .30724 L
.88939 .37924 L
.89607 .45598 L
.88721 .53444 L
.86315 .61156 L
.82484 .68429 L
.77378 .7498 L
.71198 .8055 L
.64185 .84921 L
.56616 .87921 L
.48788 .89434 L
.41006 .89398 L
.33578 .87817 L
.26794 .84751 L
.20921 .80322 L
.1619 .74702 L
.12785 .68113 L
.10841 .60813 L
.10433 .53089 L
.11578 .45243 L
.14232 .37585 L
.18289 .30413 L
.2359 .2401 L
.29928 .18628 L
.37054 .14476 L
.44688 .11719 L
Mistroke
.5253 .10463 L
.60273 .1076 L
.67613 .12597 L
.74262 .15901 L
.79958 .20544 L
.84479 .26343 L
.87646 .3307 L
.89336 .40462 L
.89483 .48228 L
.88079 .56064 L
.85182 .63661 L
.80903 .70723 L
.75412 .76971 L
.68923 .8216 L
.61692 .86088 L
.54002 .88599 L
.46155 .89596 L
.38458 .89038 L
.31215 .86948 L
.24709 .83408 L
.19195 .78558 L
.14891 .72586 L
.11964 .65728 L
.1053 .58252 L
.10645 .50453 L
.12305 .42636 L
.15444 .35108 L
.19939 .28165 L
.25614 .22078 L
.32246 .17087 L
.39575 .13388 L
.47313 .11126 L
.55156 .10389 L
.62797 .11207 L
.69936 .13548 L
.76292 .17319 L
.81617 .22372 L
.857 .2851 L
.88383 .35492 L
.89559 .43042 L
.89183 .50866 L
.87269 .58656 L
.83892 .66106 L
.79185 .72924 L
.73333 .78842 L
.66565 .83628 L
.59147 .87095 L
.5137 .89106 L
.43539 .89582 L
.35962 .88504 L
Mistroke
.28935 .85916 L
.22736 .81918 L
.17606 .76667 L
.13748 .7037 L
.11312 .63273 L
.10395 .55655 L
.11032 .47816 L
.13199 .40062 L
.1681 .32698 L
.21723 .26013 L
.27746 .2027 L
.34643 .15693 L
.42142 .12463 L
.4995 .10706 L
.57759 .10491 L
.65264 .11827 L
.7217 .14661 L
.78206 .18881 L
.83135 .24323 L
.86764 .30773 L
.88949 .37977 L
.89606 .45654 L
.88709 .535 L
.86293 .6121 L
.82452 .68479 L
.77337 .75023 L
.7115 .80586 L
.64133 .84947 L
.56561 .87938 L
.48731 .89439 L
.40952 .89392 L
.33527 .878 L
.26749 .84724 L
.20883 .80285 L
.1616 .74658 L
.12766 .68063 L
.10832 .60759 L
.10436 .53033 L
.11592 .45188 L
.14256 .37531 L
.18323 .30364 L
.23632 .23968 L
.29977 .18593 L
.37107 .14451 L
.44744 .11704 L
.52587 .1046 L
.60328 .10768 L
.67664 .12615 L
.74306 .1593 L
.79995 .20582 L
Mistroke
.84507 .26388 L
Mfstroke
1 .64 0 r
.42785 .45479 m
.44004 .44022 L
.45459 .42799 L
.47091 .41859 L
.48838 .41239 L
.5063 .40962 L
.52398 .4104 L
.54072 .4147 L
.55585 .42235 L
.5688 .43304 L
.57905 .44636 L
.58619 .46179 L
.58995 .47871 L
.59018 .49647 L
.58687 .51437 L
.58015 .53171 L
.57029 .5478 L
.55767 .56201 L
.54278 .5738 L
.52622 .58268 L
.50862 .58832 L
.49069 .59049 L
.47312 .58912 L
.45661 .58424 L
.4418 .57606 L
.42928 .56489 L
.41953 .55118 L
.41294 .53546 L
.40976 .51835 L
.41013 .50051 L
.41402 .48266 L
.42129 .46549 L
.43165 .44967 L
.44469 .43582 L
.4599 .4245 L
.47668 .41614 L
.49438 .41107 L
.5123 .40949 L
.52974 .41146 L
.54601 .41691 L
.56047 .42562 L
.57256 .43724 L
.58181 .45133 L
.58784 .46733 L
.59042 .48462 L
.58946 .5025 L
.58499 .52029 L
.57718 .53728 L
.56634 .55281 L
.55289 .56627 L
Mistroke
.53738 .57712 L
.52039 .58495 L
.50261 .58944 L
.48472 .59043 L
.46743 .58786 L
.45142 .58185 L
.43732 .57263 L
.42567 .56055 L
.41695 .5461 L
.41148 .52984 L
.40949 .5124 L
.41105 .49449 L
.4161 .47678 L
.42444 .45999 L
.43575 .44477 L
.44958 .43172 L
.46539 .42134 L
.48256 .41406 L
.50041 .41014 L
.51824 .40976 L
.53536 .41291 L
.5511 .41948 L
.56482 .42921 L
.576 .44172 L
.5842 .45652 L
.5891 .47303 L
.5905 .49059 L
.58834 .50852 L
.58272 .52612 L
.57386 .54269 L
.56209 .55759 L
.54789 .57022 L
.53181 .58011 L
.51448 .58684 L
.49658 .59017 L
.47881 .58996 L
.46188 .58622 L
.44644 .5791 L
.43311 .56887 L
.4224 .55594 L
.41474 .54081 L
.41042 .52408 L
.40962 .50641 L
.41236 .48848 L
.41855 .47101 L
.42793 .45468 L
.44014 .44012 L
.4547 .42791 L
.47103 .41854 L
.48851 .41236 L
Mistroke
.50643 .40962 L
.52411 .41042 L
.54083 .41475 L
.55596 .42241 L
.56888 .43313 L
.57911 .44647 L
.58623 .4619 L
.58996 .47884 L
.59017 .4966 L
.58683 .5145 L
.58009 .53183 L
.57021 .54791 L
.55757 .56211 L
.54267 .57387 L
.52609 .58273 L
.5085 .58835 L
.49056 .5905 L
.473 .58909 L
.4565 .58419 L
.44171 .57599 L
.4292 .5648 L
.41947 .55107 L
.4129 .53534 L
.40975 .51822 L
.41015 .50038 L
.41406 .48253 L
.42136 .46537 L
.43173 .44956 L
.44479 .43573 L
.46001 .42443 L
.47681 .41609 L
.49451 .41104 L
.51243 .40949 L
.52986 .41149 L
.54612 .41696 L
.56057 .42569 L
.57264 .43734 L
.58186 .45144 L
.58787 .46745 L
.59043 .48474 L
.58944 .50263 L
.58494 .52042 L
.57711 .5374 L
.56625 .55292 L
.55279 .56635 L
.53726 .57719 L
.52027 .58499 L
.50248 .58946 L
.48459 .59042 L
.46731 .58783 L
Mistroke
.45131 .5818 L
.43723 .57255 L
.4256 .56045 L
.4169 .54599 L
.41146 .52971 L
.40949 .51228 L
.41107 .49436 L
.41615 .47666 L
.42451 .45988 L
.43584 .44467 L
.44969 .43163 L
.46551 .42128 L
.48268 .41402 L
.50054 .41013 L
.51837 .40977 L
.53548 .41294 L
.5512 .41954 L
.56491 .42929 L
.57607 .44182 L
.58425 .45664 L
.58912 .47315 L
.59049 .49072 L
.58832 .50865 L
.58267 .52624 L
.57378 .5428 L
.562 .55769 L
.54778 .57031 L
.53169 .58016 L
.51435 .58688 L
.49645 .59018 L
.47869 .58995 L
.46176 .58618 L
.44634 .57903 L
.43302 .56878 L
.42233 .55583 L
.41469 .54069 L
.4104 .52396 L
.40962 .50628 L
.41239 .48836 L
.4186 .47089 L
.42801 .45456 L
.44023 .44002 L
.45481 .42783 L
.47116 .41848 L
.48864 .41232 L
.50656 .40961 L
.52423 .41044 L
.54095 .41479 L
.55606 .42248 L
.56897 .43321 L
Mistroke
.57917 .44657 L
Mfstroke
1 0 .804 r
.29132 .40931 m
.31862 .36737 L
.35304 .33064 L
.39322 .30056 L
.4376 .2783 L
.48442 .26475 L
.53185 .26043 L
.57804 .26551 L
.62116 .27979 L
.65953 .30271 L
.69163 .33338 L
.71622 .37059 L
.73232 .41288 L
.7393 .45858 L
.73689 .50591 L
.72518 .55301 L
.70464 .59803 L
.67607 .6392 L
.64058 .67491 L
.59958 .70375 L
.55467 .7246 L
.50761 .73663 L
.46026 .73938 L
.41446 .73273 L
.37202 .71695 L
.33461 .69265 L
.30368 .66079 L
.28046 .62262 L
.26586 .57964 L
.26045 .53354 L
.26443 .48612 L
.27766 .43924 L
.29962 .39475 L
.32944 .35438 L
.36596 .31974 L
.40774 .29216 L
.45313 .27275 L
.50037 .26225 L
.54759 .26109 L
.59294 .2693 L
.63465 .28656 L
.67107 .3122 L
.70078 .34521 L
.72261 .3843 L
.7357 .42793 L
.73954 .47438 L
.73398 .52184 L
.71924 .56845 L
.69589 .61236 L
.66486 .65187 L
Mistroke
.62735 .68542 L
.58485 .71169 L
.53902 .72965 L
.49165 .7386 L
.44462 .73819 L
.39975 .72842 L
.35882 .7097 L
.32344 .68274 L
.29498 .64861 L
.27456 .60865 L
.263 .56443 L
.26074 .51767 L
.26786 .47022 L
.2841 .42395 L
.30881 .38065 L
.34102 .34204 L
.37948 .30963 L
.42266 .28469 L
.46888 .2682 L
.51632 .26081 L
.56312 .2628 L
.60744 .27411 L
.64754 .29428 L
.68186 .32252 L
.70904 .35773 L
.72801 .39852 L
.73804 .4433 L
.73872 .4903 L
.73004 .53768 L
.71232 .58358 L
.68628 .6262 L
.65292 .66387 L
.61356 .69511 L
.56975 .71869 L
.5232 .73369 L
.47573 .73951 L
.42922 .73594 L
.38549 .72311 L
.34625 .70152 L
.31305 .67202 L
.28718 .63577 L
.26967 .5942 L
.26119 .54892 L
.26209 .50173 L
.27232 .45447 L
.29149 .40899 L
.31884 .36709 L
.35331 .3304 L
.39353 .30037 L
.43792 .27817 L
Mistroke
.48476 .26468 L
.53219 .26043 L
.57836 .26558 L
.62145 .27992 L
.65978 .30291 L
.69184 .33363 L
.71637 .37088 L
.7324 .41319 L
.73932 .45892 L
.73684 .50625 L
.72507 .55334 L
.70446 .59834 L
.67583 .63948 L
.6403 .67514 L
.59927 .70393 L
.55433 .72472 L
.50727 .73668 L
.45992 .73936 L
.41414 .73265 L
.37174 .7168 L
.33436 .69245 L
.30349 .66054 L
.28033 .62233 L
.26579 .57932 L
.26044 .5332 L
.26449 .48578 L
.27779 .43891 L
.29981 .39444 L
.32968 .35411 L
.36624 .31951 L
.40805 .29199 L
.45347 .27264 L
.50071 .26221 L
.54792 .26111 L
.59326 .26939 L
.63493 .28671 L
.67131 .31241 L
.70097 .34547 L
.72273 .3846 L
.73576 .42825 L
.73954 .47472 L
.73391 .52218 L
.7191 .56877 L
.6957 .61266 L
.66461 .65214 L
.62706 .68563 L
.58453 .71185 L
.53868 .72975 L
.49131 .73863 L
.44428 .73815 L
Mistroke
.39944 .72832 L
.35855 .70953 L
.32321 .68252 L
.2948 .64834 L
.27445 .60835 L
.26295 .5641 L
.26075 .51733 L
.26795 .46989 L
.28425 .42362 L
.30901 .38036 L
.34128 .34179 L
.37977 .30942 L
.42298 .28454 L
.46921 .26812 L
.51666 .26079 L
.56344 .26285 L
.60774 .27422 L
.64781 .29445 L
.68208 .32275 L
.7092 .358 L
.72812 .39883 L
.73808 .44363 L
.73869 .49064 L
.72994 .53801 L
.71216 .5839 L
.68606 .62649 L
.65266 .66412 L
.61326 .69531 L
.56942 .71883 L
.52286 .73376 L
.47539 .73952 L
.4289 .73588 L
.38519 .72298 L
.34599 .70133 L
.31283 .67178 L
.28702 .63549 L
.26957 .59388 L
.26116 .54859 L
.26213 .50139 L
.27243 .45413 L
.29166 .40868 L
.31907 .3668 L
.35358 .33016 L
.39383 .30018 L
.43825 .27805 L
.4851 .26462 L
.53253 .26043 L
.57868 .26565 L
.62175 .28006 L
.66004 .3031 L
Mistroke
.69204 .33387 L
Mfstroke
0 .283 1 r
.50524 .35938 m
.53295 .35968 L
.55936 .3655 L
.58345 .37659 L
.60426 .39253 L
.62098 .41268 L
.63295 .43626 L
.6397 .46235 L
.64097 .48991 L
.63671 .51786 L
.62708 .54512 L
.61247 .5706 L
.59344 .59332 L
.57074 .61237 L
.54527 .62701 L
.51802 .63667 L
.49007 .64096 L
.4625 .63972 L
.43641 .633 L
.41281 .62106 L
.39263 .60436 L
.37667 .58358 L
.36555 .55951 L
.3597 .5331 L
.35936 .5054 L
.36454 .47748 L
.37504 .45045 L
.39044 .42536 L
.41014 .40321 L
.43337 .38485 L
.45921 .37101 L
.48665 .36223 L
.51462 .35886 L
.54201 .36103 L
.56776 .36865 L
.59084 .38143 L
.61036 .39886 L
.62555 .42026 L
.63581 .44479 L
.64074 .47149 L
.64015 .4993 L
.63406 .52715 L
.62271 .55392 L
.60654 .57859 L
.58619 .60016 L
.56245 .61781 L
.53627 .63083 L
.50866 .63872 L
.48071 .64116 L
.45352 .63807 L
Mistroke
.42816 .62955 L
.40561 .61595 L
.38677 .5978 L
.37237 .57582 L
.36298 .55085 L
.35897 .52389 L
.36049 .496 L
.36749 .46826 L
.37969 .44176 L
.39661 .41755 L
.41759 .39658 L
.4418 .37967 L
.4683 .36747 L
.49604 .36048 L
.52393 .35897 L
.55089 .36299 L
.57585 .37239 L
.59783 .38679 L
.61598 .40564 L
.62957 .42819 L
.63808 .45356 L
.64116 .48075 L
.63871 .5087 L
.63082 .53631 L
.61779 .56249 L
.60013 .58622 L
.57855 .60656 L
.55389 .62273 L
.52711 .63407 L
.49926 .64016 L
.47145 .64074 L
.44475 .6358 L
.42023 .62553 L
.39883 .61034 L
.38141 .59081 L
.36864 .56772 L
.36102 .54197 L
.35886 .51458 L
.36224 .48661 L
.37102 .45917 L
.38487 .43333 L
.40324 .41011 L
.4254 .39041 L
.45049 .37502 L
.47752 .36453 L
.50544 .35936 L
.53314 .35971 L
.55954 .36556 L
.58361 .37669 L
.60439 .39266 L
Mistroke
.62108 .41284 L
.63301 .43644 L
.63973 .46254 L
.64096 .49011 L
.63666 .51806 L
.62699 .54531 L
.61234 .57078 L
.59329 .59347 L
.57057 .61249 L
.54508 .6271 L
.51782 .63672 L
.48987 .64097 L
.46231 .63969 L
.43623 .63293 L
.41265 .62095 L
.3925 .60423 L
.37657 .58341 L
.36549 .55932 L
.35968 .53291 L
.35938 .5052 L
.3646 .47728 L
.37513 .45026 L
.39056 .42519 L
.41029 .40306 L
.43354 .38473 L
.4594 .37093 L
.48685 .36219 L
.51482 .35885 L
.5422 .36106 L
.56793 .36872 L
.591 .38154 L
.61049 .399 L
.62564 .42043 L
.63587 .44497 L
.64076 .47168 L
.64013 .4995 L
.634 .52734 L
.62261 .55411 L
.6064 .57875 L
.58603 .6003 L
.56227 .61792 L
.53607 .63091 L
.50846 .63876 L
.48051 .64116 L
.45333 .63803 L
.42798 .62947 L
.40546 .61584 L
.38665 .59766 L
.37228 .57565 L
.36293 .55066 L
Mistroke
.35896 .52369 L
.36052 .49579 L
.36756 .46806 L
.37979 .44158 L
.39674 .41739 L
.41775 .39644 L
.44198 .37956 L
.46849 .36741 L
.49624 .36045 L
.52413 .35898 L
.55108 .36304 L
.57602 .37247 L
.59798 .38691 L
.61609 .40579 L
.62965 .42836 L
.63812 .45375 L
.64117 .48095 L
.63867 .5089 L
.63074 .5365 L
.61768 .56267 L
.59999 .58638 L
.57838 .60669 L
.5537 .62282 L
.52691 .63413 L
.49906 .64018 L
.47125 .64072 L
.44457 .63575 L
.42006 .62544 L
.39869 .61021 L
.3813 .59066 L
.36856 .56754 L
.36099 .54178 L
.35886 .51438 L
.36228 .48641 L
.37111 .45898 L
.38499 .43315 L
.40338 .40995 L
.42557 .39029 L
.45068 .37493 L
.47772 .36447 L
.50564 .35934 L
.53334 .35973 L
.55973 .36562 L
.58377 .37679 L
.60453 .39279 L
.62118 .413 L
.63308 .43662 L
.63976 .46273 L
.64095 .49031 L
.63661 .51826 L
Mistroke
.62691 .5455 L
Mfstroke
1 0 .673 r
.3173 .52386 m
.32068 .48768 L
.3311 .45199 L
.34815 .41818 L
.37116 .38759 L
.39922 .3614 L
.43124 .34065 L
.46596 .32616 L
.50201 .31849 L
.53799 .31794 L
.57247 .32454 L
.60411 .33803 L
.63166 .35787 L
.65405 .38329 L
.67039 .41329 L
.68004 .44669 L
.68263 .48218 L
.67805 .51838 L
.66648 .55385 L
.64838 .58721 L
.62446 .61715 L
.59565 .64249 L
.56308 .66223 L
.52805 .67561 L
.49191 .6821 L
.45608 .68144 L
.42198 .67366 L
.39095 .65907 L
.36419 .63823 L
.34276 .61197 L
.32751 .58131 L
.31902 .54746 L
.31764 .51175 L
.32341 .47558 L
.33611 .44036 L
.35525 .40749 L
.38007 .37825 L
.40959 .35378 L
.44266 .33506 L
.47798 .3228 L
.51417 .31751 L
.5498 .31937 L
.58347 .32832 L
.61387 .34401 L
.6398 .36583 L
.66025 .3929 L
.6744 .42418 L
.68171 .45844 L
.68189 .49433 L
.67493 .53044 L
Mistroke
.66111 .56535 L
.64096 .59771 L
.61528 .62622 L
.58507 .64978 L
.55153 .66747 L
.51597 .67858 L
.47977 .68268 L
.44438 .67962 L
.41116 .6695 L
.38143 .65273 L
.35636 .62997 L
.33692 .60211 L
.32388 .57024 L
.31776 .53561 L
.31878 .49959 L
.32692 .46358 L
.34185 .429 L
.36299 .39721 L
.38951 .36945 L
.42036 .34682 L
.45434 .33019 L
.4901 .32023 L
.52626 .31733 L
.56139 .3216 L
.59411 .33286 L
.62313 .35069 L
.64732 .37438 L
.66573 .40299 L
.67764 .43542 L
.68257 .47038 L
.68034 .5065 L
.67103 .54236 L
.65501 .57657 L
.63291 .60777 L
.60559 .63473 L
.57412 .65642 L
.53975 .67196 L
.50381 .68075 L
.46773 .68245 L
.43291 .67699 L
.40073 .66459 L
.37244 .64572 L
.34916 .62113 L
.3318 .5918 L
.32104 .55885 L
.3173 .5236 L
.32073 .48743 L
.3312 .45174 L
.34829 .41795 L
.37134 .38738 L
Mistroke
.39944 .36123 L
.43148 .34053 L
.46621 .32608 L
.50227 .31846 L
.53824 .31797 L
.57271 .32462 L
.60432 .33815 L
.63184 .35803 L
.65419 .38349 L
.67048 .41352 L
.68009 .44694 L
.68262 .48244 L
.67799 .51864 L
.66638 .5541 L
.64823 .58744 L
.62427 .61735 L
.59543 .64265 L
.56284 .66235 L
.52779 .67569 L
.49165 .68212 L
.45583 .68141 L
.42175 .67358 L
.39074 .65894 L
.36402 .63806 L
.34263 .61176 L
.32742 .58108 L
.31899 .54721 L
.31765 .51149 L
.32348 .47532 L
.33623 .44012 L
.35541 .40727 L
.38026 .37805 L
.40982 .35363 L
.44291 .33495 L
.47824 .32274 L
.51443 .31749 L
.55005 .31941 L
.5837 .32841 L
.61408 .34415 L
.63997 .366 L
.66037 .39311 L
.67448 .42442 L
.68174 .45869 L
.68187 .49459 L
.67486 .5307 L
.66098 .5656 L
.64079 .59792 L
.61508 .62641 L
.58484 .64993 L
.55128 .66757 L
Mistroke
.51571 .67863 L
.47952 .68269 L
.44413 .67957 L
.41093 .6694 L
.38123 .65259 L
.3562 .62979 L
.3368 .60189 L
.32381 .57 L
.31774 .53536 L
.31882 .49933 L
.32701 .46332 L
.34198 .42876 L
.36316 .39699 L
.38971 .36927 L
.42059 .34667 L
.45459 .3301 L
.49036 .32019 L
.52652 .31734 L
.56163 .32165 L
.59433 .33297 L
.62332 .35084 L
.64748 .37457 L
.66584 .40321 L
.6777 .43566 L
.68258 .47063 L
.6803 .50676 L
.67094 .54262 L
.65487 .5768 L
.63273 .60798 L
.60537 .63491 L
.57388 .65655 L
.53949 .67205 L
.50355 .68079 L
.46748 .68244 L
.43267 .67693 L
.40051 .66447 L
.37226 .64556 L
.34901 .62094 L
.3317 .59157 L
.32098 .55861 L
.3173 .52335 L
.32078 .48717 L
.3313 .45149 L
.34844 .41772 L
.37153 .38718 L
.39966 .36106 L
.43172 .3404 L
.46647 .326 L
.50253 .31843 L
.53849 .31799 L
Mistroke
.57295 .32469 L
Mfstroke
1 .118 0 r
.61778 .20918 m
.67032 .23106 L
.71619 .2635 L
.75357 .30522 L
.78099 .35459 L
.79739 .40966 L
.80212 .46828 L
.79499 .52814 L
.77629 .5869 L
.74674 .64225 L
.7075 .69201 L
.66013 .73424 L
.60647 .76728 L
.54863 .78983 L
.48888 .801 L
.42957 .80036 L
.37302 .78793 L
.32146 .7642 L
.2769 .73011 L
.2411 .68698 L
.21546 .63651 L
.20099 .58069 L
.19825 .5217 L
.20735 .46186 L
.22794 .40351 L
.25921 .34895 L
.29993 .30032 L
.3485 .25953 L
.40301 .22817 L
.46133 .20749 L
.52117 .19828 L
.58018 .20091 L
.63604 .21528 L
.68656 .24083 L
.72976 .27655 L
.76394 .32103 L
.78777 .37254 L
.8003 .42905 L
.80104 .48835 L
.78998 .5481 L
.76753 .60597 L
.73458 .65968 L
.69242 .70712 L
.64271 .74643 L
.5874 .77607 L
.52867 .79488 L
.4688 .80211 L
.41016 .79749 L
.35505 .78119 L
.30563 .75385 L
Mistroke
.26383 .71656 L
.2313 .67076 L
.20932 .61826 L
.19875 .56112 L
.19999 .50159 L
.21302 .44199 L
.2373 .38466 L
.2719 .33187 L
.31545 .28567 L
.36624 .24788 L
.42228 .21999 L
.48137 .20309 L
.54119 .19784 L
.59939 .20445 L
.6537 .22265 L
.70197 .25175 L
.74232 .29058 L
.77315 .33764 L
.79327 .39106 L
.80188 .44877 L
.79863 .50848 L
.78367 .56786 L
.75758 .62457 L
.72137 .6764 L
.67648 .72131 L
.62467 .75753 L
.56796 .78364 L
.50858 .79862 L
.44886 .80188 L
.39116 .79329 L
.33772 .7732 L
.29065 .74238 L
.2518 .70205 L
.22269 .65379 L
.20447 .59949 L
.19784 .54129 L
.20307 .48147 L
.21995 .42237 L
.24783 .36633 L
.2856 .31553 L
.33178 .27196 L
.38457 .23735 L
.44189 .21305 L
.50149 .20001 L
.56103 .19874 L
.61817 .20929 L
.67068 .23126 L
.71649 .26377 L
.7538 .30555 L
.78115 .35496 L
Mistroke
.79747 .41007 L
.80211 .4687 L
.7949 .52857 L
.77611 .58731 L
.74649 .64262 L
.70719 .69234 L
.65976 .73451 L
.60606 .76748 L
.5482 .78995 L
.48845 .80104 L
.42915 .80031 L
.37263 .7878 L
.32111 .76399 L
.27661 .72983 L
.24088 .68664 L
.21532 .63613 L
.20093 .58027 L
.19827 .52127 L
.20746 .46143 L
.22813 .40311 L
.25947 .34858 L
.30025 .3 L
.34887 .25927 L
.40342 .22799 L
.46176 .20738 L
.5216 .19826 L
.58059 .20097 L
.63642 .21543 L
.6869 .24105 L
.73004 .27683 L
.76415 .32138 L
.7879 .37293 L
.80035 .42947 L
.80101 .48878 L
.78985 .54853 L
.76733 .60637 L
.7343 .66004 L
.69209 .70743 L
.64233 .74668 L
.58699 .77624 L
.52824 .79497 L
.46838 .80212 L
.40975 .79741 L
.35467 .78103 L
.3053 .75362 L
.26356 .71626 L
.23111 .67041 L
.2092 .61787 L
.19871 .5607 L
.20005 .50116 L
Mistroke
.21315 .44156 L
.23752 .38427 L
.27218 .33151 L
.31579 .28537 L
.36662 .24765 L
.42269 .21983 L
.4818 .20301 L
.54162 .19784 L
.5998 .20454 L
.65407 .22283 L
.70229 .25199 L
.74257 .29089 L
.77334 .338 L
.79337 .39146 L
.80189 .44919 L
.79857 .50891 L
.78352 .56828 L
.75735 .62497 L
.72108 .67675 L
.67613 .7216 L
.62427 .75775 L
.56754 .78379 L
.50815 .79868 L
.44844 .80186 L
.39076 .79319 L
.33736 .77301 L
.29035 .74212 L
.25156 .70173 L
.22252 .65342 L
.20438 .59908 L
.19783 .54086 L
.20315 .48104 L
.22011 .42196 L
.24806 .36594 L
.2859 .31519 L
.33214 .27168 L
.38497 .23714 L
.44231 .21291 L
.50192 .19995 L
.56145 .19877 L
.61857 .20941 L
.67103 .23145 L
.71679 .26404 L
.75403 .30588 L
.78131 .35534 L
.79754 .41048 L
.8021 .46913 L
.7948 .52899 L
.77594 .58772 L
.74624 .643 L
Mistroke
.70688 .69267 L
Mfstroke
.791 0 1 r
.36485 .74298 m
.32258 .7174 L
.28728 .68328 L
.26032 .64197 L
.24277 .59509 L
.23531 .54447 L
.23824 .49211 L
.25144 .44006 L
.2744 .39037 L
.30622 .34497 L
.34563 .30566 L
.39111 .27398 L
.44086 .25116 L
.49293 .23812 L
.54528 .23535 L
.59585 .24296 L
.64266 .26067 L
.68387 .28776 L
.71787 .32319 L
.74331 .36556 L
.7592 .4132 L
.76493 .46425 L
.76025 .5167 L
.74536 .5685 L
.72084 .61761 L
.68766 .6621 L
.64711 .70023 L
.60078 .7305 L
.55051 .75173 L
.49824 .76308 L
.44605 .7641 L
.39598 .75476 L
.34998 .73542 L
.30988 .70684 L
.27723 .67014 L
.25333 .62677 L
.23911 .57842 L
.23513 .52699 L
.24155 .4745 L
.2581 .42302 L
.28415 .37455 L
.31867 .33101 L
.36031 .2941 L
.40743 .26528 L
.45818 .24566 L
.51058 .23603 L
.56256 .23675 L
.61208 .24781 L
.65721 .26876 L
.69616 .29879 L
Mistroke
.72742 .33672 L
.74975 .38105 L
.76228 .43006 L
.76452 .4818 L
.75637 .53426 L
.73816 .58538 L
.71061 .63315 L
.67479 .67569 L
.63211 .71133 L
.58425 .73869 L
.53308 .75667 L
.48061 .76458 L
.4289 .76211 L
.37999 .74935 L
.33578 .7268 L
.29802 .69536 L
.26818 .65624 L
.24744 .611 L
.23662 .5614 L
.23613 .50938 L
.246 .457 L
.26583 .40631 L
.29486 .3593 L
.33193 .3178 L
.37561 .28346 L
.42416 .25762 L
.47569 .24129 L
.52818 .23511 L
.57956 .23932 L
.62781 .25377 L
.67105 .27788 L
.70758 .31071 L
.73596 .35097 L
.75508 .39708 L
.76419 .44722 L
.76293 .49944 L
.75135 .55168 L
.72991 .60189 L
.69944 .6481 L
.66115 .6885 L
.61653 .7215 L
.56734 .74581 L
.51551 .76047 L
.46307 .76491 L
.41207 .75895 L
.36453 .74283 L
.3223 .71718 L
.28705 .68301 L
.26016 .64165 L
.24268 .59474 L
Mistroke
.23529 .5441 L
.2383 .49174 L
.25158 .4397 L
.2746 .39002 L
.30647 .34467 L
.34594 .3054 L
.39145 .27378 L
.44123 .25103 L
.49331 .23806 L
.54565 .23536 L
.5962 .24305 L
.64298 .26083 L
.68414 .28799 L
.71808 .32347 L
.74346 .36588 L
.75928 .41356 L
.76493 .46462 L
.76018 .51708 L
.74522 .56886 L
.72064 .61794 L
.68739 .6624 L
.6468 .70048 L
.60044 .73069 L
.55014 .75185 L
.49787 .76312 L
.44568 .76407 L
.39563 .75465 L
.34967 .73524 L
.30962 .7066 L
.27703 .66985 L
.2532 .62643 L
.23905 .57806 L
.23514 .52661 L
.24163 .47413 L
.25826 .42266 L
.28437 .37422 L
.31895 .33072 L
.36063 .29387 L
.40778 .2651 L
.45856 .24555 L
.51095 .23599 L
.56292 .23679 L
.61242 .24792 L
.65751 .26895 L
.69641 .29904 L
.72761 .33702 L
.74987 .38139 L
.76233 .43042 L
.76449 .48218 L
.75628 .53464 L
Mistroke
.738 .58574 L
.71038 .63347 L
.67451 .67597 L
.63179 .71156 L
.58389 .73885 L
.53271 .75676 L
.48024 .7646 L
.42854 .76205 L
.37965 .74922 L
.33548 .72661 L
.29777 .6951 L
.268 .65594 L
.24733 .61065 L
.23658 .56103 L
.23616 .50901 L
.2461 .45663 L
.26601 .40596 L
.2951 .35898 L
.33223 .31753 L
.37594 .28324 L
.42452 .25747 L
.47607 .2412 L
.52855 .2351 L
.57992 .23939 L
.62814 .25391 L
.67134 .27809 L
.70781 .31098 L
.73613 .35128 L
.75518 .39742 L
.76422 .44759 L
.76288 .49982 L
.75123 .55205 L
.72972 .60224 L
.6992 .64841 L
.66085 .68876 L
.6162 .72171 L
.56698 .74595 L
.51513 .76054 L
.46269 .76491 L
.41172 .75887 L
.36421 .74268 L
.32202 .71697 L
.28683 .68274 L
.26 .64133 L
.24259 .59438 L
.23528 .54373 L
.23836 .49136 L
.25171 .43933 L
.2748 .38968 L
.30673 .34436 L
Mistroke
.34625 .30515 L
Mfstroke
1 0 .108 r
.22914 .52689 m
.23584 .47321 L
.25291 .42059 L
.27967 .37108 L
.31508 .32663 L
.35775 .28898 L
.406 .25962 L
.45794 .23969 L
.51153 .22998 L
.56467 .23086 L
.61527 .24231 L
.66135 .26387 L
.70109 .2947 L
.73294 .33358 L
.75565 .379 L
.76833 .42916 L
.77047 .4821 L
.762 .53575 L
.74325 .588 L
.71495 .63679 L
.67822 .68021 L
.63449 .71656 L
.58548 .74441 L
.53312 .76267 L
.47946 .77062 L
.4266 .76795 L
.37663 .75476 L
.33149 .73158 L
.29297 .6993 L
.26258 .65921 L
.2415 .61286 L
.23057 .56209 L
.23021 .50888 L
.24044 .45532 L
.26086 .40352 L
.29066 .3555 L
.32868 .31315 L
.37342 .27814 L
.42313 .25183 L
.47585 .23526 L
.52953 .22909 L
.58204 .23354 L
.63134 .24845 L
.67548 .27324 L
.71273 .30692 L
.74164 .34818 L
.76106 .3954 L
.77024 .44673 L
.76881 .50014 L
.75683 .55355 L
Mistroke
.73477 .60486 L
.7035 .65205 L
.66424 .69328 L
.61853 .72692 L
.56818 .75165 L
.51515 .76651 L
.46152 .77091 L
.4094 .76468 L
.36084 .74805 L
.31774 .7217 L
.2818 .68664 L
.25441 .64426 L
.23667 .59622 L
.22926 .5444 L
.23248 .49084 L
.24619 .43763 L
.26987 .38688 L
.30257 .34056 L
.34303 .30051 L
.38965 .26828 L
.44059 .24514 L
.49387 .23201 L
.54739 .2294 L
.59905 .2374 L
.64682 .25571 L
.68883 .28361 L
.72343 .32 L
.74926 .36346 L
.76531 .41227 L
.77094 .46453 L
.76595 .51818 L
.75051 .57111 L
.72524 .62126 L
.69114 .66664 L
.64953 .70549 L
.60205 .73627 L
.55057 .75778 L
.4971 .76917 L
.44375 .77 L
.39261 .76023 L
.34568 .74025 L
.3048 .71084 L
.27159 .67315 L
.24734 .62867 L
.23301 .57914 L
.22915 .52651 L
.23593 .47283 L
.25307 .42022 L
.2799 .37074 L
.31537 .32633 L
Mistroke
.35808 .28874 L
.40636 .25944 L
.45832 .23959 L
.51192 .22995 L
.56504 .23091 L
.61562 .24243 L
.66166 .26406 L
.70135 .29495 L
.73314 .33388 L
.75578 .37934 L
.76838 .42953 L
.77045 .48249 L
.76191 .53613 L
.74308 .58836 L
.71472 .63712 L
.67793 .6805 L
.63415 .71679 L
.58512 .74457 L
.53274 .76276 L
.47907 .77064 L
.42623 .76789 L
.37628 .75463 L
.33119 .73138 L
.29273 .69904 L
.26239 .6589 L
.24139 .61251 L
.23053 .56172 L
.23025 .5085 L
.24055 .45494 L
.26104 .40316 L
.2909 .35517 L
.32898 .31287 L
.37376 .27792 L
.4235 .25168 L
.47624 .23518 L
.52991 .22908 L
.58241 .23361 L
.63167 .2486 L
.67577 .27345 L
.71297 .30719 L
.74181 .3485 L
.76116 .39576 L
.77026 .4471 L
.76876 .50053 L
.7567 .55393 L
.73458 .60521 L
.70324 .65237 L
.66393 .69355 L
.61819 .72713 L
.5678 .75179 L
Mistroke
.51476 .76658 L
.46114 .7709 L
.40904 .76459 L
.36051 .7479 L
.31746 .72148 L
.28157 .68636 L
.25425 .64393 L
.23658 .59586 L
.22925 .54402 L
.23254 .49045 L
.24633 .43726 L
.27007 .38653 L
.30284 .34025 L
.34334 .30025 L
.39 .26808 L
.44097 .24501 L
.49426 .23195 L
.54777 .22942 L
.59941 .2375 L
.64715 .25588 L
.68911 .28384 L
.72365 .32029 L
.74941 .36379 L
.76539 .41264 L
.77095 .46491 L
.76587 .51856 L
.75036 .57149 L
.72503 .6216 L
.69086 .66695 L
.64921 .70574 L
.60169 .73646 L
.55019 .7579 L
.49672 .76921 L
.44337 .76997 L
.39225 .76012 L
.34536 .74007 L
.30453 .7106 L
.27138 .67286 L
.2472 .62833 L
.23294 .57877 L
.22916 .52612 L
.23601 .47245 L
.25323 .41985 L
.28012 .3704 L
.31565 .32604 L
.35841 .2885 L
.40673 .25927 L
.4587 .23948 L
.5123 .22992 L
.56542 .23095 L
Mistroke
.61597 .24255 L
Mfstroke
1 0 .342 r
.17395 .48234 m
.19195 .41746 L
.22205 .35582 L
.26305 .29985 L
.31335 .25172 L
.37098 .21334 L
.43367 .18622 L
.49897 .1714 L
.5643 .16948 L
.62711 .18054 L
.68494 .20413 L
.7355 .23933 L
.77682 .28476 L
.80728 .33864 L
.82568 .39886 L
.8313 .46304 L
.82391 .52867 L
.80381 .59318 L
.77179 .65403 L
.72911 .70884 L
.67743 .75545 L
.61878 .79203 L
.55548 .81715 L
.49 .82983 L
.42491 .82956 L
.36277 .81636 L
.30601 .79074 L
.25687 .75371 L
.21727 .70673 L
.18876 .65163 L
.17247 .59058 L
.16904 .52598 L
.17859 .46035 L
.20076 .39628 L
.23467 .33629 L
.27899 .28271 L
.33199 .23767 L
.39158 .20292 L
.45543 .17983 L
.52103 .1693 L
.5858 .17176 L
.6472 .18709 L
.70283 .21471 L
.75049 .25352 L
.78833 .30201 L
.81485 .35827 L
.82901 .42008 L
.83026 .48504 L
.81855 .55058 L
.79434 .61414 L
Mistroke
.75858 .67322 L
.71266 .7255 L
.65841 .76893 L
.59793 .8018 L
.53361 .82283 L
.46797 .83119 L
.40359 .82656 L
.343 .8091 L
.28856 .77952 L
.24242 .73897 L
.20639 .68903 L
.18189 .63168 L
.16987 .56916 L
.1708 .50393 L
.18466 .43854 L
.21089 .37557 L
.24847 .31747 L
.29592 .26655 L
.35137 .22478 L
.41267 .19381 L
.47738 .17486 L
.54299 .16868 L
.60691 .17549 L
.66663 .19504 L
.71982 .22656 L
.76438 .26881 L
.79856 .32013 L
.82102 .37852 L
.83089 .44167 L
.82777 .50711 L
.81178 .57227 L
.78356 .63459 L
.74421 .69163 L
.69528 .74116 L
.63868 .78121 L
.57664 .81023 L
.51159 .82708 L
.44609 .83109 L
.3827 .8221 L
.32392 .80048 L
.27205 .76706 L
.22912 .72316 L
.19682 .6705 L
.17643 .61115 L
.16873 .54744 L
.17403 .48187 L
.19213 .41701 L
.2223 .3554 L
.26338 .29947 L
.31374 .25141 L
Mistroke
.37142 .21311 L
.43414 .18606 L
.49944 .17134 L
.56477 .16952 L
.62755 .18066 L
.68533 .20434 L
.73583 .23962 L
.77708 .28512 L
.80746 .33906 L
.82577 .39931 L
.83129 .46351 L
.82381 .52914 L
.80363 .59363 L
.77152 .65445 L
.72876 .7092 L
.67703 .75575 L
.61834 .79225 L
.55501 .81729 L
.48953 .82987 L
.42445 .82951 L
.36234 .81622 L
.30563 .79052 L
.25655 .75341 L
.21702 .70636 L
.1886 .65121 L
.1724 .59013 L
.16906 .52551 L
.1787 .45988 L
.20096 .39584 L
.23495 .33588 L
.27934 .28236 L
.3324 .23738 L
.39203 .20271 L
.4559 .17971 L
.5215 .16928 L
.58625 .17182 L
.64762 .18725 L
.7032 .21495 L
.7508 .25384 L
.78856 .30239 L
.815 .35869 L
.82907 .42054 L
.83023 .48551 L
.81842 .55105 L
.79412 .61458 L
.75828 .67362 L
.7123 .72584 L
.65799 .7692 L
.59748 .802 L
.53314 .82294 L
Mistroke
.4675 .83121 L
.40314 .82648 L
.34258 .80893 L
.2882 .77927 L
.24213 .73864 L
.20618 .68865 L
.18176 .63125 L
.16983 .5687 L
.17086 .50346 L
.1848 .43808 L
.21112 .37513 L
.24877 .31708 L
.29629 .26621 L
.35179 .22452 L
.41312 .19363 L
.47785 .17477 L
.54346 .16868 L
.60736 .17559 L
.66704 .19523 L
.72017 .22683 L
.76466 .26915 L
.79876 .32053 L
.82114 .37895 L
.83091 .44213 L
.8277 .50758 L
.81162 .57273 L
.78332 .63502 L
.74389 .69202 L
.6949 .74148 L
.63825 .78146 L
.57618 .8104 L
.51112 .82715 L
.44563 .83107 L
.38226 .82199 L
.32352 .80028 L
.27171 .76678 L
.22885 .72281 L
.19663 .6701 L
.17633 .61071 L
.16872 .54697 L
.17411 .4814 L
.1923 .41655 L
.22256 .35498 L
.26371 .2991 L
.31413 .2511 L
.37185 .21287 L
.4346 .18591 L
.49991 .17128 L
.56523 .16955 L
.62798 .18079 L
Mistroke
.68572 .20455 L
Mfstroke
1 .525 0 r
.40758 .64383 m
.38312 .62621 L
.36323 .60365 L
.34872 .57701 L
.34014 .54736 L
.33784 .51584 L
.3419 .48371 L
.35217 .45221 L
.36824 .42259 L
.38948 .396 L
.41505 .3735 L
.44396 .35597 L
.47507 .34408 L
.50716 .33831 L
.53897 .33889 L
.56925 .3458 L
.59681 .35875 L
.62057 .37725 L
.6396 .40057 L
.65315 .42778 L
.66069 .45783 L
.66192 .48954 L
.6568 .52166 L
.64552 .55293 L
.62854 .58212 L
.60651 .60808 L
.5803 .62981 L
.55094 .64644 L
.51957 .65732 L
.48745 .66203 L
.45581 .66038 L
.42591 .65244 L
.39891 .63851 L
.37589 .61915 L
.35773 .59511 L
.34516 .56734 L
.33866 .53693 L
.3385 .50506 L
.34467 .473 L
.35694 .442 L
.37483 .41327 L
.39763 .38795 L
.42444 .36702 L
.45422 .35132 L
.4858 .34145 L
.51793 .3378 L
.54936 .34052 L
.57886 .34949 L
.60526 .36438 L
.62752 .38458 L
Mistroke
.64479 .40932 L
.65637 .43761 L
.66181 .46836 L
.6609 .50034 L
.65368 .53231 L
.64043 .56302 L
.62167 .59125 L
.59813 .6159 L
.57074 .636 L
.54057 .65076 L
.50881 .65961 L
.47671 .66219 L
.44552 .65841 L
.41647 .64841 L
.39069 .63259 L
.36921 .61156 L
.35286 .58615 L
.34228 .55737 L
.3379 .52633 L
.33987 .49426 L
.34813 .46241 L
.36235 .43204 L
.38198 .40434 L
.40623 .38039 L
.43416 .36113 L
.46468 .34733 L
.49659 .33952 L
.52863 .338 L
.55954 .34284 L
.58812 .35385 L
.61324 .3706 L
.63391 .39243 L
.64934 .41847 L
.65889 .44772 L
.66222 .47902 L
.65917 .51114 L
.64988 .54282 L
.63471 .57283 L
.61425 .59997 L
.58931 .6232 L
.56086 .64158 L
.53002 .65441 L
.49801 .66118 L
.46607 .66163 L
.43547 .65573 L
.40739 .64372 L
.38296 .62607 L
.36311 .60347 L
.34864 .57681 L
.34011 .54714 L
Mistroke
.33785 .51561 L
.34196 .48348 L
.35226 .45199 L
.36837 .42239 L
.38965 .39583 L
.41525 .37336 L
.44418 .35586 L
.4753 .34402 L
.50739 .3383 L
.53919 .33892 L
.56945 .34587 L
.59699 .35887 L
.62072 .3774 L
.63971 .40075 L
.65322 .42799 L
.66072 .45806 L
.66191 .48977 L
.65674 .52189 L
.64542 .55314 L
.6284 .58232 L
.60633 .60826 L
.5801 .62995 L
.55072 .64654 L
.51935 .65738 L
.48722 .66204 L
.45559 .66035 L
.4257 .65236 L
.39873 .63839 L
.37574 .61899 L
.35762 .59492 L
.34509 .56713 L
.33864 .5367 L
.33852 .50483 L
.34474 .47277 L
.35705 .44178 L
.37498 .41308 L
.39781 .38778 L
.42465 .36689 L
.45444 .35122 L
.48603 .3414 L
.51816 .33779 L
.54958 .34056 L
.57906 .34958 L
.60543 .3645 L
.62767 .38474 L
.64489 .40951 L
.65643 .43783 L
.66183 .46858 L
.66087 .50057 L
.65361 .53254 L
Mistroke
.64031 .56323 L
.62151 .59144 L
.59794 .61606 L
.57053 .63612 L
.54035 .65085 L
.50858 .65965 L
.47648 .66219 L
.4453 .65836 L
.41627 .64832 L
.39052 .63245 L
.36907 .61139 L
.35276 .58596 L
.34223 .55715 L
.33789 .5261 L
.33991 .49403 L
.34821 .46219 L
.36247 .43183 L
.38213 .40415 L
.40642 .38023 L
.43438 .36101 L
.46491 .34725 L
.49682 .33948 L
.52885 .33801 L
.55976 .3429 L
.58831 .35395 L
.6134 .37074 L
.63404 .3926 L
.64943 .41867 L
.65894 .44794 L
.66222 .47925 L
.65913 .51137 L
.6498 .54305 L
.63458 .57303 L
.61409 .60015 L
.58912 .62335 L
.56065 .64169 L
.5298 .65448 L
.49778 .66121 L
.46585 .66161 L
.43526 .65567 L
.4072 .64361 L
.3828 .62592 L
.36299 .60329 L
.34855 .57661 L
.34007 .54692 L
.33786 .51538 L
.34201 .48325 L
.35236 .45177 L
.36851 .42218 L
.38981 .39565 L
Mistroke
.41545 .37321 L
Mfstroke
0 1 .17 r
.40553 .60717 m
.38844 .58896 L
.37572 .56726 L
.36788 .54292 L
.36523 .51689 L
.36786 .4902 L
.37569 .4639 L
.38839 .43901 L
.40547 .41651 L
.42626 .3973 L
.44994 .38211 L
.47559 .37155 L
.5022 .36603 L
.52872 .36577 L
.55411 .37077 L
.57738 .38085 L
.59762 .39561 L
.61402 .41446 L
.62595 .43667 L
.63293 .46136 L
.6347 .48757 L
.63118 .51427 L
.62251 .54041 L
.60904 .56496 L
.59128 .58696 L
.56994 .60555 L
.54586 .62 L
.51998 .62974 L
.49331 .63439 L
.46691 .63376 L
.4418 .62788 L
.41898 .61698 L
.39934 .6015 L
.38365 .58203 L
.37253 .55934 L
.3664 .53432 L
.36552 .50795 L
.36992 .48127 L
.37943 .45533 L
.39366 .43114 L
.41207 .40966 L
.43393 .39171 L
.45838 .37802 L
.48447 .36912 L
.51117 .36535 L
.53742 .36687 L
.56221 .37361 L
.58456 .38531 L
.60359 .40151 L
.61855 .42158 L
Mistroke
.62886 .44473 L
.63411 .47004 L
.6341 .49653 L
.62883 .52316 L
.6185 .54888 L
.60352 .57268 L
.58448 .59362 L
.56212 .6109 L
.53732 .62382 L
.51106 .63188 L
.48437 .63477 L
.45829 .63236 L
.43384 .62476 L
.41199 .61227 L
.3936 .59537 L
.37938 .57473 L
.3699 .55115 L
.36552 .52557 L
.36642 .49898 L
.37256 .47243 L
.3837 .44697 L
.39941 .42358 L
.41907 .4032 L
.4419 .38661 L
.46701 .37448 L
.49342 .36727 L
.52008 .36527 L
.54596 .36856 L
.57003 .377 L
.59136 .39028 L
.6091 .40786 L
.62255 .42905 L
.6312 .45303 L
.6347 .47886 L
.63291 .50551 L
.62591 .53195 L
.61396 .55713 L
.59755 .58007 L
.5773 .59987 L
.55402 .61575 L
.52862 .62709 L
.5021 .63344 L
.47549 .63455 L
.44985 .63038 L
.42617 .6211 L
.40539 .60706 L
.38833 .58882 L
.37565 .56709 L
.36784 .54274 L
.36523 .5167 L
Mistroke
.3679 .49001 L
.37576 .46371 L
.38849 .43884 L
.4056 .41636 L
.42642 .39717 L
.45012 .38202 L
.47578 .37149 L
.50239 .36601 L
.52891 .36578 L
.55429 .37083 L
.57754 .38094 L
.59775 .39573 L
.61412 .41461 L
.62601 .43684 L
.63296 .46154 L
.63469 .48776 L
.63113 .51446 L
.62243 .54059 L
.60892 .56513 L
.59114 .58711 L
.56978 .60567 L
.54568 .62009 L
.51979 .62979 L
.49312 .6344 L
.46672 .63373 L
.44163 .62782 L
.41883 .61689 L
.39921 .60137 L
.38355 .58187 L
.37246 .55916 L
.36638 .53413 L
.36554 .50776 L
.36997 .48108 L
.37951 .45515 L
.39378 .43098 L
.41222 .40951 L
.4341 .3916 L
.45857 .37794 L
.48466 .36907 L
.51136 .36534 L
.53761 .3669 L
.56238 .37367 L
.58471 .38541 L
.60371 .40164 L
.61864 .42174 L
.62892 .4449 L
.63413 .47023 L
.63408 .49672 L
.62877 .52335 L
.61841 .54906 L
Mistroke
.6034 .57284 L
.58433 .59376 L
.56195 .61101 L
.53714 .62389 L
.51087 .63192 L
.48418 .63477 L
.4581 .63233 L
.43367 .62469 L
.41185 .61216 L
.39348 .59523 L
.3793 .57457 L
.36985 .55097 L
.36551 .52538 L
.36644 .49879 L
.37262 .47224 L
.3838 .44679 L
.39954 .42343 L
.41922 .40307 L
.44207 .38651 L
.4672 .37441 L
.49361 .36724 L
.52027 .36527 L
.54614 .3686 L
.5702 .37708 L
.5915 .39039 L
.60921 .408 L
.62263 .42921 L
.63125 .45321 L
.63471 .47904 L
.63288 .5057 L
.62584 .53213 L
.61386 .5573 L
.59741 .58023 L
.57714 .6 L
.55384 .61585 L
.52843 .62715 L
.50191 .63346 L
.4753 .63454 L
.44967 .63033 L
.42601 .62101 L
.40526 .60694 L
.38822 .58867 L
.37557 .56693 L
.36781 .54255 L
.36523 .51651 L
.36794 .48982 L
.37583 .46353 L
.3886 .43867 L
.40574 .41621 L
.42658 .39705 L
Mistroke
.4503 .38192 L
Mfstroke
.942 0 1 r
.55516 .62833 m
.52721 .63996 L
.4982 .64609 L
.46925 .6465 L
.44151 .64115 L
.41606 .63027 L
.39391 .61427 L
.37593 .59378 L
.36281 .56962 L
.35507 .54273 L
.35303 .51415 L
.35675 .48503 L
.3661 .45649 L
.38069 .42965 L
.39998 .40558 L
.42318 .38522 L
.4494 .36935 L
.47761 .35862 L
.5067 .35343 L
.53552 .354 L
.56295 .3603 L
.58791 .37208 L
.60942 .38888 L
.62663 .41004 L
.63888 .43473 L
.64567 .46198 L
.64675 .49073 L
.64207 .51984 L
.63181 .54817 L
.61638 .57461 L
.59638 .59812 L
.5726 .61778 L
.54597 .63282 L
.51754 .64265 L
.48841 .64687 L
.45975 .64534 L
.43266 .6381 L
.40821 .62544 L
.38737 .60785 L
.37095 .58604 L
.35959 .56085 L
.35375 .53327 L
.35364 .50438 L
.35928 .47532 L
.37043 .44723 L
.38668 .42121 L
.40737 .39829 L
.4317 .37935 L
.45871 .36515 L
.48734 .35625 L
Mistroke
.51646 .35298 L
.54494 .35548 L
.57166 .36366 L
.59556 .37719 L
.61571 .39553 L
.63133 .41798 L
.64178 .44365 L
.64668 .47152 L
.64581 .50052 L
.63923 .52949 L
.62718 .55731 L
.61014 .58288 L
.58877 .60519 L
.56393 .62338 L
.53657 .63672 L
.50778 .6447 L
.47868 .647 L
.45042 .64353 L
.42411 .63443 L
.40077 .62005 L
.38133 .60096 L
.36655 .57791 L
.357 .5518 L
.35306 .52366 L
.3549 .49459 L
.36242 .46573 L
.37535 .43821 L
.39317 .41312 L
.41518 .39145 L
.44052 .37403 L
.46819 .36155 L
.49712 .35451 L
.52615 .35318 L
.55416 .35761 L
.58004 .36763 L
.60279 .38284 L
.6215 .40265 L
.63544 .42629 L
.64406 .45281 L
.64703 .48119 L
.64423 .5103 L
.63577 .53902 L
.62198 .5662 L
.60341 .59078 L
.58077 .6118 L
.55497 .62843 L
.52701 .64002 L
.49799 .64612 L
.46905 .64648 L
.44132 .64109 L
Mistroke
.41589 .63017 L
.39377 .61414 L
.37581 .59362 L
.36273 .56944 L
.35504 .54253 L
.35304 .51395 L
.3568 .48482 L
.36618 .45629 L
.38082 .42947 L
.40013 .40542 L
.42336 .38508 L
.4496 .36926 L
.47782 .35856 L
.50691 .35342 L
.53572 .35403 L
.56314 .36036 L
.58808 .37218 L
.60956 .38901 L
.62674 .4102 L
.63895 .43492 L
.6457 .46219 L
.64673 .49094 L
.64201 .52004 L
.63172 .54837 L
.61625 .57479 L
.59622 .59828 L
.57242 .61791 L
.54577 .63291 L
.51733 .6427 L
.48821 .64688 L
.45955 .64531 L
.43247 .63803 L
.40805 .62533 L
.38724 .60771 L
.37085 .58587 L
.35953 .56066 L
.35372 .53306 L
.35366 .50417 L
.35934 .47512 L
.37053 .44704 L
.38681 .42104 L
.40753 .39814 L
.43188 .37923 L
.45891 .36507 L
.48754 .3562 L
.51667 .35298 L
.54514 .35552 L
.57184 .36374 L
.59572 .3773 L
.61584 .39568 L
Mistroke
.63142 .41815 L
.64184 .44384 L
.64669 .47173 L
.64579 .50073 L
.63916 .5297 L
.62707 .5575 L
.61 .58305 L
.58861 .60534 L
.56374 .62349 L
.53637 .6368 L
.50757 .64474 L
.47848 .647 L
.45023 .64349 L
.42393 .63435 L
.40062 .61993 L
.38121 .60081 L
.36646 .57773 L
.35695 .5516 L
.35306 .52345 L
.35493 .49438 L
.3625 .46552 L
.37546 .43802 L
.39331 .41296 L
.41535 .3913 L
.44071 .37392 L
.4684 .36148 L
.49732 .35448 L
.52636 .35319 L
.55435 .35766 L
.58022 .36772 L
.60294 .38297 L
.62161 .40281 L
.63552 .42647 L
.6441 .45301 L
.64703 .4814 L
.64419 .51051 L
.63569 .53922 L
.62187 .56638 L
.60326 .59094 L
.5806 .61193 L
.55478 .62853 L
.5268 .64008 L
.49778 .64614 L
.46884 .64646 L
.44113 .64103 L
.41572 .63007 L
.39362 .614 L
.3757 .59346 L
.36266 .56925 L
.35501 .54233 L
Mistroke
.35304 .51374 L
Mfstroke
1 0 .255 r
.27544 .27135 m
.33085 .22554 L
.39291 .1905 L
.45916 .16761 L
.52702 .15776 L
.59382 .16135 L
.65693 .17822 L
.71389 .20773 L
.76245 .2487 L
.80071 .29954 L
.82717 .35824 L
.84079 .42251 L
.84104 .48982 L
.8279 .55753 L
.80189 .62298 L
.76404 .6836 L
.71582 .73702 L
.65913 .78114 L
.5962 .81422 L
.52949 .83497 L
.46162 .84258 L
.39526 .83674 L
.33301 .81768 L
.27732 .78616 L
.23036 .7434 L
.19399 .6911 L
.16962 .63129 L
.15822 .56633 L
.16024 .49877 L
.17559 .43126 L
.20367 .36644 L
.24338 .30687 L
.29316 .25487 L
.35106 .2125 L
.41481 .18141 L
.4819 .16282 L
.5497 .15747 L
.61554 .16555 L
.67686 .18677 L
.73123 .22028 L
.77653 .26476 L
.81098 .31848 L
.83322 .37932 L
.84238 .4449 L
.83811 .51264 L
.82056 .57988 L
.79044 .64399 L
.74892 .70245 L
.69763 .75296 L
.63858 .79355 L
Mistroke
.57409 .82261 L
.5067 .83901 L
.43904 .84211 L
.37378 .83179 L
.31347 .80844 L
.26048 .77298 L
.21689 .72681 L
.18441 .67175 L
.16432 .60994 L
.1574 .54381 L
.16392 .47597 L
.18364 .40907 L
.21577 .34574 L
.25906 .28846 L
.3118 .23948 L
.37193 .20073 L
.43709 .17373 L
.50471 .15953 L
.57215 .15869 L
.63676 .17124 L
.696 .1967 L
.74755 .23406 L
.78938 .28186 L
.81986 .33822 L
.83778 .40093 L
.84245 .46753 L
.83367 .5354 L
.8118 .60188 L
.7777 .66437 L
.73269 .7204 L
.67856 .76778 L
.61741 .80466 L
.55166 .82957 L
.48388 .84156 L
.41674 .84013 L
.35286 .82536 L
.29475 .79782 L
.2447 .7586 L
.20467 .70922 L
.17623 .65163 L
.1605 .58809 L
.15809 .5211 L
.1691 .45327 L
.1931 .38728 L
.22914 .32571 L
.27581 .27099 L
.33128 .22525 L
.39337 .19029 L
.45965 .16749 L
.52751 .15774 L
Mistroke
.59429 .16142 L
.65737 .17839 L
.71427 .20798 L
.76277 .24903 L
.80095 .29993 L
.82732 .35869 L
.84084 .42298 L
.84099 .4903 L
.82776 .55801 L
.80166 .62343 L
.76373 .68401 L
.71544 .73737 L
.6587 .78141 L
.59573 .81441 L
.529 .83507 L
.46114 .84258 L
.3948 .83665 L
.33259 .8175 L
.27695 .78589 L
.23006 .74306 L
.19377 .69069 L
.16949 .63084 L
.15819 .56586 L
.1603 .49828 L
.17574 .43078 L
.20391 .36599 L
.2437 .30647 L
.29355 .25453 L
.3515 .21223 L
.41528 .18123 L
.48238 .16273 L
.55018 .15748 L
.616 .16566 L
.67728 .18697 L
.73159 .22056 L
.77682 .26511 L
.81118 .31889 L
.83333 .37978 L
.8424 .44538 L
.83803 .51312 L
.82039 .58035 L
.79018 .64443 L
.74858 .70284 L
.69723 .75329 L
.63813 .7938 L
.57362 .82277 L
.50621 .83908 L
.43856 .84209 L
.37333 .83166 L
.31306 .80822 L
Mistroke
.26013 .77269 L
.21661 .72645 L
.18422 .67132 L
.16422 .60947 L
.1574 .54333 L
.16402 .47548 L
.18383 .4086 L
.21605 .3453 L
.25941 .28808 L
.31221 .23917 L
.37238 .2005 L
.43757 .17358 L
.5052 .15947 L
.57263 .15873 L
.63721 .17138 L
.6964 .19693 L
.74788 .23437 L
.78964 .28224 L
.82003 .33865 L
.83786 .4014 L
.84243 .46801 L
.83356 .53588 L
.8116 .60235 L
.77741 .66479 L
.73234 .72077 L
.67814 .76809 L
.61696 .80488 L
.55118 .82971 L
.4834 .84159 L
.41626 .84008 L
.35242 .82521 L
.29436 .79758 L
.24438 .75828 L
.20443 .70883 L
.17607 .65119 L
.16043 .58762 L
.15812 .52061 L
.16923 .45279 L
.19331 .38682 L
.22944 .3253 L
.27618 .27063 L
.3317 .22496 L
.39383 .19009 L
.46013 .16738 L
.52799 .15772 L
.59475 .1615 L
.6578 .17856 L
.71465 .20824 L
.76308 .24936 L
.80118 .30033 L
Mistroke
.82746 .35913 L
Mfstroke
1 0 .317 r
.24405 .73792 m
.20816 .68831 L
.18372 .6313 L
.17169 .56915 L
.17255 .50428 L
.18626 .43924 L
.21228 .37658 L
.24959 .31877 L
.29673 .26808 L
.35185 .22648 L
.41278 .19562 L
.47714 .1767 L
.54239 .17048 L
.60598 .17718 L
.66541 .19656 L
.71835 .22784 L
.76272 .2698 L
.79677 .3208 L
.81918 .37883 L
.82907 .44162 L
.82604 .5067 L
.81021 .57151 L
.78221 .63352 L
.74313 .69029 L
.69452 .73959 L
.63826 .77949 L
.57658 .80842 L
.5119 .82524 L
.44675 .8293 L
.38369 .82044 L
.32519 .799 L
.27355 .76582 L
.23081 .72222 L
.19862 .66989 L
.17827 .61089 L
.17054 .54755 L
.17574 .48233 L
.19366 .41781 L
.22361 .35652 L
.26441 .30086 L
.31445 .25301 L
.37178 .21485 L
.43413 .18789 L
.49907 .17318 L
.56405 .17129 L
.62652 .1823 L
.68401 .20578 L
.73429 .24081 L
.77537 .28601 L
.80565 .33961 L
Mistroke
.82393 .3995 L
.82949 .46334 L
.82213 .52862 L
.80212 .59277 L
.77026 .65328 L
.72779 .70778 L
.67638 .75412 L
.61804 .79049 L
.55508 .81546 L
.48995 .82805 L
.42522 .82776 L
.36342 .81461 L
.30698 .78911 L
.25812 .75227 L
.21875 .70553 L
.19042 .65072 L
.17424 .58999 L
.17084 .52573 L
.18036 .46047 L
.20243 .39675 L
.23617 .33709 L
.28027 .28382 L
.33299 .23903 L
.39227 .20449 L
.45577 .18155 L
.52101 .1711 L
.58543 .17356 L
.64649 .18883 L
.7018 .21631 L
.7492 .25493 L
.78681 .30317 L
.81317 .35913 L
.82724 .42062 L
.82846 .48522 L
.81679 .5504 L
.79269 .61361 L
.75711 .67236 L
.71143 .72434 L
.65746 .76752 L
.5973 .8002 L
.53333 .8211 L
.46805 .8294 L
.40402 .82476 L
.34376 .80739 L
.28963 .77795 L
.24376 .7376 L
.20794 .68792 L
.18359 .63087 L
.17165 .56869 L
.1726 .50381 L
Mistroke
.1864 .43878 L
.21251 .37615 L
.2499 .31838 L
.2971 .26774 L
.35227 .22622 L
.41324 .19544 L
.47761 .17661 L
.54286 .17048 L
.60642 .17728 L
.66581 .19674 L
.7187 .2281 L
.763 .27014 L
.79698 .3212 L
.8193 .37927 L
.82909 .44208 L
.82597 .50717 L
.81005 .57197 L
.78197 .63395 L
.74282 .69067 L
.69414 .73991 L
.63784 .77974 L
.57613 .80858 L
.51143 .82532 L
.44629 .82928 L
.38325 .82033 L
.32479 .7988 L
.27321 .76555 L
.23054 .72187 L
.19843 .66949 L
.17816 .61045 L
.17053 .54708 L
.17582 .48187 L
.19384 .41736 L
.22387 .3561 L
.26474 .30048 L
.31484 .2527 L
.37221 .21462 L
.43459 .18774 L
.49954 .17312 L
.56451 .17132 L
.62695 .18242 L
.6844 .20599 L
.73462 .2411 L
.77563 .28637 L
.80582 .34002 L
.82401 .39995 L
.82949 .4638 L
.82203 .52908 L
.80194 .59322 L
.76999 .6537 L
Mistroke
.72745 .70814 L
.67598 .75442 L
.61761 .79071 L
.55462 .81559 L
.48948 .82809 L
.42476 .82771 L
.36299 .81447 L
.3066 .78889 L
.2578 .75197 L
.21851 .70516 L
.19026 .6503 L
.17417 .58954 L
.17086 .52527 L
.18048 .46 L
.20263 .39631 L
.23645 .33668 L
.28062 .28347 L
.33339 .23875 L
.39271 .20428 L
.45624 .18142 L
.52148 .17107 L
.58588 .17362 L
.64691 .18898 L
.70217 .21655 L
.7495 .25524 L
.78704 .30354 L
.81331 .35955 L
.82729 .42107 L
.82842 .48569 L
.81666 .55087 L
.79248 .61405 L
.75681 .67276 L
.71107 .72469 L
.65704 .76779 L
.59685 .80039 L
.53286 .8212 L
.46758 .82941 L
.40357 .82468 L
.34335 .80722 L
.28927 .77769 L
.24347 .73727 L
.20773 .68754 L
.18346 .63044 L
.17161 .56823 L
.17266 .50334 L
.18655 .43832 L
.21274 .37572 L
.2502 .31799 L
.29747 .26741 L
.35269 .22596 L
Mistroke
.41369 .19526 L
Mfstroke
0 .717 1 r
.19264 .28122 m
.24978 .21901 L
.31673 .16783 L
.39088 .12969 L
.46931 .10607 L
.54894 .09792 L
.62665 .10555 L
.6994 .12866 L
.76431 .16634 L
.81886 .21712 L
.86089 .279 L
.88875 .34955 L
.90136 .42601 L
.89822 .50537 L
.87945 .58452 L
.84579 .66035 L
.79855 .72989 L
.7396 .79041 L
.67125 .83953 L
.59617 .87533 L
.51732 .89639 L
.43779 .9019 L
.36071 .89163 L
.28909 .866 L
.22574 .826 L
.17316 .77321 L
.13341 .70969 L
.10804 .63795 L
.09806 .56079 L
.10385 .48125 L
.12519 .40244 L
.16124 .32746 L
.21058 .25925 L
.27128 .20049 L
.34096 .15349 L
.41688 .12008 L
.49606 .10158 L
.5754 .09873 L
.65178 .11161 L
.7222 .13975 L
.7839 .18202 L
.83446 .23677 L
.87189 .30185 L
.89473 .3747 L
.90207 .45248 L
.89364 .53212 L
.86975 .6105 L
.83136 .68454 L
.77996 .75134 L
.71758 .80828 L
Mistroke
.64665 .85311 L
.56997 .88409 L
.49054 .9 L
.41149 .9002 L
.33591 .88471 L
.26677 .85411 L
.20678 .80961 L
.1583 .75297 L
.12323 .68639 L
.10294 .6125 L
.09824 .5342 L
.10931 .45455 L
.13571 .37669 L
.17641 .30366 L
.2298 .23835 L
.29381 .1833 L
.3659 .14068 L
.44325 .11216 L
.52284 .09886 L
.60152 .10131 L
.67623 .1194 L
.74401 .15243 L
.80222 .1991 L
.84857 .25758 L
.88124 .32558 L
.89895 .40042 L
.901 .47916 L
.88731 .55873 L
.85842 .63599 L
.81546 .70791 L
.76013 .77168 L
.69458 .82478 L
.6214 .86513 L
.54346 .89116 L
.46381 .90183 L
.38558 .89674 L
.31184 .87607 L
.24548 .84064 L
.18911 .79185 L
.14495 .7316 L
.11472 .66226 L
.09961 .58656 L
.10021 .50745 L
.1165 .42806 L
.14785 .35149 L
.19301 .28074 L
.25023 .2186 L
.31724 .16751 L
.39143 .12946 L
.46988 .10596 L
Mistroke
.54951 .09792 L
.6272 .10566 L
.69989 .12888 L
.76474 .16666 L
.81921 .21752 L
.86114 .27948 L
.8889 .35008 L
.9014 .42657 L
.89814 .50594 L
.87926 .58508 L
.84549 .66088 L
.79817 .73036 L
.73914 .7908 L
.67073 .83984 L
.59562 .87553 L
.51675 .89649 L
.43723 .90188 L
.36017 .89151 L
.2886 .86576 L
.22532 .82567 L
.17283 .77279 L
.13317 .70921 L
.10792 .63741 L
.09805 .56023 L
.10395 .48067 L
.1254 .40188 L
.16155 .32694 L
.21098 .25879 L
.27175 .20011 L
.34149 .1532 L
.41744 .11989 L
.49664 .10151 L
.57596 .09876 L
.65231 .11176 L
.72267 .14 L
.7843 .18237 L
.83477 .2372 L
.87211 .30235 L
.89483 .37525 L
.90207 .45305 L
.89352 .53269 L
.86953 .61105 L
.83104 .68505 L
.77955 .75179 L
.71709 .80864 L
.64612 .85339 L
.56941 .88426 L
.48997 .90006 L
.41093 .90015 L
.33539 .88454 L
Mistroke
.2663 .85384 L
.20639 .80925 L
.158 .75252 L
.12303 .68588 L
.10285 .61195 L
.09827 .53363 L
.10945 .45398 L
.13595 .37614 L
.17675 .30317 L
.23023 .23791 L
.2943 .18295 L
.36644 .14042 L
.44382 .11201 L
.52341 .09882 L
.60208 .10138 L
.67674 .11959 L
.74447 .15272 L
.8026 .19948 L
.84886 .25804 L
.88142 .32609 L
.89902 .40097 L
.90095 .47973 L
.88715 .55929 L
.85816 .63653 L
.81511 .7084 L
.75969 .7721 L
.69408 .82511 L
.62086 .86537 L
.54289 .89129 L
.46324 .90185 L
.38503 .89664 L
.31133 .87587 L
.24504 .84034 L
.18875 .79145 L
.14468 .73113 L
.11455 .66174 L
.09955 .586 L
.10027 .50688 L
.11668 .42749 L
.14812 .35095 L
.19338 .28026 L
.25067 .2182 L
.31775 .16719 L
.39198 .12924 L
.47045 .10585 L
.55008 .09792 L
.62774 .10577 L
.70039 .1291 L
.76517 .16698 L
.81955 .21793 L
Mistroke
.86139 .27995 L
Mfstroke
0 1 .328 r
.2792 .68313 m
.25263 .64022 L
.23577 .5918 L
.22928 .53978 L
.23341 .4862 L
.24801 .43316 L
.27249 .38274 L
.3059 .33692 L
.34694 .29751 L
.39397 .26604 L
.44517 .24375 L
.49852 .23152 L
.55193 .22983 L
.6033 .23874 L
.65062 .25791 L
.69203 .28657 L
.7259 .32361 L
.7509 .36757 L
.76606 .41674 L
.77077 .46916 L
.76486 .5228 L
.74855 .57555 L
.72249 .62533 L
.6877 .67019 L
.64554 .70837 L
.59767 .73837 L
.54597 .75902 L
.49246 .7695 L
.43925 .76941 L
.38842 .75874 L
.34197 .73792 L
.30172 .70776 L
.26926 .66945 L
.24585 .62449 L
.23241 .57464 L
.22948 .52186 L
.23716 .46822 L
.25516 .41584 L
.28277 .36675 L
.3189 .32289 L
.36214 .28599 L
.4108 .25748 L
.46295 .23849 L
.51655 .22977 L
.56951 .23165 L
.61974 .24406 L
.66527 .26652 L
.70431 .29814 L
.73533 .33768 L
.75712 .38359 L
Mistroke
.76882 .43407 L
.76997 .48714 L
.76052 .54071 L
.74085 .59269 L
.71172 .64103 L
.67429 .68383 L
.63002 .71942 L
.58064 .74639 L
.5281 .7637 L
.47445 .77066 L
.42181 .76699 L
.37224 .75285 L
.32768 .72879 L
.28989 .69574 L
.26034 .65501 L
.24019 .6082 L
.23024 .55714 L
.23088 .50384 L
.24208 .45039 L
.26341 .39889 L
.29402 .35135 L
.33271 .30965 L
.37797 .27542 L
.42801 .25 L
.48089 .2344 L
.53451 .22921 L
.58678 .23466 L
.63564 .25052 L
.67918 .27617 L
.71569 .3106 L
.74373 .35247 L
.76221 .40013 L
.77039 .4517 L
.76797 .50518 L
.75503 .55844 L
.73208 .60942 L
.70002 .6561 L
.66011 .69666 L
.61392 .72949 L
.56325 .75332 L
.51011 .76721 L
.45657 .77061 L
.40473 .7634 L
.35663 .74584 L
.31416 .71863 L
.27898 .68285 L
.25248 .63989 L
.23569 .59144 L
.22927 .5394 L
.23348 .48581 L
Mistroke
.24815 .43278 L
.2727 .38239 L
.30617 .33662 L
.34725 .29725 L
.39433 .26585 L
.44555 .24363 L
.49891 .23147 L
.55231 .22986 L
.60366 .23884 L
.65094 .25808 L
.6923 .28681 L
.72611 .3239 L
.75104 .36791 L
.76613 .4171 L
.77077 .46955 L
.76478 .52319 L
.7484 .57592 L
.72227 .62567 L
.68742 .67049 L
.64522 .70861 L
.59731 .73855 L
.54559 .75913 L
.49207 .76954 L
.43887 .76937 L
.38807 .75863 L
.34166 .73774 L
.30146 .70751 L
.26906 .66915 L
.24572 .62414 L
.23235 .57427 L
.2295 .52148 L
.23726 .46784 L
.25533 .41547 L
.283 .36642 L
.31919 .3226 L
.36248 .28575 L
.41116 .25731 L
.46333 .23839 L
.51694 .22974 L
.56988 .2317 L
.62008 .24419 L
.66557 .26671 L
.70456 .29839 L
.73552 .33799 L
.75724 .38394 L
.76887 .43445 L
.76994 .48753 L
.76042 .54109 L
.74067 .59305 L
.71148 .64136 L
Mistroke
.674 .68411 L
.62968 .71964 L
.58027 .74655 L
.52772 .76379 L
.47407 .77067 L
.42144 .76693 L
.3719 .75271 L
.32738 .72858 L
.28964 .69547 L
.26016 .6547 L
.24008 .60785 L
.23021 .55677 L
.23093 .50346 L
.2422 .45001 L
.26359 .39853 L
.29427 .35103 L
.33301 .30938 L
.37831 .2752 L
.42838 .24985 L
.48127 .23432 L
.53489 .22921 L
.58714 .23473 L
.63597 .25067 L
.67947 .27638 L
.71592 .31088 L
.7439 .35279 L
.7623 .40048 L
.77041 .45208 L
.76791 .50556 L
.7549 .55882 L
.73188 .60977 L
.69976 .65642 L
.6598 .69692 L
.61357 .7297 L
.56288 .75346 L
.50972 .76728 L
.45619 .7706 L
.40437 .76331 L
.3563 .74568 L
.31388 .71841 L
.27876 .68257 L
.25232 .63956 L
.2356 .59107 L
.22926 .53902 L
.23355 .48543 L
.24829 .43241 L
.27291 .38204 L
.30644 .33631 L
.34757 .297 L
.39468 .26565 L
Mistroke
.44593 .24351 L
Mfstroke
0 .969 1 r
.21422 .38579 m
.24962 .32841 L
.29484 .27777 L
.34812 .23585 L
.40735 .20429 L
.47023 .18434 L
.53427 .17678 L
.59696 .18191 L
.65586 .19951 L
.70863 .22892 L
.75322 .26895 L
.78786 .31806 L
.81122 .37431 L
.82235 .43549 L
.82084 .4992 L
.80673 .56294 L
.78059 .62422 L
.74343 .68062 L
.69672 .72993 L
.64229 .77021 L
.58228 .79989 L
.51904 .8178 L
.45505 .82324 L
.39282 .816 L
.3348 .79635 L
.28326 .76507 L
.24023 .72339 L
.2074 .67294 L
.18604 .6157 L
.17701 .55393 L
.18066 .49003 L
.19684 .42653 L
.22491 .36591 L
.26378 .31056 L
.31193 .26263 L
.36745 .22403 L
.42818 .19625 L
.49172 .1804 L
.55559 .17709 L
.61728 .18645 L
.67436 .20812 L
.72461 .24124 L
.76603 .28452 L
.79702 .33625 L
.81635 .39441 L
.82326 .45672 L
.81749 .52072 L
.79926 .58391 L
.76928 .64381 L
.72873 .69806 L
Mistroke
.67921 .74454 L
.62266 .78143 L
.56129 .80726 L
.49751 .82104 L
.43383 .82222 L
.37275 .81075 L
.31667 .78709 L
.26778 .75216 L
.228 .70734 L
.1989 .65437 L
.18161 .59535 L
.17682 .53259 L
.18471 .46854 L
.20498 .40574 L
.23683 .34663 L
.279 .29354 L
.32985 .24855 L
.38737 .21343 L
.44932 .18956 L
.51325 .17787 L
.57667 .17883 L
.63707 .19239 L
.6921 .21802 L
.73959 .25471 L
.77767 .30104 L
.80486 .35517 L
.82008 .41499 L
.82274 .47814 L
.81273 .54215 L
.79045 .60451 L
.75678 .66276 L
.71302 .71463 L
.6609 .75808 L
.60247 .79139 L
.54002 .81327 L
.476 .82286 L
.41292 .81977 L
.35325 .80413 L
.29935 .77656 L
.25332 .73814 L
.21697 .69037 L
.19173 .63512 L
.17859 .57458 L
.17806 .5111 L
.19017 .4472 L
.21443 .38536 L
.24991 .32802 L
.2952 .27744 L
.34852 .23558 L
.40779 .20411 L
Mistroke
.47068 .18425 L
.53473 .17677 L
.5974 .18199 L
.65626 .19968 L
.70898 .22917 L
.7535 .26928 L
.78807 .31844 L
.81134 .37473 L
.82239 .43594 L
.82078 .49966 L
.80659 .5634 L
.78036 .62464 L
.74313 .681 L
.69636 .73025 L
.64188 .77046 L
.58184 .80006 L
.51858 .81789 L
.45459 .82324 L
.39239 .8159 L
.3344 .79616 L
.28292 .76481 L
.23996 .72305 L
.2072 .67255 L
.18593 .61527 L
.17699 .55347 L
.18073 .48957 L
.197 .42608 L
.22515 .36549 L
.2641 .31018 L
.3123 .26232 L
.36787 .22379 L
.42863 .1961 L
.49218 .18033 L
.55604 .17711 L
.61771 .18656 L
.67475 .20832 L
.72494 .24152 L
.76629 .28486 L
.7972 .33665 L
.81644 .39485 L
.82327 .45718 L
.8174 .52118 L
.79908 .58436 L
.76903 .64422 L
.72841 .69843 L
.67883 .74484 L
.62223 .78165 L
.56083 .80741 L
.49705 .8211 L
.43338 .82218 L
Mistroke
.37233 .81063 L
.31629 .78688 L
.26746 .75187 L
.22775 .70698 L
.19873 .65397 L
.18153 .59491 L
.17683 .53213 L
.18482 .46809 L
.20517 .4053 L
.23709 .34622 L
.27934 .29318 L
.33024 .24826 L
.3878 .21322 L
.44977 .18943 L
.51371 .17783 L
.57711 .17888 L
.63749 .19253 L
.69247 .21824 L
.73989 .25501 L
.7779 .3014 L
.80501 .35558 L
.82014 .41543 L
.82271 .4786 L
.81262 .54261 L
.79025 .60494 L
.7565 .66316 L
.71267 .71498 L
.6605 .75835 L
.60204 .79159 L
.53956 .81338 L
.47554 .82288 L
.41247 .8197 L
.35284 .80398 L
.29899 .77632 L
.25302 .73783 L
.21675 .68999 L
.19159 .6347 L
.17854 .57413 L
.1781 .51065 L
.1903 .44674 L
.21465 .38493 L
.2502 .32763 L
.29555 .2771 L
.34893 .23532 L
.40824 .20392 L
.47114 .18415 L
.53518 .17677 L
.59784 .18207 L
.65666 .19986 L
.70933 .22942 L
Mistroke
.75379 .2696 L
Mfstroke
.745 0 1 r
.4447 .48438 m
.45026 .47331 L
.45778 .46329 L
.46695 .45471 L
.47742 .44791 L
.48877 .44315 L
.50057 .44062 L
.51234 .44042 L
.52363 .44256 L
.53399 .44696 L
.54302 .45344 L
.55036 .46174 L
.55572 .47155 L
.5589 .48247 L
.55976 .49408 L
.55828 .50592 L
.55451 .51753 L
.54861 .52845 L
.54079 .53826 L
.53137 .54656 L
.52073 .55304 L
.50927 .55744 L
.49744 .55958 L
.48572 .55938 L
.47456 .55685 L
.46439 .55209 L
.45562 .54529 L
.4486 .53671 L
.44359 .52669 L
.4408 .51562 L
.44032 .50394 L
.4422 .4921 L
.44634 .48057 L
.45258 .46981 L
.46069 .46023 L
.47034 .45221 L
.48115 .44607 L
.4927 .44204 L
.50454 .44029 L
.51621 .44088 L
.52723 .44379 L
.53719 .44891 L
.54568 .45603 L
.55239 .46488 L
.55704 .47511 L
.55945 .48631 L
.55952 .49805 L
.55726 .50987 L
.55276 .5213 L
.54618 .53189 L
Mistroke
.53779 .54123 L
.52792 .54896 L
.51695 .55476 L
.50532 .55841 L
.49347 .55977 L
.48189 .55879 L
.47101 .5555 L
.46127 .55003 L
.45306 .54259 L
.44668 .53349 L
.4424 .52307 L
.44038 .51174 L
.44069 .49996 L
.44334 .48817 L
.44821 .47685 L
.45511 .46644 L
.46377 .45735 L
.47386 .44993 L
.48497 .44447 L
.49667 .4412 L
.5085 .44023 L
.52 .44161 L
.53071 .44528 L
.54022 .45109 L
.54815 .45883 L
.55419 .46818 L
.5581 .47878 L
.55974 .49022 L
.55902 .50203 L
.556 .51377 L
.55077 .52497 L
.54355 .53519 L
.53462 .54402 L
.52434 .55113 L
.5131 .55623 L
.50134 .55913 L
.48953 .5597 L
.47813 .55794 L
.4676 .55389 L
.45833 .54774 L
.4507 .5397 L
.445 .53012 L
.44146 .51934 L
.44022 .50781 L
.44133 .49598 L
.44473 .4843 L
.45031 .47324 L
.45784 .46322 L
.46702 .45465 L
.47749 .44786 L
Mistroke
.48885 .44312 L
.50065 .44061 L
.51242 .44043 L
.52371 .44259 L
.53406 .447 L
.54308 .45349 L
.5504 .46181 L
.55575 .47162 L
.55891 .48255 L
.55976 .49416 L
.55826 .50601 L
.55448 .51761 L
.54856 .52853 L
.54073 .53833 L
.5313 .54662 L
.52065 .55308 L
.50918 .55746 L
.49736 .55958 L
.48564 .55937 L
.47448 .55683 L
.46432 .55205 L
.45557 .54523 L
.44856 .53664 L
.44356 .52661 L
.44078 .51554 L
.44033 .50385 L
.44222 .49202 L
.44637 .48049 L
.45263 .46974 L
.46075 .46017 L
.47041 .45216 L
.48123 .44603 L
.49279 .44202 L
.50463 .44029 L
.51629 .4409 L
.52731 .44382 L
.53725 .44896 L
.54574 .45609 L
.55243 .46495 L
.55706 .47519 L
.55946 .48639 L
.55952 .49814 L
.55724 .50995 L
.55272 .52138 L
.54613 .53196 L
.53772 .5413 L
.52784 .54901 L
.51687 .55479 L
.50523 .55843 L
.49339 .55977 L
Mistroke
.48181 .55877 L
.47094 .55546 L
.46121 .54998 L
.453 .54253 L
.44664 .53342 L
.44238 .52299 L
.44037 .51166 L
.4407 .49987 L
.44337 .48809 L
.44825 .47678 L
.45517 .46637 L
.46384 .45729 L
.47393 .44988 L
.48505 .44444 L
.49676 .44118 L
.50859 .44023 L
.52008 .44162 L
.53079 .44531 L
.54028 .45114 L
.5482 .45889 L
.55423 .46825 L
.55812 .47886 L
.55974 .4903 L
.55901 .50212 L
.55597 .51385 L
.55072 .52505 L
.54349 .53526 L
.53455 .54408 L
.52426 .55118 L
.51301 .55626 L
.50126 .55914 L
.48945 .5597 L
.47806 .55791 L
.46752 .55386 L
.45827 .54768 L
.45065 .53964 L
.44497 .53004 L
.44144 .51926 L
.44022 .50773 L
.44134 .49589 L
.44477 .48422 L
.45036 .47316 L
.4579 .46316 L
.46709 .4546 L
.47757 .44782 L
.48894 .4431 L
.50074 .4406 L
.51251 .44044 L
.52378 .44261 L
.53413 .44704 L
Mistroke
.54313 .45354 L
Mfstroke
0 .388 1 r
.64243 .57269 m
.62165 .60136 L
.5961 .62606 L
.56678 .64581 L
.53484 .65984 L
.50153 .6676 L
.46816 .66878 L
.43605 .66333 L
.40644 .65148 L
.3805 .63368 L
.35925 .61063 L
.34353 .58324 L
.33395 .55259 L
.33088 .51987 L
.33445 .48637 L
.34452 .4534 L
.36069 .42227 L
.38233 .39418 L
.40858 .37025 L
.43843 .35141 L
.47069 .3384 L
.5041 .33174 L
.53735 .33168 L
.56913 .33822 L
.5982 .35111 L
.62342 .36985 L
.64379 .39369 L
.65852 .42171 L
.66703 .4528 L
.66898 .48574 L
.6643 .51924 L
.65318 .55198 L
.63604 .58269 L
.61356 .61015 L
.58663 .63329 L
.55629 .6512 L
.52375 .66317 L
.49027 .66874 L
.45718 .66768 L
.42576 .66005 L
.39727 .64613 L
.3728 .62648 L
.35332 .60187 L
.3396 .57326 L
.33218 .54177 L
.33134 .50864 L
.33712 .47518 L
.3493 .44268 L
.36738 .41244 L
.39068 .38564 L
Mistroke
.41826 .36332 L
.44905 .34636 L
.48184 .33544 L
.51535 .33098 L
.54825 .33314 L
.57925 .34186 L
.60715 .35678 L
.63084 .37733 L
.6494 .40268 L
.66209 .43186 L
.66843 .46371 L
.66815 .49699 L
.66127 .53038 L
.64807 .56258 L
.62905 .59233 L
.60497 .61845 L
.57676 .63992 L
.54555 .6559 L
.51255 .66577 L
.47905 .66913 L
.44638 .66585 L
.41581 .65606 L
.38855 .64014 L
.36566 .61873 L
.34804 .59266 L
.33639 .56295 L
.33116 .53077 L
.33255 .49738 L
.34051 .46409 L
.35474 .43222 L
.37466 .403 L
.39951 .3776 L
.4283 .35699 L
.4599 .342 L
.49308 .33321 L
.52652 .33096 L
.55893 .33535 L
.58902 .3462 L
.61562 .36309 L
.63769 .38535 L
.65435 .41211 L
.66495 .44232 L
.66908 .47479 L
.66657 .50825 L
.65752 .54139 L
.6423 .5729 L
.62148 .60156 L
.59591 .62622 L
.56656 .64594 L
.53461 .65992 L
Mistroke
.50129 .66763 L
.46793 .66876 L
.43582 .66327 L
.40624 .65137 L
.38033 .63353 L
.35912 .61045 L
.34344 .58303 L
.3339 .55236 L
.33088 .51963 L
.3345 .48613 L
.34461 .45317 L
.36083 .42206 L
.3825 .394 L
.40879 .3701 L
.43865 .3513 L
.47093 .33833 L
.50434 .33171 L
.53758 .3317 L
.56935 .33829 L
.5984 .35123 L
.62358 .37 L
.64392 .39388 L
.65861 .42192 L
.66707 .45303 L
.66897 .48598 L
.66425 .51948 L
.65308 .55221 L
.6359 .5829 L
.61338 .61033 L
.58642 .63344 L
.55606 .6513 L
.52351 .66323 L
.49003 .66875 L
.45695 .66765 L
.42555 .65997 L
.39707 .64601 L
.37264 .62632 L
.3532 .60168 L
.33953 .57304 L
.33215 .54154 L
.33136 .5084 L
.33719 .47494 L
.3494 .44246 L
.36753 .41224 L
.39086 .38546 L
.41847 .36318 L
.44928 .34626 L
.48208 .33539 L
.51559 .33097 L
.54848 .33318 L
Mistroke
.57947 .34194 L
.60734 .35691 L
.631 .37749 L
.64951 .40288 L
.66216 .43208 L
.66845 .46395 L
.66812 .49723 L
.6612 .53062 L
.64795 .56281 L
.62889 .59253 L
.60478 .61862 L
.57655 .64006 L
.54532 .656 L
.51231 .66582 L
.47882 .66913 L
.44615 .6658 L
.41561 .65596 L
.38837 .64001 L
.36551 .61856 L
.34794 .59245 L
.33633 .56272 L
.33114 .53053 L
.33258 .49714 L
.34059 .46386 L
.35486 .432 L
.37483 .40281 L
.3997 .37743 L
.42852 .35686 L
.46013 .34191 L
.49332 .33317 L
.52676 .33097 L
.55916 .33541 L
.58923 .3463 L
.6158 .36323 L
.63783 .38552 L
.65444 .41231 L
.665 .44254 L
.66908 .47503 L
.66653 .50849 L
.65744 .54162 L
.64217 .57312 L
.62132 .60175 L
.59571 .62638 L
.56634 .64606 L
.53437 .66 L
.50105 .66766 L
.46769 .66875 L
.4356 .66321 L
.40604 .65126 L
.38016 .63338 L
Mistroke
.35899 .61027 L
Mfstroke
1 0 .738 r
.34511 .2836 m
.39499 .2517 L
.44899 .22954 L
.505 .218 L
.56081 .21752 L
.61423 .22813 L
.66317 .24941 L
.70571 .28052 L
.74017 .32025 L
.7652 .36703 L
.77983 .41903 L
.78348 .47421 L
.776 .5304 L
.75769 .5854 L
.72927 .63704 L
.69184 .68331 L
.64689 .72238 L
.59618 .75273 L
.54169 .77316 L
.48556 .78286 L
.43 .78147 L
.37719 .76903 L
.32919 .74603 L
.28791 .71337 L
.25494 .67234 L
.23159 .62455 L
.21878 .57187 L
.217 .51637 L
.22633 .46023 L
.2464 .40564 L
.27642 .35476 L
.31522 .30958 L
.36127 .27188 L
.41276 .24312 L
.46768 .22445 L
.52387 .21659 L
.57912 .21986 L
.63126 .23412 L
.67825 .25881 L
.71825 .29297 L
.74968 .33525 L
.77131 .384 L
.7823 .43731 L
.7822 .49307 L
.77103 .54911 L
.74923 .60321 L
.71764 .65327 L
.67751 .69731 L
.63041 .73361 L
.5782 .76074 L
Mistroke
.52292 .77764 L
.46673 .78364 L
.41186 .77851 L
.36044 .76245 L
.3145 .73609 L
.27584 .70046 L
.24598 .65696 L
.22608 .60731 L
.21694 .55345 L
.2189 .49748 L
.2319 .44162 L
.25542 .38805 L
.28854 .33887 L
.32996 .29601 L
.37805 .26116 L
.43092 .23569 L
.48651 .22058 L
.54263 .21645 L
.59707 .22344 L
.64771 .24128 L
.69254 .26928 L
.72983 .30634 L
.75809 .35099 L
.77622 .40149 L
.78351 .45586 L
.77968 .51196 L
.76487 .56759 L
.73966 .62057 L
.70505 .66882 L
.66239 .71044 L
.61336 .7438 L
.55988 .7676 L
.50405 .78089 L
.44806 .78316 L
.39411 .77431 L
.34431 .7547 L
.30063 .7251 L
.26477 .68666 L
.23814 .64089 L
.22179 .58959 L
.21635 .53478 L
.22205 .47861 L
.23866 .42327 L
.26553 .37094 L
.30159 .32368 L
.34545 .28334 L
.39536 .25151 L
.44939 .22942 L
.5054 .21795 L
.5612 .21756 L
Mistroke
.6146 .22824 L
.6635 .2496 L
.70598 .28078 L
.74038 .32056 L
.76535 .36739 L
.7799 .41942 L
.78347 .47461 L
.77591 .5308 L
.75752 .58578 L
.72903 .6374 L
.69155 .68362 L
.64655 .72263 L
.5958 .75291 L
.54129 .77326 L
.48516 .78289 L
.42961 .78142 L
.37682 .7689 L
.32887 .74583 L
.28764 .71311 L
.25474 .67202 L
.23146 .62419 L
.21873 .57148 L
.21703 .51597 L
.22644 .45983 L
.24658 .40526 L
.27667 .35442 L
.31553 .30928 L
.36162 .27164 L
.41315 .24295 L
.46808 .22436 L
.52427 .21658 L
.5795 .21992 L
.63162 .23426 L
.67857 .25902 L
.71851 .29325 L
.74987 .33558 L
.77143 .38437 L
.78234 .4377 L
.78216 .49347 L
.77092 .5495 L
.74904 .60359 L
.71738 .65361 L
.6772 .6976 L
.63006 .73384 L
.57781 .7609 L
.52251 .77772 L
.46633 .78364 L
.41147 .77843 L
.36009 .76229 L
.31419 .73586 L
Mistroke
.27559 .70017 L
.2458 .65663 L
.22598 .60694 L
.21691 .55305 L
.21896 .49708 L
.23203 .44122 L
.25563 .38767 L
.28881 .33853 L
.33028 .29573 L
.37841 .26094 L
.43131 .23554 L
.48691 .22051 L
.54303 .21646 L
.59745 .22353 L
.64805 .24145 L
.69284 .26952 L
.73006 .30663 L
.75825 .35133 L
.77631 .40187 L
.78352 .45626 L
.77961 .51236 L
.76472 .56798 L
.73944 .62094 L
.70477 .66914 L
.66206 .71071 L
.61299 .74401 L
.55948 .76773 L
.50364 .78094 L
.44766 .78313 L
.39373 .77421 L
.34397 .75452 L
.30034 .72485 L
.26454 .68635 L
.23798 .64054 L
.22171 .58921 L
.21636 .53438 L
.22213 .4782 L
.23882 .42288 L
.26575 .37059 L
.30188 .32337 L
.34578 .28308 L
.39574 .25131 L
.44979 .2293 L
.5058 .21791 L
.56159 .21759 L
.61497 .22836 L
.66383 .24979 L
.70626 .28103 L
.7406 .32087 L
.76549 .36774 L
Mistroke
.77996 .4198 L
Mfstroke
1 .773 0 r
.39825 .2915 m
.4442 .2702 L
.49234 .25792 L
.54078 .25513 L
.58762 .26196 L
.63102 .27813 L
.66928 .303 L
.7009 .33561 L
.72463 .37467 L
.73954 .41865 L
.74506 .46582 L
.74095 .51433 L
.72739 .56228 L
.70491 .60779 L
.67438 .64906 L
.63701 .68449 L
.59427 .71267 L
.54782 .73251 L
.4995 .74322 L
.45119 .74439 L
.4048 .73597 L
.36215 .71828 L
.32491 .69203 L
.29454 .65825 L
.27223 .61825 L
.25886 .57361 L
.25496 .52608 L
.26067 .47753 L
.27578 .42986 L
.29968 .38494 L
.33145 .34454 L
.36983 .31024 L
.41332 .28339 L
.46021 .26504 L
.50866 .25591 L
.55678 .25636 L
.60266 .26637 L
.64452 .28555 L
.6807 .31315 L
.7098 .34807 L
.73065 .38897 L
.74246 .43422 L
.74475 .48205 L
.73744 .53058 L
.7208 .57792 L
.6955 .6222 L
.66253 .66168 L
.62318 .69482 L
.579 .72031 L
.53171 .73715 L
Mistroke
.48318 .74469 L
.43531 .74262 L
.38998 .73104 L
.34897 .71038 L
.31388 .68147 L
.2861 .64544 L
.26671 .60369 L
.25648 .55788 L
.25581 .5098 L
.26472 .46133 L
.28286 .41438 L
.30953 .37079 L
.34367 .33228 L
.38394 .30034 L
.42877 .27624 L
.4764 .26092 L
.52495 .25498 L
.57252 .25866 L
.61725 .27182 L
.65738 .29392 L
.69132 .32412 L
.71776 .36121 L
.73566 .40376 L
.7443 .45008 L
.74336 .49836 L
.73287 .5467 L
.71323 .59322 L
.68523 .63607 L
.64996 .67358 L
.60881 .70428 L
.56338 .72697 L
.51546 .74074 L
.46694 .74507 L
.41972 .73978 L
.37565 .72508 L
.33646 .70155 L
.30368 .6701 L
.27861 .63198 L
.26223 .58868 L
.25518 .5419 L
.25774 .49348 L
.26981 .44531 L
.29091 .39929 L
.32021 .35722 L
.35658 .32075 L
.39857 .29132 L
.44454 .27008 L
.49269 .25786 L
.54113 .25515 L
.58795 .26204 L
Mistroke
.63132 .27827 L
.66953 .30321 L
.7011 .33587 L
.72477 .37497 L
.73962 .41898 L
.74506 .46616 L
.74089 .51468 L
.72726 .56262 L
.70472 .6081 L
.67414 .64934 L
.63672 .68472 L
.59394 .71284 L
.54748 .73262 L
.49915 .74327 L
.45085 .74436 L
.40448 .73587 L
.36186 .71812 L
.32467 .69182 L
.29435 .65798 L
.2721 .61794 L
.2588 .57328 L
.25497 .52573 L
.26075 .47718 L
.27592 .42953 L
.29988 .38464 L
.3317 .34427 L
.37012 .31002 L
.41365 .28323 L
.46056 .26494 L
.50901 .25588 L
.55712 .2564 L
.60298 .26647 L
.6448 .28572 L
.68094 .31337 L
.70998 .34835 L
.73077 .38928 L
.74251 .43455 L
.74473 .4824 L
.73735 .53093 L
.72065 .57825 L
.69529 .6225 L
.66227 .66194 L
.62288 .69503 L
.57867 .72046 L
.53137 .73724 L
.48284 .74471 L
.43498 .74257 L
.38967 .73092 L
.34869 .7102 L
.31366 .68124 L
Mistroke
.28593 .64516 L
.26661 .60338 L
.25644 .55755 L
.25584 .50945 L
.26482 .46099 L
.28302 .41406 L
.30975 .3705 L
.34393 .33202 L
.38425 .30014 L
.42911 .2761 L
.47675 .26084 L
.5253 .25498 L
.57286 .25872 L
.61756 .27194 L
.65764 .29411 L
.69154 .32436 L
.71792 .3615 L
.73575 .40408 L
.74433 .45042 L
.74332 .49871 L
.73276 .54705 L
.71306 .59354 L
.685 .63636 L
.64969 .67383 L
.60849 .70448 L
.56304 .7271 L
.51512 .74081 L
.4666 .74507 L
.41939 .73971 L
.37535 .72494 L
.3362 .70135 L
.30347 .66985 L
.27846 .63169 L
.26215 .58836 L
.25517 .54156 L
.25779 .49313 L
.26993 .44497 L
.29109 .39897 L
.32045 .35693 L
.35686 .32051 L
.39889 .29114 L
.44488 .26996 L
.49304 .25781 L
.54147 .25516 L
.58827 .26212 L
.63161 .27842 L
.66978 .30342 L
.7013 .33613 L
.72491 .37527 L
.73969 .4193 L
Mistroke
.74507 .46651 L
Mfstroke
1 0 .527 r
.31425 .81783 m
.25936 .78258 L
.21391 .73624 L
.17969 .68063 L
.15804 .61793 L
.14981 .5506 L
.15533 .48129 L
.17437 .4127 L
.20619 .34755 L
.24954 .28838 L
.30273 .23751 L
.36365 .19695 L
.42993 .16828 L
.49895 .15262 L
.56802 .1506 L
.63442 .1623 L
.69554 .18724 L
.74899 .22446 L
.79266 .2725 L
.82485 .32946 L
.84429 .39312 L
.85022 .46097 L
.84241 .53035 L
.82115 .59854 L
.7873 .66287 L
.74216 .7208 L
.68753 .77007 L
.62553 .80873 L
.55861 .83528 L
.48938 .84868 L
.42058 .84838 L
.35489 .83442 L
.29489 .80733 L
.24295 .76818 L
.20109 .71851 L
.17097 .66025 L
.15375 .59571 L
.15013 .52742 L
.16024 .45804 L
.18368 .39032 L
.21954 .3269 L
.2664 .27027 L
.32243 .22266 L
.38543 .18593 L
.45293 .16153 L
.52227 .15041 L
.59074 .15301 L
.65565 .16923 L
.71445 .19843 L
.76483 .23947 L
Mistroke
.80482 .29073 L
.83285 .35021 L
.84781 .41556 L
.84913 .48423 L
.83674 .55351 L
.81114 .6207 L
.77332 .68315 L
.72478 .73841 L
.66742 .78431 L
.60348 .81906 L
.53549 .84128 L
.4661 .85012 L
.39804 .84521 L
.33399 .82675 L
.27645 .79547 L
.22768 .75259 L
.1896 .6998 L
.1637 .63917 L
.151 .57307 L
.152 .50411 L
.16666 .43499 L
.19439 .36842 L
.23412 .30701 L
.28429 .25318 L
.34292 .20903 L
.40772 .1763 L
.47613 .15628 L
.54549 .14975 L
.61306 .15696 L
.67619 .17764 L
.73241 .21096 L
.7795 .25563 L
.81563 .30989 L
.83937 .37162 L
.84979 .43838 L
.84648 .50755 L
.82958 .57644 L
.79974 .64232 L
.75814 .70262 L
.7064 .75496 L
.64657 .7973 L
.58098 .82797 L
.51221 .84577 L
.44297 .85 L
.37596 .84049 L
.31383 .81762 L
.25899 .78229 L
.21362 .73588 L
.17949 .6802 L
.15793 .61746 L
Mistroke
.1498 .55011 L
.15542 .48079 L
.17455 .41222 L
.20646 .3471 L
.24989 .28798 L
.30314 .23718 L
.36411 .1967 L
.43041 .16812 L
.49945 .15256 L
.56851 .15064 L
.63488 .16243 L
.69595 .18747 L
.74934 .22477 L
.79294 .27288 L
.82504 .3299 L
.84439 .39359 L
.85022 .46146 L
.8423 .53085 L
.82095 .59902 L
.78701 .66331 L
.7418 .72119 L
.68711 .77038 L
.62506 .80897 L
.55812 .83543 L
.48889 .84872 L
.42009 .84833 L
.35443 .83427 L
.29449 .80709 L
.24261 .76786 L
.20083 .71812 L
.1708 .65981 L
.15368 .59523 L
.15015 .52692 L
.16036 .45755 L
.18389 .38985 L
.21983 .32646 L
.26677 .26989 L
.32286 .22235 L
.3859 .18571 L
.45342 .1614 L
.52277 .15038 L
.59122 .15308 L
.65609 .1694 L
.71484 .19869 L
.76516 .2398 L
.80507 .29113 L
.833 .35066 L
.84787 .41604 L
.84909 .48472 L
.8366 .55401 L
Mistroke
.81091 .62117 L
.77301 .68357 L
.7244 .73877 L
.66698 .7846 L
.60301 .81927 L
.53499 .8414 L
.46561 .85013 L
.39757 .84512 L
.33355 .82657 L
.27606 .7952 L
.22737 .75224 L
.18937 .69939 L
.16356 .63871 L
.15096 .57259 L
.15206 .50361 L
.16681 .4345 L
.19464 .36796 L
.23445 .3066 L
.28468 .25282 L
.34337 .20875 L
.4082 .17611 L
.47663 .15619 L
.54598 .14975 L
.61353 .15706 L
.67662 .17783 L
.73278 .21124 L
.7798 .25599 L
.81585 .31031 L
.83949 .37208 L
.84982 .43887 L
.84641 .50805 L
.82941 .57692 L
.79948 .64277 L
.7578 .70302 L
.706 .7553 L
.64611 .79756 L
.58049 .82815 L
.51172 .84585 L
.44248 .84998 L
.3755 .84038 L
.3134 .81741 L
.25863 .78199 L
.21333 .73551 L
.17929 .67978 L
.15783 .61699 L
.14979 .54961 L
.15551 .48029 L
.17474 .41174 L
.20673 .34665 L
.25024 .28759 L
Mistroke
.30355 .23685 L
Mfstroke
.159 0 1 r
.70324 .49751 m
.6947 .53788 L
.67852 .57676 L
.65533 .61263 L
.62605 .64408 L
.59181 .66988 L
.55398 .68901 L
.51403 .70072 L
.47352 .70455 L
.43406 .70035 L
.39718 .6883 L
.36434 .66885 L
.33682 .64277 L
.31571 .6111 L
.30183 .57506 L
.29572 .53608 L
.29764 .49568 L
.30749 .45545 L
.32491 .41697 L
.34919 .38174 L
.37939 .35116 L
.41432 .32642 L
.45262 .30849 L
.49278 .29808 L
.53322 .29559 L
.57236 .30113 L
.60865 .31447 L
.64068 .33509 L
.6672 .36218 L
.68715 .39468 L
.69975 .43132 L
.70452 .47065 L
.70125 .51113 L
.6901 .55118 L
.67148 .58921 L
.64613 .62375 L
.61504 .65343 L
.57944 .67709 L
.54072 .69379 L
.50041 .7029 L
.46008 .70403 L
.42131 .69717 L
.38564 .68256 L
.35445 .66079 L
.32897 .63271 L
.31021 .59942 L
.29889 .56223 L
.29547 .52259 L
.30008 .48207 L
.31253 .44226 L
Mistroke
.33233 .40471 L
.35872 .3709 L
.39066 .34215 L
.42688 .3196 L
.46597 .30413 L
.5064 .29635 L
.54658 .29656 L
.58493 .30476 L
.61995 .32061 L
.65026 .34351 L
.67467 .37255 L
.69223 .40659 L
.70224 .4443 L
.70432 .48419 L
.69837 .5247 L
.68465 .56425 L
.66367 .60127 L
.63627 .63432 L
.60353 .66209 L
.56672 .68351 L
.52729 .69772 L
.48679 .70417 L
.44681 .70261 L
.40892 .6931 L
.3746 .67601 L
.3452 .65201 L
.32188 .62205 L
.30555 .5873 L
.29685 .54912 L
.29612 .50901 L
.3034 .46855 L
.31839 .42932 L
.34051 .39287 L
.36888 .36062 L
.40241 .33384 L
.43976 .31358 L
.47948 .30064 L
.52 .29553 L
.55974 .29843 L
.59713 .30925 L
.63071 .32756 L
.65916 .35263 L
.68137 .38348 L
.69646 .41891 L
.70383 .45752 L
.70321 .4978 L
.69461 .53817 L
.67838 .57703 L
.65514 .61288 L
.62582 .64429 L
Mistroke
.59155 .67004 L
.5537 .68912 L
.51374 .70077 L
.47323 .70455 L
.43378 .7003 L
.39693 .68818 L
.36412 .66868 L
.33665 .64257 L
.31558 .61085 L
.30176 .57479 L
.29571 .53579 L
.29768 .49539 L
.30759 .45516 L
.32506 .4167 L
.34939 .38151 L
.37962 .35096 L
.41459 .32627 L
.4529 .30839 L
.49307 .29804 L
.53351 .29561 L
.57263 .3012 L
.6089 .31459 L
.6409 .33526 L
.66736 .3624 L
.68726 .39493 L
.69981 .43159 L
.70452 .47094 L
.7012 .51142 L
.68999 .55146 L
.67132 .58948 L
.64592 .62398 L
.6148 .65362 L
.57917 .67723 L
.54044 .69389 L
.50012 .70293 L
.45979 .70401 L
.42104 .69709 L
.3854 .68243 L
.35424 .66061 L
.32881 .63249 L
.3101 .59916 L
.29884 .56195 L
.29548 .5223 L
.30014 .48178 L
.31264 .44198 L
.3325 .40445 L
.35893 .37067 L
.3909 .34197 L
.42715 .31947 L
.46626 .30405 L
Mistroke
.50669 .29633 L
.54686 .29659 L
.5852 .30484 L
.62018 .32075 L
.65045 .3437 L
.67482 .37278 L
.69233 .40685 L
.70228 .44458 L
.7043 .48448 L
.6983 .52499 L
.68452 .56452 L
.6635 .60152 L
.63606 .63454 L
.60328 .66227 L
.56644 .68364 L
.527 .6978 L
.4865 .70419 L
.44653 .70257 L
.40866 .69301 L
.37437 .67586 L
.34501 .65182 L
.32174 .62182 L
.30546 .58703 L
.29682 .54883 L
.29615 .50872 L
.30348 .46826 L
.31852 .42905 L
.34069 .39262 L
.36911 .36041 L
.40266 .33367 L
.44004 .31346 L
.47977 .30058 L
.52029 .29552 L
.56001 .29848 L
.59739 .30936 L
.63094 .32771 L
.65935 .35283 L
.6815 .38372 L
.69654 .41918 L
.70386 .45781 L
.70318 .49809 L
.69452 .53845 L
.67823 .5773 L
.65495 .61312 L
.62559 .64449 L
.59129 .6702 L
.55342 .68923 L
.51344 .70083 L
.47294 .70455 L
.43351 .70024 L
Mistroke
.39668 .68807 L
Mfstroke
.852 1 0 r
.52222 .27626 m
.56569 .27951 L
.60658 .29141 L
.64328 .3115 L
.67437 .33899 L
.69861 .37279 L
.71505 .41159 L
.72306 .45386 L
.72231 .49794 L
.71283 .5421 L
.69501 .5846 L
.66953 .62379 L
.63739 .65812 L
.59987 .68624 L
.55842 .70706 L
.51469 .71974 L
.47037 .72381 L
.42722 .71909 L
.38693 .70577 L
.35107 .68437 L
.32106 .65574 L
.29807 .621 L
.283 .58151 L
.27646 .53882 L
.27868 .49461 L
.28959 .45061 L
.30876 .40854 L
.33543 .37007 L
.36857 .33669 L
.40686 .30973 L
.4488 .29023 L
.49276 .27896 L
.537 .27637 L
.57979 .28256 L
.61944 .29728 L
.65441 .31995 L
.68332 .34969 L
.70503 .38533 L
.7187 .42548 L
.72379 .46854 L
.72009 .51284 L
.70775 .55664 L
.68726 .59821 L
.65942 .63593 L
.62533 .66831 L
.58631 .69409 L
.54391 .71225 L
.49979 .72208 L
.45567 .7232 L
.41329 .71556 L
Mistroke
.37432 .69945 L
.34028 .67552 L
.31251 .6447 L
.29209 .6082 L
.27984 .56746 L
.27622 .52406 L
.28139 .47973 L
.29514 .43618 L
.31692 .39515 L
.3459 .35822 L
.38092 .32687 L
.42061 .3023 L
.46342 .2855 L
.50767 .27711 L
.55161 .27748 L
.59353 .28657 L
.63178 .30404 L
.66485 .3292 L
.69146 .36107 L
.71055 .39838 L
.72138 .43969 L
.72352 .48336 L
.71689 .52769 L
.70175 .57093 L
.67869 .61138 L
.64861 .64746 L
.6127 .67776 L
.57237 .70108 L
.5292 .71651 L
.48489 .72344 L
.44116 .7216 L
.39975 .71107 L
.36227 .69225 L
.3302 .66589 L
.30478 .63301 L
.28704 .59492 L
.27764 .5531 L
.27698 .5092 L
.28507 .46493 L
.30159 .42204 L
.3259 .38222 L
.35704 .34701 L
.3938 .31781 L
.43472 .29576 L
.4782 .28172 L
.52254 .27625 L
.56599 .27957 L
.60686 .29153 L
.64353 .31167 L
.67457 .33921 L
Mistroke
.69875 .37306 L
.71514 .41188 L
.72308 .45417 L
.72227 .49826 L
.71273 .54241 L
.69485 .5849 L
.66932 .62406 L
.63714 .65834 L
.59958 .68642 L
.55812 .70718 L
.51437 .7198 L
.47006 .7238 L
.42692 .71902 L
.38665 .70564 L
.35083 .68419 L
.32087 .65552 L
.29793 .62073 L
.28293 .58122 L
.27644 .53851 L
.27873 .49429 L
.2897 .4503 L
.30893 .40825 L
.33565 .36981 L
.36882 .33648 L
.40715 .30956 L
.44911 .29012 L
.49308 .27891 L
.53731 .27639 L
.58008 .28263 L
.61971 .29741 L
.65464 .32014 L
.6835 .34993 L
.70516 .38561 L
.71877 .42578 L
.72379 .46886 L
.72003 .51316 L
.70763 .55694 L
.68709 .5985 L
.6592 .63618 L
.62506 .66852 L
.58602 .69425 L
.5436 .71235 L
.49947 .72212 L
.45536 .72318 L
.413 .71547 L
.37406 .69931 L
.34006 .67532 L
.31233 .64446 L
.29197 .60792 L
.27978 .56715 L
Mistroke
.27623 .52375 L
.28146 .47941 L
.29527 .43588 L
.31711 .39487 L
.34613 .35798 L
.38119 .32667 L
.42091 .30216 L
.46374 .28541 L
.50799 .27709 L
.55192 .27751 L
.59382 .28667 L
.63204 .30419 L
.66507 .32941 L
.69163 .36132 L
.71066 .39867 L
.72143 .44 L
.72351 .48368 L
.71681 .528 L
.70161 .57123 L
.67849 .61166 L
.64837 .6477 L
.61243 .67795 L
.57207 .70122 L
.52889 .71659 L
.48457 .72346 L
.44086 .72156 L
.39947 .71096 L
.36202 .69209 L
.32999 .66567 L
.30463 .63276 L
.28694 .59463 L
.27761 .55279 L
.27701 .50888 L
.28516 .46462 L
.30174 .42175 L
.3261 .38195 L
.35729 .34678 L
.39408 .31762 L
.43502 .29563 L
.47852 .28165 L
.52286 .27625 L
.5663 .27962 L
.60714 .29164 L
.64377 .31185 L
.67477 .33943 L
.6989 .37332 L
.71523 .41218 L
.72311 .45448 L
.72223 .49857 L
.71263 .54272 L
Mistroke
.69469 .58519 L
Mfstroke
1 .894 0 r
.75054 .17654 m
.80367 .22463 L
.84488 .28353 L
.87256 .35093 L
.88561 .42417 L
.88354 .50039 L
.86641 .5766 L
.8349 .6498 L
.79024 .71712 L
.7342 .77592 L
.66896 .82389 L
.5971 .85915 L
.52142 .88032 L
.4449 .88656 L
.37055 .87762 L
.30127 .85387 L
.2398 .81623 L
.18853 .76618 L
.14949 .70568 L
.12421 .63711 L
.11367 .56316 L
.1183 .48673 L
.13791 .41082 L
.17172 .33841 L
.21842 .27234 L
.27618 .21521 L
.34271 .16926 L
.41542 .13628 L
.49145 .11758 L
.56781 .11389 L
.64151 .12535 L
.70966 .15151 L
.76958 .19135 L
.81892 .24331 L
.85575 .30533 L
.87861 .375 L
.88661 .44958 L
.87944 .52613 L
.85738 .60166 L
.82129 .67319 L
.7726 .73794 L
.7132 .79334 L
.64544 .83723 L
.57197 .86788 L
.49567 .8841 L
.41955 .88524 L
.34658 .87127 L
.27964 .84272 L
.22134 .80072 L
.17398 .74692 L
Mistroke
.13941 .68343 L
.11899 .61274 L
.11353 .53763 L
.12324 .46104 L
.14773 .38598 L
.18605 .31539 L
.23669 .25205 L
.29766 .19844 L
.36657 .15666 L
.44072 .12836 L
.5172 .11465 L
.593 .11605 L
.66515 .13253 L
.73082 .16343 L
.78743 .20754 L
.83276 .26312 L
.86503 .328 L
.88298 .39963 L
.88589 .47521 L
.87366 .55175 L
.84677 .62626 L
.80626 .69582 L
.75374 .75769 L
.69126 .80945 L
.62127 .84907 L
.54652 .87498 L
.46995 .88618 L
.39456 .88222 L
.3233 .86326 L
.25898 .83005 L
.20412 .78388 L
.16087 .72657 L
.13093 .66037 L
.11547 .58788 L
.11511 .51193 L
.12985 .43552 L
.15912 .36164 L
.20176 .29319 L
.25611 .23285 L
.32004 .183 L
.39102 .14559 L
.46628 .12209 L
.54287 .11342 L
.61777 .11992 L
.68805 .14134 L
.75096 .17684 L
.80401 .22502 L
.84513 .28399 L
.8727 .35143 L
.88565 .42471 L
Mistroke
.88347 .50094 L
.86623 .57714 L
.83462 .65031 L
.78988 .71758 L
.73376 .77631 L
.66847 .82419 L
.59656 .85936 L
.52087 .88042 L
.44436 .88655 L
.37003 .87751 L
.3008 .85365 L
.23939 .81591 L
.18821 .76578 L
.14926 .70522 L
.12408 .6366 L
.11365 .56262 L
.11839 .48618 L
.1381 .41029 L
.17201 .33791 L
.2188 .2719 L
.27662 .21484 L
.34321 .16897 L
.41596 .13609 L
.492 .1175 L
.56835 .11391 L
.64203 .12548 L
.71012 .15175 L
.76998 .19168 L
.81923 .24372 L
.85596 .30581 L
.87872 .37552 L
.88661 .45012 L
.87934 .52668 L
.85717 .60219 L
.82099 .67369 L
.77221 .73837 L
.71274 .7937 L
.64493 .8375 L
.57143 .86805 L
.49512 .88416 L
.41901 .8852 L
.34608 .87111 L
.27918 .84247 L
.22096 .80038 L
.17368 .7465 L
.13921 .68295 L
.1189 .61222 L
.11355 .53708 L
.12336 .46049 L
.14796 .38545 L
Mistroke
.18637 .31491 L
.23709 .25163 L
.29813 .19809 L
.36709 .15641 L
.44126 .12821 L
.51775 .1146 L
.59353 .11612 L
.66565 .1327 L
.73126 .1637 L
.7878 .2079 L
.83304 .26356 L
.86522 .32849 L
.88305 .40017 L
.88586 .47575 L
.87352 .55229 L
.84653 .62678 L
.80593 .69629 L
.75333 .7581 L
.69078 .80978 L
.62075 .8493 L
.54598 .87512 L
.4694 .88621 L
.39403 .88214 L
.32281 .86308 L
.25855 .82976 L
.20376 .78351 L
.1606 .72613 L
.13076 .65987 L
.11541 .58734 L
.11516 .51138 L
.13001 .43498 L
.15938 .36112 L
.20211 .29272 L
.25654 .23245 L
.32052 .18269 L
.39155 .14537 L
.46683 .12198 L
.54342 .11341 L
.6183 .12003 L
.68853 .14155 L
.75137 .17714 L
.80435 .2254 L
.84538 .28444 L
.87285 .35194 L
.88569 .42525 L
.88339 .50149 L
.86605 .57768 L
.83434 .65081 L
.78951 .71803 L
.73332 .77669 L
Mistroke
.66797 .82449 L
Mfstroke
1 0 .522 r
.20181 .77854 m
.15973 .72075 L
.131 .65429 L
.11674 .58178 L
.11753 .50606 L
.13334 .4301 L
.16353 .35688 L
.20692 .28928 L
.26182 .22995 L
.32607 .18122 L
.39714 .145 L
.47225 .12271 L
.54845 .11523 L
.62274 .12285 L
.69222 .14527 L
.75416 .18161 L
.80612 .23045 L
.84607 .28987 L
.87243 .35753 L
.88418 .43079 L
.88085 .50676 L
.86258 .58247 L
.83007 .65494 L
.78461 .72133 L
.72798 .77903 L
.66241 .82578 L
.59046 .85975 L
.51496 .8796 L
.43887 .88455 L
.36518 .87441 L
.29678 .84957 L
.23636 .81102 L
.18629 .76026 L
.14853 .69928 L
.12456 .63049 L
.11532 .55657 L
.12118 .48043 L
.14191 .40506 L
.1767 .33342 L
.22417 .26832 L
.28247 .2123 L
.3493 .16758 L
.42205 .1359 L
.49786 .11852 L
.57375 .1161 L
.64675 .12876 L
.71398 .15598 L
.77282 .1967 L
.82096 .24933 L
.85649 .31179 L
Mistroke
.87804 .38164 L
.88475 .45614 L
.87636 .53235 L
.8532 .6073 L
.81618 .67804 L
.76674 .74179 L
.70684 .79605 L
.63883 .83869 L
.56536 .86804 L
.48933 .88294 L
.41372 .88282 L
.34149 .86767 L
.27549 .83809 L
.21829 .79525 L
.17215 .74081 L
.13888 .67693 L
.11978 .6061 L
.11561 .53111 L
.12651 .4549 L
.15208 .38045 L
.1913 .3107 L
.24264 .24838 L
.30408 .19593 L
.3732 .15542 L
.4473 .12843 L
.52347 .11602 L
.59872 .11868 L
.6701 .13631 L
.7348 .16821 L
.79028 .21313 L
.83437 .26931 L
.86534 .33455 L
.88197 .40628 L
.88361 .48168 L
.8702 .55781 L
.84225 .63166 L
.80088 .70035 L
.74769 .76118 L
.68479 .81175 L
.61463 .85009 L
.53997 .87469 L
.46375 .88459 L
.38895 .87939 L
.3185 .8593 L
.25518 .82512 L
.20147 .77817 L
.15947 .7203 L
.13084 .65379 L
.1167 .58124 L
.1176 .50551 L
Mistroke
.1335 .42956 L
.16379 .35637 L
.20728 .28882 L
.26225 .22956 L
.32655 .18091 L
.39767 .14479 L
.47279 .1226 L
.54899 .11523 L
.62326 .12296 L
.6927 .14548 L
.75457 .18192 L
.80645 .23084 L
.8463 .29033 L
.87257 .35804 L
.88421 .43133 L
.88077 .50731 L
.86239 .583 L
.82979 .65544 L
.78424 .72177 L
.72754 .77941 L
.66191 .82607 L
.58993 .85994 L
.51441 .87969 L
.43833 .88453 L
.36467 .87428 L
.29632 .84934 L
.23596 .81069 L
.18597 .75985 L
.1483 .69881 L
.12444 .62997 L
.11531 .55603 L
.12128 .47989 L
.14211 .40453 L
.17699 .33293 L
.22455 .26788 L
.28292 .21194 L
.3498 .16731 L
.42258 .13573 L
.4984 .11845 L
.57428 .11614 L
.64725 .1289 L
.71444 .15622 L
.77321 .19704 L
.82126 .24974 L
.8567 .31227 L
.87814 .38216 L
.88474 .45668 L
.87625 .5329 L
.85298 .60783 L
.81586 .67852 L
Mistroke
.76635 .74221 L
.70638 .7964 L
.63832 .83895 L
.56482 .8682 L
.48878 .883 L
.41318 .88276 L
.34099 .86751 L
.27504 .83783 L
.21792 .7949 L
.17187 .74039 L
.13869 .67644 L
.1197 .60557 L
.11563 .53056 L
.12665 .45435 L
.15232 .37993 L
.19163 .31022 L
.24305 .24797 L
.30455 .1956 L
.37372 .15518 L
.44785 .12829 L
.52402 .11599 L
.59925 .11876 L
.67059 .13649 L
.73523 .16849 L
.79064 .2135 L
.83464 .26975 L
.86551 .33504 L
.88204 .40681 L
.88357 .48223 L
.87005 .55835 L
.842 .63218 L
.80054 .70082 L
.74727 .76158 L
.68431 .81207 L
.61411 .85032 L
.53943 .87482 L
.4632 .88461 L
.38842 .8793 L
.31802 .85911 L
.25476 .82482 L
.20112 .77779 L
.15922 .71985 L
.13069 .65329 L
.11665 .58071 L
.11766 .50496 L
.13367 .42902 L
.16406 .35586 L
.20763 .28836 L
.26268 .22917 L
.32704 .18061 L
Mistroke
.39819 .14458 L
Mfstroke
1 0 .405 r
.18824 .27124 m
.24756 .2081 L
.31678 .15642 L
.39319 .11822 L
.47379 .09501 L
.55542 .08769 L
.63488 .09656 L
.70905 .12125 L
.77501 .16081 L
.83017 .21369 L
.87238 .27779 L
.89997 .35062 L
.91187 .42932 L
.9076 .51078 L
.88734 .59183 L
.85187 .66927 L
.8026 .74006 L
.74145 .80144 L
.67082 .85098 L
.59349 .88675 L
.51249 .90734 L
.431 .91195 L
.35222 .90039 L
.27923 .87311 L
.21492 .83119 L
.16179 .77627 L
.12193 .71051 L
.09691 .63649 L
.08771 .55712 L
.09469 .4755 L
.11758 .39484 L
.15548 .31831 L
.2069 .24891 L
.26982 .18936 L
.34177 .14201 L
.41994 .1087 L
.50124 .09075 L
.5825 .08887 L
.66052 .10312 L
.73224 .13294 L
.79485 .17717 L
.84588 .23407 L
.88334 .30141 L
.90576 .37654 L
.91225 .45652 L
.90256 .5382 L
.87707 .61838 L
.83679 .69392 L
.78328 .76185 L
.71866 .8195 L
Mistroke
.64546 .86461 L
.56655 .89541 L
.48503 .91069 L
.40409 .90986 L
.32692 .89294 L
.25654 .8606 L
.19572 .81411 L
.14684 .75529 L
.11182 .68645 L
.09203 .61029 L
.08825 .52981 L
.10064 .44815 L
.12869 .36853 L
.17132 .29407 L
.22685 .22769 L
.2931 .172 L
.36747 .12918 L
.44704 .10092 L
.52869 .08831 L
.60921 .09187 L
.68545 .11144 L
.75441 .14626 L
.81338 .19496 L
.86005 .25564 L
.8926 .3259 L
.90974 .403 L
.91079 .48391 L
.89573 .56544 L
.86513 .64441 L
.8202 .71771 L
.76271 .78247 L
.69491 .83614 L
.61945 .87662 L
.53931 .90231 L
.45763 .91222 L
.37761 .90595 L
.30239 .88375 L
.23493 .84649 L
.17787 .79563 L
.13345 .73317 L
.10342 .66155 L
.08895 .5836 L
.09062 .50236 L
.10835 .42104 L
.14145 .34281 L
.18863 .27075 L
.24802 .20769 L
.3173 .1561 L
.39376 .118 L
.47438 .0949 L
Mistroke
.55601 .0877 L
.63544 .09668 L
.70955 .12148 L
.77544 .16115 L
.83052 .21411 L
.87263 .27829 L
.90012 .35117 L
.9119 .42989 L
.90752 .51137 L
.88714 .5924 L
.85157 .6698 L
.8022 .74054 L
.74097 .80184 L
.67029 .85129 L
.59292 .88695 L
.5119 .90743 L
.43042 .91192 L
.35167 .90025 L
.27874 .87286 L
.21449 .83084 L
.16145 .77584 L
.1217 .71001 L
.09679 .63594 L
.08771 .55653 L
.0948 .47491 L
.1178 .39427 L
.1558 .31778 L
.20731 .24844 L
.2703 .18898 L
.34231 .14172 L
.42051 .10852 L
.50183 .09068 L
.58308 .08891 L
.66106 .10328 L
.73273 .13321 L
.79526 .17754 L
.8462 .23452 L
.88356 .30192 L
.90586 .3771 L
.91223 .4571 L
.90243 .53878 L
.87683 .61894 L
.83645 .69444 L
.78286 .7623 L
.71816 .81987 L
.64491 .86488 L
.56597 .89558 L
.48444 .91075 L
.40352 .9098 L
.32639 .89276 L
Mistroke
.25607 .86031 L
.19532 .81373 L
.14653 .75483 L
.11162 .68592 L
.09194 .60973 L
.08828 .52922 L
.10078 .44757 L
.12895 .36798 L
.17168 .29356 L
.22729 .22725 L
.29361 .17165 L
.36803 .12893 L
.44762 .10077 L
.52927 .08828 L
.60978 .09195 L
.68597 .11164 L
.75487 .14656 L
.81376 .19536 L
.86034 .25611 L
.89278 .32644 L
.9098 .40357 L
.91074 .48449 L
.89556 .56602 L
.86486 .64496 L
.81983 .71821 L
.76226 .78289 L
.69439 .83648 L
.61889 .87685 L
.53873 .90244 L
.45705 .91224 L
.37705 .90585 L
.30188 .88354 L
.23448 .84617 L
.1775 .79522 L
.13319 .73268 L
.10326 .66101 L
.08891 .58302 L
.09069 .50178 L
.10853 .42046 L
.14174 .34227 L
.18901 .27026 L
.24848 .20727 L
.31783 .15577 L
.39432 .11778 L
.47496 .09479 L
.55659 .08771 L
.63599 .0968 L
.71006 .12172 L
.77588 .16148 L
.83087 .21453 L
Mistroke
.87288 .27878 L
Mfstroke
0 1 .174 r
.33216 .63458 m
.31289 .60193 L
.30095 .56529 L
.29683 .52608 L
.30068 .48585 L
.31235 .44617 L
.33139 .40861 L
.35705 .37463 L
.38831 .34557 L
.42396 .32258 L
.46259 .30654 L
.50269 .2981 L
.54269 .29759 L
.58101 .30501 L
.61615 .32009 L
.64673 .34223 L
.67156 .37056 L
.68965 .40397 L
.70029 .44116 L
.70308 .48064 L
.6979 .52089 L
.68495 .56032 L
.66474 .59739 L
.63807 .63062 L
.60597 .65874 L
.56972 .68062 L
.53074 .69542 L
.49054 .70254 L
.45072 .70172 L
.41283 .69298 L
.37836 .67666 L
.34867 .65342 L
.32491 .62415 L
.30803 .59001 L
.29868 .55234 L
.29723 .51261 L
.30374 .47239 L
.31796 .43325 L
.33931 .39673 L
.36697 .36427 L
.39986 .33713 L
.43667 .31638 L
.47597 .30284 L
.51621 .29704 L
.55582 .2992 L
.59323 .30924 L
.62699 .32677 L
.65576 .3511 L
.67842 .38128 L
.69408 .41611 L
Mistroke
.70212 .45423 L
.70223 .49415 L
.6944 .5343 L
.67894 .5731 L
.65646 .60904 L
.62784 .64069 L
.5942 .66683 L
.55686 .68641 L
.5173 .69868 L
.47705 .70316 L
.43771 .69966 L
.40081 .68832 L
.3678 .66959 L
.33998 .64421 L
.31844 .61317 L
.30403 .57768 L
.29731 .53915 L
.29854 .49908 L
.30768 .45905 L
.32436 .42062 L
.34794 .38531 L
.37749 .3545 L
.41185 .3294 L
.44966 .311 L
.48945 .30001 L
.52966 .29687 L
.5687 .30171 L
.60504 .31432 L
.63727 .33423 L
.6641 .36064 L
.68449 .39251 L
.69765 .42861 L
.70305 .46751 L
.70047 .50768 L
.69003 .54756 L
.67214 .58556 L
.64748 .62021 L
.61704 .65014 L
.58201 .67418 L
.54375 .69138 L
.50378 .70107 L
.46366 .70287 L
.42497 .69671 L
.38922 .68283 L
.35782 .66177 L
.332 .63436 L
.31277 .60168 L
.30089 .56501 L
.29683 .52579 L
.30074 .48556 L
Mistroke
.31246 .44589 L
.33155 .40835 L
.35725 .3744 L
.38855 .34539 L
.42423 .32244 L
.46288 .30646 L
.50298 .29807 L
.54297 .29761 L
.58127 .30509 L
.61639 .32023 L
.64693 .34241 L
.67171 .37079 L
.68975 .40423 L
.70034 .44143 L
.70307 .48093 L
.69783 .52118 L
.68483 .5606 L
.66457 .59764 L
.63785 .63085 L
.60573 .65892 L
.56945 .68075 L
.53045 .6955 L
.49025 .70256 L
.45044 .70168 L
.41257 .69289 L
.37813 .67652 L
.34848 .65323 L
.32477 .62392 L
.30794 .58975 L
.29864 .55206 L
.29725 .51232 L
.30382 .4721 L
.31808 .43298 L
.33949 .39648 L
.36719 .36405 L
.40011 .33695 L
.43695 .31626 L
.47626 .30277 L
.5165 .29703 L
.5561 .29925 L
.59349 .30934 L
.62721 .32693 L
.65595 .3513 L
.67856 .38151 L
.69416 .41637 L
.70215 .45451 L
.7022 .49444 L
.69431 .53459 L
.6788 .57337 L
.65627 .60928 L
Mistroke
.62761 .6409 L
.59394 .66699 L
.55659 .68653 L
.51701 .69874 L
.47677 .70316 L
.43743 .6996 L
.40055 .68821 L
.36758 .66943 L
.3398 .64401 L
.31831 .61293 L
.30395 .57742 L
.29729 .53887 L
.29858 .49879 L
.30777 .45877 L
.32451 .42036 L
.34814 .38507 L
.37772 .3543 L
.41211 .32925 L
.44994 .31089 L
.48974 .29996 L
.52994 .29688 L
.56897 .30177 L
.60529 .31444 L
.63748 .33439 L
.66427 .36085 L
.68462 .39276 L
.69772 .42888 L
.70306 .46779 L
.70043 .50797 L
.68993 .54784 L
.67198 .58582 L
.64728 .62044 L
.61681 .65033 L
.58174 .67433 L
.54347 .69148 L
.50349 .70111 L
.46338 .70285 L
.4247 .69664 L
.38898 .6827 L
.35762 .66159 L
.33184 .63415 L
.31266 .60143 L
.30084 .56474 L
.29683 .52551 L
.30079 .48527 L
.31258 .44561 L
.33171 .40809 L
.35746 .37418 L
.3888 .3452 L
.4245 .3223 L
Mistroke
.46316 .30637 L
Mfstroke
1 .331 0 r
.59487 .35356 m
.61975 .37165 L
.63993 .39477 L
.65462 .42203 L
.66323 .45234 L
.66545 .48453 L
.66116 .51732 L
.65056 .54943 L
.63404 .5796 L
.61227 .60665 L
.58609 .62951 L
.55653 .64729 L
.52475 .65929 L
.492 .66504 L
.45956 .66431 L
.42871 .65713 L
.40066 .64379 L
.37651 .6248 L
.3572 .60091 L
.3435 .57307 L
.33594 .54235 L
.33482 .50998 L
.34018 .47721 L
.35182 .44534 L
.36926 .41561 L
.39185 .38919 L
.41867 .36713 L
.44869 .35027 L
.48072 .3393 L
.5135 .33463 L
.54576 .33645 L
.57622 .34469 L
.60369 .35902 L
.62709 .37889 L
.64551 .40351 L
.65821 .43192 L
.6647 .463 L
.66473 .49553 L
.65829 .52824 L
.64565 .55984 L
.62728 .58909 L
.60392 .61484 L
.57648 .63609 L
.54604 .65199 L
.5138 .66193 L
.48101 .66552 L
.44897 .66261 L
.41893 .65332 L
.39207 .63801 L
.36945 .61728 L
Mistroke
.35195 .59195 L
.34026 .56302 L
.33484 .53161 L
.3359 .49896 L
.34341 .46635 L
.35705 .43506 L
.37631 .40632 L
.40043 .38125 L
.42845 .36085 L
.45928 .34591 L
.4917 .33701 L
.52446 .33451 L
.55625 .33851 L
.58583 .34885 L
.61205 .36511 L
.63387 .38667 L
.65044 .41268 L
.6611 .44212 L
.66544 .47382 L
.66328 .50656 L
.65472 .53903 L
.64009 .56998 L
.61995 .59818 L
.59511 .62252 L
.56654 .64206 L
.53536 .65602 L
.50279 .66386 L
.47011 .66527 L
.4386 .66019 L
.4095 .64882 L
.38395 .63162 L
.36296 .60925 L
.34735 .58259 L
.33773 .55269 L
.33447 .52072 L
.33771 .48794 L
.34732 .45563 L
.36293 .42507 L
.38391 .39744 L
.40945 .37384 L
.43854 .35519 L
.47005 .34222 L
.50273 .33545 L
.5353 .33513 L
.56649 .34129 L
.59507 .35367 L
.61991 .3718 L
.64005 .39496 L
.6547 .42224 L
.66327 .45257 L
Mistroke
.66544 .48476 L
.66111 .51755 L
.65046 .54965 L
.63391 .57981 L
.61209 .60683 L
.58589 .62966 L
.5563 .6474 L
.52451 .65936 L
.49176 .66506 L
.45933 .66428 L
.4285 .65706 L
.40047 .64367 L
.37635 .62464 L
.35708 .60073 L
.34343 .57286 L
.33591 .54213 L
.33484 .50974 L
.34024 .47698 L
.35192 .44511 L
.36941 .41541 L
.39202 .38902 L
.41887 .36699 L
.44891 .35017 L
.48095 .33924 L
.51374 .33462 L
.54599 .33649 L
.57643 .34477 L
.60388 .35915 L
.62724 .37905 L
.64562 .4037 L
.65828 .43213 L
.66472 .46323 L
.66471 .49577 L
.65822 .52847 L
.64553 .56006 L
.62713 .58928 L
.60374 .61501 L
.57628 .63622 L
.54582 .65209 L
.51356 .66198 L
.48078 .66552 L
.44874 .66257 L
.41872 .65323 L
.39189 .63788 L
.3693 .61712 L
.35184 .59176 L
.3402 .5628 L
.33482 .53138 L
.33593 .49872 L
.34348 .46612 L
Mistroke
.35717 .43484 L
.37647 .40612 L
.40061 .38109 L
.42866 .36072 L
.4595 .34582 L
.49194 .33697 L
.52469 .33452 L
.55647 .33856 L
.58604 .34894 L
.61222 .36525 L
.63401 .38684 L
.65053 .41288 L
.66115 .44234 L
.66544 .47405 L
.66324 .50679 L
.65464 .53926 L
.63996 .57019 L
.61979 .59837 L
.59492 .62268 L
.56633 .64218 L
.53513 .6561 L
.50255 .66389 L
.46987 .66525 L
.43838 .66013 L
.4093 .64872 L
.38379 .63148 L
.36283 .60907 L
.34726 .58238 L
.33768 .55246 L
.33447 .52049 L
.33776 .4877 L
.34742 .45541 L
.36306 .42486 L
.38408 .39726 L
.40965 .37369 L
.43876 .35508 L
.47028 .34215 L
.50296 .33543 L
.53553 .33516 L
.5667 .34136 L
.59526 .35378 L
.62008 .37195 L
.64018 .39514 L
.65478 .42244 L
.66331 .45279 L
.66543 .48499 L
.66106 .51779 L
.65036 .54988 L
.63377 .58001 L
.61192 .60701 L
Mistroke
.58568 .62981 L
Mfstroke
1 .408 0 r
.73374 .63256 m
.69701 .67969 L
.65255 .71977 L
.6021 .75123 L
.54764 .77282 L
.49132 .78371 L
.43533 .78347 L
.38189 .7721 L
.33308 .75005 L
.29082 .71818 L
.25677 .67776 L
.23226 .63036 L
.21826 .57784 L
.21532 .52227 L
.22356 .46582 L
.24264 .41072 L
.27182 .35911 L
.30996 .31304 L
.35555 .27431 L
.40682 .24443 L
.46174 .22459 L
.51816 .21555 L
.57387 .21767 L
.62668 .23088 L
.67452 .25465 L
.71551 .28804 L
.74805 .32976 L
.77084 .37816 L
.78301 .43133 L
.78407 .48721 L
.77398 .54358 L
.75314 .59825 L
.72237 .64906 L
.68286 .69402 L
.63619 .73136 L
.58416 .75963 L
.52883 .7777 L
.47238 .78488 L
.417 .78088 L
.36488 .76585 L
.31807 .74039 L
.2784 .70549 L
.24742 .66253 L
.22635 .6132 L
.21603 .55942 L
.21685 .5033 L
.22878 .44706 L
.25136 .3929 L
.28369 .34294 L
.32452 .29914 L
Mistroke
.37223 .26322 L
.42495 .2366 L
.48062 .22032 L
.53705 .21501 L
.59203 .22089 L
.6434 .23772 L
.68913 .26484 L
.72745 .3012 L
.75684 .34535 L
.77615 .39558 L
.78462 .4499 L
.78192 .50619 L
.76815 .56223 L
.74387 .61584 L
.71001 .6649 L
.66791 .70748 L
.61922 .74193 L
.56585 .76687 L
.5099 .78135 L
.45356 .78478 L
.39904 .77704 L
.34848 .75842 L
.30387 .72966 L
.26696 .69189 L
.23919 .64659 L
.22166 .59553 L
.21505 .54073 L
.21963 .48433 L
.23521 .42854 L
.26118 .37555 L
.29652 .32745 L
.33985 .28613 L
.38947 .25319 L
.44342 .22994 L
.49959 .21729 L
.55578 .21574 L
.60978 .22534 L
.65947 .24572 L
.70291 .27608 L
.73838 .31523 L
.76449 .36163 L
.78022 .41346 L
.78496 .46869 L
.77851 .52514 L
.76113 .58061 L
.73351 .63292 L
.69672 .68 L
.65221 .72003 L
.60172 .75142 L
.54725 .77294 L
Mistroke
.49091 .78375 L
.43494 .78342 L
.38152 .77197 L
.33275 .74985 L
.29054 .71792 L
.25655 .67744 L
.23212 .63 L
.2182 .57745 L
.21534 .52186 L
.22365 .46542 L
.24281 .41033 L
.27206 .35876 L
.31026 .31274 L
.3559 .27406 L
.4072 .24425 L
.46214 .22448 L
.51857 .21552 L
.57426 .21773 L
.62705 .23101 L
.67484 .25485 L
.71578 .28831 L
.74824 .33008 L
.77097 .37852 L
.78306 .43173 L
.78404 .48761 L
.77387 .54398 L
.75296 .59863 L
.72211 .6494 L
.68255 .69431 L
.63583 .7316 L
.58377 .75979 L
.52843 .77779 L
.47197 .78489 L
.41661 .78081 L
.36453 .7657 L
.31776 .74017 L
.27814 .70521 L
.24723 .6622 L
.22624 .61282 L
.21599 .55902 L
.21689 .5029 L
.22891 .44666 L
.25156 .39252 L
.28396 .3426 L
.32484 .29885 L
.37259 .263 L
.42534 .23645 L
.48103 .22024 L
.53746 .21501 L
.59242 .22097 L
Mistroke
.64375 .23788 L
.68944 .26507 L
.72769 .30149 L
.75701 .34569 L
.77625 .39595 L
.78464 .4503 L
.78186 .50659 L
.76802 .56263 L
.74366 .61621 L
.70973 .66523 L
.66758 .70776 L
.61885 .74214 L
.56546 .76702 L
.50949 .78141 L
.45316 .78477 L
.39866 .77694 L
.34814 .75825 L
.30358 .72942 L
.26673 .69159 L
.23903 .64624 L
.22157 .59515 L
.21505 .54033 L
.2197 .48392 L
.23536 .42815 L
.2614 .37519 L
.29681 .32713 L
.34019 .28586 L
.38984 .25299 L
.44382 .22981 L
.5 .21724 L
.55618 .21577 L
.61016 .22545 L
.65981 .24591 L
.70319 .27633 L
.7386 .31554 L
.76464 .36198 L
.7803 .41385 L
.78495 .46909 L
.77843 .52555 L
.76097 .581 L
.73328 .63327 L
.69642 .68032 L
.65186 .72029 L
.60134 .75161 L
.54685 .77306 L
.49051 .78379 L
.43455 .78338 L
.38115 .77185 L
.33242 .74966 L
.29027 .71766 L
Mistroke
.25634 .67712 L
Mfstroke
0 .621 1 r
.58916 .55215 m
.57483 .57014 L
.55757 .58537 L
.53805 .59726 L
.51703 .60532 L
.49535 .60926 L
.47385 .6089 L
.45337 .60427 L
.43473 .59555 L
.41864 .58308 L
.40575 .56735 L
.39656 .54898 L
.39143 .52868 L
.39056 .50726 L
.39398 .48555 L
.40157 .46441 L
.41301 .44467 L
.42788 .4271 L
.44557 .41238 L
.4654 .40111 L
.48658 .39372 L
.5083 .3905 L
.52968 .39158 L
.54991 .39691 L
.56817 .40629 L
.58376 .41935 L
.59606 .43557 L
.60459 .45432 L
.60902 .47486 L
.60916 .49639 L
.60503 .51806 L
.59677 .53902 L
.58471 .55845 L
.56933 .57559 L
.55123 .58976 L
.53112 .60041 L
.50979 .60712 L
.48807 .60962 L
.46682 .60782 L
.44687 .60179 L
.42901 .59176 L
.41393 .57814 L
.40223 .56144 L
.39437 .54234 L
.39066 .52157 L
.39123 .49996 L
.39608 .47835 L
.405 .45759 L
.41765 .43849 L
.43353 .42181 L
Mistroke
.45202 .40819 L
.4724 .39818 L
.49386 .39217 L
.51555 .39038 L
.53664 .3929 L
.55629 .39962 L
.57373 .41029 L
.58828 .42447 L
.59936 .44162 L
.60655 .46105 L
.60955 .48202 L
.60825 .50369 L
.6027 .52522 L
.59313 .54576 L
.57989 .5645 L
.56353 .58071 L
.54467 .59375 L
.52405 .60312 L
.5025 .60843 L
.48084 .60949 L
.45994 .60626 L
.44061 .59885 L
.42361 .58757 L
.4096 .57284 L
.39915 .55526 L
.39265 .53551 L
.39037 .51437 L
.39239 .49266 L
.39863 .47124 L
.40885 .45095 L
.42265 .43258 L
.43948 .41686 L
.45869 .40441 L
.47952 .3957 L
.50116 .39109 L
.52274 .39075 L
.54344 .3947 L
.56243 .40278 L
.57897 .41468 L
.59241 .42993 L
.60223 .44792 L
.60803 .46796 L
.60959 .48926 L
.60685 .51098 L
.59992 .53227 L
.58907 .55229 L
.57472 .57026 L
.55744 .58547 L
.5379 .59733 L
.51688 .60537 L
Mistroke
.49519 .60927 L
.4737 .60888 L
.45323 .60422 L
.4346 .59548 L
.41854 .58298 L
.40567 .56723 L
.39651 .54884 L
.39141 .52853 L
.39057 .5071 L
.39402 .4854 L
.40164 .46426 L
.41311 .44453 L
.42799 .42698 L
.4457 .41229 L
.46554 .40105 L
.48674 .39368 L
.50845 .39049 L
.52983 .3916 L
.55004 .39697 L
.56829 .40637 L
.58386 .41945 L
.59613 .43569 L
.60464 .45446 L
.60903 .47501 L
.60915 .49655 L
.60498 .51822 L
.5967 .53917 L
.58462 .55859 L
.56921 .5757 L
.55109 .58985 L
.53097 .60047 L
.50963 .60715 L
.48791 .60962 L
.46667 .60779 L
.44674 .60173 L
.42889 .59168 L
.41384 .57803 L
.40216 .56131 L
.39433 .54219 L
.39065 .52142 L
.39125 .4998 L
.39613 .47819 L
.40508 .45744 L
.41775 .43836 L
.43366 .4217 L
.45216 .40811 L
.47255 .39812 L
.49401 .39214 L
.51571 .39039 L
.53679 .39294 L
Mistroke
.55643 .39969 L
.57385 .41038 L
.58837 .42458 L
.59943 .44175 L
.60658 .4612 L
.60955 .48217 L
.60822 .50385 L
.60265 .52537 L
.59304 .5459 L
.57979 .56462 L
.5634 .58081 L
.54452 .59383 L
.5239 .60317 L
.50234 .60846 L
.48069 .60949 L
.45979 .60622 L
.44047 .59878 L
.42349 .58747 L
.40952 .57273 L
.39909 .55513 L
.39262 .53536 L
.39037 .51421 L
.39242 .49251 L
.39869 .47109 L
.40894 .45081 L
.42276 .43246 L
.43961 .41676 L
.45884 .40433 L
.47968 .39565 L
.50131 .39107 L
.5229 .39076 L
.54358 .39474 L
.56256 .40285 L
.57908 .41478 L
.5925 .43005 L
.60228 .44806 L
.60806 .46811 L
.60959 .48941 L
.60682 .51113 L
.59986 .53242 L
.58898 .55242 L
.57461 .57038 L
.55731 .58557 L
.53776 .5974 L
.51673 .60541 L
.49504 .60928 L
.47355 .60887 L
.45309 .60418 L
.43448 .5954 L
.41844 .58288 L
Mistroke
.4056 .5671 L
Mfstroke
1 0 .949 r
.80247 .7009 m
.74911 .76204 L
.68597 .8129 L
.61553 .85149 L
.54056 .87627 L
.46399 .88629 L
.38884 .88115 L
.31805 .86105 L
.2544 .82678 L
.20039 .77969 L
.15814 .72162 L
.12931 .65485 L
.11502 .58201 L
.11584 .50594 L
.13174 .42964 L
.16209 .35611 L
.20571 .28822 L
.26087 .22864 L
.32542 .17971 L
.39682 .14336 L
.47227 .121 L
.5488 .11351 L
.62342 .12119 L
.6932 .14374 L
.7554 .18027 L
.80757 .22935 L
.84767 .28905 L
.87413 .35703 L
.8859 .43062 L
.88253 .50693 L
.86415 .58297 L
.83147 .65576 L
.78579 .72243 L
.72889 .78037 L
.663 .82731 L
.59072 .86141 L
.51488 .88132 L
.43846 .88626 L
.36445 .87605 L
.29576 .85107 L
.23508 .81232 L
.18481 .76131 L
.1469 .70005 L
.12285 .63093 L
.1136 .55668 L
.11952 .4802 L
.14037 .4045 L
.17533 .33255 L
.22304 .26717 L
.28161 .21092 L
Mistroke
.34876 .16603 L
.42184 .13423 L
.49799 .1168 L
.57422 .1144 L
.64753 .12714 L
.71506 .1545 L
.77414 .19543 L
.82247 .24832 L
.85814 .31107 L
.87975 .38125 L
.88647 .45608 L
.87801 .53264 L
.85472 .60792 L
.81751 .67896 L
.76783 .74298 L
.70765 .79746 L
.63931 .84027 L
.56551 .86972 L
.48914 .88467 L
.41319 .88451 L
.34065 .86927 L
.27437 .83953 L
.21694 .79647 L
.17062 .74178 L
.13722 .67759 L
.11806 .60644 L
.1139 .53111 L
.12488 .45455 L
.15059 .37978 L
.19001 .30973 L
.2416 .24715 L
.30332 .19449 L
.37277 .15382 L
.44721 .12673 L
.52372 .1143 L
.5993 .117 L
.67098 .13473 L
.73596 .1668 L
.79167 .21195 L
.83594 .2684 L
.86702 .33394 L
.88369 .406 L
.88531 .48174 L
.87181 .5582 L
.84372 .63238 L
.80213 .70137 L
.74869 .76245 L
.68549 .81323 L
.61501 .85171 L
.54001 .8764 L
Mistroke
.46345 .88631 L
.38831 .88106 L
.31757 .86086 L
.25398 .82649 L
.20005 .77931 L
.15789 .72117 L
.12915 .65435 L
.11497 .58147 L
.1159 .50539 L
.13191 .4291 L
.16236 .3556 L
.20606 .28776 L
.2613 .22825 L
.32591 .17941 L
.39735 .14315 L
.47281 .12089 L
.54935 .11351 L
.62395 .1213 L
.69368 .14395 L
.75581 .18058 L
.8079 .22974 L
.84791 .28951 L
.87427 .35754 L
.88593 .43116 L
.88245 .50748 L
.86396 .58351 L
.83119 .65626 L
.78542 .72288 L
.72844 .78075 L
.6625 .8276 L
.59019 .8616 L
.51433 .8814 L
.43791 .88624 L
.36393 .87592 L
.29529 .85084 L
.23468 .812 L
.18449 .76091 L
.14668 .69958 L
.12273 .63042 L
.11359 .55614 L
.11962 .47965 L
.14057 .40397 L
.17563 .33205 L
.22342 .26673 L
.28207 .21056 L
.34926 .16575 L
.42238 .13406 L
.49854 .11673 L
.57476 .11444 L
.64804 .12728 L
Mistroke
.71551 .15475 L
.77453 .19577 L
.82277 .24873 L
.85835 .31155 L
.87986 .38177 L
.88646 .45663 L
.87789 .53319 L
.8545 .60844 L
.81719 .67945 L
.76744 .7434 L
.70718 .79781 L
.6388 .84053 L
.56497 .86988 L
.48859 .88472 L
.41266 .88446 L
.34015 .86911 L
.27392 .83927 L
.21656 .79612 L
.17033 .74135 L
.13703 .6771 L
.11798 .60591 L
.11392 .53056 L
.12501 .45401 L
.15082 .37926 L
.19034 .30925 L
.242 .24673 L
.3038 .19415 L
.37329 .15357 L
.44775 .12659 L
.52427 .11426 L
.59983 .11707 L
.67148 .13491 L
.73639 .16708 L
.79203 .21231 L
.83621 .26884 L
.86719 .33443 L
.88376 .40653 L
.88527 .48229 L
.87166 .55875 L
.84346 .6329 L
.80179 .70183 L
.74827 .76285 L
.68501 .81355 L
.61448 .85194 L
.53946 .87652 L
.4629 .88633 L
.38779 .88097 L
.31708 .86066 L
.25356 .8262 L
.1997 .77893 L
Mistroke
.15763 .72072 L
Mfstroke
1 .086 0 r
.47166 .37267 m
.49822 .36638 L
.52485 .36533 L
.5505 .36956 L
.57417 .37892 L
.59493 .39302 L
.61197 .41133 L
.62461 .43311 L
.63236 .45752 L
.63491 .4836 L
.63217 .51032 L
.62425 .53663 L
.61145 .56151 L
.59427 .58397 L
.57339 .60314 L
.54964 .61826 L
.52393 .62874 L
.49729 .63417 L
.47075 .63433 L
.44536 .62922 L
.42212 .61904 L
.40193 .60418 L
.38559 .58524 L
.37374 .56295 L
.36685 .53819 L
.36518 .51194 L
.3688 .48521 L
.37757 .45906 L
.39115 .43453 L
.409 .41256 L
.43042 .39402 L
.45457 .37964 L
.4805 .36999 L
.5072 .36543 L
.53362 .36616 L
.55871 .37215 L
.58151 .38315 L
.6011 .39873 L
.61673 .41829 L
.62777 .44106 L
.6338 .46614 L
.63458 .49255 L
.63008 .51925 L
.62047 .54519 L
.60614 .56937 L
.58764 .59082 L
.5657 .6087 L
.54118 .62232 L
.51504 .63114 L
.48832 .63481 L
Mistroke
.46205 .63319 L
.43727 .62635 L
.41496 .61454 L
.39598 .59824 L
.38108 .57809 L
.37086 .55487 L
.3657 .52949 L
.36581 .50296 L
.37118 .47632 L
.38162 .4506 L
.3967 .42682 L
.41583 .40591 L
.43827 .3887 L
.46312 .37585 L
.48943 .36788 L
.51615 .36509 L
.54224 .36759 L
.56667 .3753 L
.58848 .38789 L
.60682 .40489 L
.62097 .42562 L
.63037 .44927 L
.63466 .47491 L
.63366 .50153 L
.62741 .52809 L
.61616 .55356 L
.60036 .57692 L
.58061 .59726 L
.55771 .61378 L
.53253 .62584 L
.50608 .63296 L
.4794 .63486 L
.45352 .63147 L
.42946 .62292 L
.40817 .60954 L
.39049 .59187 L
.37711 .57059 L
.36854 .54654 L
.36514 .52067 L
.36703 .49398 L
.37414 .46753 L
.38619 .44235 L
.4027 .41944 L
.42303 .39968 L
.44639 .38387 L
.47185 .37261 L
.49841 .36635 L
.52503 .36534 L
.55068 .36961 L
.57433 .379 L
Mistroke
.59507 .39314 L
.61207 .41147 L
.62468 .43328 L
.63239 .4577 L
.63491 .48379 L
.63214 .51051 L
.62417 .53682 L
.61134 .56168 L
.59413 .58412 L
.57323 .60327 L
.54946 .61835 L
.52374 .6288 L
.4971 .63419 L
.47057 .63431 L
.44519 .62916 L
.42196 .61894 L
.4018 .60406 L
.38549 .58509 L
.37367 .56278 L
.36681 .53801 L
.36518 .51174 L
.36884 .48502 L
.37765 .45888 L
.39126 .43436 L
.40914 .41241 L
.43058 .3939 L
.45475 .37955 L
.48069 .36994 L
.50739 .36542 L
.5338 .36619 L
.55889 .37221 L
.58166 .38324 L
.60123 .39886 L
.61682 .41844 L
.62783 .44123 L
.63383 .46632 L
.63457 .49274 L
.63003 .51944 L
.62039 .54537 L
.60602 .56953 L
.58749 .59096 L
.56553 .60882 L
.54099 .6224 L
.51485 .63119 L
.48813 .63482 L
.46187 .63316 L
.4371 .62628 L
.41481 .61444 L
.39586 .59811 L
.38099 .57793 L
Mistroke
.3708 .55469 L
.36568 .52931 L
.36583 .50277 L
.37124 .47613 L
.38171 .45042 L
.39682 .42666 L
.41598 .40577 L
.43844 .38859 L
.46331 .37578 L
.48962 .36784 L
.51634 .36509 L
.54242 .36763 L
.56684 .37537 L
.58863 .388 L
.60694 .40503 L
.62106 .42578 L
.63042 .44944 L
.63467 .47509 L
.63363 .50172 L
.62735 .52828 L
.61607 .55373 L
.60023 .57707 L
.58046 .59739 L
.55753 .61388 L
.53235 .62591 L
.50589 .63299 L
.47921 .63486 L
.45334 .63143 L
.4293 .62284 L
.40803 .60943 L
.39038 .59173 L
.37703 .57043 L
.3685 .54636 L
.36514 .52048 L
.36706 .49379 L
.37421 .46734 L
.38629 .44218 L
.40283 .41928 L
.42319 .39956 L
.44656 .38377 L
.47203 .37255 L
.4986 .36633 L
.52522 .36535 L
.55085 .36966 L
.57449 .37909 L
.5952 .39326 L
.61218 .41162 L
.62475 .43344 L
.63243 .45788 L
.63491 .48398 L
Mistroke
.6321 .5107 L
Mfstroke
1 0 .842 r
.37464 .29176 m
.42159 .26577 L
.47162 .24897 L
.52276 .24202 L
.573 .2452 L
.62038 .25837 L
.66304 .28103 L
.6993 .31228 L
.72774 .3509 L
.74723 .39538 L
.75703 .44395 L
.75674 .49473 L
.74637 .54571 L
.72633 .5949 L
.69742 .64037 L
.66075 .68033 L
.61777 .7132 L
.57017 .73772 L
.51982 .7529 L
.46869 .75816 L
.41879 .75328 L
.37208 .73847 L
.33038 .71429 L
.29535 .68171 L
.26834 .64199 L
.25043 .59671 L
.24231 .54762 L
.2443 .49667 L
.25633 .44585 L
.27793 .39715 L
.30823 .35249 L
.34607 .31362 L
.38994 .28207 L
.43814 .25906 L
.48876 .24551 L
.53982 .24195 L
.58932 .24852 L
.63532 .26496 L
.676 .29062 L
.70978 .3245 L
.73532 .36526 L
.75163 .41132 L
.75806 .46085 L
.75437 .51192 L
.74069 .56253 L
.71757 .61068 L
.6859 .65448 L
.64694 .69222 L
.60222 .72242 L
.55348 .74389 L
Mistroke
.50264 .75579 L
.4517 .75765 L
.40266 .7494 L
.35743 .73135 L
.31781 .70423 L
.28533 .6691 L
.26127 .62733 L
.24659 .58056 L
.24185 .53063 L
.24724 .47949 L
.26255 .42917 L
.28718 .38162 L
.32017 .33872 L
.36021 .30214 L
.40573 .27334 L
.45496 .25343 L
.50595 .24319 L
.55671 .24304 L
.60525 .25296 L
.64965 .27259 L
.68818 .30114 L
.71933 .33749 L
.74187 .38022 L
.75491 .42766 L
.75795 .47793 L
.75087 .52906 L
.73394 .57906 L
.70783 .62596 L
.67357 .66791 L
.63249 .70327 L
.58621 .73065 L
.53655 .74898 L
.48545 .75754 L
.43493 .756 L
.38696 .7444 L
.34342 .72322 L
.30603 .69327 L
.27626 .65574 L
.25526 .61209 L
.24387 .56405 L
.24253 .5135 L
.2513 .46241 L
.26982 .4128 L
.29738 .36661 L
.33289 .32566 L
.37496 .29154 L
.42194 .26561 L
.47198 .24888 L
.52312 .24201 L
.57335 .24526 L
Mistroke
.62071 .2585 L
.66332 .28123 L
.69953 .31254 L
.72791 .3512 L
.74734 .39571 L
.75706 .44431 L
.7567 .4951 L
.74626 .54608 L
.72616 .59525 L
.69718 .64068 L
.66046 .68059 L
.61745 .71341 L
.56982 .73786 L
.51946 .75297 L
.46833 .75816 L
.41844 .75321 L
.37176 .73833 L
.33011 .71409 L
.29512 .68145 L
.26818 .64169 L
.25034 .59637 L
.24229 .54726 L
.24436 .4963 L
.25646 .44549 L
.27811 .39682 L
.30848 .35219 L
.34636 .31337 L
.39028 .28187 L
.43849 .25893 L
.48913 .24545 L
.54019 .24197 L
.58967 .24861 L
.63563 .26511 L
.67627 .29084 L
.70999 .32477 L
.73547 .36558 L
.75171 .41166 L
.75807 .46122 L
.75431 .51229 L
.74056 .56288 L
.71737 .61101 L
.68565 .65477 L
.64664 .69247 L
.60188 .72261 L
.55312 .74401 L
.50228 .75584 L
.45134 .75762 L
.40232 .7493 L
.35713 .73119 L
.31755 .70401 L
Mistroke
.28512 .66882 L
.26113 .62701 L
.24652 .58021 L
.24185 .53026 L
.24731 .47913 L
.2627 .42881 L
.28739 .38129 L
.32043 .33843 L
.36051 .30191 L
.40607 .27316 L
.45532 .25332 L
.50632 .24315 L
.55707 .24307 L
.60558 .25307 L
.64995 .27276 L
.68844 .30137 L
.71952 .33778 L
.742 .38055 L
.75497 .42801 L
.75794 .47829 L
.75078 .52943 L
.73379 .57941 L
.70762 .62628 L
.6733 .66819 L
.63217 .70349 L
.58586 .73082 L
.53619 .74908 L
.48509 .75757 L
.43457 .75595 L
.38663 .74428 L
.34313 .72303 L
.30579 .69303 L
.27607 .65545 L
.25514 .61176 L
.24382 .5637 L
.24256 .51313 L
.25139 .46205 L
.26999 .41245 L
.29761 .3663 L
.33317 .32538 L
.37528 .29133 L
.42229 .26546 L
.47235 .2488 L
.52349 .24199 L
.57371 .24531 L
.62103 .25863 L
.66361 .28142 L
.69976 .31279 L
.72808 .3515 L
.74744 .39605 L
Mistroke
.7571 .44467 L
Mfstroke
.887 1 0 r
.21396 .51236 m
.22422 .45559 L
.24531 .40057 L
.27639 .34944 L
.31624 .30423 L
.36331 .2667 L
.41574 .23832 L
.47148 .22022 L
.52834 .21309 L
.58409 .21723 L
.63653 .23246 L
.68362 .25819 L
.7235 .29341 L
.75461 .33674 L
.77573 .38648 L
.78602 .44068 L
.7851 .4972 L
.77298 .55383 L
.75015 .60835 L
.7175 .65861 L
.67631 .70265 L
.62821 .73874 L
.57507 .76546 L
.51899 .78176 L
.46216 .787 L
.40682 .78098 L
.35514 .76393 L
.30914 .73653 L
.27063 .69984 L
.24112 .6553 L
.22177 .60468 L
.21334 .54994 L
.21616 .49324 L
.23013 .43681 L
.25468 .38286 L
.28886 .33351 L
.33133 .29069 L
.38041 .25609 L
.43419 .23105 L
.49056 .21658 L
.54729 .21322 L
.60217 .22112 L
.65304 .23997 L
.6979 .26902 L
.73499 .30714 L
.76286 .35282 L
.78042 .40428 L
.78697 .4595 L
.78226 .51631 L
.76647 .57247 L
Mistroke
.74022 .6258 L
.70455 .67418 L
.66085 .71573 L
.61083 .74882 L
.55647 .77213 L
.49989 .78477 L
.44331 .78623 L
.38896 .77646 L
.33896 .75584 L
.29529 .72518 L
.25965 .68568 L
.23344 .63889 L
.2177 .58665 L
.21303 .53101 L
.21963 .47416 L
.23723 .41832 L
.26514 .36568 L
.30227 .31832 L
.34716 .27808 L
.39805 .24656 L
.45294 .22498 L
.50967 .21419 L
.56603 .21463 L
.6198 .22626 L
.66886 .24863 L
.7113 .28087 L
.74544 .32171 L
.76995 .36955 L
.78387 .42251 L
.78665 .4785 L
.77817 .53535 L
.75878 .5908 L
.72924 .64269 L
.69069 .68898 L
.64467 .72786 L
.59296 .75779 L
.53761 .7776 L
.48078 .78652 L
.42471 .7842 L
.37159 .77072 L
.32351 .74661 L
.28235 .71283 L
.24974 .6707 L
.22695 .62186 L
.21488 .56825 L
.21399 .51195 L
.22434 .45519 L
.24549 .40018 L
.27664 .34909 L
.31656 .30393 L
Mistroke
.36367 .26646 L
.41613 .23815 L
.47189 .22012 L
.52875 .21308 L
.58448 .2173 L
.63689 .23261 L
.68393 .25841 L
.72376 .2937 L
.7548 .33708 L
.77584 .38686 L
.78606 .44107 L
.78505 .4976 L
.77285 .55423 L
.74995 .60872 L
.71723 .65895 L
.67599 .70294 L
.62784 .73897 L
.57468 .76562 L
.51858 .78184 L
.46176 .787 L
.40644 .7809 L
.35478 .76377 L
.30883 .73629 L
.27038 .69954 L
.24094 .65496 L
.22167 .6043 L
.21332 .54954 L
.21623 .49284 L
.23027 .43642 L
.25489 .38249 L
.28914 .33318 L
.33166 .29041 L
.38078 .25587 L
.43459 .23091 L
.49096 .21651 L
.54769 .21324 L
.60255 .22122 L
.65338 .24014 L
.69819 .26926 L
.73523 .30744 L
.76303 .35317 L
.78051 .40467 L
.78698 .4599 L
.78219 .51671 L
.76632 .57287 L
.74 .62616 L
.70426 .67451 L
.66051 .716 L
.61045 .74902 L
.55607 .77226 L
Mistroke
.49948 .78482 L
.44291 .7862 L
.38858 .77635 L
.33863 .75566 L
.295 .72493 L
.25943 .68537 L
.23329 .63853 L
.21763 .58626 L
.21304 .53061 L
.21972 .47375 L
.23739 .41793 L
.26537 .36532 L
.30257 .318 L
.3475 .27782 L
.39843 .24637 L
.45334 .22486 L
.51008 .21416 L
.56643 .21467 L
.62017 .22638 L
.66919 .24883 L
.71157 .28114 L
.74565 .32203 L
.77009 .36991 L
.78393 .4229 L
.78662 .47891 L
.77807 .53575 L
.75861 .59119 L
.72899 .64305 L
.69039 .68929 L
.64431 .7281 L
.59258 .75797 L
.5372 .77771 L
.48037 .78655 L
.42431 .78414 L
.37122 .77058 L
.32318 .74641 L
.28209 .71256 L
.24954 .67037 L
.22683 .62149 L
.21483 .56785 L
.21403 .51154 L
.22445 .45478 L
.24568 .3998 L
.2769 .34875 L
.31687 .30363 L
.36403 .26622 L
.41652 .23799 L
.47229 .22003 L
.52915 .21307 L
.58487 .21737 L
Mistroke
.63725 .23276 L
Mfstroke
0 .614 1 r
.51292 .66895 m
.47878 .6724 L
.44547 .66908 L
.4143 .65913 L
.38649 .64293 L
.36314 .62112 L
.34516 .59456 L
.33325 .56429 L
.32789 .53149 L
.32929 .49746 L
.33738 .46353 L
.35186 .43103 L
.37215 .40124 L
.39746 .37532 L
.42679 .35429 L
.45899 .33899 L
.49281 .33 L
.5269 .32769 L
.55995 .33213 L
.59063 .34317 L
.61777 .36036 L
.64027 .38303 L
.65728 .41029 L
.66811 .44107 L
.67234 .47417 L
.66982 .50828 L
.66062 .54206 L
.64512 .57419 L
.62393 .60341 L
.59787 .62858 L
.56797 .64869 L
.53541 .66297 L
.50145 .67086 L
.46744 .67204 L
.4347 .66647 L
.40453 .65436 L
.37811 .6362 L
.35647 .61269 L
.34046 .58476 L
.33071 .5535 L
.32761 .52014 L
.33127 .48599 L
.34155 .45239 L
.35806 .42067 L
.38013 .39205 L
.40691 .36767 L
.43734 .34848 L
.47023 .33524 L
.50429 .32847 L
.53818 .32843 L
Mistroke
.57057 .33512 L
.6002 .34828 L
.62589 .3674 L
.64664 .39172 L
.66163 .42029 L
.67028 .45199 L
.67225 .48557 L
.66746 .51972 L
.6561 .5531 L
.63861 .58439 L
.61568 .61237 L
.58821 .63594 L
.55728 .65417 L
.5241 .66636 L
.48997 .67201 L
.45624 .67092 L
.42423 .66311 L
.39519 .64891 L
.37026 .62886 L
.35043 .60375 L
.33646 .57457 L
.32892 .54247 L
.32808 .5087 L
.334 .47459 L
.34643 .44147 L
.36489 .41065 L
.38865 .38334 L
.41677 .36061 L
.44817 .34334 L
.4816 .33223 L
.51575 .3277 L
.54929 .32993 L
.58089 .33884 L
.60931 .35407 L
.63345 .37503 L
.65235 .40089 L
.66526 .43064 L
.6717 .46312 L
.67139 .49704 L
.66436 .53108 L
.65088 .5639 L
.63147 .59421 L
.60691 .62082 L
.57815 .64269 L
.54632 .65897 L
.51268 .669 L
.47854 .6724 L
.44524 .66903 L
.41409 .65903 L
.38631 .64279 L
Mistroke
.36299 .62095 L
.34505 .59436 L
.33319 .56406 L
.32788 .53125 L
.32932 .49722 L
.33746 .46329 L
.35198 .43081 L
.37231 .40104 L
.39765 .37515 L
.42701 .35416 L
.45923 .3389 L
.49305 .32996 L
.52715 .32769 L
.56018 .33219 L
.59084 .34327 L
.61794 .3605 L
.64042 .38321 L
.65738 .4105 L
.66817 .4413 L
.67235 .47441 L
.66977 .50852 L
.66053 .5423 L
.64499 .57441 L
.62376 .60361 L
.59767 .62874 L
.56775 .64882 L
.53517 .66305 L
.50121 .67089 L
.4672 .67202 L
.43448 .6664 L
.40433 .65425 L
.37793 .63605 L
.35633 .6125 L
.34036 .58454 L
.33066 .55327 L
.32761 .5199 L
.33132 .48575 L
.34165 .45216 L
.3582 .42045 L
.38031 .39186 L
.40712 .36751 L
.43757 .34837 L
.47047 .33517 L
.50454 .32845 L
.53842 .32845 L
.5708 .33519 L
.60039 .3484 L
.62605 .36756 L
.64676 .39191 L
.66172 .42051 L
Mistroke
.67032 .45222 L
.67224 .48582 L
.6674 .51997 L
.65599 .55333 L
.63846 .5846 L
.61549 .61255 L
.588 .63609 L
.55704 .65428 L
.52385 .66642 L
.48973 .67203 L
.456 .67088 L
.42401 .66303 L
.39499 .64878 L
.3701 .6287 L
.3503 .60356 L
.33638 .57435 L
.32889 .54223 L
.3281 .50845 L
.33406 .47434 L
.34654 .44124 L
.36504 .41044 L
.38883 .38316 L
.41699 .36046 L
.4484 .34324 L
.48185 .33217 L
.516 .32769 L
.54952 .32997 L
.5811 .33892 L
.6095 .3542 L
.6336 .3752 L
.65246 .40109 L
.66533 .43087 L
.67172 .46336 L
.67137 .49729 L
.66429 .53132 L
.65076 .56413 L
.63131 .59441 L
.60672 .621 L
.57793 .64283 L
.54609 .65906 L
.51244 .66905 L
.47829 .6724 L
.44501 .66899 L
.41387 .65894 L
.38612 .64266 L
.36284 .62077 L
.34494 .59415 L
.33313 .56383 L
.32787 .53101 L
.32936 .49697 L
Mistroke
.33755 .46305 L
Mfstroke
0 .714 1 r
.27104 .26137 m
.32863 .21463 L
.39295 .17909 L
.46147 .15615 L
.5315 .1467 L
.6003 .15112 L
.66516 .16923 L
.72354 .20032 L
.77314 .24317 L
.81203 .29611 L
.83867 .35704 L
.85202 .42358 L
.85155 .49313 L
.83728 .56294 L
.80978 .63028 L
.77012 .69251 L
.71986 .74719 L
.66098 .79216 L
.59577 .82567 L
.5268 .8464 L
.45679 .85353 L
.38847 .84678 L
.32452 .82643 L
.26746 .79327 L
.21953 .74859 L
.18261 .69416 L
.15814 .63211 L
.14709 .56488 L
.14989 .4951 L
.16643 .42551 L
.19606 .35884 L
.23762 .29772 L
.28948 .24453 L
.3496 .20137 L
.41562 .16993 L
.48495 .15144 L
.55488 .14664 L
.62265 .1557 L
.6856 .17827 L
.74127 .21347 L
.78748 .25992 L
.8224 .31578 L
.84467 .37888 L
.85341 .44673 L
.84828 .51667 L
.82948 .58596 L
.79776 .65187 L
.75434 .71183 L
.70095 .76347 L
.63967 .80477 L
Mistroke
.5729 .8341 L
.50328 .85033 L
.43352 .85281 L
.36638 .84144 L
.30448 .81667 L
.25025 .77947 L
.20583 .73131 L
.17295 .67407 L
.1529 .60999 L
.14648 .5416 L
.15393 .47158 L
.17497 .40267 L
.20876 .33758 L
.25398 .27887 L
.30885 .22883 L
.37123 .18944 L
.43866 .16223 L
.5085 .14828 L
.578 .14814 L
.64445 .1618 L
.70522 .18874 L
.75794 .22789 L
.80054 .27772 L
.83134 .33628 L
.84914 .40126 L
.85324 .47011 L
.84347 .54014 L
.82022 .6086 L
.78441 .67279 L
.73743 .7302 L
.68114 .77857 L
.61774 .81602 L
.54971 .84106 L
.47974 .85271 L
.41056 .85052 L
.34489 .83458 L
.28531 .80551 L
.23415 .76444 L
.19343 .713 L
.16474 .6532 L
.1492 .58738 L
.14744 .51814 L
.15951 .44818 L
.18494 .38026 L
.22274 .31704 L
.27142 .26099 L
.32907 .21433 L
.39343 .17888 L
.46197 .15603 L
.53201 .14668 L
Mistroke
.60078 .1512 L
.66561 .16941 L
.72393 .20059 L
.77346 .24352 L
.81226 .29652 L
.83881 .3575 L
.85206 .42408 L
.8515 .49363 L
.83713 .56344 L
.80954 .63075 L
.7698 .69294 L
.71947 .74755 L
.66053 .79245 L
.59528 .82587 L
.5263 .8465 L
.45629 .85353 L
.38799 .84669 L
.32408 .82624 L
.26709 .79299 L
.21923 .74824 L
.18239 .69374 L
.15801 .63165 L
.14706 .56438 L
.14996 .49459 L
.1666 .42502 L
.19632 .35838 L
.23796 .29731 L
.28988 .24418 L
.35005 .2011 L
.41611 .16975 L
.48545 .15136 L
.55537 .14665 L
.62312 .15581 L
.68603 .17848 L
.74164 .21377 L
.78777 .26028 L
.82261 .31621 L
.84478 .37935 L
.85342 .44723 L
.84819 .51717 L
.8293 .58645 L
.79749 .65233 L
.75399 .71223 L
.70053 .7638 L
.6392 .80502 L
.57241 .83427 L
.50277 .8504 L
.43303 .85278 L
.36592 .84131 L
.30406 .81645 L
Mistroke
.2499 .77917 L
.20555 .73093 L
.17276 .67363 L
.15281 .60951 L
.14649 .5411 L
.15404 .47108 L
.17516 .40218 L
.20904 .33713 L
.25434 .27847 L
.30927 .22851 L
.3717 .1892 L
.43915 .16208 L
.509 .14823 L
.57849 .14819 L
.6449 .16195 L
.70563 .18898 L
.75828 .22821 L
.8008 .27811 L
.83152 .33672 L
.84922 .40174 L
.85322 .47062 L
.84335 .54064 L
.82001 .60907 L
.78411 .67323 L
.73706 .73058 L
.68071 .77888 L
.61726 .81624 L
.54921 .84119 L
.47924 .85275 L
.41007 .85046 L
.34444 .83442 L
.28491 .80525 L
.23382 .76411 L
.19318 .7126 L
.16458 .65274 L
.14914 .58689 L
.14748 .51764 L
.15965 .44768 L
.18517 .37979 L
.22305 .31661 L
.27181 .26062 L
.32951 .21404 L
.39391 .17867 L
.46247 .15592 L
.53251 .14667 L
.60126 .15128 L
.66605 .16959 L
.72432 .20086 L
.77378 .24387 L
.8125 .29693 L
Mistroke
.83895 .35796 L
Mfstroke
1 0 .938 r
.29702 .68937 m
.26842 .65003 L
.2489 .60479 L
.23924 .55545 L
.23982 .50393 L
.25061 .45225 L
.27118 .40245 L
.30074 .35648 L
.33811 .31614 L
.38184 .28302 L
.43021 .25841 L
.48131 .24328 L
.53315 .23823 L
.58369 .24345 L
.63094 .25874 L
.67305 .2835 L
.70838 .31676 L
.73552 .3572 L
.75342 .40325 L
.76138 .4531 L
.75908 .50479 L
.74661 .55629 L
.72446 .60558 L
.6935 .65073 L
.65495 .68996 L
.61032 .72174 L
.56135 .74481 L
.50998 .75828 L
.45822 .76161 L
.4081 .75467 L
.36158 .73774 L
.3205 .71148 L
.28646 .67692 L
.26081 .63541 L
.24453 .58859 L
.23829 .5383 L
.24232 .4865 L
.25646 .43523 L
.28015 .3865 L
.31248 .34223 L
.35216 .30415 L
.39765 .27375 L
.44715 .25224 L
.49873 .24044 L
.55036 .23884 L
.60001 .24748 L
.64574 .26604 L
.68574 .29378 L
.71846 .32961 L
.7426 .37212 L
Mistroke
.75723 .41966 L
.76175 .47035 L
.75601 .5222 L
.74021 .57318 L
.71499 .62129 L
.68133 .66464 L
.64056 .70153 L
.59427 .73051 L
.54428 .75044 L
.49255 .76054 L
.44111 .76042 L
.39199 .75008 L
.3471 .72992 L
.30822 .70074 L
.27686 .66368 L
.25426 .6202 L
.2413 .572 L
.2385 .52097 L
.24595 .46912 L
.26338 .41849 L
.2901 .37105 L
.32505 .32867 L
.36687 .29302 L
.41392 .26549 L
.46434 .24716 L
.51616 .23876 L
.56735 .24061 L
.61589 .25264 L
.65989 .27437 L
.69761 .30497 L
.72758 .34321 L
.74861 .38761 L
.75989 .43642 L
.76097 .48773 L
.7518 .53952 L
.73276 .58975 L
.70457 .63647 L
.66836 .67782 L
.62555 .7122 L
.5778 .73826 L
.527 .75496 L
.47515 .76165 L
.42426 .75808 L
.37635 .74437 L
.3333 .72108 L
.29678 .68911 L
.26824 .64972 L
.2488 .60445 L
.23921 .55509 L
.23986 .50356 L
Mistroke
.25072 .45189 L
.27136 .40211 L
.30098 .35617 L
.3384 .31588 L
.38217 .28281 L
.43056 .25827 L
.48168 .24321 L
.53352 .23823 L
.58404 .24353 L
.63126 .25889 L
.67333 .28371 L
.7086 .31702 L
.73568 .35751 L
.75352 .4036 L
.7614 .45347 L
.75902 .50516 L
.74648 .55665 L
.72427 .60592 L
.69325 .65103 L
.65465 .69022 L
.60998 .72194 L
.56099 .74495 L
.50961 .75834 L
.45786 .7616 L
.40775 .75459 L
.36127 .73759 L
.32023 .71126 L
.28625 .67664 L
.26065 .63509 L
.24445 .58824 L
.23828 .53793 L
.24238 .48612 L
.25659 .43487 L
.28036 .38616 L
.31274 .34193 L
.35247 .3039 L
.39799 .27356 L
.44752 .25212 L
.49911 .2404 L
.55073 .23886 L
.60036 .24758 L
.64605 .26621 L
.68601 .294 L
.71867 .32989 L
.74274 .37245 L
.75729 .42001 L
.76175 .47072 L
.75593 .52257 L
.74007 .57354 L
.71478 .62162 L
Mistroke
.68107 .66493 L
.64025 .70177 L
.59392 .73068 L
.54391 .75055 L
.49218 .76058 L
.44075 .76038 L
.39165 .74997 L
.3468 .72974 L
.30796 .7005 L
.27666 .66339 L
.25413 .61987 L
.24124 .57164 L
.23851 .5206 L
.24604 .46875 L
.26354 .41813 L
.29032 .37072 L
.32533 .32839 L
.36719 .29279 L
.41427 .26532 L
.46471 .24707 L
.51653 .23873 L
.56771 .24066 L
.61623 .25276 L
.66018 .27456 L
.69785 .30521 L
.72776 .34351 L
.74873 .38795 L
.75993 .43678 L
.76094 .4881 L
.7517 .53988 L
.73259 .5901 L
.70434 .63678 L
.66808 .6781 L
.62522 .71242 L
.57745 .73841 L
.52663 .75504 L
.47478 .76166 L
.42391 .75801 L
.37603 .74424 L
.33301 .72088 L
.29655 .68885 L
.26807 .64941 L
.24869 .60411 L
.23918 .55472 L
.2399 .50318 L
.25083 .45152 L
.27154 .40176 L
.30122 .35586 L
.3387 .31561 L
.3825 .2826 L
Mistroke
.43092 .25812 L
Mfstroke
1 .328 0 r
.5733 .24899 m
.61991 .26225 L
.66182 .28483 L
.69738 .31586 L
.72519 .35412 L
.74416 .3981 L
.75355 .44608 L
.75299 .49618 L
.7425 .54643 L
.7225 .59485 L
.69376 .63956 L
.65741 .67878 L
.61489 .71099 L
.56786 .73492 L
.51817 .74963 L
.46777 .75454 L
.41862 .74946 L
.37268 .73459 L
.33173 .71052 L
.29738 .67818 L
.27099 .63885 L
.25358 .59407 L
.24584 .5456 L
.24808 .49534 L
.26021 .44526 L
.28175 .39733 L
.31185 .35343 L
.34933 .31529 L
.39273 .28439 L
.44034 .26195 L
.49029 .24886 L
.54062 .24562 L
.58936 .25236 L
.63459 .26883 L
.67454 .29436 L
.70764 .32797 L
.73259 .36833 L
.74841 .41386 L
.75448 .46276 L
.75056 .51313 L
.73682 .56299 L
.71377 .61037 L
.68234 .65342 L
.64375 .69044 L
.59952 .72 L
.55138 .74092 L
.50123 .75239 L
.45103 .75395 L
.40275 .74554 L
.35829 .7275 L
Mistroke
.31939 .70053 L
.28757 .66569 L
.2641 .62434 L
.24988 .57812 L
.24548 .52883 L
.25107 .47841 L
.26642 .42884 L
.29095 .38206 L
.32368 .33991 L
.36333 .30404 L
.40834 .27586 L
.45695 .25648 L
.50725 .24665 L
.55726 .24677 L
.60503 .25683 L
.64868 .27643 L
.68649 .30481 L
.71698 .34084 L
.73895 .38312 L
.75155 .42999 L
.75428 .47961 L
.74703 .53002 L
.73008 .57926 L
.7041 .62539 L
.67011 .6666 L
.62945 .70126 L
.5837 .72803 L
.53467 .74585 L
.48428 .75402 L
.43451 .75223 L
.38731 .74053 L
.34453 .71939 L
.30785 .68964 L
.27871 .65245 L
.25826 .60928 L
.24729 .56182 L
.24624 .51193 L
.25516 .46157 L
.27368 .41273 L
.30108 .3673 L
.33629 .32709 L
.37792 .29366 L
.42435 .26833 L
.47374 .25209 L
.52417 .24558 L
.57364 .24905 L
.62023 .26238 L
.6621 .28503 L
.69761 .31611 L
.72536 .35442 L
Mistroke
.74426 .39844 L
.75358 .44644 L
.75295 .49654 L
.74239 .54678 L
.72232 .59519 L
.69352 .63986 L
.65713 .67904 L
.61457 .71119 L
.56752 .73506 L
.51781 .7497 L
.46741 .75454 L
.41828 .74939 L
.37236 .73445 L
.33146 .71031 L
.29716 .67792 L
.27083 .63855 L
.25349 .59374 L
.24582 .54525 L
.24813 .49498 L
.26033 .44491 L
.28193 .397 L
.31209 .35314 L
.34963 .31504 L
.39306 .28419 L
.44069 .26182 L
.49066 .2488 L
.54098 .24563 L
.5897 .25245 L
.6349 .26898 L
.6748 .29458 L
.70785 .32824 L
.73273 .36864 L
.74849 .4142 L
.75449 .46312 L
.7505 .51349 L
.73668 .56334 L
.71358 .61069 L
.68209 .6537 L
.64345 .69068 L
.59919 .72018 L
.55103 .74104 L
.50087 .75243 L
.45067 .75392 L
.40242 .74544 L
.35799 .72733 L
.31913 .7003 L
.28737 .66541 L
.26396 .62403 L
.24981 .57777 L
.24548 .52847 L
Mistroke
.25114 .47805 L
.26657 .42849 L
.29115 .38174 L
.32394 .33962 L
.36363 .30381 L
.40868 .27569 L
.4573 .25637 L
.50761 .24662 L
.55761 .24681 L
.60536 .25694 L
.64897 .2766 L
.68673 .30504 L
.71717 .34112 L
.73908 .38345 L
.75161 .43034 L
.75426 .47997 L
.74694 .53038 L
.72992 .57961 L
.70388 .6257 L
.66984 .66687 L
.62914 .70149 L
.58336 .72819 L
.53432 .74595 L
.48392 .75405 L
.43416 .75218 L
.38698 .74041 L
.34424 .71921 L
.30761 .6894 L
.27853 .65216 L
.25814 .60895 L
.24725 .56147 L
.24627 .51157 L
.25525 .46122 L
.27384 .41239 L
.3013 .36699 L
.33657 .32682 L
.37824 .29345 L
.42469 .26818 L
.4741 .25201 L
.52453 .24557 L
.57399 .24911 L
.62055 .26251 L
.66238 .28522 L
.69783 .31636 L
.72552 .35472 L
.74436 .39877 L
.75361 .44679 L
.75291 .49691 L
.74228 .54714 L
.72214 .59552 L
Mistroke
.69329 .64016 L
Mfstroke
0 1 .934 r
.56824 .83131 m
.49938 .8466 L
.43054 .84828 L
.36443 .8363 L
.30364 .81111 L
.25055 .77372 L
.20726 .72558 L
.17545 .6686 L
.15638 .60499 L
.1508 .53726 L
.15892 .46808 L
.18043 .40014 L
.21448 .33612 L
.25973 .27854 L
.31442 .22965 L
.37638 .19136 L
.4432 .16519 L
.51225 .15216 L
.58082 .15278 L
.64621 .16703 L
.70587 .19435 L
.75745 .23366 L
.79892 .28342 L
.82866 .34168 L
.84551 .40616 L
.84879 .47432 L
.83839 .54349 L
.8147 .61095 L
.77867 .67406 L
.73169 .73033 L
.67563 .77757 L
.61267 .81391 L
.54529 .83793 L
.47613 .84869 L
.40791 .84577 L
.3433 .82927 L
.28485 .79986 L
.23484 .75867 L
.19523 .70733 L
.16758 .64786 L
.15298 .58258 L
.152 .51406 L
.16468 .44499 L
.19052 .37808 L
.2285 .31596 L
.27714 .26105 L
.33452 .21553 L
.3984 .18117 L
.46627 .15932 L
.53546 .15084 L
Mistroke
.60326 .15606 L
.667 .17479 L
.72419 .20627 L
.77259 .24929 L
.81028 .30214 L
.8358 .36276 L
.84814 .42876 L
.84682 .49756 L
.83188 .56646 L
.80392 .63275 L
.76403 .69383 L
.71378 .7473 L
.65514 .79106 L
.59041 .82341 L
.52214 .84306 L
.45299 .84924 L
.38569 .84172 L
.32287 .82079 L
.26701 .78727 L
.22029 .74248 L
.18455 .68816 L
.16119 .62647 L
.15112 .55981 L
.15475 .4908 L
.17193 .42216 L
.20198 .35657 L
.24373 .29661 L
.29553 .24463 L
.35537 .20267 L
.42087 .17238 L
.48948 .15495 L
.55851 .15106 L
.62524 .16087 L
.68705 .18399 L
.74152 .2195 L
.78652 .26603 L
.82027 .32174 L
.84145 .38444 L
.84923 .45168 L
.8433 .52082 L
.8239 .58914 L
.79179 .65396 L
.74823 .71274 L
.69492 .76317 L
.63397 .80327 L
.56776 .83147 L
.49888 .84666 L
.43006 .84824 L
.36397 .83616 L
.30323 .81089 L
Mistroke
.25021 .77341 L
.20699 .7252 L
.17527 .66816 L
.1563 .60452 L
.15081 .53677 L
.15903 .46758 L
.18063 .39967 L
.21476 .33569 L
.26009 .27816 L
.31484 .22933 L
.37685 .19113 L
.44369 .16505 L
.51275 .15212 L
.5813 .15284 L
.64666 .16718 L
.70627 .19459 L
.75778 .23398 L
.79918 .28381 L
.82883 .34213 L
.84558 .40664 L
.84877 .47482 L
.83826 .54398 L
.81449 .61142 L
.77837 .67449 L
.73132 .7307 L
.6752 .77787 L
.6122 .81413 L
.5448 .83806 L
.47564 .84872 L
.40743 .8457 L
.34286 .82911 L
.28446 .7996 L
.23451 .75834 L
.19499 .70693 L
.16743 .64741 L
.15293 .5821 L
.15205 .51357 L
.16482 .4445 L
.19075 .37762 L
.22881 .31553 L
.27752 .26069 L
.33496 .21524 L
.39888 .18096 L
.46676 .15921 L
.53595 .15083 L
.60373 .15615 L
.66744 .17497 L
.72458 .20654 L
.7729 .24963 L
.81051 .30255 L
Mistroke
.83594 .36322 L
.84818 .42925 L
.84676 .49806 L
.83172 .56695 L
.80367 .63321 L
.76371 .69424 L
.71339 .74765 L
.6547 .79134 L
.58993 .82359 L
.52164 .84315 L
.4525 .84924 L
.38522 .84162 L
.32245 .82059 L
.26664 .78699 L
.21999 .74212 L
.18434 .68775 L
.16107 .62601 L
.1511 .55932 L
.15483 .49031 L
.1721 .42167 L
.20224 .35611 L
.24407 .2962 L
.29594 .24429 L
.35582 .20241 L
.42136 .17221 L
.48998 .15488 L
.559 .15109 L
.6257 .16099 L
.68747 .1842 L
.74188 .2198 L
.7868 .2664 L
.82047 .32217 L
.84155 .38491 L
.84923 .45218 L
.84321 .52132 L
.82372 .58962 L
.79152 .6544 L
.74788 .71313 L
.69451 .76349 L
.63351 .80351 L
.56727 .83162 L
.49839 .84672 L
.42957 .8482 L
.36352 .83603 L
.30282 .81066 L
.24986 .7731 L
.20672 .72482 L
.17509 .66772 L
.15621 .60404 L
.15082 .53628 L
Mistroke
.15914 .46709 L
Mfstroke
0 .258 1 r
.82762 .36526 m
.83983 .42965 L
.8387 .4968 L
.82427 .56408 L
.79712 .62884 L
.75831 .68855 L
.70937 .74086 L
.6522 .78371 L
.58906 .81543 L
.52243 .83477 L
.45492 .84098 L
.38917 .8338 L
.32778 .81352 L
.27314 .78093 L
.22741 .73732 L
.19238 .6844 L
.16941 .62424 L
.15943 .5592 L
.16281 .49184 L
.17942 .4248 L
.20861 .36071 L
.24924 .30209 L
.29971 .25124 L
.35804 .21015 L
.42195 .18043 L
.48891 .16325 L
.55631 .1593 L
.6215 .16871 L
.68193 .19112 L
.73521 .22566 L
.77926 .27096 L
.81235 .32526 L
.83319 .38641 L
.84094 .45201 L
.83532 .51951 L
.81654 .58623 L
.78533 .64957 L
.74292 .70705 L
.69099 .75639 L
.63155 .79568 L
.56696 .82335 L
.49973 .83834 L
.43252 .84005 L
.36795 .82842 L
.30857 .8039 L
.2567 .76744 L
.21438 .7205 L
.18327 .6649 L
.16458 .60282 L
.15907 .53672 L
Mistroke
.16693 .46917 L
.18786 .40283 L
.22105 .3403 L
.26518 .28405 L
.31853 .23626 L
.379 .19883 L
.44422 .17322 L
.51162 .16043 L
.57858 .16097 L
.64244 .17482 L
.70072 .20142 L
.75112 .23975 L
.79167 .28829 L
.82076 .34513 L
.83727 .40806 L
.84055 .47459 L
.83045 .54212 L
.80739 .608 L
.77227 .66964 L
.72646 .72462 L
.67176 .77079 L
.61032 .80633 L
.54455 .82984 L
.47703 .84041 L
.41042 .83762 L
.34732 .82159 L
.29021 .79293 L
.24134 .75277 L
.20261 .70269 L
.17556 .64466 L
.16124 .58095 L
.16022 .51407 L
.17253 .44663 L
.19769 .38129 L
.23472 .3206 L
.28216 .26696 L
.33815 .22246 L
.40049 .18886 L
.46673 .16746 L
.53428 .15912 L
.60049 .16415 L
.66275 .18237 L
.71863 .21305 L
.76592 .25499 L
.80278 .30655 L
.82775 .3657 L
.83987 .43012 L
.83864 .49729 L
.82412 .56456 L
.79689 .62929 L
Mistroke
.758 .68895 L
.70898 .7412 L
.65177 .78398 L
.5886 .81562 L
.52195 .83487 L
.45444 .84097 L
.38872 .8337 L
.32736 .81333 L
.27278 .78066 L
.22712 .73697 L
.19217 .68399 L
.1693 .62379 L
.1594 .55872 L
.16288 .49136 L
.17958 .42433 L
.20886 .36027 L
.24957 .3017 L
.3001 .25091 L
.35848 .20989 L
.42242 .18026 L
.4894 .16318 L
.55679 .15932 L
.62196 .16882 L
.68234 .19133 L
.73556 .22595 L
.77954 .27132 L
.81255 .32567 L
.83329 .38686 L
.84095 .45249 L
.83523 .51999 L
.81635 .5867 L
.78506 .65001 L
.74258 .70743 L
.69058 .75671 L
.63111 .79592 L
.56648 .82351 L
.49925 .8384 L
.43204 .84002 L
.36751 .82829 L
.30817 .80368 L
.25636 .76714 L
.21411 .72013 L
.18309 .66447 L
.1645 .60236 L
.15908 .53623 L
.16703 .46869 L
.18806 .40236 L
.22133 .33988 L
.26553 .28367 L
.31894 .23596 L
Mistroke
.37945 .19861 L
.44469 .17308 L
.51211 .16039 L
.57905 .16102 L
.64288 .17496 L
.70111 .20166 L
.75145 .24006 L
.79192 .28867 L
.82093 .34557 L
.83734 .40853 L
.84052 .47508 L
.83033 .54261 L
.80718 .60846 L
.77198 .67006 L
.72609 .72499 L
.67134 .77108 L
.60986 .80654 L
.54407 .82996 L
.47655 .84044 L
.40995 .83756 L
.34688 .82142 L
.28983 .79268 L
.24102 .75244 L
.20238 .7023 L
.17541 .64422 L
.16119 .58048 L
.16026 .51358 L
.17267 .44615 L
.19792 .38083 L
.23503 .32019 L
.28253 .26661 L
.33857 .22218 L
.40095 .18866 L
.46721 .16735 L
.53477 .15911 L
.60095 .16424 L
.66318 .18254 L
.719 .21331 L
.76622 .25533 L
.803 .30695 L
.82789 .36615 L
.8399 .4306 L
.83858 .49777 L
.82397 .56503 L
.79665 .62974 L
.75768 .68936 L
.7086 .74154 L
.65133 .78425 L
.58813 .8158 L
.52146 .83496 L
Mistroke
.45396 .84097 L
Mfstroke
1 .727 0 r
.2354 .23501 m
.29982 .18105 L
.37209 .13961 L
.44938 .11232 L
.52866 .10024 L
.60681 .10385 L
.68077 .12301 L
.74764 .15696 L
.80479 .20438 L
.84998 .26339 L
.88143 .3317 L
.89791 .40661 L
.89878 .48518 L
.88399 .56434 L
.85414 .64097 L
.81038 .71206 L
.75445 .77484 L
.68853 .82683 L
.61521 .86599 L
.53737 .89079 L
.45806 .90025 L
.3804 .89401 L
.30743 .8723 L
.24202 .83597 L
.18673 .78647 L
.14374 .72572 L
.11473 .65611 L
.10085 .58038 L
.10262 .50149 L
.11999 .42254 L
.15228 .34663 L
.19821 .27674 L
.25599 .21562 L
.32334 .16565 L
.39762 .12881 L
.47593 .10653 L
.55518 .0997 L
.63226 .10857 L
.70415 .13281 L
.76803 .17146 L
.82139 .223 L
.86214 .28542 L
.88868 .35625 L
.89996 .43273 L
.89554 .51185 L
.8756 .5905 L
.84092 .6656 L
.79286 .7342 L
.73331 .79361 L
.6646 .84149 L
Mistroke
.58943 .87598 L
.51075 .89571 L
.43165 .89991 L
.35523 .88841 L
.28449 .86167 L
.22221 .82074 L
.17084 .76722 L
.13238 .70321 L
.10835 .63123 L
.09969 .55409 L
.10674 .47484 L
.12922 .39657 L
.16626 .32236 L
.21639 .25512 L
.27765 .19749 L
.34765 .15174 L
.42362 .11965 L
.50258 .10249 L
.58145 .10093 L
.65712 .11503 L
.72662 .14424 L
.78723 .18742 L
.83657 .24286 L
.8727 .30839 L
.8942 .38144 L
.90023 .45915 L
.89055 .53846 L
.86555 .61626 L
.8262 .68949 L
.77404 .75529 L
.71114 .81107 L
.63994 .85465 L
.56326 .8843 L
.48409 .89887 L
.40554 .89779 L
.33071 .88109 L
.26251 .84944 L
.20364 .80408 L
.1564 .74678 L
.12264 .6798 L
.1037 .60576 L
.1003 .52757 L
.11259 .44829 L
.14009 .37105 L
.18171 .29887 L
.23583 .23458 L
.30031 .18071 L
.37263 .13937 L
.44994 .11218 L
.52923 .10021 L
Mistroke
.60736 .10393 L
.68128 .1232 L
.74809 .15726 L
.80516 .20476 L
.85025 .26385 L
.8816 .33222 L
.89797 .40716 L
.89872 .48575 L
.88383 .5649 L
.85387 .6415 L
.81002 .71255 L
.75401 .77525 L
.68802 .82716 L
.61466 .86622 L
.5368 .89091 L
.45749 .90026 L
.37985 .8939 L
.30693 .87209 L
.24159 .83566 L
.18638 .78607 L
.14348 .72525 L
.11458 .65559 L
.1008 .57982 L
.10269 .50092 L
.12017 .42198 L
.15256 .34611 L
.19858 .27627 L
.25644 .21522 L
.32385 .16534 L
.39818 .1286 L
.4765 .10643 L
.55574 .09971 L
.6328 .10869 L
.70464 .13304 L
.76845 .17179 L
.82173 .22341 L
.86238 .2859 L
.88881 .35678 L
.89998 .43329 L
.89545 .51241 L
.8754 .59105 L
.84062 .66612 L
.79247 .73466 L
.73285 .79399 L
.66408 .84179 L
.58887 .87617 L
.51018 .89579 L
.43109 .89988 L
.3547 .88827 L
.28401 .86143 L
Mistroke
.2218 .8204 L
.17051 .76679 L
.13215 .70272 L
.10823 .63069 L
.09968 .55353 L
.10684 .47427 L
.12944 .39602 L
.16657 .32185 L
.21679 .25467 L
.27813 .19712 L
.34817 .15146 L
.42417 .11947 L
.50315 .10242 L
.58201 .10098 L
.65764 .11519 L
.72709 .14451 L
.78763 .18777 L
.83688 .2433 L
.8729 .30889 L
.8943 .38199 L
.90021 .45971 L
.89043 .53902 L
.86531 .6168 L
.82587 .68999 L
.77363 .75573 L
.71065 .81143 L
.63941 .85491 L
.56269 .88446 L
.48352 .89892 L
.40499 .89772 L
.33019 .88092 L
.26205 .84917 L
.20326 .80371 L
.15611 .74633 L
.12245 .67929 L
.10362 .60521 L
.10033 .527 L
.11274 .44773 L
.14034 .37051 L
.18206 .29838 L
.23626 .23415 L
.3008 .18036 L
.37317 .13912 L
.45051 .11204 L
.52979 .10018 L
.60791 .10402 L
.68179 .12339 L
.74854 .15755 L
.80553 .20515 L
.85053 .26431 L
Mistroke
.88177 .33273 L
Mfstroke
1 .547 0 r
.71583 .65386 m
.67567 .69754 L
.62861 .73348 L
.5765 .76025 L
.52139 .7768 L
.46544 .7825 L
.41085 .7771 L
.35976 .76083 L
.31417 .73433 L
.27587 .69863 L
.24637 .65513 L
.22682 .60554 L
.218 .55182 L
.22024 .49606 L
.23346 .44045 L
.25714 .38718 L
.29036 .33834 L
.3318 .29584 L
.37984 .26136 L
.4326 .23624 L
.488 .22147 L
.54388 .21764 L
.59803 .22488 L
.64833 .24292 L
.69282 .27106 L
.72973 .30817 L
.75763 .35282 L
.77542 .40324 L
.7824 .45746 L
.7783 .51335 L
.76327 .56871 L
.73792 .62138 L
.70322 .66929 L
.66055 .71055 L
.61158 .74354 L
.55823 .76698 L
.50259 .77994 L
.44685 .78192 L
.3932 .77283 L
.34374 .75303 L
.30041 .7233 L
.26492 .68481 L
.23865 .63907 L
.22264 .58787 L
.21751 .53321 L
.22347 .47726 L
.24028 .4222 L
.26729 .37019 L
.30343 .32328 L
.34728 .2833 L
Mistroke
.39713 .25182 L
.45101 .23009 L
.50682 .21895 L
.56236 .21884 L
.61545 .22976 L
.66401 .25129 L
.70613 .28258 L
.74017 .3224 L
.76478 .3692 L
.77899 .42112 L
.78226 .47615 L
.77445 .5321 L
.75587 .5868 L
.72725 .63809 L
.68971 .68397 L
.64472 .72262 L
.59405 .75253 L
.5397 .77254 L
.48378 .78185 L
.4285 .78009 L
.37603 .76735 L
.32842 .74411 L
.28755 .71129 L
.25501 .67018 L
.23209 .62239 L
.21968 .5698 L
.21828 .51447 L
.22793 .45857 L
.24826 .40429 L
.27847 .35378 L
.31737 .309 L
.36344 .27171 L
.41487 .24339 L
.46964 .22514 L
.5256 .21767 L
.58056 .22129 L
.63236 .23584 L
.67896 .26076 L
.71853 .29507 L
.74954 .33742 L
.77074 .38616 L
.78133 .43936 L
.78087 .49494 L
.76939 .55072 L
.74733 .60451 L
.71557 .65419 L
.67535 .69783 L
.62825 .7337 L
.57611 .7604 L
.52099 .77688 L
Mistroke
.46504 .7825 L
.41047 .77702 L
.35941 .76068 L
.31386 .7341 L
.27562 .69834 L
.24619 .65479 L
.22672 .60517 L
.21797 .55142 L
.2203 .49565 L
.23359 .44006 L
.25735 .38681 L
.29063 .33801 L
.33212 .29556 L
.3802 .26114 L
.43299 .2361 L
.4884 .22141 L
.54427 .21765 L
.59841 .22497 L
.64868 .24309 L
.69311 .27129 L
.72997 .30847 L
.7578 .35316 L
.77551 .40362 L
.78241 .45786 L
.77823 .51375 L
.76313 .5691 L
.7377 .62175 L
.70294 .66961 L
.66022 .71082 L
.61121 .74375 L
.55783 .76711 L
.50219 .78 L
.44646 .78189 L
.39283 .77273 L
.34341 .75285 L
.30013 .72306 L
.2647 .68451 L
.2385 .63872 L
.22256 .58748 L
.21751 .53282 L
.22355 .47686 L
.24044 .42181 L
.26752 .36983 L
.30372 .32296 L
.34762 .28304 L
.3975 .25163 L
.45141 .22997 L
.50722 .21891 L
.56275 .21888 L
.61581 .22988 L
Mistroke
.66434 .25148 L
.70641 .28284 L
.74038 .32272 L
.76492 .36955 L
.77906 .42151 L
.78224 .47655 L
.77436 .5325 L
.7557 .58718 L
.72701 .63844 L
.68941 .68427 L
.64438 .72287 L
.59368 .75271 L
.5393 .77264 L
.48338 .78187 L
.42811 .78004 L
.37567 .76722 L
.3281 .74391 L
.28728 .71102 L
.25481 .66986 L
.23196 .62203 L
.21963 .56941 L
.21831 .51406 L
.22804 .45817 L
.24844 .40391 L
.27872 .35343 L
.31768 .3087 L
.36379 .27148 L
.41525 .24322 L
.47004 .22505 L
.526 .21766 L
.58094 .22135 L
.63271 .23598 L
.67927 .26098 L
.71879 .29535 L
.74972 .33775 L
.77086 .38652 L
.78136 .43975 L
.78083 .49534 L
.76927 .55111 L
.74714 .60488 L
.71531 .65453 L
.67504 .69812 L
.62789 .73393 L
.57573 .76056 L
.52059 .77696 L
.46464 .7825 L
.41009 .77694 L
.35906 .76052 L
.31356 .73388 L
.27538 .69805 L
Mistroke
.24602 .65446 L
Mfstroke
.114 1 0 r
.4055 .4242 m
.42476 .40503 L
.44698 .38958 L
.47128 .37847 L
.4967 .37213 L
.52225 .37081 L
.54693 .37456 L
.56977 .38323 L
.58987 .39648 L
.60644 .4138 L
.61884 .4345 L
.62657 .45777 L
.62933 .48269 L
.62702 .5083 L
.61972 .53358 L
.60773 .55755 L
.5915 .57925 L
.57169 .59784 L
.54906 .6126 L
.52451 .62293 L
.49899 .62844 L
.47352 .62891 L
.44908 .62432 L
.42664 .61486 L
.40708 .60088 L
.39117 .58294 L
.37953 .56175 L
.37262 .53814 L
.3707 .51303 L
.37386 .4874 L
.38197 .46228 L
.39472 .43863 L
.41159 .41739 L
.43193 .39939 L
.45495 .38534 L
.47973 .3758 L
.50531 .37112 L
.53068 .37151 L
.55485 .37693 L
.57686 .38719 L
.59586 .40187 L
.6111 .42041 L
.62197 .44207 L
.62806 .466 L
.62912 .49127 L
.62512 .51688 L
.6162 .54182 L
.60272 .56513 L
.58522 .58588 L
.56437 .60326 L
Mistroke
.54099 .61658 L
.516 .62534 L
.49039 .62917 L
.46515 .62793 L
.44128 .62167 L
.41971 .61064 L
.4013 .59527 L
.38676 .57615 L
.37666 .55405 L
.37141 .52983 L
.3712 .50443 L
.37604 .47886 L
.38576 .45412 L
.39995 .43119 L
.41807 .41095 L
.43941 .39421 L
.46312 .38161 L
.48828 .37367 L
.5139 .37068 L
.53898 .37277 L
.56253 .37985 L
.58362 .39165 L
.60143 .4077 L
.61526 .42737 L
.62456 .44989 L
.62898 .47438 L
.62834 .49988 L
.62266 .52537 L
.61216 .54988 L
.59727 .57242 L
.57855 .59213 L
.55675 .60821 L
.53273 .62005 L
.50742 .62718 L
.48182 .62932 L
.45694 .62638 L
.43374 .61849 L
.41314 .60594 L
.39596 .58923 L
.38285 .56902 L
.37435 .54611 L
.37077 .52138 L
.37227 .49582 L
.37878 .47042 L
.39004 .44618 L
.40563 .42405 L
.42491 .4049 L
.44715 .38949 L
.47145 .37841 L
.49688 .3721 L
Mistroke
.52243 .37082 L
.5471 .3746 L
.56992 .38331 L
.59 .39659 L
.60655 .41394 L
.61891 .43466 L
.62661 .45794 L
.62933 .48288 L
.62699 .50849 L
.61965 .53376 L
.60763 .55771 L
.59137 .5794 L
.57154 .59796 L
.54889 .61269 L
.52433 .62299 L
.49881 .62847 L
.47334 .6289 L
.44891 .62427 L
.42649 .61477 L
.40696 .60076 L
.39107 .5828 L
.37946 .56159 L
.37258 .53796 L
.37071 .51284 L
.3739 .48722 L
.38205 .4621 L
.39482 .43847 L
.41172 .41725 L
.43209 .39928 L
.45512 .38526 L
.47992 .37574 L
.5055 .37111 L
.53086 .37153 L
.55502 .37699 L
.57701 .38728 L
.59598 .40199 L
.61119 .42055 L
.62203 .44223 L
.62808 .46618 L
.62911 .49145 L
.62507 .51706 L
.61612 .542 L
.60261 .56529 L
.58508 .58602 L
.56421 .60337 L
.54081 .61666 L
.51582 .62538 L
.4902 .62918 L
.46497 .62791 L
.44112 .62161 L
Mistroke
.41957 .61055 L
.40118 .59514 L
.38667 .576 L
.37661 .55388 L
.37139 .52965 L
.37122 .50425 L
.3761 .47868 L
.38584 .45395 L
.40007 .43103 L
.41821 .41082 L
.43957 .3941 L
.4633 .38154 L
.48847 .37363 L
.51409 .37068 L
.53915 .3728 L
.56269 .37992 L
.58376 .39175 L
.60154 .40783 L
.61534 .42752 L
.62461 .45006 L
.629 .47456 L
.62831 .50006 L
.6226 .52555 L
.61207 .55005 L
.59714 .57257 L
.57841 .59225 L
.55659 .60831 L
.53255 .62012 L
.50724 .62722 L
.48164 .62932 L
.45676 .62634 L
.43358 .61841 L
.41301 .60583 L
.39585 .5891 L
.38277 .56887 L
.3743 .54594 L
.37076 .5212 L
.3723 .49563 L
.37884 .47024 L
.39014 .44601 L
.40575 .4239 L
.42506 .40478 L
.44732 .38939 L
.47163 .37835 L
.49707 .37208 L
.52261 .37083 L
.54727 .37465 L
.57008 .38339 L
.59013 .3967 L
.60665 .41407 L
Mistroke
.61898 .43481 L
Mfstroke
1 .12 0 r
.57564 .30635 m
.61075 .32037 L
.64152 .34144 L
.66673 .36873 L
.6854 .40117 L
.69679 .43749 L
.70046 .47627 L
.69626 .51598 L
.68436 .55505 L
.66523 .59197 L
.63961 .62528 L
.60851 .65367 L
.57315 .67603 L
.53492 .69149 L
.49532 .69942 L
.45591 .69953 L
.41822 .69181 L
.38375 .67657 L
.35383 .65439 L
.32966 .62615 L
.31217 .59296 L
.30205 .55613 L
.2997 .51709 L
.30521 .47738 L
.31836 .43856 L
.33864 .40215 L
.36526 .36958 L
.39716 .34213 L
.4331 .32087 L
.47167 .30664 L
.51135 .30001 L
.55058 .30122 L
.58783 .31023 L
.62163 .32669 L
.65065 .34996 L
.67377 .37911 L
.69006 .413 L
.6989 .45031 L
.69993 .48957 L
.69311 .52924 L
.67871 .56776 L
.65731 .60363 L
.62972 .63542 L
.59705 .6619 L
.56056 .68203 L
.52171 .69501 L
.48199 .70034 L
.44299 .69781 L
.40622 .68751 L
.37313 .66985 L
Mistroke
.34503 .64553 L
.323 .6155 L
.30792 .58093 L
.30038 .54319 L
.30067 .50375 L
.30879 .46417 L
.32441 .42599 L
.34692 .39072 L
.37544 .35973 L
.40885 .33425 L
.44583 .31528 L
.48494 .30355 L
.52465 .29954 L
.56338 .30339 L
.59963 .31496 L
.63196 .33379 L
.65912 .35914 L
.68004 .39002 L
.69388 .42522 L
.70012 .46335 L
.69851 .50292 L
.6891 .54238 L
.67227 .58017 L
.64868 .61482 L
.61926 .64496 L
.58516 .66941 L
.54771 .68721 L
.50839 .69767 L
.46874 .70037 L
.43032 .6952 L
.39463 .68237 L
.36308 .66239 L
.33691 .63603 L
.31713 .60434 L
.30453 .56855 L
.2996 .53006 L
.30253 .4904 L
.31322 .45112 L
.33124 .41375 L
.35588 .37977 L
.38617 .35051 L
.42094 .32711 L
.4588 .3105 L
.49828 .30133 L
.53783 .29995 L
.5759 .30643 L
.61099 .3205 L
.64172 .34161 L
.66689 .36895 L
.68551 .40142 L
Mistroke
.69684 .43777 L
.70046 .47655 L
.69621 .51626 L
.68425 .55533 L
.66507 .59223 L
.6394 .6255 L
.60827 .65386 L
.57289 .67617 L
.53464 .69157 L
.49504 .69945 L
.45563 .69951 L
.41796 .69173 L
.38352 .67643 L
.35364 .65421 L
.32951 .62593 L
.31207 .59271 L
.302 .55585 L
.29971 .5168 L
.30527 .4771 L
.31848 .43829 L
.33881 .4019 L
.36547 .36936 L
.39741 .34195 L
.43337 .32074 L
.47195 .30657 L
.51163 .29999 L
.55086 .30126 L
.58808 .31033 L
.62185 .32684 L
.65084 .35015 L
.67391 .37934 L
.69015 .41326 L
.69893 .45059 L
.69991 .48986 L
.69303 .52952 L
.67859 .56803 L
.65713 .60387 L
.6295 .63563 L
.5968 .66207 L
.56029 .68215 L
.52142 .69508 L
.48171 .70035 L
.44272 .69776 L
.40597 .68741 L
.37291 .6697 L
.34485 .64534 L
.32287 .61527 L
.30784 .58067 L
.30035 .54291 L
.3007 .50347 L
Mistroke
.30887 .46389 L
.32455 .42573 L
.3471 .39048 L
.37566 .35953 L
.4091 .33409 L
.44611 .31517 L
.48523 .30349 L
.52493 .29953 L
.56365 .30344 L
.59987 .31506 L
.63218 .33394 L
.6593 .35934 L
.68016 .39026 L
.69396 .42548 L
.70014 .46363 L
.69847 .50321 L
.68901 .54266 L
.67213 .58043 L
.64849 .61505 L
.61903 .64516 L
.5849 .66956 L
.54743 .68732 L
.50811 .69772 L
.46846 .70036 L
.43005 .69514 L
.39439 .68226 L
.36288 .66222 L
.33674 .63582 L
.31701 .60409 L
.30446 .56828 L
.29959 .52978 L
.30258 .49012 L
.31332 .45084 L
.33139 .4135 L
.35607 .37954 L
.38641 .35032 L
.4212 .32697 L
.45908 .31041 L
.49857 .30129 L
.53811 .29997 L
.57616 .3065 L
.61122 .32063 L
.64192 .34179 L
.66704 .36916 L
.68561 .40167 L
.6969 .43804 L
.70046 .47684 L
.69615 .51654 L
.68414 .5556 L
.6649 .59248 L
Mistroke
.6392 .62573 L
Mfstroke
1 .005 0 r
.30495 .54386 m
.30491 .50533 L
.31252 .46659 L
.32749 .42917 L
.34924 .39453 L
.3769 .36402 L
.40939 .33885 L
.44543 .32001 L
.48362 .30823 L
.52245 .30397 L
.5604 .30741 L
.59598 .31841 L
.6278 .33654 L
.65459 .36108 L
.67532 .39107 L
.68917 .42533 L
.6956 .46253 L
.69435 .5012 L
.68547 .53982 L
.66931 .57688 L
.64651 .61092 L
.61795 .64061 L
.58477 .66478 L
.54826 .68248 L
.50986 .69302 L
.47107 .69599 L
.43342 .69126 L
.39838 .67903 L
.36732 .65977 L
.34148 .63424 L
.32185 .60344 L
.30922 .56859 L
.30407 .53104 L
.30662 .49227 L
.31675 .45381 L
.33408 .41716 L
.35791 .38376 L
.38733 .35492 L
.42116 .33178 L
.45809 .31524 L
.49666 .30595 L
.53537 .30427 L
.57269 .31028 L
.60715 .32373 L
.63741 .3441 L
.66227 .37059 L
.68077 .40216 L
.69218 .43757 L
.69604 .47542 L
.6922 .51425 L
Mistroke
.68083 .55251 L
.66236 .58871 L
.63751 .62143 L
.60727 .64939 L
.57282 .67148 L
.53551 .68684 L
.49681 .69487 L
.45823 .69525 L
.42129 .68797 L
.38744 .67331 L
.35801 .65185 L
.33415 .62443 L
.3168 .59213 L
.30664 .55621 L
.30407 .51809 L
.30919 .47925 L
.32179 .44123 L
.34139 .40552 L
.36722 .37351 L
.39825 .34647 L
.43328 .32545 L
.47093 .31129 L
.50972 .30453 L
.54813 .30544 L
.58464 .31399 L
.61784 .32983 L
.64641 .35236 L
.66924 .38068 L
.68542 .41368 L
.69433 .45008 L
.69561 .48843 L
.68921 .52723 L
.67539 .56497 L
.65468 .60015 L
.6279 .63141 L
.59611 .65751 L
.56054 .67742 L
.5226 .69038 L
.48377 .69586 L
.44557 .69366 L
.40951 .68385 L
.37701 .66683 L
.34933 .64326 L
.32756 .61407 L
.31256 .58041 L
.30492 .54358 L
.30493 .50505 L
.3126 .46632 L
.32763 .42891 L
.34942 .39429 L
Mistroke
.37711 .36382 L
.40963 .33869 L
.4457 .3199 L
.4839 .30817 L
.52273 .30397 L
.56067 .30747 L
.59623 .31852 L
.62801 .33669 L
.65476 .36127 L
.67545 .3913 L
.68924 .42559 L
.69562 .46281 L
.69431 .50148 L
.68538 .54009 L
.66917 .57713 L
.64632 .61115 L
.61773 .6408 L
.58452 .66493 L
.54799 .68258 L
.50958 .69307 L
.4708 .69598 L
.43316 .6912 L
.39814 .67891 L
.36712 .65961 L
.34131 .63404 L
.32174 .60321 L
.30916 .56833 L
.30407 .53076 L
.30666 .49199 L
.31685 .45354 L
.33422 .41691 L
.3581 .38354 L
.38755 .35473 L
.42142 .33164 L
.45836 .31514 L
.49694 .30591 L
.53564 .30429 L
.57294 .31035 L
.60738 .32385 L
.63761 .34427 L
.66243 .3708 L
.68088 .4024 L
.69223 .43783 L
.69604 .4757 L
.69215 .51452 L
.68072 .55278 L
.6622 .58896 L
.63731 .62165 L
.60704 .64957 L
.57256 .67162 L
Mistroke
.53524 .68693 L
.49653 .6949 L
.45796 .69523 L
.42104 .68789 L
.38722 .67318 L
.35782 .65168 L
.334 .62422 L
.3167 .59188 L
.3066 .55594 L
.30408 .51781 L
.30925 .47897 L
.32191 .44096 L
.34156 .40527 L
.36742 .3733 L
.39849 .34629 L
.43355 .32532 L
.47121 .31121 L
.51 .3045 L
.5484 .30547 L
.58489 .31407 L
.61806 .32997 L
.6466 .35254 L
.66938 .3809 L
.68551 .41393 L
.69436 .45034 L
.69559 .4887 L
.68914 .52751 L
.67526 .56523 L
.65451 .60039 L
.62769 .63162 L
.59587 .65767 L
.56028 .67754 L
.52232 .69044 L
.48349 .69587 L
.4453 .69361 L
.40927 .68375 L
.37679 .66668 L
.34915 .64307 L
.32743 .61385 L
.31248 .58015 L
.30489 .54331 L
.30496 .50477 L
.31269 .46605 L
.32776 .42865 L
.34959 .39406 L
.37733 .36362 L
.40988 .33854 L
.44597 .31979 L
.48418 .30811 L
.52301 .30397 L
Mistroke
.56093 .30752 L
Mfstroke
.564 1 0 r
.22374 .58234 m
.21967 .52788 L
.22659 .47232 L
.24425 .41786 L
.27194 .36661 L
.30858 .3206 L
.35273 .28163 L
.40267 .25124 L
.45642 .2306 L
.51189 .22054 L
.56689 .22144 L
.61926 .23328 L
.66695 .25558 L
.70809 .28748 L
.74106 .32772 L
.76458 .37472 L
.77771 .42663 L
.77994 .48143 L
.77118 .53695 L
.75178 .59103 L
.7225 .64153 L
.68449 .68648 L
.63924 .7241 L
.58852 .75294 L
.53433 .77184 L
.47879 .78008 L
.42408 .77733 L
.37236 .76369 L
.32564 .7397 L
.28576 .70631 L
.2543 .66482 L
.23247 .61686 L
.22115 .56431 L
.22077 .50924 L
.23135 .45381 L
.25247 .40019 L
.28331 .35049 L
.32265 .30665 L
.36895 .27041 L
.42039 .24317 L
.47496 .22601 L
.53051 .21961 L
.58487 .22421 L
.63589 .23964 L
.68158 .26528 L
.72014 .30013 L
.75007 .34283 L
.77018 .3917 L
.77968 .44481 L
.77821 .5001 L
Mistroke
.76583 .55538 L
.743 .60848 L
.71065 .65733 L
.67002 .7 L
.62272 .73483 L
.57061 .76044 L
.51572 .77582 L
.46022 .78039 L
.40628 .77394 L
.35602 .75675 L
.3114 .72948 L
.27419 .69321 L
.24584 .64935 L
.22747 .59963 L
.21979 .546 L
.22311 .49056 L
.2373 .4355 L
.26179 .38297 L
.29563 .33503 L
.3375 .29356 L
.38574 .2602 L
.43847 .23625 L
.49361 .22264 L
.549 .21993 L
.60247 .2282 L
.65192 .24715 L
.6954 .27601 L
.73122 .31367 L
.75796 .35864 L
.77458 .40916 L
.78042 .46324 L
.77526 .51876 L
.75929 .57355 L
.73315 .62546 L
.69786 .67243 L
.6548 .71265 L
.60567 .74451 L
.55239 .76678 L
.49705 .77858 L
.44183 .77945 L
.38889 .76935 L
.34032 .74867 L
.29801 .71824 L
.26363 .67925 L
.23852 .63322 L
.22368 .58196 L
.21968 .52748 L
.22668 .47193 L
.24441 .41748 L
.27217 .36626 L
Mistroke
.30887 .3203 L
.35307 .28138 L
.40304 .25105 L
.45682 .23049 L
.51229 .2205 L
.56727 .22149 L
.61962 .2334 L
.66727 .25578 L
.70836 .28774 L
.74127 .32803 L
.76471 .37508 L
.77776 .42702 L
.77991 .48183 L
.77108 .53735 L
.75161 .5914 L
.72226 .64187 L
.68419 .68677 L
.63889 .72434 L
.58814 .75311 L
.53393 .77194 L
.47839 .7801 L
.4237 .77727 L
.372 .76355 L
.32533 .73949 L
.28551 .70604 L
.25411 .66449 L
.23235 .61649 L
.22111 .56392 L
.22081 .50884 L
.23146 .45342 L
.25266 .39982 L
.28356 .35015 L
.32296 .30636 L
.3693 .27018 L
.42077 .24301 L
.47536 .22593 L
.53091 .2196 L
.58525 .22428 L
.63624 .23978 L
.68188 .2655 L
.72039 .30041 L
.75025 .34316 L
.77028 .39207 L
.77971 .44521 L
.77816 .5005 L
.7657 .55577 L
.74281 .60885 L
.71038 .65766 L
.6697 .70028 L
.62237 .73505 L
Mistroke
.57022 .76058 L
.51533 .7759 L
.45983 .78038 L
.4059 .77386 L
.35567 .75659 L
.31111 .72925 L
.27396 .69292 L
.24568 .64901 L
.22738 .59926 L
.21978 .5456 L
.22317 .49017 L
.23744 .43511 L
.262 .3826 L
.29591 .3347 L
.33782 .29329 L
.38611 .25999 L
.43886 .23611 L
.49401 .22259 L
.54939 .21995 L
.60284 .2283 L
.65225 .24732 L
.69569 .27625 L
.73144 .31397 L
.75812 .35898 L
.77466 .40953 L
.78042 .46363 L
.77518 .51916 L
.75914 .57394 L
.73293 .62581 L
.69757 .67275 L
.65447 .71291 L
.6053 .74471 L
.55199 .7669 L
.49665 .77863 L
.44144 .77941 L
.38853 .76923 L
.33999 .74849 L
.29773 .71799 L
.26341 .67894 L
.23838 .63287 L
.22361 .58158 L
.21969 .52708 L
.22677 .47153 L
.24457 .41709 L
.2724 .36591 L
.30916 .31999 L
.35341 .28113 L
.40342 .25087 L
.45721 .23038 L
.51268 .22047 L
Mistroke
.56766 .22154 L
Mfstroke
.973 1 0 r
.61743 .18709 m
.67438 .20879 L
.72449 .24191 L
.76578 .28517 L
.79665 .33686 L
.81588 .39495 L
.82271 .45717 L
.81687 .52106 L
.7986 .58413 L
.76861 .6439 L
.72807 .69802 L
.67859 .74436 L
.6221 .78112 L
.56081 .80685 L
.49714 .82053 L
.43358 .82163 L
.37263 .81011 L
.31668 .78642 L
.26792 .75149 L
.22827 .70669 L
.19928 .65378 L
.1821 .59483 L
.17739 .53216 L
.18534 .46823 L
.20565 .40554 L
.2375 .34656 L
.27966 .29361 L
.33046 .24875 L
.38792 .21376 L
.44978 .18999 L
.5136 .1784 L
.5769 .17943 L
.63717 .19303 L
.69207 .21869 L
.73942 .25538 L
.77738 .30168 L
.80445 .35576 L
.81958 .4155 L
.82216 .47855 L
.8121 .54245 L
.78979 .60468 L
.7561 .66281 L
.71237 .71454 L
.6603 .75785 L
.60194 .79105 L
.53958 .81282 L
.47566 .82231 L
.41271 .81916 L
.35317 .80348 L
.2994 .77589 L
Mistroke
.2535 .73747 L
.21728 .68973 L
.19215 .63455 L
.17911 .57408 L
.17865 .51071 L
.19081 .44692 L
.2151 .38521 L
.25058 .328 L
.29584 .27755 L
.34912 .23583 L
.40831 .20447 L
.47111 .18471 L
.53504 .17733 L
.59759 .18261 L
.65632 .20034 L
.7089 .22984 L
.7533 .26994 L
.78774 .31907 L
.8109 .3753 L
.82186 .43642 L
.82018 .50004 L
.80594 .56365 L
.77969 .62477 L
.74246 .68099 L
.69572 .73011 L
.6413 .7702 L
.58133 .79968 L
.51817 .81741 L
.4543 .82267 L
.39222 .81527 L
.33437 .7955 L
.28302 .76413 L
.24019 .7224 L
.20755 .67193 L
.18639 .61472 L
.17754 .55301 L
.18134 .48922 L
.19765 .42585 L
.22583 .36539 L
.26476 .31021 L
.31293 .26248 L
.36844 .22407 L
.42911 .1965 L
.49257 .18083 L
.55632 .17769 L
.61785 .1872 L
.67476 .20898 L
.72482 .24219 L
.76604 .28551 L
.79683 .33726 L
Mistroke
.81597 .39539 L
.82271 .45762 L
.81678 .52152 L
.79842 .58457 L
.76835 .64431 L
.72775 .69838 L
.67821 .74466 L
.62167 .78135 L
.56036 .80699 L
.49668 .82058 L
.43313 .82159 L
.37221 .80999 L
.3163 .78621 L
.2676 .7512 L
.22802 .70634 L
.19911 .65337 L
.18202 .59439 L
.1774 .5317 L
.18545 .46777 L
.20583 .4051 L
.23777 .34616 L
.27999 .29325 L
.33085 .24846 L
.38835 .21354 L
.45023 .18987 L
.51406 .17836 L
.57734 .17948 L
.63759 .19318 L
.69244 .21891 L
.73973 .25568 L
.77761 .30204 L
.8046 .35617 L
.81964 .41594 L
.82213 .47901 L
.81198 .54291 L
.78958 .60512 L
.75582 .6632 L
.71202 .71488 L
.6599 .75813 L
.6015 .79125 L
.53912 .81293 L
.47521 .82234 L
.41226 .81909 L
.35276 .80332 L
.29904 .77565 L
.25321 .73716 L
.21706 .68936 L
.19201 .63413 L
.17906 .57364 L
.1787 .51025 L
Mistroke
.19094 .44647 L
.21532 .38478 L
.25087 .32762 L
.2962 .27722 L
.34952 .23556 L
.40875 .20429 L
.47157 .18461 L
.53549 .17732 L
.59803 .18269 L
.65672 .20051 L
.70925 .23009 L
.75358 .27026 L
.78795 .31945 L
.81102 .37572 L
.82189 .43687 L
.82012 .5005 L
.80579 .5641 L
.77946 .6252 L
.74216 .68137 L
.69536 .73043 L
.64089 .77045 L
.58089 .79985 L
.51771 .81749 L
.45384 .82266 L
.39179 .81517 L
.33397 .79532 L
.28268 .76387 L
.23991 .72206 L
.20736 .67154 L
.18628 .61429 L
.17752 .55256 L
.18142 .48876 L
.19781 .4254 L
.22607 .36497 L
.26508 .30984 L
.31331 .26217 L
.36886 .22384 L
.42956 .19634 L
.49303 .18076 L
.55677 .17771 L
.61828 .18731 L
.67515 .20918 L
.72514 .24247 L
.7663 .28586 L
.79701 .33765 L
.81606 .39582 L
.82271 .45808 L
.81669 .52198 L
.79825 .58502 L
.7681 .64472 L
Mistroke
.72742 .69874 L
Mfstroke
1 0 .563 r
.46893 .82096 m
.40654 .81646 L
.34781 .79954 L
.29506 .77086 L
.25036 .73156 L
.21545 .68316 L
.19171 .62758 L
.18006 .56699 L
.18098 .50377 L
.19441 .44041 L
.21984 .37938 L
.25626 .32308 L
.30225 .27373 L
.356 .23326 L
.4154 .20326 L
.47812 .1849 L
.5417 .17891 L
.60364 .18552 L
.66152 .20448 L
.71305 .23503 L
.75623 .27598 L
.78935 .32572 L
.81111 .3823 L
.82066 .4435 L
.81763 .50692 L
.80214 .57007 L
.77478 .63047 L
.73664 .68574 L
.68922 .73373 L
.63436 .77254 L
.57424 .80066 L
.5112 .81698 L
.44772 .82086 L
.38629 .81214 L
.32933 .79118 L
.27906 .75878 L
.23747 .71624 L
.20618 .6652 L
.18642 .60768 L
.17896 .54594 L
.18411 .48239 L
.20165 .41953 L
.2309 .35984 L
.27072 .30564 L
.31953 .25907 L
.37542 .22195 L
.43621 .19575 L
.49949 .18149 L
.5628 .17973 L
.62364 .19054 L
Mistroke
.67963 .21349 L
.72857 .24769 L
.76854 .29179 L
.79797 .34406 L
.81571 .40245 L
.82105 .46467 L
.8138 .52828 L
.79423 .59077 L
.76311 .64971 L
.72167 .70277 L
.67153 .74787 L
.61465 .78324 L
.55328 .8075 L
.48981 .81969 L
.42675 .81933 L
.36656 .80644 L
.3116 .78152 L
.26404 .74556 L
.22574 .69996 L
.19821 .64651 L
.18252 .58731 L
.17928 .52468 L
.18864 .46109 L
.21021 .39902 L
.24316 .34092 L
.28619 .28906 L
.33761 .24547 L
.3954 .21188 L
.4573 .1896 L
.52087 .17949 L
.58362 .18197 L
.64309 .19693 L
.69695 .22378 L
.74308 .26147 L
.77966 .30852 L
.80528 .36309 L
.81891 .42303 L
.82002 .48599 L
.80858 .54951 L
.78502 .61107 L
.75028 .66828 L
.70571 .71889 L
.65308 .7609 L
.59443 .79268 L
.53208 .81297 L
.46847 .82097 L
.4061 .81638 L
.34741 .79938 L
.29471 .77062 L
.25007 .73124 L
Mistroke
.21524 .68279 L
.19158 .62716 L
.18003 .56654 L
.18103 .50332 L
.19455 .43996 L
.22006 .37895 L
.25656 .3227 L
.30261 .27341 L
.35641 .23301 L
.41584 .20309 L
.47858 .18482 L
.54215 .17892 L
.60407 .18562 L
.66191 .20466 L
.7134 .23529 L
.7565 .27631 L
.78955 .32611 L
.81122 .38273 L
.82069 .44395 L
.81757 .50738 L
.80198 .57051 L
.77454 .63088 L
.73633 .68611 L
.68885 .73404 L
.63395 .77278 L
.57379 .80082 L
.51074 .81705 L
.44727 .82084 L
.38587 .81203 L
.32894 .79098 L
.27873 .75851 L
.23721 .7159 L
.20599 .66481 L
.18632 .60725 L
.17895 .54549 L
.18419 .48193 L
.20182 .41909 L
.23115 .35942 L
.27104 .30527 L
.31991 .25877 L
.37584 .22173 L
.43665 .19561 L
.49995 .18143 L
.56325 .17976 L
.62406 .19066 L
.68001 .2137 L
.72889 .24797 L
.76879 .29214 L
.79814 .34446 L
.81579 .40289 L
Mistroke
.82105 .46512 L
.8137 .52873 L
.79405 .59121 L
.76285 .65011 L
.72134 .70312 L
.67114 .74816 L
.61423 .78345 L
.55283 .80763 L
.48936 .81973 L
.4263 .81928 L
.36614 .8063 L
.31123 .7813 L
.26373 .74526 L
.22551 .6996 L
.19805 .6461 L
.18245 .58687 L
.17931 .52423 L
.18875 .46063 L
.21041 .39859 L
.24344 .34052 L
.28653 .28871 L
.338 .2452 L
.39583 .21168 L
.45775 .18948 L
.52132 .17947 L
.58406 .18203 L
.6435 .19708 L
.69731 .22401 L
.74338 .26177 L
.77989 .30889 L
.80542 .3635 L
.81896 .42348 L
.81998 .48645 L
.80845 .54996 L
.78481 .6115 L
.74999 .66867 L
.70536 .71922 L
.65268 .76117 L
.594 .79287 L
.53163 .81307 L
.46802 .82099 L
.40566 .8163 L
.34701 .79921 L
.29436 .77037 L
.24978 .73092 L
.21503 .68241 L
.19145 .62674 L
.17999 .5661 L
.18108 .50286 L
.19469 .43951 L
Mistroke
.22029 .37853 L
Mfstroke
1 .93 0 r
.43789 .30861 m
.47868 .29527 L
.52031 .28997 L
.56114 .29291 L
.59957 .30397 L
.63409 .32273 L
.66335 .34845 L
.6862 .38012 L
.70174 .41649 L
.70936 .45614 L
.70877 .4975 L
.69998 .53897 L
.68335 .57891 L
.65952 .61575 L
.62943 .64805 L
.59426 .67454 L
.55539 .69417 L
.51435 .70619 L
.47274 .71012 L
.4322 .7058 L
.39433 .6934 L
.3606 .67341 L
.33234 .64662 L
.31067 .61407 L
.29642 .57704 L
.29016 .537 L
.29214 .4955 L
.30228 .45417 L
.32017 .41465 L
.34513 .37847 L
.37616 .34707 L
.41205 .32166 L
.45139 .30326 L
.49264 .29258 L
.53418 .29003 L
.57438 .29573 L
.61166 .30945 L
.64456 .33064 L
.67178 .35848 L
.69226 .39187 L
.7052 .42951 L
.71008 .46991 L
.70672 .5115 L
.69525 .55263 L
.67611 .5917 L
.65006 .62717 L
.61812 .65765 L
.58155 .68194 L
.54177 .69909 L
.50036 .70843 L
Mistroke
.45893 .70958 L
.41911 .70252 L
.38247 .6875 L
.35044 .66513 L
.32428 .63627 L
.30502 .60207 L
.29341 .56386 L
.2899 .52315 L
.29465 .48152 L
.30745 .44062 L
.32781 .40206 L
.35492 .36733 L
.38773 .33782 L
.42495 .31466 L
.46511 .29879 L
.50664 .2908 L
.54791 .29103 L
.5873 .29946 L
.62326 .31576 L
.65439 .33929 L
.67946 .36913 L
.69748 .4041 L
.70775 .44284 L
.70987 .48382 L
.70376 .52544 L
.68964 .56605 L
.66809 .60408 L
.63994 .63802 L
.60629 .66654 L
.56848 .68853 L
.52797 .70312 L
.48637 .70974 L
.4453 .70812 L
.40638 .69834 L
.37114 .68077 L
.34095 .65611 L
.317 .62532 L
.30024 .58962 L
.29131 .55039 L
.29058 .50919 L
.29806 .46763 L
.31347 .42734 L
.3362 .3899 L
.36536 .35678 L
.3998 .32928 L
.43818 .30848 L
.47898 .2952 L
.5206 .28996 L
.56142 .29296 L
.59983 .30408 L
Mistroke
.63432 .3229 L
.66353 .34866 L
.68633 .38036 L
.70182 .41676 L
.70939 .45643 L
.70873 .4978 L
.69989 .53927 L
.6832 .57919 L
.65932 .616 L
.62919 .64826 L
.59399 .6747 L
.5551 .69429 L
.51405 .70625 L
.47244 .71011 L
.43192 .70573 L
.39407 .69328 L
.36038 .67324 L
.33216 .6464 L
.31054 .61382 L
.29634 .57677 L
.29015 .5367 L
.29218 .4952 L
.30238 .45388 L
.32033 .41438 L
.34533 .37823 L
.3764 .34686 L
.41232 .32151 L
.45168 .30316 L
.49294 .29253 L
.53448 .29005 L
.57466 .2958 L
.61191 .30957 L
.64478 .33082 L
.67195 .3587 L
.69238 .39213 L
.70526 .42979 L
.71009 .47021 L
.70667 .5118 L
.69514 .55292 L
.67595 .59197 L
.64985 .6274 L
.61787 .65784 L
.58127 .68209 L
.54148 .69918 L
.50006 .70846 L
.45864 .70956 L
.41884 .70244 L
.38222 .68737 L
.35023 .66494 L
.32412 .63604 L
Mistroke
.30491 .60181 L
.29335 .56358 L
.28991 .52285 L
.29471 .48123 L
.30757 .44034 L
.32798 .40179 L
.35514 .3671 L
.38798 .33763 L
.42523 .31452 L
.4654 .2987 L
.50694 .29078 L
.5482 .29106 L
.58757 .29955 L
.6235 .31591 L
.65459 .33949 L
.67961 .36936 L
.69758 .40437 L
.7078 .44313 L
.70986 .48412 L
.70368 .52573 L
.68952 .56634 L
.66791 .60434 L
.63971 .63824 L
.60603 .66673 L
.56819 .68866 L
.52768 .70319 L
.48607 .70975 L
.44502 .70808 L
.40612 .69824 L
.3709 .68062 L
.34076 .65591 L
.31686 .62508 L
.30015 .58935 L
.29128 .5501 L
.2906 .50889 L
.29815 .46734 L
.31361 .42706 L
.33639 .38964 L
.36559 .35656 L
.40007 .32911 L
.43846 .30836 L
.47928 .29514 L
.5209 .28995 L
.56171 .29301 L
.60009 .30419 L
.63455 .32306 L
.66372 .34887 L
.68647 .38061 L
.7019 .41704 L
.70941 .45672 L
Mistroke
.7087 .4981 L
Mfstroke
0 .216 1 r
.42099 .28293 m
.46763 .2661 L
.51554 .25845 L
.56285 .26028 L
.60768 .27151 L
.64829 .29172 L
.68308 .3201 L
.71069 .35554 L
.73003 .39664 L
.74034 .44181 L
.74121 .48926 L
.73262 .53713 L
.7149 .58354 L
.68875 .62668 L
.65519 .66484 L
.61554 .69653 L
.57135 .72051 L
.52436 .73584 L
.47642 .74191 L
.42941 .73849 L
.38516 .7257 L
.34542 .70406 L
.31175 .67441 L
.28546 .63792 L
.2676 .59601 L
.25885 .55034 L
.25957 .50268 L
.26973 .45493 L
.28892 .40894 L
.3164 .36653 L
.35108 .32935 L
.39161 .29887 L
.43639 .27629 L
.48367 .26248 L
.53159 .258 L
.57826 .26301 L
.62187 .27733 L
.6607 .30038 L
.69321 .33127 L
.71815 .36878 L
.73452 .41144 L
.74169 .45758 L
.73937 .50538 L
.72766 .55297 L
.70702 .59848 L
.67825 .64012 L
.64248 .67627 L
.60113 .7055 L
.5558 .72666 L
.50828 .73893 L
Mistroke
.46044 .74182 L
.41415 .73522 L
.37123 .71939 L
.33337 .69495 L
.30204 .66286 L
.27848 .62437 L
.26362 .58101 L
.25803 .53447 L
.26194 .48657 L
.2752 .4392 L
.29727 .39422 L
.3273 .35338 L
.36411 .31831 L
.40625 .29036 L
.45207 .27064 L
.49978 .25992 L
.54749 .25863 L
.59333 .2668 L
.63552 .28413 L
.67238 .30993 L
.70249 .34319 L
.72464 .38261 L
.73798 .42663 L
.74197 .47353 L
.73648 .52147 L
.7217 .56857 L
.69822 .61297 L
.66696 .65295 L
.62914 .68692 L
.58626 .71355 L
.54 .7318 L
.49216 .74096 L
.44464 .74066 L
.39928 .73091 L
.35788 .71211 L
.32205 .68497 L
.29321 .65058 L
.27249 .61028 L
.26069 .56565 L
.25829 .51844 L
.26537 .47051 L
.28166 .42374 L
.30652 .37996 L
.33897 .34089 L
.37774 .30807 L
.42131 .28278 L
.46797 .26601 L
.51589 .25843 L
.56318 .26032 L
.60799 .27163 L
Mistroke
.64857 .29189 L
.68331 .32033 L
.71086 .35581 L
.73013 .39696 L
.74038 .44214 L
.74118 .4896 L
.73253 .53747 L
.71474 .58386 L
.68853 .62697 L
.65492 .66509 L
.61523 .69673 L
.57102 .72066 L
.52402 .73592 L
.47608 .74192 L
.42908 .73843 L
.38486 .72558 L
.34515 .70388 L
.31153 .67417 L
.2853 .63764 L
.2675 .59569 L
.25882 .55 L
.25961 .50234 L
.26984 .45459 L
.28909 .40862 L
.31662 .36624 L
.35135 .32911 L
.39192 .29868 L
.43672 .27616 L
.48401 .26242 L
.53193 .258 L
.57859 .26308 L
.62217 .27746 L
.66095 .30058 L
.69342 .33152 L
.7183 .36907 L
.73461 .41176 L
.74171 .45791 L
.73932 .50572 L
.72755 .5533 L
.70684 .59879 L
.67802 .6404 L
.6422 .6765 L
.60081 .70568 L
.55546 .72678 L
.50794 .73898 L
.4601 .74181 L
.41383 .73514 L
.37094 .71925 L
.33312 .69475 L
.30184 .6626 L
Mistroke
.27835 .62408 L
.26355 .58069 L
.25803 .53413 L
.26201 .48623 L
.27532 .43887 L
.29746 .39391 L
.32754 .35311 L
.3644 .31808 L
.40657 .29019 L
.45241 .27053 L
.50012 .25988 L
.54783 .25865 L
.59365 .2669 L
.6358 .28429 L
.67263 .31015 L
.70267 .34346 L
.72477 .38291 L
.73804 .42696 L
.74197 .47387 L
.7364 .52181 L
.72156 .5689 L
.69802 .61328 L
.66671 .65321 L
.62885 .68713 L
.58594 .71371 L
.53966 .7319 L
.49182 .74099 L
.4443 .74062 L
.39897 .73081 L
.3576 .71194 L
.32182 .68475 L
.29303 .65031 L
.27237 .60997 L
.26064 .56532 L
.2583 .5181 L
.26545 .47017 L
.28181 .42342 L
.30672 .37966 L
.33923 .34063 L
.37804 .30786 L
.42164 .28263 L
.46831 .26592 L
.51623 .25841 L
.56351 .26037 L
.6083 .27174 L
.64884 .29207 L
.68353 .32056 L
.71103 .35609 L
.73024 .39727 L
.74041 .44248 L
Mistroke
.74116 .48995 L
Mfstroke
0 1 .876 r
.50049 .23703 m
.55272 .23576 L
.60288 .24485 L
.649 .26396 L
.68927 .29234 L
.72212 .32886 L
.74625 .3721 L
.76071 .42036 L
.76494 .47175 L
.75878 .52424 L
.74245 .57579 L
.71662 .62435 L
.68228 .66804 L
.64079 .70513 L
.59377 .73418 L
.54307 .75403 L
.49068 .76391 L
.43866 .76344 L
.38905 .75262 L
.34379 .73189 L
.30466 .70206 L
.27319 .66431 L
.25063 .6201 L
.23786 .57118 L
.23537 .51946 L
.24327 .46698 L
.26124 .4158 L
.28859 .36792 L
.32423 .32523 L
.36677 .28939 L
.41454 .26182 L
.46566 .2436 L
.51813 .23544 L
.56989 .23766 L
.61891 .25018 L
.66326 .27251 L
.7012 .30376 L
.73125 .34271 L
.75222 .38784 L
.76329 .43736 L
.76403 .48935 L
.75441 .54175 L
.7348 .59252 L
.70598 .63965 L
.66907 .68131 L
.62553 .71585 L
.57706 .74191 L
.52557 .75849 L
.47308 .76491 L
.42164 .76095 L
Mistroke
.37327 .74674 L
.32988 .72284 L
.29317 .6902 L
.26457 .6501 L
.24522 .60411 L
.23586 .55403 L
.23687 .50183 L
.2482 .44955 L
.26942 .39926 L
.29969 .35292 L
.33782 .31236 L
.38231 .27915 L
.43142 .25462 L
.48323 .23971 L
.53569 .23502 L
.58675 .24073 L
.63441 .25662 L
.67679 .28206 L
.71223 .31605 L
.73935 .35725 L
.75707 .40407 L
.7647 .45464 L
.76194 .507 L
.74891 .55908 L
.7261 .60884 L
.69442 .65434 L
.65511 .69377 L
.60972 .7256 L
.56001 .74858 L
.50796 .7618 L
.45559 .76474 L
.40496 .7573 L
.35806 .73976 L
.31674 .7128 L
.2826 .6775 L
.257 .63523 L
.24093 .58765 L
.23504 .53664 L
.23954 .48418 L
.25426 .43235 L
.27863 .38317 L
.31168 .33858 L
.35213 .30032 L
.39838 .2699 L
.44861 .2485 L
.50087 .23698 L
.55309 .23578 L
.60323 .24496 L
.64931 .26414 L
.68954 .29257 L
Mistroke
.72232 .32915 L
.74639 .37243 L
.76078 .42072 L
.76494 .47212 L
.7587 .52462 L
.7423 .57615 L
.7164 .62469 L
.68201 .66833 L
.64047 .70537 L
.59342 .73435 L
.5427 .75414 L
.49031 .76395 L
.4383 .7634 L
.3887 .75251 L
.34348 .73171 L
.3044 .70182 L
.273 .66401 L
.2505 .61976 L
.2378 .57081 L
.23539 .51909 L
.24336 .46661 L
.2614 .41544 L
.28881 .3676 L
.32451 .32495 L
.36709 .28916 L
.41489 .26166 L
.46603 .24351 L
.51851 .23542 L
.57025 .23772 L
.61924 .25031 L
.66355 .2727 L
.70144 .30401 L
.73143 .34301 L
.75233 .38818 L
.76333 .43773 L
.764 .48973 L
.7543 .54213 L
.73462 .59287 L
.70574 .63997 L
.66878 .68158 L
.6252 .71606 L
.5767 .74207 L
.5252 .75857 L
.4727 .76492 L
.42128 .76088 L
.37294 .7466 L
.32959 .72264 L
.29293 .68994 L
.2644 .64979 L
.24511 .60376 L
Mistroke
.23583 .55366 L
.23691 .50145 L
.24832 .44918 L
.26961 .39891 L
.29994 .35261 L
.33812 .31209 L
.38265 .27895 L
.43179 .25448 L
.4836 .23964 L
.53606 .23503 L
.58711 .24081 L
.63473 .25677 L
.67707 .28227 L
.71246 .31632 L
.73951 .35757 L
.75716 .40442 L
.76472 .45501 L
.76189 .50738 L
.74878 .55945 L
.7259 .60919 L
.69417 .65464 L
.65481 .69403 L
.60937 .7258 L
.55965 .74871 L
.50758 .76185 L
.45522 .76473 L
.40461 .75721 L
.35774 .73959 L
.31646 .71258 L
.28239 .67722 L
.25685 .63491 L
.24086 .5873 L
.23503 .53626 L
.23961 .48381 L
.2544 .43198 L
.27883 .38283 L
.31195 .33828 L
.35244 .30007 L
.39872 .26971 L
.44898 .24839 L
.50125 .23694 L
.55346 .23581 L
.60357 .24506 L
.64962 .26431 L
.6898 .29281 L
.72253 .32944 L
.74652 .37276 L
.76084 .42108 L
.76493 .4725 L
.75861 .52499 L
Mistroke
.74215 .57651 L
Mfstroke
1 0 .244 r
.72155 .45527 m
.72058 .49905 L
.71097 .54288 L
.69307 .58502 L
.66759 .62382 L
.63554 .65777 L
.59817 .68552 L
.55694 .70599 L
.51348 .71838 L
.46949 .72219 L
.4267 .71729 L
.38679 .70386 L
.35131 .68243 L
.32168 .65384 L
.29904 .61921 L
.28429 .5799 L
.278 .53746 L
.28043 .49355 L
.29148 .44989 L
.3107 .40819 L
.33736 .3701 L
.3704 .33711 L
.40853 .31051 L
.45024 .29135 L
.49391 .28038 L
.53782 .27802 L
.58024 .28438 L
.61952 .2992 L
.6541 .3219 L
.68264 .35159 L
.70401 .3871 L
.71737 .42705 L
.7222 .46986 L
.71831 .51385 L
.70585 .5573 L
.68532 .5985 L
.65751 .63583 L
.62352 .66783 L
.58468 .69325 L
.54252 .71108 L
.49869 .72063 L
.45491 .72152 L
.4129 .71371 L
.37431 .69752 L
.34065 .67358 L
.31325 .64282 L
.29317 .60646 L
.28122 .56592 L
.27785 .52279 L
.28319 .47877 L
Mistroke
.29705 .43559 L
.31887 .39493 L
.3478 .35839 L
.3827 .32741 L
.42221 .30321 L
.46477 .28672 L
.50871 .27861 L
.55231 .27919 L
.59386 .28843 L
.63172 .30598 L
.66442 .33114 L
.69066 .36293 L
.70942 .40009 L
.71996 .44118 L
.72186 .48458 L
.71506 .52858 L
.69982 .57146 L
.67674 .61154 L
.64672 .64724 L
.61095 .67716 L
.57081 .70012 L
.5279 .71524 L
.4839 .7219 L
.44052 .71986 L
.39948 .70919 L
.36239 .69031 L
.3307 .66396 L
.30565 .63117 L
.28822 .59324 L
.27911 .55165 L
.27867 .50803 L
.28692 .4641 L
.30352 .42157 L
.32784 .38212 L
.35892 .3473 L
.39553 .31848 L
.43624 .29677 L
.47945 .28304 L
.52347 .27783 L
.56657 .28134 L
.60706 .29342 L
.64334 .31362 L
.674 .34113 L
.69783 .37487 L
.7139 .41353 L
.72157 .45558 L
.72055 .49937 L
.71087 .54319 L
.69291 .58531 L
.66738 .62408 L
Mistroke
.63529 .65799 L
.59788 .68569 L
.55664 .70611 L
.51317 .71844 L
.46918 .72219 L
.4264 .71722 L
.38651 .70373 L
.35108 .68225 L
.32149 .65361 L
.29891 .61894 L
.28421 .57961 L
.27799 .53715 L
.28048 .49323 L
.29159 .44958 L
.31087 .4079 L
.33758 .36985 L
.37066 .3369 L
.40882 .31035 L
.45055 .29124 L
.49423 .28033 L
.53813 .27804 L
.58054 .28445 L
.61979 .29933 L
.65433 .32209 L
.68282 .35182 L
.70413 .38738 L
.71743 .42735 L
.7222 .47017 L
.71825 .51416 L
.70573 .5576 L
.68514 .59878 L
.65728 .63608 L
.62325 .66804 L
.58439 .6934 L
.54221 .71118 L
.49837 .72067 L
.4546 .72149 L
.41261 .71363 L
.37405 .69738 L
.34043 .67338 L
.31308 .64258 L
.29306 .60618 L
.28116 .56562 L
.27785 .52248 L
.28326 .47846 L
.29718 .43528 L
.31905 .39465 L
.34803 .35815 L
.38297 .32721 L
.42251 .30306 L
Mistroke
.46508 .28663 L
.50903 .27858 L
.55262 .27922 L
.59415 .28853 L
.63198 .30613 L
.66463 .33134 L
.69082 .36318 L
.70952 .40038 L
.72 .44149 L
.72185 .48489 L
.71498 .52889 L
.69969 .57176 L
.67655 .61181 L
.64648 .64747 L
.61067 .67735 L
.57051 .70026 L
.52759 .71531 L
.48358 .72192 L
.44022 .71981 L
.3992 .70908 L
.36214 .69014 L
.33049 .66374 L
.30549 .63092 L
.28813 .59295 L
.27908 .55134 L
.2787 .50771 L
.28701 .46378 L
.30367 .42128 L
.32804 .38186 L
.35916 .34707 L
.39581 .31829 L
.43654 .29664 L
.47977 .28298 L
.52379 .27782 L
.56688 .28139 L
.60734 .29354 L
.64359 .31379 L
.6742 .34135 L
.69798 .37513 L
.71399 .41382 L
.72159 .45589 L
.72051 .49969 L
.71077 .5435 L
.69275 .5856 L
.66718 .62435 L
.63504 .65821 L
.5976 .68587 L
.55633 .70623 L
.51285 .71849 L
.46887 .72219 L
Mistroke
.4261 .71716 L
Mfstroke
.751 0 1 r
.33677 .35586 m
.37266 .32267 L
.41356 .29645 L
.45785 .27821 L
.50379 .26868 L
.54958 .26823 L
.59343 .27687 L
.63361 .29427 L
.66854 .31974 L
.69686 .35229 L
.71746 .39064 L
.72952 .43327 L
.73257 .47853 L
.7265 .52463 L
.71154 .56976 L
.68827 .61215 L
.65762 .65015 L
.62078 .68225 L
.5792 .70719 L
.53451 .72401 L
.48847 .73203 L
.44288 .73095 L
.39953 .72081 L
.36012 .70199 L
.32621 .67526 L
.29911 .64164 L
.2799 .60246 L
.26933 .55927 L
.26781 .51374 L
.2754 .46768 L
.29181 .42289 L
.31639 .38112 L
.34817 .34402 L
.38591 .31304 L
.42813 .28939 L
.47317 .27402 L
.51927 .26751 L
.5646 .27012 L
.60741 .28176 L
.64599 .30197 L
.67885 .32994 L
.70469 .36459 L
.72249 .40455 L
.73156 .44826 L
.73155 .494 L
.72245 .53998 L
.70461 .58438 L
.67875 .62548 L
.64587 .66165 L
.60727 .69147 L
Mistroke
.56446 .71378 L
.51911 .72771 L
.47302 .73269 L
.42799 .72854 L
.38578 .71543 L
.34805 .69386 L
.31629 .66468 L
.29174 .62903 L
.27536 .58833 L
.2678 .54415 L
.26935 .49825 L
.27995 .45241 L
.29919 .40844 L
.32631 .36807 L
.36025 .33287 L
.39967 .30423 L
.44303 .28327 L
.48862 .27082 L
.53466 .26737 L
.57934 .27304 L
.62091 .28762 L
.65773 .31054 L
.68836 .34089 L
.7116 .37749 L
.72654 .41889 L
.73258 .46348 L
.7295 .5095 L
.71741 .55515 L
.69678 .59863 L
.66844 .63824 L
.63348 .67243 L
.59329 .69985 L
.54943 .71943 L
.50363 .73039 L
.4577 .73232 L
.41342 .72512 L
.37254 .70909 L
.33666 .68486 L
.30719 .65337 L
.28529 .61586 L
.27182 .5738 L
.2673 .52885 L
.27191 .48276 L
.28548 .43735 L
.30746 .3944 L
.337 .3556 L
.37294 .32246 L
.41387 .29629 L
.45817 .27811 L
.50412 .26865 L
Mistroke
.5499 .26826 L
.59373 .27696 L
.63388 .29442 L
.66877 .31995 L
.69704 .35255 L
.71758 .39093 L
.72958 .43359 L
.73256 .47886 L
.72642 .52496 L
.7114 .57007 L
.68808 .61244 L
.65737 .6504 L
.6205 .68245 L
.57889 .70734 L
.53418 .7241 L
.48814 .73206 L
.44256 .73091 L
.39923 .7207 L
.35986 .70183 L
.32599 .67504 L
.29895 .64138 L
.2798 .60217 L
.26929 .55895 L
.26783 .51341 L
.27549 .46735 L
.29196 .42257 L
.31659 .38083 L
.34842 .34377 L
.3862 .31284 L
.42845 .28925 L
.4735 .27394 L
.5196 .26749 L
.56492 .27018 L
.6077 .28188 L
.64625 .30214 L
.67906 .33017 L
.70484 .36486 L
.72259 .40485 L
.7316 .44858 L
.73152 .49433 L
.72235 .5403 L
.70446 .58469 L
.67854 .62576 L
.64561 .66188 L
.60698 .69166 L
.56414 .71392 L
.51878 .72777 L
.47269 .73269 L
.42767 .72848 L
.38549 .7153 L
Mistroke
.3478 .69367 L
.31609 .66444 L
.29159 .62876 L
.27528 .58802 L
.26778 .54383 L
.26939 .49792 L
.28006 .45209 L
.29936 .40814 L
.32653 .36779 L
.36051 .33264 L
.39997 .30405 L
.44335 .28315 L
.48895 .27077 L
.53499 .26738 L
.57965 .27311 L
.62119 .28776 L
.65797 .31073 L
.68856 .34113 L
.71174 .37777 L
.72661 .4192 L
.73259 .46381 L
.72944 .50983 L
.71729 .55547 L
.69661 .59893 L
.66821 .63851 L
.63321 .67265 L
.59298 .70002 L
.54911 .71954 L
.5033 .73044 L
.45737 .7323 L
.41311 .72504 L
.37226 .70895 L
.33642 .68466 L
.30701 .65312 L
.28516 .61557 L
.27175 .57349 L
.2673 .52852 L
.27198 .48243 L
.28561 .43704 L
.30765 .39411 L
.33724 .35534 L
.37322 .32225 L
.41417 .29613 L
.4585 .27801 L
.50445 .26861 L
.55022 .26829 L
.59403 .27706 L
.63415 .29458 L
.669 .32016 L
.69722 .3528 L
Mistroke
.71769 .39122 L
Mfstroke
0 .266 1 r
.69314 .48583 m
.68737 .52413 L
.67424 .56148 L
.65428 .59642 L
.62826 .62758 L
.59721 .65373 L
.56234 .67385 L
.52503 .68714 L
.48673 .69309 L
.44896 .69146 L
.41319 .68232 L
.38082 .66602 L
.35314 .6432 L
.33121 .61477 L
.31591 .58183 L
.30784 .54568 L
.30731 .50774 L
.31433 .46949 L
.32865 .43244 L
.34969 .39805 L
.37663 .36765 L
.40841 .34245 L
.44379 .32343 L
.48137 .31134 L
.51968 .30665 L
.55722 .30956 L
.59252 .31993 L
.62418 .33738 L
.65097 .3612 L
.67184 .39048 L
.68596 .42405 L
.69278 .4606 L
.69204 .4987 L
.68376 .53685 L
.66827 .57355 L
.64617 .60737 L
.61834 .63697 L
.58586 .6612 L
.55002 .6791 L
.51221 .68997 L
.47392 .69339 L
.43666 .68921 L
.40188 .67762 L
.37095 .65904 L
.34509 .63423 L
.3253 .60415 L
.31237 .56998 L
.30681 .53307 L
.30883 .49486 L
.31835 .45685 L
Mistroke
.335 .42053 L
.35813 .38733 L
.38682 .35856 L
.41995 .33533 L
.45623 .31857 L
.49423 .30893 L
.53245 .30678 L
.5694 .31222 L
.60362 .32503 L
.63378 .34471 L
.65868 .37048 L
.67736 .40133 L
.68908 .43606 L
.69338 .47329 L
.69009 .51158 L
.67934 .54941 L
.66155 .5853 L
.63742 .61784 L
.6079 .64576 L
.57414 .66796 L
.53747 .68356 L
.49933 .69196 L
.46122 .69283 L
.42463 .68613 L
.391 .67213 L
.36165 .65137 L
.33772 .62467 L
.32017 .59307 L
.30967 .55783 L
.30664 .52031 L
.3112 .482 L
.32317 .44439 L
.34208 .40897 L
.36719 .37712 L
.39751 .35009 L
.43185 .32894 L
.46887 .31451 L
.50711 .30736 L
.54507 .30777 L
.58126 .31572 L
.61426 .3309 L
.64278 .35273 L
.66569 .38033 L
.6821 .41262 L
.69137 .44835 L
.69312 .4861 L
.6873 .5244 L
.67412 .56174 L
.65411 .59666 L
.62805 .62779 L
Mistroke
.59697 .6539 L
.56208 .67397 L
.52476 .68721 L
.48646 .6931 L
.44869 .69142 L
.41294 .68222 L
.38061 .66588 L
.35296 .64302 L
.33108 .61455 L
.31583 .58158 L
.30781 .54541 L
.30733 .50746 L
.31441 .46922 L
.32878 .43219 L
.34986 .39781 L
.37684 .36745 L
.40865 .34229 L
.44405 .32332 L
.48164 .31128 L
.51996 .30665 L
.55749 .30961 L
.59276 .32004 L
.62439 .33753 L
.65114 .3614 L
.67196 .39071 L
.68603 .4243 L
.6928 .46087 L
.69201 .49898 L
.68367 .53712 L
.66813 .57381 L
.64599 .6076 L
.61812 .63717 L
.58562 .66135 L
.54975 .6792 L
.51193 .69002 L
.47365 .69339 L
.4364 .68916 L
.40164 .67751 L
.37074 .65889 L
.34492 .63403 L
.32518 .60392 L
.31231 .56973 L
.3068 .5328 L
.30887 .49458 L
.31844 .45658 L
.33514 .42028 L
.35831 .38711 L
.38704 .35837 L
.42021 .33519 L
.4565 .31847 L
Mistroke
.4945 .30888 L
.53272 .30679 L
.56965 .31229 L
.60385 .32515 L
.63398 .34487 L
.65884 .37068 L
.67747 .40157 L
.68914 .43632 L
.69338 .47357 L
.69004 .51185 L
.67924 .54967 L
.6614 .58554 L
.63722 .61806 L
.60767 .64594 L
.57388 .66809 L
.5372 .68365 L
.49906 .692 L
.46095 .69281 L
.42438 .68606 L
.39077 .672 L
.36145 .6512 L
.33757 .62446 L
.32007 .59283 L
.30962 .55757 L
.30665 .52004 L
.31126 .48173 L
.32328 .44413 L
.34224 .40873 L
.36739 .37691 L
.39774 .34992 L
.43211 .32882 L
.46914 .31443 L
.50738 .30734 L
.54533 .3078 L
.58151 .3158 L
.61448 .33104 L
.64296 .3529 L
.66583 .38054 L
.6822 .41287 L
.69141 .44862 L
.69311 .48638 L
.68723 .52468 L
.674 .562 L
.65395 .5969 L
.62785 .62799 L
.59673 .65406 L
.56182 .67409 L
.52448 .68728 L
.48619 .69312 L
.44843 .69138 L
Mistroke
.4127 .68213 L
Mfstroke
.335 0 1 r
.73278 .28632 m
.76489 .33146 L
.7866 .38321 L
.79706 .43955 L
.79586 .49826 L
.78306 .55703 L
.75914 .61357 L
.72505 .66565 L
.68213 .71123 L
.63207 .74852 L
.57682 .77606 L
.51855 .79276 L
.45956 .79797 L
.40215 .79149 L
.34859 .77357 L
.30097 .74491 L
.26115 .70664 L
.23071 .66026 L
.21084 .60759 L
.20232 .5507 L
.20548 .49182 L
.2202 .43326 L
.2459 .37732 L
.28158 .32619 L
.32582 .28189 L
.3769 .24614 L
.43281 .22036 L
.49136 .20555 L
.55025 .2023 L
.60716 .21073 L
.65987 .23052 L
.70631 .26088 L
.74465 .30062 L
.77339 .34819 L
.79139 .40172 L
.79796 .45911 L
.79284 .5181 L
.77623 .57638 L
.74877 .63166 L
.71155 .68177 L
.66603 .72475 L
.61399 .75891 L
.55748 .78291 L
.49871 .79581 L
.44 .79709 L
.38363 .78672 L
.33184 .7651 L
.28664 .73307 L
.24982 .69189 L
.22282 .64318 L
Mistroke
.20669 .58886 L
.20208 .53104 L
.20916 .47201 L
.22765 .41407 L
.25683 .35951 L
.29555 .31047 L
.3423 .26886 L
.39524 .23632 L
.45229 .21413 L
.51121 .20316 L
.56969 .20384 L
.62544 .21614 L
.67626 .23958 L
.72017 .27325 L
.75543 .31581 L
.78067 .3656 L
.7949 .42067 L
.79755 .47885 L
.78852 .53786 L
.76817 .59538 L
.7373 .64916 L
.69711 .69709 L
.64919 .73728 L
.59541 .76816 L
.53789 .78851 L
.47888 .79755 L
.4207 .7949 L
.36563 .78068 L
.31584 .75545 L
.27327 .72019 L
.2396 .67629 L
.21615 .62547 L
.20384 .56972 L
.20315 .51124 L
.21412 .45232 L
.2363 .39527 L
.26883 .34233 L
.31044 .29558 L
.35948 .25685 L
.41404 .22766 L
.47197 .20916 L
.53101 .20208 L
.58882 .20669 L
.64315 .22281 L
.69186 .2498 L
.73304 .28662 L
.76508 .33181 L
.78671 .3836 L
.79709 .43996 L
.79581 .49868 L
Mistroke
.78292 .55745 L
.75893 .61396 L
.72478 .666 L
.6818 .71153 L
.63169 .74875 L
.57641 .77621 L
.51813 .79284 L
.45914 .79797 L
.40175 .7914 L
.34822 .7734 L
.30065 .74467 L
.2609 .70633 L
.23053 .6599 L
.21074 .6072 L
.2023 .55028 L
.20555 .4914 L
.22035 .43285 L
.24612 .37693 L
.28186 .32585 L
.32616 .2816 L
.37729 .24592 L
.43323 .22021 L
.49179 .20549 L
.55067 .20232 L
.60756 .21084 L
.66023 .2307 L
.70662 .26113 L
.74489 .30094 L
.77355 .34856 L
.79148 .40212 L
.79797 .45953 L
.79276 .51852 L
.77607 .57678 L
.74854 .63204 L
.71125 .68211 L
.66568 .72503 L
.6136 .75912 L
.55707 .78305 L
.49829 .79586 L
.43958 .79706 L
.38324 .78661 L
.33149 .7649 L
.28635 .7328 L
.24959 .69157 L
.22266 .64281 L
.20662 .58845 L
.20209 .53062 L
.20925 .47159 L
.22782 .41367 L
.25707 .35914 L
Mistroke
.29586 .31014 L
.34266 .26859 L
.39564 .23612 L
.45271 .21401 L
.51163 .20312 L
.5701 .20388 L
.62582 .21627 L
.6766 .23979 L
.72045 .27352 L
.75565 .31614 L
.78081 .36598 L
.79496 .42108 L
.79753 .47927 L
.78842 .53828 L
.76799 .59578 L
.73704 .64953 L
.6968 .6974 L
.64882 .73754 L
.59501 .76834 L
.53747 .78862 L
.47846 .79757 L
.42029 .79484 L
.36525 .78054 L
.3155 .75523 L
.27299 .7199 L
.23939 .67595 L
.21602 .62508 L
.20379 .56931 L
.20319 .51082 L
.21424 .4519 L
.2365 .39487 L
.2691 .34197 L
.31077 .29527 L
.35986 .2566 L
.41445 .22749 L
.4724 .20907 L
.53143 .20207 L
.58923 .20676 L
.64352 .22296 L
.69219 .25003 L
.73331 .28692 L
.76527 .33216 L
.78683 .38399 L
.79712 .44038 L
.79576 .4991 L
.78279 .55786 L
.75872 .61435 L
.7245 .66635 L
.68146 .71183 L
.63131 .74899 L
Mistroke
.576 .77637 L
Mfstroke
0 .8 1 r
.48144 .44265 m
.49366 .43867 L
.50613 .43709 L
.51836 .43798 L
.52986 .4413 L
.5402 .44693 L
.54896 .45464 L
.55579 .46413 L
.56044 .47503 L
.56271 .48691 L
.56253 .4993 L
.55989 .51172 L
.5549 .52368 L
.54775 .53471 L
.53873 .54438 L
.52819 .55231 L
.51654 .55818 L
.50425 .56177 L
.49179 .56294 L
.47965 .56163 L
.46831 .55791 L
.45821 .55192 L
.44975 .54388 L
.44327 .53413 L
.43901 .52303 L
.43714 .51104 L
.43775 .4986 L
.44079 .48623 L
.44616 .47439 L
.45364 .46356 L
.46294 .45416 L
.4737 .44656 L
.48549 .44105 L
.49784 .43786 L
.51029 .43711 L
.52232 .43883 L
.53349 .44294 L
.54333 .4493 L
.55148 .45764 L
.55761 .46765 L
.56147 .47893 L
.56293 .49103 L
.56191 .50349 L
.55847 .51581 L
.55272 .52751 L
.54491 .53813 L
.53534 .54725 L
.52438 .55452 L
.51247 .55965 L
.50006 .56244 L
Mistroke
.48765 .56277 L
.47573 .56065 L
.46476 .55614 L
.45517 .54943 L
.44734 .54078 L
.44158 .53053 L
.43811 .51908 L
.43707 .50689 L
.4385 .49442 L
.44234 .48217 L
.44845 .47062 L
.45658 .46023 L
.46641 .45139 L
.47756 .44446 L
.4896 .43972 L
.50204 .43733 L
.5144 .43741 L
.52619 .43995 L
.53696 .44484 L
.54628 .45189 L
.55378 .46084 L
.55917 .47132 L
.56224 .48292 L
.56286 .4952 L
.56102 .50767 L
.55678 .51983 L
.55032 .53122 L
.54188 .54138 L
.5318 .54991 L
.52047 .55649 L
.50833 .56085 L
.49587 .56283 L
.48357 .56233 L
.47192 .55939 L
.46136 .55412 L
.45233 .54673 L
.44516 .5375 L
.44015 .5268 L
.43749 .51505 L
.43728 .50271 L
.43953 .49026 L
.44415 .47819 L
.45097 .46698 L
.45971 .45707 L
.47003 .44884 L
.48153 .44262 L
.49375 .43865 L
.50622 .43708 L
.51844 .43799 L
.52994 .44133 L
Mistroke
.54027 .44698 L
.54901 .4547 L
.55583 .4642 L
.56046 .47511 L
.56272 .48699 L
.56252 .49939 L
.55986 .51181 L
.55485 .52376 L
.54769 .53478 L
.53866 .54444 L
.52811 .55236 L
.51646 .55821 L
.50416 .56179 L
.4917 .56294 L
.47956 .56161 L
.46823 .55788 L
.45814 .55186 L
.4497 .54382 L
.44323 .53405 L
.43899 .52295 L
.43714 .51095 L
.43776 .49851 L
.44082 .48614 L
.44621 .47431 L
.4537 .46349 L
.46302 .4541 L
.47378 .44651 L
.48557 .44102 L
.49793 .43785 L
.51037 .43711 L
.52241 .43885 L
.53356 .44298 L
.5434 .44935 L
.55153 .45771 L
.55764 .46773 L
.56149 .47901 L
.56293 .49112 L
.5619 .50358 L
.55843 .5159 L
.55268 .52759 L
.54485 .5382 L
.53527 .54731 L
.5243 .55456 L
.51238 .55968 L
.49997 .56245 L
.48756 .56277 L
.47565 .56062 L
.46468 .5561 L
.45511 .54938 L
.44729 .54071 L
Mistroke
.44155 .53045 L
.43809 .519 L
.43707 .5068 L
.43852 .49433 L
.44238 .48208 L
.4485 .47054 L
.45664 .46016 L
.46649 .45133 L
.47765 .44442 L
.48968 .43969 L
.50213 .43733 L
.51448 .43742 L
.52627 .43997 L
.53703 .44488 L
.54634 .45195 L
.55382 .46091 L
.5592 .4714 L
.56225 .48301 L
.56286 .49529 L
.561 .50776 L
.55675 .51992 L
.55027 .53129 L
.54181 .54144 L
.53172 .54997 L
.52038 .55653 L
.50824 .56088 L
.49578 .56283 L
.48348 .56232 L
.47184 .55936 L
.46129 .55408 L
.45227 .54667 L
.44512 .53743 L
.44012 .52672 L
.43748 .51496 L
.43728 .50262 L
.43955 .49017 L
.44419 .47811 L
.45102 .4669 L
.45978 .457 L
.47011 .44879 L
.48161 .44258 L
.49384 .43863 L
.50631 .43708 L
.51853 .43801 L
.53002 .44137 L
.54034 .44703 L
.54907 .45476 L
.55588 .46428 L
.56049 .47519 L
.56273 .48708 L
Mistroke
.56251 .49948 L
Mfstroke
1 0 .096 r
.47914 .47656 m
.48473 .4723 L
.49091 .46912 L
.49745 .46715 L
.50409 .46647 L
.51057 .46711 L
.51664 .46904 L
.52205 .47218 L
.52659 .47642 L
.5301 .48158 L
.53242 .48746 L
.53347 .49384 L
.5332 .50046 L
.53164 .50706 L
.52883 .51338 L
.52489 .51918 L
.51997 .52422 L
.51427 .52832 L
.50801 .5313 L
.50143 .53305 L
.4948 .53351 L
.48838 .53265 L
.4824 .53051 L
.47712 .52718 L
.47274 .52277 L
.46943 .51748 L
.46731 .51149 L
.46648 .50506 L
.46697 .49843 L
.46875 .49186 L
.47176 .4856 L
.47587 .47992 L
.48094 .47502 L
.48675 .4711 L
.49308 .46832 L
.49968 .46678 L
.5063 .46654 L
.51266 .46762 L
.51854 .46996 L
.52368 .47349 L
.52789 .47806 L
.53101 .48349 L
.53292 .48956 L
.53353 .49605 L
.53282 .50269 L
.53083 .50922 L
.52762 .5154 L
.52334 .52097 L
.51813 .52571 L
.51222 .52945 L
Mistroke
.50582 .53203 L
.4992 .53335 L
.49261 .53337 L
.48631 .53208 L
.48054 .52952 L
.47554 .52581 L
.4715 .52109 L
.46858 .51553 L
.46689 .50937 L
.4665 .50284 L
.46742 .4962 L
.46963 .48971 L
.47302 .48362 L
.47748 .47817 L
.48281 .47359 L
.48883 .47003 L
.49528 .46766 L
.50191 .46655 L
.50847 .46676 L
.5147 .46827 L
.52035 .47102 L
.52521 .47492 L
.52907 .47979 L
.53179 .48546 L
.53327 .49171 L
.53344 .49827 L
.53229 .50491 L
.52988 .51135 L
.5263 .51734 L
.52168 .52266 L
.51622 .52709 L
.51011 .53045 L
.50361 .53262 L
.49697 .53351 L
.49045 .53308 L
.4843 .53135 L
.47877 .5284 L
.47407 .52433 L
.47039 .5193 L
.46787 .51352 L
.46661 .50721 L
.46666 .50061 L
.46803 .49399 L
.47064 .48761 L
.47441 .48171 L
.47918 .47653 L
.48477 .47227 L
.49096 .4691 L
.4975 .46714 L
.50414 .46647 L
Mistroke
.51062 .46712 L
.51668 .46906 L
.52208 .47221 L
.52662 .47645 L
.53012 .48162 L
.53243 .48751 L
.53347 .49389 L
.5332 .50051 L
.53162 .5071 L
.5288 .51342 L
.52486 .51922 L
.51993 .52426 L
.51423 .52834 L
.50796 .53132 L
.50139 .53306 L
.49476 .53351 L
.48833 .53264 L
.48236 .53049 L
.47709 .52715 L
.47271 .52274 L
.46941 .51744 L
.4673 .51145 L
.46648 .50501 L
.46698 .49838 L
.46877 .49181 L
.47178 .48556 L
.47591 .47988 L
.48098 .47499 L
.48679 .47108 L
.49313 .4683 L
.49973 .46677 L
.50634 .46654 L
.51271 .46763 L
.51858 .46999 L
.52371 .47352 L
.52792 .47809 L
.53103 .48353 L
.53292 .48961 L
.53353 .49609 L
.53281 .50274 L
.53081 .50927 L
.5276 .51544 L
.5233 .521 L
.51809 .52574 L
.51217 .52947 L
.50578 .53204 L
.49915 .53336 L
.49256 .53337 L
.48626 .53206 L
.48051 .5295 L
Mistroke
.47551 .52578 L
.47148 .52105 L
.46856 .51549 L
.46688 .50933 L
.4665 .50279 L
.46744 .49615 L
.46965 .48966 L
.47305 .48358 L
.47751 .47814 L
.48286 .47356 L
.48887 .47001 L
.49533 .46765 L
.50196 .46655 L
.50852 .46676 L
.51475 .46828 L
.52039 .47105 L
.52524 .47495 L
.52909 .47983 L
.53181 .48551 L
.53327 .49175 L
.53343 .49832 L
.53228 .50495 L
.52986 .51139 L
.52627 .51739 L
.52165 .5227 L
.51618 .52712 L
.51007 .53047 L
.50357 .53263 L
.49692 .53351 L
.4904 .53307 L
.48426 .53134 L
.47873 .52837 L
.47404 .5243 L
.47037 .51926 L
.46786 .51348 L
.46661 .50716 L
.46667 .50056 L
.46804 .49394 L
.47066 .48756 L
.47444 .48167 L
.47922 .47649 L
.48481 .47224 L
.491 .46908 L
.49755 .46713 L
.50419 .46647 L
.51066 .46713 L
.51672 .46908 L
.52212 .47224 L
.52665 .47649 L
.53014 .48166 L
Mistroke
.53244 .48755 L
Mfstroke
1 0 .785 r
.41185 .40529 m
.43459 .38728 L
.45989 .3737 L
.48677 .36507 L
.51417 .36174 L
.54101 .36383 L
.56624 .37127 L
.58887 .38376 L
.60802 .40081 L
.62292 .42176 L
.63301 .44577 L
.63787 .47192 L
.63732 .49916 L
.63138 .52644 L
.62028 .55268 L
.60447 .57686 L
.58455 .59801 L
.56132 .61533 L
.53568 .62811 L
.50864 .63587 L
.48126 .63829 L
.45462 .63529 L
.42975 .62698 L
.40765 .61368 L
.38917 .59592 L
.37503 .5744 L
.36581 .54996 L
.36185 .52356 L
.36331 .49623 L
.37013 .46905 L
.38206 .44309 L
.39861 .41936 L
.41914 .39879 L
.44284 .3822 L
.46879 .37023 L
.49596 .36335 L
.52329 .36183 L
.54971 .36574 L
.57418 .37492 L
.59573 .389 L
.61353 .40745 L
.62687 .42952 L
.63523 .45436 L
.63829 .48099 L
.63592 .50837 L
.62821 .53542 L
.61547 .56108 L
.5982 .58434 L
.57708 .60429 L
.55293 .62015 L
Mistroke
.52671 .63129 L
.49943 .63728 L
.47218 .63789 L
.44602 .63308 L
.42198 .62305 L
.401 .60819 L
.3839 .58908 L
.37137 .56648 L
.36388 .54127 L
.36173 .51443 L
.36501 .48704 L
.37359 .46015 L
.38713 .43482 L
.40509 .41206 L
.42679 .39274 L
.45135 .37764 L
.47783 .36733 L
.50517 .36223 L
.53232 .36254 L
.55819 .36825 L
.58178 .37912 L
.60216 .39474 L
.61853 .41449 L
.63025 .4376 L
.63686 .46315 L
.6381 .49015 L
.63391 .51754 L
.62447 .54424 L
.61015 .5692 L
.5915 .59145 L
.56927 .61011 L
.54431 .62444 L
.51761 .6339 L
.49023 .63809 L
.46322 .63687 L
.43766 .63028 L
.41455 .61857 L
.39479 .60221 L
.37916 .58184 L
.36827 .55826 L
.36255 .53239 L
.36223 .50525 L
.36731 .4779 L
.3776 .45142 L
.3927 .42685 L
.412 .40515 L
.43476 .38717 L
.46008 .37362 L
.48696 .36503 L
.51436 .36173 L
Mistroke
.5412 .36386 L
.56641 .37134 L
.58902 .38387 L
.60814 .40095 L
.62301 .42192 L
.63306 .44595 L
.63788 .47211 L
.63729 .49936 L
.63132 .52663 L
.62019 .55286 L
.60434 .57702 L
.5844 .59815 L
.56114 .61543 L
.53549 .62818 L
.50844 .6359 L
.48106 .63829 L
.45443 .63525 L
.42958 .6269 L
.4075 .61357 L
.38905 .59578 L
.37495 .57424 L
.36576 .54978 L
.36184 .52336 L
.36334 .49604 L
.3702 .46886 L
.38216 .44291 L
.39874 .4192 L
.4193 .39866 L
.44302 .38209 L
.46898 .37016 L
.49616 .36332 L
.52349 .36184 L
.54989 .36579 L
.57434 .375 L
.59587 .38912 L
.61364 .40759 L
.62695 .42969 L
.63527 .45455 L
.63829 .48119 L
.63588 .50857 L
.62814 .53561 L
.61537 .56125 L
.59807 .5845 L
.57692 .60442 L
.55275 .62025 L
.52651 .63136 L
.49923 .63731 L
.47199 .63787 L
.44584 .63302 L
.42182 .62296 L
Mistroke
.40086 .60806 L
.3838 .58893 L
.37129 .5663 L
.36384 .54108 L
.36173 .51424 L
.36505 .48684 L
.37367 .45996 L
.38724 .43465 L
.40524 .4119 L
.42695 .39262 L
.45154 .37754 L
.47802 .36728 L
.50537 .36222 L
.53251 .36257 L
.55837 .36831 L
.58194 .37922 L
.60229 .39487 L
.61864 .41465 L
.63032 .43777 L
.63689 .46334 L
.63809 .49035 L
.63386 .51774 L
.62439 .54443 L
.61003 .56937 L
.59136 .5916 L
.5691 .61023 L
.54412 .62453 L
.51742 .63394 L
.49003 .6381 L
.46303 .63684 L
.43749 .63021 L
.4144 .61847 L
.39466 .60208 L
.37906 .58168 L
.36821 .55808 L
.36253 .5322 L
.36225 .50505 L
.36737 .47771 L
.37769 .45124 L
.39282 .42668 L
.41215 .405 L
.43493 .38705 L
.46027 .37354 L
.48716 .36498 L
.51456 .36173 L
.54138 .3639 L
.56659 .37141 L
.58917 .38397 L
.60826 .40109 L
.6231 .42208 L
Mistroke
.63311 .44613 L
Mfstroke
1 0 .452 r
.6538 .28819 m
.68905 .31764 L
.71688 .35425 L
.73619 .39659 L
.74624 .44298 L
.74662 .4916 L
.73732 .54056 L
.71871 .58793 L
.69152 .63184 L
.65681 .67058 L
.61595 .70263 L
.57053 .72672 L
.52235 .74192 L
.47329 .74762 L
.42528 .7436 L
.3802 .73002 L
.33982 .70742 L
.30573 .67667 L
.27926 .639 L
.26146 .59586 L
.25302 .54897 L
.25427 .50015 L
.26516 .45133 L
.28528 .40441 L
.31382 .36125 L
.34966 .32353 L
.39141 .29274 L
.43741 .27009 L
.48588 .25645 L
.5349 .25238 L
.58255 .25802 L
.62695 .27316 L
.66638 .2972 L
.69928 .3292 L
.72435 .36791 L
.74062 .4118 L
.74745 .45915 L
.74457 .5081 L
.73209 .55673 L
.7105 .60314 L
.68064 .6455 L
.6437 .68215 L
.60112 .71166 L
.55457 .73285 L
.50588 .74491 L
.45696 .74735 L
.40972 .74009 L
.36603 .7234 L
.3276 .69795 L
.29594 .66473 L
Mistroke
.27228 .62504 L
.25756 .58045 L
.25235 .5327 L
.25687 .48366 L
.27092 .43527 L
.29397 .38942 L
.3251 .3479 L
.3631 .31236 L
.40646 .28418 L
.4535 .26447 L
.50237 .254 L
.55114 .25319 L
.59791 .26207 L
.64083 .28028 L
.67822 .30711 L
.70862 .34152 L
.73084 .38215 L
.74399 .4274 L
.74757 .4755 L
.74143 .52456 L
.72582 .57266 L
.70134 .6179 L
.66896 .65852 L
.62996 .69292 L
.58585 .71975 L
.53837 .73795 L
.48938 .74681 L
.44082 .74599 L
.39457 .73551 L
.35247 .71579 L
.31615 .68761 L
.28705 .65205 L
.2663 .61054 L
.25473 .56468 L
.25278 .51628 L
.26054 .46725 L
.27769 .4195 L
.30357 .37491 L
.33716 .33523 L
.37714 .30202 L
.42194 .27657 L
.4698 .2599 L
.51885 .25264 L
.56716 .2551 L
.61283 .26717 L
.65408 .28837 L
.68928 .31788 L
.71705 .35454 L
.7363 .39691 L
.74628 .44332 L
Mistroke
.74659 .49196 L
.73722 .54091 L
.71855 .58826 L
.6913 .63214 L
.65654 .67084 L
.61563 .70283 L
.57019 .72686 L
.522 .74199 L
.47294 .74762 L
.42494 .74354 L
.37989 .72989 L
.33955 .70723 L
.30551 .67643 L
.2791 .6387 L
.26137 .59554 L
.25299 .54862 L
.25431 .4998 L
.26528 .45098 L
.28545 .40409 L
.31405 .36096 L
.34994 .32329 L
.39172 .29255 L
.43776 .26996 L
.48623 .25639 L
.53525 .25238 L
.58288 .2581 L
.62726 .2733 L
.66664 .2974 L
.69949 .32946 L
.7245 .36821 L
.74071 .41212 L
.74747 .45949 L
.74451 .50845 L
.73196 .55708 L
.71031 .60346 L
.6804 .64579 L
.64341 .68239 L
.6008 .71184 L
.55423 .73297 L
.50553 .74496 L
.45661 .74734 L
.4094 .74 L
.36574 .72325 L
.32735 .69774 L
.29574 .66447 L
.27214 .62474 L
.25749 .58012 L
.25235 .53235 L
.25693 .48331 L
.27106 .43493 L
Mistroke
.29416 .3891 L
.32535 .34762 L
.36339 .31213 L
.40679 .28401 L
.45385 .26436 L
.50272 .25396 L
.55149 .25322 L
.59823 .26216 L
.64112 .28044 L
.67847 .30734 L
.70881 .34179 L
.73096 .38246 L
.74405 .42773 L
.74756 .47585 L
.74135 .52491 L
.72567 .57299 L
.70114 .61821 L
.66871 .65879 L
.62966 .69314 L
.58552 .71991 L
.53802 .73805 L
.48903 .74684 L
.44048 .74595 L
.39425 .7354 L
.35218 .71562 L
.31591 .68738 L
.28687 .65178 L
.26619 .61022 L
.25468 .56434 L
.25281 .51593 L
.26063 .4669 L
.27785 .41917 L
.30379 .37461 L
.33742 .33497 L
.37744 .3018 L
.42227 .27642 L
.47015 .25981 L
.5192 .25263 L
.5675 .25515 L
.61315 .26729 L
.65435 .28855 L
.6895 .31812 L
.71721 .35482 L
.7364 .39723 L
.74631 .44366 L
.74656 .49231 L
.73712 .54126 L
.71838 .58858 L
.69107 .63244 L
.65626 .67109 L
Mistroke
.61532 .70303 L
Mfstroke
1 .456 0 r
.78539 .2953 m
.81338 .35094 L
.82906 .41243 L
.83183 .47735 L
.82158 .54316 L
.79871 .60728 L
.76411 .66719 L
.71915 .72054 L
.66558 .76523 L
.60552 .79952 L
.54132 .82204 L
.4755 .83193 L
.41063 .8288 L
.34928 .81275 L
.29384 .78444 L
.24649 .74496 L
.20909 .69587 L
.18311 .63909 L
.16956 .57685 L
.16898 .51159 L
.1814 .44588 L
.20631 .3823 L
.24276 .32333 L
.2893 .2713 L
.3441 .22824 L
.40503 .19585 L
.46968 .1754 L
.53553 .16768 L
.59998 .17301 L
.6605 .19117 L
.71473 .22145 L
.76053 .26266 L
.7961 .31319 L
.82006 .37104 L
.83145 .43396 L
.82983 .49948 L
.81527 .56501 L
.78834 .62799 L
.75009 .68595 L
.70203 .73661 L
.64603 .77798 L
.58431 .80844 L
.51928 .8268 L
.45349 .83234 L
.38952 .82483 L
.32989 .80457 L
.27694 .77236 L
.23274 .72946 L
.19903 .67756 L
.17714 .61868 L
Mistroke
.16791 .55515 L
.17172 .48946 L
.18841 .42417 L
.21733 .36187 L
.25734 .30498 L
.30688 .25575 L
.36399 .21611 L
.42644 .1876 L
.49179 .17136 L
.55745 .16801 L
.62086 .1777 L
.67952 .20003 L
.73114 .23414 L
.77369 .27868 L
.8055 .3319 L
.82531 .39172 L
.83236 .4558 L
.82637 .5216 L
.80757 .58656 L
.77669 .64812 L
.73496 .70387 L
.68401 .75162 L
.62583 .78949 L
.56272 .816 L
.49714 .83011 L
.43168 .83127 L
.3689 .81942 L
.31126 .79504 L
.26103 .75907 L
.22018 .71294 L
.19031 .65846 L
.1726 .59775 L
.16773 .53321 L
.17591 .46736 L
.1968 .4028 L
.22959 .34205 L
.273 .2875 L
.32531 .24129 L
.38448 .20523 L
.44819 .18074 L
.51392 .16878 L
.57911 .16982 L
.6412 .18382 L
.69774 .21023 L
.74653 .248 L
.78564 .29567 L
.81353 .35136 L
.82913 .41288 L
.8318 .47782 L
.82146 .54363 L
Mistroke
.7985 .60773 L
.76382 .6676 L
.71879 .72089 L
.66517 .76552 L
.60508 .79972 L
.54085 .82216 L
.47503 .83196 L
.41018 .82873 L
.34886 .81259 L
.29347 .78419 L
.24619 .74464 L
.20886 .69548 L
.18297 .63866 L
.16951 .57639 L
.16903 .51112 L
.18153 .44542 L
.20654 .38186 L
.24306 .32293 L
.28966 .27096 L
.34452 .22797 L
.40548 .19566 L
.47016 .17529 L
.536 .16767 L
.60043 .17309 L
.66092 .19134 L
.71509 .22171 L
.76082 .26299 L
.79632 .31358 L
.82018 .37148 L
.83148 .43443 L
.82977 .49995 L
.81512 .56547 L
.7881 .62842 L
.74978 .68634 L
.70165 .73694 L
.64561 .77824 L
.58385 .80862 L
.5188 .82689 L
.45302 .83233 L
.38908 .82473 L
.32949 .80438 L
.27659 .77209 L
.23246 .72912 L
.19883 .67716 L
.17702 .61824 L
.16789 .55468 L
.17179 .48898 L
.18857 .42371 L
.21757 .36144 L
.25766 .3046 L
Mistroke
.30726 .25543 L
.36442 .21586 L
.42691 .18744 L
.49226 .17129 L
.55791 .16804 L
.6213 .17781 L
.67992 .20023 L
.73148 .23442 L
.77396 .27903 L
.80568 .33231 L
.82541 .39217 L
.83237 .45626 L
.82628 .52207 L
.80739 .58702 L
.77643 .64855 L
.73463 .70425 L
.68361 .75193 L
.6254 .78972 L
.56226 .81615 L
.49667 .83017 L
.43122 .83123 L
.36847 .81929 L
.31087 .79482 L
.2607 .75878 L
.21993 .71258 L
.19014 .65804 L
.17252 .5973 L
.16774 .53274 L
.17601 .46689 L
.19699 .40235 L
.22987 .34163 L
.27334 .28714 L
.32571 .24099 L
.38492 .20501 L
.44865 .18061 L
.51439 .16874 L
.57957 .16988 L
.64163 .18396 L
.69812 .21046 L
.74684 .24831 L
.78588 .29605 L
.81369 .35178 L
.82919 .41334 L
.83178 .47829 L
.82134 .5441 L
.79829 .60818 L
.76353 .66801 L
.71844 .72125 L
.66476 .7658 L
.60463 .79992 L
Mistroke
.54038 .82228 L
Mfstroke
.335 1 0 r
.22927 .76176 m
.18929 .70933 L
.16152 .64868 L
.14702 .58221 L
.14638 .5125 L
.15962 .44231 L
.18622 .37438 L
.22513 .31138 L
.27483 .25578 L
.33336 .20976 L
.39844 .17514 L
.4675 .15327 L
.53784 .145 L
.60669 .15067 L
.67135 .17005 L
.72929 .20237 L
.77823 .24638 L
.81626 .30034 L
.84187 .36214 L
.85406 .42934 L
.85236 .49932 L
.83683 .56933 L
.80808 .63661 L
.76724 .69854 L
.71591 .75267 L
.6561 .79689 L
.59018 .82945 L
.52071 .84908 L
.45043 .85502 L
.38209 .84702 L
.31839 .8254 L
.26181 .79101 L
.21457 .7452 L
.17854 .68977 L
.15513 .62689 L
.14525 .55903 L
.14929 .48885 L
.1671 .41911 L
.19797 .35255 L
.2407 .29177 L
.2936 .23916 L
.3546 .19679 L
.42131 .16632 L
.49111 .14895 L
.56125 .14535 L
.62899 .15567 L
.69167 .17951 L
.74683 .21592 L
.7923 .26348 L
.8263 .32033 L
Mistroke
.84749 .38422 L
.85505 .45266 L
.84867 .52296 L
.8286 .59236 L
.79564 .65813 L
.75108 .71769 L
.69666 .76872 L
.63453 .80919 L
.56712 .83753 L
.49707 .85263 L
.42713 .85388 L
.36006 .84125 L
.29848 .81522 L
.24481 .77683 L
.20115 .72757 L
.16922 .66937 L
.15027 .60453 L
.14505 .53559 L
.15376 .46525 L
.17606 .39628 L
.21107 .33137 L
.25742 .27309 L
.31329 .22371 L
.37649 .18517 L
.44453 .15899 L
.51476 .14619 L
.5844 .14727 L
.65073 .1622 L
.71114 .19039 L
.76327 .23073 L
.80507 .28164 L
.83489 .34111 L
.85157 .40682 L
.85446 .47619 L
.84343 .54649 L
.81892 .61497 L
.7819 .67894 L
.73381 .73588 L
.67655 .78357 L
.61236 .82012 L
.54376 .84412 L
.47344 .85461 L
.40416 .85118 L
.33865 .83397 L
.27947 .80365 L
.22894 .76141 L
.18905 .70892 L
.16136 .64823 L
.14697 .58171 L
.14643 .512 L
Mistroke
.15976 .44181 L
.18645 .3739 L
.22545 .31095 L
.27522 .25541 L
.33381 .20947 L
.39892 .17494 L
.468 .15316 L
.53834 .14499 L
.60717 .15076 L
.6718 .17023 L
.72968 .20265 L
.77855 .24673 L
.81649 .30076 L
.842 .3626 L
.8541 .42984 L
.85229 .49983 L
.83667 .56982 L
.80783 .63708 L
.7669 .69896 L
.71551 .75302 L
.65565 .79716 L
.58969 .82964 L
.5202 .84918 L
.44993 .85501 L
.38162 .84691 L
.31795 .8252 L
.26143 .79072 L
.21427 .74484 L
.17833 .68934 L
.15501 .62642 L
.14523 .55853 L
.14937 .48835 L
.16728 .41862 L
.19824 .35209 L
.24104 .29136 L
.29401 .23882 L
.35506 .19653 L
.4218 .16615 L
.49161 .14887 L
.56175 .14538 L
.62946 .1558 L
.6921 .17973 L
.74719 .21622 L
.79259 .26386 L
.8265 .32076 L
.84759 .3847 L
.85505 .45316 L
.84857 .52346 L
.82841 .59284 L
.79536 .65858 L
Mistroke
.75072 .71809 L
.69624 .76904 L
.63406 .80944 L
.56662 .83769 L
.49656 .85269 L
.42664 .85384 L
.3596 .84111 L
.29806 .81499 L
.24446 .77651 L
.20088 .72718 L
.16904 .66893 L
.15019 .60405 L
.14507 .53509 L
.15387 .46475 L
.17627 .3958 L
.21136 .33093 L
.25779 .2727 L
.31372 .22339 L
.37696 .18493 L
.44503 .15885 L
.51526 .14614 L
.58489 .14733 L
.65119 .16236 L
.71155 .19064 L
.76361 .23106 L
.80533 .28203 L
.83506 .34156 L
.85164 .40731 L
.85443 .4767 L
.8433 .547 L
.8187 .61545 L
.78159 .67937 L
.73343 .73626 L
.67611 .78387 L
.61188 .82034 L
.54326 .84424 L
.47294 .85463 L
.40368 .8511 L
.3382 .83379 L
.27907 .80339 L
.22861 .76107 L
.18881 .70851 L
.16121 .64777 L
.14692 .58122 L
.14647 .51149 L
.15991 .44131 L
.18669 .37343 L
.22577 .31052 L
.27561 .25505 L
.33425 .20918 L
Mistroke
.39941 .17474 L
Mfstroke
1 .219 0 r
.46723 .33901 m
.50067 .33166 L
.53409 .33091 L
.56617 .3368 L
.59565 .3491 L
.62138 .36732 L
.64235 .39074 L
.65773 .41846 L
.66692 .44937 L
.66956 .48227 L
.66554 .51587 L
.65503 .54884 L
.63843 .5799 L
.6164 .60782 L
.5898 .63151 L
.55968 .65004 L
.52721 .66268 L
.49368 .66894 L
.4604 .66856 L
.42867 .66157 L
.39974 .64824 L
.37474 .62909 L
.35466 .60488 L
.34028 .57654 L
.33218 .54521 L
.33065 .5121 L
.33578 .47852 L
.34735 .44577 L
.36491 .41516 L
.38777 .38788 L
.41504 .365 L
.44564 .34741 L
.47838 .33581 L
.51196 .33066 L
.54507 .33215 L
.57642 .34024 L
.60476 .35459 L
.629 .37464 L
.64817 .39962 L
.66153 .42854 L
.66854 .46026 L
.66895 .49354 L
.66272 .52707 L
.65011 .55955 L
.6316 .58968 L
.60793 .6163 L
.58003 .63835 L
.54898 .65497 L
.51601 .66551 L
.48241 .66955 L
Mistroke
.44951 .66694 L
.41858 .65778 L
.39085 .64243 L
.36741 .62148 L
.34916 .59577 L
.33684 .5663 L
.33092 .53423 L
.33164 .50081 L
.33896 .46736 L
.35261 .4352 L
.37203 .40557 L
.39648 .37966 L
.425 .35846 L
.45645 .34282 L
.48962 .33335 L
.52319 .33042 L
.55586 .33414 L
.58633 .34438 L
.61341 .36072 L
.63604 .38253 L
.65333 .40894 L
.66461 .43893 L
.66942 .47132 L
.66759 .50484 L
.65918 .53816 L
.64452 .56999 L
.62419 .59906 L
.59898 .62426 L
.56989 .64457 L
.53806 .65921 L
.50474 .6676 L
.47122 .66942 L
.43884 .66459 L
.40886 .65329 L
.38245 .63598 L
.36066 .61334 L
.34434 .58624 L
.33412 .55576 L
.33042 .5231 L
.33337 .48952 L
.34286 .45636 L
.35852 .42491 L
.37973 .39641 L
.40566 .37197 L
.43529 .35256 L
.46746 .33893 L
.50091 .33163 L
.53433 .33093 L
.56639 .33687 L
.59585 .34921 L
Mistroke
.62155 .36747 L
.64248 .39093 L
.65782 .41867 L
.66696 .4496 L
.66955 .48251 L
.66549 .51611 L
.65493 .54907 L
.63829 .58011 L
.61622 .60801 L
.5896 .63166 L
.55945 .65015 L
.52698 .66275 L
.49344 .66896 L
.46016 .66853 L
.42845 .6615 L
.39954 .64812 L
.37458 .62893 L
.35453 .60469 L
.3402 .57633 L
.33214 .54498 L
.33067 .51186 L
.33584 .47828 L
.34745 .44555 L
.36506 .41495 L
.38795 .3877 L
.41525 .36485 L
.44587 .34731 L
.47861 .33575 L
.5122 .33065 L
.54531 .33219 L
.57663 .34032 L
.60495 .35471 L
.62916 .37481 L
.64829 .39982 L
.6616 .42876 L
.66857 .46049 L
.66893 .49378 L
.66265 .52731 L
.64999 .55977 L
.63145 .58989 L
.60775 .61647 L
.57981 .63849 L
.54875 .65507 L
.51577 .66556 L
.48217 .66956 L
.44928 .6669 L
.41837 .65769 L
.39067 .6423 L
.36726 .62131 L
.34905 .59557 L
Mistroke
.33678 .56608 L
.3309 .53399 L
.33167 .50057 L
.33904 .46713 L
.35273 .43498 L
.37219 .40537 L
.39668 .37949 L
.42521 .35833 L
.45669 .34273 L
.48986 .33331 L
.52343 .33042 L
.55608 .33419 L
.58653 .34447 L
.61359 .36086 L
.63619 .3827 L
.65344 .40915 L
.66467 .43916 L
.66943 .47156 L
.66755 .50508 L
.65909 .53839 L
.64439 .5702 L
.62402 .59926 L
.59879 .62442 L
.56967 .6447 L
.53783 .65929 L
.5045 .66764 L
.47099 .66941 L
.43862 .66453 L
.40866 .65319 L
.38228 .63584 L
.36052 .61316 L
.34424 .58603 L
.33407 .55553 L
.33042 .52286 L
.33341 .48928 L
.34295 .45613 L
.35865 .42469 L
.3799 .39622 L
.40586 .37181 L
.43551 .35244 L
.4677 .33886 L
.50115 .3316 L
.53456 .33095 L
.56661 .33693 L
.59605 .34932 L
.62172 .36762 L
.64261 .39111 L
.65791 .41888 L
.667 .44983 L
.66955 .48275 L
Mistroke
.66543 .51635 L
Mfstroke
.952 0 1 r
.66961 .2855 m
.70469 .31808 L
.73174 .3578 L
.74969 .4031 L
.75784 .45221 L
.75587 .50319 L
.74386 .55404 L
.72228 .60278 L
.69198 .64748 L
.65414 .68639 L
.61025 .71799 L
.56204 .74103 L
.51139 .75462 L
.4603 .75821 L
.41076 .75166 L
.36472 .73524 L
.324 .70959 L
.29018 .67571 L
.26459 .63494 L
.24825 .58887 L
.24178 .53931 L
.24545 .48821 L
.25911 .43758 L
.28222 .38939 L
.31388 .34554 L
.35285 .30776 L
.39759 .27752 L
.44634 .25601 L
.49721 .24407 L
.54818 .24219 L
.59727 .25042 L
.64253 .26844 L
.6822 .29555 L
.71472 .33069 L
.73882 .37247 L
.75354 .41926 L
.75831 .46921 L
.75294 .52037 L
.73765 .57074 L
.71303 .61832 L
.68005 .66127 L
.64 .69788 L
.59446 .72673 L
.54521 .74668 L
.49419 .75695 L
.44339 .75714 L
.39482 .74723 L
.35037 .72762 L
.3118 .69908 L
.28061 .66272 L
Mistroke
.25804 .61998 L
.24495 .57253 L
.24188 .52223 L
.24894 .47106 L
.26585 .42103 L
.29195 .37409 L
.32622 .3321 L
.36731 .2967 L
.4136 .26927 L
.46328 .2509 L
.51441 .24231 L
.56497 .24383 L
.61298 .2554 L
.65656 .27657 L
.69399 .30652 L
.72381 .34405 L
.74484 .38771 L
.75627 .43577 L
.75764 .48635 L
.74889 .53747 L
.73038 .58712 L
.70283 .63335 L
.66732 .67434 L
.62524 .7085 L
.57825 .73447 L
.52818 .75124 L
.47701 .75815 L
.42674 .75492 L
.37935 .7417 L
.33669 .71898 L
.30044 .68768 L
.27202 .649 L
.25255 .60448 L
.24279 .55586 L
.24313 .50505 L
.25355 .45404 L
.27363 .40483 L
.30261 .35936 L
.33933 .31941 L
.38235 .28654 L
.43 .26205 L
.48039 .2469 L
.53155 .24169 L
.58147 .24661 L
.62819 .26147 L
.66989 .2857 L
.70491 .31834 L
.7319 .35811 L
.74978 .40344 L
.75786 .45257 L
Mistroke
.75582 .50355 L
.74374 .5544 L
.7221 .60311 L
.69173 .64778 L
.65385 .68665 L
.60992 .71819 L
.56168 .74116 L
.51102 .75468 L
.45993 .7582 L
.41041 .75158 L
.36441 .73509 L
.32373 .70938 L
.28996 .67545 L
.26444 .63463 L
.24817 .58853 L
.24177 .53895 L
.24551 .48785 L
.25924 .43722 L
.28242 .38906 L
.31414 .34525 L
.35315 .30751 L
.39792 .27733 L
.4467 .25589 L
.49758 .24403 L
.54854 .24221 L
.59761 .25051 L
.64284 .2686 L
.68246 .29578 L
.71493 .33097 L
.73896 .37279 L
.75361 .4196 L
.75831 .46958 L
.75287 .52074 L
.73751 .57109 L
.71282 .61865 L
.67978 .66156 L
.63969 .69812 L
.59412 .72691 L
.54485 .74679 L
.49382 .75699 L
.44303 .7571 L
.39448 .74712 L
.35007 .72744 L
.31155 .69884 L
.28042 .66243 L
.25791 .61965 L
.2449 .57218 L
.2419 .52187 L
.24903 .4707 L
.26601 .42068 L
Mistroke
.29217 .37377 L
.32649 .33182 L
.36762 .29647 L
.41395 .26911 L
.46365 .25081 L
.51478 .24228 L
.56533 .24388 L
.61331 .25552 L
.65685 .27676 L
.69423 .30676 L
.72399 .34434 L
.74496 .38804 L
.75631 .43612 L
.75761 .48672 L
.7488 .53783 L
.73022 .58746 L
.7026 .63366 L
.66704 .67461 L
.62492 .70871 L
.5779 .73462 L
.52781 .75132 L
.47664 .75816 L
.42639 .75486 L
.37902 .74157 L
.3364 .71879 L
.30021 .68742 L
.27185 .6487 L
.25245 .60415 L
.24276 .5555 L
.24317 .50468 L
.25366 .45368 L
.27381 .40449 L
.30285 .35905 L
.33962 .31914 L
.38268 .28633 L
.43035 .26191 L
.48075 .24683 L
.53191 .24169 L
.58182 .24668 L
.62851 .26161 L
.67016 .28591 L
.70514 .3186 L
.73206 .35841 L
.74987 .40378 L
.75788 .45293 L
.75577 .50392 L
.74362 .55476 L
.72191 .60345 L
.69149 .64808 L
.65355 .6869 L
Mistroke
.60959 .71838 L
Mfstroke
0 1 .378 r
.80492 .19723 m
.85152 .25623 L
.88433 .32481 L
.90205 .40026 L
.90399 .47962 L
.89008 .55978 L
.86086 .6376 L
.81748 .71002 L
.76163 .77419 L
.69552 .82761 L
.62174 .86816 L
.54317 .89427 L
.46292 .9049 L
.38412 .89965 L
.30986 .87871 L
.24307 .8429 L
.18636 .79364 L
.14196 .73285 L
.11162 .66293 L
.09651 .58661 L
.09724 .50689 L
.11378 .4269 L
.14547 .34978 L
.19108 .27856 L
.24881 .21603 L
.3164 .16464 L
.3912 .12641 L
.47026 .10285 L
.5505 .09487 L
.62875 .10279 L
.70195 .1263 L
.76722 .16447 L
.822 .21582 L
.86415 .27832 L
.89201 .34951 L
.90448 .42662 L
.90108 .5066 L
.88193 .58633 L
.8478 .66266 L
.80002 .73262 L
.74046 .79344 L
.67147 .84275 L
.59574 .8786 L
.51626 .8996 L
.43614 .90491 L
.35853 .89434 L
.28647 .86828 L
.22279 .82778 L
.16999 .77441 L
.13014 .71027 L
Mistroke
.1048 .63788 L
.09498 .56007 L
.10105 .47991 L
.12278 .40054 L
.15931 .32507 L
.20921 .25647 L
.27053 .19742 L
.34085 .15025 L
.41742 .11681 L
.49723 .0984 L
.57714 .09576 L
.65403 .10898 L
.72488 .13754 L
.7869 .18033 L
.83766 .23567 L
.87516 .30138 L
.89795 .37489 L
.90511 .4533 L
.89638 .53355 L
.87209 .61248 L
.8332 .687 L
.78123 .75418 L
.71822 .81138 L
.64665 .85636 L
.56933 .88736 L
.48928 .90316 L
.40965 .90313 L
.33357 .88728 L
.26402 .85623 L
.20374 .8112 L
.15508 .75396 L
.11995 .68675 L
.09974 .61221 L
.09524 .53327 L
.10663 .45302 L
.13345 .37462 L
.17466 .30113 L
.22864 .23545 L
.29326 .18016 L
.36601 .13742 L
.444 .1089 L
.5242 .09574 L
.60345 .09844 L
.67864 .1169 L
.74681 .15039 L
.8053 .19761 L
.85181 .2567 L
.88451 .32533 L
.90212 .40082 L
.90395 .4802 L
Mistroke
.88993 .56035 L
.8606 .63814 L
.81712 .71051 L
.76119 .77462 L
.69502 .82795 L
.62119 .8684 L
.5426 .8944 L
.46234 .90492 L
.38356 .89955 L
.30935 .8785 L
.24263 .84259 L
.186 .79324 L
.14169 .73238 L
.11145 .6624 L
.09646 .58605 L
.0973 .50632 L
.11395 .42634 L
.14575 .34925 L
.19145 .27808 L
.24927 .21562 L
.31692 .16431 L
.39175 .12619 L
.47084 .10273 L
.55107 .09487 L
.62929 .1029 L
.70245 .12652 L
.76765 .1648 L
.82235 .21623 L
.8644 .2788 L
.89215 .35005 L
.90451 .42718 L
.901 .50718 L
.88174 .58689 L
.84751 .66319 L
.79963 .73309 L
.74 .79384 L
.67095 .84305 L
.59518 .87881 L
.51569 .89969 L
.43558 .90489 L
.35799 .8942 L
.28598 .86804 L
.22237 .82744 L
.16965 .77398 L
.1299 .70977 L
.10468 .63733 L
.09497 .5595 L
.10115 .47934 L
.12299 .39998 L
.15962 .32455 L
Mistroke
.20962 .25601 L
.271 .19704 L
.34138 .14996 L
.41798 .11662 L
.4978 .09832 L
.57771 .09579 L
.65457 .10913 L
.72536 .1378 L
.7873 .18069 L
.83797 .23611 L
.87538 .30188 L
.89806 .37544 L
.90511 .45388 L
.89626 .53413 L
.87186 .61304 L
.83287 .68751 L
.78082 .75463 L
.71774 .81175 L
.64612 .85664 L
.56876 .88753 L
.4887 .90321 L
.40909 .90307 L
.33305 .88711 L
.26356 .85595 L
.20334 .81083 L
.15477 .75351 L
.11975 .68624 L
.09965 .61166 L
.09527 .53269 L
.10677 .45245 L
.1337 .37407 L
.175 .30063 L
.22907 .23502 L
.29376 .17981 L
.36655 .13716 L
.44458 .10875 L
.52478 .0957 L
.60401 .09851 L
.67915 .11709 L
.74727 .15069 L
.80568 .19799 L
.8521 .25716 L
.88469 .32585 L
.90219 .40137 L
.90391 .48077 L
.88977 .56092 L
.86034 .63868 L
.81676 .711 L
.76075 .77504 L
.69451 .82828 L
Mistroke
.62064 .86864 L
Mfstroke
1 0 .722 r
.56268 .7638 m
.50748 .77763 L
.45198 .78056 L
.39837 .77248 L
.34875 .75371 L
.30507 .72498 L
.26903 .68742 L
.24206 .64251 L
.22521 .592 L
.21915 .53789 L
.22411 .48228 L
.23989 .42737 L
.26589 .37531 L
.30107 .32815 L
.34406 .28773 L
.39317 .25564 L
.44647 .23314 L
.50188 .22111 L
.55721 .22003 L
.61029 .22994 L
.65905 .25044 L
.70156 .28074 L
.73616 .31965 L
.7615 .36563 L
.77657 .41689 L
.78079 .4714 L
.77399 .52704 L
.75643 .58162 L
.72881 .633 L
.69221 .67916 L
.64807 .71828 L
.59812 .74884 L
.54431 .76963 L
.48877 .77984 L
.43367 .77907 L
.38117 .76735 L
.33333 .74513 L
.29204 .71329 L
.25891 .67308 L
.23523 .62608 L
.22195 .57413 L
.21959 .51928 L
.22822 .46366 L
.24753 .40947 L
.27674 .35884 L
.31471 .31374 L
.35996 .27595 L
.4107 .24696 L
.46495 .2279 L
.52057 .21952 L
Mistroke
.57538 .22214 L
.62724 .23567 L
.6741 .25957 L
.71413 .29291 L
.74576 .33438 L
.76774 .38234 L
.77921 .43493 L
.77973 .49007 L
.76927 .54559 L
.74824 .59933 L
.71746 .64917 L
.67816 .69316 L
.63186 .72956 L
.58038 .75696 L
.52575 .77427 L
.47011 .78082 L
.41565 .77634 L
.36449 .76102 L
.31865 .73546 L
.27993 .70065 L
.24985 .65798 L
.22958 .6091 L
.21993 .55594 L
.22127 .50058 L
.23354 .4452 L
.25628 .39197 L
.28858 .34299 L
.32917 .30016 L
.37648 .26518 L
.42862 .23941 L
.48357 .22387 L
.53917 .21917 L
.59323 .22548 L
.64363 .24258 L
.68839 .26977 L
.72576 .306 L
.75427 .34985 L
.77279 .39958 L
.78062 .45326 L
.77743 .50877 L
.76335 .56394 L
.73894 .6166 L
.70515 .66468 L
.66331 .7063 L
.61506 .73983 L
.56229 .76394 L
.50708 .77769 L
.45159 .78054 L
.398 .77239 L
.34842 .75354 L
Mistroke
.30478 .72474 L
.2688 .68713 L
.2419 .64217 L
.22513 .59163 L
.21915 .53749 L
.22418 .48188 L
.24005 .42699 L
.26611 .37495 L
.30135 .32783 L
.34439 .28746 L
.39354 .25544 L
.44687 .23301 L
.50228 .22106 L
.5576 .22006 L
.61066 .23005 L
.65937 .25062 L
.70184 .28099 L
.73638 .31995 L
.76164 .36598 L
.77664 .41727 L
.78078 .4718 L
.7739 .52744 L
.75627 .58201 L
.72858 .63335 L
.69192 .67946 L
.64773 .71853 L
.59774 .74902 L
.54392 .76974 L
.48837 .77988 L
.43328 .77902 L
.38081 .76722 L
.33301 .74493 L
.29177 .71303 L
.2587 .67277 L
.2351 .62573 L
.2219 .57375 L
.21961 .51888 L
.22832 .46326 L
.2477 .40909 L
.27698 .35849 L
.31501 .31344 L
.3603 .27571 L
.41108 .24679 L
.46534 .2278 L
.52097 .2195 L
.57577 .2222 L
.6276 .2358 L
.67442 .25978 L
.71439 .29318 L
.74595 .3347 L
Mistroke
.76786 .38271 L
.77926 .43532 L
.77969 .49047 L
.76915 .54599 L
.74805 .59971 L
.71721 .64951 L
.67785 .69345 L
.6315 .72979 L
.58 .75712 L
.52536 .77435 L
.46972 .78082 L
.41527 .77627 L
.36414 .76087 L
.31835 .73524 L
.27969 .70037 L
.24967 .65765 L
.22947 .60873 L
.2199 .55554 L
.22132 .50018 L
.23367 .44481 L
.25648 .39161 L
.28884 .34265 L
.32949 .29988 L
.37683 .26496 L
.42901 .23926 L
.48397 .2238 L
.53956 .21917 L
.5936 .22557 L
.64397 .24274 L
.68868 .27 L
.72599 .30629 L
.75443 .35018 L
.77289 .39996 L
.78063 .45366 L
.77737 .50917 L
.76321 .56433 L
.73873 .61696 L
.70487 .66501 L
.66298 .70657 L
.61469 .74003 L
.5619 .76407 L
.50668 .77775 L
.4512 .78052 L
.39763 .77229 L
.34808 .75337 L
.30449 .7245 L
.26858 .68683 L
.24175 .64182 L
.22505 .59125 L
.21914 .53709 L
Mistroke
.22426 .48148 L
Mfstroke
1 .889 0 r
.62164 .79016 m
.55858 .81584 L
.49322 .82912 L
.42813 .82949 L
.36586 .81693 L
.30885 .79193 L
.25935 .75547 L
.21929 .70899 L
.19024 .6543 L
.17336 .59356 L
.16929 .52915 L
.1782 .46359 L
.19974 .39946 L
.23307 .33928 L
.27687 .2854 L
.32943 .23995 L
.38868 .2047 L
.4523 .18105 L
.51779 .16991 L
.58259 .17172 L
.64414 .18642 L
.70004 .21342 L
.74809 .25168 L
.7864 .29967 L
.81347 .35553 L
.82823 .41706 L
.83012 .48185 L
.81905 .54734 L
.79546 .61098 L
.76027 .67027 L
.71487 .72287 L
.66104 .76672 L
.60088 .80011 L
.53677 .82172 L
.47121 .8307 L
.40678 .8267 L
.34602 .80988 L
.29129 .7809 L
.24476 .7409 L
.20824 .69144 L
.18317 .63447 L
.17054 .57222 L
.17084 .50714 L
.18406 .44177 L
.20967 .3787 L
.24668 .32038 L
.29363 .26911 L
.34868 .2269 L
.40967 .19541 L
.47421 .17588 L
Mistroke
.53975 .16906 L
.60374 .17524 L
.66365 .19416 L
.71715 .22508 L
.76212 .26679 L
.7968 .31765 L
.81983 .37567 L
.83032 .43857 L
.82784 .50388 L
.81249 .56904 L
.78488 .63149 L
.74609 .68878 L
.69764 .73866 L
.64143 .77917 L
.57968 .80873 L
.51479 .82617 L
.44933 .83081 L
.38585 .82246 L
.32686 .80146 L
.27466 .76863 L
.2313 .72526 L
.19849 .67305 L
.17751 .61404 L
.16919 .55056 L
.17385 .4851 L
.19131 .42022 L
.22089 .35847 L
.26142 .30227 L
.31131 .25384 L
.36861 .21507 L
.43107 .18747 L
.49623 .17215 L
.56154 .16969 L
.62443 .18019 L
.68244 .20325 L
.73329 .23795 L
.77498 .28294 L
.80589 .33644 L
.82478 .39637 L
.83094 .46036 L
.8241 .5259 L
.80454 .59043 L
.77303 .65142 L
.73081 .70645 L
.67953 .75339 L
.6212 .79038 L
.55812 .81598 L
.49275 .82917 L
.42767 .82945 L
.36543 .81679 L
Mistroke
.30847 .79171 L
.25902 .75517 L
.21904 .70862 L
.19008 .65389 L
.17328 .59311 L
.16931 .52868 L
.17831 .46312 L
.19994 .39901 L
.23334 .33887 L
.27722 .28505 L
.32983 .23966 L
.38912 .20449 L
.45277 .18092 L
.51826 .16987 L
.58304 .17178 L
.64457 .18657 L
.70041 .21366 L
.7484 .25199 L
.78663 .30005 L
.81362 .35596 L
.82829 .41752 L
.83009 .48232 L
.81892 .54781 L
.79525 .61143 L
.75998 .67067 L
.71451 .72321 L
.66062 .767 L
.60043 .80031 L
.5363 .82183 L
.47074 .83072 L
.40633 .82663 L
.3456 .80972 L
.29093 .78066 L
.24446 .74058 L
.20802 .69106 L
.18304 .63404 L
.1705 .57176 L
.17089 .50667 L
.1842 .44131 L
.2099 .37826 L
.24698 .31998 L
.294 .26877 L
.3491 .22664 L
.41012 .19523 L
.47468 .17578 L
.54022 .16906 L
.60419 .17533 L
.66406 .19434 L
.7175 .22534 L
.7624 .26712 L
Mistroke
.79701 .31805 L
.81996 .37611 L
.83035 .43904 L
.82777 .50436 L
.81233 .5695 L
.78464 .63192 L
.74577 .68917 L
.69726 .73898 L
.64101 .77942 L
.57922 .8089 L
.51432 .82625 L
.44886 .83079 L
.38541 .82236 L
.32646 .80127 L
.27431 .76836 L
.23103 .72492 L
.1983 .67265 L
.17741 .6136 L
.16918 .5501 L
.17393 .48463 L
.19148 .41976 L
.22114 .35804 L
.26175 .3019 L
.3117 .25352 L
.36904 .21483 L
.43153 .18732 L
.4967 .17208 L
.562 .16972 L
.62486 .18032 L
.68283 .20346 L
.73362 .23824 L
.77525 .28329 L
.80607 .33685 L
.82487 .39681 L
.83093 .46082 L
.824 .52637 L
.80436 .59089 L
.77277 .65183 L
.73047 .70682 L
.67913 .75369 L
.62076 .79061 L
.55765 .81612 L
.49228 .82922 L
.42721 .8294 L
.365 .81666 L
.30808 .79148 L
.2587 .75487 L
.21879 .70826 L
.18991 .65347 L
.17321 .59266 L
Mistroke
.16932 .52821 L
Mfstroke
1 0 .859 r
.5797 .35691 m
.60458 .37199 L
.62537 .39211 L
.64123 .41645 L
.65155 .44408 L
.65593 .4739 L
.65418 .50474 L
.64638 .5354 L
.63284 .56467 L
.61408 .5914 L
.59085 .61455 L
.56405 .6332 L
.53474 .64662 L
.50406 .65428 L
.47323 .65589 L
.44344 .65139 L
.41588 .64094 L
.39162 .62496 L
.37161 .60408 L
.35664 .57911 L
.34729 .55104 L
.34394 .52096 L
.34671 .49006 L
.3555 .45955 L
.36996 .43063 L
.38953 .40443 L
.41343 .38199 L
.44072 .36417 L
.47035 .35168 L
.50113 .34502 L
.53188 .34444 L
.56137 .34996 L
.58845 .36137 L
.61206 .37822 L
.63128 .39985 L
.64534 .42541 L
.6537 .4539 L
.65602 .4842 L
.65223 .51512 L
.64245 .54544 L
.62709 .57398 L
.60674 .59962 L
.5822 .62135 L
.55444 .63831 L
.52453 .64985 L
.49367 .65551 L
.46305 .65506 L
.43389 .64853 L
.40732 .63617 L
.38438 .61846 L
Mistroke
.36598 .59611 L
.35285 .56998 L
.34549 .54111 L
.34419 .51062 L
.34901 .47972 L
.35975 .44961 L
.376 .42148 L
.39711 .39643 L
.42226 .37545 L
.45047 .35935 L
.48061 .34878 L
.51152 .34414 L
.54198 .34562 L
.57078 .35315 L
.59682 .36645 L
.61905 .38499 L
.6366 .40804 L
.6488 .43471 L
.65516 .46393 L
.65543 .49457 L
.6496 .52543 L
.63789 .55528 L
.62078 .58297 L
.59892 .6074 L
.57319 .62761 L
.54458 .64282 L
.51422 .65242 L
.4833 .65604 L
.45304 .65354 L
.42462 .64501 L
.39916 .63079 L
.37766 .61143 L
.36096 .58771 L
.34971 .56054 L
.34437 .53099 L
.34513 .50023 L
.35197 .46946 L
.36462 .43989 L
.38258 .41268 L
.40515 .38889 L
.43144 .36947 L
.46043 .35516 L
.49096 .34655 L
.52186 .34395 L
.55189 .34748 L
.57989 .35699 L
.60475 .37212 L
.6255 .39227 L
.64133 .41664 L
.65161 .44429 L
Mistroke
.65593 .47412 L
.65414 .50497 L
.6463 .53562 L
.63272 .56487 L
.61393 .59158 L
.59067 .6147 L
.56385 .63331 L
.53452 .64669 L
.50384 .65432 L
.47301 .65588 L
.44324 .65133 L
.41569 .64085 L
.39146 .62483 L
.37148 .60391 L
.35655 .57892 L
.34724 .55083 L
.34394 .52074 L
.34675 .48984 L
.35559 .45934 L
.37009 .43043 L
.38968 .40426 L
.41361 .38184 L
.44093 .36406 L
.47056 .35161 L
.50136 .34499 L
.53209 .34445 L
.56157 .35002 L
.58863 .36147 L
.61222 .37836 L
.6314 .40002 L
.64542 .42561 L
.65374 .45411 L
.65602 .48442 L
.65218 .51534 L
.64236 .54566 L
.62696 .57418 L
.60658 .59979 L
.58201 .62149 L
.55423 .63842 L
.52432 .64991 L
.49345 .65553 L
.46284 .65503 L
.43369 .64846 L
.40714 .63606 L
.38423 .61832 L
.36587 .59593 L
.35277 .56978 L
.34545 .54089 L
.3442 .5104 L
.34906 .4795 L
Mistroke
.35985 .4494 L
.37613 .42129 L
.39728 .39627 L
.42245 .37532 L
.45068 .35926 L
.48083 .34872 L
.51174 .34413 L
.54219 .34565 L
.57098 .35323 L
.59699 .36656 L
.61919 .38514 L
.63671 .40822 L
.64887 .43491 L
.65518 .46415 L
.65541 .49479 L
.64953 .52564 L
.63779 .55549 L
.62064 .58316 L
.59875 .60756 L
.57299 .62774 L
.54437 .64291 L
.514 .65247 L
.48308 .65605 L
.45283 .6535 L
.42443 .64493 L
.39899 .63067 L
.37752 .61128 L
.36086 .58752 L
.34965 .56033 L
.34435 .53077 L
.34516 .50001 L
.35204 .46924 L
.36473 .43968 L
.38273 .41249 L
.40533 .38873 L
.43164 .36934 L
.46064 .35508 L
.49119 .34651 L
.52208 .34395 L
.5521 .34753 L
.58008 .35708 L
.60491 .37225 L
.62563 .39243 L
.64142 .41683 L
.65166 .44449 L
.65594 .47434 L
.65411 .50519 L
.64623 .53584 L
.63261 .56508 L
.61378 .59176 L
Mistroke
.59049 .61485 L
Mfstroke
1 0 .684 r
.76374 .79597 m
.69321 .84992 L
.61509 .89013 L
.53246 .91503 L
.44856 .92364 L
.36667 .91563 L
.29002 .89131 L
.2216 .85162 L
.16412 .79814 L
.11981 .73296 L
.09043 .65863 L
.07712 .57808 L
.0804 .49447 L
.10016 .41107 L
.1356 .33116 L
.18535 .25788 L
.24745 .1941 L
.31945 .14232 L
.39855 .10459 L
.48162 .08237 L
.56542 .07654 L
.64665 .08733 L
.72212 .11432 L
.78888 .15644 L
.8443 .21205 L
.8862 .27895 L
.91295 .35454 L
.9235 .43583 L
.91742 .51964 L
.89496 .60268 L
.857 .68168 L
.80503 .75356 L
.74109 .81549 L
.66768 .86504 L
.5877 .90026 L
.50427 .91977 L
.42068 .92281 L
.3402 .90925 L
.26599 .87963 L
.20096 .83511 L
.14767 .77745 L
.10821 .70889 L
.08413 .63213 L
.07636 .55019 L
.08522 .46628 L
.11036 .38369 L
.1508 .30567 L
.20493 .23527 L
.27065 .17527 L
.34537 .128 L
Mistroke
.42615 .09534 L
.50984 .07856 L
.59314 .07832 L
.67278 .09462 L
.74564 .12684 L
.80887 .1737 L
.85997 .23337 L
.89694 .3035 L
.91833 .38134 L
.92331 .46384 L
.91167 .54776 L
.88388 .62981 L
.84102 .70676 L
.78478 .77559 L
.71736 .83361 L
.64141 .87854 L
.55991 .90861 L
.47606 .92264 L
.39315 .92009 L
.31443 .90105 L
.243 .86627 L
.18165 .81712 L
.13279 .75552 L
.09835 .68389 L
.07967 .60505 L
.07749 .52208 L
.09189 .43824 L
.1223 .35683 L
.16754 .28104 L
.22582 .21384 L
.29487 .15788 L
.37197 .11533 L
.45409 .08789 L
.53801 .07662 L
.62044 .08197 L
.69815 .10372 L
.76808 .14102 L
.82748 .19241 L
.87404 .25588 L
.90591 .32892 L
.92186 .40868 L
.92125 .49202 L
.9041 .57568 L
.8711 .65637 L
.82353 .73091 L
.76327 .7964 L
.69267 .85026 L
.61451 .89036 L
.53186 .91515 L
.44796 .92365 L
Mistroke
.3661 .91551 L
.28949 .89108 L
.22115 .85129 L
.16375 .79771 L
.11955 .73246 L
.09027 .65808 L
.07708 .57749 L
.08049 .49387 L
.10036 .41048 L
.13591 .33061 L
.18575 .25738 L
.24793 .19368 L
.32 .142 L
.39913 .10437 L
.48223 .08227 L
.56601 .07656 L
.64721 .08747 L
.72263 .11457 L
.78932 .15679 L
.84465 .21249 L
.88645 .27947 L
.91309 .3551 L
.92351 .43642 L
.91731 .52024 L
.89474 .60326 L
.85667 .68223 L
.80461 .75405 L
.74059 .81589 L
.66713 .86534 L
.58711 .90045 L
.50367 .91985 L
.42009 .92277 L
.33964 .90909 L
.26549 .87936 L
.20054 .83475 L
.14734 .77699 L
.10798 .70836 L
.08401 .63156 L
.07637 .54959 L
.08535 .46568 L
.1106 .38311 L
.15114 .30514 L
.20537 .2348 L
.27116 .17488 L
.34593 .12772 L
.42675 .09516 L
.51044 .0785 L
.59373 .07838 L
.67333 .0948 L
.74613 .12713 L
Mistroke
.80928 .17409 L
.86028 .23384 L
.89715 .30404 L
.91843 .38192 L
.92329 .46445 L
.91153 .54836 L
.88363 .63038 L
.84066 .70728 L
.78433 .77605 L
.71684 .83398 L
.64084 .87881 L
.55932 .90877 L
.47546 .92269 L
.39257 .92001 L
.31389 .90086 L
.24252 .86597 L
.18125 .81672 L
.13249 .75504 L
.09816 .68335 L
.0796 .60446 L
.07753 .52148 L
.09205 .43765 L
.12257 .35627 L
.16791 .28053 L
.22628 .2134 L
.2954 .15752 L
.37254 .11508 L
.45469 .08775 L
.53861 .0766 L
.62102 .08206 L
.69868 .10393 L
.76854 .14134 L
.82786 .19283 L
.87432 .25637 L
.90608 .32947 L
.92191 .40927 L
.92118 .49263 L
.90392 .57627 L
.87081 .65693 L
.82314 .73142 L
.7628 .79683 L
.69214 .85059 L
.61393 .8906 L
.53126 .91527 L
.44736 .92365 L
.36553 .9154 L
.28897 .89084 L
.2207 .85095 L
.16338 .79729 L
.11928 .73195 L
Mistroke
.09012 .65752 L
Mfstroke
1 .925 0 r
.34132 .64496 m
.31958 .61419 L
.30491 .57893 L
.2979 .54058 L
.29882 .50064 L
.30764 .46067 L
.32401 .42225 L
.34728 .38687 L
.37655 .35594 L
.41066 .33066 L
.44828 .31202 L
.48792 .30077 L
.52805 .29733 L
.56707 .30185 L
.60346 .31414 L
.63579 .33373 L
.66279 .35984 L
.6834 .39145 L
.69681 .42733 L
.7025 .46605 L
.70024 .50611 L
.69013 .54593 L
.67255 .58394 L
.6482 .61867 L
.61803 .64873 L
.58323 .67296 L
.54517 .6904 L
.50533 .70036 L
.46528 .70247 L
.4266 .69662 L
.39079 .68307 L
.35928 .66232 L
.33328 .63521 L
.31383 .60279 L
.30168 .56633 L
.29732 .52727 L
.30091 .48715 L
.31232 .44752 L
.33109 .40996 L
.35649 .37593 L
.38752 .34677 L
.42297 .32362 L
.46144 .30739 L
.50142 .29873 L
.54135 .29796 L
.57965 .30512 L
.61483 .31993 L
.6455 .34181 L
.67047 .3699 L
.68874 .40309 L
Mistroke
.6996 .44008 L
.70263 .47943 L
.69771 .51958 L
.68503 .55897 L
.66509 .59604 L
.63867 .62934 L
.6068 .65757 L
.57075 .67961 L
.53191 .6946 L
.49183 .70196 L
.45207 .70139 L
.41418 .69291 L
.37967 .67687 L
.34988 .65388 L
.32598 .62486 L
.30891 .59093 L
.29934 .55344 L
.29764 .51384 L
.30389 .47371 L
.31783 .43461 L
.33892 .39807 L
.36634 .36553 L
.39899 .33828 L
.43562 .31736 L
.47477 .30362 L
.51491 .29758 L
.55447 .29949 L
.59188 .30927 L
.6257 .32653 L
.65457 .3506 L
.67739 .38053 L
.69324 .41515 L
.7015 .45311 L
.70186 .4929 L
.6943 .53297 L
.67911 .57175 L
.65689 .60771 L
.62852 .63944 L
.5951 .6657 L
.55795 .68546 L
.51852 .69794 L
.47837 .70265 L
.43906 .69941 L
.40215 .68834 L
.36908 .66988 L
.34115 .64476 L
.31945 .61395 L
.30483 .57867 L
.29788 .5403 L
.29886 .50035 L
Mistroke
.30773 .46039 L
.32415 .42198 L
.34747 .38663 L
.37677 .35574 L
.41092 .3305 L
.44856 .31192 L
.48821 .30071 L
.52833 .29733 L
.56734 .30191 L
.60371 .31425 L
.636 .33389 L
.66296 .36005 L
.68352 .3917 L
.69688 .4276 L
.70251 .46634 L
.7002 .5064 L
.69003 .54621 L
.6724 .58421 L
.648 .6189 L
.6178 .64893 L
.58297 .67311 L
.54489 .69049 L
.50504 .70041 L
.465 .70245 L
.42633 .69655 L
.39055 .68294 L
.35907 .66215 L
.33312 .63499 L
.31372 .60254 L
.30162 .56606 L
.29732 .52699 L
.30097 .48686 L
.31243 .44724 L
.33125 .4097 L
.35669 .3757 L
.38776 .34658 L
.42323 .32348 L
.46172 .30731 L
.50171 .29869 L
.54163 .29798 L
.57992 .3052 L
.61507 .32007 L
.6457 .34199 L
.67062 .37012 L
.68884 .40334 L
.69965 .44036 L
.70262 .47972 L
.69765 .51987 L
.68491 .55924 L
.66492 .59629 L
Mistroke
.63845 .62956 L
.60656 .65775 L
.57048 .67974 L
.53163 .69468 L
.49154 .70198 L
.45179 .70135 L
.41392 .69282 L
.37944 .67673 L
.34968 .65369 L
.32583 .62463 L
.30881 .59067 L
.2993 .55316 L
.29766 .51356 L
.30396 .47342 L
.31796 .43433 L
.3391 .39782 L
.36655 .36532 L
.39924 .3381 L
.43589 .31724 L
.47506 .30355 L
.5152 .29757 L
.55474 .29953 L
.59214 .30936 L
.62592 .32668 L
.65476 .35079 L
.67753 .38076 L
.69332 .41542 L
.70154 .45339 L
.70184 .49319 L
.69422 .53325 L
.67898 .57202 L
.65671 .60795 L
.62829 .63965 L
.59484 .66587 L
.55767 .68558 L
.51823 .698 L
.47808 .70266 L
.43879 .69936 L
.4019 .68824 L
.36886 .66973 L
.34097 .64456 L
.31932 .61371 L
.30476 .5784 L
.29786 .54002 L
.29889 .50006 L
.30782 .46011 L
.32429 .42171 L
.34766 .38639 L
.377 .35553 L
.41118 .33034 L
Mistroke
.44883 .31181 L
Mfstroke
0 1 .348 r
.54021 .72334 m
.49405 .7325 L
.44812 .73253 L
.40422 .72343 L
.36409 .70557 L
.32929 .67963 L
.30118 .64665 L
.28089 .60791 L
.26919 .56494 L
.26655 .51942 L
.27307 .47313 L
.28849 .4279 L
.31222 .3855 L
.34332 .3476 L
.38057 .31567 L
.4225 .29098 L
.46748 .27449 L
.51373 .26685 L
.55944 .26837 L
.60282 .27897 L
.64217 .29825 L
.67593 .32544 L
.70279 .35949 L
.7217 .39905 L
.7319 .44257 L
.733 .48835 L
.72495 .53458 L
.70808 .57946 L
.68304 .62122 L
.65082 .65822 L
.61268 .68901 L
.57012 .71238 L
.5248 .72742 L
.47851 .73353 L
.43307 .73048 L
.39025 .71838 L
.35174 .69772 L
.31904 .66929 L
.29345 .63422 L
.27597 .59388 L
.26728 .54985 L
.26772 .50387 L
.27728 .45774 L
.29557 .41327 L
.3219 .3722 L
.35521 .33614 L
.3942 .30652 L
.43735 .28449 L
.48295 .27092 L
.52923 .26634 L
Mistroke
.57435 .27093 L
.61656 .28451 L
.6542 .30654 L
.68578 .33617 L
.71007 .37223 L
.72612 .4133 L
.73329 .45778 L
.73131 .50391 L
.72025 .54989 L
.70054 .59391 L
.67297 .63424 L
.63861 .66931 L
.5988 .69773 L
.55512 .7184 L
.50928 .73049 L
.46307 .73353 L
.41831 .72741 L
.37676 .71237 L
.34004 .68899 L
.3096 .65819 L
.28664 .62119 L
.27205 .57942 L
.2664 .53455 L
.26992 .48831 L
.28247 .44254 L
.30356 .39902 L
.33236 .35946 L
.36774 .32542 L
.4083 .29823 L
.45247 .27896 L
.4985 .26836 L
.54459 .26686 L
.58893 .2745 L
.62978 .291 L
.66554 .31569 L
.6948 .34762 L
.71642 .38553 L
.72954 .42794 L
.73365 .47317 L
.72859 .51945 L
.71457 .56497 L
.69212 .60794 L
.66213 .64668 L
.62578 .67966 L
.58449 .70558 L
.53988 .72344 L
.49372 .73253 L
.44779 .73249 L
.40392 .72333 L
.36382 .70541 L
Mistroke
.32906 .67942 L
.30101 .64639 L
.28077 .60762 L
.26913 .56462 L
.26656 .51909 L
.27315 .4728 L
.28864 .42759 L
.31242 .38521 L
.34357 .34735 L
.38085 .31547 L
.42281 .29083 L
.4678 .27441 L
.51406 .26683 L
.55976 .26841 L
.60312 .27908 L
.64243 .29842 L
.67615 .32566 L
.70296 .35975 L
.7218 .39935 L
.73194 .44289 L
.73297 .48868 L
.72486 .53491 L
.70793 .57977 L
.68284 .6215 L
.65057 .65846 L
.61239 .6892 L
.5698 .71252 L
.52447 .7275 L
.47818 .73354 L
.43275 .73043 L
.38995 .71827 L
.35148 .69754 L
.31883 .66906 L
.2933 .63394 L
.27587 .59357 L
.26725 .54953 L
.26775 .50354 L
.27738 .45742 L
.29574 .41296 L
.32211 .37192 L
.35547 .33591 L
.3945 .30634 L
.43767 .28436 L
.48328 .27085 L
.52955 .26634 L
.57467 .27099 L
.61685 .28463 L
.65445 .30673 L
.68598 .33641 L
.71022 .37251 L
Mistroke
.7262 .41361 L
.73331 .4581 L
.73126 .50424 L
.72014 .55021 L
.70037 .59421 L
.67275 .63452 L
.63834 .66954 L
.5985 .69791 L
.5548 .71851 L
.50895 .73054 L
.46274 .73352 L
.418 .72734 L
.37648 .71223 L
.3398 .68879 L
.30941 .65795 L
.2865 .6209 L
.27197 .57911 L
.26639 .53422 L
.26998 .48798 L
.28259 .44222 L
.30374 .39872 L
.33259 .3592 L
.36801 .3252 L
.40861 .29806 L
.4528 .27885 L
.49883 .26832 L
.54492 .26688 L
.58924 .27459 L
.63006 .29115 L
.66577 .3159 L
.69498 .34788 L
.71654 .38582 L
.7296 .42825 L
.73365 .4735 L
.72852 .51978 L
.71443 .56529 L
.69193 .60824 L
.66189 .64694 L
.6255 .67987 L
.58418 .70574 L
.53956 .72354 L
.49338 .73256 L
.44747 .73246 L
.40362 .72324 L
.36355 .70525 L
.32883 .67921 L
.30084 .64613 L
.28066 .60732 L
.26908 .5643 L
.26657 .51876 L
Mistroke
.27323 .47247 L
Mfstroke
.151 1 0 r
.4088 .64023 m
.38499 .62284 L
.3657 .60063 L
.35167 .57447 L
.34347 .54539 L
.34141 .51452 L
.34558 .48309 L
.3558 .45232 L
.37169 .42342 L
.39261 .39753 L
.41774 .37565 L
.44611 .35866 L
.47658 .34722 L
.50798 .34177 L
.53907 .34253 L
.56862 .34947 L
.59548 .36232 L
.61859 .38057 L
.63704 .40351 L
.65012 .43024 L
.65731 .4597 L
.65832 .49075 L
.65312 .52216 L
.64191 .55269 L
.62513 .58117 L
.60344 .60645 L
.57769 .62756 L
.54889 .64366 L
.51818 .65413 L
.48674 .65854 L
.45583 .65673 L
.42666 .64878 L
.40036 .63498 L
.37797 .61588 L
.36037 .59224 L
.34825 .56498 L
.34208 .53517 L
.34212 .50397 L
.34835 .47262 L
.36053 .44235 L
.37818 .41434 L
.40062 .38969 L
.42696 .36937 L
.45616 .35417 L
.48708 .3447 L
.51851 .34133 L
.54922 .34418 L
.57799 .35314 L
.6037 .36787 L
.62534 .38779 L
Mistroke
.64207 .41211 L
.65321 .43988 L
.65835 .47001 L
.65727 .50131 L
.65001 .53257 L
.63687 .56254 L
.61836 .59006 L
.5952 .61405 L
.56831 .63356 L
.53874 .64783 L
.50764 .6563 L
.47625 .65863 L
.44579 .65474 L
.41745 .64477 L
.39236 .62913 L
.37149 .60841 L
.35566 .58344 L
.3455 .5552 L
.3414 .52479 L
.34353 .4934 L
.35179 .46228 L
.36588 .43264 L
.38522 .40564 L
.40908 .38234 L
.4365 .36366 L
.46641 .35033 L
.49764 .34288 L
.52896 .34159 L
.55915 .34652 L
.58702 .35747 L
.61147 .37402 L
.63154 .39551 L
.64646 .4211 L
.65562 .44979 L
.65868 .48045 L
.65551 .51187 L
.64624 .54283 L
.63122 .57211 L
.61106 .59856 L
.58654 .62114 L
.55863 .63897 L
.52841 .65134 L
.49707 .65777 L
.46586 .65801 L
.43598 .65205 L
.40861 .64013 L
.38483 .6227 L
.36558 .60046 L
.35159 .57427 L
.34343 .54517 L
Mistroke
.34142 .5143 L
.34563 .48287 L
.3559 .4521 L
.37182 .42322 L
.39277 .39735 L
.41793 .37551 L
.44632 .35856 L
.47681 .34716 L
.50821 .34175 L
.53929 .34256 L
.56882 .34954 L
.59566 .36243 L
.61874 .38072 L
.63716 .40369 L
.6502 .43044 L
.65734 .45992 L
.65831 .49097 L
.65306 .52238 L
.64181 .55291 L
.625 .58136 L
.60327 .60662 L
.5775 .62769 L
.54868 .64376 L
.51795 .65418 L
.48652 .65855 L
.45562 .6567 L
.42646 .6487 L
.40018 .63486 L
.37782 .61573 L
.36026 .59206 L
.34818 .56477 L
.34206 .53495 L
.34214 .50375 L
.34841 .4724 L
.36064 .44214 L
.37833 .41415 L
.4008 .38953 L
.42716 .36924 L
.45638 .35408 L
.48731 .34466 L
.51874 .34132 L
.54943 .34422 L
.57819 .35323 L
.60387 .368 L
.62548 .38795 L
.64217 .4123 L
.65327 .44009 L
.65836 .47023 L
.65723 .50154 L
.64994 .53279 L
Mistroke
.63676 .56275 L
.61821 .59025 L
.59502 .61421 L
.56811 .63368 L
.53852 .64791 L
.50742 .65634 L
.47602 .65862 L
.44557 .65469 L
.41726 .64468 L
.39219 .62899 L
.37135 .60825 L
.35557 .58325 L
.34545 .55499 L
.34139 .52456 L
.34356 .49318 L
.35187 .46206 L
.366 .43243 L
.38538 .40545 L
.40926 .38219 L
.4367 .36355 L
.46663 .35026 L
.49787 .34285 L
.52919 .3416 L
.55936 .34658 L
.5872 .35757 L
.61163 .37415 L
.63167 .39568 L
.64654 .4213 L
.65566 .45 L
.65868 .48067 L
.65546 .5121 L
.64615 .54305 L
.6311 .57231 L
.6109 .59874 L
.58635 .62129 L
.55842 .63908 L
.52819 .65141 L
.49685 .6578 L
.46564 .65799 L
.43577 .65199 L
.40843 .64002 L
.38468 .62256 L
.36546 .60028 L
.35151 .57407 L
.3434 .54496 L
.34143 .51407 L
.34568 .48264 L
.35599 .45189 L
.37195 .42302 L
.39294 .39718 L
Mistroke
.41813 .37537 L
Mfstroke
1 .319 0 r
.51517 .21037 m
.57204 .21188 L
.62608 .22469 L
.67518 .2483 L
.7174 .2818 L
.75109 .32385 L
.77492 .37282 L
.78797 .42679 L
.78971 .48362 L
.78009 .5411 L
.75947 .59696 L
.72867 .64902 L
.68889 .69523 L
.6417 .73378 L
.58895 .76316 L
.53271 .7822 L
.47519 .79017 L
.41863 .78676 L
.36528 .77208 L
.31721 .74673 L
.27631 .7117 L
.24419 .66836 L
.22211 .61841 L
.21094 .56381 L
.21111 .50671 L
.22262 .44935 L
.24502 .39397 L
.27742 .34276 L
.31856 .29771 L
.36682 .26061 L
.4203 .2329 L
.47692 .21567 L
.53444 .2096 L
.5906 .21493 L
.64322 .23145 L
.69021 .2585 L
.72973 .29504 L
.76024 .33961 L
.78054 .39049 L
.78983 .44566 L
.78774 .50296 L
.77436 .56015 L
.75021 .61497 L
.71624 .66529 L
.67379 .70911 L
.62451 .74473 L
.57035 .77075 L
.51343 .78614 L
.45598 .7903 L
.40026 .78306 L
Mistroke
.34845 .76472 L
.30259 .73599 L
.26448 .698 L
.23561 .65223 L
.21712 .6005 L
.20972 .54481 L
.21373 .48737 L
.22896 .43043 L
.25484 .37621 L
.29033 .32685 L
.33406 .28429 L
.38429 .2502 L
.43907 .2259 L
.49624 .21237 L
.55356 .21012 L
.60877 .21925 L
.65972 .2394 L
.70439 .26978 L
.74105 .30919 L
.76825 .35609 L
.78491 .40863 L
.7904 .46477 L
.78449 .52228 L
.76741 .57892 L
.73984 .63247 L
.70286 .68081 L
.65792 .72206 L
.60677 .7546 L
.55144 .77714 L
.49409 .7888 L
.43697 .78914 L
.38232 .77812 L
.3323 .75619 L
.28885 .7242 L
.25369 .68342 L
.2282 .63543 L
.21337 .58214 L
.2098 .52561 L
.21761 .46809 L
.23651 .41181 L
.26574 .359 L
.30417 .31172 L
.35029 .27183 L
.40228 .24089 L
.45811 .22013 L
.51558 .21034 L
.57244 .21193 L
.62645 .22482 L
.67551 .24851 L
.71767 .28207 L
Mistroke
.7513 .32418 L
.77506 .3732 L
.78802 .42719 L
.78968 .48403 L
.77998 .54151 L
.75928 .59735 L
.72841 .64938 L
.68858 .69554 L
.64134 .73403 L
.58856 .76333 L
.5323 .7823 L
.47477 .79019 L
.41824 .78669 L
.36491 .77194 L
.31688 .74652 L
.27605 .71142 L
.244 .66802 L
.22199 .61803 L
.2109 .56341 L
.21116 .5063 L
.22275 .44894 L
.24522 .39359 L
.27769 .34241 L
.31888 .29742 L
.36719 .26038 L
.4207 .23274 L
.47733 .21559 L
.53485 .2096 L
.591 .21501 L
.64358 .23161 L
.69052 .25873 L
.72999 .29533 L
.76043 .33996 L
.78065 .39087 L
.78985 .44606 L
.78768 .50337 L
.77422 .56055 L
.75 .61535 L
.71597 .66562 L
.67346 .7094 L
.62414 .74495 L
.56995 .7709 L
.51302 .78621 L
.45557 .79029 L
.39987 .78297 L
.3481 .76455 L
.30229 .73575 L
.26424 .6977 L
.23544 .65188 L
.21702 .60011 L
Mistroke
.20971 .54441 L
.2138 .48696 L
.22911 .43003 L
.25506 .37584 L
.29062 .32652 L
.33439 .28402 L
.38467 .24999 L
.43947 .22577 L
.49665 .21231 L
.55396 .21015 L
.60915 .21936 L
.66006 .23958 L
.70469 .27003 L
.74128 .3095 L
.7684 .35644 L
.78499 .40903 L
.7904 .46518 L
.78441 .52269 L
.76725 .57932 L
.73961 .63284 L
.70256 .68114 L
.65757 .72233 L
.60639 .7548 L
.55103 .77726 L
.49368 .78885 L
.43657 .7891 L
.38195 .778 L
.33196 .75599 L
.28857 .72394 L
.25347 .6831 L
.22805 .63507 L
.21331 .58174 L
.20981 .5252 L
.21771 .46768 L
.23668 .41142 L
.26599 .35864 L
.30448 .3114 L
.35064 .27157 L
.40267 .24071 L
.45852 .22002 L
.51599 .21031 L
.57284 .21198 L
.62683 .22495 L
.67584 .24872 L
.71795 .28234 L
.7515 .32451 L
.77519 .37357 L
.78808 .42759 L
.78966 .48445 L
.77987 .54192 L
Mistroke
.7591 .59774 L
Mfstroke
0 .179 1 r
.60701 .35707 m
.63065 .37759 L
.64916 .40291 L
.66182 .43204 L
.66813 .46384 L
.66784 .49706 L
.66096 .53039 L
.64777 .56253 L
.62877 .59222 L
.60473 .61828 L
.57657 .63971 L
.5454 .65565 L
.51246 .66548 L
.47903 .66882 L
.44641 .66553 L
.41591 .65575 L
.3887 .63985 L
.36586 .61847 L
.34829 .59243 L
.33666 .56277 L
.33145 .53065 L
.33286 .49732 L
.34082 .46409 L
.35503 .43228 L
.37493 .40312 L
.39974 .37777 L
.42849 .35721 L
.46004 .34226 L
.49315 .3335 L
.52654 .33127 L
.55889 .33566 L
.58892 .3465 L
.61547 .36337 L
.63748 .3856 L
.6541 .41232 L
.66467 .44248 L
.66877 .4749 L
.66626 .5083 L
.65722 .54138 L
.642 .57283 L
.62122 .60143 L
.59568 .62604 L
.56638 .64571 L
.53448 .65966 L
.50122 .66734 L
.46792 .66846 L
.43588 .66296 L
.40635 .65107 L
.3805 .63325 L
.35933 .6102 L
Mistroke
.34369 .58283 L
.33419 .5522 L
.33119 .51953 L
.33481 .48609 L
.34492 .45319 L
.36111 .42214 L
.38276 .39413 L
.40901 .37029 L
.43882 .35153 L
.47104 .3386 L
.5044 .33201 L
.53758 .33201 L
.56929 .3386 L
.59828 .35152 L
.62341 .37028 L
.6437 .39412 L
.65835 .42212 L
.66678 .45318 L
.66867 .48607 L
.66394 .51951 L
.65277 .55218 L
.63561 .58281 L
.61313 .61019 L
.58621 .63324 L
.5559 .65106 L
.5234 .66296 L
.48998 .66845 L
.45696 .66734 L
.42562 .65966 L
.39721 .64572 L
.37282 .62605 L
.35343 .60144 L
.33979 .57285 L
.33244 .5414 L
.33167 .50832 L
.3375 .47492 L
.3497 .4425 L
.36781 .41234 L
.39111 .38562 L
.41867 .36338 L
.44943 .34651 L
.48218 .33567 L
.51562 .33127 L
.54845 .33349 L
.57938 .34225 L
.6072 .3572 L
.6308 .37776 L
.64928 .40311 L
.66189 .43226 L
.66815 .46408 L
Mistroke
.66781 .4973 L
.66089 .53063 L
.64765 .56275 L
.62862 .59242 L
.60454 .61846 L
.57635 .63984 L
.54517 .65574 L
.51222 .66553 L
.47879 .66882 L
.44619 .66549 L
.4157 .65566 L
.38852 .63972 L
.36571 .6183 L
.34818 .59223 L
.3366 .56255 L
.33144 .53041 L
.33289 .49708 L
.3409 .46386 L
.35516 .43206 L
.3751 .40293 L
.39994 .3776 L
.4287 .35708 L
.46027 .34217 L
.49339 .33346 L
.52678 .33128 L
.55911 .33572 L
.58913 .3466 L
.61564 .36351 L
.63762 .38578 L
.65419 .41253 L
.66472 .44271 L
.66878 .47514 L
.66622 .50854 L
.65713 .54161 L
.64187 .57305 L
.62105 .60162 L
.59548 .6262 L
.56616 .64583 L
.53424 .65974 L
.50098 .66737 L
.46769 .66844 L
.43565 .6629 L
.40615 .65096 L
.38033 .6331 L
.3592 .61002 L
.3436 .58262 L
.33414 .55197 L
.33119 .51929 L
.33486 .48585 L
.34501 .45296 L
Mistroke
.36125 .42192 L
.38293 .39395 L
.40921 .37014 L
.43905 .35142 L
.47128 .33853 L
.50464 .33199 L
.53782 .33203 L
.56951 .33867 L
.59847 .35164 L
.62357 .37043 L
.64382 .39431 L
.65843 .42233 L
.66682 .45341 L
.66866 .48631 L
.66388 .51975 L
.65267 .55241 L
.63547 .58302 L
.61295 .61037 L
.586 .63339 L
.55567 .65117 L
.52316 .66302 L
.48974 .66847 L
.45673 .66731 L
.42541 .65959 L
.39702 .6456 L
.37267 .62589 L
.35331 .60125 L
.33972 .57263 L
.33241 .54116 L
.33168 .50808 L
.33756 .47468 L
.34981 .44227 L
.36796 .41213 L
.39129 .38544 L
.41889 .36324 L
.44966 .34641 L
.48242 .33561 L
.51586 .33126 L
.54868 .33353 L
.57959 .34234 L
.60738 .35733 L
.63096 .37792 L
.64939 .40331 L
.66196 .43248 L
.66817 .46431 L
.66779 .49754 L
.66082 .53086 L
.64753 .56298 L
.62846 .59262 L
.60435 .61863 L
Mistroke
.57614 .63998 L
Mfstroke
1 0 .05 r
.50436 .69155 m
.46611 .69342 L
.42919 .6877 L
.39504 .6746 L
.36502 .65466 L
.34029 .62865 L
.32183 .59758 L
.31036 .56269 L
.30634 .52534 L
.30991 .48699 L
.32095 .44915 L
.33901 .41331 L
.36339 .38087 L
.39313 .35311 L
.42707 .33111 L
.46387 .31574 L
.50209 .3076 L
.54022 .30701 L
.57678 .314 L
.61032 .32828 L
.63953 .34931 L
.66327 .37625 L
.6806 .40804 L
.69084 .44345 L
.6936 .48107 L
.68875 .51944 L
.6765 .55704 L
.65732 .59241 L
.63196 .62415 L
.60143 .65101 L
.56691 .67195 L
.52977 .68614 L
.49147 .69303 L
.45349 .69234 L
.41734 .6841 L
.38444 .66864 L
.35607 .64656 L
.33335 .61872 L
.31717 .58623 L
.30816 .55035 L
.30669 .5125 L
.3128 .47416 L
.32626 .43683 L
.34653 .40198 L
.37283 .37097 L
.40412 .34503 L
.43918 .32518 L
.47662 .31218 L
.51497 .30655 L
.55274 .30852 L
Mistroke
.58844 .318 L
.62067 .33463 L
.64817 .35774 L
.66984 .38644 L
.68486 .41959 L
.69261 .4559 L
.69281 .49394 L
.68544 .53222 L
.6708 .56923 L
.64945 .60353 L
.62223 .63376 L
.59022 .65875 L
.55467 .6775 L
.51697 .68929 L
.4786 .69365 L
.44108 .69041 L
.40587 .67969 L
.37435 .66193 L
.34776 .6378 L
.32715 .60827 L
.31332 .5745 L
.30682 .53779 L
.3079 .49961 L
.31652 .46144 L
.33234 .42478 L
.35474 .39108 L
.38284 .36165 L
.41554 .33765 L
.45155 .32002 L
.48947 .30945 L
.52779 .30637 L
.56503 .31088 L
.59972 .32281 L
.63049 .3417 L
.65614 .3668 L
.67566 .39713 L
.68829 .4315 L
.69353 .46855 L
.69117 .50684 L
.68132 .54486 L
.66434 .58112 L
.64092 .6142 L
.61196 .64279 L
.57861 .66578 L
.54218 .68226 L
.50409 .6916 L
.46584 .69341 L
.42893 .68763 L
.39481 .67448 L
.36482 .65449 L
Mistroke
.34013 .62844 L
.32172 .59735 L
.3103 .56243 L
.30633 .52506 L
.30996 .48672 L
.32105 .44889 L
.33916 .41307 L
.36359 .38066 L
.39336 .35293 L
.42733 .33098 L
.46414 .31566 L
.50236 .30757 L
.54049 .30704 L
.57703 .31408 L
.61055 .32841 L
.63973 .34948 L
.66342 .37646 L
.6807 .40828 L
.69089 .44371 L
.69359 .48134 L
.68869 .51971 L
.67638 .5573 L
.65715 .59265 L
.63176 .62436 L
.60119 .65118 L
.56666 .67208 L
.5295 .68622 L
.49119 .69305 L
.45322 .69231 L
.41709 .68402 L
.38422 .6685 L
.35589 .64638 L
.33321 .61851 L
.31708 .58598 L
.30813 .55009 L
.30671 .51223 L
.31287 .47388 L
.32638 .43657 L
.3467 .40174 L
.37304 .37077 L
.40436 .34487 L
.43944 .32506 L
.47689 .31211 L
.51525 .30654 L
.55301 .30856 L
.58869 .3181 L
.62089 .33477 L
.64834 .35793 L
.66998 .38666 L
.68494 .41984 L
Mistroke
.69264 .45617 L
.69279 .49422 L
.68536 .53249 L
.67067 .56949 L
.64927 .60376 L
.62202 .63396 L
.58998 .65891 L
.5544 .67761 L
.51669 .68935 L
.47833 .69365 L
.44082 .69036 L
.40563 .67959 L
.37414 .66177 L
.34759 .63761 L
.32703 .60805 L
.31325 .57424 L
.3068 .53752 L
.30794 .49933 L
.31661 .46117 L
.33248 .42453 L
.35492 .39085 L
.38306 .36145 L
.41578 .3375 L
.45182 .31992 L
.48974 .3094 L
.52807 .30637 L
.56529 .31094 L
.59995 .32292 L
.63069 .34186 L
.6563 .367 L
.67578 .39737 L
.68836 .43176 L
.69354 .46883 L
.69113 .50712 L
.68122 .54513 L
.66419 .58137 L
.64073 .61442 L
.61174 .64298 L
.57836 .66592 L
.54191 .68236 L
.50381 .69164 L
.46557 .69339 L
.42867 .68756 L
.39458 .67436 L
.36462 .65433 L
.33998 .62823 L
.32161 .59711 L
.31025 .56217 L
.30633 .52479 L
.31002 .48644 L
Mistroke
.32116 .44862 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{1000, 1000},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000?X0003j2000`400?l00000o`00003ooooonf[o
oookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00
oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[
oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Z
oooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooook
J_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z
003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooook
J^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooo
nf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oo
oo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]Zjooo
nfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oo
oo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[o
oookJ_oooo]ZjooonfX00?3ooo]Z0ol007oooookJ_3ooo]Z0ol007oooookJPCooo]Z003`oookJP?o
001ooooonf[`oookJP?o001ooooonfX4oookJP00l?oonfX3o`00Oooooo]Zl?oonfX3o`00Oooooo]Z
1?oonfX00>3ooo]Z2_l007l6oookJP?o001o2?oonfX4o`000?oooo]Ze?oonfX:o`00O`Kooo]Z0ol0
07l8oookJPCo0000mooonfX00>3ooo]Z2_l007l00ooonf[oU?l0oiCo000=oiCo00co0?n]3_l03ol=
oookJQKoo`0HoooonfZLoookJP[o001o1_oonfX3o`00O`Kooo]Z5ooo01PBoookJQKoo`0H__oonfX0
0>_ooo]Z3onDo`02o`3o[@[o00oo0ooonfX9o`0?oaWooo]Z4Ooo01SooookJZOooo]Z0ol007l2oook
JPGoo`0H00?ooo]Zool06?oo01P02_oo01PToookJQ7oo`0H^_oonfX00>_ooo]Z0_nDo`000ol03ooo
U?l0oiCo0002oiCo00[o00oo1ol0ojd6oookJPKo00oo9_oonfX@ool06?oooo]ZW_oonfX<ool060?o
0000=_oonfX@ool06;7ooo]Z003MoookJPooobP000?oU?l0o`0?ool03ol00ol03ol3o`3o[@03oiCo
0?oonf[ooo]Z00?ooo]Z1_l0ojd8oookJPCo00oo;_oonfX=ool06?oooo]ZU_oonfX:ool060Kooo]Z
1?l0000loookJPgoo`0H[_oonfX00=gooo]Z2ooo:006o`3o[@KoU?l01ooonfX3o`3o[@03o`000?oo
nf[ooo]Z00Sooo]Z00?o00oooookJ_oonfX0=OoonfX:ool06?oooo]ZT?oonfX7ool06004oookJ_l0
07oo001oo`00O`Sooo]Z1?l00013oookJPWoo`0HZooonfX00=gooo]Z1?oo:007o`3o[@;oobP00_oo
nfX6oiCo0003o`00Oooonf[ooo]Z00Kooo]Z00Co0?n]o`000?l0003o0000B?oonfX7ool06?oooo]Z
QooonfX7ool060Cooo]Z1_l007l8oookJPCo0000B?oonfX7ool06:Sooo]Z003MoookJP04ool06?l0
ojgo0?n]o`3o[@;oU?l01Ooo:005oookJP?oU?l00ol007l8oookJPCo0000C?oonfX6ool06?oooo]Z
P?oonfX6ool060Wooo]Z1_l007l8oookJPCo0000COoonfX6ool06:Cooo]Z003JoookJP03ool06?nD
o`3oU?l000;oU?l01ooo:007oookJP03oiCo0?oonf[o001o00?o001o2?oonfX4o`0004oooo]Z1_oo
01SooookJW[ooo]Z1_oo01P>oookJPCo001o2?oonfX4o`00053ooo]Z1_oo01RQoookJP00e_oonfX5
oiCo0003oolX0?oo01Sooo]Z00OoobP02ooonfX3o`00O`Sooo]Z1?l0001CoookJPKoo`0HoooonfYa
oookJPOoo`0H4ooonfX3o`00O`Sooo]Z1?l0001DoookJPGoo`0HW_oonfX00=;ooo]Z1?nDo`03oolX
0003ool06?oonf[ooo]Z00;ooo]Z1Ooo:00HoookJPCo0000E_oonfX7ool06?oooo]ZJOoonfX8ool0
627ooo]Z1?l0001GoookJPKoo`0HV_oonfX00<oooo]Z00?oo`0HoiCo0?nDo`000ooo:0000ooo01So
oo]ZoookJP07oookJP;oobP06_oonfX5o`0005Sooo]Z1ooo01SooookJV?ooo]Z1ooo01PUoookJPGo
0000FOoonfX6ool069Oooo]Z003=oookJP03ool06?oo:03oobP000;oobP000?oo`0HoookJ_oonfX0
2_oonfX00ooo:03ooo]ZoookJP0IoookJPCo0000G?oonfX6ool06?oooo]ZGooonfX6ool062Sooo]Z
1?l0001MoookJPGoo`0HUOoonfX00<[ooo]Z00Coo`0HoolX0?oo:03oobP00_oo01P[oookJPCo0000
GooonfX5ool06?oooo]ZF_oonfX6ool062_ooo]Z1?l0001PoookJPCoo`0HTooonfX00<Oooo]Z1?oo
:002ool062kooo]Z1?l0001QoookJPKoo`0HoooonfYDoookJPKoo`0H;_oonfX4o`0006;ooo]Z1Ooo
01R@oookJP00a?oonfX3oolX00?oo`0H<OoonfX4o`0006Cooo]Z1_oo01SooookJTkooo]Z1_oo01Pa
oookJPCo0000IOoonfX5ool068gooo]Z0031oookJP03ool06?oo:03oobP000?oo`0H=?oonfX4o`00
06Oooo]Z1Ooo01SooookJTWooo]Z1_oo01PdoookJPCo0000J?oonfX5ool068[ooo]Z002ooookJPGo
o`0H=ooonfX4o`0006Wooo]Z1Ooo01SooookJTGooo]Z1Ooo01PgoookJPCo0000J_oonfX5ool068So
oo]Z002moookJPGoo`0H>OoonfX4o`0006_ooo]Z1?oo01SooookJT;ooo]Z1Ooo01PioookJPCo0000
K?oonfX4ool068Oooo]Z002koookJPCoo`0H??oonfX4o`0006gooo]Z1Ooo01SooookJSgooo]Z1Ooo
01PkoookJPCo0000K_oonfX4ool068Gooo]Z002ioookJPCoo`0H?_oonfX4o`0006oooo]Z1Ooo01So
oookJSWooo]Z1Ooo01PmoookJPCo0000L?oonfX4ool068?ooo]Z002foookJPCoo`0H@OoonfX4o`00
07;ooo]Z1Ooo01SooookJS?ooo]Z1Ooo01Q0oookJPCo0000L_oonfX5ool0683ooo]Z002doookJPCo
o`0H@ooonfX5o`0007?ooo]Z1Ooo01SooookJRoooo]Z1Ooo01Q2oookJPGo0000LooonfX5ool067ko
oo]Z002boookJPCoo`0HAOoonfX4o`0007Kooo]Z1?oo01SooookJRcooo]Z1Ooo01Q4oookJPCo0000
M_oonfX4ool067gooo]Z002aoookJP?oo`0HAooonfX4o`0007Sooo]Z1?oo01SooookJRWooo]Z1?oo
01Q6oookJPCo0000N?oonfX4ool067_ooo]Z002_oookJP?oo`0HBOoonfX4o`0007Wooo]Z1?oo01So
oookJRKooo]Z1?oo01Q8oookJPCo0000N_oonfX3ool067[ooo]Z002]oookJP?oo`0HBooonfX4o`00
07_ooo]Z0ooo01SooookJR?ooo]Z1?oo01Q:oookJPCo0000O?oonfX3ool067Sooo]Z002ZoookJPCo
o`0HCOoonfX4o`0007gooo]Z0ooo01SooookJQkooo]Z1Ooo01Q<oookJPCo0000OOoonfX4ool067Ko
oo]Z002XoookJPGoo`0HC_oonfX4o`0007kooo]Z1?oo01SooookJQ[ooo]Z1Ooo01Q>oookJPCo0000
OooonfX4ool067Cooo]Z002VoookJPGoo`0HD?oonfX4o`00083ooo]Z1?oo01SooookJQKooo]Z1Ooo
01Q@oookJPCo0000POoonfX4ool067;ooo]Z002UoookJPCoo`0HD_oonfX4o`0008;ooo]Z0ooo01So
oookJQCooo]Z1?oo01QBoookJPCo0000PooonfX3ool0677ooo]Z002SoookJPCoo`0HE?oonfX4o`00
08?ooo]Z0ooo01SooookJQ7ooo]Z1?oo01QDoookJPCo0000Q?oonfX3ool0673ooo]Z002RoookJP?o
o`0HE_oonfX4o`0008Gooo]Z0ooo01SooookJPkooo]Z0ooo01QFoookJPCo0000Q_oonfX2ool066oo
oo]Z002PoookJP?oo`0HF?oonfX5o`0008Kooo]Z0ooo01SooookJP_ooo]Z0ooo01QGoookJPGo0000
Q_oonfX3ool066gooo]Z002OoookJP;oo`0HF_oonfX4o`0008Sooo]Z0ooo01SooookJPSooo]Z0ooo
01QIoookJPCo0000ROoonfX2ool066cooo]Z002MoookJP?oo`0HFooonfX4o`0008Wooo]Z1?oo01So
oookJPCooo]Z0ooo01QKoookJPCo0000R_oonfX3ool066[ooo]Z002KoookJP?oo`0HGOoonfX4o`00
08_ooo]Z1?oo01SooookJP?oo`0HGOoonfX4o`0008_ooo]Z1?oo01QXoookJP00VOoonfX2ool00003
ool06?oonf[ooo]Z05gooo]Z1?l0002<oookJPCoo`0Ho?oonfX4ool065kooo]Z1?l0002=oookJP?o
o`0HIooonfX009Kooo]Z1Ooo001PoookJPCo0000S_oonfX3ool06?[ooo]Z1?oo01QOoookJPCo0000
S_oonfX3ool066Kooo]Z002DoookJPKoo`00HOoonfX4o`0008oooo]Z0ooo01ShoookJP?oo`0HHOoo
nfX4o`0008oooo]Z0ooo01QUoookJP00T_oonfX7ool006;ooo]Z1?l0002@oookJP?oo`0HmOoonfX4
ool066;ooo]Z1?l0002@oookJP?oo`0HI?oonfX008oooo]Z2Ooo001SoookJPCo0000T_oonfX2ool0
6??ooo]Z0ooo01QToookJPCo0000T_oonfX2ool066?ooo]Z002=oookJP[oo`00I?oonfX4o`0009?o
oo]Z0_oo01S`oookJPCoo`0HIOoonfX4o`0009?ooo]Z0_oo01QRoookJP00S?oonfX:ool006Gooo]Z
1?l0002DoookJP?oo`0HkOoonfX3ool066Oooo]Z1?l0002DoookJP?oo`0HH?oonfX008cooo]Z2_oo
001UoookJPGo0000U?oonfX3ool06>[ooo]Z1?oo01QXoookJPGo0000UOoonfX2ool065oooo]Z002=
oookJPSoo`00I_oonfX4o`0009Kooo]Z0ooo01SWoookJPCoo`0HJ_oonfX4o`0009Oooo]Z0_oo01QN
oookJP00S?oonfX2ool060Koo`00IooonfX4o`0009Oooo]Z0_oo01SVoookJP04ool06?oonf[oo`0H
ool066_ooo]Z1?l0002HoookJP;oo`0HGOoonfX008_ooo]Z00?oo`0Hool00?oo00001Ooo001Xoook
JPCo0000VOoonfX2ool06>?ooo]Z0ooo01Q]oookJPCo0000VOoonfX2ool065cooo]Z002:oookJP03
ool06?oo003oo`0H00;ooo]Z0ooo001YoookJPCo0000V_oonfX2ool06>7ooo]Z0ooo01Q^oookJPCo
0000V_oonfX2ool065_ooo]Z0029oookJP03ool06?oo003ooo]Z00Cooo]Z00?oo`00oookJ_oonfX0
J?oonfX4o`0009_ooo]Z0_oo01SOoookJP?oo`0HKooonfX4o`0009_ooo]Z0_oo01QJoookJP00R?oo
nfX00ooo01Soo`00oookJP1`oookJPCo0000W?oonfX3ool06=cooo]Z0_oo01QaoookJPCo0000W?oo
nfX3ool065Sooo]Z0026oookJP03ool06?oo003oo`0004cooo]Z1Ol007l4oookJP?o001o0ooonfX3
o`00O`Oooo]Z1Ol007l8oookJPCo0000WOoonfX3ool06=Wooo]Z0ooo01Q<oookJPGo001o1?oonfX3
o`00O`?ooo]Z0ol007l7oookJPGo001o2?oonfX4o`0009gooo]Z0ooo01QGoookJP00QOoonfX00ooo
01Soo`00oookJP1<oookJPOo001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPOo001o1ooonfX4o`00
09kooo]Z0ooo01SGoookJP?oo`0HC?oonfX7o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX7o`00
O`Oooo]Z1?l0002NoookJP?oo`0HE_oonfX008?ooo]Z0_oo01P00ooo003ooo]ZoookJP1<oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`?ooo]Z0ol007l5oookJPCo001o00Cooo]Zo`00
Ool007oo001o1ooonfX4o`0009oooo]Z0ooo01SEoookJP?oo`0HCOoonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l3oookJP?o001o1OoonfX4o`00O`04oookJ_l007oo001oo`00O`Oooo]Z
1?l0002OoookJP?oo`0HEOoonfX008;ooo]Z00?oo`0Hool00?oo0000@_oonfX:o`00O`;ooo]Z0ol0
07l3oookJP?o001o2OoonfX2o`00O`Gooo]Z0ol007l3oookJP?o001o1_oonfX4o`000:3ooo]Z0ooo
01SCoookJP;oo`0H@_oonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o2OoonfX2o`00O`Gooo]Z0ol0
07l3oookJP?o001o1_oonfX4o`000:3ooo]Z0ooo01QDoookJP00P?oonfX2ool06003ool00?oonf[o
oo]Z04;ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Wooo]Z0ol007l:oookJP?o001o1_oonfX6
o`0009oooo]Z0_oo01SAoookJP?oo`0H@ooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o2OoonfX3
o`00O`[ooo]Z0ol007l6oookJPKo0000WooonfX2ool065Cooo]Z001ooookJP;oo`0H00?oo`00oook
J_oonfX0CooonfX3o`00O`?ooo]Z0ol007l9oookJP?o001o2_oonfX3o`00O`Kooo]Z1?l0002Qoook
JP?oo`0HcooonfX3ool0653ooo]Z0ol007l3oookJP?o001o2OoonfX3o`00O`[ooo]Z0ol007l6oook
JPCo0000X_oonfX2ool065?ooo]Z001noookJP;oo`0H00?oo`00oookJ_oonfX0D?oonfX3o`00O`?o
oo]Z0ol007l:oookJP;o001o1OoonfX2o`00O`;ooo]Z1?l007l6oookJPCo0000X_oonfX3ool06<go
oo]Z0_oo01QBoookJP?o001o0ooonfX3o`00O`[ooo]Z0_l007l5oookJP;o001o0_oonfX4o`00O`Ko
oo]Z1?l0002SoookJP;oo`0HD_oonfX007gooo]Z00?oo`0Hool00?oo0000DooonfX3o`00O`?ooo]Z
0ol007l:oookJP?o001o1?oonfX7o`00O`Oooo]Z1?l0002SoookJP?oo`0HbooonfX2ool065?ooo]Z
0ol007l3oookJP?o001o2_oonfX3o`00O`Cooo]Z1ol007l7oookJPCo0000Y?oonfX2ool0657ooo]Z
001loookJP03ool06?oo003ooo]Z05Cooo]Z0ol007l3oookJP?o001o2ooonfX2o`00O`Cooo]Z1_l0
07l8oookJPCo0000Y?oonfX3ool06<Wooo]Z0_oo01QDoookJP?o001o0ooonfX3o`00O`_ooo]Z0_l0
07l4oookJPKo001o2?oonfX4o`000:Gooo]Z0_oo01Q@oookJP00NooonfX00ooo01Soo`00oookJP1E
oookJP?o001o0ooonfX3o`00O`cooo]Z0_l007l3oookJP;o001o3?oonfX4o`000:Gooo]Z0ooo01S7
oookJP03ool06?oonf[ooo]Z05Cooo]Z0ol007l3oookJP?o001o3?oonfX2o`00O`?ooo]Z0_l007l<
oookJPCo0000Y_oonfX2ool064oooo]Z001ioookJP03ool06?oo003oo`0005Sooo]Z0ol007l01?oo
nf[o001oo`00Ool007l=oookJP;o001o0ooonfX2o`00O`cooo]Z1?l0002VoookJP?oo`0Ha?oonfX2
ool065Sooo]Z0ol007l01?oonf[o001oo`00Ool007l=oookJP;o001o0ooonfX2o`00O`cooo]Z1?l0
002VoookJP?oo`0HC_oonfX007Sooo]Z00?oo`0Hool00?oo01P0FOoonfX7o`00O`Oooo]Z2Ol007l3
oookJPOo001o1_oonfX4o`000:Oooo]Z0ooo01S2oookJP;oo`0HFOoonfX7o`00O`Oooo]Z2Ol007l3
oookJPOo001o1_oonfX4o`000:Oooo]Z0ooo01Q=oookJP00MooonfX00ooo01Soo`00ool0601Koook
JPGo001o2?oonfX9o`00O`?ooo]Z1ol007l6oookJPCo0000Z?oonfX3ool06<3ooo]Z0_oo01QKoook
JPGo001o2?oonfX9o`00O`?ooo]Z1ol007l6oookJPCo0000Z?oonfX3ool064cooo]Z001foookJP03
ool06?oo003oo`0H08;ooo]Z1?l0002YoookJP03ool06?oonf[oo`0H0;kooo]Z0_oo01R2oookJPCo
0000ZOoonfX00ooo01Sooo]Zool0601;oookJP00M_oonfX00ooo003oo`0HoookJP22oookJPGo0000
ZOoonfX2ool06;gooo]Z0_oo01R3oookJPGo0000ZOoonfX2ool064_ooo]Z001eoookJP;oo`0HQ?oo
nfX4o`000:[ooo]Z0ooo01RkoookJP;oo`0HQ?oonfX4o`000:_ooo]Z0_oo01Q:oookJP00M?oonfX2
ool068Gooo]Z1?l0002[oookJP?oo`0H^OoonfX2ool068Gooo]Z1?l0002/oookJP;oo`0HBOoonfX0
07?ooo]Z0_oo01R6oookJPCo0000[?oonfX2ool06;Sooo]Z0_oo01R6oookJPCo0000[OoonfX00ooo
01Sooo]ZoookJP17oookJP00LOoonfX3ool068Oooo]Z1?l0002]oookJP;oo`0H]OoonfX3ool068Oo
oo]Z1?l0002]oookJP;oo`0HB?oonfX0073ooo]Z0ooo01R8oookJPCo0000[_oonfX2ool06;?ooo]Z
0ooo01R8oookJPCo0000[_oonfX2ool064Oooo]Z001_oookJP?oo`0HROoonfX4o`000:oooo]Z0_oo
01RaoookJP?oo`0HROoonfX4o`000:oooo]Z0_oo01Q6oookJP00K_oonfX3ool068[ooo]Z1?l0002`
oookJP;oo`0H[ooonfX3ool068[ooo]Z1?l0002`oookJP;oo`0HAOoonfX006gooo]Z0ooo01R;oook
JPCo0000/?oonfX3ool06:gooo]Z0ooo01R;oookJPCo0000/?oonfX3ool064Cooo]Z001/oookJP?o
o`0HS?oonfX4o`000;7ooo]Z0ooo01R[oookJP?oo`0HS?oonfX4o`000;7ooo]Z0ooo01Q3oookJP00
JooonfX3ool068gooo]Z1?l0002boookJP;oo`0HZ_oonfX3ool068gooo]Z1?l0002boookJP?oo`0H
@_oonfX006_ooo]Z0_oo01R>oookJPGo0000/OoonfX3ool06:Wooo]Z0ooo01R=oookJPGo0000/_oo
nfX2ool064;ooo]Z001ZoookJP;oo`0HSooonfX4o`000;?ooo]Z0_oo01RXoookJP?oo`0HS_oonfX4
o`000;?ooo]Z0ooo01Q1oookJP00JOoonfX2ool0693ooo]Z1?l0002doookJP;oo`0HY_oonfX3ool0
68oooo]Z1?l0002doookJP;oo`0H@OoonfX006Sooo]Z0_oo01RAoookJPCo0000]?oonfX3ool06:Co
oo]Z0ooo01R@oookJPCo0000]OoonfX2ool0643ooo]Z001WoookJP;oo`0HT_oonfX4o`000;Gooo]Z
0_oo01RSoookJP?oo`0HTOoonfX4o`000;Gooo]Z0ooo01PooookJP00I_oonfX2ool069?ooo]Z1?l0
002foookJP;oo`0HXOoonfX3ool069;ooo]Z1?l0002foookJP;oo`0H?ooonfX006Gooo]Z0_oo01RD
oookJPCo0000]_oonfX2ool06:3ooo]Z0ooo01RCoookJPCo0000]ooonfX2ool063kooo]Z001Toook
JP?oo`0HU?oonfX4o`000;Oooo]Z0_oo01RNoookJP?oo`0HU?oonfX4o`000;Sooo]Z00?oo`0Hoook
J_oonfX0??oonfX006?ooo]Z0ooo01REoookJPCo0000^?oonfX2ool069cooo]Z0ooo01REoookJPCo
0000^?oonfX2ool063gooo]Z001RoookJP?oo`0HU_oonfX4o`000;Sooo]Z0ooo01RJoookJP?oo`0H
U_oonfX4o`000;Wooo]Z0_oo01PloookJP00HOoonfX3ool069Oooo]Z1?l0002ioookJP?oo`0HV?oo
nfX3ool069Oooo]Z1?l0002joookJP;oo`0H>ooonfX0063ooo]Z0ooo01RHoookJPGo0000^OoonfX2
ool069Sooo]Z0_oo01RHoookJPGo0000^OoonfX2ool063_ooo]Z001PoookJP;oo`0HVOoonfX4o`00
0;[ooo]Z0ooo01RFoookJP?oo`0HV?oonfX4o`000;_ooo]Z0_oo01PjoookJP00GooonfX2ool069[o
oo]Z1?l0002koookJP;oo`0HUOoonfX3ool069Wooo]Z1?l0002koookJP;oo`0H>_oonfX005kooo]Z
0_oo01RKoookJPCo0000^ooonfX3ool069?ooo]Z0ooo01RJoookJPCo0000_?oonfX2ool063Wooo]Z
001MoookJP?oo`0HVooonfX4o`000;cooo]Z0_oo01RCoookJP;oo`0HVooonfX4o`000;gooo]Z00?o
o`0HoookJ_oonfX0=ooonfX005gooo]Z0_oo01RLoookJPCo0000_?oonfX3ool0697ooo]Z0_oo01RL
oookJPCo0000_OoonfX2ool063Sooo]Z001LoookJP;oo`0HWOoonfX4o`000;gooo]Z0_oo01R@oook
JP;oo`0HWOoonfX4o`000;kooo]Z0_oo01PgoookJP00FooonfX2ool069kooo]Z1?l0002noookJP;o
o`0HS_oonfX2ool069kooo]Z1?l0002noookJP?oo`0H=_oonfX005[ooo]Z0_oo01ROoookJPCo0000
__oonfX3ool068cooo]Z0_oo01ROoookJPCo0000_ooonfX2ool063Kooo]Z001IoookJP;oo`0HX?oo
nfX4o`000;oooo]Z0_oo01R;oookJP?oo`0HWooonfX4o`000<3ooo]Z0_oo01PeoookJP00F?oonfX3
ool06:3ooo]Z1?l0002ooookJP?oo`0HROoonfX3ool06:3ooo]Z1?l00030oookJP?oo`0H=?oonfX0
05Oooo]Z0ooo01RQoookJPGo0000_ooonfX3ool068Oooo]Z0ooo01RQoookJPGo0000`?oonfX2ool0
63Cooo]Z001GoookJP;oo`0HX_oonfX4o`000<3ooo]Z0ooo01R7oookJP;oo`0HX_oonfX4o`000<7o
oo]Z0ooo01PcoookJP00E_oonfX2ool06:?ooo]Z1?l00031oookJP?oo`0HQOoonfX3ool06:;ooo]Z
1?l00032oookJP;oo`0H<ooonfX005Gooo]Z0_oo01RToookJPCo0000`_oonfX2ool068Cooo]Z0ooo
01RSoookJPCo0000`_oonfX2ool063?ooo]Z001EoookJP;oo`0HY?oonfX4o`000<;ooo]Z0_oo01R4
oookJP;oo`0HY?oonfX4o`000<?ooo]Z0_oo01PboookJP00E?oonfX2ool06:Gooo]Z1?l00033oook
JP;oo`0HP_oonfX2ool06:Gooo]Z1?l00033oookJP;oo`0H<_oonfX005?ooo]Z0_oo01RVoookJPCo
0000`ooonfX2ool068;ooo]Z0_oo01RUoookJPCo0000a?oonfX2ool0637ooo]Z001CoookJP03ool0
6?oonf[ooo]Z08Wooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Sooo]Z1?l00034oookJP;oo`0H
P?oonfX2ool068[ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Sooo]Z1?l00034oookJP;oo`0H
<OoonfX005;ooo]Z0_oo01R:oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPCo0000a?oo
nfX2ool067oooo]Z0_oo01R:oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPCo0000a?oo
nfX2ool0637ooo]Z001AoookJP;oo`0HRooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l00034oookJP;oo`0H
OooonfX00ooo01Sooo]ZoookJP29oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03
oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`000<Gooo]Z0_oo01P`oook
JP00D?oonfX2ool067oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o
001o1_oonfX4o`000<Gooo]Z0_oo01QmoookJP;oo`0HO_oonfX:o`00O`;ooo]Z0ol007l3oookJP?o
001o1_oonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000aOoonfX3ool062oooo]Z001?oookJP?oo`0H
OooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z1_l00033oookJP;oo`0H
O?oonfX2ool067oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPKo0000
a?oonfX2ool062oooo]Z001>oookJP?oo`0HS?oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oo
nfX4o`000<Kooo]Z0_oo01QjoookJP;oo`0HS?oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oo
nfX4o`000<Kooo]Z0ooo01P^oookJP00C_oonfX2ool068gooo]Z0ol007l3oookJP?o001o1ooonfX2
o`00O`;ooo]Z1?l007l6oookJPCo0000a_oonfX2ool067Wooo]Z0ooo01R<oookJP?o001o0ooonfX3
o`00O`Oooo]Z0_l007l2oookJPCo001o1_oonfX4o`000<Oooo]Z0_oo01P^oookJP00COoonfX2ool0
68kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Oooo]Z1?l00036oookJP?oo`0HN?oonfX2ool0
68gooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Oooo]Z1?l00037oookJP;oo`0H;_oonfX004go
oo]Z0_oo01R>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPCo0000aooonfX2ool067Oo
oo]Z0_oo01R>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPCo0000b?oonfX2ool062go
oo]Z001<oookJP;oo`0HSooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX4o`000<Oooo]Z
0_oo01QgoookJP;oo`0HS_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX4o`000<Sooo]Z
0_oo01P]oookJP00C?oonfX2ool0693ooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o
3?oonfX4o`000<Sooo]Z0_oo01QeoookJP;oo`0HT?oonfX3o`00O`04oookJ_l007oo001oo`00O`So
oo]Z0_l007l<oookJPCo0000bOoonfX00ooo01Sooo]ZoookJP0[oookJP00BooonfX2ool0697ooo]Z
1ol007l9oookJPOo001o1_oonfX4o`000<Sooo]Z0_oo01QdoookJP;oo`0HTOoonfX7o`00O`Wooo]Z
1ol007l6oookJPCo0000bOoonfX2ool062cooo]Z001:oookJP;oo`0HTooonfX5o`00O`[ooo]Z1ol0
07l6oookJPCo0000b?oonfX2ool067Cooo]Z0_oo01RBoookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0
0039oookJP;oo`0H;?oonfX004[ooo]Z0_oo01R_oookJPCo0000bOoonfX2ool067;ooo]Z0_oo01R_
oookJPCo0000b_oonfX00ooo01Sooo]ZoookJP0ZoookJP00BOoonfX2ool06;3ooo]Z1?l00039oook
JP;oo`0HLOoonfX3ool06:oooo]Z1?l0003:oookJP;oo`0H:ooonfX004Wooo]Z00?oo`0HoookJ_oo
nfX0[ooonfX5o`000<Sooo]Z0_oo01QaoookJP;oo`0H/?oonfX5o`000<Wooo]Z0_oo01P[oookJP00
B?oonfX2ool06;7ooo]Z1?l0003:oookJP;oo`0HKooonfX2ool06;7ooo]Z1?l0003;oookJP;oo`0H
:_oonfX004Oooo]Z0_oo01RboookJPCo0000b_oonfX2ool066kooo]Z0ooo01RaoookJPCo0000booo
nfX2ool062[ooo]Z0016oookJP?oo`0H/_oonfX4o`000<_ooo]Z0_oo01Q/oookJP03ool06?oonf[o
o`0H0;;ooo]Z1?l0003<oookJP;oo`0H:OoonfX004Kooo]Z0_oo01RcoookJPCo0000booonfX2ool0
66cooo]Z0_oo01RcoookJPCo0000c?oonfX2ool062Wooo]Z0015oookJP;oo`0H]?oonfX4o`000<_o
oo]Z0_oo01Q[oookJP?oo`0H/ooonfX4o`000<cooo]Z0_oo01PYoookJP00AOoonfX2ool06;Cooo]Z
1?l0003<oookJP;oo`0HJ_oonfX2ool06;Cooo]Z1?l0003=oookJP;oo`0H:?oonfX004Cooo]Z0_oo
01ReoookJPCo0000c?oonfX2ool066Wooo]Z0ooo01RdoookJPCo0000cOoonfX2ool062Sooo]Z0014
oookJP;oo`0H]OoonfX4o`000<gooo]Z0_oo01QXoookJP;oo`0H]OoonfX4o`000<gooo]Z0_oo01PX
oookJP00@ooonfX2ool06;Kooo]Z1?l0003=oookJP;oo`0HIooonfX2ool06;Kooo]Z1?l0003>oook
JP03ool06?oonf[ooo]Z02Kooo]Z0013oookJP;oo`0H]_oonfX5o`000<cooo]Z0_oo01QWoookJP;o
o`0H]_oonfX5o`000<gooo]Z0_oo01PWoookJP00@_oonfX2ool06;Oooo]Z1?l0003>oookJP;oo`0H
IOoonfX2ool06;Oooo]Z1?l0003>oookJP;oo`0H9ooonfX004;ooo]Z00?oo`0HoookJ_oonfX0]_oo
nfX4o`000<kooo]Z0_oo01QUoookJP;oo`0H]ooonfX4o`000<oooo]Z0_oo01PVoookJP00@OoonfX2
ool06;Sooo]Z1?l0003>oookJP?oo`0HHooonfX2ool06;Sooo]Z1?l0003?oookJP;oo`0H9_oonfX0
047ooo]Z00?oo`0HoookJ_oonfX0]ooonfX4o`000<oooo]Z0_oo01QSoookJP03ool06?oonf[ooo]Z
0;Oooo]Z1?l0003?oookJP;oo`0H9_oonfX0043ooo]Z0_oo01RioookJPCo0000cooonfX00ooo01So
ogT0oomi001QoookJP;oo`0H^OoonfX4o`000=3ooo]Z0_oo01PUoookJP00?ooonfX2ool06;[ooo]Z
1?l0003?oookJP03ool06?ooN@3oo`0H063ooo]Z0_oo01RjoookJPCo0000d?oonfX2ool062Gooo]Z
000ooookJP;oo`0H^_oonfX4o`000<oooo]Z00?oo`0Hoomi0?oonfX0H?oonfX2ool06;[ooo]Z1?l0
003@oookJP;oo`0H9OoonfX003kooo]Z0_oo01RkoookJPCo0000d?oonfX00oooN@3ooo]ZoookJP1N
oookJP;oo`0H^ooonfX4o`000=3ooo]Z0_oo01PUoookJP00?_oonfX00ooo01Sooo]ZoookJP2joook
JPCo0000d?oonfX00ooo01SoogT0oookJP1NoookJP;oo`0H^ooonfX4o`000=3ooo]Z0ooo01PToook
JP00?_oonfX00ooo01Sooo]ZoookJP2joookJPCo0000d?oonfX00ooo01SoogT0oookJP1NoookJP03
ool06?oonf[ooo]Z0;[ooo]Z1?l0003AoookJP;oo`0H9?oonfX003gooo]Z00?oo`0HoookJ_oonfX0
^ooonfX5o`000<oooo]Z00?oo`0Hoomi0?oonfX0GOoonfX2ool06;cooo]Z1Ol0003@oookJP;oo`0H
9?oonfX003gooo]Z00?oo`0HoookJ_oonfX0^ooonfX4o`000=7ooo]Z00?oogT0ool06?oonfX0G?oo
nfX00ooo01Sooo]ZoookJP2koookJPCo0000dOoonfX2ool062Cooo]Z000loookJP03ool06?oonf[o
oo]Z0;cooo]Z1?l0003AoookJP03oomi0?oo01Sooo]Z05_ooo]Z0_oo01RmoookJPCo0000dOoonfX2
ool062Cooo]Z000loookJP03ool06?oonf[ooo]Z0;cooo]Z1?l0003AoookJP03oomi0?oo01Sooo]Z
05_ooo]Z00?oo`0HoookJ_oonfX0_?oonfX4o`000=;ooo]Z00?oo`0HoookJ_oonfX08_oonfX003_o
oo]Z0_oo01RnoookJPCo0000dOoonfX00ooo01SoogT0ool0601JoookJP;oo`0H__oonfX4o`000=;o
oo]Z0_oo01PSoookJP00>_oonfX2ool06;oooo]Z1?l0003BoookJP03oomi0?oo01Sooo]Z05Wooo]Z
0_oo01RnoookJPCo0000d_oonfX2ool062?ooo]Z000joookJP;oo`0H_ooonfX4o`000=;ooo]Z00?o
ogT0ool06?oonfX0F?oonfX2ool06;oooo]Z1?l0003BoookJP;oo`0H8ooonfX003Wooo]Z0_oo01S0
oookJPCo0000d_oonfX00oooN@3ooo]Zool0601GoookJP?oo`0H_ooonfX4o`000=?ooo]Z0_oo01PR
oookJP00>OoonfX2ool06<3ooo]Z1?l0003BoookJP03oomi0?oonf[oA?l005Oooo]Z0_oo01S0oook
JPCo0000dooonfX2ool062;ooo]Z000hoookJP?oo`0H`?oonfX4o`000=;ooo]Z00?oogT0ool06?m4
o`00E_oonfX00ooo01Sooo]Zool06030oookJPCo0000dooonfX2ool062;ooo]Z000hoookJP;oo`0H
`OoonfX4o`000=;ooo]Z00?oo`0Hoomi0?m4o`00E_oonfX2ool06<7ooo]Z1?l0003CoookJP;oo`0H
8_oonfX003Oooo]Z0ooo01S1oookJPGo0000d_oonfX00oooN@3oA?l0oookJP1DoookJP03ool06?oo
nf[oo`0H0<7ooo]Z1Ol0003BoookJP;oo`0H8_oonfX003Oooo]Z0_oo01S2oookJPCo0000dooonfX0
0oooN@3oA?l0oookJP1DoookJP;oo`0H`_oonfX4o`000=Cooo]Z00?oo`0HoookJ_oonfX08?oonfX0
03Oooo]Z0_oo01S2oookJPCo0000dooonfX00oooN@3oA?l0oookJP1DoookJP;oo`0H`_oonfX4o`00
0=Cooo]Z00?oo`0HoookJ_oonfX08?oonfX003Kooo]Z0ooo01S2oookJPCo0000dooonfX00oooN@3o
A?l0oookJP1CoookJP?oo`0H`_oonfX4o`000=Cooo]Z0_oo01PQoookJP00=_oonfX2ool06<?ooo]Z
1?l0003CoookJP03oomi0?m4o`3ooo]Z05?ooo]Z0_oo01S3oookJPCo0000e?oonfX2ool0627ooo]Z
000foookJP;oo`0H`ooonfX4o`000=?ooo]Z00?oogT0ool06?m4o`00DooonfX2ool06<?ooo]Z1?l0
003DoookJP;oo`0H8OoonfX003Gooo]Z0_oo01S4oookJPCo0000e?oonfX00oooN@3oA?l0oookJP1A
oookJP;oo`0Ha?oonfX4o`000=Gooo]Z00?oo`0HoookJ_oonfX07ooonfX003Gooo]Z0_oo01RNoook
JPGo001o1?oonfX3o`00O`03oookJ_l007oo001o00Oo001o0ooonfX5o`00O`Sooo]Z1?l0003Doook
JP03oomi0?m4o`3ooo]Z057ooo]Z0_oo01RNoookJPGo001o1?oonfX3o`00O`03oookJ_l007oo001o
00Oo001o0ooonfX5o`00O`Sooo]Z1?l0003EoookJP03ool06?oonf[ooo]Z01oooo]Z000doookJP;o
o`0HW_oonfX7o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`07o`00O`;ooo]Z1ol007l7oookJPCo
0000e?oonfX00oooN@3oA?l0oookJP1AoookJP03ool06?oonf[ooo]Z09cooo]Z1ol007l3oookJP?o
001o00?ooo]Zo`00Ool007l01ol007l2oookJPOo001o1ooonfX4o`000=Gooo]Z00?oo`0HoookJ_oo
nfX07ooonfX003Cooo]Z0_oo01RNoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03
oookJ_l007oo001o00;o001o1_oonfX4o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l0003Doook
JP03oomi0?m4o`3oogT0053ooo]Z0_oo01RNoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`03oookJ_l007oo001o00;o001o1_oonfX4o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l0
003EoookJP03ool06?oonf[ooo]Z01oooo]Z000coookJP?oo`0HTOoonfX:o`00O`;ooo]Z0ol007l3
oookJP?o001o1ooonfX4o`00O`Gooo]Z0ol007l3oookJP?o001o1_oonfX4o`000=?ooo]Z0_ooN@00
0om4o`3oogT0oookJP1?oookJP;oo`0HTOoonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1ooonfX4
o`00O`Gooo]Z0ol007l3oookJP?o001o1_oonfX4o`000=Gooo]Z0_oo01PPoookJP00<ooonfX2ool0
69;ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol007l9oookJP?o001o1_oonfX6o`00
0<oooo]Z1?ooN@000om4o`3o0?onoookJP1?oookJP03ool06?oonf[ooo]Z093ooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`Sooo]Z1Ol007l9oookJP?o001o1_oonfX6o`000=?ooo]Z0_oo01PPoook
JP00<_oonfX3ool069kooo]Z0ol007l3oookJP?o001o2_oonfX4o`00O`Sooo]Z0ol007l6oookJPCo
0000dOoonfX4oomi0003odCo0?l0ookooo]Z04kooo]Z0_oo01RNoookJP?o001o0ooonfX3o`00O`[o
oo]Z1?l007l8oookJP?o001o1_oonfX4o`000=Kooo]Z00?oo`0HoookJ_oonfX07_oonfX003;ooo]Z
0_oo01ROoookJP?o001o0ooonfX3o`00O`_ooo]Z0ol007l3oookJP;o001o0_oonfX4o`00O`Kooo]Z
1?l0003BoookJP?oogT000?oA?l0o`3oo_oonfX0C_oonfX00ooo01Sooo]ZoookJP2MoookJP?o001o
0ooonfX3o`00O`_ooo]Z0ol007l3oookJP;o001o0_oonfX4o`00O`Kooo]Z1?l0003FoookJP03ool0
6?oonf[ooo]Z01kooo]Z000boookJP;oo`0HWooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o0_oo
nfX7o`00O`Oooo]Z1?l0003BoookJP?oogT000?oA?l0o`3oo_oonfX0C_oonfX00ooo01Sooo]Zoook
JP2MoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l2oookJPOo001o1ooonfX4o`000=Kooo]Z00?o
o`0HoookJ_oonfX07_oonfX0037ooo]Z0ooo01ROoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3
oookJP?o001o0_oonfX6o`00O`Sooo]Z1?l0003CoookJP;oogT000?oA?l0o`3oo_oonfX0COoonfX2
ool069oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l2oookJPKo001o2?oonfX4
o`000=Kooo]Z00?oo`0HoookJ_oonfX07_oonfX0037ooo]Z0_oo01RPoookJP?o001o0ooonfX3o`00
O`Kooo]Z0ol007l3oookJP?o001o0_oonfX2o`00O`cooo]Z1?l0003CoookJP;oogT000?oA?l0o`3o
o_oonfX0COoonfX00ooo01Sooo]ZoookJP2NoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o0_oonfX2o`00O`cooo]Z1?l0003FoookJP03ool06?oonf[ooo]Z01kooo]Z000aoookJP;o
o`0HXOoonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l007l2oookJP?o001o0_oonfX2o`00
O`cooo]Z1?l0003CoookJP;oogT000?oA?l0o`3oo_oonfX0COoonfX00ooo01Sooo]ZoookJP2Ooook
JP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`00O`;ooo]Z0ol007l2oookJP;o001o3?oonfX4
o`000=Kooo]Z00?oo`0HoookJ_oonfX07_oonfX0037ooo]Z00?oo`0HoookJ_oonfX0X?oonfX7o`00
O`Sooo]Z1ol007l4oookJPOo001o1_oonfX4o`000=Cooo]Z00?oogT0odCo0?l0ooh0COoonfX00ooo
01Sooo]ZoookJP2PoookJPOo001o2?oonfX7o`00O`Cooo]Z1ol007l6oookJPCo0000e_oonfX2ool0
61oooo]Z000`oookJP;oo`0HXooonfX5o`00O`[ooo]Z1Ol007l5oookJPOo001o1_oonfX4o`000=Co
oo]Z00?oogT0odCo0?l0ooh0COoonfX00ooo01Sooo]ZoookJP2QoookJPGo001o2_oonfX5o`00O`Go
oo]Z1ol007l6oookJPCo0000e_oonfX2ool061oooo]Z000`oookJP;oo`0HbOoonfX4o`000=Gooo]Z
00?oogT0o`3oo_oonfX0C?oonfX00ooo01Sooo]ZoookJP37oookJPCo0000e_oonfX2ool061oooo]Z
000`oookJP03ool06?oonf[ooo]Z0<Sooo]Z1?l0003EoookJP03oomi0?l0ookooo]Z04_ooo]Z0_oo
01S9oookJPCo0000e_oonfX2ool061oooo]Z000`oookJP03ool06?oonf[ooo]Z0<Sooo]Z1Ol0003E
oookJP03o`3oo_oonf[ooo]Z04[ooo]Z00?oo`0HoookJ_oonfX0b?oonfX5o`000=Kooo]Z00?oo`0H
oookJ_oonfX07OoonfX002oooo]Z0_oo01S:oookJPCo0000e_oonfX00ol0ookooo]ZoookJP19oook
JP;oo`0Hb_oonfX4o`000=Oooo]Z00?oo`0HoookJ_oonfX07OoonfX002oooo]Z00?oo`0HoookJ_oo
nfX0bOoonfX4o`000=Kooo]Z00?o0?onoookJ_oonfX0BOoonfX2ool06<[ooo]Z1?l0003GoookJP03
ool06?oonf[ooo]Z01gooo]Z000_oookJP03ool06?oonf[ooo]Z0<Wooo]Z1?l0003BoookJPCoA?l0
00?o0?onoookJ_oonfX0BOoonfX2ool06<[ooo]Z1?l0003GoookJP03ool06?oonf[ooo]Z01gooo]Z
000^oookJP;oo`0HbooonfX4o`000=;ooo]Z1?m4o`000ol0ookooo]ZoookJP18oookJP;oo`0Hbooo
nfX4o`000=Oooo]Z00?oo`0HoookJ_oonfX07OoonfX002kooo]Z00?oo`0HoookJ_oonfX0b_oonfX4
o`000=?ooo]Z0om4o`000ol0ookooo]ZoookJP18oookJP;oo`0HbooonfX4o`000=Oooo]Z00?oo`0H
oookJ_oonfX07OoonfX002kooo]Z00?oo`0HoookJ_oonfX0b_oonfX4o`000=?ooo]Z0om4o`000ol0
ookooo]ZoookJP18oookJP;oo`0HbooonfX4o`000=Oooo]Z00?oo`0HoookJ_oonfX07OoonfX002go
oo]Z0_oo01S<oookJPCo0000e?oonfX3odCo04Wooo]Z0_oo01S<oookJPCo0000mooonfX002gooo]Z
0_oo01S<oookJPCo0000e?oonfX3odCo04Wooo]Z0_oo01S<oookJPCo0000mooonfX002gooo]Z00?o
o`0HoookJ_oonfX0booonfX4o`000=Cooo]Z0om4o`19oookJP;oo`0Hc?oonfX4o`000?Oooo]Z000]
oookJP03ool06?oonf[ooo]Z0<_ooo]Z1Ol0003DoookJP;oA?l0BOoonfX2ool06<cooo]Z1Ol0003f
oookJP00;?oonfX2ool06<gooo]Z1?l0003EoookJP;oA?l0B?oonfX2ool06<gooo]Z1?l0003goook
JP00;?oonfX00ooo01Sooo]ZoookJP3<oookJPCo0000e_oonfX00om4o`3ooo]ZoookJP16oookJP;o
o`0HcOoonfX4o`000?Oooo]Z000/oookJP03ool06?oonf[ooo]Z0<cooo]Z1?l0003FoookJP03odCo
0?oonf[ooo]Z04Kooo]Z0_oo01S=oookJPCo0000mooonfX002_ooo]Z0_oo01S>oookJPCo0000oooo
nfXOoookJP;oo`0Hc_oonfX4o`000?Oooo]Z000[oookJP;oo`0Hc_oonfX4o`000?oooo]Z7ooonfX2
ool06<kooo]Z1?l0003goookJP00:ooonfX2ool06<kooo]Z1?l0003ooookJQoooo]Z0_oo01S>oook
JPCo0000mooonfX002[ooo]Z0_oo01S?oookJPCo0000dooonfX4o`3ooTKooo]Z0ooo01S>oookJPCo
0000mooonfX002[ooo]Z0_oo01S?oookJPCo0000dooonfX4o`3ooTKooo]Z0_oo01S?oookJPCo0000
mooonfX002[ooo]Z0_oo01S?oookJPCo0000dooonfX4o`3ooTKooo]Z0_oo01S?oookJPCo0000mooo
nfX002[ooo]Z0_oo01S?oookJPCo0000e?oonfX3o`3ooTKooo]Z0_oo01S?oookJPCo0000mooonfX0
02[ooo]Z0_oo01S?oookJPGo0000dooonfX3o`3ooTKooo]Z0_oo01S?oookJPGo0000m_oonfX002Wo
oo]Z0_oo01S@oookJPCo0000e?oonfX3o`3ooTGooo]Z0_oo01S@oookJPCo0000mooonfX002Wooo]Z
0_oo01P2o`00ObGooo]Z1Ol007l4oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol007lMoookJPGo001o
1?oonfX3o`00O`?ooo]Z1Ol007lMoookJPGo001o1?oonfX3o`00O`03oookJ_l007oo001o00Oo001o
0ooonfX5o`00Oaoooo]Z1?l0000UoookJPGo001o1?oonfX3o`00O`03oookJ_l007oo001o00Oo001o
0ooonfX5o`00Oagooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00Oagooo]Z1Ol007l4oookJP?o001o
0ooonfX3o`00O`Oooo]Z1Ol007lUoookJP?o0?on00?o001ooookJ_oonfX0@_oonfX2ool060?o001o
9?oonfX5o`00O`Cooo]Z0ol007l3oookJP?o001o1ooonfX5o`00Oagooo]Z1Ol007l4oookJP?o001o
0ooonfX5o`00Oagooo]Z1Ol007l4oookJP?o001o00?ooo]Zo`00Ool007l01ol007l3oookJPGo001o
7ooonfX4o`0002Gooo]Z1Ol007l4oookJP?o001o00?ooo]Zo`00Ool007l01ol007l3oookJPGo001o
7OoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o7OoonfX5o`00O`Cooo]Z0ol007l3oookJP?o001o
1ooonfX5o`00ObOooo]Z0ol007lNoookJP00:OoonfX2ool060;o001o9?oonfX7o`00O`?ooo]Z0ol0
07l3oookJP?o001o1_oonfX7o`00Oa_ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Oa_ooo]Z1ol0
07l3oookJP?o001o00?ooo]Zo`00Ool007l01ol007l2oookJPOo001o7_oonfX4o`0002Cooo]Z1ol0
07l3oookJP?o001o00?ooo]Zo`00Ool007l01ol007l2oookJPOo001o6ooonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o6ooonfX7o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX7o`00ObGooo]Z0_l0
ooh00ol007oooo]ZoookJP12oookJP;oo`0H0ol007lSoookJPOo001o0ooonfX3o`00O`?ooo]Z0ol0
07l6oookJPOo001o6ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o6ooonfX7o`00O`?ooo]Z0ol0
07l00ooonf[o001oo`00O`07o`00O`;ooo]Z1ol007lNoookJPCo00009?oonfX7o`00O`?ooo]Z0ol0
07l00ooonf[o001oo`00O`07o`00O`;ooo]Z1ol007lKoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol0
07lKoookJPOo001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPOo001o9_oonfX3o`00Oakooo]Z000Y
oookJP;oo`0H0_l007lToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`?ooo]Z0ol0
07l5oookJPCo001o00Cooo]Zo`00Ool007oo001o6ooonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l6oookJPCo001o00Cooo]Z
o`00Ool007oo001o7_oonfX4o`0002Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o
00?ooo]Zo`00Ool007l00_l007l6oookJPCo001o00Cooo]Zo`00Ool007oo001o6ooonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001o
o`00Oa_ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o0ooonfX3o`00O`Gooo]Z1?l0
07l01?oonf[o001oo`00Ool007lUoookJP;o0?on00?o001ooookJ_oonfX0@_oonfX2ool060?o001o
8ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l3oookJP?o001o1OoonfX4o`00O`04
oookJ_l007oo001oo`00Oa_ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Z
o`00Ool007l00_l007l01?oonf[o001oo`00Ool007lKoookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`03oookJ_l007oo001o00;o001o1_oonfX4o`00O`04oookJ_l007oo001oo`00Oako
oo]Z1?l0000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o
00;o001o1_oonfX4o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lKoookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`?ooo]Z0ol007l5oookJPCo001o00Cooo]Zo`00Ool0
07oo001o9_oonfX00ol007ooo`0Ho`00O`0NoookJP006_oonfX:o`00O`Gooo]Z00Coo`0Ho`00Ool0
07oo001o5ooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o2OoonfX2o`00O`Gooo]Z0ol007l3oook
JP?o001o3OoonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l=oook
JP[o001o0_oonfX3o`00O`?ooo]Z0ol007l7oookJPCo001o1OoonfX3o`00O`?ooo]Z0ol007lMoook
JPCo00008ooonfX3o`00O`?ooo]Z0ol007l7oookJPCo001o1OoonfX3o`00O`?ooo]Z0ol007lIoook
JP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o6OoonfX3o`00O`?ooo]Z0ol007l9oook
JP;o001o1OoonfX3o`00O`?ooo]Z0ol007lToookJP;o0?on00?o001ooookJ_oonfX0=?oonfX:o`00
O`Cooo]Z00?oo`0HoookJ_l007l00_l007lFoookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l9oook
JP;o001o1OoonfX3o`00O`?ooo]Z0ol007l=oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oook
JP?o001o0ooonfX3o`00O`gooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Oooo]Z1?l007l5oook
JP?o001o0ooonfX3o`00Oagooo]Z1?l0000SoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l007l5oook
JP?o001o0ooonfX3o`00OaWooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007lIoook
JP?o001o0ooonfX3o`00O`Wooo]Z0_l007l5oookJP?o001o0ooonfX3o`00ObGooo]Z00?o001oool0
6?l007l07_oonfX001[ooo]Z2_l007l4oookJP;oo`0H0ol007lGoookJP[o001o0_oonfX3o`00O`?o
oo]Z0ol007l9oookJP?o001o2_oonfX3o`00O`gooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l=oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo001o2OoonfX3o`00Oago
oo]Z1?l0000SoookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol007l9oookJP?o001o6OoonfX3o`00O`?o
oo]Z0ol007l<oookJP?o001o6OoonfX3o`00O`?ooo]Z0ol007l9oookJP?o001o2_oonfX3o`00ObCo
oo]Z00?o001oo`3oo_l007l0=_oonfX:o`00O`Cooo]Z00?oo`0HoookJ_l007l00_l007lFoookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l9oookJP?o001o2_oonfX3o`00O`gooo]Z2_l007l2oookJP?o
001o0ooonfX3o`00O`cooo]Z0ol007l=oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo
001o2OoonfX3o`00Oagooo]Z1?l0000SoookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol007l9oookJP?o
001o6OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o6OoonfX3o`00O`?ooo]Z0ol007l9oookJP?o
001o2_oonfX3o`00ObGooo]Z00?o001oool06?l007l07_oonfX002Sooo]Z0_oo01P3o`00Ob?ooo]Z
0ol007l3oookJP?o001o2OoonfX3o`00O`[ooo]Z0ol007lIoookJP?o001o0ooonfX3o`00O`cooo]Z
0ol007lIoookJP?o001o0ooonfX3o`00O`[ooo]Z1?l007l8oookJP?o001o7OoonfX4o`0002?ooo]Z
0ol007l3oookJP?o001o2_oonfX4o`00O`Sooo]Z0ol007lIoookJP?o001o0ooonfX3o`00O`cooo]Z
0ol007lIoookJP?o001o0ooonfX3o`00O`Wooo]Z0ol007l:oookJP?o001o9?oonfX00ol007oo0?on
o`00O`13oookJP;oo`0H00Cooo]Zo`00Ool007oo001o8_oonfX3o`00O`?ooo]Z0ol007l9oookJP?o
001o2_oonfX3o`00OaWooo]Z0ol007l3oookJP?o001o3?oonfX3o`00OaWooo]Z0ol007l3oookJP?o
001o2_oonfX4o`00O`Sooo]Z0ol007lMoookJPCo00008ooonfX3o`00O`?ooo]Z0ol007l:oookJPCo
001o2?oonfX3o`00OaWooo]Z0ol007l3oookJP?o001o3?oonfX3o`00OaWooo]Z0ol007l3oookJP?o
001o2OoonfX3o`00O`[ooo]Z0ol007lUoookJP03o`00Oooo01So001o01kooo]Z000XoookJP;oo`0H
0ol007lSoookJP?o001o0ooonfX3o`00O`[ooo]Z0_l007l5oookJP;o001o0_oonfX4o`00OaWooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007lIoookJP?o001o0ooonfX3o`00O`_ooo]Z
0ol007l3oookJP;o001o0_oonfX4o`00Oagooo]Z1?l0000SoookJP?o001o0ooonfX3o`00O`_ooo]Z
0ol007l3oookJP;o001o0_oonfX4o`00OaWooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z
1?l007lIoookJP?o001o0ooonfX3o`00O`[ooo]Z0_l007l5oookJP;o001o0_oonfX4o`00ObCooo]Z
00?o001oo`3oo_l007l0@ooonfX2ool06004oookJ_l007oo001oo`00Ob;ooo]Z0ol007l3oookJP?o
001o2_oonfX2o`00O`Gooo]Z0_l007l2oookJPCo001o6OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o0_oonfX4o`00OaWooo]Z0ol007l3oookJP?o001o2ooonfX3o`00O`?ooo]Z0_l007l2oookJPCo
001o7OoonfX4o`0002?ooo]Z0ol007l3oookJP?o001o2ooonfX3o`00O`?ooo]Z0_l007l2oookJPCo
001o6OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00OaWooo]Z0ol007l3oookJP?o
001o2_oonfX2o`00O`Gooo]Z0_l007l2oookJPCo001o9OoonfX00ol007ooo`0Ho`00O`0NoookJP00
:?oonfX2ool060?o001o8ooonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o1?oonfX7o`00Oa[ooo]Z
0ol007l3oookJP?o001o1ooonfX7o`00Oa[ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`;ooo]Z
1ol007lNoookJPCo00008ooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o0_oonfX7o`00Oa[ooo]Z
0ol007l3oookJP?o001o1ooonfX7o`00Oa[ooo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`Cooo]Z
1ol007lUoookJP03o`00Ool0ooko001o04?ooo]Z0_oo01P01?oonf[o001oo`00Ool007lRoookJP?o
001o0ooonfX3o`00O`[ooo]Z0ol007l4oookJPOo001o6_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo
001o6_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o0_oonfX7o`00Oakooo]Z1?l0000SoookJP?o
001o0ooonfX3o`00O`cooo]Z0ol007l2oookJPOo001o6_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo
001o6_oonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o1?oonfX7o`00ObKooo]Z00?o001oool06?l0
07l07_oonfX002Oooo]Z0_oo01P01?oonf[o001oo`00Ool007lSoookJP?o001o0ooonfX3o`00O`_o
oo]Z0_l007l4oookJPKo001o6ooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o6ooonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`;ooo]Z1_l007lOoookJPCo00008ooonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`;ooo]Z1_l007lKoookJP?o001o0ooonfX3o`00O`Oo
oo]Z1_l007lKoookJP?o001o0ooonfX3o`00O`_ooo]Z0_l007l4oookJPKo001o9_oonfX00ol007oo
o`0Ho`00O`12oookJP;oo`0H0_oonfX3o`00Ob;ooo]Z0ol007l3oookJP?o001o2ooonfX2o`00O`Co
oo]Z1_l007lKoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lKoookJP?o001o0ooonfX3o`00O`Ko
oo]Z0ol007l3oookJP?o001o0_oonfX6o`00Oaoooo]Z1?l0000SoookJP?o001o0ooonfX3o`00O`Ko
oo]Z0ol007l3oookJP?o001o0_oonfX6o`00Oa_ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa_o
oo]Z0ol007l3oookJP?o001o2ooonfX2o`00O`Cooo]Z1_l007lWoookJP03o`00Oooo01So001o01ko
oo]Z000WoookJP;oo`0H1?l007lSoookJP?o001o0ooonfX3o`00O`cooo]Z0_l007l3oookJP;o001o
7ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o
0ooonfX3o`00O`;ooo]Z0_l007lSoookJPGo00008_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o
0ooonfX3o`00O`;ooo]Z0_l007lOoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lOoookJP?o001o
0ooonfX3o`00O`cooo]Z0_l007l3oookJP;o001o9ooonfX4o`00O`03ool06?l007oooo]Z047ooo]Z
0_oo01P5o`00Ob;ooo]Z0ol007l3oookJP?o001o3?oonfX2o`00O`?ooo]Z0_l007lOoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007lOoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
0_oonfX2o`00Ob?ooo]Z1Ol0000RoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
0_oonfX2o`00Oaoooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oaoooo]Z0ol007l3oookJP?o001o
3?oonfX2o`00O`?ooo]Z0_l007lXoookJPCo001o00?oo`0Ho`00OooonfX07OoonfX002Oooo]Z0_oo
01P4o`00ObCooo]Z0ol007l01?oonf[o001oo`00Ool007l=oookJP;o001o0ooonfX2o`00Ob3ooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o8?oonfX3o`00O`04oookJ_l007oo001oo`00
O`Oooo]Z1?l007l2oookJP?o001o0_oonfX2o`00Ob?ooo]Z1?l0000ToookJP?o001o00Cooo]Zo`00
Ool007oo001o1ooonfX4o`00O`;ooo]Z0ol007l2oookJP;o001o8?oonfX3o`00O`04oookJ_l007oo
001oo`00O`Sooo]Z0_l007lPoookJP?o001o00Cooo]Zo`00Ool007oo001o3OoonfX2o`00O`?ooo]Z
0_l007lWoookJPCo001o00?oo`0Ho`00OooonfX0@OoonfX2ool060Go001o8ooonfX3o`00O`04oook
J_l007oo001oo`00O`gooo]Z0_l007l3oookJP;o001o8?oonfX3o`00O`04oookJ_l007oo001oo`00
O`Sooo]Z0_l007lPoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`00O`;ooo]Z0ol007l2
oookJP;o001o8ooonfX4o`0002Cooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPCo001o0_oo
nfX3o`00O`;ooo]Z0_l007lPoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Ob3ooo]Z
0ol007l01?oonf[o001oo`00Ool007l=oookJP;o001o0ooonfX2o`00ObSooo]Z1?l007l00ooo01So
001ooookJP0MoookJP009ooonfX2ool060Co001o9?oonfX7o`00O`Oooo]Z2Ol007l3oookJPOo001o
6_oonfX7o`00O`Wooo]Z1ol007lJoookJPOo001o2?oonfX7o`00O`Cooo]Z1ol007lMoookJPCo0000
9?oonfX7o`00O`Sooo]Z1ol007l4oookJPOo001o6_oonfX7o`00O`Wooo]Z1ol007lJoookJPOo001o
1ooonfX9o`00O`?ooo]Z1ol007lSoookJP;o001o00?oo`0Ho`00OooonfX0@OoonfX2ool06003oook
J_l007oo001o00;o001o8ooonfX7o`00O`Oooo]Z2Ol007l3oookJPOo001o6_oonfX7o`00O`Wooo]Z
1ol007lJoookJPOo001o2?oonfX7o`00O`Cooo]Z1ol007lMoookJPCo00009?oonfX7o`00O`Sooo]Z
1ol007l4oookJPOo001o6_oonfX7o`00O`Wooo]Z1ol007lJoookJPOo001o1ooonfX9o`00O`?ooo]Z
1ol007lToookJP04o`00Oooo01Soo`0Ho`00Oakooo]Z000WoookJP;oo`0H00Cooo]Zo`00Ool007oo
001o9OoonfX5o`00O`Sooo]Z2Ol007l3oookJPOo001o6ooonfX5o`00O`[ooo]Z1ol007lKoookJPGo
001o2_oonfX5o`00O`Gooo]Z1ol007lMoookJPCo00009OoonfX5o`00O`[ooo]Z1Ol007l5oookJPOo
001o6ooonfX5o`00O`[ooo]Z1ol007lKoookJPGo001o2?oonfX9o`00O`?ooo]Z1ol007lToookJP;o
o`0H00?o001ooookJ_oonfX0@?oonfX2ool060;ooo]Z0ol007lToookJPGo001o2?oonfX9o`00O`?o
oo]Z1ol007lKoookJPGo001o2_oonfX7o`00Oa_ooo]Z1Ol007l:oookJPGo001o1OoonfX7o`00Oago
oo]Z1?l0000UoookJPGo001o2_oonfX5o`00O`Gooo]Z1ol007lKoookJPGo001o2_oonfX7o`00Oa_o
oo]Z1Ol007l8oookJPWo001o0ooonfX7o`00ObGooo]Z0_oo01P00ol007oooo]ZoookJP0LoookJP00
9ooonfX2ool06=;ooo]Z1?l0003EoookJP;oo`0H@ooonfX2ool06=;ooo]Z1?l0003FoookJP;oo`0H
7ooonfX002Oooo]Z00?oo`0HoookJ_oonfX0dOoonfX4o`000=Gooo]Z0_oo01Q3oookJP03ool06?oo
nf[ooo]Z0=7ooo]Z1?l0003FoookJP;oo`0H7ooonfX002Oooo]Z00?oo`0HoookJ_oonfX0dOoonfX4
o`000=Gooo]Z0_oo01Q3oookJP03ool06?oonf[ooo]Z0=7ooo]Z1?l0003FoookJP;oo`0H7ooonfX0
02Oooo]Z00?oo`0HoookJ_oonfX0dOoonfX4o`000=Gooo]Z0_oo01Q3oookJP03ool06?oonf[ooo]Z
0=7ooo]Z1?l0003FoookJP;oo`0H7ooonfX002Kooo]Z0_oo01SCoookJPCo0000eOoonfX00ooo01So
oo]ZoookJP11oookJP;oo`0HdooonfX4o`000=Kooo]Z00?oo`0HoookJ_oonfX07_oonfX002Kooo]Z
0_oo01SCoookJPCo0000eOoonfX00ooo01Sooo]ZoookJP11oookJP;oo`0HdooonfX4o`000=Kooo]Z
00?oo`0HoookJ_oonfX07_oonfX002?ooo]Z0ol00002ool06?oo0000[Ol000000ooo01So0000o`00
000noookJP?o00000_oo01Soo`000:go00000_oo01P2o`0001kooo]Z000SoookJP?o00000_oo01So
o`000:go000000?oo`0Ho`000?l00000?_oonfX3o`0000;oo`0Hool0002]o`0000;oo`0H0_l0000N
oookJP008ooonfX3o`000003ool06?l0003o00000?oo0000[?l000000ooo01So0000o`00000noook
JP?o000000?oo`0Ho`000?l00000ool0002/o`0000;oo`0H0_l0000NoookJP008ooonfX3o`000003
ool06?l0003o00000?oo0000Zol00002ool060;o0000?_oonfX3o`000003ool06?l0003o00000?oo
0000[?l00002ool060;o00007_oonfX002Gooo]Z0_oo01PdoookJP03o`000?oonf[ooo]Z03?ooo]Z
00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0aoookJPCo0000=?oonfX00ol0003ooo]Z
oookJP0coookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<OoonfX2ool06003o`00
0?oonf[ooo]Z03oooo]Z0_oo01PdoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP0aoookJPCo0000=?oonfX00ol0003ooo]ZoookJP0doookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<OoonfX2ool06003o`000?oonf[ooo]Z01gooo]Z
000UoookJP03o`1Ooooo01Sooo]Z0=?ooo]Z1?l0003DoookJP;oo`0H@_oonfX2ool06=Cooo]Z1?l0
003EoookJP;oo`0H8?oonfX002Gooo]Z00?o05ooool06?oonfX0dooonfX4o`000=Cooo]Z0_oo01Q2
oookJP;oo`0He?oonfX4o`000=Gooo]Z0_oo01PPoookJP009OoonfX00ol0Goooo`0HoookJP3Coook
JPCo0000e?oonfX00ooo01Sooo]ZoookJP11oookJP;oo`0He?oonfX4o`000=Cooo]Z0_oo01PQoook
JP009OoonfX2o`1OomCooo]Z1?l0003DoookJP03ool06?oonf[ooo]Z047ooo]Z0_oo01SDoookJPCo
0000e?oonfX2ool0627ooo]Z000UoookJP;o05ooe?oonfX4o`000=?ooo]Z0_oo01Q3oookJP;oo`0H
e?oonfX4o`000=Cooo]Z0_oo01PQoookJP009OoonfX2o`1OomCooo]Z1?l0003CoookJP;oo`0H@ooo
nfX2ool06=Cooo]Z1?l0003DoookJP;oo`0H8OoonfX002Gooo]Z0_l0GooDoookJPCo0000dooonfX2
ool064?ooo]Z00?oo`0HoookJ_oonfX0dooonfX4o`000=Cooo]Z00?oo`0HoookJ_oonfX08?oonfX0
02Gooo]Z0_l0GooDoookJPGo0000d_oonfX2ool064?ooo]Z00?oo`0HoookJ_oonfX0dooonfX5o`00
0=?ooo]Z00?oo`0HoookJ_oonfX08?oonfX002Gooo]Z0ol0GooCoookJPCo0000dooonfX2ool064?o
oo]Z00?oo`0HoookJ_oonfX0dooonfX4o`000=Cooo]Z00?oo`0HoookJ_oonfX08?oonfX002Gooo]Z
0ol0GooCoookJPCo0000d_oonfX3ool064?ooo]Z00?oo`0HoookJ_oonfX0dooonfX4o`000=?ooo]Z
0_oo01PRoookJP009OoonfX3o`1Oom?ooo]Z1?l0003BoookJP;oo`0HA?oonfX00ooo01Sooo]Zoook
JP3CoookJPCo0000dooonfX2ool062;ooo]Z000UoookJP?o05oodooonfX4o`000=;ooo]Z0_oo01Q4
oookJP03ool06?oonf[ooo]Z0=?ooo]Z1?l0003CoookJP03ool06?oonf[ooo]Z027ooo]Z000Uoook
JP?o05oodooonfX4o`000=;ooo]Z0_oo01Q4oookJP03ool06?oonf[ooo]Z0=?ooo]Z1?l0003Coook
JP03ool06?oonf[ooo]Z027ooo]Z000UoookJPCo05ood_oonfX4o`000=;ooo]Z0_oo01SooookJQ_o
oo]Z1?l0003CoookJP03ool06?oonf[ooo]Z027ooo]Z000UoookJPCo05ood_oonfX4o`000=;ooo]Z
0_oo01SooookJQ_ooo]Z1?l0003CoookJP03ool06?oonf[ooo]Z027ooo]Z000UoookJPCo05ood_oo
nfX4o`000=7ooo]Z0ooo01SooookJQ_ooo]Z1?l0003BoookJP;oo`0H8ooonfX00?_ooo]Z1?l0003A
oookJP?oo`0HoooonfXKoookJPCo0000d_oonfX2ool062?ooo]Z000UoookJP03o`3oGOoonf[ooo]Z
0=?ooo]Z1Ol0003@oookJP;oo`0HoooonfXLoookJPGo0000dOoonfX00ooo01Sooo]ZoookJP0Roook
JP009OoonfX00ol0oegooo]ZoookJP3CoookJPCo0000dOoonfX2ool06?oooo]Z7?oonfX4o`000=;o
oo]Z00?oo`0HoookJ_oonfX08_oonfX002Gooo]Z00?o0?mMoookJ_oonfX0dooonfX4o`000=3ooo]Z
0ooo01SooookJQcooo]Z1?l0003AoookJP;oo`0H9?oonfX002Gooo]Z00?o0?mMoookJ_oonfX0dooo
nfX4o`000=3ooo]Z0_oo01SooookJQgooo]Z1?l0003AoookJP;oo`0H9?oonfX002Gooo]Z0_l0oegD
oookJPCo0000d?oonfX2ool06?oooo]Z7OoonfX4o`000=7ooo]Z00?oo`0HoookJ_oonfX08ooonfX0
02Gooo]Z0_l0oegDoookJPCo0000d?oonfX2ool06?oooo]Z7OoonfX4o`000=3ooo]Z0_oo01PUoook
JP009OoonfX2o`3oGMCooo]Z1?l0003@oookJP;oo`0HoooonfXMoookJPCo0000d?oonfX2ool062Go
oo]Z000UoookJP?o0?mMdooonfX4o`000<oooo]Z0ooo01SooookJQgooo]Z1?l0003@oookJP;oo`0H
9OoonfX002Gooo]Z0ol0oegCoookJPCo0000cooonfX3ool06?oooo]Z7OoonfX4o`000=3ooo]Z0_oo
01PUoookJP009OoonfX3o`3oGM?ooo]Z1?l0003?oookJP;oo`0HoooonfXNoookJPCo0000cooonfX2
ool062Kooo]Z000UoookJP?o0?mMdooonfX4o`000<oooo]Z0_oo01SooookJQkooo]Z1?l0003?oook
JP;oo`0H9_oonfX002Gooo]Z1?l0oegBoookJPGo0000cOoonfX3ool06?oooo]Z7_oonfX5o`000<ko
oo]Z0_oo01PVoookJP009OoonfX4o`3oGM;ooo]Z1?l0003>oookJP?oo`0HoooonfXNoookJPCo0000
c_oonfX3ool062Kooo]Z003koookJPCo0000c_oonfX2ool06?oooo]Z7ooonfX4o`000<kooo]Z0_oo
01PWoookJP009OoonfX00ooUo`3ooo]ZoookJP3CoookJPCo0000c_oonfX2ool06?oooo]Z7ooonfX4
o`000<kooo]Z0_oo01PWoookJP009OoonfX00ol0oegooo]ZoookJP3CoookJPCo0000cOoonfX3ool0
64Sooo]Z00?oo`0HoookJ_oonfX0dooonfX4o`000<gooo]Z0ooo01PWoookJP009OoonfX00ol0oego
oo]ZoookJP3CoookJPCo0000cOoonfX2ool064Wooo]Z00?oo`0HoookJ_oonfX0dooonfX4o`000<go
oo]Z0_oo01PXoookJP009OoonfX00ol0oegoiOl0oookJP3CoookJPCo0000cOoonfX2ool064Wooo]Z
00?oo`0HoookJ_oonfX0dooonfX4o`000<gooo]Z0_oo01PXoookJP009OoonfX00ol0oegoiOl0oook
JP3CoookJPCo0000c?oonfX2ool064[ooo]Z00?oo`0HoookJ_oonfX0dooonfX4o`000<cooo]Z0ooo
01PXoookJP009OoonfX00ol0oegoiOl0oookJP3CoookJPCo0000c?oonfX2ool064[ooo]Z00?oo`0H
oookJ_oonfX0dooonfX4o`000<cooo]Z0ooo01PXoookJP009OoonfX00ol0oegoiOl0onGo003Coook
JPCo0000c?oonfX2ool064[ooo]Z00?oo`0HoookJ_oonfX0dooonfX4o`000<cooo]Z0_oo01PYoook
JP009OoonfX00ol0oegoiOl0onGo003CoookJPCo0000c?oonfX00ooo01Sooo]ZoookJP19oookJP03
ool06?oonf[ooo]Z0=?ooo]Z1?l0003<oookJP;oo`0H:OoonfX002Gooo]Z00?o0?mMonGo0?oUo`00
dooonfX5o`000<[ooo]Z0_oo01Q;oookJP;oo`0He?oonfX5o`000<[ooo]Z0ooo01PYoookJP009Ooo
nfX01?l0oegoiOl0onGo0?oUo`3BoookJPCo0000booonfX2ool064_ooo]Z0_oo01SDoookJPCo0000
booonfX3ool062Wooo]Z000UoookJP04o`3oGOoUo`3oiOl0onGo0=;ooo]Z1?l0003;oookJP03ool0
6?oonf[ooo]Z04[ooo]Z0_oo01SDoookJPCo0000booonfX2ool062[ooo]Z000UoookJP04o`3oGOoU
o`3oiOl0onGo0=;ooo]Z1?l0003:oookJP;oo`0HC?oonfX2ool06=Cooo]Z1?l0003:oookJP?oo`0H
:_oonfX002Gooo]Z00?o0?mMonGo0?oUo`000_oUo`3AoookJPCo0000b_oonfX2ool064cooo]Z0_oo
01SDoookJPCo0000b_oonfX00ooo01Sooo]Zool0600ZoookJP009OoonfX00ol0oegoiOl0oookJP3C
oookJPCo0000bOoonfX2ool064gooo]Z0_oo01SDoookJPCo0000b_oonfX2ool062_ooo]Z000Uoook
JP03ool06?l0oegooo]Z0=?ooo]Z1?l00039oookJP;oo`0HCOoonfX2ool06=Cooo]Z1?l00039oook
JP?oo`0H:ooonfX002Gooo]Z00?oo`0Ho`3oGOoonfX0[OoonfX5o`00O`Cooo]Z0ol007l00ooonf[o
001oo`00O`07o`00O`?ooo]Z1Ol007l8oookJPCo0000bOoonfX00ooo01Sooo]ZoookJP1<oookJP;o
o`0H[_oonfX5o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`07o`00O`?ooo]Z1Ol007l8oookJPCo
0000bOoonfX2ool062cooo]Z000UoookJP03ool06?l0oegooo]Z0:cooo]Z1ol007l3oookJP?o001o
00?ooo]Zo`00Ool007l01ol007l2oookJPOo001o1ooonfX4o`000<Sooo]Z0_oo01Q?oookJP03ool0
6?oonf[ooo]Z0:_ooo]Z1ol007l3oookJP?o001o00?ooo]Zo`00Ool007l01ol007l2oookJPOo001o
1ooonfX4o`000<Wooo]Z0_oo01P/oookJP009_oonfX00ol0oegooo]ZoookJP2[oookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o1_oonfX4o`00O`04oook
J_l007oo001oo`00O`Oooo]Z1?l00038oookJP;oo`0HCooonfX00ooo01Sooo]ZoookJP2[oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o1_oonfX4o`00
O`04oookJ_l007oo001oo`00O`Oooo]Z1?l00038oookJP;oo`0H;OoonfX002Kooo]Z00?o0?mMoook
J_oonfX0Z_oonfX3o`00O`?ooo]Z0ol007l7oookJPCo001o1OoonfX3o`00O`?ooo]Z0ol007l6oook
JPCo0000b?oonfX00ooo01Sooo]ZoookJP1>oookJP03ool06?oonf[ooo]Z0:[ooo]Z0ol007l3oook
JP?o001o1ooonfX4o`00O`Gooo]Z0ol007l3oookJP?o001o1_oonfX4o`000<Sooo]Z0_oo01P]oook
JP009_oonfX00ol0oegooo]ZoookJP2ZoookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol007l9oookJP?o
001o1_oonfX6o`000<Gooo]Z0_oo01Q@oookJP03ool06?oonf[ooo]Z0:[ooo]Z0ol007l3oookJP?o
001o2?oonfX5o`00O`Wooo]Z0ol007l6oookJPKo0000a_oonfX2ool062gooo]Z000VoookJP03o`3o
GOoUo`3ooo]Z0:[ooo]Z0ol007l3oookJP?o001o2_oonfX4o`00O`Sooo]Z0ol007l6oookJPCo0000
aooonfX2ool0653ooo]Z0_oo01R[oookJP?o001o0ooonfX3o`00O`[ooo]Z1?l007l8oookJP?o001o
1_oonfX4o`000<Oooo]Z0_oo01P^oookJP009_oonfX00ol0oegoiOl0oookJP2ZoookJP?o001o0ooo
nfX3o`00O`_ooo]Z0ol007l3oookJP;o001o0_oonfX4o`00O`Kooo]Z1?l00037oookJP03ool06?oo
nf[ooo]Z04oooo]Z0_oo01R[oookJP?o001o0ooonfX3o`00O`_ooo]Z0ol007l3oookJP;o001o0_oo
nfX4o`00O`Kooo]Z1?l00037oookJP;oo`0H;_oonfX002Kooo]Z00?o0?mMonGo0?oonfX0Z_oonfX3
o`00O`?ooo]Z0ol007l<oookJP?o001o0_oonfX7o`00O`Oooo]Z1?l00036oookJP;oo`0HDOoonfX2
ool06:_ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`;ooo]Z1ol007l7oookJPCo0000a_oonfX2
ool062oooo]Z000VoookJP03o`3oGOoUo`3ooo]Z0:[ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00
O`?ooo]Z0ol007l2oookJPKo001o2?oonfX4o`000<Kooo]Z0_oo01QAoookJP;oo`0HZooonfX3o`00
O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`;ooo]Z1_l007l8oookJPCo0000a_oonfX2ool0
62oooo]Z000VoookJP03o`3oGOoUo`3ooo]Z0:[ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?o
oo]Z0ol007l2oookJP;o001o3?oonfX4o`000<Kooo]Z00?oo`0HoookJ_oonfX0D?oonfX2ool06:_o
oo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l2oookJP;o001o3?oonfX4o`000<Ko
oo]Z00?oo`0HoookJ_oonfX0;_oonfX002Kooo]Z00?o0?mMonGo0?oonfX0ZooonfX3o`00O`04oook
J_l007oo001oo`00O`Oooo]Z1?l007l2oookJP?o001o0_oonfX2o`00O`cooo]Z1?l00035oookJP;o
o`0HD_oonfX2ool06:cooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPCo001o0_oonfX3o`00
O`;ooo]Z0_l007l<oookJPCo0000aOoonfX2ool0633ooo]Z000VoookJP03o`3oGOoUo`3oo`0H0:_o
oo]Z1ol007l8oookJPOo001o1?oonfX7o`00O`Kooo]Z1?l00035oookJP;oo`0HD_oonfX3ool06:_o
oo]Z1ol007l8oookJPOo001o1?oonfX7o`00O`Kooo]Z1?l00035oookJP;oo`0H<?oonfX002Kooo]Z
00?oo`0HonGo0?oo01P0[?oonfX5o`00O`[ooo]Z1Ol007l5oookJPOo001o1_oonfX4o`000<Cooo]Z
0_oo01QCoookJP?oo`0H[?oonfX5o`00O`[ooo]Z1Ol007l5oookJPOo001o1_oonfX4o`000<Cooo]Z
0_oo01PaoookJP009_oonfX2ool06003onGo0?oonf[ooo]Z0=3ooo]Z1?l00034oookJP;oo`0HE?oo
nfX2ool06=;ooo]Z1?l00034oookJP;oo`0H<OoonfX002Oooo]Z00?oo`0HonGo0?oonfX0dOoonfX4
o`000<?ooo]Z0_oo01QEoookJP;oo`0Hd_oonfX4o`000<Cooo]Z00?oo`0HoookJ_oonfX0<?oonfX0
02Oooo]Z00?oo`0HonGo0?oonfX0dOoonfX5o`000<;ooo]Z0_oo01QEoookJP;oo`0Hd_oonfX5o`00
0<;ooo]Z0_oo01PboookJP009ooonfX00ooo01SoiOl0ool0603AoookJPCo0000`_oonfX2ool065Oo
oo]Z0_oo01SAoookJPCo0000`ooonfX00ooo01Sooo]ZoookJP0aoookJP00:?oonfX00ooUo`3oo`0H
oookJP3@oookJPCo0000`_oonfX2ool065Oooo]Z0_oo01SAoookJPCo0000`_oonfX2ool063?ooo]Z
000XoookJP03onGo0?oo01Sooo]Z0=3ooo]Z1?l00032oookJP03ool06?oonf[ooo]Z05Kooo]Z0_oo
01SAoookJPCo0000`_oonfX00ooo01Sooo]ZoookJP0boookJP00:?oonfX00ooUo`3oo`0HoookJP3@
oookJPCo0000`OoonfX2ool065Sooo]Z0_oo01SAoookJPCo0000`_oonfX00ooo01Sooo]ZoookJP0b
oookJP00:?oonfX00ooUo`3oo`0HoookJP3@oookJPCo0000`OoonfX2ool065Sooo]Z0_oo01SAoook
JPCo0000`OoonfX2ool063Cooo]Z000YoookJP03onGo0?oo01Sooo]Z0<oooo]Z1?l00030oookJP;o
o`0HF_oonfX2ool06=3ooo]Z1?l00030oookJP;oo`0H=OoonfX002Wooo]Z00?oiOl0ool06?oonfX0
cooonfX4o`000<3ooo]Z0_oo01QJoookJP;oo`0Hd?oonfX4o`000<3ooo]Z0_oo01PeoookJP00:Ooo
nfX00ooUo`3oo`0HoookJP3?oookJPCo0000_ooonfX3ool065[ooo]Z0_oo01S@oookJPCo0000_ooo
nfX3ool063Gooo]Z000YoookJP03onGo0?oo01Sooo]Z0<oooo]Z1?l0002ooookJP;oo`0HFooonfX2
ool06=3ooo]Z1?l0002ooookJP;oo`0H=_oonfX002Wooo]Z0_oo01S@oookJPCo0000__oonfX3ool0
65_ooo]Z0ooo01S?oookJPCo0000__oonfX3ool063Kooo]Z000ZoookJP;oo`0HcooonfX5o`000;go
oo]Z0_oo01QMoookJP;oo`0HcooonfX5o`000;gooo]Z0_oo01PgoookJP00:_oonfX2ool06<oooo]Z
1?l0002moookJP;oo`0HG_oonfX2ool06<oooo]Z1?l0002moookJP?oo`0H=ooonfX002[ooo]Z0_oo
01S?oookJPCo0000_OoonfX2ool065kooo]Z0ooo01S>oookJPCo0000_OoonfX2ool063Sooo]Z000Z
oookJP;oo`0HcooonfX4o`000;cooo]Z0_oo01QPoookJP;oo`0Hc_oonfX4o`000;cooo]Z0_oo01Pi
oookJP00:ooonfX00ooo01Sooo]ZoookJP3=oookJPCo0000_?oonfX2ool0663ooo]Z0_oo01S>oook
JPCo0000_?oonfX2ool063Wooo]Z000[oookJP;oo`0Hc_oonfX4o`000;_ooo]Z0_oo01QQoookJP;o
o`0Hc_oonfX4o`000;_ooo]Z0_oo01PjoookJP00:ooonfX2ool06<kooo]Z1?l0002koookJP03ool0
6?oonf[ooo]Z067ooo]Z0_oo01S=oookJPCo0000^ooonfX2ool063[ooo]Z000[oookJP;oo`0Hc_oo
nfX4o`000;[ooo]Z0_oo01QSoookJP;oo`0HcOoonfX4o`000;[ooo]Z0_oo01PkoookJP00:ooonfX2
ool06<kooo]Z1?l0002joookJP;oo`0HHooonfX2ool06<gooo]Z1?l0002joookJP;oo`0H>ooonfX0
02cooo]Z0_oo01S=oookJPCo0000^OoonfX2ool066Cooo]Z0_oo01S=oookJPCo0000^OoonfX2ool0
63cooo]Z000/oookJP;oo`0HcOoonfX5o`000;Sooo]Z0_oo01QUoookJP;oo`0Hc?oonfX5o`000;So
oo]Z0_oo01PloookJP00;?oonfX2ool06<gooo]Z1?l0002hoookJP;oo`0HI_oonfX2ool06<cooo]Z
1?l0002hoookJP;oo`0H?OoonfX002cooo]Z0ooo01S<oookJPCo0000]ooonfX3ool066Kooo]Z0_oo
01S<oookJPCo0000]ooonfX3ool063gooo]Z000]oookJP;oo`0Hc?oonfX4o`000;Oooo]Z0_oo01QW
oookJP?oo`0HbooonfX4o`000;Oooo]Z0_oo01PnoookJP00;OoonfX3ool06<_ooo]Z1?l0002foook
JP;oo`0HJOoonfX2ool06<_ooo]Z1?l0002foookJP;oo`0H?ooonfX002kooo]Z0_oo01S;oookJPCo
0000]_oonfX2ool066Wooo]Z0_oo01S;oookJPCo0000]_oonfX2ool063oooo]Z000^oookJP;oo`0H
booonfX4o`000;Gooo]Z0_oo01Q[oookJP03ool06?oonf[ooo]Z0<Wooo]Z1?l0002eoookJP;oo`0H
@?oonfX002kooo]Z0ooo01S:oookJPCo0000]?oonfX2ool066cooo]Z0_oo01S:oookJPCo0000]?oo
nfX3ool0643ooo]Z000_oookJP;oo`0Hb_oonfX4o`000;Cooo]Z0_oo01Q/oookJP;oo`0Hb_oonfX4
o`000;Cooo]Z0_oo01Q1oookJP00;ooonfX2ool06<[ooo]Z1?l0002coookJP;oo`0HKOoonfX2ool0
6<[ooo]Z1?l0002coookJP?oo`0H@OoonfX002oooo]Z0ooo01S9oookJPCo0000/ooonfX00ooo01So
oo]ZoookJP1]oookJP;oo`0HbOoonfX4o`000;?ooo]Z0_oo01Q2oookJP00<?oonfX2ool06<Wooo]Z
1Ol0002aoookJP;oo`0HKooonfX2ool06<Wooo]Z1Ol0002aoookJP?oo`0H@_oonfX0033ooo]Z0_oo
01S9oookJPCo0000/_oonfX00ooo01Sooo]ZoookJP1^oookJP;oo`0HbOoonfX4o`000;;ooo]Z0_oo
01Q3oookJP00<?oonfX3ool06<Sooo]Z1?l0002aoookJP;oo`0HLOoonfX2ool06<Sooo]Z1?l0002a
oookJP?oo`0H@ooonfX0037ooo]Z0_oo01S8oookJPCo0000/?oonfX2ool067;ooo]Z0_oo01S8oook
JPCo0000/?oonfX3ool064Cooo]Z000aoookJP?oo`0HaooonfX4o`000;3ooo]Z0_oo01QboookJP?o
o`0HaooonfX4o`000;3ooo]Z0ooo01Q4oookJP00<OoonfX3ool06<Oooo]Z1?l0002_oookJP;oo`0H
M?oonfX2ool06<Oooo]Z1?l0002_oookJP?oo`0HAOoonfX003;ooo]Z0_oo01S7oookJPCo0000[_oo
nfX2ool067Gooo]Z0ooo01S6oookJPCo0000[ooonfX2ool064Kooo]Z000boookJP?oo`0HZ_oonfX5
o`00O`Cooo]Z0ol007l3oookJPGo001o2?oonfX4o`000:kooo]Z00?oo`0HoookJ_oonfX0MOoonfX2
ool06:[ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Sooo]Z1?l0002^oookJP;oo`0HAooonfX0
03?ooo]Z0_oo01RYoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPCo0000[OoonfX00ooo
01Sooo]ZoookJP1foookJP;oo`0HZOoonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX4o`00
0:gooo]Z0_oo01Q8oookJP00<ooonfX3ool06:Sooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l7oookJPCo0000[?oonfX2
ool067Wooo]Z0_oo01RXoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`000:cooo]Z0ooo01Q8oookJP00=?oo
nfX2ool06:Oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000[?oo
nfX00ooo01Sooo]ZoookJP1hoookJP;oo`0HYooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooo
nfX3o`00O`Kooo]Z1?l0002/oookJP;oo`0HBOoonfX003Cooo]Z0_oo01RWoookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l6oookJPKo0000ZOoonfX2ool067_ooo]Z0_oo01RVoookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l6oookJPKo0000ZOoonfX2ool064[ooo]Z000eoookJP;oo`0HY_oonfX3o`00
O`?ooo]Z0ol007l<oookJP?o001o1_oonfX4o`000:[ooo]Z0_oo01QloookJP;oo`0HY_oonfX3o`00
O`?ooo]Z0ol007l<oookJP?o001o1_oonfX4o`000:[ooo]Z0ooo01Q:oookJP00=OoonfX2ool06:Ko
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l6oookJPCo0000Z_oonfX00ooo01So
oo]ZoookJP1loookJP03ool06?oonf[ooo]Z0:Cooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;o
oo]Z1?l007l6oookJPCo0000Z_oonfX2ool064_ooo]Z000foookJP;oo`0HYOoonfX3o`00O`?ooo]Z
0ol007l7oookJPOo001o1ooonfX4o`000:Wooo]Z0_oo01QnoookJP;oo`0HYOoonfX3o`00O`?ooo]Z
0ol007l7oookJPOo001o1ooonfX4o`000:Wooo]Z0_oo01Q<oookJP00=_oonfX2ool06:Gooo]Z0ol0
07l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1?l0002XoookJP;oo`0HOooonfX2ool06:Gooo]Z0ol0
07l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1?l0002XoookJP?oo`0HC?oonfX003Oooo]Z0_oo01RT
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPCo0000YooonfX3ool0683ooo]Z0_oo01RT
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPCo0000Z?oonfX2ool064gooo]Z000goook
JP;oo`0HYOoonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPCo0000Y_oonfX3
ool0687ooo]Z0_oo01RUoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1?l0
002WoookJP?oo`0HCOoonfX003Sooo]Z0_oo01RToookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0002V
oookJP;oo`0HPooonfX2ool06:Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`000:Kooo]Z0ooo01Q>
oookJP00>OoonfX00ooo01Sooo]ZoookJP2SoookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0002Uoook
JP;oo`0HQOoonfX00ooo01Sooo]ZoookJP2SoookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0002Uoook
JP?oo`0HCooonfX003Wooo]Z0_oo01S0oookJPCo0000Y?oonfX2ool068Kooo]Z0_oo01S0oookJPCo
0000YOoonfX2ool0653ooo]Z000joookJP03ool06?oonf[ooo]Z0;kooo]Z1?l0002SoookJP;oo`0H
R?oonfX00ooo01Sooo]ZoookJP2noookJPCo0000Y?oonfX2ool0657ooo]Z000joookJP;oo`0H_ooo
nfX5o`000:;ooo]Z0_oo01R8oookJP;oo`0H_ooonfX5o`000:;ooo]Z0_oo01QBoookJP00>ooonfX0
0ooo01Sooo]ZoookJP2moookJPCo0000X_oonfX2ool068[ooo]Z00?oo`0HoookJ_oonfX0_OoonfX4
o`000:;ooo]Z0ooo01QBoookJP00>ooonfX2ool06;kooo]Z1?l0002QoookJP;oo`0HRooonfX2ool0
6;kooo]Z1?l0002RoookJP;oo`0HDooonfX003_ooo]Z0_oo01RnoookJPCo0000X?oonfX3ool068_o
oo]Z0_oo01RnoookJPCo0000XOoonfX2ool065Cooo]Z000loookJP;oo`0H_OoonfX4o`0009oooo]Z
0ooo01R=oookJP;oo`0H_OoonfX4o`000:3ooo]Z0ooo01QDoookJP00??oonfX2ool06;gooo]Z1?l0
002OoookJP;oo`0HS_oonfX3ool06;cooo]Z1?l0002OoookJP?oo`0HEOoonfX003gooo]Z0_oo01Rl
oookJPCo0000W_oonfX3ool068oooo]Z0_oo01RloookJPCo0000W_oonfX3ool065Kooo]Z000moook
JP?oo`0H^ooonfX4o`0009gooo]Z0ooo01R@oookJP?oo`0H^ooonfX4o`0009gooo]Z0ooo01QGoook
JP00?_oonfX2ool06;_ooo]Z1?l0002LoookJP?oo`0HT_oonfX2ool06;_ooo]Z1?l0002MoookJP;o
o`0HF?oonfX003oooo]Z0_oo01RjoookJPCo0000VooonfX3ool069Cooo]Z0_oo01RjoookJPCo0000
W?oonfX2ool065Wooo]Z0010oookJP;oo`0H^OoonfX4o`0009[ooo]Z0ooo01RFoookJP;oo`0H^Ooo
nfX4o`0009_ooo]Z0_oo01QJoookJP00@?oonfX2ool06;Wooo]Z1Ol0002HoookJP?oo`0HUooonfX2
ool06;Wooo]Z1Ol0002IoookJP;oo`0HFooonfX0047ooo]Z0_oo01RhoookJPCo0000VOoonfX2ool0
69Wooo]Z0_oo01RhoookJPCo0000VOoonfX2ool065cooo]Z0011oookJP;oo`0H^?oonfX4o`0009So
oo]Z0_oo01RJoookJP?oo`0H]ooonfX4o`0009Sooo]Z0_oo01QMoookJP00@_oonfX2ool06;Oooo]Z
1?l0002GoookJP;oo`0HW?oonfX2ool06;Oooo]Z1?l0002GoookJP?oo`0HGOoonfX004;ooo]Z0ooo
01RfoookJPCo0000U_oonfX2ool069gooo]Z0ooo01RfoookJPCo0000UooonfX2ool065kooo]Z0013
oookJP;oo`0H]_oonfX4o`0009Gooo]Z0_oo01ROoookJP?oo`0H]OoonfX4o`0009Kooo]Z0_oo01QO
oookJP00@ooonfX3ool06;Gooo]Z1?l0002DoookJP;oo`0HX?oonfX3ool06;Gooo]Z1?l0002Eoook
JP;oo`0HH?oonfX004Cooo]Z0ooo01RdoookJPCo0000TooonfX2ool06:;ooo]Z0ooo01RdoookJPCo
0000U?oonfX00ooo01Sooo]ZoookJP1PoookJP00A?oonfX3ool06;Cooo]Z1?l0002BoookJP;oo`0H
XooonfX3ool06;Cooo]Z1?l0002CoookJP03ool06?oonf[ooo]Z067ooo]Z0015oookJP?oo`0H/ooo
nfX4o`00097ooo]Z0_oo01RUoookJP?oo`0H/ooonfX4o`0009;ooo]Z00?oo`0HoookJ_oonfX0H_oo
nfX004Kooo]Z0ooo01RboookJPGo0000SooonfX2ool06:Oooo]Z0ooo01RboookJPGo0000T?oonfX2
ool066Cooo]Z0017oookJP?oo`0H/OoonfX4o`0008oooo]Z0ooo01RXoookJP?oo`0H/OoonfX4o`00
093ooo]Z0_oo01QUoookJP00B?oonfX2ool06;7ooo]Z1?l0002>oookJP?oo`0HZ_oonfX2ool06;7o
oo]Z1?l0002?oookJP;oo`0HI_oonfX004Wooo]Z0_oo01R`oookJPCo0000SOoonfX3ool06:cooo]Z
0_oo01R`oookJPCo0000S_oonfX2ool066Oooo]Z0019oookJP?oo`0H[ooonfX4o`0008cooo]Z0ooo
01R^oookJP;oo`0H[ooonfX4o`0008gooo]Z0_oo01QXoookJP00B_oonfX3ool06:kooo]Z1?l0002;
oookJP?oo`0H[ooonfX3ool06:kooo]Z1?l0002<oookJP;oo`0HJOoonfX004_ooo]Z0_oo01R^oook
JPCo0000ROoonfX4ool06;7ooo]Z0_oo01R^oookJPCo0000R_oonfX3ool066[ooo]Z001;oookJP?o
o`0H[OoonfX4o`0008Sooo]Z1?oo01RcoookJP;oo`0H[OoonfX4o`0008Wooo]Z0ooo01Q[oookJP00
C?oonfX3ool06:cooo]Z1?l00027oookJP?oo`0H]_oonfX2ool06:cooo]Z1?l00028oookJP;oo`0H
KOoonfX004gooo]Z0ooo01R[oookJPCo0000Q_oonfX3ool06;Sooo]Z0_oo01R[oookJPCo0000Qooo
nfX2ool066kooo]Z001>oookJP;oo`0HZooonfX4o`0008Gooo]Z0ooo01RjoookJP03ool06?oonf[o
oo]Z0:Wooo]Z1?l00026oookJP;oo`0HKooonfX004oooo]Z0_oo01RZoookJPGo0000PooonfX3ool0
6;cooo]Z00?oo`0HoookJ_oonfX0Z?oonfX5o`0008Cooo]Z0_oo01Q`oookJP00D?oonfX2ool06:Wo
oo]Z1?l00023oookJP?oo`0H_OoonfX2ool06:Wooo]Z1?l00024oookJP;oo`0HLOoonfX0057ooo]Z
0_oo01RXoookJPCo0000P_oonfX3ool06;oooo]Z0_oo01RXoookJPCo0000PooonfX2ool067;ooo]Z
001BoookJP;oo`0HYooonfX4o`00087ooo]Z0ooo01S1oookJP;oo`0HYooonfX4o`0008;ooo]Z0_oo
01QcoookJP00D_oonfX3ool06:Kooo]Z1?l00020oookJP?oo`0H`_oonfX3ool06:Kooo]Z1?l00020
oookJP?oo`0HM?oonfX005?ooo]Z0ooo01RUoookJPCo0000OooonfX3ool06<Cooo]Z0ooo01RUoook
JPCo0000OooonfX3ool067Gooo]Z001DoookJP?oo`0HY?oonfX4o`0007gooo]Z1?oo01S6oookJP?o
o`0HY?oonfX4o`0007kooo]Z0ooo01QfoookJP00EOoonfX3ool067gooo]Z1Ol007l4oookJP?o001o
0ooonfX3o`00O`Oooo]Z1Ol007l8oookJPCo0000O?oonfX3ool06<Wooo]Z0ooo01QmoookJPGo001o
1?oonfX3o`00O`?ooo]Z0ol007l7oookJPGo001o2?oonfX4o`0007gooo]Z0_oo01QhoookJP00Eooo
nfX2ool067_ooo]Z1ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z1ol007l7oookJPCo0000Nooo
nfX3ool06<cooo]Z0_oo01QkoookJPOo001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPOo001o1ooo
nfX4o`0007_ooo]Z0ooo01QioookJP00F?oonfX2ool067[ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o0ooonfX3o`00O`Gooo]Z1?l007l01?oonf[o001oo`00Ool007l7oookJPCo0000
N_oonfX3ool06<kooo]Z0_oo01QjoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`?o
oo]Z0ol007l5oookJPCo001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`0007[ooo]Z0ooo01Qjoook
JP00F?oonfX3ool067Sooo]Z0ol007l3oookJP?o001o2OoonfX2o`00O`Gooo]Z0ol007l3oookJP?o
001o1_oonfX4o`0007Sooo]Z0ooo01SAoookJP;oo`0HN?oonfX3o`00O`?ooo]Z0ol007l9oookJP;o
001o1OoonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000NOoonfX2ool067cooo]Z001IoookJP?oo`0H
MooonfX3o`00O`?ooo]Z0ol007l9oookJP?o001o2_oonfX3o`00O`Kooo]Z1_l0001eoookJP?oo`0H
d_oonfX3ool067Oooo]Z0ol007l3oookJP?o001o2OoonfX3o`00O`[ooo]Z0ol007l6oookJPKo0000
M_oonfX2ool067gooo]Z001JoookJP?oo`0HM_oonfX3o`00O`?ooo]Z0ol007l9oookJP?o001o2_oo
nfX3o`00O`Kooo]Z1?l0001foookJP?oo`0He?oonfX3ool067Kooo]Z0ol007l3oookJP?o001o2Ooo
nfX3o`00O`[ooo]Z0ol007l6oookJPCo0000MooonfX2ool067kooo]Z001KoookJP?oo`0HMOoonfX3
o`00O`?ooo]Z0ol007l:oookJP;o001o1OoonfX2o`00O`;ooo]Z1?l007l6oookJPCo0000MOoonfX3
ool06=Kooo]Z0ooo01QeoookJP?o001o0ooonfX3o`00O`[ooo]Z0_l007l5oookJP;o001o0_oonfX4
o`00O`Kooo]Z1?l0001eoookJP?oo`0HOooonfX005cooo]Z0ooo01QdoookJP?o001o0ooonfX3o`00
O`[ooo]Z0ol007l4oookJPOo001o1ooonfX4o`0007?ooo]Z1?oo01SHoookJP?oo`0HM?oonfX3o`00
O`?ooo]Z0ol007l:oookJP?o001o1?oonfX7o`00O`Oooo]Z1?l0001doookJP?oo`0HP?oonfX005go
oo]Z1?oo01QboookJP?o001o0ooonfX3o`00O`_ooo]Z0_l007l4oookJPKo001o2?oonfX4o`0007;o
oo]Z1?oo01SJoookJPCoo`0HL_oonfX3o`00O`?ooo]Z0ol007l;oookJP;o001o1?oonfX6o`00O`So
oo]Z1?l0001coookJP?oo`0HPOoonfX005kooo]Z1?oo01QaoookJP?o001o0ooonfX3o`00O`cooo]Z
0_l007l3oookJP;o001o3?oonfX4o`00077ooo]Z1?oo01SLoookJPCoo`0HLOoonfX3o`00O`?ooo]Z
0ol007l<oookJP;o001o0ooonfX2o`00O`cooo]Z1?l0001boookJP?oo`0HP_oonfX0063ooo]Z0ooo
01QaoookJP?o001o00Cooo]Zo`00Ool007oo001o3OoonfX2o`00O`?ooo]Z0_l007l<oookJPCo0000
KooonfX4ool06>3ooo]Z0ooo01QaoookJP?o001o00Cooo]Zo`00Ool007oo001o3OoonfX2o`00O`?o
oo]Z0_l007l<oookJPCo0000L?oonfX3ool068Cooo]Z001QoookJP?oo`0HL?oonfX7o`00O`Oooo]Z
2Ol007l3oookJPOo001o1_oonfX4o`0006kooo]Z1?oo01SRoookJP?oo`0HL?oonfX7o`00O`Oooo]Z
2Ol007l3oookJPOo001o1_oonfX4o`0006oooo]Z0ooo01R5oookJP00H_oonfX3ool0673ooo]Z1Ol0
07l8oookJPWo001o0ooonfX7o`00O`Kooo]Z1?l0001/oookJPCoo`0HiOoonfX3ool0673ooo]Z1Ol0
07l8oookJPWo001o0ooonfX7o`00O`Kooo]Z1?l0001]oookJP?oo`0HQooonfX006?ooo]Z0ooo01RE
oookJPCo0000JooonfX3ool06>Wooo]Z0_oo01REoookJPCo0000K?oonfX3ool068Sooo]Z001Toook
JP?oo`0HU?oonfX4o`0006[ooo]Z0ooo01S[oookJP;oo`0HU?oonfX4o`0006_ooo]Z0_oo01R:oook
JP00IOoonfX3ool069?ooo]Z1Ol0001WoookJP?oo`0Hk_oonfX3ool069;ooo]Z1Ol0001XoookJP?o
o`0HRooonfX006Kooo]Z0ooo01RBoookJPCo0000IooonfX3ool06?3ooo]Z0ooo01RAoookJPCo0000
J?oonfX3ool068cooo]Z001WoookJPCoo`0HT?oonfX4o`0006Kooo]Z0ooo01SboookJP?oo`0HT?oo
nfX4o`0006Kooo]Z1?oo01R=oookJP00J?oonfX4ool068oooo]Z1?l0001ToookJPCoo`0Hm?oonfX4
ool068kooo]Z1?l0001UoookJPCoo`0HS_oonfX006[ooo]Z0ooo01R>oookJPCo0000H_oonfX4ool0
6?Sooo]Z0ooo01R=oookJPCo0000HooonfX4ool0693ooo]Z001[oookJPCoo`0HS?oonfX4o`00067o
oo]Z0ooo01SkoookJP?oo`0HS?oonfX4o`00067ooo]Z1?oo01RBoookJP00KOoonfX3ool068_ooo]Z
1?l0001OoookJPCoo`0Ho_oonfX3ool068[ooo]Z1?l0001PoookJP?oo`0HU?oonfX006oooo]Z0ooo
01R9oookJPCo0000G_oonfX3ool06?oooo]Z0_oonfX3ool068Wooo]Z1?l0001NoookJP?oo`0HU_oo
nfX0073ooo]Z0ooo01R8oookJPCo0000G?oonfX4ool06?oooo]Z1?oonfX3ool068Sooo]Z1?l0001L
oookJPCoo`0HUooonfX0077ooo]Z0ooo01R7oookJPCo0000F_oonfX4ool06?oooo]Z1ooonfX4ool0
68Kooo]Z1?l0001KoookJP?oo`0HVOoonfX007;ooo]Z1?oo01R5oookJPCo0000FOoonfX4ool06?oo
oo]Z2OoonfX4ool068Gooo]Z1?l0001IoookJPCoo`0HV_oonfX007?ooo]Z1?oo01R4oookJPGo0000
E_oonfX5ool06?oooo]Z2ooonfX4ool068Cooo]Z1Ol0001GoookJPCoo`0HVooonfX007Gooo]Z1?oo
01R2oookJPCo0000EOoonfX5ool06?oooo]Z3ooonfX4ool068;ooo]Z1?l0001FoookJPCoo`0HWOoo
nfX007Oooo]Z0ooo01R1oookJPCo0000DooonfX5ool06?oooo]Z4ooonfX3ool0687ooo]Z1?l0001D
oookJPCoo`0HWooonfX007Wooo]Z0ooo01QooookJPCo0000D_oonfX4ool06?oooo]Z5ooonfX3ool0
67oooo]Z1?l0001BoookJPCoo`0HXOoonfX007_ooo]Z0_oo01QnoookJPCo0000D?oonfX3ool06?oo
oo]Z7?oonfX3ool067gooo]Z1?l0001@oookJPCoo`0HXooonfX007gooo]Z0_oo01QloookJPCo0000
C_oonfX3ool06?oooo]Z8?oonfX2ool067cooo]Z1?l0001>oookJPCoo`0HYOoonfX007kooo]Z0_oo
01QkoookJPCo0000C?oonfX3ool06?oooo]Z8ooonfX3ool067[ooo]Z1?l0001<oookJPCoo`0HYooo
nfX007oooo]Z0ooo01QioookJPCo0000B_oonfX4ool06?oooo]Z9OoonfX4ool067Sooo]Z1?l0001:
oookJPGoo`0HZ?oonfX0087ooo]Z0ooo01QgoookJPCo0000B?oonfX4ool06?oooo]Z:OoonfX4ool0
67Kooo]Z1?l00019oookJPCoo`0HZ_oonfX008?ooo]Z0ooo01QeoookJPCo0000A_oonfX3ool06?oo
oo]Z;_oonfX4ool067Cooo]Z1?l00016oookJPCoo`0H[OoonfX008Gooo]Z0ooo01QcoookJPCo0000
A?oonfX3ool06?oooo]Z<_oonfX4ool067;ooo]Z1?l00014oookJPCoo`0H[ooonfX008Kooo]Z1?oo
01QaoookJPGo0000@OoonfX3ool06?oooo]Z=_oonfX4ool0673ooo]Z1Ol00011oookJPCoo`0H/Ooo
nfX008Sooo]Z1?oo01Q_oookJPCo0000@?oonfX4ool06?oooo]Z>?oonfX5ool066kooo]Z1?l00010
oookJPCoo`0H/ooonfX008[ooo]Z00Coo`0HoookJ_oo01Soo`0HKOoonfX4o`0003gooo]Z1Ooo01So
oookJScooo]Z00?oo`0HoookJ_oo01P00_oo01Q/oookJPCo0000?OoonfX6ool06;Cooo]Z002;oook
JP;oo`0H00?ooo]Zool06?oo01P0JooonfX4o`0003_ooo]Z1Ooo01SooookJSoooo]Z0_oo01P01?oo
nf[oo`0Hool06?oo01QZoookJPCo0000>ooonfX6ool06;Kooo]Z002=oookJPKoo`0HJ?oonfX4o`00
03Sooo]Z1_oo01SooookJT?ooo]Z1_oo01QXoookJPCo0000>?oonfX7ool06;Sooo]Z002@oookJPGo
o`0HI_oonfX4o`0003Gooo]Z1_oo01SooookJTWooo]Z1Ooo01QVoookJPCo0000=_oonfX6ool06;_o
oo]Z002CoookJPCoo`0HI?oonfX4o`0003;ooo]Z1_oo01SooookJToooo]Z1?oo01QToookJPCo0000
<ooonfX6ool06;kooo]Z002EoookJPCoo`0HH_oonfX4o`0002oooo]Z1_oo01SooookJUCooo]Z1Ooo
01QQoookJPCo0000<?oonfX6ool06<7ooo]Z002GoookJPCoo`0HH?oonfX4o`0002cooo]Z1?oo01P3
ooo90?oooo]ZF?oonfX5ool065oooo]Z1?l0000]oookJPKoo`0Ha?oonfX009[ooo]Z1?oo01QMoook
JPCo0000:OoonfX3ool060CoolT0oooonfYNoookJPCoo`0HGOoonfX4o`0002[ooo]Z1_oo01S7oook
JP00WOoonfX4ool065[ooo]Z1Ol0000UoookJP;oo`0H1?oob@3ooookJVGooo]Z1Ooo01QIoookJPGo
00009_oonfX6ool06<[ooo]Z002PoookJPGoo`0HE_oonfX4o`0002?ooo]Z00?oo`0Hooo90?oob@00
0_oob@02ool06?oooo]ZJ_oonfX5ool065Kooo]Z1?l0000ToookJPKoo`0HcOoonfX00:;ooo]Z1_oo
01QCoookJPCo00005?oonfX2ooo900[ooo]Z1?oob@001?l0o`coo`0Hool06?oo01SooookJVkooo]Z
1ooo01QBoookJPCo00008?oonfX8ool06<oooo]Z002ToookJPSoo`0HCooonfX4o`0001;ooo]Z1?oo
b@06oookJPCoolT000?oo`0Ho`3o3?l0o``00_l0o`cooookJW?ooo]Z2Ooo01Q>oookJPCo00007?oo
nfX9ool06=;ooo]Z002XoookJPSoo`0HBooonfX4o`00013ooo]Z1_oob@03oookJP?oolT01Ol0o`co
oookJW_ooo]Z2?oo01Q;oookJPCo00006OoonfX8ool06=Kooo]Z002[oookJPSoo`0HB?oonfX4o`00
00Kooo]Z0_l0o``6oookJPWoolT01Ol0o``00ooo01Sooo]ZoookJP3ooookJX7ooo]Z2?oo01Q7oook
JPCo00005OoonfX9ool06=Wooo]Z002^oookJPWoo`0HA?oonfX4o`0000?ooo]Z1Ol0o``4oookJPKo
olT01Ol0/?l3ool06?oooo]ZROoonfX8ool064Cooo]Z1?l0000AoookJP[oo`0Hg?oonfX00;7ooo]Z
2ooo01PdoookJP?o001o1?oonfX2o`2`o`;ooo]Z1?l000000ooonf[o0?l<o`3o3005o`3o30;ooo]Z
00?oolT0o`2`ool0/?l01Ol0/?l5ooo90?oooo]ZSooonfX:ool063Cooo]Z0ol007l8oookJPCo0000
3?oonfX<ool06=oooo]Z002foookJP_oo`0H;ooonfX3o`00O`03oookJ_l0/?oo0;3o00?o0;3o0_oo
nfX3o`0000Go0?l<1ol0/?l00ol0o`coolT0ooo9000:ooo90?oooo]ZTooonfX:ool062oooo]Z0ol0
07l8oookJPCo00001OoonfX=ool06>Gooo]Z002noookJP[oo`0H:?oonfX00ol007oo0;3oo`2`o`06
o`2`o`;ooo]Z00?o0?l<o`2`ool0/?l01Ol0/?l5o`3o30ooolT0oooonfZJoookJP[oo`0H:?oonfX3
o`00O`Sooo]Z0_l0000<ool06>gooo]Z0036oookJPgoo`0H6ooonfX>o`2`o`co0?l<oooonfZaoook
JPkoo`0H7?oonfX3o`00O`koo`0HmOoonfX00<_ooo]Z0_oo01P2oookJP[oo`0H4_oonfX?o`2`o`ko
0?l<oooonfZfoookJP;oo`0H0ooonfX:ool061;ooo]Z2_oo01P3oookJP?oo`0H1Ol0003eoookJP00
l?oonfX3o`00O`Sooo]Z1?l0003ooookJ^Cooo]Z0ol007l8oookJPCo0000mooonfX00?3ooo]Z0ol0
07l8oookJPCo0000oooonf[ToookJP?o001o2?oonfX4o`000?Oooo]Z003`oookJP?o001ooooonf[`
oookJP?o001ooooonfX4oookJP00l?oonfX3o`00Oooooo]Zl?oonfX3o`00Oooooo]Z1?oonfX00>go
oo]Z1_l007oooookJ^gooo]Z1_l007oooookJPCooo]Z003]oookJPKo001ooooonf[]oookJPKo001o
oooonfX4oookJP00kooonfX4o`00Oooooo]ZkooonfX4o`00Oooooo]Z1?oonfX00?3ooo]Z0ol007oo
oookJ_3ooo]Z0ol007oooookJPCooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oo
oo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[o
oookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00
oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[
oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Z
oooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooook
J_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z
003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooook
J^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooo
nf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oo
oo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]Zjooo
nfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oo
oo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[o
oookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00
oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[
oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Z
oooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooook
J_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z
003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooook
J^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooo
nf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oo
oo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00i_oonfX3o`00O`Gooo]Z1Ol0
07oooookJ^Kooo]Z0ol007l5oookJPGo001ooooonfX4oookJP00i_oonfX3o`00O`Cooo]Z1ol007oo
oookJ^Gooo]Z0ol007l4oookJPOo001ooooonfX3oookJP00i_oonfX3o`00O`?ooo]Z1?l007l01?oo
nf[o001oo`00Ool007oooookJ^Gooo]Z0ol007l3oookJPCo001o00Cooo]Zo`00Ool007oo001ooooo
nfX3oookJP00e_oonfX:o`00O`Kooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0003o
oookJ/[ooo]Z2_l007l6oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000mooonfX0
0=Kooo]Z2_l007l6oookJP?o001o2OoonfX3o`00O`Kooo]Z1_l0003ooookJ/Sooo]Z2_l007l6oook
JP?o001o2OoonfX3o`00O`Kooo]Z1_l0003eoookJP00i_oonfX3o`00O`Wooo]Z0ol007l6oookJPCo
0000oooonf[JoookJP?o001o2OoonfX3o`00O`Kooo]Z1?l0003goookJP00i_oonfX3o`00O`Cooo]Z
0_l007l2oookJPCo001o1_oonfX4o`000?oooo]Zf_oonfX3o`00O`Cooo]Z0_l007l2oookJPCo001o
1_oonfX4o`000?Oooo]Z003VoookJP?o001o1?oonfX7o`00O`Oooo]Z1?l0003ooookJ][ooo]Z0ol0
07l4oookJPOo001o1ooonfX4o`000?Oooo]Z003VoookJP?o001o1?oonfX6o`00O`Sooo]Z1?l0003o
oookJ][ooo]Z0ol007l4oookJPKo001o2?oonfX4o`000?Oooo]Z003SoookJPKo001o1?oonfX2o`00
O`cooo]Z1?l0003ooookJ]Oooo]Z1_l007l4oookJP;o001o3?oonfX4o`000?Oooo]Z003SoookJPKo
001o1?oonfX2o`00O`cooo]Z1?l0003ooookJ]Oooo]Z1_l007l4oookJP;o001o3?oonfX4o`000?Oo
oo]Z003UoookJPCo001o1OoonfX7o`00O`Kooo]Z1?l0003ooookJ]Wooo]Z1?l007l5oookJPOo001o
1_oonfX4o`000?Oooo]Z003VoookJP?o001o1OoonfX7o`00O`Kooo]Z1?l0003ooookJ][ooo]Z0ol0
07l5oookJPOo001o1_oonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX0
0?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oo
oo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0
003goookJP00looonfX9o`2`o`Co00003?oonfXFo`3o2Ooooo]Zc?oonfX5o`0000cooo]Z5_l0o`WD
oookJP00looonfXAo`2`ob[o0?l9oooonf[0oookJPCo000000?ooo]Zo`3o2Ol0o`T0;?l0o`W8oook
JP00i_oonfX=o`3o30oo0;3o0_l0o`TPoookJQGo0?l9oooonfZ^oookJQ3o0?l98OoonfXEo`3o2Kco
oo]Z003VoookJPko0?l<2ol0/?lboookJP_o0?l9oooonfZWoookJPCo0?l900?ooo]Zo`3o2Ol0o`T0
1Ol0o`T3o`0003;ooo]Z3?l0o`VioookJP00i_oonfX9o`3o30ko0;3o0_l0000hoookJPWo0?l9oooo
nfZOoookJP[o0?l91OoonfX4o`0003Sooo]Z2Ol0o`VfoookJP00hOoonfX6ooo900?o0?l<1Ol0/?l3
o`3o30;ooo]Z1ol0/?l4o`0003cooo]Z2_l0o`WooookJYGooo]Z2Ol0o`T;oookJPCo0000??oonfX:
o`3o2K7ooo]Z003IoookJP_oolT01_l0/?l6o`3o30Gooo]Z0ol0/?l3oookJPCo0000@OoonfX8o`3o
2Ooooo]ZSooonfX7o`3o2A3ooo]Z1?l00011oookJPSo0?l9[_oonfX00=Wooo]Z1_oob@05o`2`o`?o
olT01ol0o``7oookJP03o`2`oooonf[ooo]Z00?ooo]Z1?l00015oookJPOo0?l9oooonfZ7oookJPKo
0?l95_oonfX4o`0004Gooo]Z1ol0o`V[oookJP00f_oonfX2ooo900?o0;3o0_l0o``4ooo900;ooo]Z
1Ol0o``?oookJPCo0000BOoonfX6o`3o2Ooooo]ZP?oonfX6o`3o2A[ooo]Z1?l00019oookJPKo0?l9
Z?oonfX00=Sooo]Z00?o0?l9o`3o3?l0o``00_l0o``6ooo900Gooo]Z0ol0o``@oookJPCo0000C?oo
nfX6o`3o2Ooooo]ZN_oonfX6o`3o2Agooo]Z1?l0001=oookJPGo0?l9YOoonfX00=Gooo]Z1?l0o``0
0ooob@3o0?l9ooo90006ooo900Kooo]Z00?o0?l<oookJ_oonfX04?oonfX4o`00053ooo]Z1?l0o`Wo
oookJWGooo]Z1_l0o`TPoookJPCo0000D?oonfX5o`3o2J;ooo]Z003AoookJPCo0?l<0_oob@001?l0
o`Wooo]ZoookJ_oonfX5ooo901_ooo]Z1?l0001DoookJP?o0?l9oooonfY^oookJPOo0?l98ooonfX4
o`0005Cooo]Z1?l0o`VOoookJP00c_oonfX00ol0o`Wo0?l<o`3o3003ooo900Oooo]Z0ooob@0Moook
JPCo0000EooonfX4o`3o2Ooooo]ZIooonfX6o`3o2BOooo]Z1?l0001GoookJPCo0?l9W?oonfX00<co
oo]Z00?o0?l9ooo90?oob@000_oob@0;oookJP03ooo90?oonf[ooo]Z01cooo]Z1?l0001IoookJPGo
0?l9oooonfYRoookJPKo0?l9:OoonfX4o`0005Wooo]Z1Ol0o`VIoookJP00b_oonfX3ooo90003o`3o
2Ooonf[ooo]Z02_ooo]Z1Ol0001JoookJPGo0?l9oooonfYNoookJPGo0?l9;?oonfX5o`0005[ooo]Z
1Ol0o`VGoookJP00aooonfX3ooo900;o0?l9;ooonfX4o`0005gooo]Z1?l0o`WooookJU_ooo]Z1Ol0
o`T^oookJPCo0000GOoonfX5o`3o2IGooo]Z0034oookJP?oolT00_l0o`TboookJPCo0000H?oonfX4
o`3o2Ooooo]ZEOoonfX5o`3o2C7ooo]Z1?l0001PoookJPCo0?l9TooonfX00<7ooo]Z00?o0?l9ooo9
0?oob@000_l0o`TeoookJP?o00002Ol0/?mJoookJPGo0?l9oooonfY?oookJPGo0?l9=?oonfX4o`00
06;ooo]Z1Ol0o`V@oookJP00_ooonfX5o`3o2Bkooo]Z2Ol0o``3o`00013o0;3o3ooo0:m6oookJPGo
0?l9oooonfY;oookJPGo0?l9=_oonfX4o`0000_ooo]Z5?oo0:m5oookJPGo0?l9S_oonfX00;gooo]Z
1Ol0o`T`oookJPco0?l<3_l0/?lLool0[ckooo]Z0ol0o`WooookJTSooo]Z1Ol0o`ThoookJPCo0000
:Ooo0:lnoookJP?o0?l9SOoonfX00;cooo]Z1?l0o`TboookJP[o0?l<3Ol0/?lGoookJPgoo`2_>ooo
nfX3o`3o2Ooooo]ZAOoonfX4o`3o2CWooo]Z3Ooo0:lIoookJPgoo`2_>ooonfX3o`3o2H_ooo]Z002j
oookJPCo0?l9:?oonfX<ooo900?o0?l<1ol0/?l2o`3o3003o`000?l0/?oo0;3o00Ko0;3o9?oonfX8
ool0[cKooo]Z0ol0o`WooookJT;ooo]Z1?l0o`TeoookJPSoo`2_0ol0000/oookJPWoo`2_=OoonfX3
o`3o2H[ooo]Z002goookJPCo0?l9:ooonfX8ooo900Oo0;3o1ol0o``3o`0000Ko0;3o;?oonfX8ool0
[c;ooo]Z1?l0o`WooookJScooo]Z1?l0o`TboookJPOoo`2_1_oonfX4o`0003?ooo]Z2?oo0:laoook
JPCo0?l9QooonfX00;Gooo]Z1?l0o`T]oookJPCoolT01?l0/?l2o`3o30;oolT000?ooo]Zo`3o3?l0
o``01Ol0o``00ooonf[o0000o`000002o`0000?o0;3o1?oonfXNool0Ia;ooo]Z1ooo0:l`oookJPCo
0?l9oooonfXhoookJPCo0?l9;ooonfX7ool0[`_ooo]Z1?l00008oookJQgoo`1W4ooonfX7ool0[boo
oo]Z1?l0o`V5oookJP00]?oonfX3o`3o2Boooo]Z1Ol0o``5ooo900?ooo]Z1Ol0o``3oookJP05o`00
0?oo06Ooo`1Wool0Iol0/?l03ooo06L4oookJQKoo`1W4OoonfX6ool0[boooo]Z1?l0o`WooookJSGo
oo]Z0ol0o`T^oookJPKoo`2_3ooonfX00ol0003oo`1Wool0I`0Bool0I`Cooo]Z5Ooo06LAoookJPOo
o`2_;_oonfX4o`3o2H?ooo]Z002boookJP?o0?l9;?oonfX5o`3o30SoolT01OoonfX3o`3o3003oook
J_oo06Oo05oo00So05oo0_oo06LOoookJPgoo`1W3ooonfX7ool0[b_ooo]Z1?l0o`WooookJS;ooo]Z
0ol0o`T[oookJPOoo`2_4?oonfX<ool0Iakooo]Z3Ooo06L?oookJPSoo`2_:_oonfX4o`3o2H;ooo]Z
002`oookJPCo0?l9:OoonfX01?oo0:oo0?l<o`3o3?l0o``2ooo90004ool0[ooonf[ooo]ZoookJPKo
olT01_l03ol00ol0o`coo`1Wool0I`02ool0Ia3o05oo6_l0of08oookJP[oo`1W3_oonfX6ool0[b[o
oo]Z0ol0o`WooookJRoooo]Z0ol0o`TYoookJPOoo`2_3?oonfX;ool0I`Co00001_oonfXMo`3oH0Wo
oo]Z2Ooo06L>oookJPOoo`2_:OoonfX3o`3o2H7ooo]Z002_oookJP?o0?l9:?oonfX2ool0[`CoolT0
0ooonfX5o`0?o`?oolT000?o00ooo`3oGOl0oed01ol0oed3oookJPko05oo8Ol0of0;oookJPSoo`1W
2ooonfX5ool0[b[ooo]Z0ol0o`WooookJR_ooo]Z0ol0o`TXoookJPOoo`2_3?oonfX9ool0I`Cooo]Z
;Ol0of0;oookJPSoo`1W2ooonfX6ool0[bWooo]Z0ol0o`UooookJP00[OoonfX3o`3o2BSooo]Z1?oo
b@000ooo0:oooo]ZoookJP04oookJPGo00oo00CoolT0o`0?ool03ooo00oo3?l0oed<o`1Oo`03o`3o
H?l03ooo00oo00?o00oo4?oo^P07o`2go`03oookJ_l0of3o0?mP00co0?mP1_oonfX9ool0I`[ooo]Z
1?oo0:lYoookJP?o0?l9oooonfXWoookJP?o0?l9:?oonfX5ool0[`cooo]Z1ooo06L6oookJPoo0?mP
0_l0]olCoonj00Oo0;Oo00?ooo]Zo`3oH?l0of003?l0of07oookJPSoo`1W2_oonfX4ool0[bWooo]Z
0ol0o`UmoookJP00ZooonfX3o`3o2BKooo]Z1?oob@02ool0[`Gooo]Z1?l0ojd6o`0?o`?oiOl01ol0
oed?o`1Oo`Ko00oo7?oo^P07o`2go`03oookJ_l0of3o0?mP00Wo0?mP0ooonfX9ool0I`Wooo]Z1?oo
0:lWoookJPCo0?l9oooonfXSoookJP?o0?l99ooonfX5ool0[`cooo]Z1Ooo06L4oookJP_o0?mP0_l0
]olXoonj00So0;Oo2ol0of04oookJPSoo`1W2OoonfX4ool0[bOooo]Z1?l0o`UkoookJP00ZOoonfX3
o`3o2BGooo]Z00?oo`2_ooo90?oob@000ooo0:l:o`3o[@coiOl01_l0Gol6o`3oG@Oo05oo1Ol03olL
ofl0o`gookX00_l0]ol00ooonf[o0?mPo`3oH007o`3oH0Cooo]Z1ooo06L:oookJPCoo`2_9_oonfX4
o`3o2Ooooo]Z7ooonfX4o`3o2BGooo]Z1_oo0:l:oookJPGoo`1W1OoonfX9o`3oH0;o0;Oo3Ooo^P00
0ooonf[oK`3oofl0o`0Kofl0o`cookX00ol0]ol9o`3oH0Gooo]Z1ooo06L9oookJPCoo`2_9_oonfX4
o`3o2GWooo]Z002XoookJP?o0?l99?oonfX5ool0[`?ooo]Z2?l0ojd2o`0?o`OoiOl01Ol0Gol:o`3o
G@03o`0?ool0ojgo05oo00Co05oo1Ol03ol;ofl0o`_ooo]Z3om_0?l:oonj00?o0;Oo2?l0of05oook
JPKoo`1W2OoonfX4ool0[bGooo]Z1?l0o`WooookJQgooo]Z0ol0o`TUoookJPGoo`2_2OoonfX6ool0
I`Cooo]Z2?l0of000ol0]ooookX0oonj0006oonj00;ooo]Z4om_0?l;oookJQ3oK`3o2_oo^P02o`2g
o`So0?mP1OoonfX6ool0I`Wooo]Z1?oo0:lUoookJPCo0?l9N?oonfX00:Kooo]Z0ol0o`TToookJPCo
o`2_1_oonfX00onDo`3o0?n]o`3o[@02o`3o[@?o00oo0_l0ojd4onGo00?o05oo0ol0oed00ooUo`3o
00ooo`3oG@07o`3oG@Co0?n]0ol0Gol5o`0?o`;oK`3o8OoonfX9ofl0o`_ookX00_l0]ol6o`3oH0Go
oo]Z1_oo06L8oookJPGoo`2_9?oonfX3o`3o2Ooooo]Z6ooonfX2o`3o2BGooo]Z1?oo0:l9oookJPGo
o`1W1OoonfX6o`3oH0SookX01?oonfX<ofl0ob7ooo]Z2_m_0?l;oonj0003o`2gool0of3o0?mP00Go
0?mP1?oonfX6ool0I`Sooo]Z1Ooo0:lToookJP?o0?l9MooonfX00:Cooo]Z0ol0o`TToookJP?oo`2_
0_oonfX8oiCo00Co00oo1?l0ojd00ol0of3o0?mMo`3oG@03o`3oG@CoiOl000?o00ooo`3o[Ol0ojd0
1_l0oed4o`3o[@;oK`3o00?o05oooookJ_l03ol00_l03ol00ol0003ooo]ZoookJP0[oookJPOoK`3o
2?oo^P04o`2go`Co0?mP1OoonfX6ool0I`Oooo]Z1_oo0:lRoookJP?o0?l9oooonfXHoookJP?o0?l9
8ooonfX4ool0[`Wooo]Z1Ooo06L4oookJPGo0?mP00?o0;Oooonj0?oo^P001Ooo^P02oookJP[oK`3o
00?ooo]Zo`000?l000000_l0000]oookJPSoK`3o2?oo^P03o`2go`Go0?mP1?oonfX6ool0I`Oooo]Z
1_oo0:lRoookJP?o0?l9M_oonfX00:;ooo]Z0ol0o`TSoookJPCoo`2_2OnDo`03o`0?o`Co0?n]1Ol0
oed00ol0of3oiOl0onGo0005onGo00GoU?l00ol0oed4o`3o[@;ooo]Z1?l0ooh00ol03ooo0?ono`3o
oP02o`3ooP04oookJ_ooi03oon@0oooT01goo`3b4?oonfX7ofl0o`KookX01?l0]ol6o`3oH0?ooo]Z
1Ooo06L8oookJP;oo`2_00?ooo]Zool0[ooo0:l08_oonfX2o`3o2Ooooo]Z5OoonfX3o`3o2B;ooo]Z
1?oo0:l9oookJPGoo`1W0_oonfX6o`3oH0;o0;Oo1_oo^P0;ofl0o`Kooo]Z1?l00003oookJP;oon@0
7Ooo0?8AoookJPOoK`3o1_oo^P04o`2go`Go0?mP0ooonfX5ool0I`Sooo]Z0_oo0:l00ooonf[oo`2_
ool0[`0RoookJP;o0?l9MOoonfX00:7ooo]Z0ol0o`TRoookJP?oo`2_0ooonfX6oiCo00?o00oo0_l0
ojd00onDo`3oobP0o`3oH002o`3oG@;oiOl000Co0?mPo`3o[Ol0ojgo0?n]1OoUo`06oiCo0003ofl0
ool0oegooo]Z00?o0?n]1?oonfX3o`3ooQ?oo`3b2ooo08DBool0lPcooo]Z1_m_0?l6oonj00?o0;Oo
1_l0of02oookJPGoo`1W2?oonfX2ool0[`03oookJ_oo0:oooo]Z027ooo]Z0_l0o`WooookJQ?ooo]Z
0ol0o`TQoookJP?oo`2_2OoonfX5ool0I`;ooo]Z1_l0of07oonj00WoK`3o3?oonfXBool0lP_oo`25
4ooo0?8<oookJPGoK`3o00?ooo]Zoonj0?oo^P000ooo^P03o`2go`Ko0?mP0ooonfX4ool0I`Sooo]Z
0_oo0:l00ooonf[oo`2_oookJP0QoookJP;o0?l9M?oonfX009oooo]Z0ol0o`TRoookJP?oo`2_1_oo
nfX3oiCo00;o00oo0ol0ojd00onDo`3o0?n]onGo0003onGo0004o`3oH?oo:03o0?n]o`3o[@?oU?l0
00?oobP0onGo0?oUo`001_nDo`02oookJP?oA?l000?o0?n]odCo0?m4o`000om4o`0<ool0lPCo0?on
1ooo08D:oookJPcoo`252ooo0?8<oookJPKoK`3o1Ooo^P03o`2go`Go0?mP0ooonfX5ool0I`Oooo]Z
1?oo0:lQoookJP?o0?l9oooonfX?oookJP?o0?l98OoonfX3ool0[`Sooo]Z1_oo06L2oookJPGo0?mP
1_oo^P000ooonf[oK`3oofl0o`05ofl0o`_ooo]Z0_ooi00;ool0lP_oo`252ooonfX;ool0Q@coo`3b
3?oonfX5ofl0o`03oookJ_oo^P3ookX000;ookX00ol0]ol5o`3oH0?ooo]Z1Ooo06L7oookJPCoo`2_
8OoonfX3o`3o2G;ooo]Z002MoookJPCo0?l98OoonfX3ool0[`Cooo]Z1?oo:002oiCo00?o0?n]0_nD
o`03onGo00?o0?mP00?oobP0oiCo0?nDo`000_nDo`04oolX0003onGo0?nDo`3oU?l000?oU?l01?oo
nfX2odCo00Soo`3b3?l0oohOoookJPSoo`252_oo0?8:oookJPGoK`3o00?ooo]Zoonj0?oo^P000ooo
^P000ol0]ooo0?mPo`3oH003o`3oH0?ooo]Z1_oo06L6oookJP?oo`2_8OoonfX3o`3o2Ooooo]Z3?oo
nfX4o`3o2B3ooo]Z0ooo0:l8oookJPGoo`1W0_oonfX6o`3oH0GookX000?ooo]Zofl0oom_0?l01?m_
0?l7oookJP?oon@01ooo0?8;ool0QB7ooo]Z2?oo08D9ool0lP_ooo]Z1?m_0?l00ooonf[ookX0oonj
0003oonj0003o`2gool0of3o0?mP00?o0?mP1?oonfX5ool0I`Kooo]Z1?oo0:lPoookJP?o0?l9LOoo
nfX009cooo]Z0ol0o`TQoookJP?oo`2_00?ooo]ZoolX0?oo:0001_oo:003o`3o[@;oU?l00ooUo`03
o`3oH0CoU?l01_oo:0001?l0GoooogT0oomi0?ooN@03oiCo00;oogT02?oo0?85o`3ooP03odCo0?l0
ooko0?on00Oo0?on;?oonfX2ool0Q@Soo`3b2ooonfX4ofl0o`KookX000?o0;Ooo`3oH?l0of000ol0
of03oookJPCoo`1W1ooonfX3ool0[b7ooo]Z0_l0o`WooookJP[ooo]Z0ol0o`TPoookJP?oo`2_2?oo
nfX4ool0I`;ooo]Z1_l0of05oonj00;ooo]Z1Om_0?l7oookJPWoo`3b1?oo08D4oookJPCo0000;_oo
nfX3ool0Q@Ooo`3b2ooonfX5ofl0o`GookX000?o0;Ooo`3oH?l0of000ol0of03oookJPCoo`1W1ooo
nfX3ool0[b7ooo]Z0_l0o`U`oookJP00VooonfX3o`3o2Aoooo]Z1?oo0:l8oolX00?o0?n]00?oobP0
oiCo0?l0of000_oUo`03o`3oH0?oU?l00_oo:0000ol0ojgoobP0oolX0004oolX00;o05oo00CoogT0
o`2`ool0/?ooU?l00_l0/?l6ool0lP?o0?on1_m4o`000ooonf[o0?ono`3ooP05o`3ooS;ooo]Z0ooo
08D6ool0lP03oooT0?oonf[ooo]Z00Oooo]Z1Om_0?l5oonj0003o`2gool0of3o0?mP00Co0?mP0_oo
nfX4ool0I`Kooo]Z1?oo0:lPoookJP03o`3o2Ooonf[ooo]Z0?oooo]Z1ooonfX2o`3o2Aoooo]Z1?oo
0:l7oookJPGoo`1W00?ooo]Zo`3oH?l0of001?l0of05oonj0003oookJ_m_0?ooK`3o00CoK`3o1_oo
nfX9ool0lP?oo`252OoonfX4o`0003;ooo]Z1?oo08D5ool0lP03oooT0?oonf[ooo]Z00Sooo]Z1?m_
0?l5oonj0003o`2gool0of3o0?mP00Co0?mP0ooonfX3ool0I`Oooo]Z0ooo0:lPoookJP;o0?l9Kooo
nfX009[ooo]Z0ol0o`TNoookJPCoo`2_0_oonfX5oolX00?o0?n]0ooo:005o`3oH003oonj0?nDo`3o
U?l000;oobP000CoU?l0o`3o[Ol0ojgo0?n]1Ooo:007o`2`o`Coo`3b0_m4o`02oomi00OoA?l01?oo
nfX3o`3ooP?o0000=_oonfX4ool0Q@Goo`3b2OoonfX4ofl0o`GookX00_l0]ol4o`3oH0?ooo]Z1?oo
06L6oookJPCoo`2_7ooonfX2o`3o2Ooooo]Z1_oonfX2o`3o2Akooo]Z1?oo0:l6oookJPGoo`1W0_oo
nfX5o`3oH0KookX01_m_0?l6oookJPSoo`3b0_oo08D>oookJPCo0000=_oonfX4ool0Q@Goo`3b2Ooo
nfX5ofl0o`GookX000?o0;Ooo`3oH?l0of000ol0of03oookJP?oo`1W1ooonfX3ool0[aoooo]Z0ol0
o`U]oookJP00V?oonfX3o`3o2Aoooo]Z0ooo0:l5oookJP?oobP000?o0?n]oiCo0?oo:0000_oo:005
o`3oH0;ookX00_oo:002oiCo00;o00oo0ol0/?l3oolX00So0;3o00?oo`3bodCo0?ooN@001OooN@00
0ooonf[oA?l0odCo0003odCo00Kooo]Z00?o0?onoookJ_l000000ol0000joookJPCoo`251?oo0?80
0oooi03ooo]ZoookJP05oookJPGoK`3o1Ooo^P000ol0]ooo0?mPo`3oH002o`3oH0?ooo]Z1?oo06L6
oookJP?oo`2_7ooonfX2o`3o2Ooooo]Z0ooonfX3o`3o2Akooo]Z0ooo0:l6oookJPGoo`1W0_oonfX5
o`3oH0GookX01_m_0?l6oookJP03oooT0?oo0?;oo`3b00Coo`3b0_oo08DBoookJPCo0000>_oonfX4
ool0Q@Coo`3b00?oon@0oookJ_oonfX01_oonfX4ofl0o`KookX01?l0of04oookJPCoo`1W1_oonfX2
ool0[aoooo]Z0ol0o`U/oookJP00UooonfX3o`3o2Akooo]Z0ooo0:l6oookJP04ool0IonDo`3oU?l0
oiCo00?oobP01?l0of000ol0ojgookX0oolX0002oolX00?oU?l000?o00ooo`3oGOl0oed01?l0/?l0
0ooo:03o0;3oo`2`o`05o`2`o`SoogT00ooonfX3odCo00[ooo]Z2Ol0GolioookJP?oo`251?oo0?80
0oooi03ooo]ZoookJP05oookJPCoK`3o1Ooo^P02o`2go`?o0?mP0ooonfX4ool0I`Kooo]Z0ooo0:lN
oookJP;o0?l9oooonfX1oookJP;o0?l97_oonfX3ool0[`Oooo]Z1?oo06L2oookJPCo0?mP00?o0;Oo
oonj0?oo^P000_oo^P06ofl0o`Gooo]Z0_ooi006ool0lP;oo`255OoonfX5o`0003gooo]Z0ooo08D5
ool0lPOooo]Z1Om_0?l5oonj0004o`2gool0of3o0?mPo`3oH0?ooo]Z1Ooo06L6oookJP;oo`2_7_oo
nfX3o`3o2F_ooo]Z002EoookJP?o0?l97_oonfX3ool0[`Kooo]Z00?oo`1WoiCo0?nDo`000ooo:004
o`3oH0;o0?n]0ooo:005oiCo00;o0?n]0ol0oed:o`2`o`03o`1OooooN@3oogT000GoogT01?oonfX0
0om4o`3ooo]ZoookJP0:oookJQ3o05oo3_oohP0WoookJP?oo`251?oo0?87oookJPGoK`3o1?oo^P02
o`2go`?o0?mP0ooonfX3ool0I`Oooo]Z0_oo0:lNoookJP?o0?l9o?oonfX3o`3o2Agooo]Z1?oo0:l6
oookJPCoo`1W0_oonfX3o`3oH0;o0;Oo1?oo^P05ofl0o`Gooo]Z0_ooi005ool0lP;oo`256OoonfX4
o`0000Wooo]Z4_oohP0VoookJP?oo`251Ooo0?87oookJPCoK`3o1Ooo^P000ol0]ooo0?mPo`3oH002
o`3oH0;ooo]Z1?oo06L6oookJP;oo`2_7_oonfX4o`3o2FWooo]Z002DoookJP?o0?l97OoonfX3ool0
[`Kooo]Z00?oo`1WoiCo0?nDo`000ooo:004o`3oH005o`3o[Ooo:03oobP0oolX0?oo^P001OnDo`07
o`3o30So0;3o00?ooo]Zo`1Oool0Gol01OooN@09oookJP[o0?mM3_l0GolIoooR02;ooo]Z00?oo`25
ool0l_oo0?800_oo0?88oookJPCoK`3o0ooo^P02o`2go`Co0?mP0ooonfX3ool0I`Kooo]Z0_oo0:lN
oookJP?o0?l9n_oonfX2o`3o2Agooo]Z1?oo0:l6oookJPCoo`1W0_oonfX3o`3oH003o`2goooo^P3o
okX000;ookX01Om_0?l6oookJPKoo`3b00?oo`25oookJ_oonfX06ooonfX3o`0002Goon808OoonfX2
ool0Q@Coo`3b1ooonfX4ofl0o`CookX000?o0;Ooo`3oH?l0of000ol0of02oookJP?oo`1W1ooonfX2
ool0[akooo]Z0ol0o`UXoookJP00T_oonfX3o`3o2Agooo]Z1?oo0:l5oookJP?oU?l000?oobP0oook
J_oo:0000ol0of02oolX0005oonj0?oo:03ookX0oonj0?oo:0000_l03ol9o`3o30;o0;3o00?o0?l<
o`2`ool0/?l01?l0/?l2oookJP?o05oo0_ooN@0;oookJP[o0?mM2ol0GolJoookJP_oon807?oonfX0
0ooo08Goo`3bool0lP02ool0lPOooo]Z0om_0?l01?oonf[ookX0oonj0?oo^P02o`2go`?o0?mP0ooo
nfX3ool0I`Oooo]Z0_oo0:lMoookJP?o0?l9mooonfX3o`3o2Acooo]Z1?oo0:l6oookJP?oo`1W0ooo
nfX3o`3oH003o`2goooo^P3ookX000;ookX01?m_0?l6oookJPKoo`3b00?oo`25oookJ_oonfX07?oo
nfX<oooR01cooo]Z2ooohP0KoookJP03ool0QOoo0?;oo`3b00;oo`3b2?oonfX3ofl0o`CookX000?o
0;Ooo`3oH?l0of000_l0of03oookJP?oo`1W1_oonfX3ool0[agooo]Z0ol0o`UWoookJP00TOoonfX3
o`3o2Acooo]Z1?oo0:l5oookJP04ool0IonDo`3oobP0oolX00?ooo]Z0_l0of02oolX00?ookX00ooo
:003onGo00Ko0?l<0ol0/?l3o`3o30Go0;3o1?oonfX01?l0Gooooo]Zoomi0?oonfX;onGo00Co0?mM
1_l0Gol:o`0?ob7ooo]Z2OoohP0JoookJP;oo`251?oo0?86oookJP?oK`3o00?ooo]Zoonj0?oo^P00
0_oo^P001?l0]ooo0?mPo`3oH?l0of03oookJP?oo`1W1ooonfX2ool0[acooo]Z0ol0o`WeoookJP?o
0?l96ooonfX4ool0[`Kooo]Z0ooo06L3oookJP?o0?mP00Go0;Oooonj0?oo^P3ookX0oookJP04ofl0
o`Gooo]Z1_oo0?82ool0QA_ooo]Z1ooohP04o`0002Sooo]Z2?oohP0JoookJP;oo`251?oo0?87oook
JP?oK`3o1?oo^P000ol0]ooo0?mPo`3oH002o`3oH0?ooo]Z0_oo06L7oookJP?oo`2_7?oonfX3o`3o
2FKooo]Z002@oookJP?o0?l97?oonfX3ool0[`Kooo]Z00Goo`1WoolX0?oo:03oo`1WoookJP04o`3o
H004oolX0?oo^P3ookX0oonj00?oobP00_l0ojd4onGo00;o0?l<0ol0/?l4o`3o30;o0?mM0ol0/?l:
oookJPWoiOl01Ol0Gol9o`3ooPco00oo4_mEo`0@oookJPWoon805ooonfX2ool0Q@Coo`3b1_oonfX4
ofl0o`CookX000Co0;Ooo`3oH?l0of3o0?mP0ooonfX3ool0I`Kooo]Z0_oo0:lLoookJP;o0?l9m?oo
nfX2o`3o2Acooo]Z1?oo0:l6oookJP?oo`1W00?ooo]Zo`3oH?l0of000_l0of02o`2go`;ookX01Om_
0?l4oookJP03oooT0?oo0?;oo`3b00Coo`3b00?oo`25oookJ_oonfX05ooonfX6oooR00Kooo]Z1?l0
000:oookJQ;oEOl04OoonfX8oooR01Oooo]Z0ooo08D3ool0lPOooo]Z0om_0?l4oonj0003o`2gool0
of3o0?mP00;o0?mP0ooonfX2ool0I`Kooo]Z0ooo0:lLoookJP;o0?l9I_oonfX008oooo]Z0ol0o`TK
oookJP?oo`2_1_oonfX01Ooo06OoobP0oolX0?oo06Oooo]Z00Co0?mP00Co0;Oooonj0?oo^P3ookX0
1?oo:003oiCo00CoolT00_l0/?l6o`3o3005oookJ_l0oego0?mMoookJ_l0/?l02ooonfX4onGo00;o
0?mM0ol0Gol2onGo00?o0?n]4?l0oohPoeGo00cooo]Z1ooohP0FoookJP;oo`251?oo0?86oookJPCo
K`3o0ooo^P02o`2go`?o0?mP0_oonfX4ool0I`Kooo]Z0_oo0:lKoookJP;o0?l9l_oonfX2o`3o2Aco
oo]Z0ooo0:l6oookJP?oo`1W00?ooo]Zo`3oH?l0of000_l0of001?l0]ooookX0oonj0?oo^P05ofl0
o`Cooo]Z00?oon@0ool0l_oo0?800ooo0?82ool0QAKooo]Z1_oohP0;oookJPCo00000_oonfXSoeGo
00gooo]Z1_oohP0GoookJP;oo`250ooo0?87oookJP?oK`3o0ooo^P02o`2go`Co0?mP0_oonfX3ool0
I`Kooo]Z0_oo0:lLoookJP;o0?l9IOoonfX008kooo]Z0_l0o`TLoookJP;oo`2_1ooonfX2oolX0003
ool0Iooonf[o0?mP00?o0?mP00?oU?l0oonj0?oo^P000_oo^P03oolX00KoolT00ol0/?l7o`3o30;o
oo]Z00?o0?mMoookJ_oonfX02ooonfX5o`3oG@[oA?l03_l0ooh8o`0?oa?o0;Ko3?mEo`0<oookJPGo
on805OoonfX2ool0Q@Coo`3b00?oon@0oookJ_oonfX00ooonfX3ofl0o`CookX000?o0;Ooo`3oH?l0
of000_l0of02oookJP?oo`1W1_oonfX2ool0[a_ooo]Z0ol0o`W^oookJP?o0?l96ooonfX3ool0[`Ko
oo]Z0ooo06L00ooonf[o0?mPo`3oH002o`3oH003o`2goooo^P3ookX000;ookX01?m_0?l4oookJP03
oooT0?oo0?;oo`3b00?oo`3b00?oo`25oookJ_oonfX04_oonfX8oooR00_ooo]Z2omEo`0Jo`2fo`co
EOl03OoonfX5oooR01Gooo]Z0_oo08D3ool0lP03oooT0?oonf[ooo]Z00?ooo]Z0om_0?l01Ooonf[o
okX0oonj0?oo^P3o0;Oo00Go0?mP0_oonfX2ool0I`Kooo]Z0ooo0:lKoookJP;o0?l9I?oonfX008go
oo]Z0_l0o`TKoookJP?oo`2_1_oonfX2oolX0003ool0Iooonf[ooo]Z00Co0?mP1?oo^P02o`3o[@Ko
olT00ol0/?l01?l0o`coolT0ooo90?oUo`04o`3o30kooo]Z00Coon80o`3oGOl0oego0?mM0_oUo`03
oiCo00[oA?l02ol0ooh00ol03ooo0?o_o`3ok`0Mo`3ok`?oolT01?l0]_l8oeGo0003ooo90?oonf[o
oo]Z00Sooo]Z1?oohP0DoookJP;oo`251Ooo0?85oookJP?oK`3o1?oo^P001?l0]ooo0?mPo`3oH?l0
of03oookJP;oo`1W1_oonfX3ool0[a[ooo]Z0ol0o`W/oookJP?o0?l96_oonfX3ool0[`Kooo]Z0ooo
06L2oookJPCo0?mP1?oo^P04ofl0o`Cooo]Z00?oon@0ool0l_oo0?800_oo0?82ool0QA;ooo]Z2?oo
hP0;oookJPOoEOl01Ol0]_l00ooo08Ko0?o_o`3ok`0Po`3ok`?o0;Ko2?mEo`0<oookJPCoon805?oo
nfX2ool0Q@Coo`3b1OoonfX3ofl0o`CookX000?o0;Ooo`3oH?l0of000_l0of02oookJP;oo`1W1ooo
nfX3ool0[a[ooo]Z0_l0o`USoookJP00RooonfX3o`3o2A[ooo]Z0ooo0:l6oookJP;oobP00_oo06L0
0ooonf[o0?mPo`3oH002o`3oH004oiCo0?oo^P3ookX0oonj00;o0?n]00?oU?l0oolX0?oob@001?oo
b@000ol0/?oo0?l<o`3o3003ooo900;oiOl00ol0o``<oookJP?oon801?oUo`02oookJP03oiCo0?oo
N@3oogT000GoA?l01Ol0ooh00om4o`3o0?ono`3ooP06o`3ooP_o0?o_2_oonfX@o`3ok`;oiOl00_oo
b@000ooo08Ko0;Koo`2fo`03o`2fo`KoEOl02_oonfX5oooR01?ooo]Z00?oo`25ool0l_oo0?800ooo
0?85oookJP?oK`3o1?oo^P03o`3oH0?ooo]Z0ooo06L5oookJP?oo`2_6_oonfX3o`3o2NWooo]Z0ol0
o`TJoookJPCoo`2_1OoonfX4ool0I`03oookJ_l0of3o0?mP00;o0?mP00Co0;Oooonj0?oo^P3ookX0
0om_0?l5oookJP03oooT0?oo0?;oo`3b00;oo`3b00?oo`25oookJ_oonfX04?oonfX7oooR00Wooo]Z
1omEo`02o`2foa7o0?o_2ooonfXDo`3ok`Go0;Ko1_mEo`0;oookJPCoon804ooonfX00ooo08Goo`3b
ool0lP03ool0lPGooo]Z0om_0?l4oonj00Co0?mP0ooonfX2ool0I`Kooo]Z0ooo0:lJoookJP;o0?l9
H_oonfX008[ooo]Z0ol0o`TIoookJPCoo`2_1OoonfX01Ooo06OoobP0ool0Iooo06Oooo]Z00Co0?mP
00Go0;Oooonj0?oo^P3ookX0o`3o[@02oiCo00?oobP000?ooo]Zooo90?oob@000ol0o``4ooo900?o
iOl000?ooo]Zo`3o3?oonfX02_oonfX2oooR00;oiOl02OooN@06o`3ooPGoA?l000?o0?o_o`3oo_l0
ooh01?l0ooh2o`3ok`Wo00oo1ooonfX:ool0@@_ooo]Z1OoUo`02ooo900?o0?l<00Coo`26ooo90?oo
b@3oolT01omEo`000ol0o`cooo]ZoookJP05oookJPGoon804_oonfX00ooo08Goo`3bool0lP02ool0
lPGooo]Z0om_0?l5oonj00?o0?mP0ooonfX3ool0I`Gooo]Z0_oo0:lJoookJP?o0?l9iooonfX3o`3o
2AWooo]Z1?oo0:l5oookJPCoo`1W0_oonfX3o`3oH004o`2goooo^P3ookX0oonj00?oK`3o1OoonfX0
0oooi03oo`3bool0lP02ool0lP03ool0QOoonf[ooo]Z013ooo]Z1_oohP04oookJP?o001o1_mEo`03
o`2fo`;oo`262_l0onl00ol0003ooo]ZoookJP0<oookJP[oo`112ooonfX:o`3ok`04ool0Q_l0]_oo
0;Koo`2fo`OoEOl02OoonfX4oooR01;ooo]Z00?oo`25ool0l_oo0?800_oo0?85oookJPCoK`3o1?oo
^P03o`3oH0?ooo]Z0ooo06L5oookJP?oo`2_6_oonfX2o`3o2F7ooo]Z0029oookJP;o0?l96_oonfX3
ool0[`Kooo]Z0ooo06L00ooonf[o0?mPo`3oH002o`3oH005o`2goooo^P3ookX0oonj0?oo:0000_nD
o`04oolX00;ooo]Z0_l0o``6ooo900;ooo]Z00?oiOl0oookJ_oonfX02OoonfX01?oohP3oiOl0onGo
0?oUo`03oolX00KoogT00ol0ooh00om4o`3oogT0odCo0006odCo00?o0?o_0ol0ooh00ol0ojgo00oo
o`0?o`0=o`0?o`go04;o1?oUo`000ol0@_ooo`11ool0@@04ool0@@;ooo]Z1ooUo`001?l0onooolT0
o`3oGOl0oed2o`3o30CoolT02OmEo`06oookJPGoon804OoonfX00ooo08Goo`3bool0lP02ool0lPGo
oo]Z0om_0?l4oonj00?o0?mP0ooonfX3ool0I`Gooo]Z0_oo0:lJoookJP?o0?l9iOoonfX3o`3o2AWo
oo]Z1?oo0:l5oookJP?oo`1W0_oonfX3o`3oH004o`2goooo^P3ookX0oonj00CoK`3o1OoonfX4ool0
lP03ool0QOoonf[ooo]Z013ooo]Z1OoohP06oookJPKoEOl00_l0]_l:o`3ok`Cooo]Z0_l0000;ool0
@A;o04;o1_oo0448oookJPSo0?o_00Coo`26o`2fool0]_oo0;Ko2?mEo`06oookJPGoon804OoonfX0
0ooo08Goo`3bool0lP02ool0lPGooo]Z1?m_0?l3oonj00?o0?mP0ooonfX3ool0I`Kooo]Z00?oo`2_
oookJ_oonfX06OoonfX2o`3o2F3ooo]Z0028oookJP;o0?l96_oonfX2ool0[`Kooo]Z0ooo06L00ooo
nf[o0?mPo`3oH003o`3oH0?ookX000?oobP0oiCo0?nDo`001Ooo:0000ooonf[o0?l<o`3o3007ooo9
00gooo]Z00?oon80onGo0?oUo`000_oohP001?oonf[oobP0oolX0?oo:002oomi00CoA?l01OooN@06
odCo00Co0?n]00Co0?ono`3o[Ol0ojgo0?n]1_l03ol7o`12o`Co0?mM1_l0@_l01?l0GoooolT0ooo9
0?oob@05o`12o`GoiOl00ol0oed00ol0@_ooiOl0onGo0007onGo00Co0?mM0ol0o``2o`2`o`;oolT0
00?o0?l<oeGo0?mEo`001_mEo`06oookJPCoon804OoonfX00ooo08Goo`3bool0lP02ool0lPGooo]Z
0_m_0?l4oonj0004o`2gool0of3o0?mPo`3oH0;ooo]Z0ooo06L5oookJP?oo`2_6OoonfX3o`3o2NCo
oo]Z0_l0o`TIoookJP?oo`2_1OoonfX3ool0I`;ooo]Z1?l0of000ol0]ooookX0oonj0004ofl0o`Go
oo]Z1?oo0?800ooo08Gooo]ZoookJP0?oookJPGoon801_oonfX6oeGo00;o0;Ko2?l0onl2o`00O`Co
oo]Z1ooo044So`12o`Koo`111?oonfX9o`3ok`;o0;Ko2?mEo`06oookJPCoon804OoonfX00ooo08Go
o`3bool0lP02ool0lPGooo]Z0om_0?l3oonj0004o`2gool0of3o0?mPo`3oH0?ooo]Z0ooo06L5oook
JP;oo`2_6OoonfX3o`3o2Eoooo]Z0027oookJP;o0?l96_oonfX2ool0[`Gooo]Z1?oo06L5o`3oH0?o
okX000?ooo]ZoiCo0?nDo`001Ooo:003o`3o3004ooo90?oo08Goo`25oookJPCoolT02ooonfX5oooR
00Go001o1?m4o`07oomi00?o0?o_0om4o`000onDo`3o0?n]o`3o[@04o`3o[@Oo04;o1OoUo`03o`0?
o`03oookJ_l0oego0?mM00Oo0?mM00?ooo]Zo`1Ooooob@001_oob@02oookJP?o0?l<0ooonfX00ooU
o`3o0?mMo`3oG@03o`3oG@05onGo0?l0Gooo05ooo`1OoooUo`001_l0oed00ooob@3o0?l<o`3o3002
o`1Oo`04o`2`ool0o`co0?l<o`3o30OoEOl01_oonfX3oooR017ooo]Z0_oo08D4ool0lPCooo]Z0om_
0?l3oonj0003o`2gool0of3o0?mP00;o0?mP0_oonfX2ool0I`Gooo]Z0ooo0:lIoookJP?o0?l9h_oo
nfX00ol0o`Wooo]ZoookJP0HoookJP?oo`2_1?oonfX4ool0I`03oookJ_l0of3o0?mP00;o0?mP00Co
0;Oooonj0?oo^P3ookX00om_0?l4oookJPGoo`3b00?oo`25oookJ_oonfX03ooonfX4oooR00Go001o
1omEo`02o`2fo`Ko0?o_0_l007l3oookJP03o`00Oooo047oo`1100;oo`112ol0@_lOoookJP[o04;o
00?oo`11oookJ_oonfX00ooonfX7o`3ok`?o0;Ko1_mEo`07oookJP?oon804OoonfX00ooo08Goo`3b
ool0lP02ool0lPCooo]Z0om_0?l01Ooonf[ookX0oonj0?oo^P3o0;Oo00?o0?mP0_oonfX3ool0I`Go
oo]Z0_oo0:lIoookJP?o0?l9G_oonfX008Kooo]Z0_l0o`TIoookJP?oo`2_1OoonfX3ool0I`03oook
J_l0of3o0?mP00;o0?mP0ooo^P001Ooonf[oU?l0oiCo0?oo:03ooo]Z00?oobP000Coo`3bo`3o3?oo
b@3oolT00_oo08D3oookJP?oolT02_oonfX4oooR00Go001o00?oEOl0odCo0?m4o`000_ooN@000onD
o`3oogT0oomi0005oomi0006o`3okonDo`3oU?l0oiCo0?m4o`3oU?l00_l0ojd2o`0?o`So04;o0ol0
3ol9onGo00[o0?mM00?o05ooooo90?oob@001ooob@06o`3o3003oookJ_oUo`3oiOl000;o0;3o00?o
iOl0o`3oGOl0oed00_l0oed3o`1Oo`Ko0?mM00?oolT0o`1Oool0Gol00_l0Gol2o`2`o`Co0?l<1OmE
o`07oookJP?oon804?oonfX2ool0Q@Coo`3b0ooonfX3ofl0o`?ookX00_l0]ol3o`3oH0;ooo]Z0_oo
06L5oookJP?oo`2_6OoonfX2o`3o2N3ooo]Z0_l0o`TJoookJP;oo`2_1OoonfX3ool0I`;ooo]Z0ol0
of001?l0]ooookX0oonj0?oo^P04ofl0o`?ooo]Z1Ooo0?800ooo08Gooo]ZoookJP0>oookJPCoon80
1Ol007l6oeGo00;o0;Ko00?oo`26o`3okol0onl00ol0onl3oookJP?o001o1?oo0448o`12o`Ko0000
9_oonfX8o`12o`03ool0@Ooonf[ooo]Z00?ooo]Z1_l0onl00ooo08Ko0;Koo`2fo`05oeGo00Oooo]Z
1?oohP0@oookJP03ool0QOoo0?;oo`3b00;oo`3b0ooonfX3ofl0o`05oookJ_oo^P3ookX0oonj0?l0
]ol00ol0of02oookJP?oo`1W1OoonfX2ool0[aWooo]Z0_l0o`UNoookJP00QOoonfX2o`3o2AWooo]Z
0_oo0:l5oookJP?oo`1W0_oonfX3o`3oH004o`2goooo^P3ookX0oonj00;oU?l000?oobP0oookJ_oo
nfX00_oonfX01?ooi03oo`3booo90?oob@02ool0Q@Kooo]Z00?oolT0oookJ_oonfX01_oonfX4oooR
00Kooo]Z00CoEOl0oomi0?ooN@3oogT00_nDo`000ooo:03o0?o_oomi0004oomi00CoU?l00_l0ojd0
0ol03ooo04;oo`12o`05o`12o`;o0?n]1ol0ooh6onGo00Ko05oo1Oooh`06o`3o30KoolT02Ol0o``5
o`2`o`;oiOl00ol0oed3o`1Oo`Co0?mM1Ol0Gol00ol0o`co0;3oo`2`o`03o`3o30;o0;3o1?mEo`07
oookJP?oon803ooonfX2ool0Q@Coo`3b1?oonfX2ofl0o`05oookJ_oo^P3ookX0oonj0?oonfX00ol0
of02oookJP;oo`1W1_oonfX3ool0[aSooo]Z0_l0o`WNoookJP;o0?l96OoonfX3ool0[`Cooo]Z1?oo
06L2oookJP;o0?mP0_l0]ol2oonj00CoK`3o0ooonfX00oooi03oo`3bool0lP02ool0lP03ool0QOoo
nf[ooo]Z00kooo]Z0ooohP06oookJPGoEOl00_l0]_l5o`3ok`05oookJ_l007oo001oo`00OooonfX0
0ooo0447o`12o`03o`00Oooonf[ooo]Z00Cooo]Z1?l000000ooonf[oog@0oomd0007oomd00_oon<0
1_ooM00AoookJPSo04;o0_oo0444oookJPCo0?o_0_oo08H2o`2fo`GoEOl01_oonfX4oooR00oooo]Z
00?oo`25ool0l_oo0?800_oo0?84oookJP?oK`3o1?oo^P03o`3oH0?ooo]Z0_oo06L5oookJP?oo`2_
6?oonfX2o`3o2Egooo]Z0024oookJP;o0?l96?oonfX3ool0[`Cooo]Z1?oo06L2oookJP?o0?mP0ooo
^P000om_0?ooU?l0oolX0005oookJP03ool0l_oob@3oolT000;oo`253ooonfX4oooR00Kooo]Z0ooo
N@000onDo`3oobP0oolX0004o`3ok`03oolX0?ooN@3oogT000Co0?n]1ol0@_l00onDo`3ooo]Zo`3o
[@04o`3o[@;o0?on0_ooM006o`3oG@Goon<03ooob@03o`3o30Co0;3o2?l0o``7o`2`o`Ko0?mM2ol0
Gol00ol0o`co0;3oo`2`o`05o`2`o`GoEOl01_oonfX3oooR00oooo]Z0_oo08D3ool0lPCooo]Z0om_
0?l4oonj00?o0?mP0_oonfX2ool0I`Kooo]Z00?oo`2_oookJ_oo0:l06?oonfX2o`3o2Mcooo]Z0_l0
o`THoookJP?oo`2_1?oonfX4ool0I`;ooo]Z0ol0of001?l0]ooookX0oonj0?oo^P03ofl0o`Cooo]Z
1?oo0?82ool0Q@kooo]Z1?oohP06oookJPCoEOl00_l0]_l5o`3ok`?ooo]Z1?oo0446o`12o`?ooo]Z
0ol007l3oookJPSoog@08oooh`0=oookJPKo04;o0ooo0443oookJPCo0?o_0_oo08H00ol0]_ooEOl0
oeGo0003oeGo00Kooo]Z0ooohP0@oookJP04ool0QOoo0?;oo`3bool0lPCooo]Z0om_0?l01?oonf[o
okX0oonj0?oo^P03o`3oH0?ooo]Z0_oo06L5oookJP?oo`2_6?oonfX2o`3o2Ecooo]Z0022oookJP?o
0?l96?oonfX2ool0[`Gooo]Z0ooo06L2oookJP?o0?mP00Go0;Oooonj0?oo^P3ookX0ofl0o`02oolX
00Cooo]Z00?oon@0ooo90?oob@000_oo08D>oookJPGoon801OoonfX3oomi00?oobP01Ol0onl3oolX
0003oomi0?l0ojgo04;o00Go04;o0onDo`07odCo0003oomd0?oUo`3oiOl001?oon<01Ol0oed2o`1O
o`WoolT000?o0?l<o`2`ool0/?l01Ol0/?l00ol0o`co0;3oo`2`o`08o`2`o`Ko0?mM2_l0Gol00ol0
o`co0;3oo`2`o`06o`2`o`CoEOl01_oonfX3oooR00oooo]Z00Coo`25ool0l_oo0?;oo`3b1OoonfX3
ofl0o`?ookX00ol0of03oookJP;oo`1W1OoonfX3ool0[aSooo]Z0_l0o`WIoookJP?o0?l96?oonfX3
ool0[`Cooo]Z1?oo06L2oookJP;o0?mP00Co0;Oooonj0?oo^P3ookX01?m_0?l3oookJP04oooT0?oo
0?;oo`3bool0lP;oo`253_oonfX4oooR00Gooo]Z1?mEo`02o`2fo`Go0?o_0ooonfX3ool0@@Ko04;o
00Cooo]Zo`00Ool007oo001o0ooonfX2o`00O`?oog@04oooh`000ooo057oeOl0omGo0007omGo01?o
on<01?ooM009oookJPGo04;o0_oo0444oookJPCo0?o_0_oo08H00ol0]_ooEOl0oeGo0002oeGo00Ko
oo]Z0ooohP0@oookJP?oo`3b1OoonfX3ofl0o`?ookX000?o0;Ooo`3oH?l0of000ooonfX2ool0I`Go
oo]Z0ooo0:lHoookJP;o0?l9FooonfX0087ooo]Z0_l0o`THoookJP?oo`2_1OoonfX3ool0I`;ooo]Z
0_l0of001Ol0]ooookX0oonj0?oo^P3oK`3o00;oobP01OoonfX2ooo900?oo`253OoonfX5oooR00Co
oo]Z00CoEOl0oomi0?ooN@3oEOl00_oo:005o`3ok`03oookJ_oo:03oobP000;oobP01_l0@_l6oiCo
00;oA?l000?oog@0oooS0?ooh`002Oooh`03o`3ooPOoiOl000?oo`00o`3oGOl0oed01?l0oed3omGo
00;o05oo2Ooob@08o`3o30go0;3o1?l0oed<o`1Oo`Wo0;3o1?mEo`06oookJPCoon803OoonfX2ool0
Q@;oo`3b1OoonfX3ofl0o`?ookX00ol0of03oookJP;oo`1W1OoonfX2ool0[aSooo]Z0_l0o`WHoook
JP?o0?l95ooonfX4ool0[`Cooo]Z0ooo06L3oookJP;o0?mP00Co0;Oooonj0?oo^P3ooo]Z0om_0?l4
oookJP?oo`3b0_oo08D>oookJPCoon801?oonfX4oeGo00;o0;Ko1_l0onl2oookJP?oo`111_l0@_l0
1?l007oooo]ZoookJ_oonfX3o`00O`;oog@02_ooh`07ool0DAcoeOl01?oo054:oooS00?oog@02Ooo
nfX4o`12o`?oo`110_oonfX5o`3ok`03ool0Q_l0]_oo0;Ko00?oEOl01_oonfX4oooR00kooo]Z00Co
o`25ool0l_oo0?;oo`3b1?oonfX3ofl0o`?ookX000Co0;Ooo`3oH?l0of3o0?mP0_oonfX2ool0I`Go
oo]Z0_oo0:lIoookJP;o0?l9F_oonfX0083ooo]Z0_l0o`THoookJP?oo`2_1OoonfX3ool0I`;ooo]Z
0_l0of04oonj0003ofl0oooo:03oK`3o00Cooo]Z0_oob@000ooo0?;oo`25ool0Q@0<oookJPKoon80
1?oonfX3oeGo00;oobP01_l0onl2oookJP03ool0@Ooo:03o04;o00Go04;o1_ooN@03oomd00Soon<0
2Ol0ooh4onGo00ConOl00_l0oed7ooWo00;o05oo1_oob@02ooWo0003o`3hool0o`co0?l<00Ko0?l<
4?l0/?l>o`1Oo`Wo0;3o0_l0]_l3oeGo00Gooo]Z1OoohP0=oookJP04ool0QOoo0?;oo`3bool0lPCo
oo]Z0om_0?l3oonj0003o`2gool0of3o0?mP00?ooo]Z0_oo06L5oookJP;oo`2_6?oonfX2o`3o2MKo
oo]Z0ol0o`TGoookJPCoo`2_1?oonfX3ool0I`;ooo]Z0_l0of001?l0]ooookX0oonj0?oo^P03ofl0
o`Cooo]Z00?oon@0ool0l_oo0?800_oo08D=oookJPGoon801?oonfX3oeGo00;o0;Ko1_l0onl3oook
JP03ool0@Ol0@_oo04;o00Go04;o1?l007l01?oonf[oog@0oomd0?ooM008oooS00Coo`1A1ooEo`0I
ooWo00So0?So1_oEo`000ooo057oon<0oooS0006oooS00?oog@02?oonfX3o`12o`Coo`110_oonfX4
o`3ok`03ool0Q_l0]_oo0;Ko00CoEOl01?oonfX5oooR00kooo]Z0ooo0?801?ooi03ooo]ZoookJ_oo
nfX3ofl0o`?ookX000Co0;Ooo`3oH?l0of3o0?mP0_oonfX2ool0I`Gooo]Z0_oo0:lHoookJP?o0?l9
FOoonfX007oooo]Z0_l0o`THoookJP;oo`2_1_oonfX2ool0I`;ooo]Z0_l0of02ool000;ookX000?o
K`3ooolX0?oo:0001?oonfX00ooo0?;oolT0ool0lP02ool0Q@cooo]Z1OoohP05oookJP?oEOl000?o
obP0o`3okol0onl01?l0onl3oookJP03ool0@Ol0@_oo04;o00Co04;o0ooo:002oomi00;oog@02?oo
h`02o`3ooPGoA?l000?o0?onooWo0?oio`001?oio`000ooUo`3onOl0ooWo0002ooWo00koo`2@0_oo
b@07ool0T0Co0?l<1?oio`0Ao`2`o`03oooS0?ooM03o05oo00co05oo2Ol0/?l2o`2fo`?oEOl01Ooo
nfX2oooR0003oookJ_oohP3ooo]Z00cooo]Z00?oo`25ool0l_oo0?800_oo0?83oookJP?oK`3o0ooo
^P000ol0]ooo0?mPo`3oH003oookJP;oo`1W1OoonfX2ool0[aSooo]Z0_l0o`WDoookJP?o0?l95ooo
nfX3ool0[`Gooo]Z0_oo06L2oookJP?o0?mP0ooo^P001?oonf[oK`3oofl0oom_0?l3oookJP04oooT
0?oo0?;oo`3bool0lP;oo`253?oonfX4oooR00Gooo]Z0omEo`000ol0]_oo0?o_o`3ok`04o`3ok`Co
oo]Z1ol0@_l01?oonf[o001oo`00Ool007l2oomd00Soon<00ooo0545omGo00_onOl06Ooo0906ooWo
00?o0?So1_oEo`000ooo057oon<0oooS0006oooS00;oog@01ooonfX4o`12o`?oo`110_oonfX4o`3o
k`03ool0Q_l0]_oo0;Ko00CoEOl01?oonfX4oooR00kooo]Z00Coo`25ool0l_oo0?;oo`3b1?oonfX2
ofl0o`04oookJ_oo^P3ookX0o`2go`?o0?mP0_oonfX2ool0I`Gooo]Z0ooo0:lGoookJP?o0?l9F?oo
nfX007kooo]Z0_l0o`THoookJP;oo`2_1_oonfX2ool0I`;ooo]Z0_l0of03ool00004oonj0?oo:03o
obP0ofl0o`?ooo]Z00?oon@0ool0l_oo0?800_oo08D=oookJPCoon800ooonfX00ol0ookoEOl0oeGo
0002oeGo0003o`2fool0onoo0?o_00?o0?o_1?oonfX00ooo:03o04;oo`12o`03o`12o`GoobP00_oo
M007oooS0003o`3oo_ooN@3oA?l000GoA?l01ooio`0@ool0T0Soo`0000?ooo]Zool0T?oo09003?oo
0908o`2`o`03omGo0?oo:03oobP000;oU?l000?oo`1AoooS0?ooh`001Oooh`001?ooM03ooo]ZoiCo
0?nDo`08o`1Oo`03o`12ool0/?oo0;3o00Ko0;3o00?oo`26o`2fool0]_l00omEo`05oookJP?oon80
3OoonfX2ool0Q@?oo`3b0ooonfX3ofl0o`CookX00_l0of03oookJP;oo`1W1OoonfX3ool0[aOooo]Z
0_l0o`WBoookJP?o0?l95ooonfX3ool0[`Gooo]Z0_oo06L2oookJP;o0?mP00Co0;Oooonj0?oo^P3o
okX00om_0?l3oookJP;oon@00_oo0?82ool0Q@gooo]Z1?oohP03oookJPCoEOl000?o0;Koo`3okol0
onl01?l0onl3oookJP03ool0@Ol0@_oo04;o00Co04;o1?oonfX2oomd00Ooon<00ooo0544omGo0003
o`00Oooio`3onOl000GonOl04?oo090:oookJPooo`2@1_oio`05omGo0003ool0DOooh`3oon<000Go
on<000?oog@0oookJ_oonfX01_oonfX4o`12o`;oo`110ooonfX4o`3ok`;o0;Ko1?mEo`04oookJP?o
on803_oonfX01?oo08Goo`3bool0l_oo0?84oookJP;oK`3o00Cooo]Zoonj0?oo^P3ookX00_l0of03
oookJP;oo`1W1OoonfX3ool0[aOooo]Z0ol0o`UGoookJP00OOoonfX2o`3o2ASooo]Z0_oo0:l5oook
JP?oo`1W0_oonfX2o`3oH0?oo`0000?ookX0oolX0?m_0?l01?oonfX00oooi03oo`3bool0lP02ool0
Q@cooo]Z1?oohP03oookJP03o`3oo_mEo`3oEOl000;oEOl000?o0;Koo`3okol0onl00ol0onl3oook
JP;oobP01?l0@_l3oookJP;oobP00_ooM006oooS00KoogT000Co0?SoooWo0?oio`3onOl02_oo0903
ool00003oookJ_l0oaSo0?lH00?o0?lH4?oo0004o`3o60;ooo]Z0_oUo`05oookJP[oo`2@00?onOl0
omGo0?oo:0000onDo`000ooo:03oo`1Aool0D@04oooS00;oog@000?oU?l0oookJ_oonfX01?oonfX4
o`12o`;oo`1100?ooo]Zo`2`ool0/?l00_l0/?l00ol0onooo`26o`2fo`04oeGo00Gooo]Z0ooohP0=
oookJP04ool0QOoo0?;oo`3bool0lPCooo]Z0_m_0?l01?oonf[ookX0oonj0?oo^P02o`3oH0?ooo]Z
0ooo06L4oookJP?oo`2_5_oonfX3o`3o2M7ooo]Z0_l0o`TGoookJP?oo`2_1?oonfX3ool0I`;ooo]Z
0_l0of001?l0]ooookX0oonj0?oo^P02ofl0o`Cooo]Z00Goon@0ool0l_oo0?;oo`3bool0Q@0=oook
JPCoon800ooonfX4oeGo0003o`2fool0onoo0?o_00?o0?o_0ooonfX2ool0@@Go04;o1?oonfX2oomd
00Koon<01?oo0542omGo0004o`00Oooio`3onOl0ooWo00[oo`2@0ol000000ooonf[o0?lHo`3o600G
o`3o60[ooo]Z2Ooo09000ooio`3o0?SoomGo0004omGo00;oo`1A1?ooh`02oomd00Oooo]Z1?l0@_l2
ool0@@?ooo]Z1?l0onl00ol0]_ooEOl0oeGo0003oeGo00Cooo]Z0ooohP0>oookJP?oo`3b1OoonfX2
ofl0o`?ookX000?ooo]Zo`3oH?l0of000_oonfX3ool0I`Cooo]Z0ooo0:lGoookJP03o`3o2Ooonf[o
0?l905Kooo]Z001loookJP;o0?l96?oonfX00ooo0:oooo]ZoookJP04oookJP?oo`1W00?ooo]Zo`3o
H?l0of001?oo00000om_0?ooobP0ofl0o`04oookJP;oo`3b0_oo08D<oookJPCoon801?oonfX4oeGo
00;o0;Ko1?l0onl00ol0ookooo]ZoolX0002oolX00?o04;o1OoonfX2oomd00Koon<01_ooN@03ooWo
00Soo`2@0_oonfX2o`3o61Soo`002Ol0oaP5onGo0004o`3o6?oonf[ooo]ZoookJP;o0?mM00?ooo]Z
ool0T?oo09001_oo0902ool00005o`3hoonDo`3oU?l0oiCo0?oo:0000_oo0544oooS00;oog@01_oo
nfX4o`12o`;oo`110ooonfX2o`3ok`;oo`2600?o0;KooeGo0?mEo`000_mEo`05oookJP;oon803Ooo
nfX01?oo08Goo`3bool0l_oo0?84oookJP;oK`3o00Cooo]Zoonj0?oo^P3ookX00ol0of02oookJP?o
o`1W1?oonfX3ool0[aKooo]Z0_l0o`W@oookJP;o0?l95ooonfX2ool0[`Gooo]Z0ooo06L01Ooonf[o
0?mPo`3oH?l0of3o0;Oo00;ookX00om_0?l4oookJP?oo`3b0_oo08D<oookJPCoon800ooonfX4oeGo
00;o0;Ko1?l0onl2oookJP?oo`111?l0@_l4oookJP;oog@01_ooh`03ool0D@?oeOl00ooio`08ool0
T0?ooo]Z3ol0oaP:oookJQ3o0?lH1_oonfX8ool0T003ooWo0?l0n?ooeOl000?oeOl00ooo0543oooS
00;oog@01ooonfX3o`12o`;oo`110ooonfX3o`3ok`03ool0Q_l0]_ooEOl000CoEOl01?oonfX2oooR
00kooo]Z0ooo0?85oookJP;oK`3o0ooo^P000ol0]ooo0?mPo`3oH002oookJP?oo`1W1?oonfX3ool0
[aOooo]Z0_l0o`UFoookJP00NooonfX2o`3o2AOooo]Z0_oo0:l5oookJP?oo`1W00Cooo]Zool00?l0
of3o0?mP1Ooo00000om_0?oooo]ZoookJP02oookJP04oooT0?oo0?;oo`3bool0Q@cooo]Z1?oohP05
oookJP?oEOl00_l0]_l4o`3ok`;o0?on0_oo:003o`12o`Kooo]Z00?oog@0oooS0?ooh`001?ooh`02
oomi0003omGo0?ooN@3oogT000?onOl02?oo0902oookJP_o0?lH1_oonfX;oolT00GoiOl01_oonfX8
onGo0003o`3o6?l0oego0?mM00;o0?mM00?o0?lHoookJ_oonfX02?oo09000ooo003onOl0ooWo0002
oiCo0003o`3o[Ooo057oo`0000?oon<00_ooM007oookJP?o04;o00?oo`11oookJ_oonfX00_oonfX3
o`3ok`;o0;Ko1?mEo`04oookJP;oon803_oonfX3ool0lPCooo]Z0_m_0?l01?oonf[ookX0oonj0?l0
]ol3o`3oH0;ooo]Z0ooo06L4oookJP?oo`2_5_oonfX2o`3o2Lkooo]Z0_l0o`TGoookJP;oo`2_1?oo
nfX3ool0I`;ooo]Z0_l0of001?l0]ooookX0oonj0?oo^P02ofl0o`Cooo]Z00?oon@0ool0l_oo0?80
0_oo08D<oookJPCoon801?oonfX3oeGo00;o0;Ko1?l0onl01?oonf[oo`11ool0@Ooo0444o`12o`Go
oo]Z00?oog@0oooS0?ooh`001?ooh`03ool0D@;oeOl00ooio`08ool0T0?ooo]Z2_l0oaP6oookJQ7o
ob@02OoonfX:o`3o60?ooo]Z2?oo0902ooWo00?oeOl00_oo0544oooS0003oomd0?oonf[ooo]Z00Go
oo]Z0ol0@_l00ooo047ooo]ZoookJP02oookJP?o0?o_0_l0]_l5oeGo00?ooo]Z0ooohP0=oookJP03
ool0QOoo0?;oo`3b00Gooo]Z0_m_0?l01?oonf[ookX0o`2gool0]ol2o`3oH0;ooo]Z0ooo06L4oook
JP?oo`2_5ooonfX2o`3o2EGooo]Z001joookJP;o0?l95ooonfX2ool0[`Gooo]Z0ooo06L01?oo003o
0?mPo`3oH?l0of05ool00003ofl0oooonf[ooo]Z00;ooo]Z0ooo0?800ooo08Gooo]ZoookJP09oook
JPCoon801OoonfX3oeGo00;o0;Ko1?l0onl3o`3ooP04ool0@Ol0@_oo04;oo`12o`Kooo]Z1_ooh`00
0oooN@3oo`1AomGo0002omGo00?onOl01_oo0902oookJPOo0?lH1OoonfX00ol0003oob@0oolT000G
oolT00CoiOl01?l0oed7onGo00Ko0?mM0_l0oaP2o`1Oo`;oobP01_oo09000ooo003onOl0ooWo0005
ool000?oon<00_ooM006oookJP?o04;o0_oo0443oookJP?o0?o_0_l0]_l3oeGo00Gooo]Z0_oohP0=
oookJP03ool0QOoo0?;oo`3b00Cooo]Z0_m_0?l01?oonf[ookX0oonj0?oo^P03o`3oH0;ooo]Z0ooo
06L4oookJP?oo`2_5_oonfX2o`3o2Lcooo]Z0_l0o`TGoookJP;oo`2_1?oonfX3ool0I`04oookJ_l0
of3o0?mPo`3oH0?ookX000?ooo]Zofl0oom_0?l01?oonfX3ool0lP03ool0QOoonf[ooo]Z00[ooo]Z
1?oohP04oookJP?oEOl00_l0]_l4o`3ok`04oookJ_oo047oo`11ool0@@Co04;o1OoonfX6oooS00;o
o`1A0ooEo`03ooWo00Ooo`2@0_oonfX6o`3o60Gooo]Z0_l0000RoolT00Oooo]Z1ol0oaP4oookJPGo
o`2@0ooio`03omGo00;oo`1A1?ooh`000oooM03ooo]ZoookJP04oookJP?o04;o0_oo0443oookJPCo
0?o_00?o0;KooeGo0?mEo`000_mEo`04oookJP?oon803OoonfX3ool0lP?ooo]Z0_m_0?l2oookJP;o
okX000?o0;Ooo`3oH?l0of000_oonfX3ool0I`Cooo]Z00?oo`2_oookJ_oo0:l05_oonfX3o`3o2ECo
oo]Z001ioookJP;o0?l95ooonfX2ool0[`Gooo]Z0_oo06L2ool000?o0?mP1Ooo00001?m_0?oooo]Z
oookJ_oonfX3ool0lP;oo`252ooonfX3oooR00Cooo]Z00CoA?l0oeGo0?mEo`3oEOl00_l0]_l4o`3o
k`Co0?on0ol0@_l5oookJPKoon<000?oogT0ool0DOoEo`000_oEo`03ooWo00Goo`2@0ooonfX5o`3o
60?ooo]Z2_oo90000ol0003ooo]ZoookJP05oookJP;oo`004_oonfX3onGo00Co0?mM0ol0Gol8o`3o
G@;o05oo1_oo:005ool0T0Ooo`001?ooh`02oomd00Gooo]Z0_l0@_l3ool0@@;ooo]Z1?l0onl01?l0
]_ooEOl0oeGo0?mEo`06oookJP03oooR0?oonf[ooo]Z00_ooo]Z00?oo`25ool0l_oo0?801?oonfX0
0ooo003oK`3oofl0o`03oonj00?o0?mP0_oonfX3ool0I`Cooo]Z0_oo0:lFoookJP;o0?l9booonfX2
o`3o2AOooo]Z0_oo0:l4oookJP?oo`1W00Cooo]Zo`3oH?l0of3o0?mP0ooo^P000ooonf[oK`3oofl0
o`03oookJPCoo`3b00?oo`25oookJ_oonfX02_oonfX3oooR00Cooo]Z0omEo`02o`2fo`Co0?o_0_oo
nfX2ool0@@Co04;o1?oonfX6oooS00;oo`1A0ooEo`03ooWo00Goo`2@0ooonfX6o`3o60?ooo]Z2Ooo
90000ol0003ooo]ZoookJP0LoookJP[oob@01?oonfX6o`3o60Cooo]Z1?oo0902ooWo0005o`3hoooE
o`3oeOl0omGo0?oo05401Oooh`000oooM03ooo]ZoookJP03oookJP?o04;o0_oo0442oookJPGo0?o_
1?mEo`05oookJP;oon803OoonfX3ool0lP?ooo]Z0om_0?l01?oonf[ookX0oonj0?l0]ol2o`3oH0;o
oo]Z0ooo06L4oookJP;oo`2_5ooonfX2o`3o2ECooo]Z001hoookJP;o0?l95ooonfX2ool0[`Gooo]Z
0_oo06L01?oo003o0?mPo`3oH?l0of06ool000Cooo]Z0ooo0?800ooo08Gooo]ZoookJP0:oookJP;o
on801?oonfX00om4o`3oEOl0oeGo0002oeGo00Go0?o_00?oA?l0o`3oo_l0ooh00ol0@_l6oookJPGo
on<000?oogT0ool0DOoEo`000_oEo`03ooWo00Coo`2@0ooonfX5o`3o60Cooo]Z1ooo9003oookJPGo
05oo6_oonfX8onGo00;o0?mM1?l0Gol4o`3oG@Ko05oo00?oobP0o`3o6?l0oaP00_oonfX00onDo`3o
o`2@ool0T002ool0T0Koo`0000Coo`1AoooS0?ooh`3oon<00oooM004oookJP?o04;o0_oo0442oook
JP?o0?o_00?oo`26o`2foomEo`000_mEo`05oookJP;oon803?oonfX00ooo08Goo`3bool0lP03oook
JP04ool00?m_0?ooK`3oofl0o`?ookX00_l0of000ooo003ooo]ZoookJP02ool0I`Gooo]Z0_oo0:lF
oookJP;o0?l9bOoonfX2o`3o2AOooo]Z0_oo0:l4oookJP;oo`1W0_oonfX2o`3oH005o`2goooo^P3o
okX0oonj0?oonfX00_m_0?l3oookJP?oo`3b0_oo08D;oookJP?oon801?oonfX4oeGo00Go0?o_0_oo
nfX00ooo047o04;oo`12o`02o`12o`Gooo]Z1Oooh`02ool0D@?oeOl00ooio`04ool0T0?ooo]Z1_l0
oaP3oookJPOoob@00ooonfX4o`0002?ooo]Z2_oo9003oookJPOo0?lH0_oonfX4ool0T003ooWo0?l0
n?oo0?So00;oeOl00_oo0544oooS00;oog@01?oonfX3o`12o`;oo`110_oonfX4o`3ok`03o`2foomE
o`3oEOl000;oEOl01?oonfX2oooR00gooo]Z00?oo`25ool0l_oo0?800ooonfX3ofl0o`04oookJ_oo
^P3ookX0o`2go`;o0?mP0_oonfX2ool0I`Gooo]Z0_oo0:lGoookJP;o0?l9DooonfX007Oooo]Z0_l0
o`TGoookJP;oo`2_1OoonfX2ool0I`04oookJ_l0of3o0?mPo`3oH0Ooo`000ooonfX2ool0lP;oo`25
2ooonfX3oooR00Gooo]Z0omEo`04o`3ok`?oA?l000Coo`11o`12ool0@_oo04;o1_oonfX4oooS00;o
o`1A0ooEo`03ooWo00?oo`2@1?oonfX5o`3o60?ooo]Z1Ooo9009oookJPco05oo5?oo7P08onGo00Go
0?mM3?l0Gol01?oo:03o0?lHoiCo0?nDo`02ool000Coo`2@1Ooo0002ool0D@;oon<01?ooM004oook
JP?o04;o00?oo`11oookJ_oonfX00ol0onl00ooo08Ko0;Koo`2fo`03oeGo00Cooo]Z0ooohP0;oook
JP04ool0QOoo0?;oo`3bool0lP?oo`000om_0?l3oonj0004o`3oH?oo003ooo]ZoookJP?oo`1W1?oo
nfX3ool0[aKooo]Z0_l0o`W7oookJP;o0?l95ooonfX2ool0[`Cooo]Z0_oo06L2oookJP;o0?mP00Co
0;Oooonj0?oo^P3ooo]Z0_m_0?l4oookJP?oo`3b00?oo`25oookJ_oonfX02_oonfX3oooR00Cooo]Z
0omEo`04o`3ok`?ooo]Z00?oo`11o`12ool0@_l00_l0@_l5oookJPCoon<00_oo0543omGo0003o`3h
oooio`3onOl000Coo`2@0ooonfX5o`3o60?ooo]Z1_oo9008oookJP03o`000?oo7P3ooah001gooah0
3?oonfX8oolT00?ooo]Z1ol0oaP2oookJP?oo`2@0_oio`02o`3ho`03omGo0?oonf[oo`1A00?oon<0
0oooM004oookJP?o04;o00?oo`11oookJ_oonfX01?l0onl00ooo08Ko0;KooeGo0002oeGo00Cooo]Z
0ooohP0<oookJP?oo`3b0ooonfX3ofl0o`04oookJ_oo^P3ookX0o`2go`;o0?mP0_oonfX2ool0I`Go
oo]Z0_oo0:lGoookJP03o`3o2Ooonf[ooo]Z057ooo]Z001foookJP;o0?l95ooonfX2ool0[`Cooo]Z
0ooo06L01?oonf[o0?mPo`3oH?l0of07ool000?ooo]Z0_oo0?800ooo08Gooo]ZoookJP0:oookJP;o
on801OoonfX3oeGo00Co0?o_1?m4o`001?oo047o04;oo`12ool0@_l4oookJPGoon<000Coo`1AomGo
0?oEo`3oeOl00ooio`04ool0T0?ooo]Z1Ol0oaP00ooonf[oob@0oolT0004oolT00Cooo]Z2Ol0oed@
o`1Oo`;oE@3o0ooo0006oeD0o`cooah02Ol0oed:o`1Oo`?oobP01Ooo0004ool0T0?oo`0000?o00oo
ool0DOoo05400oooh`02oomd00Cooo]Z1?l0@_l3oookJP?o0?o_00?oo`26o`2foomEo`000omEo`03
oookJP?oon802ooonfX01?oo08Goo`3bool0l_oo0?83ool000?oK`3o0ooo^P001?l0of3oo`00oook
J_oonfX3ool0I`Cooo]Z0_oo0:lGoookJP;o0?l9aOoonfX2o`3o2AKooo]Z0ooo0:l4oookJP;oo`1W
0_oonfX2o`3oH004o`2goooo^P3ookX0oookJP;oK`3o1?oonfX3ool0lP03ool0QOoonf[ooo]Z00Wo
oo]Z0ooohP04oookJP?oEOl01Ol0onl2oookJP;oo`110ol0@_l4oookJPGoon<00_oo0542omGo0003
o`3hoooio`3onOl000Coo`2@0ooonfX5o`3o60;ooo]Z1Ooo900:oookJPkooah04OmE0?l<oolN00Wo
oo]Z1Ooo9004oookJPKo0?lH0_oonfX4ool0T003ooWo0?l0n?oo0?So00;oeOl000?oo`1AoooS0?oo
h`000_ooh`000oooM03ooo]ZoookJP03oookJP?o04;o0ooonfX3o`3ok`03ool0Q_l0]_ooEOl000?o
EOl00ooonfX3oooR00cooo]Z1?oo0?82oookJP?oK`3o00?ooo]Zoonj0?oo^P000ol0of02oookJP;o
o`1W1OoonfX2ool0[aKooo]Z0_l0o`UBoookJP00MOoonfX3o`3o2AGooo]Z0ooo0:l4oookJP?oo`1W
00Gooo]Zo`3oH?l0of3o0?mPoonj0006ool000?ooo]Z0_oo0?800ooo08Gooo]ZoookJP09oookJP?o
on800ooonfX01OooN@3oEOl0oeGo0?mEo`3o0;Ko00Co0?o_1?m4o`03o`12o`Cooo]Z1Oooh`000ooo
057oeOl0o`0?o`03ooWo00Coo`2@0ooonfX4o`3o6003oookJ_oo903oob@000Coob@02?oonfX9o`3o
G@ko05oo1?mE0?l6ool000_oE@3o0ooonfX8oolN00;o0?mM3?l0Gol8ool000;oo`2@0_oob@03ool0
0003o`0?ool0ojgoo`1A00?oon<00_ooM004oookJP?o04;o00Coo`11oookJ_oonf[ooo]Z0ol0onl0
0ooonP3o0;KooeGo0002oeGo00Cooo]Z0_oohP0;oookJP04ool0QOoo0?;oo`3bool0lP;oo`0000Co
oo]Zofl0oom_0?ooK`3o0ooo^P001?l0of3oo`00oookJ_oonfX3ool0I`Cooo]Z0_oo0:lGoookJP;o
0?l9`ooonfX2o`3o2AKooo]Z0ooo0:l4oookJP;oo`1W0_oonfX2o`3oH003o`2goooo^P3ookX000?o
K`3o1?oonfX2ool0lP;oo`252_oonfX4oooR00?ooo]Z0omEo`000ol0]_oo0?o_o`3ok`02o`3ok`?o
oo]Z00Coo`11o`12ool0@_oo04;o1?oonfX5oooS00;oo`1A00CoeOl0o`3hoooio`3onOl01Ooo0902
oookJPCo0?lH0_oonfX5oolT00[ooo]Z2Ooo7P000ol0003oE@3ooeD0o`0NoeD0o`?ooo]Z2Ooo7P07
oookJPCoob@00ooonfX5o`3o60?ooo]Z1?oo09001Ol0n?ooeOl0omGo0?oEo`3oo`1A00Coon<000?o
og@0oookJ_oonfX00_oonfX3o`12o`04ool0@Ooonf[ooo]ZoookJP?o0?o_00?oo`26o`2foomEo`00
0_mEo`04oookJP;oon803?oonfX4ool0lP;ooo]Z0om_0?l00ooonf[ookX0oonj0003o`3oH0;ooo]Z
0_oo06L5oookJP03ool0[ooonf[ooo]Z01Gooo]Z0_l0o`UAoookJP00M?oonfX3o`3o2AGooo]Z0ooo
0:l4oookJP?oo`1W00Cooo]Zo`3oH?l0of3o0?mP0_oo00000ooo^P3oo`00ool00003ool00003oook
J_oo0?;oo`3b00;oo`252_oonfX3oooR00;ooo]Z0_ooN@03oeGo00;o0;Ko0ol0onl4odCo00?o04;o
1?oonfX5oooS00?o00oo0_oio`05ool0T0;ooo]Z1?l0oaP2oookJPGoob@00ooonfX8onGo00?o0?mM
4Ol0Gol7o`1Go`[oo`0000?o0?lfoookJ_oonfX00_oonfX:oeD0o`Oooah03?l0Gol3oolX00Goo`00
0_oo0902ooo900;oo`000ol03ol01Ooo057oon<0oooS0?ooh`3oog@000Gooo]Z0_l0@_l2ool0@@;o
oo]Z1?l0onl01?l0]_ooEOl0oeGo0?mEo`04oookJP;oon802OoonfX2ool00004ool0QOoo0?;oo`3b
ool0lP;oo`0000Cooo]Zofl0oom_0?ooK`3o0_oo^P000ol0]ooo0?mPool00002oookJP?oo`1W1?oo
nfX2ool0[aKooo]Z0ol0o`W1oookJP;o0?l95_oonfX3ool0[`Cooo]Z0_oo06L2oookJP;o0?mP00?o
0;Oooonj0?oo^P000om_0?l3oookJP?oo`3b00?oo`25oookJ_oonfX02?oonfX4oooR00?ooo]Z0omE
o`02o`2fo`?o0?o_0ooonfX01?oo047o04;oo`12ool0@_l4oookJPGoon<00_oo05400ooEo`3o0?So
ooWo0006ool0T0;ooo]Z0ol0oaP3oookJPCoob@02?oonfX7oolN00[oE@3o00?ooo]Zo`3o=_l0ocH0
0ol0ocH:o`1Go`So0?lf1OoonfX9oeD0o`Oooah01ooonfX5oolT00;ooo]Z1Ol0oaP2oookJPCoo`2@
00GonOl0omGo0?oEo`3oeOl0ool0D@03oooS0003oomd0?oonf[ooo]Z00?ooo]Z0_l0@_l2ool0@@;o
oo]Z1?l0onl2o`2fo`;oEOl01?oonfX2oooR00cooo]Z1?oo0?82oookJP?oK`3o00?ooo]Zoonj0?oo
^P000ol0of02oookJP;oo`1W1?oonfX2ool0[aOooo]Z0_l0o`U@oookJP00M?oonfX2o`3o2AGooo]Z
0ooo0:l3oookJP;oo`0000?oo`1WoookJ_oonfX00_l0of001?l0]oooo`00oonj0?oonfX2ofl0o`?o
o`0000Cooo]Zool0l_oo0?;oo`252ooonfX3oooR00;ooo]Z00?oogT0oeGo0?mEo`000_mEo`001?l0
]_oo0?o_o`3okol0onl2oomi0003oookJ_m4o`3o04;o00;o04;o1?oonfX00oooM03oon<0oooS0002
oooS00?o00oo00?onOl0ool0T?oo09001?oo09000ooonf[o0?lHo`3o6002o`3o60;ooo]Z1Ooo9006
oookJPOoiOl01?l0Gol7o`3oG@So05oo1?l0Eol5oomA00goo`000_l0Eol3o`3o=P?ooo]Z1omE0?l0
0ooonf[ooah0oolN0003oolN00;oo`002?l0Gol2ool00003oolT0?oo:03oobP000;oU?l00ol0ojd2
ool0T004ooo90?oo003oo`00ooWo00?o00oo00GoolT0oooS0?ooh`3oon<0oomd0004oookJP?o04;o
0_oo0442oookJP04o`3okooo08Ko0?o_o`2fo`?oEOl01?oonfX2oooR00Oooo]Z1?oo00001Ooo08Go
o`3bool0l_oo0?;oo`0000;ooo]Z0_m_0?l3oonj0003o`2gool0of3oo`0000;ooo]Z0ooo06L4oook
JP;oo`2_5_oonfX00ol0o`Wooo]Zo`3o2@30oookJP;o0?l95OoonfX3ool0[`Cooo]Z00?oo`1Woook
J_oonfX00_l0of001?l0]ooookX0oonj0?oonfX3ofl0o`?ooo]Z0ooo0?800ooo08Gooo]ZoookJP08
oookJPCoon800_oonfX4oeGo0004o`2fool0onoo0?o_o`3ok`?ooo]Z00?oo`11o`12ool0@_l00_l0
@_l3oookJP03oomd0?ooh`3oon<000;oon<00_oo05400ooEo`3o0?Soool0T005ool0T0;ooo]Z1?l0
oaP00ooonf[oob@0oolT0003oolT00Oooo]Z1Ooo7P09oeD0o`03oookJ_l0ocKo0?lf00?o0?lf2Ol0
Eol9oomA00co05Oo0_l0ocH4oookJPKoE@3o00?ooo]ZoolN0?oo7P001Ooo7P06oookJPGoob@00_oo
nfX4o`3o60;ooo]Z0ooo0902ooWo00?oeOl000Goo`1AoooS0?ooh`3oon<0oomd0005oookJP;o04;o
0_oo0442oookJP?o0?o_0_l0]_l2oeGo00Cooo]Z0_oohP0<oookJPCoo`3b0_oonfX3ofl0o`;ookX0
00Go0;Ooo`3oH?l0of3o0?mPoookJP03ool0I`Cooo]Z0_oo0:lFoookJP?o0?l9CooonfX007?ooo]Z
0_l0o`TEoookJP?oo`2_0ooonfX3ool00008ool0Iooonf[o0?mPo`3oH?l0]oooo`00oonj0?oonfX2
ofl0o`;ooo]Z00Goo`00ool0l_oo0?;oo`3bool0Q@0;oookJP?oon800ooonfX3oeGo0003o`2foooo
N@3o0?o_00;o0?o_0_ooN@001?oo047o04;oo`12ool0@_l4oookJP03oomd0?ooh`3oon<000;oon<0
0ol03ol00ooio`3oo`2@ool0T003ool0T003oookJ_l0oaSo0?lH00?o0?lH00?ooo]ZoolT0?oo9000
0ooo9005oookJPCooah00_oUo`06o`3oG@03onGo0?l0oego0?mM00Oo0?mM0ol0Gol4oomA01Woo`00
0oooD@05o`1Go`?o0?lf1OmE0?l2oookJP?ooah00_oo0003oookJP?oobP00ooo0002oolT0005oolX
0?nDo`3oU?l0oiCo0?l0ojd00_nDo`001Ooo093oolT0ooo90?oo093onOl000;o00oo0_oob@001Ooo
057oon<0oooS0?ooh`3oog@000?ooo]Z00GoogT0o`12ool0@_oo04;oool0@@02oookJP?o0?o_00Co
0;KooeGo0?mEo`3oEOl01?oonfX3oooR00Oooo]Z0ooo00001Ooo08Goo`3bool0l_oo0?;oo`0000;o
oo]Z0_m_0?l3oonj0003o`3oH?oo003o0?mP00;ooo]Z0ooo06L4oookJP;oo`2_5_oonfX2o`3o2Koo
oo]Z0_l0o`TEoookJP?oo`2_1?oonfX2ool0I`04oookJ_l0of3o0?mPo`2go`;ookX000?ooo]Zofl0
oom_0?l00ooonfX3ool0lP03ool0QOoonf[ooo]Z00Wooo]Z0ooohP03oookJP?oEOl00_l0]_l3o`3o
k`;ooo]Z00?oo`11o`12ool0@_l00_l0@_l3oookJP03oomd0?ooh`3oon<000;oon<00_oo05400ooE
o`3onOl0ool0T005ool0T003oookJ_l0oaSo0?lH00;o0?lH00?ooo]ZoolT0?oo90000ooo9006oook
JPGooah02?mE0?l3o`3o=PWo05Oo7oooD@05o`1Go`?o0?lf00?ooo]ZoeD0oomE0?l00omE0?l00ooo
nf[ooah0oolN0003oolN00Kooo]Z1Ooo9002oookJP?o0?lH0ooonfX3ool0T0;onOl00ooEo`001Ooo
057oon<0oooS0?ooh`3oog@000Cooo]Z0ol0@_l00ooo047ooo]ZoookJP03o`3ok`03ool0Q_l0]_oo
EOl000;oEOl00ooonfX3oooR00_ooo]Z1?oo0?82oookJP?oK`3o0_oo^P001Ol0]ooo0?mPo`3oH?l0
of3ooo]Z00?oo`1W1?oonfX2ool0[aKooo]Z0_l0o`U?oookJP00L_oonfX2o`3o2AGooo]Z0ooo0:l2
oookJPCoo`0000Ooo`1WoookJ_l0of3o0?mPo`2goooo003ookX000?oK`3o0ooonfX3ool0lP03ool0
QOoonf[ooo]Z00Sooo]Z0ooohP03oookJP05ool00?mEo`3oEOl0oeGo0?l0]_l00ol0onl4oomi00;o
04;o1?oonfX00oooM03oon<0oooS0002oooS00?o00oo00?onOl0ool0T?oo09000ooo09000ooonf[o
0?lHo`3o6002o`3o60;ooo]Z1Ooo9004oookJPGooah000CoE@3oo`3oGOl0oego0?mM1ooUo`04o`3o
GA7ooe401?oSo`0=ool000[ooe401?l0Eol3o`3o=P;ooo]Z1OmE0?l00ooonf[ooah0ool00002ool0
00;ooo]Z1Ooo0002oolT00CoU?l00_l0ojd2oiCo0004ool0T?oob@3o0?l<o`3o30CoolT000?oo`1A
oooS0?ooh`000_ooh`02oookJP03oomi0?oonf[o04;o00?o04;o0ooonfX2o`3ok`;o0;Ko0_mEo`04
oookJP?oon802?oonfX2ool00003ool0QOoo0?;oo`3b00;oo`000_oonfX2ofl0o`?ookX000?o0?mP
ool00?l0of000_oonfX3ool0I`?ooo]Z0ooo0:lEoookJP?o0?l9_OoonfX2o`3o2AGooo]Z0ooo0:l3
oookJP?oo`1W00Cooo]Zo`3oH?l0of3o0;Oo0_oo^P03ofl0o`?ooo]Z0ooo0?800ooo08Gooo]Zoook
JP09oookJP?oon800ooonfX3oeGo0004o`2fool0onoo0?o_o`3ok`;ooo]Z0_oo0443o`12o`?ooo]Z
00?oog@0oooS0?ooh`000_ooh`02ool0D@05omGo0?oio`3onOl0ool0T?oio`000ooo09000ooonf[o
0?lHo`3o6002o`3o6003oookJ_oo903oob@000?oob@01OoonfX4oolN00SoE@3o0ol0ocH5o`1Goa3o
oe402OoSo`0BoomA00Co05Oo0ol0ocH2oookJPKoE@3o1?oo7P06oookJPCoob@00ooonfX3o`3o6003
oookJ_oo093oo`2@00;oo`2@0_oio`03omGo0004ool0DOooh`3oon<0oooS00Gooo]Z0ol0@_l3oook
JP;o0?o_00?oo`26o`2foomEo`000_mEo`03oookJP?oon802ooonfX3ool0lP?ooo]Z0om_0?l2oonj
0005o`2gool0of3o0?mPo`3oH?oonfX00ooo06L4oookJP;oo`2_5_oonfX2o`3o2Dkooo]Z001aoook
JP;o0?l95OoonfX3ool0[`03oookJ_oo003oo`0000Coo`0000Kooo]Zo`3oH?l0of3o0;Ooool00?oo
^P02ofl0o`Cooo]Z0_oo0?800ooo08Gooo]ZoookJP08oookJPCoon800_oonfX01Ooo003oEOl0oeGo
0?mEo`3oo`0000Co0?o_0oooN@03o`12o`?ooo]Z00?oog@0oooS0?ooh`000_ooh`03o`0?o`;onOl0
1?oo09000ol03ooo0?lHo`3o6002o`3o60;ooo]Z1?oo9004oookJPGooah00_mE0?l:onGo00[ooe40
00?ohol0o`1OoooSo`001ooSo`07oomX00Woo`002OoSo`08oomA00?o05Oo0_oo0002ooo90003o`3o
=_oonf[oE@3o00CoE@3o00?oo`00oolN0?oo00001ooo0003oolT00CoU?l000Oo0?n]o`0?ool03ooo
00ooool0T?oob@3o0?l<00CoolT000?o00ooool0DOooh`000_ooh`03oomi00;ooo]Z0ol0@_l00ooo
047ooo]ZoookJP02o`3ok`;o0;Ko0_mEo`05oookJP;oon802OoonfX01Ooo003oo`25ool0l_oo0?;o
o`0000?ooo]Z0_m_0?l3oonj0003o`3oH?oo003o0?mP00;ooo]Z0_oo06L4oookJP;oo`2_5_oonfX2
o`3o2Kcooo]Z0_l0o`TEoookJP?oo`2_0ooonfX3ool0I`04oookJ_l0of3o0?mPo`2go`;ookX00om_
0?l3oookJP?oo`3b00?oo`25oookJ_oonfX02?oonfX3oooR00?ooo]Z0omEo`000ol0]_oo0?o_o`3o
k`02o`3ok`;ooo]Z00Coo`11o`12ool0@_oo04;o0ooonfX2oomd00?oon<00_oo05400ooEo`3o0?So
ooWo0004ool0T0;ooo]Z1?l0oaP00ooonf[oob@0oolT0002oolT00Gooo]Z1?oo7P06oeD0o`Co0?lf
0ol0Eol9oomA00_ohol02?ooJ00@on?o00Wooe401?l0Eol3o`3o=P;ooo]Z1OmE0?l4oolN00Gooo]Z
0ooo9003oookJPCo0?lH00?ooo]Zool0T?oo09000_oo0902ooWo00;oeOl000Coo`1AoooS0?ooh`3o
on<01_oonfX2o`12o`03ool0@Ooonf[ooo]Z00?o0?o_00Co0;KooeGo0?mEo`3oEOl01?oonfX2oooR
00_ooo]Z0ooo0?83oookJP?oK`3o0_oo^P001Ol0]ooo0?mPo`3oH?l0of3ooo]Z00;oo`1W1OoonfX0
0ooo0:oooo]ZoookJP0DoookJP;o0?l9C_oonfX0073ooo]Z0_l0o`TEoookJP?oo`2_00?ooo]Zool0
0?oo00001?oo00001_oonf[o0?mPo`3oH?l0]oooo`00oonj00;oK`3o1?oonfX2ool0lP03ool0QOoo
nf[ooo]Z00Sooo]Z0ooohP001?oonf[oo`00ool00?oo0003oeGo0004ool00?l0onoo0?o_o`3ok`Co
ogT00_l0@_l4oookJP04oomd0?ooh`3oon<0oooS00;o0?n]00?o00ooooWo0?oio`001?oo0902o`0?
o`;o0?lH0_oonfX4oolT00Gooo]Z1?oo7P000ooonf[oiOl0onGo0002onGo00?o0?lf00Co05OoonGo
0?oUo`3oiOl01oooD@08on?o0003oomX0?ooS03ooh`000cooh`01_oo0009oon<0003oomX0?oSo`3o
hol000GoolT01oooD@002?l0Eoooo`00ool00?oo003o05Ooooo90?l0ocKoo`001?mE0?l9ool00004
oiCo0?oo903oob@0oolT00CoU?l000?o0?n]o`0?ool03ol00_oob@02o`3o30?oolT000?o00ooool0
DOooh`000_ooh`03oomi00?ooo]Z0_l0@_l00ooo047ooo]ZoookJP02o`3ok`04ool0Q_l0]_ooEOl0
oeGo00Gooo]Z0_oohP0:oookJP04ool0QOoo0?;oo`3bool000?ooo]Z0_m_0?l3oonj0004o`3oH?oo
003ooo]ZoookJP?oo`1W1?oonfX2ool0[aGooo]Z0ol0o`VjoookJP;o0?l95OoonfX3ool0[`?ooo]Z
0ooo06L2oookJP04o`3oH?l0]ooo0;Oooonj00?oK`3o0ooonfX2ool0lP;oo`252_oonfX3oooR00?o
oo]Z0omEo`001?l0]_oo0?o_o`3okol0onl2oookJP;oo`110_l0@_l4oookJP04oomd0?ooh`3oon<0
oooS00;oo`1A00?oeOl0o`3hoooio`001?oo09000ooonf[o0?lHo`3o6002o`3o60;ooo]Z0ooo9006
oookJPCooah01?mE0?l4o`3o=PCo05Oo1_ooD@09on?o01gooh`000?oofP0on?o0?oSo`001OoSo`07
oomA00Ko05Oo0ol0ocH4oeD0o`03oookJ_oo7P3ooah000;ooah01OoonfX3oolT00;ooo]Z0ol0oaP2
oookJPCoo`2@0_oio`000ooEo`3oo`1Aool0D@02oooS0003oomd0?oonf[ooo]Z00?ooo]Z0_l0@_l0
0ooo047ooo]ZoookJP03o`3ok`04ool0Q_mEo`3oEOl0oeGo00Cooo]Z0_oohP0;oookJP?oo`3b0ooo
nfX3ofl0o`;ookX000?o0;Ooo`3oH?l0of000_oonfX2ool0I`Cooo]Z0_oo0:lFoookJP;o0?l9COoo
nfX006oooo]Z0ol0o`TDoookJP?oo`2_2?oo0002o`3oH0;oo`0000?ookX0ofl0oom_0?l00ooonfX3
ool0lP03ool0QOoonf[ooo]Z00Oooo]Z1?oohP03ool000?oEOl00_oo0002o`3ok`;ooo]Z0_ooN@03
o`12o`?ooo]Z00Coog@0oooS0?ooh`3oon<01?l0ojd01?oio`3oo`2@ool0T?oo0904o`0?o`03o`3o
6?oonf[ooo]Z00?oob@01OoonfX4oolN0005oookJ_mE0?ooiOl0onGo0?mE0?l00_l0ocH4o`1Go`Ko
oe401OoSo`000oooJ03ooh`0oon<0004oon<013oo`2h0_oo0007ool0^0CoolT01OooS007ooo900Co
0?l<1OooD@07ool000CoE@3o2?oo00001Ooonf[oob@0oolT0?oo903oU?l000?o0?n]1Ooob@001ol0
o`coolT0ooo90?oob@3o00ooo`3o3?oo05400_ooh`000oooM03oogT0oomi0003oookJP?o04;o0ooo
nfX00ol0onooo`26o`2fo`02oeGo00Gooo]Z00?oon80oookJ_oonfX02OoonfX01?oo08Goo`3bool0
l_ooi002oookJP?oK`3o0ooo^P001?l0of3oo`00oookJ_oonfX3ool0I`Cooo]Z0_oo0:lEoookJP;o
0?l9^OoonfX2o`3o2AGooo]Z0ooo0:l3oookJP?oo`1W00Cooo]Zo`3oH?l0of3o0;Oo0_oo^P03ofl0
o`?ooo]Z0_oo0?82ool0Q@Wooo]Z0ooohP03oookJP?oEOl00_l0]_l2o`3ok`?ooo]Z00Coo`11o`12
ool0@_oo04;o0ooonfX01?ooM03oon<0oooS0?ooh`02ool0D@04omGo0?l0n?oonOl0ooWo00?oo`2@
00?ooo]Zo`3o6?l0oaP00_l0oaP2oookJP?oob@01OoonfX4oolN00CoE@3o0ol0ocH4o`1Go`Gooe40
1_oSo`06oon<01koo`2h2OooS006on?o00Gooe401Ol0Eol3o`3o=P?oE@3o00?ooo]ZoolN0?oo7P00
0ooo7P04oookJP?oob@00_oonfX3o`3o60;ooo]Z1?oo09001?oio`3oeOl0omGo0?oo0542oooS0003
oomd0?oonf[ooo]Z00?ooo]Z0ol0@_l3oookJP;o0?o_00Coo`26o`2foomEo`3oEOl01?oonfX2oooR
00_ooo]Z0ooo0?82oookJP;oK`3o00Cooo]Zofl0oooo^P3ookX00ol0of02oookJP;oo`1W1?oonfX2
ool0[aKooo]Z00?o0?l9oookJ_oonfX0BooonfX006kooo]Z0ol0o`TDoookJP?oo`2_1ooo0003o`3o
H003ool00?oo^P3ookX000;oK`3o0ooonfX2ool0lP;oo`252OoonfX3oooR0003oookJ_oo003oo`00
00CoEOl00_oo0002o`3ok`;ooo]Z00Coo`11o`12ool0@_oo04;o0ooonfX2oomd00;oon<01?l0ojd0
1?oio`3oo`2@ool0T?oo0905o`0?o`;ooo]Z0ooo9005oookJP?ooah00_oonfX3oeD0o`04oookJ_l0
Eooo05Ooo`1Go`Kooe4000?ohol0onGo0?oSo`000_oSo`03oomX0003oon<0?oo0;Soo`2h01;oo`2h
1ol03ol4oi3o00Koo`2h1?oob@03o`3o30GoolT01Ol0o``2odCo00Kooe401_oo0004oeD0o`Koo`00
0_oonfX4oolT0003o`3o[Ooob@3oolT000CoolT000Oo0?l<o`2`ool0/?ooolT0o`3o3?ooN@3oo`1A
00?oon<000?oog@0oomi0?oonfX00_oonfX3o`12o`?ooo]Z00Co0?o_ool0Q_l0]_oo0;Ko0_mEo`04
oookJP;oon802_oonfX01?oo08Goo`3bool0l_ooi002oookJP?oK`3o0ooo^P001?oo003o0?mPoook
J_oonfX2ool000Cooo]Z0_oo0:lFoookJP;o0?l9]ooonfX2o`3o2AGooo]Z0ooo0:l3oookJP?oo`1W
00Cooo]Zo`3oH?l0of3o0;Oo0_oo^P000ooonf[oK`3oofl0o`02oookJP03oooT0?oo0?;oo`3b00;o
o`252OoonfX3oooR00;ooo]Z1?mEo`001?l0]_ooo`26o`3okol0onl2oookJP04ool0@Ol0@_oo04;o
o`12o`Cooo]Z00?oog@0oooS0?ooh`000_oo05401?oEo`3o0?Soo`3hoooio`02ool0T0?ooo]Z0ol0
oaP2oookJP?oob@01?oonfX4oolN0006oookJ_mE0?ooE@3ooeD0oooonf[o0?lf0ol0Eol5oomA0003
oookJ_oSo`3ohol000?ohol00_ooJ002oon<01?oo`2h1ol0oi44oi3o00goo`2h1_ooS007on?o00Go
oe400ol0Eol3o`3o=PCoE@3o1Ooo7P03oookJPGoob@000Cooo]Zo`3o6?l0oaSo0?lH0_oonfX4ool0
T0;oeOl00_oo0542oooS0003oomd0?oonf[ooo]Z00?ooo]Z0_l0@_l3oookJP;o0?o_00?oo`26o`2f
oomEo`000_mEo`03oookJP;oon802ooonfX3ool0lP;ooo]Z0_m_0?l01?oonf[oK`3ooonj0?oo^P03
o`3oH0;ooo]Z00?oo`1WoookJ_oonfX00ooonfX00ooo0:oooo]ZoookJP0DoookJP;o0?l9C?oonfX0
06gooo]Z0ol0o`TDoookJP?oo`2_1ooo0003o`3oH003ool00?oo^P3ookX000;oK`3o0ooonfX2ool0
lP03ool0QOoonf[ooo]Z00Sooo]Z0ooohP001Ooonf[oo`00ool00?mEo`3oo`0000;oEOl000?oo`00
o`3okol0onl01?oo0003o`12o`;ooo]Z0_ooM003oooS00?o0?n]00Co05ooool0T?oo093oo`2@0_l0
ojd4o`0?o`04oookJ_oo903oob@0oolT00Cooo]Z1?oo7P001Ooonf[oE@3ooeD0oomE0?oooo]Z00?o
05Oo1OooD@000ooonf[ohol0o`2`o`07o`2`o`_oo`2h0onDo`000ol0ooko0?n]o`3o[@03o`3o[@?o
0?nA1_l03ol3oookJP_o0?nA00CoogT0ooo90?oob@3oolT01?l0o``3o`2`o`Go0?l<00CoA?l0o`2`
ool0/?oo0;3o0_ooD@02oolX0003oomA0?oo003oo`0000Coo`000_oo:0000omE0?ooo`00ool00003
ool000?ooo]Z0_oo9008ooo900;o0?l<00?o0;3oo`3o3?l0o``00_ooN@04oooS0004oomi0?oonf[o
oo]ZodCo00?o04;o0ooonfX01?l0onooo`26o`2fool0]_l2oeGo00Cooo]Z0_oohP0:oookJP?oo`3b
00?oon@0oookJ_oonfX00om_0?l2oonj0003o`3oH?oo003ooo]Z00?oo`0000?oo`1WoookJ_oonfX0
0_oonfX2ool0[aGooo]Z0_l0o`VfoookJP;o0?l95OoonfX3ool0[`?ooo]Z0ooo06L01?oonf[o0?mP
o`3oH?l0]ol2oonj00;oK`3o0ooonfX01?ooi03oo`3bool0l_oo08D:oookJP?oon800_oonfX4oeGo
0003o`2fool0onoo0?o_00;ooo]Z0_oo0443o`12o`?ooo]Z00Goog@0oooS0?ooh`3oon<0ool0D@02
omGo0004o`3hoooio`3oo`2@ool0T0;ooo]Z1?l0oaP2oookJP?oob@00ooonfX4oolN0006oookJ_mE
0?ooE@3ooeD0oooonf[o0?lf0ol0Eol5oomA0003oookJ_oSo`3ohol000?ohol00_ooJ002oon<00[o
o`2h3Ol0oi400ooo00?ooo]ZoookJP05oookJP_o0?nA0on@o`09ool0^003oon<0?ooJ03ohol000Go
hol01OooD@02o`1Go`?o0?lf00Cooo]ZoeD0oomE0?ooE@3o1Ooo7P03oookJPGoob@01?l0oaP00ooo
nf[oo`2@ool0T002ool0T0?oeOl000Coo`1AoooS0?ooh`3oon<01OoonfX2o`12o`?ooo]Z0_l0onl0
0ooo08Ko0;KooeGo0002oeGo00?ooo]Z0_oohP0:oookJP04ool0QOoo0?;oo`3bool0lP;ooo]Z0om_
0?l2oonj0003o`2gool0of3o0?mP00;ooo]Z0_oo06L5oookJP03ool0[ooonf[ooo]Z01Cooo]Z00?o
0?l9oookJ_oonfX0B_oonfX006cooo]Z0ol0o`TDoookJP?oo`2_1ooo0003o`3oH003ool00?oo^P3o
okX000;oK`3o0ooonfX2ool0lP03ool0QOoonf[ooo]Z00Sooo]Z0ooohP03ool000?oEOl00_oo0002
o`3ok`Coo`000_l0@_l2oookJP;oog@00oooh`02o`3o[@;o05oo1?oo0902o`3o[@04o`3o6?l03ooo
00ooo`0?o`?oob@00ooonfX4oolN0003oookJ_mE0?ooE@3o00;oE@3o00Co0?lfo`1Gool0Eooo05Oo
1OooD@08o`2`o`Ooo`2h1?oo:0001?m4o`3oU?l0oiCo0?nDo`04o`3ooP;o0?n]0_l0ooh3ool00003
o`3oo_l03ooo00oo01?ooo]Z1ooob@03o`3o30?o0;3o0_l0o``6o`2`o`05o`3oo_ooD@3oobP0oolX
0?ooD@001?oo0003oolX00?oE@3o0ooo00001?oonf[o0?n]o`3o[Ol0ojd3oolT00KoolT00_l0o``0
0ol0/?oo0?l<o`3o3002oomi0008ool0DOooh`3oon<0oooS0?ooN@3ooo]ZodCo0?oonfX2o`12o`;o
o`110_oonfX2o`3ok`;o0;Ko0_mEo`04oookJP;oon802_oonfX3ool0lP?ooo]Z0_m_0?l3oonj0003
o`3oH?oo003oo`0000?oo`001OoonfX00ooo0:oooo]ZoookJP0DoookJP;o0?l9]?oonfX2o`3o2AGo
oo]Z0ooo0:l3oookJP?oo`1W00Cooo]Zo`3oH?l0of3o0;Oo0_oo^P02ofl0o`?ooo]Z00Coon@0ool0
l_oo0?;oo`252_oonfX3oooR00;ooo]Z0omEo`001?l0]_ooo`26o`3okol0onl2oookJP;oo`110_l0
@_l3oookJP09oomd0?ooh`3oon<0oooS0?oo057ooo]ZomGo0?l0n?oonOl000?oo`2@00?ooo]Zo`3o
6?l0oaP00_l0oaP2oookJP;oob@00ooonfX5oolN00CoE@3o0_l0ocH3o`1Go`Cooe4000?ooo]Zon?o
0?oSo`000ooSo`03oon<00Koo`2h00?oT?l0o`3oTOl0oi401Ol0oi43o`0001kooo]Z1Ol0oi42oi3o
00Ooo`2h0_ooS002oomX00Cohol01?ooD@03o`1Go`?o0?lf1?mE0?l3oolN00Cooo]Z1?oo90001?oo
nf[o0?lHo`3o6?l0oaP2oookJP?oo`2@00ConOl0omGo0?oEo`3oo`1A0oooh`05oookJP;o04;o00?o
o`11oookJ_oonfX00_l0onl00ooo08Ko0;KooeGo0002oeGo00?ooo]Z0_oohP0:oookJP04ool0QOoo
0?;oo`3bool0lP;ooo]Z0om_0?l2oonj0003o`2gool0of3o0?mP00;ooo]Z0_oo06L4oookJP;oo`2_
5OoonfX2o`3o2D_ooo]Z001[oookJP03o`3o2Ooonf[o0?l901Cooo]Z0ooo0:l2oookJPGoo`000ol0
of000ooo003ookX0oonj0002ofl0o`?ooo]Z00?oon@0ool0l_oo08D02_oonfX3oooR00?oo`000omE
o`001?oo003o0?o_o`3okol0onl3ool000;o04;o0ooonfX2oomd00;oon<000Coo`1Ao`1Oool0Gooo
05oo1?oo0903o`3o[@;o0?lH00?ooo]Zo`0?oooo90000_oo9002oookJPCooah000Kooo]ZoeD0oomE
0?ooE@3ooookJ_l0ocH2o`1Go`Gooe401_l0/?l8ool0^003oomi0?oo:03oobP000?oobP00om4o`00
0onDo`3oA?l0odCo0008o`3ooPOoo`000_l0ooh:o`3oD`Coo`0K00?ooo]Zooo90?oob@001_oob@06
o`3o30[o0;3o0_oSo`02oolX0003oomA0?oo003oobP000CoobP01?mE0?l2ool000?ooo]Z00Co0?n]
oolT0?oo903oob@00_l0ojd00ol03oooolT0ooo90003o`3o3003o`2`ool0o`co0?l<00;oogT000Go
o`1AoooS0?ooh`3oon<0oomd0002odCo0003oookJ_l0@_oo04;o00;oo`110_oonfX2o`3ok`;o0;Ko
0_mEo`04oookJP;oon802_oonfX3ool0lP?ooo]Z0_m_0?l2oonj00Koo`0000?oo`1WoookJ_oonfX0
0_oonfX2ool0[aKooo]Z0_l0o`VboookJP;o0?l95OoonfX3ool0[`Cooo]Z0_oo06L01?oonf[o0?mP
o`3oH?l0]ol2oonj00;oK`3o0ooonfX01?ooi03oo`3bool0l_oo08D:oookJP?oon800_oonfX3oeGo
0004o`2fool0onoo0?o_o`3ok`;ooo]Z0_oo0442o`12o`?ooo]Z00Soog@0oooS0?ooh`3oon<0ool0
DOoEo`3o0?SoooWo00?oo`2@00?ooo]Zo`3o6?l0oaP00_l0oaP2oookJP?oob@00ooonfX4oolN00Co
E@3o00Co0?lfo`1Gool0Eooo05Oo1OooD@05on?o0003oon<0?oo0;Soo`2h00Goo`2h00?oT?l0o`3o
TOl0oi400ol0oi400ooo00?ooo]ZoookJP02oookJPCo00000_oo01/Fo`3oD`Goo`0K1ooonfX3o`3o
T@03oi3o0?oo0;Soo`2h00Goo`2h0_ooS002oomX00Cohol00oooD@03o`1Go`?o0?lf1?mE0?l3oolN
00?ooo]Z1?oo9002oookJP;o0?lH0_oonfX3ool0T0;onOl000?oeOl0ool0DOoo05400_ooh`000ooo
M03ooo]ZoookJP02oookJP;o04;o00?oo`11oookJ_oonfX00_l0onl00ooo08Ko0;KooeGo0002oeGo
00?ooo]Z0_oohP0:oookJP04ool0QOoo0?;oo`3bool0lP;ooo]Z0om_0?l2oonj0003o`2gool0of3o
oo]Z00;ooo]Z0_oo06L4oookJP;oo`2_5OoonfX2o`3o2D[ooo]Z001[oookJP;o0?l95?oonfX3ool0
[`Cooo]Z0ooo0003o`3oH003ool00?oo^P3ookX000;oK`3o0ooonfX3ool0lP03ool0QOoonf[ooo]Z
00Oooo]Z0_oohP02oookJP;oo`000omEo`000ooo003o0?o_o`3ok`03ool000?o04;o0ooonfX01?oo
M03oon<0oooS0?ooh`03o`1Oo`Coo`2@00Ko05ooo`3o[Ol0ojgo0?n]o`3o6?oonfX4oolT00?ooo]Z
0ooo7P001Ooonf[oE@3ooeD0oomE0?oo0?lf00;o05Oo1OooD@02o`3o30Co0;3o1ooo0;P00on@o`3o
ogT0oomi0002oomi00?oobP000?oogT0odCo0?m4o`001?m4o`09o`3ooP[oo`0000?oogT0ool06ol0
oe<02ol0oe<7ooo900So0?l<2_l0/?l00ol0ookohol0oomi0002oolX00;oU?l01?oo:0001?l0o`co
E@3ooiCo0?mE0?l2ool00003oolN0?oonf[ooo]Z00;ooo]Z0ooo9002o`0?o`Go0?l<0_l0/?l01Ol0
o`coogT0oomi0?l0/?ooo`1A00?oon<00_m4o`001Ooonf[o04;oo`12ool0@_ooo`1100;ooo]Z0_l0
onl01?oo08Ko0;KooeGo0?mEo`04oookJP;oon802_oonfX2ool0lP04oooT0?oonf[ooo]ZoookJP;o
K`3o2?oo00000ooo06Oooo]ZoookJP02oookJP;oo`2_5OoonfX3o`3o2K7ooo]Z00?o0?l9oookJ_oo
nfX04ooonfX3ool0[`Cooo]Z0_oo06L01?oonf[o0?mPo`3oH?l0]ol2oonj00;oK`3o0ooonfX3ool0
lP03ool0QOoonf[ooo]Z00Oooo]Z0ooohP03oookJP?oEOl000?o0;Koo`3okol0onl00ooonfX00ooo
047o04;oo`12o`04oookJP?oon<000Coo`1AomGo0?l0n?oonOl00ooo0902oookJP?o0?lH0_oonfX3
oolT00?ooo]Z1?oo7P04oeD0o`?o05Oo1OooD@05on?o0003oon<0?oo0;Soo`2h00Coo`2h0_n@o`03
o`3oT@03ool00ooonf[ooo]Z00Gooo]Z0_oo01/=o`3oD`Oooo]Z0_oo01/=o`3oD`;oo`0K1_oonfX0
1Ooo00?o0?nAo`3oTOl0oi7oT?l000Koo`2h0_ooS002oomX00?ohol01?ooD@03o`1Go`;o0?lf0omE
0?l4oolN00?ooo]Z0ooo9002oookJP?o0?lH0_oonfX3ool0T004ooWo0?oEo`3oeOl0ool0D@?oon<0
1?oonfX3o`12o`;ooo]Z0_l0onl01?oo08Ko0;KooeGo0?mEo`04oookJP;oon802_oonfX00ooo08Go
o`3bool0lP03oookJP;oK`3o00?ooo]Zoonj0?l0]ol00_l0of02oookJP?oo`1W1?oonfX2ool0[aGo
oo]Z0_l0o`U9oookJP00J_oonfX3o`3o2A?ooo]Z0ooo0:l4oookJP03ool0Iooo003oo`0000?o0?mP
00Goo`00oonj0?oo^P3oo`00ofl0o`03oookJP?oo`3b00?oo`25oookJ_oonfX01ooonfX2oooR00Co
oo]Z0_mEo`02ool000;o0?o_0ooo0003o`12o`?ooo]Z0oooh`04o`1Oo`Coo`2@00Go05ooo`3o[Ol0
ojgo0?n]oookJP04oolT00;ooo]Z1?oo7P001Ooonf[oE@3ooeD0oomE0?oo0?lf00;o05Oo1OooD@05
o`3o3003o`2`oooo0;Soo`2h00Coo`2h1?l0/?l4oomi0004oolX0?ooN@3oogT0oomi00Ko0?on0_m4
o`02o`3ooP?oU?l00_l0on0>ool000;obP3o1Om4o`02oookJP03ool06ol0oe?o0?mC00;o0?mC0ooo
N@08o`3o30co0;3o0_oSo`03oolX00;oU?l00ooo:0000ol0o`coU?l0oiCo0002oeD0o`?ooah01?oo
nfX2oolT00So0?l<00Ko0;3oo`3o3?oEo`3o0;3oodCo0?oo0543oooS00;oA?l000Gooo]Zo`12ool0
@_oo04;oool0@@02oookJP;o0?o_00Coo`26oeGo0?mEo`3oEOl01?oonfX00ooohP3oo`00oookJP08
oookJP03ool0QOoo0?;oo`3b00Cooo]Z2Ooo0002ool0I`Cooo]Z0_oo0:lEoookJP;o0?l9/?oonfX2
o`3o2ACooo]Z0ooo0:l4oookJP;oo`1W00Cooo]Zo`3oH?l0of3o0;Oo0_oo^P02ofl0o`?ooo]Z0ooo
0?800ooo08Gooo]ZoookJP07oookJP?oon800ooonfX2oeGo00;o0;Ko0_l0onl2oookJP;oo`110_l0
@_l3oookJPCoon<000Coo`1Ao`3hoooio`3onOl00ooo09000ooonf[o0?lHo`3o6002o`3o6004oook
J_oo903oob@0oolT00?ooo]Z1?oo7P03oeD0o`04o`3o=_l0Eooo05Ooo`1Go`Cooe401OoSo`000ooo
J03ooh`0ool0^004ool0^005oi3o0?l0oi7o0?nAo`3oTOoo00<00ooonfX2ool06`Wo0?mC1?l00002
oookJQ3o0?oP0oo:0?l7oookJPWo0?mC1OoonfX00ooo00?o0?nAo`3oT@02o`3oT@Goo`2h00?ooh`0
oomX0?ooJ0001?oSo`03oomA00?o05Oo0_l0ocH3oeD0o`?ooah01?oonfX3oolT00;ooo]Z0_l0oaP2
oookJP?oo`2@00?onOl0omGo0?oEo`000_oo0542oooS00Cooo]Z0ol0@_l2oookJP?o0?o_00?o0;Ko
oeGo0?mEo`001?oonfX2oooR00[ooo]Z0ooo0?83oookJP;oK`3o00?ooo]Zoonj0?l0]ol00_l0of02
oookJP?oo`1W0ooonfX3ool0[aCooo]Z0_l0o`U9oookJP00JOoonfX3o`3o2ACooo]Z0_oo0:l4oook
JP04ool0Iooo003oo`1Wool000;o0?mP00Goo`00oonj0?oo^P3oo`00ofl0o`03oookJP?oo`3b00?o
o`25oookJ_oonfX01ooonfX2oooR00Cooo]Z0_mEo`000ooo003o0?o_o`3ok`03ool000?o04;o0_oo
00000ooonf[oog@0oooS0002oooS00Co05oo0ooo0902o`1Oo`?o0?n]1?oo9002oookJP;o05oo0ooo
7P03oeD0o`03o`3o=_l0Eooo05Oo00Cooe401_l0o``5ool0^003oi3o0?l0/?oo0;3o00Ko0;3o0_oo
N@04odCo00Oo0?on0_l0on0Gool000[o0?oP00Co0?onoookJ_oonf[ooo]Z1Ol0oe<4odCo00ko0;3o
1Ooo:0000onDo`3oobP0oolX0004oiCo00?oE@3o0_oo7P02oookJP;o00oo0ooo9007o`3o30Co0;3o
00?oA?l0ool0DOoo05400_ooh`001?m4o`3ooo]ZoookJ_oonfX2o`12o`03ool0@Ooonf[ooo]Z00;o
0?o_00Coo`26oeGo0?mEo`3oEOl00ooonfX00ooohP3oo`00oookJP09oookJP03ool0QOoo0?;oo`3b
00?ooo]Z0_m_0?l8ool00003ool0Iooonf[ooo]Z00?ooo]Z00?oo`2_oookJ_oonfX04ooonfX3o`3o
2Jkooo]Z0_l0o`TEoookJP;oo`2_1?oonfX2ool0I`;ooo]Z00Co0?mPo`2gool0]ooookX00_m_0?l3
oookJP?oo`3b00?oo`25oookJ_oonfX01ooonfX3oooR00?ooo]Z0_mEo`001?l0]_oo0?o_o`3okol0
onl2oookJP04ool0@Ol0@_oo04;oo`12o`;ooo]Z00Ooo`1GoooS0?ooh`3oon<0ool0DOoEo`3o0?So
00;onOl00_oo0902oookJP?o0?lH00Cooo]ZoolT0?oo903oob@00ooonfX4oolN00?oE@3o0_l0ocH2
o`1Go`Cooe401?oSo`000oooJ03ooh`0ool0^003ool0^005oi3o0?l0oi7o0?nAo`3oTOoo00<01?oo
nfX2ool06`Oo0?mC1?oonfX00ol0003o0?oPo`3oh00Po`3oh0Cooo]Z1_l0oe<00ooo01_ooo]Zoook
JP03oookJP04ool00ol0oi7o0?nAo`3oT@Goo`2h0_ooJ004on?o00Cooe400_l0Eol2o`3o=P?oE@3o
0ooo7P03oookJPCoob@000Gooo]Zo`3o6?l0oaSo0?lHoookJP03ool0T0;onOl000?oeOl0oookJ_oo
05400_ooh`04oookJP?o04;o0_oonfX3o`3ok`03o`2foomEo`3oEOl000?ooo]Z0_oohP0;oookJP?o
o`3b0ooonfX2ofl0o`;ookX000?ooo]Zo`3oH?l0of000_oonfX2ool0I`Cooo]Z0_oo0:lEoookJP;o
0?l9B?oonfX006Wooo]Z0_l0o`TDoookJP;oo`2_1?oonfX01?oo06Ooo`00ool0Iooo0002o`3oH003
ool00?oo^P3ookX000;oo`000ooonfX3ool0lP03ool0QOoonf[ooo]Z00Oooo]Z0_oohP03oookJP?o
EOl000?oo`26o`3okol0onl00ooo0003o`12o`;oo`0000Cooo]ZoooS0?ooh`3oon<01?l0Gol4ool0
T0;o05oo00?o0?lHoookJ_l0ojd00ooo90000ooonf[o05ooo`1Oo`03o`1Oo`05oolN0?mE0?ooE@3o
oeD0ool0ocH00ol0Eol3oomA0003on?o0?oob@3o0?l<00;o0?l<00Co0;3oool0^?oo0;Soo`2h0_n@
o`07o`2`o`;oo`0K00?o0?mCodCo0?m4o`001Om4o`09o`3oh0Oo0?on3Ooo0005ool0l0;oA?l02Ol0
on000oo:0?ooogT0oomi0002oomi00Co0?mC3ol0/?l6oolX00;oU?l00_l0ojd3oiCo00CoE@3o0_oo
7P02oookJP;o00oo0ooo90000ol03ooo0?l<o`3o3002o`3o30Go0;3o00WoA?l0ool0DOoo057oon<0
oomd0?m4o`3ooo]Zo`3oo_oonfX00_l0@_l00ooo047ooo]ZoookJP02o`3ok`04ool0Q_mEo`3oEOl0
oeGo00?ooo]Z00?oon80ool00?oonfX02OoonfX2ool0lP04oooT0?oonf[ooo]ZoookJP;oK`3o1ooo
0002ool0I`Cooo]Z0_oo0:lEoookJP;o0?l9[_oonfX00ol0o`Wooo]ZoookJP0CoookJP;oo`2_1?oo
nfX2ool0I`;ooo]Z0_l0of001?l0]ooookX0ofl0oom_0?l3oookJP?oo`3b00?oo`25oookJ_oonfX0
2?oonfX2oooR00?ooo]Z0_mEo`000ol0]_oo0?o_o`3ok`02oookJP;oo`110_l0@_l3oookJPCoon<0
00Coo`1AomGo0?l0n?oonOl00ooo09001Ooonf[o0?lHo`3o6?l0oaSooo]Z00?oob@01?oonfX3oolN
00?oE@3o00Co0?lfo`1Gool0Eooo05Oo0oooD@04on?o0003oomX0?ooS03oo`2h00?oo`2h00GoT?l0
o`3oTOl0oi7o0?nAool00`04oookJP;oo`0K1?l0oe<3oookJPWo0?oP0oo:0?lGool0l003oaWo0?l0
on3o0?oP00Oo0?oP00?obP3ooookJ_oonfX00_oonfX00ooo01_o0?mCo`3oD`02o`3oD`;oo`0K1?oo
nfX00ooo00?o0?nAo`3oT@06ool0^0;oofP00ooSo`04oomA0003o`1Gool0ocKo0?lf00CoE@3o0ooo
7P03oookJP?oob@00_oonfX2o`3o60;ooo]Z0_oo0902ooWo0005omGo0?oonf[oo`1AoooS0?ooM000
1?oonfX3o`12o`03ool0@Ooonf[o0?o_00;o0?o_00?o0;KooeGo0?mEo`000ooonfX2oooR00[ooo]Z
00?oo`25ool0l_oo0?801?oonfX01?m_0?oooo]Zoonj0?oo^P02o`3oH0;ooo]Z0ooo06L4oookJP;o
o`2_5?oonfX2o`3o2DSooo]Z001XoookJP;o0?l95?oonfX2ool0[`Cooo]Z00Coo`1Wool00?oo06Oo
oo]Z0_l0of000ooo003ookX0oonj0002ool000?ooo]Z0ooo0?800ooo08Gooo]ZoookJP07oookJP;o
on800ooonfX3oeGo0003ool0Q_l0onoo0?o_00?oo`000ol0@_l2ool00006oomd0?ooh`3oon<0oooS
0?oo057o0?mM0_l0Gol3ool0T0?o05oo00?o0?lHoookJ_oo90000_oo9007o`1Oo`?oE@3o00Co0?lf
o`1Gool0o`co0?l<0_ooD@05ooo90003o`2`oooo0;Soo`2h00;oo`2h00?oT?l0o`3o3?l0o``00ol0
/?l00ol0o`coo`0Kool06`05oomi00?oA?l01ol0on09o`3ooQKol`3o1ooo0?000ol0ookobP3oo`3o
h007o`3oh003oomi0?oonf[oA?l000Go0?mC00Co0?onoolX0?oo:03o0?on1Ol0/?l8oolX00?oU?l0
00So0?n]oiCo0?nDo`3oU?l0o`2`oomE0?oo0?n]oeD0o`?ooah00ooonfX3oolT00;o00oo0_l0o``6
o`2`o`03odCo0?oo057oon<000;oon<00_l0ooh2oookJP;o04;o00?oo`11oookJ_oonfX00_l0onl0
1?oonP3oEOl0oeGo0?mEo`03oookJP03oooR0?oo003ooo]Z00Wooo]Z0_oo0?801?ooi03ooo]Zoook
J_oonfX2ofl0o`03oonj0?oo003oo`0000Coo`0000?oo`1WoookJ_oonfX00ooonfX00ooo0:oooo]Z
oookJP0DoookJP;o0?l9[?oonfX00ol0o`Wooo]ZoookJP0CoookJP;oo`2_1?oonfX2ool0I`;ooo]Z
0_l0of001?l0]ooookX0oookJ_m_0?l3oookJP?oo`3b00?oo`25oookJ_oonfX02?oonfX2oooR00?o
oo]Z0_mEo`000ol0]_oo0?o_o`3ok`02oookJP;oo`110_l0@_l3oookJP08oooS0?ooM03oon<0oooS
0?oo057oeOl0o`3hoooio`02ool0T003oookJ_l0oaSo0?lH00;o0?lH00Cooo]ZoolT0?oo903oob@0
0ooonfX3oolN00?oE@3o00Co0?lfo`1Gool0Eooo05Oo0oooD@04on?o0003oomX0?ooS03oo`2h00;o
o`2h0_n@o`02o`3oT@03ool00ooonf[ooo]Z00;oo`0K1Ol0oe<01?oo01_ooo]ZoookJ_oonfX6o`3o
h0;obP3o1ooo0?0Foo<0o`Ooo`3`0_lIo`08o`3oh0?ooo]Z00?oo`0Ko`3oDol0oe<00_l0oe<00ooo
01_ooo]ZoookJP02oookJP?o0?nA1Ooo0;P2oomX00?ohol00oooD@02o`1Go`;o0?lf0omE0?l3oolN
00?ooo]Z0ooo9002oookJP;o0?lH0_oonfX2ool0T0;onOl00_oEo`03oooS0004oomd0?oonf[ooo]Z
oookJP;o04;o0_oo04401Ooonf[o0?o_o`3okol0onoo0;Ko00;oEOl00ooonfX2oooR00[ooo]Z00?o
o`25ool0l_oo0?800ooonfX2ofl0o`03oookJ_oo^P3ookX000;o0?mP0_oonfX2ool0I`Cooo]Z0_oo
0:lEoookJP;o0?l9AooonfX006Oooo]Z0_l0o`TDoookJP?oo`2_0ooonfX2ool0I`05ool00?oonf[o
0?mPo`3oH?oo00000_oo^P03ool000;ooo]Z0ooo0?800ooo08Gooo]ZoookJP07oookJP;oon800ooo
nfX2oeGo0004ool00?oo08Ko0?o_o`3ok`?oo`000_l0@_l3ool00004oomd0?ooh`3oon<0oooS00Co
0?mM0_oo0904o`1Oo`;ooo]Z00?oob@0o`1Oool0Gol01_l0Gol3oeD0o`04o`3o=_l0o`co0?l<o`3o
30;ooe401Ooob@05ool0^0Ko0?l<00?o0;3oool06ol0oe<01oooN@05o`3oh0So0?on3Ooc0?l3ool0
00?o0?n]0_l03ol=oo<0o`Koo`3`0_oo0004o`3oh0;oobP000Co0?oPodCo0?oonf[o0?mC0_l0ooh3
oolX00Ko0?on0ooo0;P4oolX00CoU?l000Ko0?n]oiCo0?nDo`3oU?l0o`2`ool0ojd2oeD0o`Cooah0
0ooonfX3oolT0003o`0?ool0/?oo0;3o00Ko0;3o00?oA?l0ool0DOooh`000_ooh`02o`3ooP;ooo]Z
0_l0@_l00ooo047ooo]ZoookJP02o`3ok`04oooj0?mEo`3oEOl0oeGo00?ooo]Z00?oon80ool00?oo
nfX02?oonfX01?oo08Goo`3bool0l_ooi003oookJP;oK`3o00?ookX0ool00?oo00000ooo00000ooo
nf[oo`1WoookJP04oookJP03ool0[ooonf[ooo]Z01?ooo]Z0_l0o`V[oookJP03o`3o2Ooonf[ooo]Z
01?ooo]Z0_oo0:l4oookJP?oo`1W00Kooo]Zo`3oH?l0of3o0;Oooonj0?oonfX2ofl0o`;ooo]Z0ooo
0?800ooo08Gooo]ZoookJP07oookJP?oon800ooonfX2oeGo0003o`2fool0onoo0?o_00;ooo]Z0_oo
04400ol0@_oooo]ZoookJP02oookJP?oon<000?oo`1AomGo0?l0n?l00_oio`000ooo093ooo]Zoook
JP03o`3o60;ooo]Z0_oo9004oookJP;ooah00omE0?l01?l0ocKo05Ooo`1Gool0Eol3oomA00Cohol0
00?ooh`0ool0^?oo0;P00_oo0;P01_n@o`3o0?nAo`3oTOl0oi7oo`03oookJP;oo`0K1Ol0oe<3oook
JPKo0?oP1ooo0?0=oo<0o`Soo`3G3Ooc0?l8ool0l003olX0ool0on3o0?oP00Co0?oP0_oonfX00ooo
01_o0?mCo`3oD`02o`3oD`Cooo]Z00?oo`03o`3oTOl0oi401?oo0;P00on@o`3oofP0oomX0003on?o
00?ooe400_l0Eol2o`3o=P;oE@3o00Cooo]ZoolN0?oo7P3ooah00ooonfX3oolT0005oookJ_l0oaSo
0?lHo`3o6?oonfX00_oo09001?oio`3oeOl0omGo0?oo0543oooS0004oomd0?oonf[ooo]ZoookJP;o
04;o0_oo04401Ooonf[o0?o_o`3okol0onoo0;Ko00;oEOl00ooonfX2oooR00[ooo]Z0ooo0?83oook
JP;oK`3o0ooo^P02o`3oH0;ooo]Z0_oo06L4oookJP;oo`2_5?oonfX2o`3o2DOooo]Z001WoookJP;o
0?l95?oonfX2ool0[`?ooo]Z0_oo06L01Ooo003ooo]Zo`3oH?l0of3o0;Oo00;ookX00ooo0002oook
JP?oo`3b00?oo`25oookJ_oonfX01ooonfX2oooR00?ooo]Z0_mEo`001_oo003oo`26o`3okol0onoo
oo]Zool000?o04;o0ooo00000oooM03oon<0oooS0004o`3oG@?oo`2@1?l0Gol00ooonf[o05ooo`1O
o`07o`1Oo`?oE@3o00Co0?lfo`1Gool0Eooo0?l<0_ooD@05ooo900Coo`2h00?oT?l0o`3o3?l0o``0
1?l0o``00ooo01_o0?mCo`3oD`02o`3oD`?oogT01?l0on09o`1Oo`Gol`3o0_l0ooh7oomC00;oo`00
4oooD`000ol03oool`3ooo<0o`07oo<0o`?oo`0000Coo`3`olX0ool0on3o0?oP0ooo:0000om4o`3o
oo]ZoolX0004oolX00?oogT01?l0ooh4ool0^003oon<0?nDo`3oU?l000?oU?l00_l0ojd01?nDo`3o
0?n]o`3o[Ol0ojd3oeD0o`?ooah00ooonfX2oolT00[o0;3o00?oA?l0ool0DOooh`000_ooh`02o`3o
oP;ooo]Z0_l0@_l00ooo047ooo]ZoookJP02o`3ok`04o`2foomEo`3oEOl0oeGo00?ooo]Z00?oo`00
oooR0?oonfX02?oonfX00ooo08Goo`3bool0lP04oookJP04ofl0oooonf[ookX0o`2go`Coo`000_oo
06L4oookJP;oo`2_5OoonfX00ol0o`Wooo]ZoookJP2XoookJP;o0?l95?oonfX2ool0[`Cooo]Z0ooo
06L01_oonf[o0?mPo`3oH?l0]ooookX0oookJP;oK`3o0_oonfX3ool0lP03ool0QOoonf[ooo]Z00Oo
oo]Z0_oohP03oookJP;oEOl00_l0]_l2o`3ok`;ooo]Z00?oo`11o`12ool0@_l01?oonfX3oooS0004
ool0DOoEo`3o0?SoooWo00;oo`2@0_oonfX3o`3o6003oookJ_oo903oob@000Cooo]Z0_oo7P03oeD0
o`04o`3o=_l0Eooo05Ooo`1Go`?ooe400ooSo`000oooJ03ooh`0ool0^002ool0^0;oT?l00_l0oi40
1?oo00?ooo]ZoookJ_oo01/5o`3oD`?ooo]Z1Ol0on05ool0l0Sol`3o00?oo`3GoomC0?ooD`006ooo
D`000ooo0=Ool`3ooo<0o`06oo<0o`Coo`3`00?o6Ol0o`3oh?l0on001?l0on02oookJPCo0?mC00Go
o`0KoookJ_oonf[ooo]Zool00`02o`3oT@Coo`2h00?oT?l0oon<0?ooJ0000ooSo`03oomA0004o`1G
ool0ocKo0?lfo`3o=P;oE@3o1?oo7P03oookJP;oob@00_oonfX2o`3o6003oookJ_oo093oo`2@00;o
nOl000?oeOl0ool0DOooh`000_ooh`001?ooM03ooo]ZoookJ_oonfX2o`12o`;oo`1100Cooo]Zo`3o
kol0onoo0?o_0omEo`03oookJP;oon802_oonfX3ool0lP?ooo]Z00CoK`3ooookJ_oo^P3ookX00_l0
of02oookJP?oo`1W1?oonfX2ool0[aCooo]Z0_l0o`U6oookJP00I_oonfX2o`3o2ACooo]Z0_oo0:l3
oookJP;oo`1W00?oo`00oookJ_l0of000_l0of03oonj00?oo`0000Gooo]ZoooT0?oo0?;oo`3bool0
Q@09oookJP;oon800ooonfX2oeGo0003o`2foooo08Ko0?o_00;ooo]Z00Coo`11o`12ool0@_oo04;o
0ooo0003oooS00Co0?mM0_oo0902o`3oG@?o05oo00?ooo]Zo`1Oool0Gol01ol0Gol3oeD0o`?o05Oo
0oooD@02on?o0003ooo90?l0o`coo`2h00?oo`2h00?oT?l0ooo90?oob@000ol0o``00ooob@3oo`0K
o`3oD`03o`3oD`03oookJ_l0Gooo05oo00go05oo0_oc0?l00ol0ookooe<0oomC000;oomC00;oU?l0
1ol0ojd6o`0?o`Wooe<00ooo0007oo<0o`05ool00?oo0?3oo`3`ool0l?l0ooh00_l0on09oolX00;o
U?l00oooN@001?l0oi7oogT0ool0^?oo0;P8oiCo00;o00oo0ol0ojd01?l0/?ooE@3ooeD0oomE0?l3
oolN00;ooo]Z0ooo9008o`2`o`;o0?on00Goo`1AoooS0?ooh`3oon<0o`3ooP03oookJP;o04;o00?o
o`11oookJ_l0onl00_l0onl00ol0]_ooEOl0oeGo0004oookJP03ool00?oohP3ooo]Z00Sooo]Z0ooo
0?83oookJP;oK`3o0_oo^P001_l0]oooo`00ool00?oo003ooo]Zool0I`Gooo]Z0_oo0:lEoookJP03
o`3o2Ooonf[ooo]Z0:Kooo]Z0_l0o`TDoookJP;oo`2_1?oonfX3ool0I`04oookJ_l0of3o0?mPo`2g
o`;ookX00_m_0?l2oookJP04oooT0?oo0?;oo`3bool0Q@Wooo]Z0_oohP03oookJP;oEOl00_l0]_l2
o`3ok`03oookJ_oo047oo`1100;o04;o1?oonfX3oooS0004omGo0?l0n?oonOl0ooWo00;oo`2@00Go
oo]Zo`3o6?l0oaSo0?lHoookJP03oolT00?ooo]Z0_oo7P001?oonf[oE@3ooeD0oomE0?l3o`1Go`?o
oe400ooSo`02oon<00?oo`2h0_n@o`02o`3oT@?ooo]Z00?oo`0Ko`3oDol0oe<00_l0oe<2oookJPGo
0?oP1_oo0?05oo<0o`03ool0eoooD`3ooe<000_ooe<03ooonfX=oomC00Kol`3o1?oo0?000olIo`3o
0?oPo`3oh003o`3oh0?ooo]Z1?l0oe<3oookJP03ool00ol0oi7o0?nA00Coo`2h0_ooS0001?ooJ03o
hol0on?o0?oSo`03oomA0003o`1Gool0ocKo0?lf00?oE@3o0ooo7P03oookJP;oob@00_oonfX2o`3o
6007oookJ_oo093oo`2@ool0T?oio`3oeOl0ool0D@03oooS0004oomd0?oonf[ooo]ZoookJP;o04;o
0_oo04401?oonf[o0?o_o`3okol0onl2oeGo00Cooo]Z0_oohP09oookJP04ool0QOoo0?;oo`3bool0
lP?ooo]Z00CoK`3ooookJ_oo^P3ookX00_l0of02oookJP;oo`1W1?oonfX2ool0[aGooo]Z00?o0?l9
oookJ_oonfX0A?oonfX006Gooo]Z0_l0o`TDoookJP;oo`2_1?oonfX00ooo06Ooo`00oookJP03o`3o
H0?ookX00ooo00001Ooonf[oon@0ool0l_oo0?;oo`2500Wooo]Z0_oohP03oookJP;oEOl000?o0;Ko
o`3okol0onl00_oonfX01?oo047o04;oo`12ool0@_l2ool00004oomd0?ooh`3oon<0oooS00?o0?mM
00?o05ooool0T?oo09000ol0oed01?l0oaSo05oooolT0?oo9007o`1Oo`?oE@3o0_l0Gol01?l0Eooo
oe40oomA0?ooD@03on?o0003oon<0?l0o`coo`2h00;oo`2h00?oT?l0ooo90?oob@000ooob@000ol0
o`co0?mCo`3oD`02o`3oD`04o`0?ool0on3o0?oPo`3oh0go05oo1_ooD`000ol0ookoobP0oolX0003
oolX0003o`000?nDo`3oU?l000?oU?l00_oo:003o`3o[@?oobP000CoU?l0o`0?ool03ooo00oo0_nD
o`02o`3o[@;o00oo0_l0ojd00ol03ooooo]ZoomC0004oomC00Goo`001Ooc0?l4ool0l004o`3oo_oo
:03oU?l0oiCo00GoobP00onDo`03oomi00?oA?l00ooo0;P5oiCo00;o0?n]00Go00ooo`3o[Ol0ojgo
0?n]o`2`o`03oeD0o`?ooah00ooonfX2oolT0003oookJ_l0oaSo0;3o00Go0;3o0_l0ooh01Ooo057o
on<0oooS0?ooh`3o0?on00;ooo]Z0ol0@_l2oookJP;o0?o_00Coo`26oeGo0?mEo`3oEOl01?oonfX0
0ooo003oon80oookJP08oookJP;oo`3b1?oonfX2ofl0o`;ookX000Cooo]Zool00?oo003oo`000_oo
06L4oookJP;oo`2_5OoonfX2o`3o2JKooo]Z0_l0o`TDoookJP?oo`2_1?oonfX2ool0I`04oookJ_l0
of3o0?mPo`2go`;ookX00_m_0?l2oookJP04oooT0?oo0?;oo`3bool0Q@Wooo]Z0_oohP03oookJP;o
EOl000Go0;Koo`3okol0onoo0?o_oookJP02ool0@@;o04;o0ooonfX01oooM03oon<0oooS0?oo057o
eOl0o`3hoooio`000_oo0902oookJP?o0?lH0ooo9003oookJP?ooah00omE0?l3o`1Go`?ooe400ooS
o`02oon<00?oo`2h00CoT?l0o`3oTOl0oi7oo`030_oonfX2ool06`Co0?mC00?ooo]Zo`3oh?l0on00
0ol0on05ool0l0Col`3o2?ooD`02oookJPCo00006ooonfX:oomC00Gol`3o1Ooo0?001Oo:0?oo0?oP
o`3oh?l0on3obP3o00;ooo]Z1?l0oe<3oookJP03ool00ol0oi7o0?nA00Coo`2h0_ooS0001?oo0;co
hol0on?o0?oonfX2oomA00;o05Oo00Co0?lfoookJ_mE0?ooE@3o0ooo7P03oookJP;oob@000Gooo]Z
o`3o6?l0oaSo0?lHoookJP03ool0T003ooWo0?oEo`3oo`1A00?oon<000Coog@0oookJ_oonf[ooo]Z
0_l0@_l00ooo047ooo]ZoookJP02o`3ok`03o`2foomEo`3oEOl000Cooo]Z0_oohP09oookJP03ool0
QOoo0?;oo`3b00?ooo]Z0_m_0?l2oonj0003o`2gool0of3o0?mP00;ooo]Z0_oo06L4oookJP;oo`2_
5?oonfX2o`3o2DGooo]Z001ToookJP;o0?l95?oonfX2ool0[`Cooo]Z00?oo`1Wool00?oonfX00ol0
of03oonj00?oo`000_oonfX2ool0lP03ool0QOoonf[ooo]Z00Oooo]Z0_oohP03oookJP;oEOl000?o
0;Koo`3okol0onl00_oonfX01ooo047o04;oo`12ool0@_oooo]Zool00?ooM0000oooh`03o`3oG@?o
o`2@0ol0oed2oookJP04oolT0?oonf[ooo]Zo`3oG@Co05oo0omE0?l3o`1Oo`03ooo90?ooD@3ooe40
00?ohol000?o0?l<ooo90?oo0;P00_oo0;P00on@o`3oolT0ooo90003ooo90005ool06ol0oe?o0?mC
o`3oDooonfX00ol0on03o`3oG@co05oo0oooD`02oookJP03o`3oo_oonf[oobP000?oobP06ooo07<3
o`3o[@03o`0?ool0ooko0?on00;o00oo0_l0ooh7ool000Col`3o0_oo0?03oolX00;oU?l00_oo:005
oiCo00KoA?l000Ko0?nAool0^?oo0;Soo`2hoon<0?nDo`04o`3o[@08o`0?ool0ojgo0?n]o`3o[Ol0
/?oooo]Zo`0?oomE0?l3oolN00?ooo]Z0_oo90000ooonf[o0?lHo`3o6005o`2`o`;o0?on00Goo`1A
oooS0?ooh`3oog@0o`3ooP02oookJP?o04;o0_oonfX2o`3ok`04ool0Q_mEo`3oEOl0oeGo00Cooo]Z
00?oo`00oookJ_oonfX01ooonfX00ooo08Goo`3bool0lP04oookJP04ofl0oooonf[ookX0oonj00;o
0?mP00Coo`00oookJ_oo06Ooo`1W1?oonfX2ool0[aGooo]Z00?o0?l9oookJ_oonfX0XooonfX2o`3o
2ACooo]Z0ooo0:l4oookJP;oo`1W00Cooo]Zo`3oH?l0of3o0;Oo0_oo^P02ofl0o`?ooo]Z0_oo0?80
0ooo08Gooo]ZoookJP07oookJP;oon800ooonfX2oeGo0005o`2fool0onoo0?o_o`3okooonfX00_oo
0442o`12o`?ooo]Z0oooh`000ooo057oeOl0o`3ho`03ool0T005oookJ_l0oaSo0?lHo`3o6?oonfX0
0_oo9004oookJP;ooah01?mE0?l3o`1Go`;ooe401?oSo`001OooS03oo`2hool0^?oo0;SoT?l000;o
0?nA00Coo`03oookJ_oonf[oo`0K1?l0oe<00ooonf[o0?oPo`3oh003o`3oh0Coo`3`1Ooc0?l6oomC
00Oooo]Z00?o0000ool0Looo07<06Ooo07<:oookJPOooe<01Ooc0?l4ool0l0Co0?oP00?obP3ooook
J_oonfX00_l0oe<2ool06`;ooo]Z00?oo`03o`3oTOl0oi400ooo0;P2oon<0004oomX0?oSo`3ohol0
oookJP;ooe400_l0Eol01?l0ocKooo]ZoeD0oomE0?l3oolN00?ooo]Z0_oo90000ooonf[o0?lHo`3o
6002o`3o60?oo`2@00?onOl0omGo0?oo05400_ooh`02oomd00?ooo]Z0_l0@_l00ooo047ooo]Zo`3o
k`02o`3ok`03o`2foomEo`3oEOl000Cooo]Z00?oon80oookJ_oonfX02?oonfX3ool0lP?ooo]Z00Co
K`3ooookJ_oo^P3ookX00ol0of001?oonf[oo`1Wool0Iooo06L4oookJP;oo`2_5?oonfX00ol0o`Wo
oo]ZoookJP13oookJP00HooonfX2o`3o2ACooo]Z0ooo0:l3oookJP03ool0Iooo003ooo]Z00?o0?mP
0ooo^P04ool00004oookJ_oo0?;oo`3bool0Q@Sooo]Z0ooohP03oookJP;oEOl000?o0;Koo`3okol0
onl00_oonfX00ooo047o04;oo`12o`02oookJP04o`0?ooooM03oon<0oooS00;oiOl00_l0oed3ool0
T0?o0?mM00Cooo]ZoolT0?oo903ooo]Z0ol0oed2o`1Oo`CoE@3o0_l0Gol01?oob@3ooe40oomA0?oo
D@02on?o00;oolT00ooo0;P00on@o`3o0?l<ooo90003ooo900Co0?mC00?ooo]Zo`3oh?l0oed01ol0
oed9o`1Oo`03oomC0?m4o`3oA?l000?o00oo3Ooo07<6oiCo0003o`3o[Ooo:03oobP000GoobP03Ooo
07<4o`0?o`[oo`001?oc0?l4oolX00?oU?l00_l0ojd3oiCo00;o0?mC00Ko0?n]odCo0?m4o`3oA?l0
o`3oTOl0ooh2ool0^003oi3o0?l0ojgo0?n]00?o0?n]0_l03ol2o`3o[@05o`2`ool03oooE@3ooeD0
oooonfX00_oo7P03oookJP;oob@000Cooo]Zo`3o6?l0oaSo0?lH1?l0/?l00ol0ookoobP0oolX0002
oooS0004oomd0?l0ookooo]ZoookJP?o04;o0_oonfX2o`3ok`04o`2foomEo`3oEOl0oeGo00?ooo]Z
00Coo`00oooR0?oonf[ooo]Z0_oo0005oookJP03ool0QOoo0?;oo`3b00?ooo]Z0_m_0?l00ooonf[o
okX0o`2go`02o`3oH004ool00?oonf[oo`1Wool0I`Cooo]Z0_oo0:lDoookJP;o0?l9XooonfX3o`3o
2A?ooo]Z0ooo0:l4oookJP;oo`1W00Cooo]Zo`3oH?l0of3o0;Oo0_oo^P02ofl0o`?ooo]Z0_oo0?80
0ooo08Gooo]ZoookJP07oookJP;oon800ooonfX2oeGo0003o`2fool0onoo0?o_00?ooo]Z00?oo`11
o`12oooonfX00ooonfX3oooS00;oeOl000Go0?Soool0T?oo093oo`2@oookJP03o`3o6003oookJ_oo
903oob@000?ooo]Z0_oo7P04oeD0o`?o05Oo0oooD@03on?o0005oon<0?oo0;Soo`2hool0^?n@o`00
0_l0oi401?oo00?ooo]Zool06ooo01/3o`3oD`;ooo]Z1Ol0on03ool0l0Gol`3o1OooD`05oookJPko
o`1c3_ooa@0<ool0L`Sooo]Z1_ooD`05oo<0o`Coo`3`1?l0on02oookJP?o0?mC00Coo`0KoookJ_oo
nf[oo`030_l0oi42ool0^004oi3o0?ooS03oofP0oomX00;ohol00oooD@02o`1Go`04o`3o=_mE0?oo
E@3ooeD0o`;ooah00ooonfX2oolT0003oookJ_l0oaSo0?lH00;o0?lH0ooo09000ooio`3oeOl0ool0
D@02oooS00;oog@00ooonfX2o`12o`03ool0@Ooonf[o0?o_00;o0?o_00?o0;KooeGo0?mEo`000ooo
nfX2oooR00[ooo]Z0_oo0?84oookJP04ofl0oooonf[ookX0oonj00?o0?mP00Cooo]Zool0Iooo06Oo
o`1W0ooonfX3ool0[a?ooo]Z0_l0o`U4oookJP00HooonfX2o`3o2A?ooo]Z0ooo0:l3oookJP04ool0
Iooo003ooo]ZoookJP;o0?mP00?oo`00oonj0?oo^P001?oo00001?oonf[oo`3bool0l_oo08D8oook
JP?oon800ooonfX2oeGo0003o`2fool0onoo0?o_00;ooo]Z00Coo`11o`12ool0@_oooo]Z0_l03ol0
0oooM03oon<0oooS0003onGo00?oo`2@1Ol0oed00ooo903o0?mMo`3oG@03o`3oG@;o05oo0omE0?l3
o`1Oo`?ooe400_oSo`02ooo900?oo`2h00CoT?l0o`3o3?l0o`co0?l<0ooob@03o`3oD`04o`3o[Ol0
on3o0?oPo`3oh0Ko0?mM2Ol0Gol2oookJP03odCo0?l03ooo00oo00Woo`1c1_oo:003o`0go`KoobP0
1onDo`03o`3o[@;oU?l01Ol0ojd8ool0L`[oo`0000?oobP0oo<0oooc0?l00_oc0?l2oolX00CoU?l0
00Go0?n]oiCo0?nDo`3oU?l0o`3oD`02o`3o[@GoA?l000?oo`2ho`3o[Ol0ojd01_l0ojd00ol03ooo
0?n]o`0?o`02o`0?o`;oE@3o00Cooo]ZoolN0?oo7P3ooah00_oonfX2oolT0006oookJ_l0oaSooo]Z
o`3o6?oonf[oo`2@0_l0/?l3oolX00;oon<000Coog@0oookJ_oonf[ooo]Z0_l0@_l00ooo047ooo]Z
oookJP02o`3ok`04o`2foomEo`3oEOl0oeGo00?ooo]Z00?oo`00oooR0?oo00000_oo0006oookJP03
ool0QOoo0?;oon@000?ooo]Z0_m_0?l2oonj0004o`2gool0of3o0?mPoookJP;oo`1W1?oonfX2ool0
[aGooo]Z0_l0o`VRoookJP;o0?l94ooonfX3ool0[`Cooo]Z0_oo06L2oookJP04o`3oH?l0]ooo0;Oo
oonj00;oK`3o0ooonfX2ool0lP03ool0QOoonf[ooo]Z00Oooo]Z0ooohP02oookJP?oEOl00_l0onl2
oookJP03ool0@Ol0@_oo04;o00Cooo]Z0_ooh`001?oo057oeOl0omGo0?oio`03ool0T004oookJ_l0
oaSo0?lHoookJP?oob@00_oonfX3oolN00CoE@3o0_l0Eol3oomA00?ohol00_ooS002ool0^005oi3o
0?l0oi7o0?nAool00ooonfX00_oo01/3o`3oD`03oookJ_l0on3o0?oP00?o0?oP0ooo0?05oo<0o`Go
oe<01OoonfX:ool0L`GoolD05?l0=ol7ooo500Ooo`1c1OoonfX6oomC00Gol`3o0ooo0?03o`3oh003
olX0oooonf[o0?mC00?o0?mC00Coo`0KoookJ_oonf[oo`030_l0oi42ool0^0;ooh`000CoofP0on?o
0?oSo`3ohol00oooD@02o`1Go`03oookJ_mE0?ooE@3o00?ooah00_oonfX2oolT0003oookJ_l0oaSo
0?lH00;o0?lH0ooo09000ooio`3oeOl0ool0D@02oooS00;oog@00ooonfX01?l0@_ooo`11ool0@Ooo
nfX3o`3ok`03o`2foomEo`3oEOl000?ooo]Z0_oohP0:oookJP;oo`3b0ooonfX2ofl0o`;ookX000?o
0;Ooo`3oH?l0of000_oonfX2ool0I`Cooo]Z0_oo0:lDoookJP;o0?l9@ooonfX006;ooo]Z0_l0o`TD
oookJP;oo`2_0ooonfX01?oo06Ooo`00oookJ_oonfX2o`3oH003ool00?oo^P3ookX000Goo`000_oo
0?800ooo08Gooo]ZoookJP06oookJP?oon800ooonfX2oeGo0006o`2fool0onoo0?o_oookJ_oo047o
o`000_l0@_l01?oonf[o00oooomd0?ooM002oooS00?oiOl00ooo090;o`3oG@04o`1Oool0oegoE@3o
oeD0o`?o05oo0oooD@02on?o0003oon<0?oob@3ooh`000;oo`2h00SoT?l0ooo90?l0oi7oU?l0o`3o
3?nDo`3o0?mCooo900;o0?mC0_l0on05onGo00;o0?mM0ol0Gol2o`3oG@_o05oo0ooo07<5ooo50003
o`3o_Ol0=ooo03Oo00_o03Oo00?oU?l0oolX0?oo:0001Ooo:005oiCo00Co0?n]0ol03ol00ol0ojgo
00ooo`0?o`02o`0?o`Koo`1c2_oo00000ooo0=Ool`3ooo<0o`02oo<0o`CoU?l00_l0ojd00onDo`3o
0?n]o`3o[@02o`3o[@07odCo0?l0ooko0?ono`3oo_l0oi7oA?l0ool0^007o`3o[@Go00oo0_mE0?l0
1?oonf[ooah0oolN0?oo7P02oookJP;oob@000Gooo]Zo`3o6?oonf[o0?lHoookJP02ool0T004o`2`
oooo:03oobP0oolX00;oon<000Coog@0oookJ_oonf[ooo]Z0_l0@_l00ooo047ooo]ZoookJP02o`3o
k`04o`2foomEo`3oEOl0oeGo00;ooo]Z1_oo0006oookJP;oo`3b00Coon@0oookJ_oonf[ooo]Z0_m_
0?l2oonj00?o0?mP00?ooo]Zool0Iooo06L01?oonfX2ool0[aCooo]Z0_l0o`VQoookJP;o0?l95?oo
nfX2ool0[`Cooo]Z0_oo06L2oookJP;o0?mP00?o0;Oooonj0?m_0?l00_m_0?l2oookJP?oo`3b2Ooo
nfX3oooR00;ooo]Z0omEo`02o`3ok`;ooo]Z00?oo`11o`12ool0@_l00ooonfX01?ooM03oon<0oooS
0?oo0542omGo0003ooWo0?oo093oo`2@00;ooo]Z0_l0oaP00ooonf[oob@0oolT0003oookJP?ooah0
0omE0?l00ol0ocKo05OooomA0002oomA00?ohol00_ooS003ool0^0;o0?nA00?oo`03oookJ_oonfX0
1?l0oe<5o`3oh0Coo`3`1?oc0?l4oomC00Kooo]Z1_oo07<5ooo500ko03Oo1ooo0<d<o`0go`KoolD0
1Ooo07<5oookJPGooe<000?ooo]Zoo<0oooc0?l00ooc0?l2ool0l0Co0?oP00Cooo]Zo`3oDol0oe?o
0?mC0_oo01/2oookJP;o0?nA0ooo0;P2oon<00?ohol00oooD@02o`1Go`03oookJ_mE0?ooE@3o00?o
oah00_oonfX3oolT00Co0?lH0ooo09000ooio`3oeOl0ool0D@02oooS00;oog@00ooonfX01?l0@_oo
o`11oookJ_oonfX3o`3ok`?oEOl00ooonfX00ooohP3ooo]ZoookJP08oookJP03ool0QOoo0?;oo`3b
00?ooo]Z0_m_0?l2oonj00?o0?mP00Cooo]Zool0Iooo06Ooo`1W0ooonfX3ool0[a?ooo]Z0_l0o`U3
oookJP00HOoonfX2o`3o2ACooo]Z0_oo0:l3oookJP04ool0Iooo003oo`1WoookJP?o0?mP0_oo^P05
ool000?oo`3b2?oonfX3oooR00?ooo]Z0_mEo`001_l0]_oo0?o_o`3okooonf[oo`11ool000;o04;o
0_l03ol2oomd00;oon<00ooUo`03ool0T0;oiOl02?l0oed2o`1Oo`06o`3oGOmE0?ooE@3oo`3oGOl0
Goooo`000oooD@02on?o00;ooh`00_oo0;P01On@o`3oolT0ooo90?nDo`3oobP000Go0?mC00?o0?oP
onGo0?oUo`001_oUo`02o`1Oo`Ko0?mM2?l0Gol01?oo07?oolD0ooo50?ooa@08o`0go`Coo`3=1_oo
:0000ooo0<goU?l0oiCo0007oolX00KoU?l01_l0ojd2ooo900Oo00oo1Ooo07<8ool00003oomC0?oo
0=Ool`3o00;ol`3o1OnDo`06o`3o[@04o`3oDol0ooko0?ono`3ooP;o0?nA0ooo0;P3o`3o[@Oo00oo
0omE0?l00ooo7P3oobP0oolN0002oookJP?oob@00_l0oaP2oolX00;oo`2@1?oo:002oooS0004oomd
0?oonf[ooo]ZoookJP;o04;o00?oo`11oookJ_l0onl00_l0onl01?l0]_ooEOl0oeGo0?mEo`07ool0
00Kooo]Z00Coo`25ool0l_oo0?;oon@00_oonfX2ofl0o`?ookX00_l0of000ooonf[oo`1Wool0I`04
oookJP;oo`2_5?oonfX3o`3o2Ioooo]Z0_l0o`TDoookJP;oo`2_1?oonfX2ool0I`;ooo]Z0_l0of00
0ol0]ooookX0oookJP02ofl0o`;ooo]Z0ooo0?800ooo08Gooo]ZoookJP06oookJP?oon800_oonfX3
oeGo00;o0?o_0_oonfX00ooo047o04;oo`12o`03oookJP04oomd0?ooh`3oon<0ool0D@;oeOl000Co
nOl0ool0T?oo093ooo]Z0ol0oaP3oolT00?ooo]Z0ooo7P02oeD0o`03o`3o=_l0Eooo05Oo00?ooe40
0ooSo`001?ooS03oo`2hool0^?oo0;P2o`3oT@03ool00ooonf[ooo]Z00Co0?mC1Ol0on04ool0l0?o
l`3o1?ooD`05oookJPGoo`1c0oooa@09o`0go`coo`3=1ooonfX;ool0c@So03Oo0oooa@04ool0L`Go
oo]Z1?ooD`000ooonf[ol`3ooo<0o`02oo<0o`?oo`3`1?l0on001?oonf[o0?mCo`3oDol0oe<2ool0
6`04oookJ_oo00?o0?nAo`3oT@;oo`2h0_ooS0000oooJ03ohol0on?o0003oomA00;o05Oo00?ooo]Z
oeD0oomE0?l00ooo7P02oookJP?oob@00ol0oaP00ooonf[oo`2@ool0T002ooWo0004omGo0?oo057o
on<0oooS00;oog@00ooonfX01?l0@_ooo`11oookJ_oonfX3o`3ok`?oEOl00ooonfX00ooohP3ooo]Z
oookJP08oookJP;oo`3b00?oon@0oookJ_oonfX00_m_0?l3oonj00;o0?mP0_oonfX2ool0I`Cooo]Z
0_oo0:lCoookJP?o0?l9@_oonfX0067ooo]Z00?o0?l9oookJ_oonfX04_oonfX2ool0[`?ooo]Z00Co
o`1Wool00?oo06Oooo]Z0ol0of02oonj00Goo`000ooo0?88oookJP?oon800ooonfX2oeGo0006o`2f
ool0onoo0?o_oookJ_oo047oo`000_l0@_l2o`0?o`;oog@000?oon<0onGo0?oUo`000_oUo`03ool0
T0;oiOl000Co0?lHoolX0?l0oegoob@01?l0oed01?l0Gooo0?mMoeD0oomE0?l2o`3oG@;o05oo0_oo
D@02on?o0003ooo90?ooS03oo`2h00;oo`2h0ooob@000ooo:03o0?mCo`3oD`02o`3oD`;o0?on0_l0
on06onGo00Wo0?mM2?l0Gol2ool000Ko03Oo1_oo0<d2o`0000CoobP00_oonfX<o`3oF@GoU?l01_l0
ojd4ooo900;o00oo0_l0o``5o`0?o`Coo`1c1?oonfX3oomC00;oU?l01?oc0?l2oiCo0003o`3o[Ol0
3ooo00oo00Co0?n]00Go0?mCo`0?ool0ooko0?onool00`02o`3oT@?oo`2h2?l03ol01_l0ocKoE@3o
oeD0oomE0?ooobP0oolN00?ooo]Z0ooo9004oolX00;oo`2@0ooo:003oooS00Cooo]Z0_l0@_l00ooo
047ooo]Zo`3ok`02o`3ok`03o`2foomEo`3oEOl000Soo`001_oonfX00ooo08Goo`3bool0lP03oook
JP05ofl0ooooN@3ookX0oonj0?l0]ol00_l0of000ooonf[oo`1Wool0I`04oookJP;oo`2_5?oonfX2
o`3o2Ioooo]Z0_l0o`TCoookJP;oo`2_1?oonfX2ool0I`;ooo]Z0_l0of000ol0]ooookX0oookJP02
ofl0o`;ooo]Z0ooo0?800ooo08Gooo]ZoookJP06oookJP?oon800_oonfX3oeGo00;o0?o_0_oonfX0
0ooo047o04;oo`12o`03oookJP06oomd0?ooh`3oon<0ool0DOoEo`3o0?So0ooo09001?oonf[o0?lH
o`3o6?oonfX3oolT00?ooo]Z0_oo7P03oeD0o`03o`3o=_l0Eooo05Oo00;ooe400ooSo`001oooS03o
o`2hool0^?oo0;SoT?l0o`3oTOoo00<00_oonfX4o`3oD`03oookJ_l0on3o0?oP00;o0?oP0ooo0?04
oo<0o`?ooe<01OoonfX5ool0L`;oolD01ol0=ol6ool0c@?o00001_oonfX;o`3oF@[ooo]Z1Ooo0<d6
o`0go`?oolD01?oo07<4oookJPCooe<000?ooo]Zoo<0oooc0?l00ooc0?l2ool0l0?o0?oP00CobP3o
oookJ_l0oe?o0?mC0_oo01/2oookJP03ool00ol0oi7oT?l000;oo`2h00Cooh`0oomX0?oSo`3ohol0
0oooD@000ol0Eooo0?lfoookJP02oeD0o`;ooah00ooonfX3oolT00?o0?lH00?ooo]Zool0T?oo0900
0_oio`001OoEo`3oo`1AoooS0?ooh`3oog@000?ooo]Z0_l0@_l00ooo047ooo]ZoookJP03o`3ok`;o
EOl00ooonfX2oooR00Wooo]Z00?oo`25ool0l_oo0?800ooonfX2ofl0o`?ookX00_l0of001?oonf[o
o`1Wool0Iooo06L3oookJP;oo`2_5?oonfX2o`3o2D;ooo]Z001PoookJP;o0?l95?oonfX2ool0[`;o
oo]Z00?oo`1Wool00?oo06L00_oonfX2o`3oH0;ookX000?oK`3oool00?oo00000_oo0003ool0lPSo
oo]Z0ooohP03oookJP;oEOl000Ko0;Koo`3okol0onoooo]Zool0@Ooo0002o`12o`;o00oo0_ooM000
0oooh`3oiOl0onGo0002onGo00?oo`2@0_oUo`001?oonf[oob@0oolT0?oo9002onGo0003o`3oGOl0
Gooo05oo00?oE@3o0_l0oed00ol0Gooooe40oomA0003on?o0005oon<0?oo0;Soo`2hool0^?oo0000
0ooob@001?oo01_o0?mCo`3oDol0oe<2o`3ooPCo0?oP00?oo`3`onGo0?oUo`000ol0oed3onGo00Go
0?mM1ol0Gol2ool00003o`0gool03ooo00oo00Wo00oo7?l0oeT3ooo900;o0?n]1_oob@03o`3o30Go
00oo0_ooa@04ool0L`Cooo]Z0oooD`000ooonf[ol`3ooo<0o`02oo<0o`?o0?n]00?o00ooo`3o[Ol0
ojd00_l0ojd01Ol03ooo0?mCo`3oo_l0ookooo]Z00;o0?on00?oo`2ho`0?ool03ol02?l03ol01_l0
EoooE@3ooeD0oomE0?ooobP0oolN00?ooo]Z0ooo90001?l0oaSoobP0oolX0?oo:002ool0T0?oobP0
0oooh`03oookJP?o04;o0_oonfX2o`3ok`04o`2foomEo`3oEOl0oeGo00Ooo`001ooonfX3ool0lP;o
oo]Z0_m_0?l00oooN@3ookX0oonj0002o`3oH003oookJ_oo06Ooo`1W00Cooo]Z0_oo0:lDoookJP;o
0?l9W_oonfX2o`3o2ACooo]Z0_oo0:l3oookJP;oo`1W0_oonfX2o`3oH003o`2goooo^P3ooo]Z00;o
K`3o0_oonfX3ool0lP03ool0QOoonf[ooo]Z00Kooo]Z0ooohP02oookJP?oEOl00_l0onl2oookJP03
ool0@Ol0@_oo04;o00?ooo]Z00Koog@0oooS0?ooh`3oo`1AomGo0?oio`03ool0T0?o0?lH00?ooo]Z
oolT0?oo90000ooonfX2oolN00CoE@3o0ol0Eol2oomA00;ohol000?oofP0oon<0?oo0;P00_oo0;P2
o`3oT@;ooo]Z00Goo`0Ko`3oDol0oe?o0?mCoookJP04o`3oh0?oo`3`0ooc0?l4oomC00Cooo]Z1Ooo
07<2ooo500Ko03Oo1Ooo0<d4oookJQoo0?mI1OoonfX4ool0c@Go03Oo1?ooa@03ool0L`Cooo]Z0ooo
D`000ooonf[oo`3Goo<0o`03oo<0o`;oo`3`0ol0on001Oo:0?oooo]Zo`3oDol0oe?oo`0K00;ooo]Z
00?oo`03o`3oTOn@o`000_oo0;P2oon<0003oomX0?oSo`3ooo]Z00;ooe400_l0Eol00ol0ocKoE@3o
oeD0o`03oolN00;ooo]Z0ooo9003o`3o6003oookJ_oo093oo`2@00;onOl000GoeOl0ool0DOooh`3o
on<0oomd0003oookJP;o04;o0ooonfX2o`3ok`03o`2foomEo`3oEOl000?ooo]Z0_oohP09oookJP03
ool0QOoo0?;oo`3b00?ooo]Z0_m_0?l2oonj00;o0?mP0_oonfX2ool0I`Cooo]Z0_oo0:lCoookJP;o
0?l9@_oonfX005oooo]Z0_l0o`TDoookJP;oo`2_0_oonfX00ooo06Ooo`00ool0I`02oookJP;o0?mP
0ooo^P001Om_0?ooo`00ool00?oo003oon@000;oo`3b2?oonfX3oooR00?ooo]Z0_mEo`001_l0]_oo
0?o_o`3okooonf[oo`11ool000;o04;o0_l03ol01oooM03oon<0oooS0?oo057o00ooonGo0?l0oed0
0_oo0904onGo0003oolT0?oUo`3oiOl000?oiOl000?o05ooo`3oGOmE0?l00_mE0?l3o`3oG@;ooe40
0_oSo`000ooob@3ooh`0ool0^002ool0^0?oo`0000CoolT0o`3oDol0oe?o0?mC0_l0ooh3o`3oh0Co
o`3`00?oiOl0o`3oGOoUo`001?oUo`04o`3oG@Oo05oo0ooo00000ol0=oooo`3=o`0?o`04o`0?o`co
0?mI0_o00?l2oolX00KoU?l01_oo0004ol00o`Go0?mI0ooob@03o`3o30;oolT01Ol0o``00ol03ooo
0;3oo`2`o`02o`0?o`?oolD01?oo07<3oookJP?ooe<000Cooo]Zoo<0oooc0?ool`3o0ol0ojd2o`0?
o`05o`3o[Ol03ooo00ooo`0?ool0oe<00_l0ooh00ooonf[o0?nAo`3ooP02ool0^0Wo00oo00Ko05Oo
oeD0oomE0?ooE@3ooolX0?oo7P03oookJP?oob@000Co0?lHoolX0?oo:03oobP00_oo09000ol0ojgo
obP0oiCo0002oooS0004oomd0?oonf[ooo]ZoookJP?o04;o0_oonfX2o`3ok`04o`2foomEo`3oEOl0
oookJPKoo`001ooonfX00ooo08Goo`3bool0lP03oookJP05ofl0ooooN@3ookX0oonj0?l0]ol00_l0
of000ooonf[oo`1Wool0I`04oookJP03ool0[ooonf[ooo]Z01?ooo]Z0_l0o`VLoookJP;o0?l95?oo
nfX2ool0[`?ooo]Z0ooo06L01?oonf[o0?mPo`3oH?l0]ol2oonj00;oK`3o0_oonfX01?ooi03oo`3b
ool0l_oo08D8oookJP?oon800_oonfX3oeGo00;o0?o_0_oonfX00ooo047o04;oo`12o`03oookJP?o
on<000?oo`1AomGo0?oio`000_oo09001Ooonf[o0?lHo`3o6?l0oaSooo]Z00;oob@00ooonfX2oolN
00?oE@3o00?o0?lfo`1Gool0Eol00_ooD@02on?o00;oofP00ooo0;P2o`3oT@03ool00ooonf[ooo]Z
00?o0?mC00?ooo]Zo`3oh?l0on000_l0on03ool0l0?ol`3o0oooD`04oookJPGoo`1c00?oolD0o`0g
ool0=ol01Ol0=ol3ool0c@;ooo]Z3?l0oeT3ol00o`ko0?lU0oo00?l<o`3oF@?ooo]Z0ooo0<d5o`0g
o`?oolD01?oo07<3oookJP?ooe<000?ooo]Zool0eooc0?l00_oc0?l2ool0l0Co0?oP00?ooo]Zo`3o
Dol0oe<00_oo01/2oookJP;o0?nA0ooo0;P01?ooS03oofP0on?o0?oonfX2oomA00;o05Oo00?o0?lf
oeD0oomE0?l00ooo7P02oookJP?oob@00ol0oaP00ooonf[oo`2@ool0T002ooWo0005omGo0?oo057o
on<0oooS0?ooM0000ooonfX2o`12o`;ooo]Z0ol0onl00ol0]_ooEOl0oookJP03oookJP;oon802Ooo
nfX2ool0lP?ooo]Z0_m_0?l3oonj00;o0?mP0_oonfX2ool0I`?ooo]Z0_oo0:lDoookJP;o0?l9@Ooo
nfX005oooo]Z00?o0?l9oookJ_oonfX04_oonfX2ool0[`?ooo]Z00Coo`00ool0Iooonf[ooo]Z0_l0
of03oonj0005ofl0oooo003ooo]ZoookJ_ooi0000_oo0?88oookJP?oon800ooonfX2oeGo0003o`2f
ool0onoo0?o_00;ooo]Z00Koo`00o`12ool0@_oooo]Zo`0?ooooM003oooS0003o`0?oooo:03o0?mM
00;oo`2@2_oUo`001?l0Gooo0?mMoeD0oomE0?l3o`3oG@;ooe400ooSo`001?ooS03oo`2hool0^?oo
0;P4ool000Co0?mC00?oA?l0ool00?l0on000_l0on02ool0l0?oiOl000?ol`3oonGo0?oUo`000ooU
o`02o`3oG@03o`1Oool0oego05oo00Ko05oo1_l0ojd2o`0?o`So0?mI0ol03ol2o`3o9@;oobP01onD
o`03o`3o[@Woo`001ol03ol5ooo900So0?l<0ol0/?l2o`0?o`03o`0gooooa@3oolD000;oolD01?oo
07<2oookJP;ooe<00_l0ojd3oo<0o`?o0?n]1Ol03ol00ol0oe?o0?ono`3ooP02oookJP;o0?nA0ooo
0;P7o`0?o`06o`1GoomE0?ooE@3ooeD0oooo:03ooah00ooonfX2oolX0004oolT0?l0oaSo0?lHoolX
00;oo`2@00Co0?n]oiCo0?nDo`3oU?l00_ooh`001?ooM03ooo]ZoookJ_oonfX2o`12o`06ool0@Ooo
nf[ooo]Zo`3okooonf[o0;Ko0_mEo`000ooonf[oo`00ool00004ool000Oooo]Z0ooo0?82oookJP;o
K`3o00GoogT0oonj0?oo^P3o0;Ooo`3oH002oookJP;oo`1W1?oonfX00ooo0:oooo]ZoookJP0Boook
JP;o0?l9W?oonfX2o`3o2A?ooo]Z0_oo0:l4oookJP;oo`1W00Cooo]Zo`3oH?l0of3o0;Oo0_oo^P02
ofl0o`;ooo]Z00Coon@0ool0l_oo0?;oo`252?oonfX3oooR00;ooo]Z0omEo`02o`3ok`;ooo]Z00?o
o`11o`12ool0@_l00ooonfX3oooS0003ool0DOoEo`3onOl000;oo`2@00Kooo]Zo`3o6?l0oaSo0?lH
oookJ_oo9003oookJP?ooah00omE0?l00ol0ocKo05OooomA0002oomA00;ohol000OoofP0ool0^?oo
0;Soo`2hoi3o0?l0oi7oo`0300;ooo]Z0ol0oe<2oookJP?o0?oP0_oo0?04oo<0o`?ooe<01?oonfX4
ool0L`;oolD01Ol0=ol4ool0c@;ooo]Z2?l0oeT3ol00o`?o0?lU6?l0T_l3o`3o9@03ol00ool0oeWo
0?mI00Ko0?mI0ooonfX4ool0c@Co03Oo0oooa@04ool0L`;ooo]Z0oooD`001Ooonf[oo`3Goo<0oooc
0?ooo`3G00;oo`3`1?l0on001?oonf[o0?mCo`3oDooo01/2oookJP;o0?nA0ooo0;P01?ooS03oofP0
on?o0?oSo`02oomA00;o05Oo00?o0?lfoeD0oomE0?l00ooo7P02oookJP?oob@00ol0oaP01?oonf[o
o`2@ool0T?oio`02omGo00?oon<000?oog@0oookJ_oonfX00ol0@_l2oookJP;o0?o_00?o0;KooeGo
0?mEo`000ooonfX2oooR00Wooo]Z00?oo`25ool0l_oo0?800ooonfX2ofl0o`;ookX000Co0;Ooo`3o
H?oonf[ooo]Z0_oo06L4oookJP;oo`2_4ooonfX2o`3o2D7ooo]Z001NoookJP03o`3o2Ooonf[ooo]Z
01;ooo]Z0_oo0:l3oookJP;oo`1W0_oonfX2o`3oH0?ookX000?oK`3oool00?oonfX00_oonfX2ool0
lP03ool0QOoonf[ooo]Z00Kooo]Z0_oohP03oookJP;oEOl000?o0;Koo`3okol0onl00_oonfX01_oo
047o04;oo`12oooonf[o0?n]oomd00?oon<000?o00oooolX0?l0oed00_oo090:onGo0005o`3oGOoU
o`3oE@3ooeD0oooUo`000_l0oed2oomA00;ohol000?oolT0ool0^?oo0;P00_oo0;P4ool000?o0?mC
00?oA?l0ool00?l0on000_l0on02ool0l0;oiOl00_oc0?l6onGo00?o05oo0_l0oed5o`1Oo`;oo`00
1Ol0ojd5o`3oF@Oo00oo2_oo:006oiCo00coo`001?l03ol6ooo900?o0?l<0_l0/?l2o`3o30Go0;3o
1?l0=ol3ooo500?oo`1c1?oonfX2oomC0003o`3o[Ooc0?ool`3o00;o0?n]1_l03ol2o`3oD`03o`3o
o_oonf[ooo]Z00;o0?nA0ooo0;P00oooS03o00ooo`0?o`03o`0?o`03o`1GoonDo`3oE@3o00;oE@3o
00?oobP0oolN0?oonfX00ooo:0001Ooo903ooo]Zo`3o6?oonf[o0?lH00;oo`2@00Co0?n]oiCo0?nD
o`3oU?l00_ooh`001?ooM03ooo]ZoookJ_oonfX2o`12o`;ooo]Z0_l0onl01Ooob@3o0;KooeGo0?mE
o`3ooo]Z00Goo`001ooonfX00ooo08Goo`3bool0lP03oookJP05ofl0ooooN@3ookX0oonj0?l0]ol0
0_l0of000ooonf[oo`1Wool0I`04oookJP03ool0[ooonf[ooo]Z01?ooo]Z00?o0?l9oookJ_oonfX0
VOoonfX2o`3o2A?ooo]Z0ooo0:l3oookJP;oo`1W00Cooo]Zo`3oH?l0of3o0?mP0_oo^P02ofl0o`?o
oo]Z0_oo0?800ooo08Gooo]ZoookJP07oookJP;oon800ooonfX2oeGo00;o0?o_0ooonfX2o`12o`;o
oo]Z00Koog@0oooS0?ooh`3oon<0ool0DOoEo`02ooWo0003ool0T?oonf[o0?lH00;o0?lH00?ooo]Z
oolT0?oonfX00_oonfX3oolN00;oE@3o00?o0?lfo`1Gool0Eol00_ooD@03on?o00Coo`2h0_l0oi40
0ooo00?ooo]Zo`3oD`03o`3oD`04oookJ_l0on3o0?oPo`3oh0;oo`3`1?oc0?l3oomC00Cooo]Z0ooo
07<2ooo500Go03Oo0ooo0<d3oookJPGo0?mI0_o00?l3o`3o9@go09;o3OoonfX;o`2Bo`;o0?lU0_o0
0?l5o`3oF@Cooo]Z0_oo0<d5o`0go`;oolD00ooo07<4oookJP;ooe<000Kooo]Zool0eooc0?ool`3o
oonQ0?oo0?04o`3oh004oookJ_l0oe?o0?mCool06`?ooo]Z00Co0?nAoi3o0?oo0;Soo`2h0_ooS002
on?o00;ooe400_l0Eol00ol0ocKoE@3ooeD0o`03oolN00;ooo]Z0_oo90001Ooonf[o0?lHo`3o6?l0
oaSooo]Z00;oo`2@00?onOl0omGo0?oEo`000oooh`03oookJP;o04;o00?oo`11oookJ_oonfX00_l0
onl00ol0]_ooEOl0oeGo0003oookJP;oon802OoonfX00ooo08Goo`3boookJP02oookJP;oK`3o00?o
oo]Zoonj0?oo^P000_l0of02oookJP;oo`1W0ooonfX2ool0[aCooo]Z00?o0?l9oookJ_oonfX0?ooo
nfX005gooo]Z0_l0o`TCoookJP?oo`2_0_oonfX3ool0I`04oookJ_l0of3o0?mPo`3oH0;ookX000?o
K`3oool00?oonfX00_oonfX2ool0lP03ool0QOoonf[ooo]Z00Kooo]Z0ooohP02oookJP?oEOl00_l0
onl2oookJP06ool0@Ol0@_oo04;ooookJ_l0ojgoog@00oooh`000ol03oooobP0o`3oG@02ool0T003
oookJ_l0oaSoiOl000OoiOl000?o0?mMoeD0oomE0?l00_oUo`000ol0Gooo0?mMoomA0003on?o0004
oomX0?oo0;Soo`2hool0^0;o0?nA0ooo0002o`3oD`;oA?l00ol0on02ool0l003oo<0oooUo`3ol`3o
00SoiOl000?o05ooo`3oGOl0oed01?l0oed2o`1Oo`CoU?l00_l0ojd4o`3oF@03o`3o[Ol03ooo00oo
00Ko00oo0_l0T_l01?oonf[o0000o`000?l00006om[o00goo`0n2?oo0007ooo900Go0?l<2?l0/?l0
0ooo0<go03Ooo`0go`03o`0go`;oolD01?oo07<2oookJP?ooe<000?oo`3Goo<0oooc0?l01ol03ol3
o`3oD`;ooo]Z00?oo`03o`3oTOn@o`000_oo0;P00oooS03o0?ono`0?o`03o`0?o`03oiCo0?oo:03o
E@3o00;oE@3o00?oobP0oiCo0?oo:0000ooo:0001Ooo903ooo]Zo`3o6?l0oaSoU?l000;oo`2@00Co
0?n]oiCo0?nDo`3oU?l00_ooh`000oooM03ooo]ZoookJP03o`12o`;ooo]Z0_l0onl2o`2fo`03oeGo
0?oonf[ooo]Z00Goo`001ooonfX3ool0lP?ooo]Z00?oK`3ooomi0?oo^P000_l0]ol01Ol0of3ooo]Z
oookJ_oo06OoogT000Cooo]Z00?oo`2_oookJ_oonfX04_oonfX2o`3o2IWooo]Z0_l0o`TCoookJP?o
o`2_0ooonfX2ool0I`04oookJ_l0of3o0?mPo`3oH0;ookX00om_0?l2oookJP;oo`3b00?oo`25oook
J_oonfX01ooonfX2oooR00?ooo]Z0_mEo`02o`3ok`?ooo]Z0_l0@_l2oookJP07oomd0?ooh`3oon<0
oooS0?oo057oeOl0ooWo0002ool0T003oookJ_l0oaSo0?lH00;ooo]Z00Coob@0oookJ_oonf[ooo]Z
0ooo7P02oeD0o`03o`3o=_l0Eooo05Oo00;ooe400_oSo`002OooJ03oo`2hool0^?oo0;SoT?l0o`3o
TOoo00?ooo]Zool06`03o`3oD`04oookJ_l0on3o0?oPo`3oh0;oo`3`1?oc0?l3oomC00?ooo]Z1?oo
07<00oooa@3o03Ooo`0go`03o`0go`?oo`3=0ooonfX4o`3oF@;o`03o00?o0?lUo`2Bool0T_l01_l0
T_l00ooonf[o0000o`000002o`0000Gof_l03_oo03h4om[o00Kooo]Z1_l0T_l00ol0obGo`03ool00
o`04o`3oF@?ooo]Z0ooo0<d4o`0go`;oolD01?oo07<2oookJP?ooe<000Gooo]Zoo<0oooc0?ool`3o
ool0l004o`3oh004olX0oooonf[o0?mCo`3oD`?ooo]Z00Co0?nAoi3o0?oo0;Soo`2h0_ooS002on?o
00;ooe400_l0Eol00ol0ocKoE@3ooeD0o`03oolN00;ooo]Z0_oo90000ooonf[o0?lHo`3o6002oook
JP;oo`2@00?onOl0omGo0?oEo`000oooh`03oookJP;o04;o00?oo`11oookJ_oonfX00_l0onl00ol0
]_ooEOl0o`2fo`03oookJP03oooR0?oonf[ooo]Z00Oooo]Z00?oo`25ool0l_oo0?800ooonfX2ofl0
o`;ookX000Co0;Ooo`3oH?oonf[ooo]Z0ooo06L3oookJP;oo`2_4ooonfX2o`3o2D3ooo]Z001Loook
JP;o0?l94ooonfX3ool0[`?ooo]Z0_oo06L01?oonf[o0?mPo`3oH?l0of02oonj0003ofl0oooo003o
oo]Z00;ooo]Z00?oon@0ool0l_oo08D02?oonfX3oooR00;ooo]Z0omEo`02o`3ok`;ooo]Z00?oo`11
o`12ool0@_l00_l0ojd01oooM03oon<0oooS0?ooh`3o0?n]o`0?oooUo`000_oo09001ooonf[o0?lH
oookJ_oonf[oiOl0oolT0?oonfX00_oUo`02o`3oG@;oE@3o0_oUo`000ol0Gooooe40oomA0003on?o
0005oon<0?oo0;Soo`2hool0^?l0oi400_m4o`001Ol0ookoo`00o`3oDol0oe?oA?l000?o0?oP0ooo
0?03oo<0o`KoiOl000?o0?mMonGo0?oUo`001_l0oed00onDo`3o05oooiCo0003oiCo00?o0?mI1Ol0
ojd6o`0?o`;ooo]Z7ooo03h2ool000KoolT01ol0o``9o`2`o`;oo`3=0ol0=ol3ooo500Coo`1c0_oo
nfX2oomC0003o`0?oooc0?ool`3o00Oo00oo00?o0?ono`3oDol0oe<00ooonfX01Ol0oi7oT?l0ool0
^?oo0;Sooh`000;o0?on00Gooe40o`0?ool03oooU?l0oolX0003oeD0o`03oiCo0?oo:03oobP000;o
obP00_oo90001?oonf[oU?l0oiCo0?nDo`02ool0T004o`3o[OnDo`3oU?l0oiCo00;oon<000?oog@0
oookJ_oonfX00_l0@_l01_oo047ooo]ZoookJ_l0onooolT0o`2fo`;oEOl00ooonfX3ool000Sooo]Z
0_oo0?83oookJP05ofl0ooooN@3ookX0oonj0?oonfX00_l0of001?oonf[oo`1Woomi0?oo06L3oook
JP;oo`2_4ooonfX2o`3o2ISooo]Z0ol0o`TBoookJP?oo`2_1?oonfX2ool0I`04oookJ_l0of3o0?mP
o`2go`;ookX00_m_0?l2oookJP03oooT0?oo0?;oo`2500Wooo]Z0_oohP03oookJP;oEOl000?o0;Ko
o`3okooonfX00_oonfX2o`12o`;ooo]Z00Ooog@0oooS0?ooh`3oon<0ool0DOoEo`3onOl000;oo`2@
00?ooo]Zo`3o6?l0oaP00_oonfX2oolT00;ooo]Z0ooo7P02oeD0o`;o05Oo0oooD@02on?o0004oomX
0?oo0;Soo`2hool0^0;o0?nA0_oonfX00ooo01_o0?mCo`3oD`02oookJP?o0?oP0_oo0?03oo<0o`?o
oe<00ooonfX3ool0L`03ooo50?l0=ooo03Oo00?o03Oo0ooo0<d3oookJPCo0?mI00?o`03oo`3o9Ol0
obD01_l0T_l3oookJP03om[o0?oo03koo`0n01goo`0n1?oJo`04oookJPGo09;o00?o0?lUol00ooo0
0?l01?l0oeT3oookJP;oo`3=0ol0=ol3ooo500Coo`1c0_oonfX3oomC0005ool0eooc0?ool`3ooonQ
0?oo0?000ol0on001?o:0?oooo]Zo`3oDol0oe<3oookJP04o`3oTOn@o`3oo`2hool0^0;ooh`00_oS
o`02oomA00;o05Oo00?o0?lfoeD0oomE0?l00_oo7P03oookJP;oob@000Cooo]Zo`3o6?l0oaSooo]Z
0_oo0902ooWo00;oeOl00oooh`02oookJP;o04;o0_oo04401?oonf[o0?o_o`3okooonP02oeGo00?o
oo]Z0_oohP09oookJP03ool0QOoo0?;ooo]Z00?ooo]Z00CoK`3ooookJ_oo^P3ookX00_l0of02oook
JP;oo`1W0ooonfX3ool0[a;ooo]Z0_l0o`U0oookJP00FooonfX2o`3o2ACooo]Z0_oo0:l3oookJP;o
o`1W0_oonfX2o`3oH0;ookX00_m_0?l01_oo003ooo]ZoookJ_ooi03oo`3bool0Q@Sooo]Z0ooohP02
oookJP?oEOl000Go0;Koo`3okooonf[ooo]Zool0@@02o`12o`;o0?n]00Coog@0oooS0?ooh`3oon<0
0_l0ojd00ooUo`3oo`2@ool0T002o`3o60;ooo]Z0_oo9003oookJP04o`3oGOoUo`3oE@3ooeD0o`?o
iOl00_ooD@02on?o0004oomX0?oo0;Soo`2hool0^0;o0?nA0om4o`02o`3oD`04oomi0?m4o`3o0?oP
o`3oh0?oo`3`0ooc0?l2oomC0003ool00?oUo`3oiOl000?o0?mM0ooUo`04o`3oG@?oobP00_nDo`03
o`3oF@Wo0?n]0ol03ol00ooJo`3oo`0nool0?P07ool0?P;oobP01?oonfX2oiCo00;ooo]Z0ooo:003
ool000;oU?l01_oo0007ool0?P;of_l01ol0o``:o`2`o`?oo`3=0ol0=ol2ooo500Coo`1c0ooonfX2
oomC0003o`0?oooc0?ool`3o00Go00oo00Co0?oPo`3oo_l0oe?o0?mC0ooonfX01ol0oi7oT?l0ool0
^?oo0;Sooh`0on?o0?l0ooh00_ooD@000ol03oooU?l0oolX0003oeD0o`03oiCo0?oo:03oobP000;o
obP00_oo90001?oonf[o0?lHoiCo0?nDo`02ool0T0?oU?l000?oo`1AoooS0?ooh`000ooonfX2o`12
o`06ool0@Ooonf[o0?o_o`3okooob@3o0;Ko0_mEo`03oookJP?oo`001ooonfX00ooo08Goo`3bool0
lP03oookJP06oomi0?m_0?oookX0o`2gooooN@3o0?mP0_oonfX00ooo06OoogT0oookJP03oookJP03
ool0[ooonf[ooo]Z01;ooo]Z0_l0o`VFoookJP03o`3o2Ooonf[o0?l901?ooo]Z0ooo0:l3oookJP;o
o`1W00Cooo]Zo`3oH?l0of3o0;Oo0_oo^P02ofl0o`?ooo]Z0_oo0?800ooo08Gooo]ZoookJP06oook
JP;oon800ooonfX2oeGo0003o`2fool0onoo0?o_00;ooo]Z0_l0@_l2oookJP07oomd0?ooh`3oon<0
oooS0?oo057oeOl0ooWo0002ool0T004oookJ_l0oaSo0?lHoookJP?oob@00_oonfX2oolN0003oook
J_mE0?ooE@3o00;o05Oo0_ooD@03on?o0006oomX0?oo0;Soo`2hoi3o0?l0oi7oo`030_oonfX3o`3o
D`04oookJ_l0on3o0?oPo`3oh0;oo`3`0ooc0?l3oomC00?ooo]Z0ooo07<00oooa@3o03Ooo`0go`03
o`0go`;oo`3=0ooonfX4o`3oF@03ol00ool0T_oo09;o00Co09;o0ooonfX2om[o00Woo`0n00?o0000
oookJ_oonfX05OoonfX7ool0?PCof_l00ooonfX4o`2Bo`03o`3o9Oo00?oo0?mI00Co0?mI0_oonfX2
ool0c@Co03Oo0_ooa@03ool0L`?ooo]Z0oooD`02oo<0o`03ool0eooo0?3o0?oP00?o0?oP00Cooo]Z
o`3oDol0oe?o0?mC0_oonfX01?l0oi7oT?l0ool0^?oo0;P2oon<00;ohol00_ooD@02o`1Go`03o`3o
=_mE0?ooE@3o00;ooah00ooonfX2oolT0004oookJ_l0oaSo0?lHoookJP;oo`2@0_oio`000ooEo`3o
o`1AoooS0002oooS00;ooo]Z0_l0@_l2ool0@@04oookJ_l0onoo0?o_o`2fo`;oEOl00ooonfX00ooo
hP3ooo]ZoookJP08oookJP;oo`3b0ooonfX2ofl0o`;ookX000Co0;Ooo`3oH?oonf[ooo]Z0ooo06L3
oookJP;oo`2_4ooonfX2o`3o2Coooo]Z001KoookJP;o0?l94ooonfX2ool0[`?ooo]Z0_oo06L2oook
JP;o0?mP0ooo^P000om_0?ooo`00oookJP02oookJP03ool0l_oo08Gooo]Z00Sooo]Z0_oohP02oook
JP?oEOl000Go0;Koo`3okooo08Kooo]Zool0@@02o`12o`;o0?n]00Coog@0oooS0?ooh`3oon<00_l0
ojd00ooUo`3oo`2@ool0T003o`3o60?oob@00ooonfX01?l0oegooo]ZonGo0?mE0?l2onGo00?ooe40
0_oSo`001?ooS03oo`2hool0^?oo0;P2o`3oT@06odCo0?ooN@3o0?mCo`3oDooo01_oogT00ol0on02
ool0l0?ol`3o0oooD`02ool00003onGo0?l0oegoiOl000GoiOl00ol0oed3oolX00?o0?mI0_l0ojd3
oiCo00Go0?n]0_oJo`000ol03oooo`0nool0?P03ool0?PCooo]Z1?l00009oookJPKoobP01OnDo`00
0ooonf[o0?n]o`3o[@05oookJPCoo`0n0_oUo`001?oJo`3oiOl0onGo0?oUo`0<o`2`o`03oookJ_oo
0<goo`3=00;oo`3=0_l0=ol2ooo500?oo`1c0ooonfX00oooD`3oobP0oolX0002oo<0o`Go00oo00Co
0?oPoookJ_l0oe?o0?mC0_oonfX2o`3oT@?oo`2h00?oofP0on?o0?oSo`000_ooD@03oolX00?oE@3o
00CoU?l0oolX0?oo:03oobP00ooo90001?oonf[o0?lHoiCo0?nDo`02ool0T0?oU?l00_ooh`001_oo
M03ooo]ZoookJ_oonf[o04;oool0@@;ooo]Z0_l0onl00ooonP3o0;KooeGo0003oookJP03oooR0?oo
003oo`0000Sooo]Z0_oo0?801Ooo:03ooo]ZoookJ_m_0?ooogT000;ookX000Ko0;Ooo`3oH?l0of3o
oo]Zool0IoooN@04oookJP;oo`2_4ooonfX2o`3o2IKooo]Z0_l0o`TCoookJP?oo`2_0ooonfX2ool0
I`04oookJ_l0of3o0?mPo`3oH0;ookX00_m_0?l3oookJP;oo`3b00?oo`25oookJ_oonfX01ooonfX0
1?oohP3ooo]ZoookJ_oonfX2oeGo0003o`2fool0onoo0?o_00;ooo]Z0_l0@_l2oookJP07oomd0?oo
h`3oon<0oooS0?oo057oeOl0ooWo0002ool0T004oookJ_l0oaSo0?lHoookJP?oob@00_oonfX2oolN
0003oookJ_mE0?ooE@3o00;o05Oo0_ooD@02on?o0004oomX0?ooS03oo`2hool0^0;o0?nA00?oo`03
oookJ_oonfX00_l0oe<00ooonf[o0?oPo`3oh002o`3oh004ool0l?ooX@3ol`3ooo<0o`?ooe<00ooo
nfX4ool0L`03ooo50?l0=ooo03Oo00;o03Oo0_oo0<d2oookJPCo0?mI00?o`03oo`2Bool0T_l01?l0
T_l3oookJP03om[o0?oo03koo`0n00Goo`0n0ooonfX4o`0001cooo]Z1_oo03h3om[o00?ooo]Z1?l0
T_l00ol0obGo`03oo`3oF@03o`3oF@;ooo]Z0ooo0<d3o`0go`;oolD00_oo07<3oookJPCooe<000Co
l`3oool0eooo0?3oo`3`0ol0on001?oonf[oo`0Ko`3oDol0oe<2oookJP06o`3oTOn@o`3oo`2hool0
^?ooS03oofP00_oSo`02oomA00;o05Oo00?o0?lfoeD0oomE0?l00_oo7P02oookJP?oob@000Cooo]Z
o`3o6?l0oaSooo]Z0_oo0902ooWo0004omGo0?ooh`3oon<0oooS00?ooo]Z0_l0@_l00ooo047ooo]Z
oookJP02o`3ok`03o`2foomEo`3ooo]Z00;ooo]Z0_oohP09oookJP03ool0QOoo0?;oon@000?ooo]Z
0_m_0?l2oonj00;o0?mP0_oonfX2ool0I`?ooo]Z0ooo0:lBoookJP;o0?l9?ooonfX005[ooo]Z0_l0
o`TDoookJP;oo`2_0ooonfX2ool0I`04oookJ_l0of3o0?mPo`2go`;ookX000?oK`3oool00?oonfX0
0_oonfX2ool0lP03ool0QOoonf[ooo]Z00Kooo]Z0_oohP02oookJP?oEOl000Go0;Koo`3okooo08Ko
oo]Zool0@@02o`12o`;o0?n]0_ooM002oooS00;o0?n]00?oiOl0ool0T?oo09000ol0oaP3oolT00?o
oo]Z00Co0?mMonGo0?mE0?ooE@3o0_oUo`03oomA0003on?o0?ooJ03oo`2h00?oo`2h00Co0?nAodCo
0?m4o`3oogT00_l0oe<2oomi00;o0?oP0_oo0?03oo<0o`?ooe<00ooo00000ooo07?oiOl0onGo0005
onGo0003ool00?oo:03o0?mM00;oobP00ol0oeT8oiCo00;o0?n]1Ooo03h9oookJPCo00002OoonfX6
oolX00KoU?l01Ol0ojd00ooonf[o00ooo`0?o`03oookJP;oo`0n1?oUo`0>o`2`o`;ooo]Z0ooo0<d2
o`0go`;oolD00_oo07<4oookJP03oomC0?oo:03ol`3o00;oo`001?l03ol01_oo003ooo]Zo`3oDol0
oe?oo`0KoookJP;o0?nA0ooo0;P00oooJ03ohol0on?o0002oomA0007oolX0?nDo`3oobP0oeD0oooo
003oE@3ooiCo0003oolX00;oU?l000Coob@0o`3o6?l0oaSoU?l00ooo09000onDo`3o0?n]o`3o[@02
oooS00?ooo]Z0_l0@_l01_oo047ooo]ZoookJ_l0onooolT0o`2fo`;oEOl00ooonfX00ooohP3oo`00
oookJP07oookJP03ool0QOoo0?;oo`3b00?ooo]Z00KoogT0odCo0?oo^P3ookX0oomi0?l0of02oook
JP03oomi0?oonf[ooo]Z00?ooo]Z00?oo`2_oookJ_oonfX04_oonfX2o`3o2ICooo]Z0_l0o`TDoook
JP;oo`2_0ooonfX2ool0I`;ooo]Z0_l0of001?l0]ooookX0ofl0oom_0?l3oookJP;oo`3b00?oo`25
oookJ_oonfX01ooonfX2oooR00;ooo]Z0omEo`02o`3ok`;ooo]Z00Coo`11o`12oooonf[ooo]Z0_oo
M002oooS0003ool0DOoEo`3onOl000;oo`2@00Cooo]Zo`3o6?l0oaSooo]Z0ooo9002oookJP;ooah0
0_mE0?l00ol0ocKo05Ooo`1Go`02oomA00;ohol000CoofP0ool0^?oo0;Soo`2h0_l0oi42oookJP?o
0?mC00Cooo]Zo`3oh?l0on3o0?oP0_oo0?02oo<0o`03ool0eoooD`3ooe<000Cooo]Z0ooo07<00ooo
a@3o03Ooo`0go`02o`0go`;oo`3=0_oonfX4o`3oF@03o`3o9Ol0T_oo09;o00?o09;o0ooonfX00ooJ
o`3oo`0nool0?P03ool0?PSooo]Z1?l0000PoookJPGoo`0n0ooJo`03oookJPCo09;o00?o`03oo`3o
FOl0oeT00_l0oeT3oookJP;oo`3=0_l0=ol3ooo500;oo`1c0ooonfX3oomC00;ol`3o00?ooj40ool0
l?l0on000_l0on001?oonf[oo`0Ko`3oDol0oe<2oookJP06o`3oTOn@o`3oo`2hool0^?ooS03oofP0
0_oSo`02oomA00;o05Oo00?o0?lfoeD0oomE0?l00_oo7P02oookJP?oob@000Cooo]Zo`3o6?l0oaSo
oo]Z0_oo09000ooio`3oeOl0oookJP03oooS00?ooo]Z0_l0@_l01Ooo047ooo]Zo`3okol0onooooX0
00;oEOl00ooonfX2oooR00Wooo]Z0_oo0?83oookJP;oK`3o00Cooo]Zoonj0?oo^P3o0?mP0_oonfX2
ool0I`Cooo]Z0_oo0:lCoookJP;o0?l9?_oonfX005[ooo]Z0_l0o`TCoookJP;oo`2_0ooonfX2ool0
I`;ooo]Z0_l0of02oonj0003ofl0oooo003ooo]Z00;ooo]Z0_oo0?800ooo08Gooo]ZoookJP06oook
JP;oon800_oonfX3oeGo0005o`2fool0onooo`26oookJ_oo04400_l0@_l01?oonf[o0?n]o`3o[Ooo
M002oooS00;o0?n]0_l0ooh01?oo093o0?lHo`3o6?l0oaP3oolT00?ooo]Z00KoiOl0oolN0?mE0?oo
E@3oonGo0?l0oed2oomA00;ohol000?oofP0ool0^?oo0;P00_oo0;P01?l0oi7oA?l0odCo0?oo01/2
o`3oD`04oomi0?l0on3o0?oPo`3oh0;oo`3`0_oc0?l00om4o`3ooe<0oomC0002oookJP06ool00?oo
07?oiOl0onGo0?oo003oolD01?oUo`02ool00003o`0?ool0oeWo0?mI00;o0?mI0ooo:005oiCo0003
om[o0?oo03ko0?n]00?oo`0n3?oonfX4o`0000Cooo]Z0oookP05oolX00WoU?l01_l0ojd4o`0?o`?o
oo]Z1?oUo`02o`3oG@03onGo0?l0oego0?mM00[o0;3o0ooonfX2ool0c@?o03Oo00CoolD0ool0Looo
003oo`000ooonfX01OooD`3oo`00oomC0?oc0?ooo`0000?o00oo00?oo`00o`3oh?oonfX00_l0oe<0
1?oo01_ooo]Zo`3oTOl0oi43ool0^003oomX0?oSo`3ohol000;ooe4000SoobP0o`3o[Ooo:03oo`00
oeD0oooo:03oU?l0oolX00?oU?l000Goob@0oookJ_l0oaSo0?lHoookJP03ool0T0?o0?n]00?oon<0
oomd0?oonfX00_oonfX2o`12o`;ooo]Z0_l0onl00ooob@3o0;KooeGo0003oookJP;oon8000?oo`00
oookJ_oonfX01OoonfX01?oo08Goo`3bool0l_oUo`02oookJP05ofl0ooooN@3ookX0oonj0?ooN@00
0_l0of000ooonf[oo`1Woomi0004oookJP03ool0[ooonf[ooo]Z01;ooo]Z0_l0o`VDoookJP;o0?l9
4ooonfX3ool0[`;ooo]Z0_oo06L2oookJP;o0?mP00Co0;Oooonj0?m_0?ooK`3o0ooonfX2ool0lP03
ool0QOoonf[ooo]Z00Oooo]Z0_oohP02oookJP?oEOl00_l0onl2oookJP03ool0@Ol0@_oooo]Z00;o
oo]Z00Koog@0oooS0?ooh`3oo`1AomGo0?oio`02ool0T004oookJ_l0oaSo0?lHoookJP?oob@00_oo
nfX2oolN00;oE@3o0_l0ocH00ol0Eooooe40oomA0002on?o0008oon<0?oo0;Soo`2hool0^?l0oi7o
o`03oookJ_oo01/2o`3oD`04oookJ_l0on3o0?oPo`3oh0;oo`3`00Coo`3Goo<0oooo0=Oooo]Z0_oo
D`03oookJP?oo`1c00CoolD0o`0gool0=ooo03Oo0ooo0<d2oookJP?o0?mI00?o`03oo`3o9Ol0T_l0
0ol0T_l3oookJPKoo`0n2ooonfX4o`0000Cooo]Z3OookP0DoookJP?oo`0n0ooJo`02oookJPCo09;o
00Co`03oo`3oFOl0oeWo0?mI1?oonfX01?oo0<go03Ooo`0gool0=ol2ooo500?oo`1c0_oonfX3oomC
00;ol`3o00?ooj40ool0l?l0on000_l0on02oookJP06o`3oDooo01_ooo]ZoookJ_l0oi7oT?l00_oo
0;P01?ooS03oofP0on?o0?oSo`02oomA00;o05Oo0_mE0?l00ooonf[ooah0oolN0002oookJP;oob@0
0_oonfX2o`3o6006oookJ_oo093oo`2@ooWo0?oEo`3oo`1A0_ooh`000oooM03ooo]ZoookJP03o`12
o`;ooo]Z0_l0onl00ol0]_ooEOl0oookJP03oookJP;oon802?oonfX00ooo08Goo`3bool0lP03oook
JP;oK`3o0_oo^P02o`3oH0;ooo]Z0_oo06L3oookJP;oo`2_4ooonfX2o`3o2Ckooo]Z001IoookJP;o
0?l94ooonfX2ool0[`?ooo]Z0ooo06L00ooonf[o0?mPo`3oH002oonj0003ofl0oooo003oK`3o00;o
oo]Z00?oon@0ool0l_oo08D02?oonfX2oooR00;ooo]Z0omEo`000ol0]_oo0?o_o`3ok`02oookJP;o
04;o00Cooo]ZoiCo0?nDo`3oog@00_ooh`02o`3o[@?o0?on0ol0oaP3oolT00;ooo]Z0_oUo`001Ooo
7P3oE@3ooeD0oooUo`3o0?mM00;ooe400_oSo`001?ooJ03oo`2hool0^?oo0;P2o`3oT@06oomi0?m4
o`3o0?mCo`3oDooonf[oogT00ol0on02ool0l0;ol`3o0oooD`03oookJP;oiOl000Coo`00ooo50?l0
=ooo03Oo0ooUo`02ool000?o0?mI1_oo:003oiCo00Coo`0n3ooonfX3o`3ooP_oonh01_oo:003oiCo
00Wo0?n]1_l03ol00ooonf[oiOl0onGo0004onGo00Oo0?mM0ol0Gol4o`2`o`03o`3oFOoonf[ooo]Z
00?oo`3=0ol0=ol00oooa@3oo`1cool00002oookJP;oo`000_oo:0000ooc0?ooo`00oolX0003ool0
0006o`3oh?oonf[o0?mCo`3oDooo01_ooo]Z0_l0oi43ool0^003oomX0?oSo`3ohol000;ooe4000Oo
0?n]oiCo0?mE0?ooo`00oeD0oonDo`3o0?n]00CoU?l000Goob@0oookJ_l0oaSo0?lHoomi0003ool0
T0;o0?n]0_ooh`001_ooM03ooo]ZoookJ_oonf[o04;oool0@@;ooo]Z00Go0?o_ooo90?l0]_oo0;Ko
oeGo0003oookJP;oon802?oonfX00ooo08Goo`3bonGo0003oookJP06oomi0?m4o`3ookX0oonj0?oo
N@3o0?mP0_oonfX00oooN@3ooo]ZoookJP03oookJP03ool0[ooonf[ooo]Z017ooo]Z0_l0o`VCoook
JP;o0?l94ooonfX3ool0[`;ooo]Z0ooo06L2oookJP04o`3oH?l0]ooookX0oonj00;oK`3o0_oonfX0
0oooi03oo`3bool0lP09oookJP;oon800_oonfX3oeGo00;o0?o_0_oonfX00ooo047o04;ooookJP02
oookJP05oomd0?ooh`3oon<0ool0DOoEo`000_oio`001Ooo093ooo]Zo`3o6?l0oaSooo]Z00?oob@0
0_oonfX2oolN00;oE@3o00?o0?lfo`1Gool0Eol00_ooD@000ooSo`3oofP0oon<0002ool0^0;o0?nA
0_oonfX3o`3oD`04oookJ_l0on3o0?oPo`3oh0;oo`3`0_oc0?l00ooonf[ooe<0oomC0004oookJP;o
o`1c0_ooa@02o`0go`;oo`3=0ooonfX3o`3oF@03o`3o9Ol0T_oo09;o00;o09;o0ooonfX5ool0?Poo
oo]Z0_l0000Iooo^017ooo]Z0ooo03h3om[o0006oookJ_l0T_oo09;oo`2Bool0obGo`03o0ol0oeT3
oookJP;oo`3=0ol0=ol2ooo500;oo`1c0_oonfX3oomC00;ol`3o00?ooj40ool0l?oo0?000_l0on02
oookJP;o0?mC0_oonfX01_l0oi7oT?l0ool0^?oo0;Sooh`0oomX00;ohol00_ooD@001?l0Eooo0?lf
oeD0oomE0?l3oolN00;ooo]Z0_oo90001Ooonf[o0?lHo`3o6?l0oaSooo]Z00;oo`2@0_oEo`000ooo
057oon<0oooS0003oookJP;o04;o00Ooo`11oookJ_oonf[o0?o_ool0Q_l0]_ooEOl000?ooo]Z0_oo
hP09oookJP;oo`3b0ooonfX2ofl0o`04oookJ_oo^P3ookX0o`3oH0;ooo]Z0_oo06L4oookJP;oo`2_
4_oonfX2o`3o2Ckooo]Z001IoookJP03o`3o2Ooonf[ooo]Z017ooo]Z0_oo0:l3oookJP?oo`1W0_oo
nfX01_l0of3o0;Oooonj0?oo^P3oo`00ofl0o`;ooo]Z00?oon@0ool0l_oo08D02?oonfX2oooR00?o
oo]Z0_mEo`000ol0]_oo0?o_o`3ok`02oookJP;o04;o00Cooo]ZoiCo0?nDo`3oog@00_ooh`000ol0
ojgo0?ono`3ooP02o`3ooP?o0?lH00?ooo]ZoolT0?oo90000_oonfX00ooUo`3ooah0oolN0002oeD0
o`;o0?mM0_ooD@02on?o0005oomX0?oo0;Soo`2hool0^?l0oi400oooN@02o`3oD`04oookJ_o:0?oo
0?oPo`3oh0;oo`3`0_oc0?l2o`1Oo`08oomC0?oonf[ooo]ZoookJ_oo07?oiOl0ool0Loooa@03o`0g
o`;o00oo00?oiOl0o`0?ool0oeT00_l0oeT00oo00?ooo`00oolX0004oolX0003om[o0?oo03koU?l0
00;oo`0n3?oonfX5o`3ooPKoonh02?l0ooh00ooonf[oobP0oolX0003oolX00KoU?l01?l0ojd:o`0?
o`KoiOl00ol0oed2o`1Oo`03o`3oGOl0Gooo05oo00?o05oo00?oobP0o`3o9Oo00?l00_l0oeT00oo0
0?oooo]ZoookJP02ool0c@?o03Oo00?oolD0ool0Looo00001?oo00000ooo:03oU?l0oo<0o`05ool0
0006o`3oh?oonf[o0?mCo`3oDooo01_ooo]Z0_l0oi43ool0^003oomX0?oSo`3ohol000;ooe4000Ko
0?n]oiCo0?mE0?ooo`00oeD0ool0ojd4oiCo00;oob@000?ooo]Zoomi0?l0ojd00ooo0903o`3o[@;o
on<000?oog@0oookJ_oonfX00_l0@_l01_oo047ooo]ZoookJ_l0onoo0?l<o`2fo`;oEOl000?oolT0
oookJ_oonfX00_oohP07oookJP04ool0QOoo0?;oo`3bonGo00;ooo]Z00GoK`3oodCo0?oo^P3ookX0
oomi0002o`3oH003oookJ_oo06OoogT000Cooo]Z0_oo0:lCoookJP;o0?l9T_oonfX2o`3o2A?ooo]Z
0_oo0:l2oookJP?oo`1W0_oonfX2o`3oH0;ookX00_m_0?l2oookJP03oooT0?oo0?;oo`3b00Wooo]Z
0_oohP03oookJP;oEOl00ol0onl00ooonf[oo`11o`12o`03oookJP05oomd0?ooh`3oon<0ool0DOoE
o`000_oio`001Ooo093ooo]Zo`3o6?l0oaSooo]Z00?oob@00_oonfX2oolN00;oE@3o00Co0?lfo`1G
ool0Eooooe400_oSo`001?ooJ03ooh`0ool0^?oo0;P2o`3oT@;ooo]Z0ol0oe<01Oo:0?oo0?oPo`3o
h?l0on3oo`3`00?ol`3o0_ooD`04oookJP;oo`1c0_ooa@02o`0go`;oo`3=0ooonfX3o`3oF@03o`3o
9Ol0T_oo09;o00;o09;o0_oonfX5ool0?Pkooo]Z2?ookP0EoookJPOoonh03_oonfX4ool0?P;of_l0
00Kooo]Zo`2Bool0T_oo09;oo`3o9Oo00?l3o`3oF@?ooo]Z00Coo`3=o`0gool0=ooo03Oo0_ooa@02
ool0L`?ooo]Z0_ooD`000ooonf[ol`3oool0e`02ool0l0?o0?oP00?ooo]Zo`3oDol0oe<00_oonfX0
1ol0oi7oT?l0ool0^?oo0;Sooh`0oomX0?oSo`000oooD@001?l0Eooo0?lfoeD0oomE0?l2oolN00?o
oo]Z0_oo90001?oonf[o0?lHo`3o6?oonfX2ool0T003ooWo0?oEo`3oeOl000?oon<00ooonfX2o`12
o`;ooo]Z0_l0onl00ol0]_ooEOl0oeGo0003oookJP;oon802?oonfX00ooo08Goo`3bool0lP03oook
JP04ofl0oooonf[ookX0oonj00;o0?mP0_oonfX00ooo06Oooo]ZoookJP02oookJP;oo`2_4ooonfX2
o`3o2Cgooo]Z001HoookJP;o0?l94_oonfX3ool0[`?ooo]Z0_oo06L2oookJP06o`3oH?l0]ooookX0
oonj0?m_0?ooo`000ooonfX00ooo0?;oo`25ool0Q@08oookJP;oon800_oonfX3oeGo00;o0?o_0_oo
nfX3o`12o`;oU?l000Coog@0oooS0?ooh`3oo`1A1Ol0ooh2o`3o6003oookJ_oo903oob@000;ooo]Z
00?oiOl0oolN0?oo7P000_mE0?l01?l0oegoiOl0oomA0?ooD@02on?o0005oomX0?oo0;Soo`2hool0
^?l0oi400_ooN@03o`3oD`05oookJ_o:0?oo0?oPo`3oh?oo0?000ooc0?l3o`1Oo`;ooo]Z0ooo07<0
0oooa@3o03Ooo`0go`02o`0go`03o`0?ool0ojgo00oo00?o0?mI00Co`03oool00?oo003oo`001?oo
:003ool0?PSooo]Z1ooo000Do`3ooPGoobP01_nDo`06o`3o[@Oo00oo1_oUo`06o`3oG@Oo05oo00?o
obP0oiCo0?o00?l00ol0oeT2oookJP?oo`3=0_l0=ol00oooa@3oo`00ool00004ool00003oiCo0?oo
003oo`0000Coo`000_l0on000ooonf[o0?mCo`3oD`02oookJP;o0?nA0ooo0;P00oooJ03ohol0on?o
0002oomA0006o`3o[OnDo`3oE@3oool00?mE0?oo0?n]1?nDo`000ooo903ooo]Zo`3o[@02o`3o[@?o
o`2@0ol0ojd00oooh`3oog@0ool00002oookJP;o04;o0_oonfX2o`3ok`;o0;Ko00CoEOl0ooo90?oo
nf[ooo]Z0_oohP08oookJP03ool0QOoo0?;oiOl000?ooo]Z00CoogT0odCo0?oo^P3ookX00ol0of00
0ooonf[oogT0ool0I`03oookJP;oo`2_4ooonfX2o`3o2I7ooo]Z0_l0o`TCoookJP;oo`2_0ooonfX2
ool0I`;ooo]Z0_l0of02oonj00;oK`3o0ooonfX2ool0lP03ool0QOoonf[ooo]Z00Oooo]Z00Coon80
oookJ_oonf[ooo]Z0_mEo`03o`3ok`04oookJ_oo047o04;oo`12o`;ooo]Z00Coog@0oooS0?ooh`3o
o`1A0_oEo`000ooio`3oo`2@oookJP02o`3o6004oookJ_oo903oob@0oolT00;ooo]Z0_oo7P02oeD0
o`04o`3o=_l0Eooo05OooomA00;ohol000CoofP0oon<0?oo0;Soo`2h0_l0oi42oookJP;o0?mC00Go
oo]ZolX0ool0on3o0?oPool0l003oo<0o`03oookJ_ooD`3ooe<000?ooo]Z0_oo07<2ooo500?o03Oo
0_oo0<d2oookJP;o0?mI00?o`03oo`3o9Ol0T_l00_l0T_l2oookJPGoo`0n3?oonfX6ooo^00?ooo]Z
0_l00004obP0o`ko0?l/1OlX0?l5oookJPOoonh03?oonfX4ool0?P;ooo]Z0ol0T_l00ol0obGo`03o
o`3oF@02o`3oF@;ooo]Z0_oo0<d2o`0go`;oolD00_oo07<3oookJP;ooe<000Cooo]Zoo<0oooc0?oo
o`3`1?l0on000ooonf[o0?mCo`3oD`02oookJP07o`3oTOn@o`3oo`2hool0^?ooS03oofP0on?o0003
oomA0004o`1Gool0ocKoE@3ooeD0o`;ooah00ooonfX00ooo903ooo]ZoookJP02o`3o6004oookJ_oo
093oo`2@ooWo00;oeOl00_ooh`000oooM03ooo]ZoookJP02o`12o`03ool0@Ooonf[ooo]Z00;o0?o_
00?o0;KooeGo0?oonfX00_oonfX2oooR00Wooo]Z0_oo0?83oookJP;oK`3o0_oo^P03o`3oH003oook
J_oo06Ooo`1W00?ooo]Z0_oo0:lCoookJP;o0?l9?OoonfX005Sooo]Z00?o0?l9oookJ_oonfX04Ooo
nfX2ool0[`?ooo]Z0ooo06L00ooonf[o0?mPo`3oH002oonj0003ofl0oooo003ooo]Z00;ooo]Z0_oo
0?800ooo08Gooo]ZoookJP06oookJP;oon800_oonfX3oeGo0004ool0Q_l0onoooo]ZoookJP?o04;o
0_nDo`000oooM03oon<0oooS0006o`3ooP;o0?lH00?ooo]ZoolT0?oo90000_oonfX00ooUo`3ooah0
oolN0002oeD0o`04o`3oGOoUo`3ooe40oomA00;ohol000Gooh`0ool0^?oo0;Soo`2ho`3oT@02oomi
00?o0?mC00?ooo]Zo`3oh?l0on000_oo0?03oo<0o`?o05oo00Gooo]Zool0Looo07?oo`1cooo50004
o`0go`03o`0?ool0ojgo0?n]00?o0?mI00?o`03oo`0?oooo00000ooo0003oolX0004ool0?_oonf[o
oo]ZoookJPWoo`001_m4o`0@o`3ooQ?oon`00_l0ojd<o`0?o`Oo0?mM2?l0Gol2oiCo0003o`3o9Oo0
0?oo0?mI00;o0?mI0_oonfX2ool0c@03o`0goooo003oo`0000goo`000_l0on000ooonf[o0?mCo`3o
D`02oookJP;o0?nA0ooo0;P01?ooJ03ohol0on?o0?ooD@03oiCo0004ool00?mE0?ooE@3oo`3o[@;o
o`0000GoU?l0oolT0?oo903ooo]Zo`3o6002o`3o[@;oo`2@0ol0ojd2oooS0003ool00?oonf[ooo]Z
00;o04;o00Koo`11oookJ_oonf[o0?o_o`3o3?l0]_l2oeGo00?ooo]Z00?oon80oookJ_oonfX01_oo
nfX00ooo08Goo`3bonGo0003oookJP05oomi0?m4o`3ookX0oonj0?ooN@000_l0of000ooonf[oogT0
ool0I`04oookJP;oo`2_4_oonfX2o`3o2I7ooo]Z00?o0?l9oookJ_oonfX04_oonfX2ool0[`;ooo]Z
0ooo06L00ooonf[o0?mPo`3oH002oonj00;oK`3o0ooonfX2ool0lP03ool0QOoonf[ooo]Z00Oooo]Z
00Coon80oookJ_oonf[ooo]Z0_mEo`001Ol0]_oo0?o_o`3okooonf[oo`1100;o04;o0_oonfX2oomd
0007oooS0?oo057oeOl0omGo0?oio`3oo`2@oookJP02o`3o6004oookJ_oo903oob@0oolT00;ooo]Z
0_oo7P02oeD0o`04o`3o=_l0Eooo05OooomA00;ohol000KoofP0oon<0?oo0;Soo`2ho`3oTOoo00<2
oookJP;o0?mC00Gooo]ZolX0ool0on3o0?oPool0l003oo<0o`;ooe<00ooonfX3ool0L`04ooo50?l0
=ooo03Ooo`0go`;oo`3=0_oonfX2o`3oF@03ol00ool0obGo09;o00;o09;o0_oonfX4ool0?P_ooo]Z
1_ookP03oookJPCo:03o00?o0?l/ooo/0?ook0006Oook0000ol0obco:03oobP0o`03oookJPOoonh0
2_oonfX4ool0?P03om[o0?oonf[o09;o00;o09;o00?o0?lUol00ool0oeT00_l0oeT2oookJP;oo`3=
00?o03Ooo`3o_Oooa@000ooo07<2oookJP;ooe<00ooc0?l00ooo0?3o0?oPo`3oh002o`3oh003ool0
6ol0oe?o0?mC00;ooo]Z00Go0?nAoi3o0?oo0;Soo`2hoon<0002on?o00;ooe400_l0Eol3oeD0o`;o
oah00_oonfX2oolT00;ooo]Z00Co0?lHoookJ_oonf[oo`2@0_oio`001?oEo`3oo`1AoooS0?ooh`03
oookJP;o04;o00Goo`11oookJ_l0onoo0?o_o`2fo`02oeGo00?ooo]Z0_oohP08oookJP03ool0QOoo
0?;oo`3b00?ooo]Z00CoK`3ooookJ_oo^P3ookX00_l0of02oookJP03ool0Iooonf[ooo]Z00;ooo]Z
0_oo0:lBoookJP;o0?l9?OoonfX005Oooo]Z00?o0?l9oookJ_oonfX04OoonfX2ool0[`Cooo]Z0_oo
06L02?oonf[o0?mPo`3oH?l0]ooookX0ofl0oooo003oK`3o0_oonfX00oooi03oo`3bool0Q@08oook
JP;oon800ooonfX2oeGo0004o`2fool0onoooo]ZoookJP?o04;o0_nDo`000oooM03oon<0oooS0007
o`3ooP04o`3o6?oonf[oob@0oolT00;ooo]Z00?oiOl0oolN0?oo7P000_mE0?l01?l0oegoiOl0oomA
0?ooD@02on?o0005oon<0?oo0;Soo`2hool0^?l0oi400_ooN@02o`3oD`;ooo]Z0_l0on02ool0l0;o
l`3o1?l0Gol4ool0L`05ooo50?l0=ooo03Ooo`0gool03ol00_l0ojd3o`3oF@03ol00ool03ooo00oo
00?oo`0000Cof_l0ool0?_oo03koobP01OoonfX9ool000KoA?l03_l0ooh;oolN00koon`03?l03ol2
oookJP?o0?mM2_l0Gol00onDo`3o09;oo`3o9@03o`3oF@?ooo]Z4Ooo0002o`3oh003oookJ_l0oe?o
0?mC00;ooo]Z0_l0oi43ool0^005oomX0?oSo`3ohol0oomA0?l0ojd00_nDo`000ooo003oE@3oool0
0002ool000;oU?l00_oo90000ooonf[o0?lHo`3o[@03ool0T0?o0?n]0_ooh`000ooo003ooo]Zoook
JP02o`12o`06ool0@Ooob@3o0?o_o`3okol0o`co0;Ko0_mEo`02oookJP;oon802?oonfX00ooo08Go
o`3bonGo0003oomi0004odCo0?ooN@3ookX0oonj00?o0?mP00?oo`1Woomi0?m4o`000ooonfX2ool0
[a?ooo]Z0_l0o`V?oookJP;o0?l94ooonfX2ool0[`?ooo]Z0_oo06L01?oonf[o0?mPo`3oH?l0of02
oonj00;oK`3o0_oonfX00oooi03oo`3bool0Q@09oookJP04oooR0?oonf[ooo]ZoookJP;oEOl000Go
0;Koo`3okol0onoooo]Zool0@@02o`12o`?ooo]Z00?oog@0oooS0?oo05400_oEo`000ooio`3oo`2@
ool0T003o`3o60?oob@00_oonfX2oolN00;oE@3o00?o0?lfo`1Gool0Eol00_ooD@000ooSo`3ooh`0
ool0^002ool0^004o`3oTOoonf[ooo]ZoookJP;o0?mC00?ooo]Zo`3oh?l0on000_oo0?03oo<0o`;o
oe<00_oonfX4ool0L`03ooo50?l0=ooo03Oo00;oo`3=0_oonfX3o`3oF@04o`3o9Ol0T_oo09;oo`2B
o`;ooo]Z00Cof_l0ool0?_oo03koo`0n2_oonfX5ooo^00;ooo]Z1?lX0?l;ooo/00gooah03_ook000
0ol0obco:03ooookJP02oookJPKoonh02OoonfX3ool0?P;of_l000Gooo]Zo`2Bool0T_oo09;ool00
o`03o`3oF@;ooo]Z0_oo0<d2o`0go`;oolD00_oo07<2oookJP;ooe<00ooc0?l00ooo0?3o0?oPo`3o
h002o`3oh003ool06ol0oe?o0?mC00;ooo]Z00Go0?nAoi3o0?oo0;Soo`2hoon<0002on?o00;ooe40
0_l0Eol3oeD0o`;ooah00_oonfX2oolT0004oookJ_l0oaSo0?lHoookJP;oo`2@0_oio`001?oEo`3o
o`1AoooS0?ooh`03oookJP04o`12oooo047oo`11oookJP;o0?o_00?o0;KooeGo0?mEo`000_oonfX2
oooR00Wooo]Z0_oo0?83oookJP;oK`3o0_oo^P03o`3oH003oookJ_oo06Ooo`1W00?ooo]Z0_oo0:lC
oookJP;o0?l9??oonfX005Kooo]Z0_l0o`TBoookJP?oo`2_0ooonfX2ool0I`;ooo]Z00Ko0?mPo`2g
oooo^P3ookX0ool00?m_0?l2oookJP04oooT0?oo0?;oo`25ool0Q@Sooo]Z00Coon80oookJ_oonf[o
oo]Z0_mEo`001Ol0]_oo0?o_o`3okooonf[oo`1100;o04;o0_nDo`000oooM03oon<0oooS0007o`3o
oP04o`3o6?oonf[oob@0oolT00;ooo]Z0ooo7P02oeD0o`04onGo0?l0Eooooe40oomA00;ohol000Oo
oh`0ool0^?oo0;Soo`2ho`3oTOoonf[oogT000;o0?mC0_oonfX2o`3oh004ool0l?l0Goool`3ooo<0
o`Co05oo0ooo07<2ooo500?o03Oo0_l0ojd3o`3oF@04ol00ool0obGoo`00o`0?o`;ooo]Z00Cof_l0
ool0?_oo03koo`0n1ooonfX3ool000KoogT01?m4o`0=o`3ooP04oolN0?l0ooko0?ono`3ooPWoo`40
1Ooo0005oolN00Soon`02_l03ol00oookP3ooo]ZoookJP0<o`1Oo`04oiCo0?l0T_oo0?n]o`3o9@?o
0?mI00?ooo]Zoomi0?oo0<d04?oo0002o`3oh003oookJ_l0oe?o0?mC00;ooo]Z0_l0oi43ool0^006
oomX0?oSo`3ohol0oomA0?l0ojgo00oo1_oo00001onDo`3o0?n]o`3o[Ooo903ooo]Zo`3o6?l0ojd0
0_oo0903o`3o[@;oon<000Coo`00oookJ_oonf[ooo]Z0_l0@_l2ooo900;o0?o_00?o0;KooeGo0?mE
o`000ooonfX00ooohP3ooo]ZoookJP06oookJP;oo`2500?oiOl0oomi0?ooN@000_ooN@001?m4o`3o
okX0oomi0?oo^P02o`3oH003oookJ_ooN@3oA?l000Cooo]Z0_oo0:lBoookJP;o0?l9S_oonfX2o`3o
2A?ooo]Z0_oo0:l3oookJP;oo`1W0_oonfX2o`3oH0;ookX00_m_0?l3oookJP;oo`3b00?oo`25oook
J_oonfX01_oonfX2oooR00;ooo]Z0_mEo`001Ol0]_oo0?o_o`3okooonf[oo`1100;o04;o0ooonfX0
1_ooM03oon<0oooS0?oo057oeOl0ooWo00;oo`2@0ol0oaP3oolT00;ooo]Z0_oo7P02oeD0o`03o`3o
=_l0Eooo05Oo00;ooe4000?ohol0oon<0?oo0;P00_oo0;P01Ol0oi7ooo]ZoookJ_oo01_o0?mC00;o
oo]Z0_l0on02ool0l0?ol`3o0_ooD`02oookJP?oo`1c00CoolD0o`0gool0=ooo03Oo0_oo0<d01Ooo
nf[o0?mIo`3oFOl0oeWo0?lU00;o09;o0ooonfX00ooJo`3oo`0nool0?P0:oookJPCoonh00_oonfX3
obP0o`03o`3o;?ook03oon`000Coon`02?oo7P03oh_o00Woo`401On;o`06oolN00Soon`000?o0?l/
obP0oooonfX00_oonfX6ooo^00Sooo]Z0ooo03h2om[o00?o09;o00?o0?lUol00ool0oeT00_l0oeT0
0ooonf[oo`3=ool0c@02o`0go`;oolD00_oo07<2oookJP;ooe<00ooc0?l00ooo0?3o0?oPo`3oh002
o`3oh004ool06ol0oe?o0?mCoookJP;o0?nA0ooo0;P00oooS03ohol0on?o0002oomA00;o05Oo0_mE
0?l3oolN00;ooo]Z0_oo90001?oonf[o0?lHo`3o6?oonfX2ool0T003ooWo0?oEo`3ooo]Z00;oon<0
00?oog@0oookJ_oonfX00_l0@_l00ooo047ooo]ZoookJP02o`3ok`;oEOl00ooonfX2oooR00Sooo]Z
00?oo`25ool0l_oo0?800_oonfX3ofl0o`;ookX00_l0of000ooonf[oo`1Wool0I`04oookJP;oo`2_
4_oonfX2o`3o2Ccooo]Z001FoookJP03o`3o2Ooonf[ooo]Z013ooo]Z0ooo0:l3oookJP?oo`1W00?o
oo]Zo`3oH?l0of000_oo^P000ooo003oK`3ooookJP02oookJP;oo`3b00?oo`25oookJ_oonfX01_oo
nfX2oooR00;ooo]Z0_mEo`001Ol0]_oo0?o_o`3okooonf[oo`1100;o04;o0_nDo`02oomd00;oon<0
1ol0ooh00ooonf[oob@0oolT0002oookJP?ooah00_mE0?l01ooUo`3o05OooomA0?ooD@3o00ooon?o
0?ooS0000ooo0;P00ol0oi7ooo]ZoookJP02o`3oD`04oookJ_l0on3o0?oPool0l0;o05oo00?ol`3o
o`1Oool0Gol00ol0Gol3ool0L`06ooo50?l0=ooo03Ooo`0gool0ojgoU?l01?l0oeT01_l0ojgo09;o
ool00?l0T_oooo]Zom[o00?oo`0n00?oo`00oookJ_oonfX01_oonfX3ool000OoogT01_m4o`08o`3o
oP?oo`403_oo00`6ool100Coo`000oooN@04ooo/00;oolT00_oo0002o`3ooP03oookJ_ookP3oonh0
00?oonh00ooonfX:o`1Oo`?o0?n]00?oogT0ol00ool0oeT00_l0oeT00ooonf[oo`3=ool0c@0>ool0
00?o0?oP00?ooo]Zo`3oDol0oe<00_oonfX00ol0oi7oT?l0ool0^002ool0^0;ohol00_ooD@07ool0
00?o0?n]00Goob@0oookJ_l0oaSo0?lHo`3o[@02ool0T003o`3o[Ol03ooo00oo00;oon<000?oo`00
oookJ_oonfX00ol0@_l01Ooob@3o0?o_o`3okol0o`co0;Ko00;oEOl00_oonfX2oooR00Sooo]Z00?o
o`25onGo0?oo0?800oooN@001?m4o`3ookX0oonj0?oo^P02o`3oH003oookJ_ooN@3oA?l000Cooo]Z
0_oo0:lBoookJP;o0?l9S_oonfX2o`3o2A;ooo]Z0ooo0:l2oookJP?oo`1W00?ooo]Zo`3oH?l0of00
0_oo^P02ofl0o`?ooo]Z0_oo0?800ooo08Gooo]ZoookJP06oookJP;oon800_oonfX2oeGo0004o`2f
oooo08Ko0?o_o`3ok`;oo`110_l0@_l2oookJP06oomd0?ooh`3oon<0ool0DOoEo`3onOl00_oo0903
o`3o60?oob@00_oonfX2oolN00;oE@3o00?o0?lfo`1Gool0Eol00_ooD@000ooSo`3ooh`0ool0^002
ool0^005o`3oTOoo00?ooo]Zool06ol0oe<00_oonfX2o`3oh0;oo`3`0_oc0?l2oomC00?ooo]Z0ooo
07<00oooa@3o03Ooo`0go`02ool0c@05oookJ_l0oeWo0?mIo`3oFOo00?l00ol0T_l2oookJP03om[o
0?oo03koo`0n00Wooo]Z1?ookP02oookJP;o:03o0_l0ob`4ooo/00Kooah000?oRol0ool10?oo0@00
1Ooo0@0=ool030Ooo`401On;o`02oolN00Goon`000?o0?l/obP0oooonfX00ooonfX5ooo^00Sooo]Z
0ooo03h00ooJo`3ooo]Zo`2Bo`02o`2Bo`04o`3o9Ol0oeWo0?mIo`3oF@;ooo]Z0_oo0<d00ol0=ooo
olD0ooo50002ool0L`;ooo]Z0_ooD`03oo<0o`06ool0l?l0on3o0?oPo`3oh?oonf[oo`0K0_l0oe<0
1ooonf[o0?nAoi3o0?oo0;SoT?l0ool0^?ooS0000_oSo`001?ooD@3o05Ooo`1Gool0ocH2oeD0o`?o
oah00_oonfX01?oo903ooo]Zo`3o6?l0oaP2oookJP;oo`2@00?onOl0omGo0?oo05400_ooh`000ooo
M03ooo]ZoookJP02o`12o`05ool0@Ooonf[o0?o_o`3okol0]_l00_mEo`02oookJP;oon802OoonfX3
ool0lP;ooo]Z0_m_0?l2oonj00;o0?mP0_oonfX00ooo06Oooo]ZoookJP02oookJP;oo`2_4_oonfX2
o`3o2Ccooo]Z001EoookJP;o0?l94_oonfX2ool0[`?ooo]Z0ooo06L01Ooonf[o0?mPo`3oH?l0]ooo
okX000;oK`3o0ooonfX2ool0lP03ool0QOoonf[ooo]Z00Kooo]Z0_oohP02oookJP;oEOl000?o0;Ko
o`3okol0onl00_oonfX2o`12o`;ooo]Z00CoU?l0oomd0?ooh`3oon<01ol0ooh00ooonf[oob@0oolT
0002oookJP?ooah00_mE0?l01ooUo`3o05OooomA0?ooD@3o00ooon?o0?ooS0000ooo0;P00ol0oi7o
oo]ZoookJP02o`3oD`03oookJ_l0on3o0?oP00;o05oo0_oc0?l5o`1Oo`?oo`1c0ol0=ol00ol0ojgo
U?l0oiCo0003o`3oF@04ol00ool0ojgo09;oo`2Bo`;ooo]Z0ooo03h00ooonf[oo`00oookJP05oook
JP04ooo^0?oo003oo`00ooo^00;oo`001OooN@08odCo00Ko0?on6ooo00`00ooo0@3oogT0oomi0004
oomi00;oA?l00ooob@02ooo/00;o0?on00?oo`00oookJ_oonfX01?ookP000ooonf[oiOl0oookJP02
oiCo00Oo05oo0ol0ojd00ol0T_ooogT0o`3oF@02o`3oF@;ooo]Z00?oo`3=o`3o_Ooo00001Ooo0000
0onDo`3oo`00ool00004ool000?o0?oP0ol0oe<2oookJP05o`3oTOn@o`3oo`2hool0^?ooS0000_oS
o`02oomA00Ooo`000ol0ojd01?oo903ooo]Zo`3o6?l0oaP3ool0T0?o00oo0_ooh`03oookJP;o04;o
0_oob@02o`3ok`03o`2foomEo`3oEOl000?ooo]Z0_oohP07oookJP03ool0QOoo0?;oiOl000?oogT0
00GoA?l0o`3oo_oo^P3oogT0oonj0002o`3oH003oookJ_ooN@3oA?l000?ooo]Z0_oo0:lCoookJP;o
0?l9S?oonfX2o`3o2A?ooo]Z0_oo0:l3oookJP;oo`1W0_oonfX2o`3oH0;ookX000CoK`3ooookJ_oo
nf[ooo]Z0_oo0?800ooo08Gooo]ZoookJP06oookJP;oon800_oonfX2oeGo00;o0;Ko0_l0onl01?oo
nf[oo`11o`12ool0@_l2oookJP06oomd0?ooh`3oon<0ool0DOoEo`3onOl00_oo0903o`3o60?oob@0
0_oonfX2oolN00;oE@3o00?o0?lfo`1Gool0Eol00_ooD@000ooSo`3ooh`0ool0^002ool0^0;o0?nA
00?ooo]Zool06ol0oe<00_oonfX01?l0on3oo`3`ool0l?oo0?02oo<0o`;ooe<00ooonfX2ool0L`03
ooo50?l0=ooo03Oo00;oo`3=0_oonfX3o`3oF@03o`3o9Ol0T_oo09;o00;ooo]Z00?of_l0ool0?_oo
03h02?oonfX4ooo^00;ooo]Z0_lX0?l2o`3o;0Coon`01?oo7P05ool100;o04Co7?oo00`3ool100Co
Rol000?ooah0ooo/0?ook0000oook0000ol0obco:03ooookJP03oookJP?oonh02?oonfX3ool0?P03
om[o0?oonf[o09;o00?o09;o00?o`03oo`3oFOl0oeT00_oonfX2ool0c@03o`0gooooa@3oolD000;o
o`1c0_oonfX2oomC00?ol`3o00Goo`3`o`3oh?l0on3o0?oPoookJP03o`3oD`03oookJ_l0oi7oT?l0
00;oo`2h0_ooS0000ooSo`3ooe40oomA0002o`1Go`03o`3o=_mE0?ooE@3o00;ooah00_oonfX2oolT
0004oookJ_l0oaSo0?lHoookJP?oo`2@00GoeOl0oookJ_ooh`3oon<0oomd0002oookJP;o04;o00?o
o`11oookJ_oonfX00_l0onl2oeGo00?ooo]Z0_oohP08oookJP03ool0QOoo0?;oo`3b00;ooo]Z0om_
0?l2oonj00;o0?mP00?ooo]Zool0Iooo06L01?oonfX00ooo0:oooo]ZoookJP0AoookJP;o0?l9>ooo
nfX005Cooo]Z0_l0o`TBoookJP?oo`2_0ooonfX2ool0I`;ooo]Z00Co0?mPo`2goooo^P3ookX00_m_
0?l2oookJP;oo`3b00?oo`25oookJ_oonfX01_oonfX2oooR00;ooo]Z0omEo`02o`3ok`;ooo]Z00Ko
o`11o`12ool0@_oooo]ZoolX0?ooM002oooS00So0?on00Cooo]ZoolT0?oo903ooo]Z0ooo7P02oeD0
o`04onGo0?l03ooooe40oomA00;o00oo00Gooh`0ool0^?oo0;Soo`2ho`3oT@02oookJP;o0?mC00?o
oo]Zo`3oh?l0on000_l0Gol2oo<0o`Go05oo0_oo07<01Oooa@3o03Ooo`0gool0=ooo0?n]00;oU?l0
0_l0oeT01?o00?ooU?l0o`3o[Ol0T_l2oookJPCoo`0n1ooonfX4ooo^00;ooo]Z0ooo0006oomi00Ko
A?l000?o0?onool03?oo00`01Ooo00`2o`0000_ooo]Z1?oo0004o`14o`Woo`0<00?oogT0odCo0?m4
o`001Ooob@001Oook03o0?l<o`3o3?l0ookoo`0000Cooo]Z0oookP03oookJP?oU?l01Ol0Gol3o`3o
[@03o`2Bool03ooo0?mI00;o0?mI0_oonfX00ooo0<go0?nmo`0go`04ool000;oU?l000?o0?n]ool0
0?oo00000ooo0003o`3oh0?o0?mC00Cooo]Zooo90?l0oi7oT?l00_oo0;P00oooJ03ohol0on?o0002
oomA00Koo`000ol0ojd01Ooo903ooo]ZoookJ_m4o`3o00oo00;oo`2@0ol03ol3oooS00;ooo]Z0ol0
@_l01_oob@3o0?o_o`3okol0/?oo0;KooeGo00?ooo]Z0_oohP08oookJP03ool0QOoUo`3o0?mM00?o
ogT000Co0?onoonj0?oo^P3ookX00_l0of000ooonf[oogT0odCo0004oookJP;oo`2_4_oonfX2o`3o
2H_ooo]Z0_l0o`TCoookJP;oo`2_0ooonfX2ool0I`;ooo]Z0_l0of02oonj00;oK`3o0_oonfX3ool0
lPSooo]Z0_oohP02oookJP?oEOl000Go0;Koo`3okol0onoooo]Zool0@@02o`12o`?ooo]Z0_ooh`00
0ooo057oeOl0ooWo0002ool0T0?o0?lH00?ooo]ZoolT0?oo90000_oonfX2oolN00;oE@3o00?o0?lf
o`1Gool0Eol00_ooD@000ooSo`3ooh`0ool0^002ool0^0;o0?nA00Kooo]Zo`3oDol0oe?ooo]ZolX0
ool0on03ool0l0;ol`3o0_ooD`03oookJP;oo`1c00?oolD0o`0gool0=ol00_oo0<d2oookJP;o0?mI
00?o0?lUo`2Bool0T_l00_oonfX01?oJo`3oo`0nool0?_oo03h7oookJPCoonh00_oonfX00olX0?oo
0?l/o`3o;004ooo/00?ooah01Ooo0@000ol0A?ooo`0<ool03005ool03003o`14ool0003ooo]Z00oo
oo]Z0ol0A?l:ool030;oo`400on;o`02oolN00?oon`000?o0?l/obP0oolX0?l00ooonfX3ooo^00So
oo]Z0ooo03h2oookJP?o09;o00?o`03oo`3oFOl0oeT00_oonfX2ool0c@;o03Oo00?oolD0ool0Looo
07<00_oonfX2oomC00?ol`3o00_oo`3`o`3oh?l0on3o0?oPoookJ_l0oe?oo`0Ko`3oDooonf[o0?nA
oi3o0002ool0^003oon<0?oSo`3ohol000;ooe400_l0Eol2oeD0o`03oookJ_oo7P3ooah000;ooo]Z
0_oo90001?oonf[o0?lHoookJ_oonfX2ool0T003ooWo0?oEo`3oo`1A00;oon<000?oog@0oookJ_oo
nfX00_l0@_l01_oo047ooo]Zo`3okol0onoo0;KooeGo00?ooo]Z0ooohP08oookJP?oo`3b0_oonfX2
ofl0o`;ookX00_l0of02oookJP03ool0Iooonf[ooo]Z00;ooo]Z0_oo0:lBoookJP;o0?l9>ooonfX0
05Cooo]Z0_l0o`TBoookJP;oo`2_0ooonfX3ool0I`03oookJ_l0of3o0?mP00;ookX00_m_0?l2oook
JP04oooT0?oo0?;oo`3bool0Q@Oooo]Z0_oohP03oookJP;oEOl00_l0onl2oookJP03ool0@Ol0@_oo
04;o00;oobP000Coog@0oooS0?ooh`3oo`1A1ol0ooh01?oonf[oob@0oolT0?oonfX3oolN0003oook
J_mE0?ooiOl000;o05oo00Cooe40o`0?ool03ooooh`00ooo0;P00ol0oi7ooo]Zo`3oD`02o`3oD`03
oookJ_l0on3o0?oP00;oo`3`0_oc0?l4o`1Oo`?oo`1c00?oolD0o`0gool0=ol01?nDo`02o`3oF@;o
U?l00_l0T_l00ooonf[of_l0ool0?P02ool0?POooo]Z1?ookP001Ooonf[o:03oobP0ool0obcoon`0
00WoogT000?oA?l0ool03?oo00`01?oo00`01?l0A?oooo]ZoookJ_oonfX4o`0001Sooo]Z1ooo00`6
ooo900?o0?l<0_ook0001Ol0obco:03ooolX0?oonf[oiOl000?oonh01?oonfX3o`3o[@05ool0?_l0
Gooo05ooool0?_l0ojd00_l03ol01ol0T_oo0?mIo`3oFOl0oeWooo]ZodCo0?oo0<d00ol0=ol3ool0
00;oU?l00_l0ojd3ool00004o`3o[Ol0on3o0?oPo`3oh0;o0?mC00Goo`0Kooo90?oob@3o0?nAoi3o
0002ool0^004oomX0?oSo`3ooe40oomA00Koo`000ol0ojd2oolT0004oookJ_l03ooo00ooo`0?o`;o
o`2@0ol03ol2oooS0003oomd0?oonf[ooo]Z00;o04;o0_oob@02o`3ok`03ooo90?l0]_ooEOl000?o
oo]Z0_oohP07oookJP03ool0QOoo0?;o0?mM00?oogT000CoA?l0o`3oo_oo^P3ookX00_l0of000ooo
N@3oo`1WodCo0004oookJP;oo`2_4_oonfX2o`3o2@03onGo0?oonf[ooo]Z08Sooo]Z0_l0o`TCoook
JP;oo`2_0ooonfX2ool0I`05oookJ_l0of3o0?mPo`2goooo^P000_m_0?l3oookJP;oo`3b00?oo`25
oookJ_oonfX01OoonfX3oooR00;ooo]Z0_mEo`001Ol0]_oo0?o_o`3okooonf[oo`1100;o04;o0ooo
nfX2oooS0003ool0DOoEo`3oeOl000;oo`2@0ol0oaP00ooonf[oob@0oolT0002oookJP;ooah000?o
oo]ZoeD0ool0ocH00_l0Eol2oomA0003on?o0?ooS03oo`2h00;oo`2h0_l0oi401?oonf[o0?mCo`3o
DooonfX2o`3oh0;oo`3`0_oc0?l00ooo0=Oooe<0oookJP02oookJP?oo`1c0ol0=ol2ool0c@04oook
J_l0oeWo0?mIol00o`?o09;o0_oonfX3ool0?PSooo]Z0oookP001?oonf[o:03oobP0ool0ob`4ooo/
00?ooah01?oo0@06ool03004o`14oooonf[ooo]ZoookJPCo00006?oonfX8ool030;oo`400on;o`02
oolN00?oon`000?o0?l/obP0oooonfX00ooonfX3ooo^00Oooo]Z0ooo03h01Ooonf[o09;oo`2Bool0
T_oo`03o00;o0?mI0_oonfX01Ooo0<go03Ooo`0gool0=oooolD000;oo`1c0_oonfX2oomC00?ol`3o
00Goo`3`o`3oh?l0on3o0?oPoookJP02o`3oD`;ooo]Z00Go0?nAoi3o0?oo0;Soo`2hoon<0002on?o
0004oomA0?l0Eooo05Ooo`3o=P;oE@3o0_oo7P03oookJP04oolT0?oonf[o0?lHo`3o60;ooo]Z0_oo
0902omGo00;oon<00_ooM0001?oonf[o04;oo`12oooo0442oookJP04o`3okooo08Ko0;KooeGo00?o
oo]Z0_oohP08oookJP03ool0QOoo0?;oo`3b00;ooo]Z0_m_0?l2oonj00;o0?mP0_oonfX00ooo06Oo
oo]ZoookJP03oookJP03ool0[ooonf[ooo]Z013ooo]Z0ol0o`TjoookJP00DooonfX2o`3o2A;ooo]Z
0ooo0:l2oookJP?oo`1W00Oooo]Zo`3oH?l0of3o0;Oooonj0?oonf[oK`3o00;ooo]Z00Coon@0ool0
l_oo0?;oo`252?oonfX2oooR00;ooo]Z0_mEo`000ol0onooo`26o`3ok`02oookJP;o04;o0_oo:000
1?ooM03oon<0oooS0?oo0542odCo00Ko0?on0_oo90001ooonf[ooah0oolN0?oo7P3ooo]ZoeD0oooU
o`000ol0Gol2o`0?o`06oon<0?oo0;Soo`2hool0^?l0oi7ooo]Z0ol0oe<01ooonf[o0?oPo`3oh?oo
0?3o0?mMoo<0ool0oed01?l0Gol3ool0L`04ooo50?l0=oooU?l0oiCo00;oobP00_l0oeT01_o00?oo
U?l0oiCo0?l0T_oooo]Zom[o00?oo`0n1ooonfX3ooo^00;ooo]Z0_lX0?l4ooo/0003ool00?oo7P3o
ogT000?oogT01_oo00`8oookJPCo00005ooonfX6oomi0003ool03?oob@3oolT000CoolT01Ol0o``0
1?ook03o0;3oooo/0?l0ob`3onGo00Coonh000?o0?mMo`3o[Ol0ojd01?l0ojd3ool0?P?o00oo00Go
09;ooomi0?l0oeWo0?mIodCo0002ool0c@?o03Oo00Coo`1cool00?oo003oU?l00ol0ojd01?oc0?oo
o`00ool00?oo0?03o`3oh0;o0?mC00Coo`0Kooo90?oob@3o0?nA0_oo0;P00oooS03oofP0on?o0002
oomA00Koo`000ol0ojd00ooo903ooo]ZoookJP02o`0?o`;oo`2@0ol03ol3oooS00;ooo]Z0_oo0000
1_l0@_ooolT0ooo90?l0onoo0;3oo`2fo`;oEOl000Co0?l<oookJ_oohP3oon802?oonfX01?oo08Go
0?mMoookJ_ooN@02oolX0004o`3oo_oo^P3ookX0oonj00;o0?mP0_ooN@001?m4o`3oogT0oomi0?oo
N@02ool0[a?ooo]Z00?o0?l9onGo0?oonfX0R?oonfX2o`3o2A?ooo]Z0_oo0:l3oookJP;oo`1W00Co
oo]Zo`3oH?l0of3o0?mP0_oo^P001?m_0?oooo]ZoookJ_oonfX2ool0lP03ool0QOoonf[ooo]Z00Ko
oo]Z0_oohP02oookJP;oEOl000Go0;Koo`3okol0onoo0?o_oookJP03o`12o`;ooo]Z0oooh`02omGo
00;oo`2@00Cooo]Zo`3o6?l0oaSooo]Z0_oo9002oookJP;ooah000?ooo]ZoeD0oomE0?l00_l0Eol2
oomA0003on?o0?ooS03oo`2h00;oo`2h0_l0oi401?oonf[o0?mCo`3oDooonfX3o`3oh005ool0l?oc
0?ool`3oool0eoooD`000ooonfX2ool0L`03ooo50?l0=ooo03Oo00;oo`3=00Gooo]Zo`3oFOl0oeWo
0?mIo`3o9@02o`2Bo`;ooo]Z0ooo03h8oookJP;oonh00_oonfX2obP0o`Coon`00ooo7P03ool100Ko
o`0<2?oonfX4o`0001gooo]Z1_oo00`3ool100;oRol000Kooah0ooo/0?ook03oon`0o`3o;?lX0?l3
oookJPCoonh01_oonfX3ool0?P07om[o0?oonf[o09;oo`2Bool0obGo`03oo`3oF@02oookJP05ool0
cOl0=ooo03Ooo`0gooooa@000_oo07<2oookJP;ooe<00ooc0?l01Ooo0?3o0?oPo`3oh?l0on3ooo]Z
00;o0?mC0_oonfX01_l0oi7oT?l0ool0^?ooS03oofP0on?o00;ooe400_l0Eol00ol0ocKoE@3ooeD0
o`02oolN00;ooo]Z0_oo90001?oonf[o0?lHo`3o6?oonfX2ool0T003ooWo0?oEo`3ooo]Z00;oon<0
00?oog@0oookJ_oonfX00_l0@_l2oookJP;o0?o_00?o0;KooeGo0?mEo`000_oonfX3oooR00Sooo]Z
0_oo0?83oookJP;oK`3o0_oo^P02o`3oH003oookJ_oo06Ooo`1W00Cooo]Z00?oo`2_oookJ_oonfX0
4OoonfX2o`3o2C[ooo]Z001CoookJP;o0?l94_oonfX2ool0[`;ooo]Z0ooo06L2oookJP04o`3oH?l0
]ooookX0oonj00;oK`3o0_oonfX00oooi03oo`3bool0Q@08oookJP;oon800ooonfX01?mEo`3o0;Ko
o`3okol0onl2oookJP;o04;o0_oo:0000oooM03oon<0oooS0004odCo00Go0?on0_oo9002oookJP;o
oah000?ooo]ZoeD0ool03ol00ol0Gol2o`0?o`06oon<0?oo0;Soo`2hool0^?l0oi7ooo]Z0ol0oe<0
0ooonf[o0?oPo`3oh002o`3oG@04oo<0ool0oego05ooo`3oG@;o05oo0ooo07<2o`0go`05oiCo0?oo
:03oobP0oolX0?l0oeT00_o00?l2oiCo0003o`2BoooJo`3oo`0n00?oo`0n1ooonfX2ooo^00;ooo]Z
00?o:03oo`3o;?ook0000oook003oolN00;oo`4000?oogT0ool03?oo00`00_oo00`00ol0A?oooo]Z
oookJP09oookJP03o`000?oo0:coo`2/01?oo`2/1OoonfX6oomi0003odCo0?oob@3oolT000?oolT0
1ol0o``2o`2`o`?oon`00ooUo`03ooo^00;ooo]Z1Ol0ojd3ool0?P?o00oo00Go09;oodCo0?l0oeWo
0?mIodCo0002ool0c@?o03Oo0_oo07<01Ooo003o0?n]o`3o[Ol0ojgo00oo00;ol`3o00Goo`00ool0
l?l0on3o0?oPoookJP02o`3oD`04ool06ooob@3o0?nAoi3o00;oo`2h00Gooh`0on?o0?oSo`3ooe40
o`0?o`05ool00003o`0?ool0ojgo0?n]00;oob@00_oonfX2o`0?o`;oo`2@0ol03ol3oooS00?oo`00
00?o04;oool0@Ooob@000_l0onl01?l0o`co0;KooeGo0?l0o``2oookJP03oooR0?oonf[ooo]Z00Ko
oo]Z00?oo`25onGo0?l0oed00ooo:002oomi00;ookX00_l0of02oomi0005odCo0?ooN@3oogT0oomi
0?oonfX00_oo0:lBoookJP03o`3o2OoUo`3ooo]Z08Sooo]Z0_l0o`TBoookJP;oo`2_0ooonfX2ool0
I`;ooo]Z0_l0of02oonj00;oK`3o0ooonfX2ool0lPSooo]Z0_oohP03oookJP;oEOl000Co0;Koo`3o
kol0onoooo]Z0ol0@_l2oookJP?oon<00_oEo`03ool0T0?o0?lH0_oo9003oookJP06oolN0?oonf[o
E@3ooeD0ool0ocKo05Oo0_ooD@000ooSo`3ooh`0ool0^002ool0^0;o0?nA00Cooo]Zo`3oDol0oe?o
oo]Z0ol0on000ooo0?3ol`3ooo<0o`02oomC00?ooo]Z0_oo07<3o`0go`;oo`3=00Gooo]Zo`3oFOl0
oeWo`03oo`3o9@02o`2Bo`03oookJ_oo03koo`0n00;oo`0n1ooonfX2ooo^00;ooo]Z0_lX0?l4ooo/
00?ooah00ooo0@04ool03003o`14oooonf[ooo]Z00Wooo]Z00?o0000ool0[?oo0:`04ooo0:`?oook
JPGoo`0<0ooo0@000on;o`3ooah0ooo/0003ooo/0004o`3o;?lX0?oooo]ZoookJP?oonh01ooonfX2
ool0?P05om[o0?oonf[o09;oo`2Bool0obD00ol0oeT00ooonf[oo`3=o`0go`02o`0go`03ooo50?oo
07?oo`1c00;ooo]Z0_ooD`03oo<0o`05ool0l?l0on3o0?oPoookJ_oo01/00_l0oe<00ooonf[oo`03
oi3o0002ool0^003oon<0?ooJ03ohol000;ooe400_l0Eol01?oonf[oE@3ooookJ_oo7P03oookJP;o
ob@000Cooo]Zo`3o6?l0oaSooo]Z0_oo09000ol0n?ooeOl0oooS0002oooS0006oomd0?oonf[o04;o
o`12oooo047ooo]Z0ol0onl00ol0]_ooEOl0oookJP02oookJP;oon802?oonfX3ool0lP;ooo]Z0_m_
0?l2oonj00;o0?mP0_oonfX00ooo06Oooo]ZoookJP02oookJP;oo`2_4_oonfX2o`3o2C[ooo]Z001B
oookJP;o0?l94_oonfX2ool0[`?ooo]Z0ooo06L00ooonf[o0?mPo`3oH002oonj00;oK`3o0_oonfX0
1?ooi03oo`3bool0l_oo08D8oookJP04oooR0?oonf[ooo]ZoookJP;oEOl00_l0onl2oookJP?o04;o
00CoobP0oomd0?ooh`3oon<01?m4o`000ol0ookoA?l0odCo0003o`3ooP03oolT0?oonf[ooo]Z00;o
oah000?ooo]ZoeD0ool0Gol01?l0Gol00ol03ooooh`0ool0^002ool0^003o`3oTOoonf[o0?mC00;o
0?mC00?ooo]Zo`3oh?l0on000_l0oed00ooc0?oo0?mMo`1Oo`03o`3oG@;oo`1c00Co05ooo`0gool0
=oooU?l00_oo:002o`3oF@06ol00oooo:03o09;ooiCo0?l03ooof_l00ooo03h7oookJP;oonh00_oo
nfX00olX0?oo0?l/ooo/0003ooo/00;ooah00ooo0@03ool030;o04Co2_oonfX?ool0[0Kooo]Z2_oo
0:`5oookJP;oA?l01Ooob@06o`3o30Co0;3o1?ook002o`3oG@Coonh00ooonfX01?l0ojgo00ooo`0?
ool03ol2ool0?P?o00oo00Go09;oodCo0?l0oeWo0?mIodCo0002ool0c@?o03Oo0_oo07<3o`3o[@04
o`0?ool0ojgol`3ooo<0o`;o00oo0_l0on001_oonf[o0?mCo`3oDooo01_oolT0o`3oT@?oo`2h00Go
oh`0on?o0?oSo`3ooe40o`0?o`05ool000;o0?n]00Gooo]Zo`0?ool03ooooo]Zo`3o6002o`0?o`05
ool0T?l03ooo00ooo`0?ool0ooh00_ooh`03ool00007o`12oooo047o0?l<o`3o3?l0onoo0?l<o`2f
o`02oeGo00;ooo]Z0_oohP06oookJP;oobP000Coo`25o`3oGOoo:03oobP00_oUo`001?ooN@3ookX0
oonj0?ooN@02o`3oH003oomi0?m4o`3oogT000;oogT000?ooo]Zool0[ooo0:l04_oonfX00ol0o`Wo
iOl0oookJP27oookJP;o0?l94ooonfX2ool0[`?ooo]Z0_oo06L01?oonf[o0?mPo`3oH?l0of02oonj
0004ofl0oooonf[ooo]ZoookJP;oo`3b00?oo`25oookJ_oonfX01_oonfX2oooR00;ooo]Z0_mEo`00
1?l0]_oo0?o_o`3okooonfX3o`12o`;ooo]Z00Goon<0oomd0?ooh`3oo`1AomGo0003ool0T0?o0?lH
0ooo9002oookJP;ooah00_mE0?l01_l0ocKo05OooomA0?ooD@3ohol0oon<00?oo`2h0_l0oi401?oo
nf[o0?mCo`3oDooonfX3o`3oh003ool0l?oc0?ool`3o00;ooe<00ooonfX2ool0L`?o03Oo00?oo`3=
oookJ_oonfX00_l0oeT01Ol0obGo09;oo`2Bool0T_oooo]Z00?oo`0n1ooonfX3ooo^0003oookJ_lX
0?oo0?l/00Coon`00_oo7P03ool100Coo`0<00?o04CooookJ_oonfX02?oonfX?ool0[0Kooo]Z2_oo
0:`=oookJPGoo`0<00?oo`40oh_o0?n;o`000_oo7P03ooo/0003o`3o;?lX0?oooo]Z00?oonh01ooo
nfX2ool0?P03om[o0?oonf[o09;o00;o09;o0ol0oeT00ooonf[oo`3=o`0go`02o`0go`03ooo50?oo
07?oo`1c00;ooo]Z0_ooD`02oo<0o`;oo`3`0_l0on001ooonf[oo`0Ko`3oDooo01_ooo]Zool00on@
o`000_oo0;P00oooS03oofP0on?o0002oomA0004o`1Gool0ocKoE@3ooeD0o`;ooah00_oonfX3oolT
00;o0?lH00Kooo]Zool0T?oo093onOl0omGo0?oonfX2oooS0004oomd0?oonf[ooo]Zo`12o`;oo`11
00Cooo]Zo`3okol0onoo0;Ko0_mEo`02oookJP;oon802OoonfX2ool0lP?ooo]Z00CoK`3ooookJ_oo
^P3o0;Oo0_l0of000ooonf[oo`1WoookJP04oookJP03ool0[ooonf[ooo]Z013ooo]Z0_l0o`Tjoook
JP00D_oonfX2o`3o2A;ooo]Z0_oo0:l2oookJP?oo`1W00?ooo]Zo`3oH?l0of000_oo^P000ooonf[o
K`3oofl0o`02oookJP;oo`3b00?oo`25oookJ_oonfX01_oonfX01?oohP3ooo]ZoookJ_oonfX2oeGo
0005o`2fool0onoo0?o_oookJ_oo04400_l0@_l01?oo:03oog@0oomd0?ooh`04odCo0003o`3oo_m4
o`3oA?l000;o05oo00Co0?onoolT0?oonf[ooo]Z0_oo7P000ooonf[oE@3oo`1Oo`04o`1Oo`03o`0?
ooooS03oo`2h00;oo`2h00?o0?nAoookJ_l0oe<00_l0oe<00ooonf[o0?oPo`3oh002o`3oG@;ol`3o
00?o05ooo`3oGOl0oed00ooo07<01?l0Gooo03Ooo`0goooo0<d2oolX00;o0?mI00Ko`03ooolX0?l0
T_oo09;oo`0?oooJo`02ool0?POooo]Z0_ookP02oookJP03obP0ool0obcoon`000;oon`00_oo7P03
ool100?oo`0<0_l0A?l9oookJPWoo`2/0ol0000<oookJP;oobP00ooonfX2oiCo00;oo`000_oo0:`2
ooo900?oo`2/00?ooo]Zooo90?oob@001?oob@05o`3o30Ko0;3o00Cooah0ooo/0?ook03oon`00ol0
oed4ooo^0003o`1Oool03ooo00oo00?o00oo0_oo03h2o`0?o`;o09;o00Co`03oo`3oFOl0oeWooo]Z
0_oo0<d2o`0go`03ooo50?oo07?oo`1c00?o0?n]00Ko00ooo`3o[Ooc0?ool`3oo`0?oooonfX2o`3o
h0?o0?mC00?ooo]Zooo90?l0oi400_oo0;P00ooo0;cooh`0on?o0002oomA00;o00oo0ooo0005o`0?
o`;ooo]Z00Go0?lHo`0?oooo093oo`2@o`0?o`02ool000?oon<00ooo00000ol0@_oo0?l<o`3o3002
o`3ok`04o`2foomEo`3oEOl0o`3o30;ooo]Z00?oon80oookJ_oonfX00ooonfX3oolX0003ool0QOl0
oegoiOl000?oiOl000CoogT0oonj0?oo^P3ookX00_l0of000oooN@3oA?l0oomi0002oomi00;ooo]Z
00?oo`2_oookJ_oonfX04OoonfX00ol0o`WoiOl0oookJP26oookJP;o0?l94_oonfX2ool0[`?ooo]Z
0_oo06L01?oonf[o0?mPo`3oH?l0of02oonj00;oK`3o0_oonfX2ool0lP03ool0QOoonf[ooo]Z00Ko
oo]Z0_oohP02oookJP;oEOl000Go0;Koool0Q_l0onoooo]Zool0@@02o`12o`;ooo]Z00Goog@0oooS
0?ooh`3oo`1AomGo0003ool0T003oookJ_l0oaSo0?lH00?oob@00_oonfX2oolN00;oE@3o00Ko0?lf
o`1GooooD@3ooe40on?o0?ooS003ool0^0;o0?nA00Cooo]Zo`3oDol0oe?ooo]Z0ol0on001Ooo0?3o
l`3ooo<0oooc0?oooe<000;ooo]Z0_oo07<01Oooa@3o03Ooo`0gool0=oooo`3=00;ooo]Z00?o0?mI
ol00ool0T_l00_l0T_l2oookJP;oo`0n1ooonfX3ooo^00;ooo]Z0_l0ob`3ooo/0003oolN0?oo0@3o
o`4000;oo`400ooo00`00ol0A?oooo]ZoookJP07oookJPWoo`2/0ol0000EoookJPOoo`2/2_oonfX5
ool03004ool10?n;o`3ooah0oolN00?oon`000Co0?l/obP0oooonf[ooo]Z0oookP06oookJP;oo`0n
00?of_l0oookJ_l0T_l00_l0T_l3o`3oF@04oookJ_oo0<go03Ooo`0go`;oolD00_oo07<2oookJP;o
oe<00_oc0?l2ool0l0;o0?oP00?ooo]Zo`3oDol0oe<00_oonfX00ol0oi7oT?l0ool0^002oon<00;o
hol00_ooD@001?l0Eooo0?lfoeD0oooonfX2oolN00;ooo]Z0_oo90002?oonf[o0?lHo`3o6?oonf[o
o`2@ooWo0?l0n?ooeOl00oooh`02oookJP;o04;o00?oo`11oookJ_l0onl00_l0onl00ol0]_ooEOl0
oookJP02oookJP;oon802?oonfX2ool0lP?ooo]Z0_m_0?l2oonj00;o0?mP00?ooo]Zool0Iooo06L0
1?oonfX2ool0[a;ooo]Z0_l0o`TioookJP00DOoonfX2o`3o2A;ooo]Z0_oo0:l3oookJP;oo`1W00Co
oo]Zo`3oH?l0of3o0;Oo0_oo^P02ofl0o`;ooo]Z00?oon@0ool0l_oo08D02?oonfX00ooohP3ooo]Z
oookJP02oookJP06oeGo0?l0]_oo0?o_o`3okooonf[oo`110_l0@_l2oolX0003oomd0?ooh`3oon<0
00?oA?l000Go0?onodCo0?m4o`3oA?l0o`1Oo`02oolT00;ooo]Z0_oo7P000ooonf[oE@3oo`1Oo`05
o`1Oo`07o`0?oooo0;Soo`2hool0^?l0oi7oo`00oookJP02o`3oD`05oookJ_l0on3o0?oPool0l?oU
o`000_oc0?l00ol0Gooo0?mMo`3oG@03ool0L`03ooo50?l0=ooo03Oo00?oobP00_l0oeT00ooo003o
obP0o`2Bo`02o`0?o`?oo`0n1ooonfX2ooo^00;ooo]Z00Co:03oooo/0?ook03oon`00_oo7P02ool1
00Coo`0<0_l0A?l6oookJP;o001o1ooo0:`4oookJPCo00003?oonfX5oolX00?oU?l000?oo`00o`3o
[Ol0ojd00ooob@02ool0[0GoogT00_oob@05o`3o30Oo0;3o0_oo7P03ooo/00?o0?mM0oookP02oook
JP?o00oo0ooo03h2o`0?o`;o09;o00Co`03oo`3oFOl0oeWo0?on0_oo0<d2o`0go`03ooo50?oo07?o
o`1c00?o0?n]0_l03ol2oo<0o`04o`0?oooonf[o0?oPoookJP?o0?mC0_l0o``01?l0oi7oo`2hool0
^?ooS002on?o00;ooe400_l03ol3ool000Co00oo00Koob@0oookJ_l0oaSo0?lHo`0?oooo0904ool0
00;oon<00ooo0002o`12o`;o0?l<00?o0?o_o`3o3?l0]_l00_mEo`02oookJP;oon801?oonfX2oolX
00?oiOl000Co0?mMonGo0?oUo`3oiOl00_ooN@02oonj0005o`3oH?oo:03o0?mPoomi0?m4o`000_oo
N@02oookJP;oo`2_4_oonfX00ol0o`WoiOl0oookJP25oookJP;o0?l94_oonfX3ool0[`?ooo]Z0_oo
06L3o`3oH0;ookX00_m_0?l3oookJP;oo`3b2?oonfX2oooR00?ooo]Z0_mEo`001?l0]_oo0?o_oook
J_oo0443o`12o`;ooo]Z0oooh`001OoEo`3onOl0ool0T?oo093ooo]Z00;o0?lH0ooo9002oookJP;o
oah00_mE0?l01?l0ocKo05OooomA0?ooD@02on?o00?oo`2h0_l0oi401?oonf[o0?mCo`3oDooonfX3
o`3oh005ool0l?oc0?ool`3ooo<0ooooD`000_oonfX2ool0L`03ooo50?l0=ooo03Oo00;oo`3=0_oo
nfX00ol0oeWo`03oo`2Bo`02o`2Bo`04oookJ_oJo`3oo`0nool0?POooo]Z0_ookP02oookJP03obP0
ool0obcoon`000;oon`000Cooah0ool10?oo0@3oo`400ooo00`2o`14o`Kooo]Z0_l007l7ool0[0Co
oo]Z1?l0000JoookJPGoo`2/2OoonfX4ool030;oo`4000?oRol0oolN0?oo7P000oook002obP0o`04
oookJ_ookP3oonh0ooo^00Kooo]Z0_oo03h00ooJo`3ooo]Zo`2Bo`02o`2Bo`?o0?mI00Cooo]Zool0
cOl0=ooo03Oo0_ooa@02ool0L`;ooo]Z00Cooe<0oookJ_oc0?ool`3o0_oo0?000ol0on3obP3ooook
JP02o`3oD`0<oookJ_oo00?o0?nAoi3o0?oo0;Sooh`0oomX0?oSo`3ooe40oookJ_ooD@3o0?lf0_mE
0?l00ooonf[ooah0oookJP02oookJP;oob@00ol0oaP2ool0T003ooWo0?oEo`3ooo]Z00;oon<000?o
og@0oookJ_oonfX00_l0@_l01Ooo047ooo]Zo`3okol0onoo0;Ko00;oEOl00_oonfX2oooR00Sooo]Z
00?oo`25ool0l_oo0?800_oonfX2ofl0o`;ookX00ol0of000ooonf[oo`1WoookJP03oookJP;oo`2_
4_oonfX2o`3o2CWooo]Z001@oookJP;o0?l94ooonfX01?oo0:oooo]ZoookJ_oonfX3ool0I`03oook
J_l0of3o0?mP00;ookX00_m_0?l3oookJP03ool0l_oo08Gooo]Z00Sooo]Z00Koon80oookJ_oonf[o
oo]ZoeGo0?l0]_l2o`3ok`;ooo]Z0_l0@_l2oookJP03oomd0?ooh`3oon<000CoA?l000?o0?onodCo
0?m4o`000_l0Gol2oolT00;ooo]Z0_oo7P08o`1Oo`?oo`2h00?o0?nAool00?l03ol00_l0oe<00ooo
nf[o0?oPo`3oh002onGo00;ol`3o00?o05ooo`3oGOl0oed00ooo07<01_ooa@3o03Ooool0cOoo:03o
00ooool000;o0?mI00Coo`00oolX0?l0T_oo00oo1?oo03h6oookJP;oonh00_oonfX01_lX0?ooon`0
ooo/0?ook03o05oooolN00;oo`401?oo00`00ol0A?oooo]ZoookJP05oookJPKoo`2/0_l007l7oook
JP;o00000olTo`0;o`2Mo`GoobP01?nDo`03o`3o[@;oolT00_l03ol2o`3o30CoogT01Ol0o``9o`2`
o`03o`3oGOl0Goooon`000;oon`000?o0?l/o`1Oool0oed00oookP03oookJP;o00oo0ooo03h2o`0?
o`;o09;o00Co`03oo`3oFOl0oeWo0?on0_oo0<d2o`0go`04ooo50?oo07?oo`1co`3o[@Co00oo00?o
l`3oo`0?oooo0?000_l0on000ooonf[o0?mCo`3oD`02o`3o3005o`3oTOoo0;Soo`2hoi3o0?ooS000
0_oSo`001?ooD@3o00ooo`0?ool03ol2ool000Go00oo0_oonfX2o`3ooP03ool0T?oo003oo`0000;o
o`000_ooh`03ool000;o04;o0_l0o``2o`3ok`03o`2foomEo`3oEOl000;ooo]Z0_oohP05oookJPCo
iOl000Co0?mMonGo0?oUo`3oiOl00_ooN@02oonj0006o`3oo_oo:03o0?mPoomi0?m4o`3o0?on0_oo
N@000ooonf[oo`2_ool0[`0BoookJP03o`3o2OoUo`3ooo]Z08Gooo]Z00?o0?l9oookJ_oonfX04Ooo
nfX2ool0[`?ooo]Z0_oo06L01?oonf[o0?mPo`3oH?l0of02oonj0004ofl0oooonf[ooo]ZoookJP;o
o`3b00?oo`25oookJ_oonfX01_oonfX2oooR00;ooo]Z0_mEo`001Ol0]_oo0?o_o`3okooonf[oo`11
00;o04;o0_oonfX3oooS0003ool0DOoio`3oo`2@00;oo`2@0_l0oaP00ooonf[oob@0oolT0002oook
JP;ooah00_mE0?l01?l0ocKo05OooomA0?ooD@02on?o00?oo`2h0_l0oi400ooonf[o0?mCo`3oD`02
oookJP;o0?oP00Goo`3`oo<0oooc0?ool`3ooomC0002oookJP?oo`1c0_l0=ol01_oo0<gooo]Zoook
J_o00?oo0?mIol00o`?o09;o00Cof_l0ool0?_oo03koo`0n1_oonfX3ooo^0003oookJ_lX0?oo0?l/
00?oon`000Cooah0ool10?oo0@3oo`400ooo00`2o`14o`Kooo]Z1_oo0:`2o`00O`Oooo]Z0_l00004
obCo00go09go0olTo`0;oookJPCoo`2/2_oonfX3ool030;oo`4000?oRol0oolN0?oo7P000oook002
obP0o`?oonh01_oonfX2ool0?P05om[o0?oonf[o09;oo`2Bool0obD00_l0oeT2oookJP05ool0cOl0
=ooo03Ooooo50?oonfX00_oo07<01Ooonf[ooe<0oomC0?oonf[ol`3o00;oo`3`0_l0on02oookJP03
o`3oDooonf[ooo]Z00;o0?nA00?oo`2hoi3o0?ooS0000_oSo`02oomA0004o`1Gool0ocKoE@3ooook
JP;ooah00_oonfX2oolT0004oookJ_l0oaSo0?lHoookJP;oo`2@00Gooo]ZomGo0?ooh`3oon<0oomd
0002oookJP;o04;o00?oo`11oookJ_l0onl00_l0onl2oeGo00?ooo]Z00?oon80oookJ_oonfX01ooo
nfX2ool0lP?ooo]Z00CoK`3ooookJ_oo^P3ookX00_l0of000ooonf[oo`1Wool0I`04oookJP03ool0
[ooonf[ooo]Z013ooo]Z0_l0o`TioookJP00D?oonfX2o`3o2A;ooo]Z0_oo0:l3oookJP;oo`1W00Co
oo]Zo`3oH?l0of3o0;Oo0_oo^P02ofl0o`;ooo]Z0_oo0?800ooo08Gooo]ZoookJP06oookJP04oooR
0?oonf[ooo]ZoookJP;oEOl000Go0;Koo`3okol0onoooo]Zool0@@02o`12o`04oookJ_ooM03oog@0
oooS00CoA?l000Go0?onodCo0?m4o`3oA?l0o`1Oo`02oolT00;ooo]Z0_oo7P08o`1Oo`03oon<0?oo
0;Soo`2h00;o0?nA00Co00ooo`3oDol0oe?ooo]Z0_l0on02onGo00;ol`3o00?oiOl0o`3oGOl0oed0
0ooo07<01?l0oego03Ooool0cOoo:002ool000;o0?mI00Coo`00oolX0?l0T_oo00oo0ooo03h6oook
JP?oonh000?ooo]ZobP0ool0ob`00_ook003o`1Oo`;oo`400ooo00`00ol0A?oooo]ZoookJP04oook
JPGoo`2/0_l007l01?oonf[o001oo`00Ool007l4oookJQ?o09go1?oo:005oiCo00Go0?n]0ol03ol2
o`3o30;oogT000?o0;3oodCo0?oUo`000_oUo`000ol0o`co0;3oo`2`o`08o`2`o`;o05oo00Cooah0
ooo/0?ook03oon`00ol0Gol2ooo^00Cooo]Z00Co00ooool0?_oo03koo`0n0_l03ol2o`2Bo`?o0?mI
00?ooo]Zool0cOoo0<d00_l0=ol00oooa@3oo`1cool0L`04o`0?o`;ol`3o0_oo0?02o`3oh003oook
J_l0oe?o0?mC00;o0?l<00Co0?nAool0^?oo0;Sooh`00_oSo`02oomA00;o00oo00?oE@3oool00?l0
3ol01?l03ol00ooo903ooo]Zo`3ooP02o`3ooP03ool0T?oo003oo`0000;oo`000_ooh`02ool00003
oookJ_l0@_oo04;o00;o0?l<00Co0?o_o`3o3?mEo`3oEOl00ooonfX2oooR00Cooo]Z1?oUo`001?l0
oegoiOl0onGo0?oUo`02oomi00;ookX000Ko0?onoolX0?l0of3oogT0odCo0?l0ooh2oomi00;ooo]Z
0_oo0:lAoookJP03o`3o2OoUo`3ooo]Z08Gooo]Z00?o0?l9oookJ_oonfX04?oonfX2ool0[`Cooo]Z
0_oo06L3o`3oH0;ookX00_m_0?l2oookJP?oo`3b2?oonfX2oooR00;ooo]Z0_mEo`001Ol0]_ooo`26
o`3okooonf[oo`1100;o04;o0_oonfX01OooM03oon<0oooS0?oo057oeOl000?oo`2@0_l0oaP00ooo
nf[oob@0oolT0002oookJP;ooah000?ooo]ZoeD0oomE0?l00_l0Eol2oomA0004on?o0?ooS03oo`2h
ool0^0;o0?nA00?ooo]Zo`3oDol0oe<00_oonfX2o`3oh005ool0l?oc0?ool`3ooo<0ooooD`000_oo
nfX3ool0L`;o03Oo00?oo`3=oookJ_oonfX00_l0oeT01Ol0obGo09;oo`2Boooonf[of_l000?oo`0n
1OoonfX3ooo^00;ooo]Z0_l0ob`2ooo/00;ooah00ooo0@02ool03003o`14oooonf[ooo]Z00Cooo]Z
1Ooo0:`2o`00O`04oookJ_l007oo001oo`00O`Cooo]Z7Ol0WOl00olTo`3ooo]ZoookJP07oookJPCo
o`2/2OoonfX3ool030;oo`4000?oRol0oolN0?oo7P000_ook002obP0o`03oookJ_ookP3oonh000Ko
oo]Z0_oo03h01OoJo`3ooo]Zo`2Bool0T_oo0?lU00;o0?mI0_oonfX01?oo0<go03Ooo`0gooooa@03
ool0L`03oookJ_ooD`3ooe<000;ol`3o0_oo0?02o`3oh0;ooo]Z00[o0?mCoookJ_oonf[o0?nAoi3o
0?oo0;Sooh`0oomX0?oSo`3ooo]Z0_ooD@001Ol0EoooE@3ooeD0oooonf[ooah000?ooo]Z0_oo9003
o`3o60;oo`2@00?onOl0omGo0?oonfX00_ooh`000oooM03ooo]ZoookJP02o`12o`06ool0@Ooonf[o
0?o_o`3okol0]_ooEOl00ooonfX2oooR00Sooo]Z0ooo0?82oookJP;oK`3o0_oo^P02o`3oH003oook
J_oo06Ooo`1W00Cooo]Z0_oo0:lBoookJP03o`3o2Ooonf[ooo]Z03Oooo]Z001?oookJP;o0?l94_oo
nfX2ool0[`?ooo]Z0ooo06L00ooonf[o0?mPo`3oH002oonj00;oK`3o0_oonfX2ool0lP03ool0QOoo
nf[ooo]Z00Kooo]Z0_oohP02oookJP;oEOl000Go0;Koo`3okol0onoooo]Zool0@@02o`12o`;ooo]Z
00Coog@0oooS0?ooM03o05oo0_m4o`001Ol0ookoA?l0odCo0?m4o`3o05oo00;oob@00_oonfX2oolN
00Wo05oo0ooo0;P01Ol0oi7o00ooo`3oDol0oe?ooo]Z00;o0?oP0_oUo`02oo<0o`03onGo0?l0oego
iOl000?oo`1c00Co0?mMo`0gool0=oooobP00_oo0002o`3oF@;oo`0000?o00ooom[o0?oo03h00_oo
03h6oookJP;oonh00_oonfX01?l0Goooon`0ooo/0?ook002o`1Oo`;oo`400ooo00`00ol0A?oo001o
o`00O`04o`00O`Coo`2/00?ooo]Zo`00Ool007l03ooo000Co`0]o`?oU?l01Ol0ojd6o`0?o`04o`3o
3?m4o`3o0;3oo`2`o`;oA?l000?o0?ono`2`ool0/?l02_l0/?l2o`1Oo`;ooah00_ook003o`1Oo`;o
onh01OoonfX3ool0?P04o`0?ool0T_oo09;oo`2Bo`?o0?mI00?ooo]Zool0cOoo0<d00_l0=ol00ol0
3oooo`1co`0?o`04o`0?o`;ol`3o00Coo`3`oookJ_l0on3ooo]Z0_l0oe<01?oo01_o0?l<o`3o3?l0
oi42ool0^004oon<0?oSo`3ohol0oomA00?o00oo00?oE@3oool00?l03ol00ol03ol00ooo903ooo]Z
oookJP02o`3ooP;oo`2@0ooo0002oooS00;oo`0000?ooo]Zo`12ool0@_l00_l0o``2o`3ok`03o`2f
oomEo`3oEOl000;ooo]Z0_oohP05oookJPCoiOl000Co0?mMonGo0?oUo`3oiOl00_ooN@001ooo^P3o
ogT0oomi0?oo:03o0?mPoomi0?l0ooh00_ooN@02oookJP;oo`2_4_oonfX00ooUo`3ooo]ZoookJP23
oookJP03o`3o2Ooonf[ooo]Z013ooo]Z0ooo0:l3oookJP;oo`1W00?ooo]Zo`3oH?l0of000_oo^P02
ofl0o`;ooo]Z0ooo0?800ooo08Gooo]ZoookJP05oookJP;oon800_oonfX3oeGo0004o`2fool0onoo
oo]ZoookJP;o04;o0ooonfX2oooS0003ool0DOoEo`3onOl000;oo`2@00?ooo]Zo`3o6?oonfX00ooo
90001?oonf[ooah0oolN0?oonfX2oeD0o`;o05Oo0_ooD@000ooSo`3ooh`0ool0^002ool0^004o`3o
TOoonf[o0?mCo`3oD`;ooo]Z0_l0on001Ooo0?3ol`3ooo<0oooc0?oooe<000;ooo]Z0ooo07<3o`0g
o`05ool0cOoonf[o0?mIo`3oFOl0obD00_l0T_l01?oonf[of_l0ool0?_oo03h6oookJP?oonh000?o
oo]ZobP0ool0ob`00_ook002oolN00?oo`400ooo00`6o`00O`Coo`2/00Cooo]Zo`00Ool007oo001o
0ooonfX00ol007oo9?l0obCo0007o`2Mo`03oolh0?l0;Ooo02go017o02go1?oo>005o`2Mo`;o9?l0
1ooonfX3ool0[0Sooo]Z00?o04Coool03?oo00`00_oo0@000on;o`3ooah0oolN0002ooo/00;o:03o
00Cooo]Zooo^0?ookP3oonh01OoonfX2ool0?P05om[o0?oonf[o09;oo`2Bool0obD00_l0oeT00ooo
nf[oo`3=ool0c@02o`0go`03ooo50?oo07?oo`1c00;ooo]Z0_ooD`02oo<0o`;oo`3`00So0?oPolX0
oooonf[o0?mCool06ooonf[oo`03o`3oT@;oo`2h00?ooh`0oomX0?oSo`000_ooD@001_l0Eooo0?lf
oeD0oomE0?oooo]ZoolN00;ooo]Z0_oo90001?oonf[o0?lHo`3o6?oonfX2ool0T003ooWo0?oEo`3o
o`1A00;oon<000Koog@0oookJ_l0@_oo04;oool0@OoonfX2o`3ok`03ool0Q_mEo`3oEOl000;ooo]Z
0_oohP08oookJP03ool0QOoo0?;oo`3b00?ooo]Z00CoK`3ooookJ_oo^P3ookX00_l0of000ooonf[o
o`1WoookJP03oookJP;oo`2_4_oonfX00ol0o`Wooo]ZoookJP0goookJP00CooonfX2o`3o2A;ooo]Z
0_oo0:l3oookJP;oo`1W00Cooo]Zo`3oH?l0of3o0;Oo0_oo^P001Om_0?oooo]ZoookJ_oonf[oo`3b
00;oo`251ooonfX2oooR00?ooo]Z00CoEOl0o`2fool0onoo0?o_0_oonfX01Ooo047o04;ooookJ_oo
nf[oog@000;oon<000Co05oooomi0?ooN@3o0?on1?m4o`000ol0Goooob@0oookJP02oookJP03oolN
0?l0Gooo05oo00Oo05oo0ooo0;P2o`0?o`;o0?mC00?o00ooo`3oh?l0on000_oUo`02oo<0o`03onGo
0?l0oegoiOl000?oo`1c00?o0?mMo`0gool0=ol00ooo00001_l0oeWoo`00ool00?oo003o00ooom[o
00?oo`0n1_oonfX2ooo^00;o05oo0oook002o`1Oo`;oo`400ooo00`2oookJPCo001o1Ooo0:`00ol0
07oooo]ZoookJP02oookJP[oo`002Ol0;Ol9oomD00;oobP02Ol0;Ol3o`3o[@Oo00oo1?l0/?l01Om4
o`3o0?ono`3oo_l0ooko0?mM00[o0;3o0_l0Gol2oolN00;oon`00ol0Gol2ooo^00Gooo]Z0ooo03h0
1?l03ooo09;oo`2Bool0T_l3o`3oF@04oookJ_oo0<go03Ooo`0go`;oolD000?oo`1co`0?ool03ol0
0ol03ol00ooc0?oooj40ool0l002o`3oh006ooo90?l0oe?o0?mCool06ol0o`co0?nA0ooo0;P01?oo
J03ohol0oomA0?ooD@02o`0?o`;oE@3o1?l03ol2oolT0004oookJ_l0oaSo0?ono`3ooP;oo`2@0_oo
0002oooS00?oo`0000?ooo]Zo`12oooo04400_l0o``01?l0onoo0?l<oeGo0?mEo`03oookJP03oooR
0?oonf[ooo]Z00Cooo]Z0ooUo`003ol0oego05ooonGo0?oUo`3oA?l0oomi0?oo^P3oogT0o`3oo_oo
:03o0?mPoomi0?m4o`3o0?onoomi0002oookJP;oo`2_4_oonfX00ol0o`WoiOl0oookJP22oookJP;o
0?l94_oonfX2ool0[`Cooo]Z00?oo`1WoookJ_l0of000_l0of02oonj00;oK`3o0_oonfX2ool0lP03
ool0QOoonf[ooo]Z00Gooo]Z0ooohP02oookJP;oEOl000Go0;Koo`3okol0onoooo]Zool0@@02o`12
o`;ooo]Z00Goog@0oooS0?ooh`3oeOl0ooWo0002ool0T004oookJ_l0oaSo0?lHoookJP;oob@00_oo
nfX2oolN00;oE@3o00Ko0?lfo`1GooooD@3ooe40on?o0?ooJ003ool0^004o`3oTOoo00?o0?mCo`3o
D`;ooo]Z0_l0on02ool0l0;ol`3o00?ooe<0oookJ_oonfX00ooo07<3o`0go`05ool0cOoonf[o0?mI
o`3oFOl0obD00_l0T_l01?oonf[of_l0ool0?_oo03h6oookJP;oonh000?ooo]ZobP0ool0ob`00_oo
k002oolN00?oo`400ooo00`00ooonf[o001oo`00O`02o`00O`Goo`2/00?o001ooookJ_oonfX01?oo
nfX00olTo`3o09goo`2Mo`04o`2Mo`03oolh0?l0;Ooo02go00So02go2_ooE009o`0]o`?oocP01?l0
WOl2obCo00Oooo]Z0_oo0:`8oookJP?oo`0<00?oo`40oh_o0?n;o`000_oo7P001?ook03o0?l/obP0
oooonfX3ooo^00Gooo]Z0_oo03h01OoJo`3ooo]Zo`2Bool0T_oooo]Z00;o0?mI00Cooo]Zool0cOoo
0<go03Oo0_ooa@02ool0L`;ooo]Z00Cooe<0oookJ_oc0?oooj400_oo0?002?l0on3obP3ooookJ_l0
oe?oo`0KoookJ_l0oi7oT?l00_oo0;P00oooJ03ohol0on?o0002oomA0005o`1GoomE0?ooE@3ooook
J_oo7P000ooonfX2oolT00;o0?lH00Kooo]Zool0T?oo093onOl0omGo0?oonfX2oooS0004oomd0?oo
nf[ooo]Zo`12o`;oo`1100Gooo]Zo`3okol0onoo0;KooeGo0003oookJP;oon802?oonfX3ool0lP;o
oo]Z00CoK`3ooookJ_oo^P3ookX00_l0of000ooonf[oo`1Wool0I`03oookJP;oo`2_4_oonfX2o`3o
2CSooo]Z001>oookJP;o0?l94_oonfX2ool0[`?ooo]Z0_oo06L2oookJP;o0?mP0_oo^P02ofl0o`;o
oo]Z0_oo0?800ooo08Gooo]ZoookJP06oookJP;oon800_oonfX2oeGo00?o0?o_00?ooo]Zool0@Ol0
@_l00ooonfX2oooS0006ool0DOooN@3oogT0o`3oo_m4o`3oogT00om4o`02oolT00;ooo]Z00Cooah0
oeD0oomE0?oo0?mM1ol0Gol2ool0^0;o00oo0_l0oe<00ol03ooo0?oPo`3oh002onGo00;ol`3o00Co
iOl0o`3oGOoUo`3oiOl00_oo07<00oooa@3o03Ooool00003ool00003o`3oFOoo003oo`0000;oo`00
00?of_l0ool0?_oo03h01ooonfX01?ookP3o05ooo`1Oool0Gol2ooo/00?o05oo0_oo0@02ool03003
o`14oooonf[ooo]Z00?ooo]Z1?oo0:`6oookJP;o9?l02?l0Gol4o`0]oa3ooe@01Ooo:004oiCo0003
o`3o[Ol0;Ooo02go00?o02go2?l03ol3o`2`o`Ko0?on0_l0oed7o`2`o`?o05oo00Cooah0ooo/0?oo
k03oon`00_l0Gol2ooo^00Gooo]Z0ooo03h01?l03ooo09;oo`2Bool0T_l3o`3oF@04oookJ_ooN@3o
03Ooo`0go`;oolD000?oo`1co`0?ool03ol00_l03ol2oo<0o`;oo`3`00?o0?oPo`3o3?oob@000_l0
oe<00ooonf[o0?l<o`3oT@02ool0^003oon<0?oSo`3ohol000;ooe400_l03ol2oeD0o`Co00oo0_oo
90000ooonf[o0?lHo`3ooP02ool0T003o`0?oooo003oo`0000;oon<00_oo00001Ooonf[o04;oo`12
oooonf[o0?l<00;o0?o_00Go0;KooeGo0?mEo`3o0;3ooookJP02oooR00Gooo]Z0ooUo`001_l0oego
05ooonGo0?oUo`3oA?l0o`3ooP;oogT000Oo0?onoolX0?l0of3oogT0odCo0?l0ookoogT000?ooo]Z
00?oo`2_oookJ_oonfX04?oonfX00ol0o`WoiOl0oookJP22oookJP03o`3o2Ooonf[ooo]Z013ooo]Z
0ooo0:l3oookJP;oo`1W00?ooo]Zo`3oH?l0of000_oo^P02ofl0o`;ooo]Z0ooo0?88oookJP;oon80
0_oonfX2oeGo0005o`2fool0onoo0?o_oookJ_oo04400_l0@_l2oookJP06oomd0?ooh`3oon<0ool0
DOoEo`3onOl00_oo0902o`3o6003oookJ_oo903oob@000;ooo]Z0_oo7P02oeD0o`04o`3o=_l0Eooo
oe40oomA00;ohol000Gooh`0ool0^?oo0;So0?nAool00`03o`3oD`03oookJ_l0on3o0?oP00;oo`3`
0_oc0?l00oooD`3ooo]ZoookJP03ool0L`?o03Oo00Goo`3=oookJ_l0oeWo0?mIo`3o9@02o`2Bo`04
oookJ_oJo`3oo`0nool0?PKooo]Z00?oonh0oookJ_oonfX00_l0ob`2ooo/00;ooah00_oo0@001?oo
nf[oo`0<ool03?l0A?l4oookJPGoo`2/1_oonfX00olTo`3o09goo`2Mo`02o`2Mo`03oolh0?l0;Ooo
02go00Go02go6_ooE006o`0]o`;oocP00ol0WOl00olTo`3ooo]ZoookJP05oookJP?oo`2/1_oonfX4
ool03004ool10?n;o`3ooah0oolN00;oon`000?o:03ooookJ_ookP000_ookP05oookJP;oo`0n00Go
f_l0oookJ_l0T_oo09;ooookJP02o`3oF@04oookJ_oo0<gooo]Zo`0go`;oolD00_oo07<2oookJP03
oomC0?oc0?ool`3o00;oo`3`0_l0on000oo:0?oo0?mCo`3oD`02oookJP06o`3oTOn@o`3oo`2hoon<
0?ooJ03ohol00_ooD@02o`1Go`;oE@3o00Cooo]ZoolN0?oonf[ooo]Z0ooo9002o`3o6006oookJ_oo
093onOl0ooWo0?oEo`3oo`1A0_ooh`02oookJP;o04;o00Goo`11oookJ_l0onoo0?o_ool0QP02oeGo
00;ooo]Z0_oohP08oookJP?oo`3b0_oonfX2ofl0o`;ookX00_l0of000ooonf[oo`1Wool0I`04oook
JP;oo`2_4_oonfX00ol0o`Wooo]ZoookJP0foookJP00COoonfX00ol0o`Wooo]Zo`3o2@0BoookJP;o
o`2_0ooonfX2ool0I`03oookJ_l0of3o0?mP00;ookX000Oooo]Zofl0oooonf[ooo]ZoooT0?oo0?;o
o`2500Sooo]Z0_oohP02oookJP;oEOl000?o0;Koo`3okol0onl00_oonfX2o`12o`;ooo]Z0_ooh`00
1Ooo057oogT0oomi0?l0ookoA?l000;oogT000Co05ooodCo0?oo903oob@00_oonfX00ooo7P3oE@3o
oeD0o`03o`3oG@Go05oo0_oo0;P3o`0?o`04o`3oDol0Gooo05ooo`3oh0;oo`3`0_oc0?l01?oUo`3o
0?mMonGo0?oUo`02ool0L`03ooo50?l0=oooo`0000?oo`000_l0oeT3ool00003om[o0?oo03koo`0n
00Kooo]Z0_ookP02o`1Oo`?oon`00_l0Gol2ool100;oo`0<00?o04CooookJ_oonfX00ooonfX4ool0
[0;ooo]Z3_l0Gol01?l0;Oooo`00ool00?oo0004oomD00koohH01?oo:004oiCo00Go0?n]1Ol0;Ol6
o`0?o`?o0;3o1_l0ooh4o`1Oo`Go0;3o00Co05ooool10?l0Gooooah00oook002oolX00;oonh01Ooo
nfX3ool0?P04o`0?ool0T_oo09;ool00o`;o0?mI0_oonfX01?ooN@3o03Ooo`0gooooa@02ool0L`Co
00oo0_oc0?l01?oo0?3oolT0o`3oh?oob@03o`3oD`03o`2`ool0oi7o0?nA00;oo`2h00?ooh`0on?o
0?ooD@000_ooD@000ol03oooE@3ooeD0o`04o`0?o`;oob@000Cooo]Zo`3o6?l0oaSo0?on0_oo0900
1?oio`3oo`00oooS0?ooh`02ool000;ooo]Z00?o04;oool0@Ol0o``00_l0onl01Ol0]_ooEOl0oeGo
0?l0/?oooo]Z00;oon801_oonfX2onGo0004o`3oGOl0GoooiOl0onGo00;oU?l000WoogT0oonj0?oo
N@3oobP0o`3oH?ooN@3oA?l0o`3oo_ooN@000ooonfX2ool0[a7ooo]Z00?o0?l9onGo0?oonfX0POoo
nfX2o`3o2A;ooo]Z0_oo0:l4oookJP04ool0Iooonf[o0?mPo`3oH0;ookX000?ooo]Zofl0oom_0?l0
0_oonfX2ool0lP03ool0QOoonf[ooo]Z00Gooo]Z0_oohP03oookJP;oEOl000Ko0;Koo`3okooonf[o
oo]Zool0@Ol0@_l2oookJP06oomd0?ooh`3oon<0ool0DOoEo`3onOl00_oo09000ooonf[o0?lHoook
JP02oolT00;ooo]Z0_oo7P02oeD0o`04o`3o=_l0Eooooe40oomA00;ohol000Kooh`0ool0^?oo0;So
0?nAool00ooonfX2o`3oD`03oookJ_l0on3o0?oP00;oo`3`0_oc0?l00oooD`3ooo]ZoookJP03ool0
L`?o03Oo00Goo`3=oookJ_l0oeWo0?mIo`3o9@02o`2Bo`;of_l00_oo03h5oookJP;oonh000?ooo]Z
obP0ool0ob`00_ook002oolN00;oo`4000Cooo]Zool03?oo00co04Co1OoonfX3ool0[0Oooo]Z1?l0
WOl00ooo>03o02goo`0]o`04o`0]o`Oooe@04oooQP08oomD00Go02go00?oocP0o`2Mool0WOl00_l0
WOl7oookJP?oo`2/1_oonfX3ool030;oo`400_oo7P02ooo/0003obP0oooonf[oonh000;oonh01Ooo
nfX2ool0?P06om[o0?oonf[o09;oo`2Booo00?oo0?mI0_oonfX01?oo0<gooo]Zo`0gooooa@03ool0
L`03oookJ_ooD`3ooe<000;ol`3o0_oo0?000ol0on3obP3ooookJP02o`3oD`03oookJ_l0oi7o0?nA
00;oo`2h00?ooh`0on?o0?oSo`000_ooD@001?l0EoooE@3ooeD0oooonfX2oolN00;ooo]Z0_oo9002
o`3o6006oookJ_oo093oo`2@ooWo0?oEo`3oo`1A0_ooh`001?ooM03ooo]ZoookJ_l0@_l2ool0@@05
oookJ_l0onooo`26o`2foomEo`000_oonfX2oooR00Sooo]Z00?oo`25ool0l_oo0?800ooonfX01Om_
0?oooo]Zoonj0?oo^P3o0?mP00;ooo]Z00?oo`1WoookJ_oonfX00_oonfX2ool0[a;ooo]Z00?o0?l9
oookJ_oonfX0=_oonfX004gooo]Z0_l0o`TBoookJP;oo`2_0ooonfX2ool0I`;ooo]Z00Go0?mPo`2g
oooo^P3ookX0ofl0o`03oookJP;oo`3b00?oo`25oookJ_oonfX01OoonfX2oooR00?ooo]Z0_mEo`02
o`3ok`;ooo]Z0_l0@_l2oookJP03oomd0?ooh`3oon<000;oogT000Co0?onodCo0?ooN@3oogT00_l0
Gol2oolT00;ooo]Z00?ooah0oeD0oomE0?l01?l0oed5o`1Oo`05ool0^?l03ooo00ooo`0?ool0oe<0
0ol0Gol01_l0on3oo`3`oo<0oooc0?ooiOl0o`3oG@;oiOl00_oo07<00oooa@3o03Ooool00003ool0
00;o0?mI0ooo00000ooJo`3oo`0nool0?P06oookJP;oonh000Co05ooooo/0?ook03oon`00_l0Gol2
ool100?oo`0<1OoonfX4ool0[0?ooo]Z00?o0?mMo`1Oool0Gol02ol0Gol3ool00003oomD0?ooQP3o
ohH000GoohH03olVo`000oooQP3oU?l0oiCo0002oiCo00Go0?n]1?l03ol4o`0]o`Co00oo0ol0/?l7
o`3ooPKo05oo0_l0/?l01Ol0Goooo`40o`1Ooooo7P3oobP000;oon`00_oo:002ooo^00Gooo]Z0ooo
03h01?l0ooko09;oo`2Booo00?l2o`3oF@03oookJ_ooN@3oogT000;o03Oo00?oolD0ool0Looo07<0
1?l03ol2oo<0o`04ool0l?l0on3o0?oPooo900;o0?mC0_l0/?l01_l0oi7oo`2hool0^?ooS03oiOl0
on?o00;ooe400_l03ol2oeD0o`?o00oo00Cooo]ZoolT0?oo903ooo]Z0_l0oaP2ool0T003ooWo0?l0
ookoo`0000;oon<000?oo`00oookJ_oonfX00_l0@_l2o`2`o`;o0?o_0omEo`02oookJP03oooR0?oo
nf[ooo]Z00Gooo]Z0_oUo`000ol0oego05ooonGo0002oiCo0009o`3oo_oo^P3oogT0odCo0?oo:03o
A?l0oomi0?l0ookoogT000?oA?l00_oo0:lBoookJP03onGo0?l0o`Wooo]Z083ooo]Z00?o0?l9oook
J_oonfX04?oonfX3ool0[`?ooo]Z0_oo06L00ooonf[o0?mPo`3oH002oonj00;oK`3o0_oonfX3ool0
lPSooo]Z00Coon80oookJ_oonf[ooo]Z0_mEo`001_l0]_oo0?o_o`3okooonf[oo`11o`12o`;ooo]Z
0_ooM002oooS0005omGo0?oio`3oo`2@ool0T?oonfX00_l0oaP3oolT00;ooo]Z00Gooah0oeD0oomE
0?oo0?lfo`1Go`02oomA00;ohol000Kooh`0ool0^?oo0;So0?nAool00ooonfX2o`3oD`03oookJ_o:
0?oo0?oP00;oo`3`0_oc0?l00oooD`3ooo]ZoookJP03ool0L`?o03Oo00Goo`3=oookJ_l0oeWo0?mI
o`3o9@02o`2Bo`03om[o0?oo03koo`0n00Kooo]Z0_ookP000ooonf[o:03oooo/0002ooo/0004oolN
0?oo0@3oo`40ool100;oo`0<00?o04CooookJ_oonfX00ooonfX3ool0[0Kooo]Z00Go9?l0o`2Mool0
WOoo09gooolh0005o`0]o`Kooe@01_ooQP000ol0003o9_l0obKo000=obKo00SoohH000?o00OooomD
0?ooE0000_ooE005o`0]o`04oolh0?l0WOoo09goo`2Mo`Kooo]Z1?oo0:`5oookJP?oo`0<0_oo0@00
1_n;o`3ooah0ooo/0?ook03o:03ooookJP?oonh01OoonfX2ool0?P;ooo]Z0_l0T_l2o`3oF@;ooo]Z
00Coo`3=o`0gool0=oooolD00ooo07<00ooonf[ooe<0oomC0002oo<0o`;oo`3`00Co0?oPolX0oooo
nf[o0?mC0_oonfX01Ol0oi7oT?l0ool0^?ooS03oofP000;ohol000?ooe40o`1Gool0Eol00_mE0?l2
oolN00;ooo]Z0ooo9002o`3o6003oookJ_oo093onOl000;oeOl000?oo`1AoooS0?ooM0000_oonfX2
o`12o`05ool0@Ooonf[o0?o_o`3okol0]_l00_mEo`02oookJP;oon802?oonfX3ool0lP;ooo]Z00Go
K`3ooookJ_oo^P3ookX0o`3oH002oookJP03ool0Iooonf[ooo]Z00;ooo]Z0_oo0:lBoookJP;o0?l9
=ooonfX004cooo]Z00?o0?l9oookJ_l0o`T04_oonfX2ool0[`;ooo]Z0ooo06L00ooonf[o0?mPo`3o
H002oonj00;oK`3o0_oonfX00oooi03oo`3bool0Q@08oookJP;oon800_oonfX2oeGo0006o`2fool0
onooo`26oookJ_oo047o04;o0ooonfX2oooS00CoogT000?oA?l0oomi0?ooN@000_l0Gol00ooo903o
05oooookJP02oolN0003oeD0ool0oego0?mM00;o0?mM00?o05ooo`3oGOl0oed00ol0Gol3o`0?o`06
o`3oDol0Gooo05ooo`1Oool0on3oo`3`0ooc0?l3onGo00;oo`1c00CoolD0o`0gool0=oooo`3=0_oo
0002o`3oF@Coo`000_oo03h6oookJP03ooo^0?l0oego0?mM00?oon`00_l0Gol2ool100;oo`0<1Ooo
nfX4ool0[003oookJ_l0oego0?mM00?o0?mM2ol0Gol3ool000?oohH00_oonfX:obKo00Goo`3K3OlV
o`000oooQP3o00ooo`0?o`06o`0?o`Co02go0ol03ol2o`2`o`03oookJ_l0ooko0?on00Go0?on00?o
oo]Zo`1Oool0Gol00_l0Gol2ool03003o`1Ooooo0@3o00oo00;oobP000Coon`0oolX0?oo:03ooo]Z
0_ookP05oookJP;oo`0n00Gof_l0o`3oo_l0T_oo09;ool00o`02o`3oF@?oogT00_l0=ol00oooa@3o
o`1co`0?o`04o`0?o`;ol`3o00Coo`3`o`3oh?l0on3oolT00_l0oe<2o`2`o`05o`3oTOoo0;Soo`2h
oon<0?oSo`000oooD@001?l03ooo0?lfoeD0oomE0?l3o`0?o`;oob@000Cooo]Zo`3o6?l0oaSo0?on
0_oo09001Ooio`3o0?onoooS0?ooh`3oo`0000;ooo]Z0_l0@_l2o`2`o`;o0?o_00?o0;KooeGo0?mE
o`000_oonfX2oooR00Gooo]Z0_nDo`001?oUo`3o0?mMo`1OoooUo`02oiCo00;oA?l000KoogT0o`3o
o_oo:03o0?mPodCo0?l0ooh4odCo0003oookJ_oo0:oooo]Z017ooo]Z00?oiOl0o`3oGOoonfX0Oooo
nfX2o`3o2A;ooo]Z0_oo0:l3oookJP;oo`1W00?ooo]Zo`3oH?l0of000_oo^P02ofl0o`?ooo]Z0_oo
0?88oookJP;oon800_oonfX2oeGo0005o`2fool0onoo0?o_oookJ_oo04400_l0@_l2oookJP04oomd
0?ooh`3oon<0ool0D@;onOl00_oo0902o`3o6003oookJ_oo903oob@000;ooo]Z0_oo7P02oeD0o`03
o`1GooooD@3ooe4000;ohol000KoofP0ool0^?oo0;So0?nAool00ooonfX2o`3oD`03oookJ_o:0?oo
0?oP00;oo`3`0_oc0?l2oomC0004oookJ_oo07?oo`1cool0L`?o03Oo00Goo`3=oookJ_l0oeWo0?mI
o`3o9@02o`2Bo`03om[o0?oo03koo`0n00Kooo]Z0_ookP001?oonf[o:03oooo/0?ook002oolN00?o
o`400_oo00`5oookJP?oo`2/1_oonfX4o`2Mo`Go02go1?ooE004oon600?ooo]Z2OlVo`06ool0f`co
9_l01OooQP04oomD00Co02go0_oo>002o`2Mo`Kooo]Z1?oo0:`4oookJP;oo`0<00?ooo]Zool10?oo
0@000_oo7P02ooo/0003obP0oooonf[oonh000;oonh01OoonfX01?oo03kof_l0oookJ_oonfX2o`2B
o`;o0?mI00?ooo]Zool0cOoo0<d00_l0=ol00oooa@3oo`1cool0L`02oookJP05oomC0?oonf[ol`3o
oo<0oooo0?000_l0on001_oonf[o0?mCo`3oDooonf[oo`03o`3oT@;oo`2h00?ooh`0on?o0?oSo`00
0_ooD@001?l0Eooo0?lfoeD0oomE0?l2oolN00;ooo]Z0_oo9002o`3o6006oookJ_oo093oo`2@ooWo
0?oEo`3oo`1A0_ooh`02oookJP;o04;o00Goo`11oookJ_oonf[o0?o_ool0QP02oeGo00;ooo]Z0_oo
hP08oookJP03ool0QOoo0?;oo`3b00;ooo]Z0_m_0?l2oonj00;o0?mP00?ooo]Zool0Iooo06L01?oo
nfX00ooo0:oooo]ZoookJP0@oookJP;o0?l9=ooonfX004cooo]Z0_l0o`TBoookJP;oo`2_0ooonfX2
ool0I`;ooo]Z00Go0?mPoonj0?oo^P3ookX0ofl0o`03oookJP03ool0l_oo08Goo`2500Oooo]Z0_oo
hP02oookJP;oEOl000Go0;Koo`3okol0onoooo]Zool0@@02o`12o`;ooo]Z00?oog@0oooS0?ooN@00
0oooN@001Om4o`3oogT0oomi0?ooN@3o0?mM00;oob@000Co05oooolN0?oo7P3oE@3o1?l0oed01_l0
Gooo0?mMo`3oGOooS03oo`2ho`1Oo`?o00oo00?o0?mCo`1Oool0Gol00_l0Gol01ooo0?3ol`3ooo<0
oooc0?ooiOl0oomC0?oonfX00_oo07<01?oUo`3o03Ooo`0goooo0<d2oiCo00;o0?mI1?oo0002ool0
?PGooo]Z00Co0?mMooo^0?l0oego0?mM0_ook002o`1Oo`;oo`400ooo00`4oookJPCoo`2/0ooonfX6
o`3oG@So05oo0ooo00000oooQP3ooo]ZoookJP06obKo00[oo`3K00?o0?l<o`2`ool0/?l00_l0/?l7
ool0f`Oo9_l00oooQP03o`0?o`03ool00?l03ooo02go00Co02go00?o00ooo`2`ool0/?l00ooonfX5
o`3ooP;ooo]Z1?l0Gol2ool03005ool10?oo:03oobP0oolX0?ook0000_oo:0000onDo`3oonh0ooo^
0005oookJP;oo`0n00Cof_l0o`3oo_l0T_oo09;o0_l0oeT3oomi00;o03Oo00CoolD0ool0Looo07?o
oo]Z0ol03ol2oo<0o`04ool0l?l0on3o0?oPooo900;o0?mC00?o0?l<o`2`ool0oi400_oo0;P00ooo
S03oiOl0on?o0002oomA00;o00oo0_mE0?l3o`0?o`04oookJ_oo903oob@0oookJP;o0?lH0_oo0900
0ooio`3o0?onool0D@02oooS0003ool00?oonf[ooo]Z00;o04;o00Co0;3oo`3okol0onoo0;Ko0_mE
o`02oookJP;oon801OoonfX2oiCo0004onGo0?l0oego05ooonGo00?o0?mM00GoA?l0oomi0?oo^P3o
obP0o`3oH002odCo0006o`3oo_m4o`3oA?l0odCo0?oonf[oo`2_4_oonfX00ooUo`3o0?mMoookJP1o
oookJP03o`3o2Ooonf[ooo]Z017ooo]Z00?oo`2_oookJ_oonfX00_oonfX2ool0I`03oookJ_l0of3o
0?mP00;ookX00_m_0?l2oookJP;oo`3b00?oo`25oookJ_oonfX01_oonfX01?oohP3ooo]ZoookJ_oo
nfX2oeGo0003ool0Q_l0onoo0?o_00;oo`1100Co04;ooookJ_oonf[oog@00_ooh`000ooo057onOl0
ooWo0002ool0T0;o0?lH00?ooo]ZoolT0?oo90000_oonfX2oolN00;oE@3o0_l0Eol2oomA0007on?o
0?ooJ03ooh`0ool0^?n@o`3o0?nAoookJP02o`3oD`;ooo]Z00?o0?oPool0l?oo0?000_oc0?l2oomC
0004oookJ_oo07?oo`1cool0L`?o03Oo00Goo`3=oookJ_l0oeWo0?mIo`3o9@02o`2Bo`03om[o0?oo
03koo`0n00Kooo]Z00Coonh0oookJ_lX0?oo0?l/0_ook0001?oo7P3oo`40ool10?oo0@02ool03003
o`14oooonf[ooo]Z00;ooo]Z1?oo0:`5oookJP?o09go1Ol0;Ol4oomD00CoohH000?ooo]ZobKo0?lV
o`001?lVo`0:ool0f`Gooo]Z1ooo0=/7obKo00GoohH01?ooE004o`0]o`03oolh0?l0WOoo09go00Ko
oo]Z0ooo0:`5oookJP;oo`0<00Coo`40oh_o0?oo7P3ooah00_ook0000olX0?oooo]Zooo^0002ooo^
00Gooo]Z00?oo`0nom[o0?oonfX00ol0T_l2o`3oF@04oookJ_oo0<goo`3=o`0go`;oolD00_oo07<0
0ooonf[ooe<0oomC0002oo<0o`;oo`3`00_o0?oPolX0oooonf[o0?mCool06ooonf[o0?nAoi3o0?oo
0;Sooh`0oomX0002on?o0003oomA0?l0Eooo05Oo00;oE@3o0_oo7P02oookJP;oob@000?ooo]Zo`3o
6?l0oaP00_oo09001_oio`3oeOl0omGo0?oo057oon<0oomd00;ooo]Z0_l0@_l01_oo047ooo]Zo`3o
kooo08Ko0;KooeGo00?ooo]Z0_oohP07oookJP03ool0QOoo0?;oo`3b00;ooo]Z0_m_0?l01?oonf[o
okX0o`2gool0of02oookJP03ool0Iooonf[ooo]Z00;ooo]Z00?oo`2_oookJ_oonfX04?oonfX2o`3o
2COooo]Z001<oookJP;o0?l94_oonfX01?oo0:oooo]ZoookJ_oonfX3ool0I`03oookJ_l0of3o0?mP
00;ookX00_m_0?l2oookJP;oo`3b00?oo`25oookJ_oonfX01OoonfX3oooR00;ooo]Z0_mEo`001_l0
]_oo0?o_oookJ_oonf[oo`11o`12o`?ooo]Z0_ooh`03oomi0005odCo0?ooN@3oogT0oomi0?l0oed0
0_oo90001?l0Gooooah0oolN0?oo7P04o`3oG@05o`1Oool0oego0?mMo`3oGOn@o`000_oo0;P2o`0?
o`03o`3oDol0Gooo05oo00;o05oo0_oo0?02oo<0o`03onGo0?ooD`3ooo]Z00;oo`1c00CoiOl0o`0g
ool0=oooo`3=0_nDo`02o`3oF@Goo`0000?oo`0noookJ_oonfX00ooonfX2ooo^00;o0?mM0_ook002
o`1Oo`;oo`400_oo00`00ol0Gooooo]ZoookJP02oookJP?oo`2/0ooonfX00ol0/?ooiOl0onGo0005
o`3oG@Oo05oo00?o0?onool00?oonfX01OlVo`06ool0f`03o`000?oob@3oolT000;oolT01Ol0o``7
o`2`o`Cooo]Z1?oo0=/6obKo00?oohH00_oo0003o`2`o`Co02go00GoocP0o`2`oolTo`3ooo]Zool0
0002oolX00?o0?on0ooonfX3o`1Oo`;oo`0<00Goo`40oolX0?oo:03oobP0ooo/0003oiCo00;oonh0
1OoonfX2ool0?P04om[o0?l0ooko09;oo`3ooP;o0?mI0_ooN@001om4o`3o03Ooo`0gooooa@3oo`1c
odCo0?oonfX00ol03ol2oo<0o`04ool0l?l0on3o0?oPo`3o30;o0?mC0_l0/?l01?l0oi7oo`2hool0
^?oUo`02on?o0004oomA0?l0Eooo00ooo`3o=P;oE@3o0_l03ol01?oonf[oob@0oolT0?oonfX2o`3o
60;oo`2@00?onOl0o`3oo_oo05400_ooh`000ooo003ooo]ZoookJP02o`12o`;o0;3o0_l0onl00ol0
]_ooEOl0oeGo0002oookJP03oooR0?oonf[ooo]Z00Cooo]Z00CoU?l0o`3oGOl0oego05oo1?l0oed0
1Om4o`3oogT0oonj0?oo:03o0?mP00;oA?l000Go0?onodCo0?m4o`3oA?l0oookJP02ool0[a7ooo]Z
00?o0?l9o`3oGOoonfX0O_oonfX2o`3o2A;ooo]Z0_oo0:l3oookJP;oo`1W0_oonfX00ol0of3ookX0
oonj0002ofl0o`?ooo]Z0_oo0?88oookJP;oon800_oonfX2oeGo0005o`2fool0onoo0?o_oookJ_oo
04400_l0@_l2oookJP05oomd0?ooh`3oo`1AomGo0?oio`000_oo0903o`3o6004oookJ_oo903ooo]Z
oookJP;ooah00_mE0?l01ol0ocKo05OooomA0?ooD@3ohol0oomX0?ooS0000_oo0;P00ol0oi7ooo]Z
o`3oD`02o`3oD`03oookJ_l0on3oo`3`00;oo`3`00Col`3ooomC0?ooD`3ooo]Z0ooo07<3o`0go`05
ool0cOoonf[o0?mIo`3oFOl0obD00_l0T_l00ooJo`3oo`0nool0?P05oookJP;oonh000?ooo]ZobP0
ool0ob`00_ook0000ooo7P3oo`40ool10003ool030Gooo]Z0ooo0:`4oookJP04obCo0?l0WOoo09go
o`2Mo`Co02go1?ooE004oon600Go9_l01_oo0=/3o`0001;ooo]Z1?oo0=/6obKo00GoohH00oooE004
o`0]o`03oolh0?l0WOoo09go00Gooo]Z0ooo0:`5oookJP;oo`0<00Coo`40oh_o0?oo7P3ooah00_oo
k0000olX0?oooo]Zooo^0002ooo^00Gooo]Z00?oo`0nom[o0?oonfX00_l0T_l01Ooonf[o0?mIo`3o
FOoonf[oo`3=00;o03Oo00?oolD0ool0Looo07<00_oonfX2oomC00;ol`3o00Coo`3`o`3oh?l0on3o
oo]Z0_l0oe<00ooo01_ooo]Zo`3oT@02ool0^003oon<0?oSo`3ohol000;ooe400_l0Eol2oeD0o`04
oolN0?oonf[ooo]ZoookJP;oob@00_l0oaP00ooonf[oo`2@ooWo0002omGo0003ool0DOooh`3oog@0
00;ooo]Z0_l0@_l01Ooo047ooo]Zo`3okol0onoo0;Ko00;oEOl00_oonfX2oooR00Sooo]Z0_oo0?83
oookJP;oK`3o0_oo^P001?l0of3ooo]ZoookJ_oo06L4oookJP;oo`2_4_oonfX00ol0o`Wooo]Zoook
JP0eoookJP00BooonfX2o`3o2A;ooo]Z0_oo0:l3oookJP;oo`1W00?ooo]Zo`3oH?l0of000ooo^P00
1Om_0?oooo]ZoookJ_oonf[oo`3b00;oo`251ooonfX2oooR00;ooo]Z0_mEo`001_l0]_oo0?o_ool0
Q_oonf[oo`11o`12o`?ooo]Z00Koog@0oooS0?oo003oo`00oomi0?m4o`04oomi00;oob@00_oonfX2
oolN00Go0?mM00Co05ooo`3oGOl0oego0?mM0_oo0;P00ol0ojgo00ooo`1Oo`05o`1Oo`06ool0l?oc
0?ool`3oonGo0?ooD`3ooo]Z0_oo07<01_ooa@3o03Ooo`0gool0=oooo`3=oiCo00;o0?mI0_l0T_l3
ool00003ool0?_l0ojgooo]Z00?ooo]Z0_ookP02o`3oG@;oon`000Co05ooo`3oGOoo0@3oo`400_oo
00`00ol0Gooooo]ZoookJP02oookJP?oo`2/0_oonfX5onGo00Go0?mM1_l0Gol3o`3ooP?o9_l01?oo
0=/4oookJP03o`000?oo003oolT000?oolT01?l0o``:o`2`o`Oooo]Z0ooo0=/5obKo00?oo`000_oo
E002o`2`o`Co02go00?o0;3oobCo0?oo00001?oo:0000onDo`3o0?onoookJP04oookJP04o`1Ooooo
00coo`0<ool100;oobP000?oU?l0ooo/0?nDo`000_nDo`02ooo^00Gooo]Z0_oo03h01?oJo`3o09;o
o`2Bool0ooh2o`3oF@;oogT000GoA?l0o`0gooooa@3oolD0ool0L`02oookJP;o00oo0_oc0?l2ool0
l008o`3oh?l0/?oo0?mCo`3oDoooN@3o0;3oonGo0?n@o`02ool0^006onGo0?oSo`3ooe40oomA0?l0
Eooo0?lf0_mE0?l2o`0?o`07oookJ_oo903oob@0oolT0?oonf[o0?lHoookJP02ool0T003ooWo0?oE
o`3oon<000;oon<000Coog@0oookJ_l0@_oo04;o0_l0/?l2o`3ok`03o`2foomEo`3oEOl000;ooo]Z
00?oon80oolX0?oonfX00ooonfX5o`3oG@04o`1Oool0oego0?mMo`3oG@;oA?l000KoogT0odCo0?oo
:03oU?l0odCo0?l0ooh3odCo0003oookJ_oo0:ooo`2_01;ooo]Z00?o0?mMoookJ_oonfX0OOoonfX0
0ol0o`Wooo]ZoookJP0@oookJP?oo`2_0ooonfX00ooo06Oooo]ZoookJP02o`3oH0;ookX00_m_0?l2
oookJP;oo`3b00?oo`25oookJ_oonfX01_oonfX01?oohP3ooo]ZoookJ_oonfX2oeGo00;o0?o_00Co
oo]Zool0@Ol0@_oo04;o0_oonfX01?ooM03oon<0oooS0?oo0542ooWo0005ool0T?oonf[o0?lHo`3o
6?oonfX00_oo9002oookJP05oolN0?oonf[oE@3oo`3o=_l0Eol00_ooD@02on?o0005oon<0?oo0;So
o`2ho`3oTOoo00<00ol0oe<00ooonf[o0?oPo`3oh002ool0l003oo<0ooooD`3ooe<000;ooo]Z0_oo
07<3o`0go`05ool0cOoonf[o`03oo`3oFOl0obD00_l0T_l01?oJo`3oo`0nool0?_oo03h4oookJP;o
onh000Cooo]ZobP0ooook03oon`00_oo7P02ool100?oo`0<1?oonfX4ool0[0?ooo]Z00Co9?l0o`2M
ool0WOoo09go1?l0;Ol3oomD00CoohH01OlVo`04ool0f`Cooo]Z1?l0000GoookJP?oo`3K1OlVo`04
oon600?ooe@01?l0;Ol2o`2Mo`03obCo0?oonf[ooo]Z00?ooo]Z0_oo0:`5oookJP;oo`0<00Coo`40
oh_o0?oo7P3ooah00_ook0001?lX0?oooo]Zooo^0?ookP05oookJP;oo`0n00Cof_l0oookJ_l0T_oo
09;o0_l0oeT00ooonf[oo`3=ool0c@02o`0go`03ooo50?oo07?oo`1c00;ooo]Z00Gooe<0oo<0oooc
0?ooo`3Gool0l002o`3oh006oookJ_l0oe?oo`0KoookJ_l0oi7oT?l00_oo0;P01?ooJ03ohol0on?o
0?ooD@02o`1Go`;oE@3o0_oo7P02oookJP;oob@000?ooo]Zo`3o6?oonfX00_oo09000ooio`3oeOl0
ool0D@02oooS0005oomd0?oonf[o04;oo`12oooo04400_oonfX01?l0onooo`26oeGo0?mEo`02oook
JP?oon801ooonfX00ooo08Goo`3bool0lP02oookJP;oK`3o0_oo^P02o`3oH003oookJ_oo06Ooo`1W
00?ooo]Z0_oo0:lBoookJP03o`3o2Ooonf[ooo]Z03Gooo]Z001;oookJP;o0?l94_oonfX00ooo0:oo
oo]ZoookJP02oookJP;oo`1W00?ooo]Zo`3oH?l0of000_oo^P02ofl0o`;ooo]Z0_oo0?800ooo08Go
oo]ZoookJP05oookJP?oon8000Cooo]ZoeGo0?mEo`3oEOl00_l0onl2oookJP;o04;o0_oonfX00ooo
M03oon<0ool00002ool00003ooWo0?m4o`3oogT000?oogT00_oo90000ooonf[ooah0oolN0002oeD0
o`04onGo0?l0oego0?mMo`1Oo`?o0?mM0_oo0;P2o`3o[@Oo05oo0_oc0?l00ooUo`3ooe<0oookJP02
ool0L`06ooo50?l0=ooo03Ooo`0goooo0<goU?l00_l0oeT2o`2Bo`;o05oo00?oo`00ool0?_l0ojd0
1?oonfX2ooo^0003oookJ_l0oegoon`000?o0?mM00Goo`40ool03?oo00coo`0<o`1Oo`03oookJP?o
o`2/00Cooo]Zo`3o3?l0o`co0?l<1_oUo`05o`3oG@;o05oo1?l0ooh2obKo00?oo`3K0_l007l6oook
JP03o`000?oo003oolT000?oolT01?l0o``=o`2`o`;ooo]Z0_oo:003oookJP?oo`3K1?lVo`02ool0
0004oon60?oo003oo`00ool000Co02go0ooo0002oolX00?oU?l00_oo0:`4oookJP?oo`0<00?oo`40
oiCo0?nDo`000_ook002oiCo0003oookJ_ookP3oonh000Gooo]Z00?oo`0nom[o0?oonfX00_l0T_l0
1Ol0obGo0?mIoomi0?ooN@3oA?l000;o03Oo00?oolD0ool0Looo07<00_oonfX01Ol03ooo0?l<oo<0
oooc0?ooo`3`00;o0?oP00Co0?l<o`3oDol0oe?oogT00_oUo`02ool0^004onGo0?oSo`3ooe40oomA
00;o05Oo0_mE0?l01?oo7P3o00ooo`0?oooonfX2oolT0003oookJ_l0oaSo0?lH00;oo`2@00?onOl0
o`3oo_oo05400_ooh`000oooM03ooo]ZoookJP02o`12o`04o`2`ool0onoo0?o_o`2`o`;oEOl00_oo
nfX00ooohP3oobP0oookJP03oookJPGo0?mM00Co05ooo`3oGOl0oego0?mM0_m4o`001_ooN@3o0?on
oolX0?nDo`3oA?l0o`3ooP?oA?l00_oonfX00ooo0:oooo]ZoookJP0@oookJP03o`3oGOoonf[ooo]Z
07cooo]Z0_l0o`TBoookJP;oo`2_0ooonfX2ool0I`;ooo]Z00?o0?mPoonj0?oo^P000_m_0?l3oook
JP;oo`3b2?oonfX2oooR00;ooo]Z0_mEo`001?oo08Ko0?o_o`3okooonfX3o`12o`;ooo]Z0_ooh`00
0ooo057oeOl0ooWo0002ool0T0;o0?lH00?ooo]ZoolT0?oo90000_oonfX2oolN00;oE@3o0_l0Eol0
1?ooD@3ohol0on?o0?ooS002ool0^003o`3oTOoo00?ooo]Z00;o0?mC00?ooo]Zo`3oh?l0on000_oo
0?000ooc0?oooe<0oomC0002oookJP;oo`1c0ol0=ol01Ooo0<gooo]Zol00ool0oeWo0?lU00;o09;o
00Cof_l0ool0?_oo03koo`0n1?oonfX2ooo^0004oookJ_lX0?ooon`0ooo/00;ooah00_oo0@02ool0
30Cooo]Z1?oo0:`3oookJP;o9?l00_l0WOl4o`0]o`?ooe@00oooQP000ooonf[o9_l0obKo0002obKo
00?oo`3K0_l007l6oookJP;o00004?oa0?l<oookJP?oo`3K1?lVo`001?oonf[oohH0oon60?ooQP03
oomD00?o02go0_l0WOl2obCo00Cooo]Z0_oo0:`4oookJP?oo`0<00Soo`40oh_o0?oo7P3ooah0ooo/
0?l0obco:03ooookJP;oonh01OoonfX2ool0?P04oookJ_l0T_oo09;oo`3o9@;o0?mI00?ooo]Zool0
cOoo0<d00_l0=ol01?ooa@3oo`1coookJ_oonfX2oomC00;ol`3o00Coo`3`o`3oh?l0on3ooo]Z0_l0
oe<00ooo01_ooo]Zo`3oT@02ool0^003oon<0?oSo`3ohol000;ooe4000Go05Ooo`3o=_mE0?ooE@3o
oolN0003oookJP07oolT0?oonf[o0?lHo`3o6?oonf[oo`2@ooWo0002omGo0003ool0DOooh`3oog@0
00;ooo]Z0_l0@_l01_oo047ooo]Zo`3okooo08Ko0;KooeGo00;ooo]Z0ooohP07oookJP03ool0QOoo
0?;oo`3b00;ooo]Z0_m_0?l2oonj00;o0?mP0_oonfX00ooo06Oooo]ZoookJP02oookJP03ool0[ooo
nf[ooo]Z013ooo]Z0_l0o`TfoookJP00BooonfX00ol0o`Wooo]ZoookJP0@oookJP;oo`2_0ooonfX2
ool0I`03oookJ_l0of3o0?mP00;ookX00_m_0?l2oookJP;oo`3b0_oo08D6oookJP?oon800_oonfX2
oeGo00;o0?o_0_oonfX01Ooo047o04;ooookJ_oonf[o05oo00;oon<00_oo00001?oio`3oA?l0oomi
0?oo0002oomi00;oob@00_oonfX2oolN0005oeD0oooUo`3oiOl0onGo0?l0Gol01?l0oed00ooo0;So
0?n]o`3o[@07o`1Oo`;ol`3o00?ooo]ZoomC0?oonfX00_oo07<2ooo500;o03Oo00Goo`3=oiCo0?l0
oeWo0?mIo`2Bo`03o`1Oo`;oo`0n00?o0?n]oookJ_oonfX00_oonfX2ooo^00;oiOl000Goon`0o`3o
GOl0oego0?mMool10003ool03004o`1Ooooonf[ooo]ZoookJP?oo`2/1Ol0o``00ol0WOooiOl0onGo
0003onGo00Go0?mM00?o05ooo`3oo_l0ooh00_l0ooh3ool0f`Oooo]Z1_oa0?l4ooo900?o0?l<0_oo
:002o`2`o`;oU?l00_l0/?l2o`3o[@Ko0;3o0ooo:004oookJP03ool0fooo003oo`0000Co9_l01_oo
00000ol0;Oooo`00ool00003ool000GoU?l00_oo0:`4oookJP?oo`0<0onDo`02ooo/00;oU?l000?o
0?n]ooo^0?ookP001?oonfX2ool0?P04om[o0?oonf[o09;oo`2Bo`;o0?mI0om4o`02o`0go`08ooo5
0?oo07?oobP0oookJ_ooD`3o00ooool0eooc0?l2ool0l004o`3oh?l0/?oo0?mCo`3oD`;oogT00_oU
o`02ool0^006o`3oGOoSo`3ooe40oomA0?l0Eooo0?lf0_mE0?l00ooo7P3o00oooookJP03oolT00;o
0?lH00Gooo]Zool0T?oio`3onOl0oookJP03oooS00;ooo]Z0_l0@_l2o`2`o`03o`3okol0/?oo0;Ko
00;oEOl00_oonfX00ooo:03ooo]ZoookJP03oookJPCo0?mM00[o05ooo`3oGOl0oego0?mMo`3oo_m4
o`3oogT0odCo0?oo:03oU?l00_m4o`000ol0ookoA?l0odCo0002oookJP03ool0[ooUo`3ooo]Z013o
oo]Z00?oiOl0o`3oGOoonfX0O?oonfX00ol0o`Wooo]ZoookJP0@oookJP?oo`2_0ooonfX00ooo06Oo
oo]ZoookJP02o`3oH0;ookX00_m_0?l2oookJP;oo`3b00?oo`25oookJ_oonfX01OoonfX2oooR00?o
oo]Z00KoEOl0o`2fool0onoo0?o_oookJ_oo0442o`12o`;ooo]Z0_ooh`001_oo057oeOl0ooWo0?oi
o`3oo`2@oookJP;o0?lH00Cooo]ZoolT0?oonf[ooo]Z0_oo7P001?oonf[oE@3oo`3o=_l0Eol2oomA
0007on?o0?ooJ03oo`2hool0^?n@o`3o0?nAoookJP02o`3oD`;ooo]Z00?o0?oPool0l?oo0?000_oc
0?l00oooD`3ooo]ZoookJP02ool0L`08ooo50?l0=ooo03Ooool0cOoonf[o`03oo`3oFOl0obD2o`2B
o`04om[o0?oo03koo`0nool0?PCooo]Z0_ookP001_oonf[o:03oooo/0?ook03ooah0oh_o00;oo`40
0_oo00`4oookJP?oo`2/1?oonfX01?lTo`3o09goo`2Moooo>002o`0]o`?ooe@01?ooQP04obKo00?o
o`3K1ooonfX<oo40o`Cooo]Z3?oa0?l9oookJP?oo`3K0olVo`03oon600Cooe@00_l0;Ol01?oo>03o
09goo`2MoolTo`04oookJP;oo`2/1?oonfX3ool03006ool10?n;o`3ooah0oolN0?ook03o0?l/0_oo
nfX2ooo^00Gooo]Z00?oo`0nom[o0?oonfX00_l0T_l01Oo00?oo0?mIoookJ_oonf[oo`3=00?o03Oo
0_oo07<2oookJP;ooe<000?ol`3oool0eooo0?000_l0on001?oonf[o0?mCool06ooonfX2o`3oT@;o
o`2h00?oofP0on?o0?ooD@000_ooD@000ol0EoooE@3ooeD0o`02oolN00;ooo]Z0_oo90000ooonf[o
0?lHoookJP02ool0T003ooWo0?oEo`3oo`1A00;oon<00_oonfX2o`12o`05ool0@Ooonf[o0?o_o`3o
kol0]_l00_mEo`02oookJP;oon801ooonfX00ooo08Goo`3bool0lP02oookJP?oK`3o0_oo^P001?l0
of3ooo]ZoookJ_oo06L4oookJP;oo`2_4OoonfX2o`3o2CKooo]Z001:oookJP;o0?l94OoonfX2ool0
[`Cooo]Z0_oo06L00ooonf[o0?mPo`3oH002oonj00;oK`3o0_oonfX2ool0lP03ool0QOoonf[ooo]Z
00Gooo]Z0_oohP02oookJP;oEOl000?o0;Koo`3oo_l0onl00_oonfX01?l0@_oooo]ZoookJ_l0Gol2
oooS0005ool0DOoo003oo`00odCo0?ooN@000_oo00000ol0oegoogT0oolT0002oookJP;ooah000Go
E@3oonGo0?oUo`3oiOl0o`1Oo`02onGo00?o0?mM00?oT?l0o`3o[Ol0Gol01ol0Gol01?oc0?oooo]Z
oomC0?ooD`03ool0L`05ooo50?l0=ooo03Ooool0cOoo:0000_l0oeT01?o00?oo05ooo`1Oool0Gol2
ool0?P03o`1Ooooonf[ooo]Z00;ooo]Z0_ookP02onGo00;oon`000?oiOl0o`3oGOoo0@000_oo00`0
0ol0oegooo]ZoookJP02oookJP?oo`2/00Gooo]Zo`3o3?l0o`coiOl0o`2Mo`02oolh00GoiOl00ol0
oed6o`3ooP03ool0fooonf[ooo]Z00Cooo]Z00?ol@3oo`0?ool03ol00ol03ol01?oa0?oooo]Zo`00
0?oo0004ooo900?o0?l<1?oo:004oiCo00?o0?n]00?o0;3oo`0?ool03ol00ol0/?l00ooa0?ooobP0
oolX0002oiCo0003oookJ_oo003oo`0000Coo`000olVo`0;ool000GoU?l00_oo0:`4oookJP?oo`0<
0onDo`02ooo/00;o0?n]0oookP04oookJP;oo`0n00Cof_l0o`2Bool0T_ooA?l00_l0oeT2odCo0005
o`3oo_l0=oooolD0ool0Looo:0000_oonfX01OooD`3o0?l<oo<0oooo:03oo`3`00;o0?oP00?o0?l<
o`3oDol0oe<00_ooN@001OoUo`3oo`2hool0^?oUo`3ohol000;ooe4000Co05Ooo`3o=_mE0?ooE@3o
0_oo7P02oookJP;oob@000?ooo]Zo`3o6?oonfX00_oo09000ooio`3oeOl0ool0D@02oooS0006oomd
0?oonf[ooo]Zo`12ooooN@3o0;3o0_l0onl00ol0]_ooEOl0oeGo0002oookJP03oooR0?oo:03ooo]Z
00Cooo]Z0ol0oed02_l0Gooo0?mMo`3oGOl0oego0?onodCo0?ooN@3oA?l0oolX0?nDo`02odCo0003
o`3oo_m4o`3oA?l000;ooo]Z00?oo`2_onGo0?oonfX04?oonfX00ooUo`3o0?mMoookJP1koookJP;o
0?l94_oonfX2ool0[`?ooo]Z0_oo06L00ooonf[o0?mPo`3oH002oonj00;oK`3o0ooonfX2ool0lPSo
oo]Z00Coon80oookJ_oonf[ooo]Z0_mEo`03o`3ok`03oookJ_l0@_oo04;o00;ooo]Z0oooh`001Ooo
057oeOl0ooWo0?oo093ooo]Z00;o0?lH00?ooo]ZoolT0?oo90000_oonfX01Ooo7P3ooo]ZoeD0ool0
ocKo05Oo00;ooe400_oSo`02ool0^003oi3o0?l0oi7ooo]Z00?o0?mC00Cooo]Zo`3oh?oo0?3oo`3`
0_oc0?l2oomC0004oookJ_oo07?oo`1cooo500;o03Oo00Goo`3=oookJ_oonf[o0?mIol00o`02o`2B
o`04om[o0?oo03koo`0nool0?PCooo]Z0_ookP001_oonf[o:03oooo/0?ook03ooah0oh_o00;oo`40
0_oo00`4oookJP?oo`2/1?oonfX2o`2Mo`03oolh0?l0;Ooo02go00?ooe@00oooQP04obKo00?oo`3K
1_oonfX7oo40o`03oookJ_l0003o000000;o00004OoonfX6oo40o`Sooo]Z0ooo0=/3obKo00?oohH0
0oooE003o`0]o`03oookJ_l0WOoo9?l000Cooo]Z0_oo0:`4oookJP?oo`0<00?oo`40oh_o0?oo7P00
0_ook0000ol0obcooo]ZoookJP02ooo^00Gooo]Z00?oo`0nom[o0?oonfX00_l0T_l01Oo00?oo0?mI
oookJ_oonf[oo`3=00;o03Oo00CoolD0ool0Looonf[ooo]Z0_ooD`02oo<0o`06ool0l?l0on3o0?oP
o`3oh?oonf[o0?mC0_oonfX01?l0oi7oT?l0ool0^?ooS002on?o00;ooe4000Go05OooookJ_mE0?oo
oo]ZoolN0002oookJP;oob@000Oooo]Zo`3o6?oonf[ooo]Zool0T?oio`3oeOl000;oo`1A00Goon<0
oomd0?oonf[ooo]Zo`12o`02ool0@@;o0?o_00?o0;KooeGo0?mEo`000_oonfX3oooR00Oooo]Z00?o
o`25ool0l_oo0?800_oonfX2ofl0o`;ookX00_l0of000ooonf[oo`1WoookJP03oookJP;oo`2_4Ooo
nfX2o`3o2CKooo]Z001:oookJP;o0?l94OoonfX2ool0[`?ooo]Z0ooo06L01_oonf[o0?mPo`2goooo
^P3ooo]Zofl0o`;ooo]Z0_oo0?82ool0Q@Kooo]Z0ooohP02oookJP;oEOl000Co0?o_o`3oo_oonf[o
oo]Z0_l0@_l3oookJP07oooS0?oo057oo`1Ao`1Ooom4o`3oogT0ool0T002ool000?oob@000Cooo]Z
oolN0?oo7P3oE@3o0ooUo`002?l0GoooiOl0onGo0?oUo`3ooh`0o`3oGOoo0;So0?n]2?l0Gol01?oc
0?oooo]ZoomC0?ooD`03ool0L`05ooo50?l0=ooo03Ooool0cOoo:0000_l0oeT01?o00?oo05ooo`1O
ool0Gol2ool0?P03o`1Ooooonf[ooo]Z00;ooo]Z0_ookP02onGo00;oon`00_oUo`001?oo0@3oo`0<
ool03?l0oed4oookJP;oo`2/00Cooo]Zooo90?oob@3oiOl00_l0WOl01?oo>03o02goo`0]oom4o`04
onGo0003o`3oo_l0oego0?on00Go0?on1OoonfX4o`3o[@co00oo00CoolT0o`3o3?l0o`co0?l<1?oo
:004oiCo00Co0?n]0ol03ol2oolX00Gol@3o00?oU?l0ool00?oo00001_oo0002obKo00[oo`0000Co
09gooiCo0?nDo`3oU?l00_l0ojd00ooo0:cooo]ZoookJP03oookJP;oo`0<00Coo`40oiCo0?nDo`3o
0?n]0_ook002o`3o[@;oonh01OoonfX2ool0?P04oookJ_l0T_oo09;ool00o`;o0?mI00WoA?l0o`3o
o_l0=ooo03Ooooo50?oo07?oobP0oookJ_ooD`000ooo:002ool0l007o`3oh?l0o`co0?mCo`3oDol0
/?ooogT0o`3oT@03ool0^003o`3oGOoSo`3ooe4000;o0?mM00Co0?lfoeD0oomE0?oooah00_oonfX2
oolT0003oookJ_l0oaSo0?lH00;oo`2@00?onOl0omGo0?oo05400_ooh`000oooM03ooo]ZoookJP02
o`12o`04oookJ_l0onoo0?o_o`2`o`;oEOl00_oonfX00ooohP3oobP0oookJP04oookJP?o0?mM00Co
05ooo`3oGOl0oego0?mM0_l0ooh3odCo0004oolX0?nDo`3oA?l0o`3ooP;oA?l00_oonfX00ooo0:oo
iOl0oookJP0AoookJP03o`3oGOoonf[ooo]Z07[ooo]Z0_l0o`TAoookJP?oo`2_0ooonfX2ool0I`03
oookJ_l0of3o0?mP00;ookX000CoK`3ooookJ_oonf[ooo]Z0_oo0?800ooo08Gooo]ZoookJP05oook
JP;oon800ooonfX01OmEo`3o0;Koo`3okol0onoooo]Z00?o04;o0_oonfX2oooS0003ool0DOoEo`3o
nOl000;oo`2@0_l0oaP00ooonf[oob@0oolT0002oookJP;ooah00_mE0?l00ol0ocKooe40oomA0002
on?o0004oon<0?oo0;Soo`2ho`3oT@;ooo]Z0_l0oe<01?oonf[o0?oPo`3oh?oo0?02oo<0o`;ooe<0
00Cooo]Zool0Looo07?oolD00_l0=ol01Ooo0<gooo]ZoookJ_l0oeWo`03o00;o09;o00Cooo]Zom[o
0?oo03koo`0n1?oonfX3ooo^0009obP0ooook03oon`0oolN0?n;o`3oo`40o`14oooo00co04Co00Co
oo]Z0_oo0:`4oookJP?o09go0_l0;Ol01?oo>03ooe@0oomD0?ooE003oon600?o9_l00_oo0=/6oook
JPKol@3o1?oonfXGo`18o`Gooo]Z1?oa0?l6oookJP?oo`3K0olVo`02oon60004o`07ooooE03ooe@0
oomD00;o02go00?oocP0o`2Mool0WOl01?oonfX2ool0[0Cooo]Z0_oo00`2ool10006oh_o0?oo7P3o
on`0ooo/0?l0obcooo]Z0_ookP05oookJP;oo`0n00Cooo]Zo`2Bool0T_oo0?lU0_l0oeT00ooonf[o
o`3=o`0go`02o`0go`;oo`1c0_oonfX2oomC0003oo<0ooooX@3oo`3`00;o0?oP00Kooo]Zo`3oDooo
01_ooo]Zool00ol0oi42ool0^004oomX0?oSo`3ooe40oomA00;o05Oo0_mE0?l01?oo7P3ooo]Zoook
J_oonfX2oolT0005oookJ_l0oaSooo]Zool0T?oio`000_oEo`000ooo057oon<0oomd0002oookJP;o
04;o00Koo`11oookJ_l0onooo`26o`2foomEo`02oookJP?oon801ooonfX00ooo08Goo`3bool0lP02
oookJP;oK`3o0_oo^P02o`3oH003oookJ_oo06Ooo`1W00?ooo]Z0_oo0:lBoookJP03o`3o2Ooonf[o
oo]Z03Cooo]Z0019oookJP;o0?l94OoonfX2ool0[`?ooo]Z0ooo06L00ooonf[o0?mPo`3oH002oonj
00;oK`3o0_oonfX2ool0lP03ool0QOoonf[ooo]Z00Gooo]Z0_oohP02oookJP;oEOl000Ko0;Koo`3o
o_l0ookooo]Zool0@Ol0@_l3oookJP;oon<000Soo`1Ao`1Ooooio`3oo`2@oomi0?l0Goooo`00o`3o
G@;oob@000Co0?mMoookJ_oo7P3ooah01?oUo`001?l0oegoiOl0onGo0?ooS002ool0^003o`3o[Ol0
Gooo05oo00Ko05oo0_oc0?l2oomC0004oookJ_oo07?oo`1cooo500;o03Oo00?oo`3=oolX0?oo:000
0_l0oeT3o`1Oo`;oo`0n0_l0Gol3oookJP;oonh000Co0;3oonGo0?ook03oon`00_oUo`001?oo0@3o
o`0<ool03?l0oed3oookJP?oo`2/1?oob@02o`2Mo`?o02go0_m4o`03onGo00So0?on1?oonfX2oo40
o`Co0?n]4?l03ol:ool0b003o`3o[Ol03ooo00oo00?o00oo0ooo:0000onDo`3ol@3ooo40o`0;ool0
0003obKo0?oo003oo`0000Soo`0000?o09gooiCo0?l0ojd00ol0ojd00ooo0:cooo]ZoookJP03oook
JP;oo`0<00?oo`40o`3o[Ol0ojd00_ook003o`3o[@;oonh01?oonfX3ool0?P03oookJ_l0T_oo09;o
00;o0?mI0_m4o`001?l0ooko03Ooooo50?ooa@05oolX0006oo<0oooo:03oo`3`ool0l?l0on3o0;3o
0_l0oe<2oomi0005onGo0?oo0;Soo`2ho`3oGOoSo`000_ooD@001?l0oego0?lfoeD0oomE0?l2oolN
00;ooo]Z0_oo90000ooonf[o0?lHoookJP02ool0T003ooWo0?oEo`3oon<000;oon<00_oonfX2o`12
o`07oookJ_l0/?oo0?o_o`3okoooN@3oolT0oeGo0002oookJP03oolX0?oonf[ooo]Z00Cooo]Z0ol0
oed00ol0Gooo0?mMo`3oG@02o`3o[@07o`3oo_m4o`3ookX0oolX0?nDo`3oA?l0o`3ooP02odCo00;o
oo]Z00?oo`2_onGo0?oonfX04OoonfX00ol0oegooo]ZoookJP1ioookJP;o0?l94_oonfX2ool0[`?o
oo]Z0_oo06L00ooonf[o0?mPo`3oH002oonj00;oK`3o0_oonfX00oooi03oo`3bool0Q@08oookJP04
oooR0?oonf[ooo]ZoookJP;oEOl00_l0onl2oookJP;o04;o0_oonfX3oooS0005omGo0?l0n?oonOl0
ool0T?oonfX00_l0oaP01?oonf[oob@0oookJ_oonfX2oolN0004oookJ_mE0?oo0?lfo`1Go`;ooe40
00Oohol0oomX0?oo0;Soo`2hoi3o0?l0oi7ooo]Z00;o0?mC00?ooo]Zo`3oh?l0on000_oo0?000ooc
0?oooe<0oomC0002oookJP05ool0Loooa@3oolD0o`0goooo0<d00_oonfX2o`3oF@;o09;o00Cooo]Z
om[o0?oo03koo`0n1?oonfX3ooo^0003oookJ_ook03oon`000;ooah000Coo`40o`14oooo00co04Co
1?oonfX2ool0[0Cooo]Z0_l0WOl3o`0]o`?ooe@00oooQP03obKo00;oo`3K1_oonfX4oo40o`Cooo]Z
1?l0B?lDool0b0Oo04So1?oonfX3oo40o`Kooo]Z0ooo0=/3obKo00;oohH000?o00OooomD0?ooE000
0ol0;Ol2o`2Mo`Cooo]Z0_oo0:`4oookJP;oo`0<0_oo0@001_n;o`3ooah0ooo/0?l0obco:03ooook
JP;oonh01OoonfX2ool0?P05oookJ_l0T_oo09;ool00ool0oeT00_oonfX01?oo0<go03Ooo`0goooo
a@02ool0L`03oookJ_ooD`3ooe<000;ol`3o0_oo0?02o`3oh0;o0?mC0_oonfX01?l0oi7oo`2hool0
^?ooJ002on?o00;ooe4000?o05OooookJ_mE0?l00_oo7P02oookJP;oob@000?ooo]Zo`3o6?oonfX0
0_oo09000ooio`3oeOl0ool0D@02oooS00;ooo]Z0_l0@_l01Ooo047ooo]Zo`3okol0onoo0;Ko00;o
EOl00_oonfX2oooR00Oooo]Z00?oo`25ool0l_oo0?800_oonfX2ofl0o`04oookJ_oo^P3o0?mPo`3o
H0;ooo]Z00?oo`1WoookJ_oonfX00_oonfX00ooo0:oooo]ZoookJP0@oookJP;o0?l9=OoonfX004Wo
oo]Z0_l0o`TAoookJP;oo`2_0ooonfX3ool0I`06oookJ_l0of3ookX0oonj0?oonf[oK`3o0ooonfX0
0ooo0?;oo`25ool0Q@07oookJP;oon800_oonfX2oeGo00;o0?on0_oonfX2o`12o`;ooo]Z00[oog@0
oooS0?oo057o0?mMooWo0?oo093oogT0onGo0?l0GoooiOl00_oo90001?l0oegooo]ZoolN0?oo7P04
onGo0004o`3oGOoUo`3oiOl0onGo00;oo`2h00CoU?l0o`3o[Ol0ojgo0?mC1_l0Gol01?oc0?oooe<0
oomC0?oonfX2ool0L`04ooo50?l0=ooo03Ooool0c@;oobP00_l0oeT3o`1Oo`;oo`0n0_l0Gol3oook
JP;oonh00_l0/?l2ooo/00;oiOl000Coo`40ool03?oo00coiOl00ooonfX2ool0[0;ooo]Z0ooob@00
0ol0WOooocP0o`0]o`02o`0]o`CoA?l000?oiOl0o`3oo_l0ooh01Ol0ooh3oookJP03oo40oonDo`3o
U?l000;oU?l01?l0ojd>o`0?o`03oolF0?oo:03oobP000;oobP00onDo`0:ool0b0;o00oo1OnDo`02
oo40o`[oo`0000?o9_l0ool00?oo00001ooo00000ol0WOoo0?n]o`3o[@02o`3o[@03oookJ_oo0:co
oo]Z00Cooo]Z0_oo00`00ooo0@3o0?n]o`3o[@02ooo/00;o0?n]00?ooo]Zooo^0?oonfX01?oonfX2
ool0?P04om[o0?l0T_oo09;ool00o`;o0?mI00?oA?l0o`3oo_l0=ol01ooo:0001Ooo0=OoobP0ool0
l?oo0?3o0?oP00;o0;3o00Co0?mCoomi0?ooN@3o0?mM0ooo0;P01_l0Gooohol0oomA0?l0oego05Oo
oookJP;oE@3o00?ooah0oookJ_oonfX00_oo90000ooonf[o0?lHoookJP02ool0T003ooWo0?oEo`3o
o`1A00;oon<00ooonfX00ooo003o04;ooookJP02o`3ok`03o`2foooob@3oEOl000;ooo]Z00?oobP0
oookJ_oonfX01?oonfX3o`3oG@03o`1Oool0oego0?mM00;o0?n]00Go0?onoomi0?m4o`3oobP0oiCo
0003oolX0005odCo0?oonf[ooo]ZoookJ_oUo`004_oonfX00ol0oegooo]ZonGo0002onGo07Oooo]Z
0_l0o`TBoookJP;oo`2_0_oonfX3ool0I`03oookJ_l0of3o0?mP00;ookX000CoK`3ooookJ_oonf[o
oo]Z0_oo0?800ooo08Gooo]ZoookJP05oookJP;oon800_oonfX2oeGo0004o`2fool0onoo0?o_oook
JP?o04;o0_oonfX2oooS0003ool0DOl0n?oonOl000;oo`2@0_l0oaP00ooonf[oob@0oolT0002oook
JP05oolN0?oonf[oE@3ooeD0ool0Eol00_ooD@02on?o0005oon<0?oo0;SoT?l0o`3oTOoonfX00_l0
oe<00ooonf[o0?oPo`3oh002ool0l003oo<0ooooD`3ooe<000;ooo]Z0_oo07<01Oooa@3o03Ooo`0g
oooo0<gooo]Z00;o0?mI0_l0T_l01?oonf[of_l0ool0?_oo03h4oookJP?oonh000?ooo]Zooo/0?oo
k0000_oo7P001?oo0@3o04Coool03?l0A?l4oookJP03ool0[?oonf[ooo]Z00?ooo]Z00?o09gooolh
0?l0;Ol00_l0;Ol2oomD00?oohH000?ooo]ZobKo0?lVo`000_oo0=/5oookJPCol@3o0ooonfX4o`18
o`Soo`383?oo5P0:ool0b0Go04So0ooonfX3oo40o`Gooo]Z0_oo0=/00ooonf[o9_l0obKo0003oon6
00;ooe@00ol0;Ol2o`2Mo`Cooo]Z0_oo0:`4oookJP;oo`0<00Koo`40oh_o0?n;o`3ooah0ooo/0?l0
ob`2oookJP;oonh01OoonfX02?oo03kof_l0oookJ_l0T_oo0?lUol00ool0oeWooo]Z0_oo0<d2o`0g
o`04oookJ_oo07?ooo]ZoookJP;ooe<000?ol`3oool0eooo0?000_l0on001?oonf[o0?mCool06ooo
nfX2o`3oT@;oo`2h00CoofP0on?o0?ooD@3ooe400_l0Eol2oeD0o`07oolN0?oonf[ooo]ZoookJ_oo
903ooo]Zo`3o6002oookJP07ool0T?oio`3oeOl0omGo0?oo057oon<0oomd0002oookJP;o04;o00Co
oo]Zo`3okol0onoo0;Ko0_mEo`02oookJP;oon802?oonfX2ool0lP;ooo]Z0om_0?l01_oo^P3o0?mP
o`3oH?l0of3ooo]Zool0I`Cooo]Z00?oo`2_oookJ_oonfX04?oonfX2o`3o2CGooo]Z0018oookJP;o
0?l94_oonfX2ool0[`;ooo]Z0ooo06L00ooonf[o0?mPo`3oH002oonj00;oK`3o0_oonfX2ool0lP03
ool0QOoonf[ooo]Z00Gooo]Z0_oohP02oookJP;oEOl00ol0ooh00ooonf[oo`11o`12o`03oookJP;o
on<000Soo`1Ao`1Ooooio`3oogT0ool0T?l0Gooo0?mMonGo00;oob@000?o0?mMoolN0?oo7P001?oU
o`000ol0oegoiOl0onGo0002onGo00;oo`2h00?oU?l0o`3o[Ol0oe<00_l0oed4o`1Oo`04oo<0oooo
D`3ooe<0oookJP;oo`1c00?oolD0o`0gool0=ol00_oo0<d00ooo:03o0?mIo`3oF@03o`1Oo`;oo`0n
0_l0Gol3oookJP;oonh00_l0/?l2ooo/0003oolN0?oUo`3oo`4000;oo`0<00CoiOl0oookJ_oonf[o
oo]Z0_oo0:`01?oonf[o05ooo`1Oool0Gol2o`2Mo`03oolh0?l0;Ooo02go00;oogT01_m4o`05o`3o
oP03oookJ_oo:03oobP000;oobP01?nDo`05o`3o[@[o00oo0ooo5P000ol0ob_oobP0oolX0002oolX
00CoU?l00ol0ojd2o`0?o`Ooo`380onDo`03o`3o[@Col@3o1ooo0002obKo0003oookJ_oo003oo`00
00Goo`0000?o09goo`3o[Ol0ojd00_l0ojd00ol03oooo`2/oookJP04oookJP;oo`0<00?oo`40o`3o
[Ol0ojd00_ook0001?l0ojgo00ooooo^0?ookP04oookJP04ool0?_oJo`3oo`0noookJP;o09;o0_l0
oeT2o`3ooPGoobP000OoU?l0oolX0?oo:03ooo]ZoolX0?oc0?ooo`3`00;oobP000Go0;3oo`3oDol0
oe?oA?l0o`3oG@03ool0^006o`1OoooUo`3ooe40oomA0?l0Eooo0?lf0_mE0?l2oolN0003oookJ_oo
903oob@000;ooo]Z00Ko0?lHool0T?oo093onOl0o`3hoooo0542oooS0006oomd0?oonf[ooo]Zool0
0?l0@_oooo]Z0_l0onl00ol0/?ooolT0oeGo0002oookJP03oolX0?oohP3ooo]Z00Cooo]Z00Co0?n]
o`3oGOl0oego05oo0_l0oed2o`3o[@CoobP000CoU?l0oolX0?oo:03oobP01?l0ooh00ooo0:ooiOl0
oookJP0>oookJP;oiOl000?o0?mMonGo0?oUo`000_oUo`1foookJP;o0?l94_oonfX2ool0[`?ooo]Z
0_oo06L00ooonf[o0?mPo`3oH002oonj00;oK`3o0_oonfX00oooi03oo`3bool0Q@08oookJP06oooR
0?oonf[ooo]ZoookJ_mEo`3o0;Ko0_l0onl01?oonf[oo`11o`12ool0@_l2oookJP?oon<000CoeOl0
o`3hoooo093oo`2@0ol0oaP01?oonf[oob@0oookJ_oonfX2oolN00;oE@3o00?o0?lfo`1GooooD@00
0_oSo`002?ooS03oo`2hool0^?l0oi7ooo]Zool06ol0oe?ooo]Z0ol0on001?oo0?3ol`3ooo<0oooo
D`02oookJP;oo`1c00GoolD0o`0gool0=oooo`3=oookJP02o`3oF@04ol00ool0T_oooo]Zom[o00;o
o`0n1?oonfX3ooo^0003oookJ_l0obcoon`000;ooah000Coo`40o`14oooo00co04Co1?oonfX00ooo
0:cooo]ZoookJP02oookJP03obCo0?l0WOooocP000;o02go0oooE003oon600;o9_l00ooo0=/4oook
JP?ol@3o0ooonfX3o`18o`Goo`3800?ooo]ZoolF0?oo5P002Ooo5P001?l0ob_ooo]ZoookJ_oonfX9
oolF00Ooo`381?l0B?l3oookJP?ol@3o1OoonfX2ool0f`;o9_l000?ooo]Zoon60?ooQP000_ooE003
o`0]o`;o09go1?oonfX2ool0[0Cooo]Z0_oo00`01ooo0@3oRol0oolN0?oo7P3oon`0obP0oooonfX0
0_ookP05oookJP;oo`0n00Gooo]Zo`2Bool0T_oo0?lUo`3oF@02oookJP04ool0cOl0=ooo03Ooooo5
00;oo`1c00?ooo]ZoomC0?ooD`000_oc0?l2ool0l007o`3oh?oonf[o0?mCo`3oDooonf[oo`03o`3o
T@02ool0^003oomX0?oSo`3ohol000;ooe4000?o05OooookJ_mE0?l00_oo7P02oookJP;oob@000[o
oo]Zo`3o6?oonf[oo`2@ooWo0?l0n?ooeOl0ool0DOooh`3oog@00_oonfX2o`12o`06ool0@Ol0onoo
0?o_ool0Q_l0]_ooEOl00_oonfX2oooR00Sooo]Z00?oo`25ool0l_oonfX00_oonfX2ofl0o`;ookX0
0_l0of000ooonf[oo`1Wool0I`03oookJP;oo`2_4OoonfX2o`3o2CGooo]Z0018oookJP;o0?l94Ooo
nfX2ool0[`?ooo]Z0ooo06L2o`3oH0;ookX000?ooo]Zofl0oom_0?l00_oonfX00ooo0?;oo`25ool0
Q@07oookJP;oon800_oonfX00omEo`3o0?ono`3ooP02o`3ooP03oookJ_l0@_oo04;o00;ooo]Z00[o
og@0oooS0?oo057o05ooooWo0?oo093oogT0onGo0?l0oegoiOl00_oo9002oookJP;ooah00_mE0?l0
0ooUo`3o0?mMonGo0003onGo00;oo`2h0onDo`03o`3oG@03o`1Oool0oego05oo00;ol`3o0_ooD`00
1?oonf[oo`1cooo50?ooa@02o`0go`04ool0cOoonf[o0?mIo`3oF@?o05oo0ooo03h2o`1Oo`;ooo]Z
00Co0;3oooo^0?l0/?oo0;3o0_ook0000ooo7P3o05ooool10002ool03004onGo0?oonf[ooo]Zoook
JP;oo`2/1?l0Gol2o`2Mo`?o02go0oooN@06odCo00Co0?on00?ooo]Zoo40oooo:0000ooo:005oiCo
00Co0?n]1ol03ol2ool00003o`000?oUo`3oiOl000;oiOl00ooo:005oiCo00?o0?n]1ol03ol4ool0
b003oiCo0?l0ojgo0?n]00;o0?n]00Co00oooo40oooa0?ool@3o0_oonfX5ool000;o9_l000?ooo]Z
oon60?oo00001?oo00001?oo>03o09goo`3o[Ol0ojd2o`0?o`;oo`2/1?oonfX01?l0A?ooo`0<o`14
oooo0@02o`3o[@;oon`00_l03ol2ooo^00Cooo]Z0_oo03h01?oJo`3ooo]Zo`2Booo00?l2o`3oF@03
o`3oo_oo:03oobP000?oobP000GoU?l0oolX0?oo:03oobP0oo<0o`04oolX0003o`2`oooo01_o0?mC
00;oA?l000Go0?mMool0^?oo0;So0?mMonGo0002oomA0004o`1Gool0ocKoE@3ooeD0o`;ooah00_oo
nfX01Ooo903ooo]ZoookJ_l0oaSooo]Z00;oo`2@00Go0?SoomGo0?ooh`3oon<0oomd0002oookJP08
ool00?l0@_oooo]ZoookJ_l0onoo0;3ooomi0?oob@02oookJP03oooR0?oo:03ooo]Z00Cooo]Z0_l0
ojd00ol0oego05ooo`3oG@03o`1Oo`CoobP000CoU?l0oolX0?oo:03oobP01?l0ooh00ooo0:ooiOl0
oookJP0<oookJPCoiOl000?o0?mMonGo0?oUo`000_oUo`1foookJP;o0?l94_oonfX2ool0[`;ooo]Z
0ooo06L3o`3oH0;ookX00_m_0?l2oookJP;oo`3b00?oo`25oookJ_oonfX01_oonfX00ooohP3ooo]Z
oookJP02oeGo0004o`2fool0onoo0?o_oookJP?o04;o0_oonfX2oooS0003ool0DOl0n?oonOl000;o
o`2@0_l0oaP01?oonf[oob@0oookJ_oonfX2oolN00;oE@3o00?o0?lfo`1GooooD@000_oSo`02oon<
0004ool0^?n@o`3oo`03ool06`;o0?mC00Cooo]Zo`3oh?l0on3oo`3`0_oc0?l2oomC0003oookJ_oo
07?oo`1c00;oolD000?o03Ooool0cOoonfX00_l0oeT01?o00?oo09;oo`2BoooJo`02ool0?PGooo]Z
0_ookP000ooonf[o0?l/ooo/0002oolN0004ool10?l0A?ooo`0<o`14o`Cooo]Z00?oo`2/oookJ_oo
nfX00_oonfX2o`2Mo`?o02go0_ooE003oon600;o9_l00ooo0=/4oookJP?ol@3o0ooonfX2o`18o`Go
o`381_oo5P000ol0ob_o0000o`000002o`00013ooo]Z00?o0?l[oolF0?oo5P000ooo5P05ool0b0Co
04So0_oonfX3oo40o`Gooo]Z00Coo`3KobKo0?lVo`3o9_l00_ooQP02oomD00?o02go0_l0WOl3oook
JP?oo`2/1?oonfX01Ooo00co04Coool10?n;o`3ooah000;oon`000Co:03ooookJ_ookP3oonh01Ooo
nfX00ooo03kof_l0oookJP02o`2Bo`03ol00ool0oeWooo]Z00;oo`3=0_l0=ol2ool0L`;ooo]Z0_oo
D`000ooc0?ooo`3`ool0l002o`3oh008oookJ_l0oe?oo`0KoookJ_l0oi7oT?l0ool0^?ooS002on?o
00;ooe4000Go05OooookJ_mE0?oooo]ZoolN0002oookJP;oob@000?ooo]Zo`3o6?oonfX00_oo0900
0ooio`3oeOl0ool0D@02oooS00;ooo]Z0_l0@_l01_oo047ooo]Zo`3okol0onoo0;KooeGo00;ooo]Z
0ooohP07oookJP03ool0QOoo0?;oo`3b00;ooo]Z0_m_0?l2oonj00;o0?mP00?ooo]Zool0Iooo06L0
0ooonfX2ool0[a7ooo]Z00?o0?l9oookJ_l0o`T0=?oonfX004Sooo]Z00?o0?l9oookJ_oonfX04?oo
nfX2ool0[`;ooo]Z0ooo06L00ooonf[o0?mPo`3oH002oonj00;oK`3o0_oonfX2ool0lP03ool0QOoo
nf[ooo]Z00Gooo]Z0_oohP02oookJP;oEOl01?l0ooh01Ooo047o04;ooookJ_oonf[o0?mM00;oon<0
00Koo`1Ao`1Ooooio`3oogT0ool0T?l0oed2onGo00;oob@000Sooo]ZoolN0?oo7P3oA?l0oeD0oom4
o`3oobP0o`3oG@CoiOl000Coo`2ho`0?oonDo`3oU?l00ol0oed00ol0Gooo0?mMo`3oG@02oo<0o`;o
oe<000Cooo]Zool0Looo07?oolD00_l0=ol01_oo0<gooo]Zo`3oFOl0oeWo`03oo`3oG@;o05oo0_oo
03h2o`1Oo`;ooo]Z00Co0;3oooo^0?l0/?oo0;3o0_ook0000ooo7P3o05ooool10002ool03004onGo
0?oonf[ooo]ZoookJP;oo`2/1?l0Gol00ol0WOooocP0o`0]o`02o`0]o`GoogT01Om4o`03o`3ooP?o
l@3o1Ooo:004oiCo00Co0?n]2?l03olDoago00Oo00oo1?oo0<P00ol0ojgo00ooo`0?o`02o`0?o`?o
l@3o1?oonfX2ool000;o9_l000?ooo]Zoon60?ooQP001?oo00000ooo>03o09goo`0?o`03o`0?o`;o
o`2/1?oonfX01?l0A?ooo`0<ool10?oo0@02o`0?o`05ooo/0?l03ooo00oooookJ_ookP001OoonfX2
ool0?P03om[o0?l0T_oo09;o00?o0?mI00?o0?onoolX0?oo:0000ooo:0000onDo`3oobP0oolX0002
oolX0007oiCo0?oo:03oobP0o`3oh?l0/?oo0?mCodCo0002onGo00?oo`2h0_oUo`02oomA0004o`1G
ool0ocKoE@3ooeD0o`;ooah000Kooo]ZoolT0?oo003ooo]Zo`3o6?oonfX2ool0T003ooWo0?oEo`3o
on<000;oon<00ooonfX00ooo003oo`11oookJP02o`3ok`03oomi0?oob@3oEOl000;ooo]Z00?oobP0
oookJ_oonfX01?oonfX00ol0ojgo05ooo`1Oo`04o`1Oo`05oomi0?oo:03oobP0oolX0?nDo`000ooo
:004o`3ooP03ool0[ooUo`3ooo]Z00cooo]Z1OoUo`001?l0GoooiOl0onGo0?oUo`1foookJP;o0?l9
4_oonfX01?oo0:oooo]ZoookJ_oonfX2ool0I`03oookJ_l0of3o0?mP00;ookX00_m_0?l3oookJP;o
o`3b2?oonfX01?oohP3ooo]ZoookJ_oonfX2oeGo0004ool0Q_l0onoooo]Zool0@@;o04;o0_oonfX0
1OooM03oon<0oooS0?oEo`3o0?So00;oo`2@0_l0oaP00ooonf[oob@0oolT0002oookJP;ooah00_mE
0?l2o`1Go`08oomA0?oSo`3ohol0oon<0?oo0;SoT?l0o`3oTOoonfX2o`3oD`04oookJ_l0on3o0?oP
ool0l0;ol`3o0_ooD`002?oonf[oo`1cool0Looo07?oolD0o`0goooo0<gooo]Z0ol0oeT2o`2Bo`03
oookJ_oJo`3oo`0n00Gooo]Z0_ookP000ooonf[o0?l/ooo/0002oolN0004ool10?l0A?ooo`0<o`14
o`Cooo]Z0_oo0:`3oookJP;o09go0ol0;Ol00oooE03o00Oooon60002oon600;o9_l00_oo0=/4oook
JP?ol@3o0_oonfX3o`18o`Coo`381?oo5P000ol0ob_ooo]ZoookJP02oookJQOo7Ol00_oonfX00ol0
ob_ooaH0oolF0002oolF00Goo`380ol0B?l2oookJP?ol@3o1?oonfX2ool0f`;o9_l00_ooQP000ol0
1ooooe@0o`0]o`02o`0]o`;o09go0ooonfX3ool0[0Cooo]Z00[oo`0<o`14oooo0@3oRol0oolN0?oo
k03o0?l/obP0oooonf[oonh01_oonfX01Ooo03kof_l0oookJ_l0T_oo0?lU00;o0?mI00Gooo]Zool0
cOl0=ooo03Ooooo50002ool0L`03oookJ_ooD`3ooe<000;ol`3o00Coo`3`o`3oh?l0on3o0?oP0_l0
oe<00ooonf[oo`03o`3oT@02ool0^003oomX0?oSo`3ooe4000;ooe4000?o05OooeD0oomE0?l00_oo
7P02oookJP;oob@00_l0oaP00ooonf[oo`2@ooWo0002omGo00;oon<000Koog@0oookJ_oonf[o04;o
ool0@OoonfX2o`3ok`03o`2foomEo`3oEOl000;ooo]Z0_oohP07oookJP03ool0QOoo0?;oo`3b00;o
oo]Z0_m_0?l00ooonf[ookX0o`3oH002o`3oH0;oo`1W1?oonfX00ooo0:oooo]ZoookJP0?oookJP?o
0?l9=?oonfX004Oooo]Z0_l0o`TAoookJP;oo`2_0ooonfX3ool0I`;o0?mP0_oo^P001?oonf[oK`3o
ofl0oooonfX3ool0lP03ool0QOoonf[ooo]Z00Gooo]Z00?oon80oookJ_oonfX00_mEo`05o`3ooP;o
04;o00cooo]Zo`3oGOooM03oon<0ool0DOl0GooonOl0ool0T?ooN@3oiOl0o`3oGOoUo`02oolT00;o
oo]Z0_oo7P02oeD0o`04oolX0?l0oegoiOl0oiCo00?oiOl000?oo`2hoiCo0?nDo`000ol0oed00ol0
Gooo0?mMo`3oG@02oo<0o`;ooe<000Cooo]Zool0Looo07?oolD00_l0=ol01Ooo003ooo]ZoookJ_l0
oeWo`03o00;o0?mM00?o05ooool0?_oo03h00ol0Gol00ooonf[o0;3oooo^0002o`2`o`;oon`000?o
oah0o`1Ooooo0@000_oo00`4oookJP;oo`2/1?l0Gol01_l0WOooocP0o`0]ool0;Ooooe@0onGo00Ko
ogT01?m4o`001Ol0Gooo0?onoo40oooa0?oooo]Z00;oA?l01?oo:004oiCo00?o0?n]1ol03ol3oago
0003o`000?oUo`3oiOl000;oiOl00ol0oed4o`1Oo`?o0?n]1olMo`07o`0?o`?oo`381Ol03ol2oo40
o`Cooo]Z0_oo0=/00ooonf[o9_l0oookJP02oon600;ooe@00_oo00000ooo>03o09goo`0?o`03o`0?
o`;oo`2/1?oonfX00ol0A?ooo`0<ool10002o`0?o`;oon`00_l03ol2ooo^00Cooo]Z0ooo03h00ooo
nf[o09;oo`2Bo`02o`3oF@;o0?on1?oo:0000onDo`3oobP0oolX0002oolX0005oiCo0?oo:03oobP0
oolX0?l0/?l00_l0oe<3onGo00;oo`2h0_oUo`02oomA0004o`1Gool0ocKoE@3ooeD0o`;ooah000Co
oo]ZoolT0?oo003ooo]Z0_l0oaP01Ooonf[oo`2@ooWo0?l0n?ooo`1A00;oon<00ooonfX00ooo003o
04;ooookJP02o`3ok`03oomi0?oob@3oEOl000;ooo]Z00?oobP0oiCo0?oonfX00ooonfX6o`1Oo`?o
ogT00ooo:0001?nDo`3o0?n]oolX0?oo:004o`3ooP03ool0[ooUo`3ooo]Z00gooo]Z1?oUo`001?l0
GoooiOl0onGo0?oUo`1eoookJP;o0?l94_oonfX2ool0[`;ooo]Z0ooo06L3o`3oH0;ookX00_m_0?l2
oookJP;oo`3b00?oo`25oookJ_oonfX01OoonfX2oooR00;ooo]Z0_mEo`001Ooo08Ko0?o_o`3okooo
nf[oo`1100;o04;o00Wooo]Zoomd0?ooh`3oon<0ool0DOl0n?oonOl0ool0T?oonfX00_l0oaP01?oo
nf[oob@0oookJ_oonfX2oolN00;oE@3o0_l0Eol01?ooD@3ohol0on?o0?ooS002ool0^003o`3oTOoo
nf[oo`0K00;o0?mC00?obP3oo`3oh?oo0?000ooc0?l00oooD`3ooo]Zool0L`02ool0L`05ooo50?l0
=oooo`3=ool0cOoonfX00_l0oeT2o`2Bo`03oookJ_oJo`3oo`0n00Gooo]Z0_ookP000ooonf[o0?l/
ooo/0002oolN0004ool10?l0A?ooo`0<ool030Cooo]Z0_oo0:`3oookJP;o09go0_l0;Ol2oomD00?o
ohH00_lVo`03ool0f`?ooo]Z0ooa0?l01?oonf[o04Soo`18ool0B?l4ool0b0CooaH000Co0?l[oook
J_oonf[ooo]Z2?lMo`000ol0003ooo]ZoookJP0<oookJPOo7Ol00_oonfX01Ol0ob_ooaH0oolF0?oo
5P3ooo]Z00Coo`380_l0B?l3oookJP;ol@3o1?oonfX2ool0f`;o9_l00_ooQP02oomD00?o02go0_l0
WOl3oookJP?oo`2/0ooonfX01?l0A?ooo`0<ool10?n;o`02oolN0005ooo/0?lX0?oooo]ZoookJ_oo
kP001OoonfX2ool0?P06oookJ_l0T_oo09;ool00ool0oeWooo]Z0_oo0<d2o`0go`;oo`1c0_oonfX0
0oooD`3ooo]Zoo<0o`02ool0l0;o0?oP0_l0oe<2oookJP04o`3oTOn@o`3oo`2hoon<00;ohol00_oo
D@000ol0Eooooo]ZoeD0o`02oolN00;ooo]Z0_oo90000ooonf[o0?lHoookJP02ool0T005o`3hoooE
o`3oo`1AoooS0?ooM0000_oonfX2o`12o`04oookJ_l0onoo0?o_o`2fo`;oEOl00_oonfX2oooR00So
oo]Z0_oo0?83oookJP06ofl0oooonf[ookX0o`3oH?oonf[o0?mP0ooo06L3oookJP03ool0[ooonf[o
oo]Z013ooo]Z0_l0o`TdoookJP00AooonfX00ol0o`Wooo]ZoookJP0@oookJP;oo`2_0ooonfX2ool0
I`03oookJ_l0of3o0?mP00;ookX00_m_0?l2oookJP;oo`3b00?oo`25oookJ_oonfX01OoonfX2oooR
00;ooo]Z0_mEo`04o`3ooP05ool0@Ol0@_oooo]Zo`3oGOooM0000_ooh`001_l0Gooo0?mMooWo0?oo
N@3oo`2@o`3oG@;oiOl00_oo90000ooonf[ooah0oolN0002oeD0o`0:oolX0?l0oegoiOl0oiCo0?oo
:03o00ooonGo0?oo0;So00oooiCo00Co0?mM00?o05ooo`3oGOl0oed00_oc0?l01OooD`3ooo]Zoook
J_oo07?oolD000?o03Oo00Coo`00oookJ_l0oeWo0?mI0_l0oed00ol0Goooo`0nool0?P03o`1Oo`;o
0;3o0_ookP001_l0/?ooon`0ooo/0?oo7P3o05ooo`2`o`;oo`0<1?oonfX2ool0[0Co05oo00Co09go
oolh0?l0;Ooo02go1?oUo`05oomi00?oA?l000?o05oooo40oooa0?l00oooN@000om4o`3oo`38oolX
0003oolX00CoU?l000?o0?n]o`0?ool03ol01Ol03ol00ooonf[o0?m/o`3oK003o`3oK0?oiOl01?l0
oed;o`1Oo`03oookJ_l03ooo7Ol000?o7Ol01Ol03ol01?l0ob_oo`38ool0b?oo0<P4o`0?o`03oook
J_oa0?ool@3o00Cooo]Z00Coo`3KoookJ_lVo`3ooo]Z0_ooQP02oomD0003o`0]oooo003o09go00Go
00oo00?oo`2/oookJ_oonfX00ooonfX2ool03003ool10?l03ooo00oo00;oon`000?o00oooookJ_oo
kP001OoonfX2ool0?P03om[o0?oonf[o09;o00?o0?mI0_l0ooh3oolX0003oiCo0?oo:03oobP000;o
obP000CoU?l0oolX0?oo:03oobP00_l0/?l01?l0oe?oA?l0onGo0?oUo`02ool0^004o`3oGOoUo`3o
oe40oomA00;o05oo00Oooo]ZoeD0oooo7P3ooah0oookJ_oo903oo`0000;ooo]Z00Ko0?lHoookJ_oo
093oo`2@o`3hoooonfX2oooS00?ooo]Z00Soo`00o`12oooonf[ooo]Zo`3okooo08KoolT0oeGo00;o
oo]Z00?oobP0oiCo0?oonfX00ooonfX6o`1Oo`CoogT00ooo:0000ol0ojgoobP0oolX0004o`3ooP03
ool0[ooUo`3ooo]Z00gooo]Z1?oUo`001?l0GoooiOl0onGo0?oUo`1eoookJP;o0?l94_oonfX2ool0
[`;ooo]Z0_oo06L00ooonf[o0?mPo`3oH003oonj0004ofl0oooonf[ooo]ZoookJP;oo`3b2?oonfX0
1?oohP3ooo]ZoookJ_oonfX2oeGo0004ool0Q_l0onoooo]Zool0@@;o04;o0_oonfX01OooM03oon<0
oooS0?oEo`3onOl000;oo`2@0_l0oaP01?oonf[oob@0oolT0?oonfX2oolN00;oE@3o00Ko0?lfo`1G
ooooD@3ooe40on?o0?ooJ002ool0^0;o0?nA00Cooo]Zo`3oDol0oe?ooo]Z0_l0on001?oo0?3ol`3o
oo<0ooooD`02oookJP;oo`1c00GoolD0o`0gool0=oooo`3=oookJP02o`3oF@;o09;o00?ooo]Zom[o
0?oo03h01OoonfX2ooo^0003oookJ_lX0?ooon`000;ooah000Coo`40o`14oooo00coo`0<1?oonfX2
ool0[0?ooo]Z0_l0WOl2o`0]o`;ooe@00oooQP02obKo00;oo`3K1?oonfX2oo40o`;ooo]Z0_l0B?l4
ool0b0?ooaH000Co0?l[oookJ_oonf[ooo]Z1OlMo`03oookJQ?o0?m/1OoonfX4oago00;ooo]Z00Co
0?l[oolF0?oo5P3ooaH00ooo0<P3o`18o`;ooo]Z0_oa0?l4oookJP;oo`3K0_lVo`02oon600;ooe@0
0ol0;Ol00ol0WOoo9?l0oookJP02oookJP;oo`2/1?oonfX2ool03003ool10?n;o`3ooah000;oon`0
00Co:03ooookJ_ookP3oonh01OoonfX01Ooo03kof_l0oookJ_l0T_oo0?lU00;o0?mI00Gooo]Zool0
cOl0=ooo03Ooooo50002ool0L`03oookJ_ooD`3ooe<000;ol`3o00Woo`3`o`3oh?l0on3ooo]Zo`3o
Dooo01_ooo]Zo`3oTOn@o`000_oo0;P2on?o00;ooe4000Go05Ooo`3o=_mE0?oooo]ZoolN0002oook
JP;oob@000?ooo]Zo`3o6?oonfX00_oo09000ooio`3oeOl0ool0D@02oooS00;ooo]Z0_l0@_l2oook
JP;o0?o_00Co0;KooeGo0?oonf[ooo]Z0_oohP08oookJP;oo`3b0ooonfX2ofl0o`05oonj0?l0of3o
0?mPo`3oH?oonfX00_oo06L3oookJP03ool0[ooonf[ooo]Z013ooo]Z0_l0o`TdoookJP00AooonfX0
0ol0o`Wooo]ZoookJP0?oookJP;oo`2_0ooonfX3ool0I`;o0?mP00?o0;Oooonj0?oo^P000_m_0?l0
1Ooonf[oo`3bool0l_oo0?;oo`2500Oooo]Z00?oon80oookJ_oonfX00_mEo`05o`3ooP;o04;o0_oo
nfX2oooS0006ool0DOl0GooonOl0oomi0?oo093o0?mM0_oUo`02oolT000;onGo0?oonf[ooah0oolN
0?mE0?ooA?l0o`1GoooUo`3ooe40oiCo0?l03ol00_oo0;P2o`0?o`Co0?mM00?o05ooo`3oGOl0oed0
0_oc0?l2oomC0003oookJ_oo07?oo`1c00?o03Oo00Coo`00oookJ_l0oeWo0?mI0_l0oed01_l0Gooo
o`0nool0?_oo03ko0?mMo`1Oo`;o0;3o0_ookP001?l0/?ooon`0ooo/0?oo7P02o`2`o`;oo`0<00Co
05oooookJ_oonf[ooo]Z0_oo0:`01_l0oego05ooo`1Oool0Gooo09gooolh00;o02go00Gooe@0onGo
0?oUo`3oiOl0obKo0005oomi0005o`3oGOm4o`3o05oooo40oooonfX00oooN@03ool0b0GoobP00_nD
o`07o`0?o`So0?m/0ooUo`04o`3oG@go05oo0ooonfX4oago00?o00oo00?ooaH0o`0?oooo0<P00_oo
0<P3o`0?o`03oookJ_oa0?ool@3o00Cooo]Z00Coo`3KoookJ_lVo`3ooo]Z0_ooQP02oomD0003o`0]
oooo>03o09go00Co00oo00?ooo]Zool0[?oonfX01?oonfX00ooo00coo`40ool10002o`0?o`03ooo/
0?l03ooooo]Z00;oonh01?oonfX3ool0?P03oookJ_l0T_oo0?lU00;o0?mI0_l0ooh2oolX00?oU?l0
1?oo:0001OnDo`3oobP0oolX0?l0on3o0;3o00;o0?mC00?oA?l0onGo0?oo0;P00_oo0;P2onGo00;o
oe4000Co05ooo`3o=_mE0?oooo]Z0_oo7P001?oonf[oob@0ool00?oonfX2o`3o60;oo`2@00GonOl0
omGo0?ooh`3oon<0oomd0002oookJP08ool00?l0@_ooA?l0oookJ_l0onooo`26ooo90?mEo`02oook
JP03oolX0?nDo`3ooo]Z00Cooo]Z1_l0Gol3oomi00?oobP000?o0?n]oolX0?oo:0001?l0ooh00ooo
nf[oiOl0ool0[`0>oookJP?oiOl000Co05ooonGo0?oUo`3oiOl0MOoonfX00ol0o`Wooo]ZoookJP0@
oookJP;oo`2_0ooonfX2ool0I`?o0?mP0_oo^P02ofl0o`;ooo]Z0_oo0?800ooo08Gooo]ZoookJP05
oookJP;oon800_oonfX2oeGo0005o`2fool0onoo0?o_oookJ_oo04400_l0@_l01_oonf[oog@0oooS
0?ooh`3oo`1Ao`3ho`;oo`2@00?ooo]Zo`3o6?oonfX00_oo9002oookJP;ooah00_mE0?l2o`1Go`04
oomA0?oSo`3ohol0oon<00;oo`2h00Go0?nAoookJ_l0oe?o0?mCoookJP02o`3oh003ool0l?oc0?oo
l`3o00;ooe<000Cooo]Zool0Looo07?oo`1c0_l0=ol01Ooo0<gooo]Zo`3oFOl0oeWo`03o00;o09;o
00?of_l0ool0?_oo03h01?oonfX2ooo^0005oookJ_lX0?ooon`0ooo/0?oo7P000_oo0@02ool030Co
oo]Z0_oo0:`2oookJP03obCo0?l0WOoo09go00;o02go00Cooe@0o`07ooooQP3oohH00_lVo`02ool0
f`Cooo]Z0_oa0?l2oookJP;o04So1?oo0<P3oolF00?ooo]Z1?lMo`000ooonf[o0?m/o`3oK008o`3o
K0_ooo]Z1ol0of`5oookJPCo7Ol000?ooo]Zo`3o:ooo5P000_oo5P03ool0b0;o04So0_oonfX3oo40
o`?ooo]Z0_oo0=/2obKo00;oohH00_ooE002o`0]o`;o09go00Co9?l0oookJ_oonf[ooo]Z0_oo0:`4
oookJP07ool03?oo0@3oo`40oh_o0?oo7P3oon`0o`3o;002oookJP03ooo^0?oonf[ooo]Z00?ooo]Z
0_oo03h01Ooonf[o09;oo`2Booo00?oo0?mI00;ooo]Z00?oo`3=o`0gooooa@000_oo07<2oookJP03
oomC0?oc0?ool`3o00;oo`3`0_l0on02o`3oD`03oookJ_oo00?o0?nA00;oo`2h00?oofP0on?o0?oS
o`000_ooD@000ol0ocKoE@3ooeD0o`02oolN00;ooo]Z0_oo9002o`3o60;oo`2@00?onOl0omGo0?oo
05400_ooh`03oookJP03o`12oooo047ooo]Z00;o0?o_00?o0;KooeGo0?oonfX00_oonfX00ooohP3o
oo]ZoookJP06oookJP?oo`3b0_oonfX2ofl0o`;ookX00_l0of000ooonf[oo`1Wool0I`03oookJP;o
o`2_4OoonfX2o`3o2CCooo]Z0016oookJP;o0?l94OoonfX2ool0[`?ooo]Z0_oo06L00ooonf[o0?mP
o`3oH002oonj00;oK`3o0_oonfX2ool0lP03ool0QOoonf[ooo]Z00Kooo]Z00?oon80oookJ_oonfX0
0_mEo`04o`3ooP05o`2`ool0@_oooo]ZoookJ_ooM0000_ooh`001?l0Gooo0?SoooWo0?oo0902o`3o
G@05o`3o6?oUo`3oob@0onGo0?oonfX00_oo7P02oeD0o`04o`1GooooD@3oiOl0oiCo00;o00oo0_oo
0;P2o`0?o`;o0?mC00?o0?mMo`1Oool0oed00_l0oed00ooc0?oooe<0oomC0002oookJP04ool0Looo
a@3o03Ooo`0go`;oo`0000Ko`03oo`3oFOo00?oo0?mMo`1Oool0/?l2ool0?P;o0?mM0ol0/?l01Ooo
kP3o0;3oooo/0?ook03ooah000;o0;3o0_oo00`01_l0Gooooo]ZoookJ_oonf[o0?mMool0[0?o0?mM
00Co05ooo`2Mool0;Ooo02go0_ooE0001?l01oooohH0onGo0?lVo`02onGo00?oogT00ol0oed01?oa
0?oooo]Zo`18ool0B?l3ool0b0;oU?l000Ko0?n]oolX0?oo:03o0?n]o`0?oonDo`06o`0?o`;o0?m/
0ooonfXBooKo00So05oo1?oonfX3oago00;ooo]Z0ooo5P000ol03oooo`38ool0b002o`0?o`;ooo]Z
0_oa0?l3oookJP;oo`3K00?ooo]ZobKo0?oonfX00_ooQP001Ooo:03o02goo`0]oooo>03o09go00?o
00oo0_oonfX00ooo0:cooo]ZoookJP02oookJP;oo`0<0_oo0@02o`0?o`03ooo/0?lX0?oooo]Z00;o
onh01?oonfX2ool0?P05om[o0?oonf[o09;ool00ool0oeT00_l0ooh5oiCo0005o`3o[Ooo:03oobP0
oolX0?nDo`000_oo:0001?l0on3o0;3oool06ol0oe<3onGo00;oo`2h0_oUo`02oomA0004o`1Oool0
ocKoE@3ooeD0o`;ooah000Cooo]ZoolT0?oo003ooo]Z0_l0oaP2ool0T005ooWo0?oEo`3oo`1AoooS
0?ooM0000_oonfX03?oo003o04;oodCo0?oonf[o0?o_ool0Q_ooN@3oolT0oeGo0?oonf[oon80oiCo
00Gooo]Z1_l0Gol4oomi00;oobP000?o0?n]oolX0?oo:0001?l0ooh00ooonf[oiOl0o`3oG@0>oook
JP?oiOl000Co05ooonGo0?oUo`3oiOl0M?oonfX2o`3o2A;ooo]Z0_oo0:l2oookJP;oo`1W00Cooo]Z
o`3oH?l0of3o0?mP0_oo^P001?m_0?oooo]ZoookJ_oonfX2ool0lPSooo]Z00Coon80oookJ_oonf[o
oo]Z0_mEo`001?oo08Ko0?o_oookJ_oo0442o`12o`03oookJ_ooM03oog@000;oon<000OoeOl0ooWo
0?oo093oo`2@oookJ_l0oaSooo]Z00;oob@000?ooo]ZoolN0?oo7P000_mE0?l2o`1Go`;ooe4000Ko
hol0oomX0?oo0;Soo`2ho`3oTOoo00<3o`3oD`04oookJ_l0on3o0?oPool0l0;ol`3o00?ooe<0oook
J_oonfX00_oo07<01oooa@3o03Ooool0cOoo0<gooo]Zo`3oFOo00?l00_l0T_l00ooJo`3oo`0nool0
?P05oookJP03ooo^0?oonf[o:03o00;oon`000?ooah0ool10?oo0@000_oo00`4oookJP;oo`2/0_oo
nfX00olTo`3o09goo`2Mo`02o`0]o`04oomD0?l01oooohH0oon600;o9_l00_oo0=/4oookJP;ol@3o
0_oonfX00ol0B?ooo`38ool0b002ool0b0?ooaH00_oonfX4oago0003oookJ_l0ofco0?m/00Co0?m/
0_oonfXCooKo00Cooo]Z1?l0of`3oookJPCo7Ol00_oonfX2oolF0004oookJ_oo0<Soo`38oookJP;o
04So0_oonfX2oo40o`?ooo]Z0_oo0=/2obKo00;oohH00_ooE002o`0]o`;o09go00Co9?l0oookJ_oo
nf[ooo]Z0_oo0:`4oookJP03ool03?oo0@3oo`4000;ooah000?oon`0o`3o;?oonfX00_ookP05oook
JP05ool0?_oJo`3ooo]Zo`2Bool0obD00_l0oeT01Ooonf[oo`3=o`0gool0=oooolD000;oo`1c00Ko
oo]ZoomC0?ooD`3ol`3oool0eooo0?02o`3oh006oookJ_l0oe?ooo]ZoookJ_l0oi7oT?l00_oo0;P2
on?o00;ooe4000?o05OooeD0oomE0?l00_oo7P02oookJP;oob@00_l0oaP01Ooonf[oo`2@ool0T?oo
nf[oeOl000;oon<000Koog@0oookJ_oonf[o04;oool0@OoonfX2o`3ok`03o`2foomEo`3oEOl000;o
oo]Z0_oohP07oookJP03ool0QOoo0?;oo`3b00;ooo]Z0_m_0?l2oonj00;o0?mP00?ooo]Zool0Iooo
06L00ooonfX2ool0[a7ooo]Z0_l0o`TdoookJP00A_oonfX00ol0o`Wooo]ZoookJP0?oookJP?oo`2_
0ooonfX2ool0I`03oookJ_l0of3o0?mP00;ookX00_m_0?l01Ooonf[oo`3bool0l_oo0?;oo`2500Oo
oo]Z00Coon80oookJ_oonf[o0?on0_mEo`04o`3ooP04o`2`ool0@_oooo]ZoookJP;oon<000?oo`1A
o`1Ooooo00000_oo09000ol0oegoiOl0oookJP02oolT0009onGo0?oo7P3ooah0oolN0?mE0?ooA?l0
o`1GoooUo`3ooe4000;o00oo0_oo0;P2o`0?o`04oiCo0?l0oe?oiOl0o`1Oo`?o0?mM00?ol`3oo`3o
GOooD`000_oonfX00ooo07?oolD0o`0go`02o`0go`;oo`0000Co0?mIol00oooUo`3o0?mM0_l0/?l0
0ooo03ko0?mMo`3oG@02oookJP03o`2`ooookP3o0;3o00?oon`000Kooah0o`2`ool0/?ooo`0<o`2`
ool0Gol2oookJP03o`3oGOoo0:co0?mM00?o0?mM00?o09goo`0]ool0;Ol00oooE0000oooQP3ooo]Z
obKo0004onGo0005oomi0?l0oego0?mMo`3oGOoonfX00ol0B?l3ool0b0CoU?l000?oobP0o`3o[Ol0
ojd01_l03ol01?l0ofcooo]ZoookJ_oonfX6ooKo00;o00000ooUo`03o`3oG@?o05oo2Oofo`04o`1O
o`;o0?m/0ooonfX3oago00;ooo]Z0ooo5P03ool0b003o`0?oooonf[ooo]Z00;ol@3o0ooonfX2ool0
f`;o9_l01?oo:002o`0]o`03oolh0?l0WOoo00oo00;o00oo00?ooo]Zool0[?oo0:`01?oonfX2ool0
3003ool10?l03ooo00oo00;oon`000?o:03oooo^0?ookP001OoonfX00ooo03kof_l0oookJP02o`2B
o`;o0?mI00?o0?onoiCo0?nDo`000onDo`001_l0ojgoU?l0oolX0?oo:03oU?l0oolX00?oU?l000Go
0;3oo`3oDol0oe?o05ooonGo0002ool0^003o`3oGOoUo`3ooe4000;ooe4000Wo05OooeD0oooo:03o
oo]ZoolN0?oonf[oob@0ool00?oo90000_l0oaP01Ooonf[oo`2@ool0T?l0n?ooo`1A00;oon<00ooo
nfX00ooo003oA?l0oookJP02o`3ok`03oomi0?oob@3o0?l<00;ooo]Z00?oU?l0oolX0?oo:0000_oo
:002oookJPKo05oo0oooN@02oolX0003o`3o[Ooo:03oobP000Co0?on00?ooo]ZonGo0?l0oed03ooo
nfX2onGo0004o`1OoooUo`3oiOl0onGo07Cooo]Z0_l0o`TAoookJP;oo`2_0ooonfX2ool0I`03oook
J_l0of3o0?mP00;ookX00_m_0?l2oookJP;oo`3b00?oo`25oookJ_oonfX01OoonfX2oooR00;ooo]Z
0_mEo`001Ol0]_oo0?o_o`3okooonf[oo`1100;o04;o00Kooo]Zoomd0?ooh`3oon<0ool0DOoEo`02
ool0T003oookJ_l0oaSooo]Z00;oob@000Cooo]ZoolN0?oo7P3ooah00_mE0?l2o`1Go`03oomA0?oS
o`3ohol000?oo`2h00Go0?nAoookJ_l0oe?o0?mCoookJP02o`3oh004ool0l?oc0?ool`3ooomC00;o
oo]Z0_oo07<01Oooa@3o03Ooo`0goooo0<gooo]Z00;o0?mI0_l0T_l00ooonf[of_l0ool0?P05oook
JP03ooo^0?oonf[ooo]Z00;oon`000?ooah0ool10?oo0@000_oo00`4oookJP;oo`2/0_oonfX00olT
o`3o09goo`2Mo`02o`0]o`;ooe@00_ooQP02obKo00;oo`3K1?oonfX00ooa0?oooo]ZoookJP02o`18
o`Coo`3800CooaH0o`3o:ooonf[ooo]Z0olMo`02oookJPGo0?m/0_oonfX7ooKo0003o`000?oonf[o
oo]Z00Sooo]Z2Oofo`02oookJPCo0?m/0ooonfX3oago0005oookJ_l0ob_ooaH0oolF0?oonfX00_oo
0<P2o`18o`;ooo]Z0_oa0?l3oookJP;oo`3K00Co9_l0oookJ_ooQP3oohH00_ooE002o`0]o`;o09go
0ooonfX3ool0[0?ooo]Z00Go04Coool03?oo0@3oRol0oolN0002ooo/0003obP0oooonf[oonh000Go
oo]Z0_oo03h00ooonf[o09;oo`2Bo`02o`3oF@;ooo]Z00?oo`3=o`0gooooa@000_oo07<2oookJP03
oomC0?oc0?ool`3o00;oo`3`00Oo0?oPoookJ_l0oe?o0?mCoookJ_oo00?oT?l000;oo`2h00KoofP0
on?o0?ooD@3ooe40o`1Gool0ocH2oeD0o`03oolN0?oonf[ooo]Z00;oob@000?ooo]Zo`3o6?oonfX0
0_oo09001Ol0n?ooeOl0ool0DOooh`3oog@000;ooo]Z00?o04;oool0@OoonfX00ol0onl2oeGo00;o
oo]Z0_oohP08oookJP;oo`3b0ooonfX00om_0?oookX0oonj0002o`3oH003oookJ_oo06Ooo`1W00?o
oo]Z0_oo0:lAoookJP;o0?l9=?oonfX004Kooo]Z00?o0?l9oookJ_oonfX03ooonfX2ool0[`?ooo]Z
0ooo06L2o`3oH0;ookX00_m_0?l2oookJP;oo`3b00?oo`25oookJ_oonfX01OoonfX2oooR0004oook
J_l0ookoEOl0oeGo00Co0?on0_l0/?l2oookJP07oomd0?ooh`3oon<0ool0DOoo003onOl0ool0T002
o`3oG@03o`3o6?oonf[oob@000;ooo]Z0_oo7P02oeD0o`03o`1GoooUo`3ooe4000?o00oo00Goo`2h
o`0?ool03ooo00ooo`3oD`03onGo0004o`3oGOoUo`3ol`3ooo<0o`;ooe<000Cooo]Zool0Looo07?o
olD00_l0=ol2ool000;o0?mI0_oUo`03o`2`o`?o0?mM0_l0o``00oookP3o0;3oooo/0002ooo/0006
oolN0?l0/?oo0;3oool03?l0/?oo05oo0ooonfX00ooo0:co0?mMo`3oG@02o`3oG@03o`2Mool0;Ooo
02go00?ooe@000CoohH0oookJ_lVo`3oo`3K1OoUo`000ooa0?oo0?mMoookJP02o`18o`?oo`380_oo
:004oiCo00Co0?n]0ol03ol3oookJPCom_l00ooonfX4o`00013ooo]Z1Oofo`02oookJPCo0?m/00?o
oo]Zoago0?lMo`000_lMo`001Ooonf[ooaH0oolF0?oo5P3o00oo00;oo`3800?o00oooookJ_oonfX0
0_oa0?l3oookJP;oo`3K0_lVo`04oolX00;o02go0_l0WOl2oolX0003onGo0?oonf[oo`2/00Cooo]Z
00Co04Coool03?oo00coo`400_l03ol00oook03o:03ooookJP02ooo^00Cooo]Z0_oo03h01?oJo`3o
09;oo`2Booo00?l2o`3oF@03o`3oo_nDo`3oU?l000;oU?l000?o0?n]oiCo0?oo:0001_nDo`000ol0
/?oo0?mCo`3oD`02onGo0003o`3oGOoo0;So05oo00;o0?mM0_ooD@001Ol0Eooooo]ZoolX0?oonf[o
oah000;ooo]Z00Goo`00oolT0?oonf[o0?lHoookJP02ool0T005ooWo0?oo057oon<0oooS0?ooM000
0_oonfX02?oo003o04;ooookJ_ooN@3o0?o_oomi0?oob@3o0?l<0_ooN@000ooo:03oU?l0oolX0002
oolX00;ooo]Z1_l0Gol3oomi0003odCo0?oo:03o0?n]00;oobP00ol0ooh2oookJP03onGo0?l0oego
oo]Z00kooo]Z0_oUo`000ol0GoooiOl0onGo001eoookJP03o`3o2Ooonf[ooo]Z013ooo]Z0_oo0:l3
oookJP;oo`1W0ol0of02oonj0004ofl0oooonf[ooo]ZoookJP;oo`3b2?oonfX00ooohP3ooo]Zoook
JP03oeGo0004ool0Q_l0onoooo]Zool0@@;o04;o00Oooo]Zoomd0?ooM03oon<0ool0DOoEo`3onOl0
00;oo`2@0_l0oaP01?oonf[oob@0oolT0?oonfX2oolN00;oE@3o0_l0Eol01?ooD@3ooo]Zon?o0?oo
S002ool0^003o`3oTOoo00?o0?mC00;o0?mC00?ooo]Zo`3oh?oo0?000ooc0?l00oooD`3ooo]Zool0
L`02ool0L`04ooo50?l0=oooo`3=oookJP;o0?mI00Go0?lUo`2Boooonf[of_l0ool0?P05oookJP03
ooo^0?oonf[ooo]Z00;oon`000?ooah0oh_o0?oo0@000_oo00`4oookJP;oo`2/0_oonfX00olTo`3o
09goo`2Mo`02o`0]o`;ooe@00_ooQP02obKo0003ool0fooonf[ooo]Z00;ooo]Z0_oa0?l2oookJP03
o`18oooo0<Soo`3800;oo`3800?ooaH0o`3o:ooonfX01?lMo`000ooonf[o0?m/o`3oK003o`3oK0;o
oo]Z1?ofo`03oookJPCo00004OoonfX5ooKo00;ooo]Z1?l0of`01?oonf[o7Ol0oago0?lMo`02oook
JP;ooaH000?ooo]Zool0b?oo0<P00_l0B?l2oookJP;ol@3o0ooonfX2ool0f`04obKo0?oonf[oohH0
o`07o`;ooe@00_l0;Ol00ol0WOoo9?l0oookJP02oookJP;oo`2/1?oonfX2ool03006ool10?oo7P3o
oah0ooo/0?l0obcooo]Z0_ookP05oookJP05ool0?_oJo`3o09;oo`2Bool0obD00_l0oeT01_oonf[o
o`3=o`0gool0=oooolD0ool0L`;ooo]Z0_ooD`000ooc0?ooo`3`ool0l002o`3oh0;o0?mC0_oonfX0
1?l0oi7oo`2hool0^?ooS002on?o0003oomA0?l0Eooo0?lf00;oE@3o00Kooah0oookJ_oonf[ooo]Z
oolT0?oonfX2o`3o60;oo`2@00?onOl0omGo0?oo05400_ooh`02oookJP;o04;o0_oonfX2o`3ok`04
o`2foomEo`3ooo]ZoookJP;oon802?oonfX2ool0lP?ooo]Z00?oK`3ooonj0?oo^P000_l0of000ooo
nf[oo`1Wool0I`03oookJP;oo`2_4OoonfX2o`3o2CCooo]Z0015oookJP;o0?l94OoonfX2ool0[`?o
oo]Z0_oo06L00ooonf[o0?mPo`3oH002oonj00;oK`3o0_oonfX2ool0lP03ool0QOoonf[ooo]Z00Go
oo]Z0_oohP02oookJP;oEOl00ol0ooh3o`2`o`;ooo]Z00Goog@0oooS0?oo057o0?mMo`3ho`02ool0
T003o`3o6?oUo`3ooo]Z00;oob@000Wooo]ZoolN0?oo7P3ooah0oeD0ooooN@3o05OoonGo0?ooD@00
0_l03ol2ool0^0?o00oo0ooUo`001ol0oegoiOl0oo<0oooc0?oo0?mMoomC0?oonfX00_oo07<00ooo
a@3o03Ooo`0go`02ool000;o0?mI0_oUo`03o`2`o`06ool0?_l0oego0?mMo`3oGOl0o`coonh00_l0
o``2ooo/00?o0;3o00Goo`0<o`2`ool0/?oo05oooookJP02o`0?o`05onGo0?l0oego0?mMo`3oGOl0
WOl00ol0;Ol2oomD0004oon60?oonf[o9_l0ool0f`;ooo]Z0ooUo`000ooa0?oooo]ZoookJP02o`18
o`;oo`001?oo:004oiCo00Co0?n]00?o00oooookJ_oonfX00oofo`07oookJPCo00005?oonfX4ooKo
0003oookJ_l0ofco0?m/00;o0?m/00Cooo]Zoago0?lMo`3o7Ol00_oonfX2oolF0006o`0?oooo0<So
o`38o`0?ool0B?oooo]Z0_oa0?l2oookJP?oobP00_lVo`03oolX0003oomD0?l0;Ooo02go00;o09go
00GoobP0onGo0?oonf[ooo]Zool0[004oookJP;oo`0<00?oo`40o`0?ool03ol00_ook0000olX0?oo
oo]Zooo^0005oookJP05ool0?_oJo`3ooo]Zo`2Booo00?l00_l0oeT2o`3ooPSoU?l000Go0?n]oiCo
0?nDo`3oU?l0o`3oh002o`3oD`?o0?mM0_oo0;P2o`3oG@;ooe4000Go05Ooo`3o=_oo:03ooo]ZoolN
0002oookJP03ool00?oo903ooo]Z00;o0?lH0_oo09003ooio`3oeOl0ool0DOooh`3oog@0oookJ_oo
N@3oo`00o`12oom4o`3oogT0o`3okoooN@3oolT0o`3o3002oomi0003oolX0?nDo`3oobP000;oobP0
0ooonfX5o`1Oo`08o`0?ooooN@3oogT0odCo0?oo:03oU?l0o`3o[Ooo:003o`3ooP;ooo]Z00?oo`2_
o`3oGOoonfX03ooonfX01?oUo`3o05ooonGo0?oUo`1doookJP;o0?l94_oonfX01?oo0:oooo]Zoook
J_oonfX2ool0I`03oookJ_l0of3o0?mP00;ookX00_m_0?l3oookJP03ool0l_oo08Gooo]Z00Oooo]Z
00?oon80oookJ_oonfX00_mEo`001_l0]_oo0?o_o`3okooonf[oo`11o`12o`;ooo]Z00?oog@0oooS
0?ooh`000_oEo`001Ooio`3oo`2@oookJ_l0oaSooo]Z00;oob@000Kooo]ZoolN0?oo7P3ooah0oeD0
ool0ocH2o`1Go`03oomA0?oSo`3oofP000;oo`2h00?o0?nAool00ooonfX00_l0oe<00ooonf[o0?oP
o`3oh003oo<0o`03oomC0?oonf[oo`1c00;oo`1c00?oolD0o`0goooo0<d00_oonfX01Ol0oeWo`03o
o`2Bool0T_oooo]Z00;oo`0n1?oonfX2ooo^0003oookJ_lX0?ooon`000;ooah000?oo`40ool03?oo
00`01?oonfX2ool0[0;ooo]Z00?o9?l0o`2Mool0WOl00_l0;Ol2oomD00;oohH000?o9_l0ool0fooo
0=/01?oonfX01Ooa0?oooo]ZoookJ_oonf[o04So00?oo`380_oo5P000ooonf[o7Ol0oago0002oago
0003oookJ_l0ofco0?m/00;o0?m/0_oonfX4ooKo00Kooo]Z1?l0000EoookJPCom_l000?ooo]Zo`3o
K?l0of`00_l0of`01?oonf[o7Ol0oago0?lMo`02oookJP;ooaH000Cooo]Zool0b?l0B?oo04So0_oo
nfX2oo40o`?ooo]Z00?oo`3KoookJ_lVo`000_ooQP001ol01ooooe@0o`0]ool0;OooocP0o`2MoolT
o`000ooonfX2ool0[0?ooo]Z00Go04Coool03?oo0@3oo`40oolN0002ooo/0004obP0oooonf[oonh0
ooo^00Cooo]Z0_oo03h00ooonf[o09;oo`2Bo`02o`3oF@05oookJ_oo0<goo`3=o`0gooooa@000_oo
07<00ooonf[ooe<0oomC0002oo<0o`08ool0l?l0on3o0?oPoookJ_l0oe?oo`0KoookJ_l0oi42ool0
^006oon<0?oSo`3ohol0oomA0?l0Eooo0?lf0_mE0?l01_oo7P3ooo]ZoookJ_oonf[oob@0oookJP;o
0?lH0_oo09000ooio`3oeOl0ool0D@02oooS00?ooo]Z00?o04;oool0@OoonfX00_l0onl00ol0]_oo
EOl0oookJP02oookJP03oooR0?oonf[ooo]Z00Kooo]Z0_oo0?83oookJP03ofl0oooonf[ookX000?o
0?mP0_oo06L4oookJP03ool0[ooonf[ooo]Z00oooo]Z0_l0o`TdoookJP00AOoonfX00ol0o`Wooo]Z
oookJP0?oookJP?oo`2_0_oonfX3ool0I`04oookJ_l0of3ookX0oonj00;oK`3o0_oonfX2ool0lP03
ool0QOoonf[ooo]Z00Gooo]Z0_oohP02oookJP;oEOl000CoA?l0o`3oo_m4o`3o0?on0ol0/?l2oook
JP;oon<000Woo`1Ao`3hoooio`3oo`2@o`3o6?oUo`3o0?lHoookJ_oo90000_oonfX2oolN0005oeD0
ooooN@3o05OoonGo0?ooD@000_l03ol2ool0^0?o00oo1?oUo`001Ol0oegoiOl0oo<0ool03ooooe<0
00;ooo]Z00?oo`1cooo50?l0=ol00_l0=ol2ool00003o`3oFOo00?ooiOl000Co0;3o00CoiOl0oook
J_l0oego0?l<0_ookP000ol0o`coon`0ooo/0002o`2`o`;o0?on00Coo`0<o`2`ool0/?oooo]Z0ol0
3ol2onGo0003o`3oGOl0WOoo02go00;o02go0_ooE002oon60003obKo0?oo0=_ooo]Z00?ooo]Z00Co
iOl0oo40oooonf[o04So1Ooo00000ooo5P3oobP0oolX0002oolX00CoU?l00_l0ojd01?oonf[om_l0
ooKo0?ofo`0:oookJP03o`000?l0W_oo09ko00ko09ko2_oonfX3ooKo00;ooo]Z0_l0of`2oookJP?o
7Ol00_oonfX2oolF00;oo`3800?o00ooo`18oooonfX00_oa0?l5oolX00;o9_l000CoobP0oiCo0?nD
o`3oobP00_l0;Ol2o`2Mo`03onGo0?oonf[ooo]Z00;oo`2/1?oonfX2ool03003ool10?l03ooo00oo
00;oon`000?ooo]Zooo^0?ookP001?oonfX2ool0?P05oookJ_l0T_oo09;ool00ool0oeT00_l0ooh8
oiCo0007o`3o[OnDo`3oU?l0oiCo0?l0on3o0?ono`3oD`03o`3oG@;oo`2h0_l0oed3oomA0003o`3o
=_mE0?ooobP000;ooah000Cooo]ZoolT0?oo003oob@00_l0oaP2ool0T005ooWo0?oEo`3oo`1AoooS
0?ooM0000_ooN@002?oo003o04;ooomi0?ooN@3o0?o_oomi0?oob@3o0?l<0_ooN@000ooo:03oU?l0
oolX0002oolX00;ooo]Z0_l03ol4o`1Oo`07o`0?ooooN@3oogT0odCo0?l0ookoobP0o`3o[@03oiCo
0005o`3oo_oonf[ooo]ZoookJ_l0oed04?oonfX01?oUo`3o05ooo`3oGOoUo`1doookJP;o0?l94Ooo
nfX2ool0[`?ooo]Z0_oo06L00ooonf[o0?mPo`3oH002oonj0004ofl0oooonf[ooo]ZoookJP;oo`3b
00?oo`25oookJ_oonfX01OoonfX00ooohP3ooo]ZoookJP03oeGo00;o0?o_00Cooo]Zool0@Ol0@_oo
04;o0_oonfX01OooM03oon<0ool0DOoEo`3onOl000;oo`2@0_l0oaP01?oonf[oob@0oolT0?oonfX2
oolN00;oE@3o0_l0Eol00oooD@3ooo]Zon?o0003ool0^003o`3oTOoonf[o0?mC00;o0?mC0_l0on00
1?oo0?3ol`3ooo<0ooooD`02oookJP;oo`1c00OoolD0o`0gool0=oooo`3=oookJ_l0oeWo`03o00;o
09;o00?ooo]Zom[o0?oo03h01?oonfX2ooo^0006oookJ_lX0?ooon`0ooo/0?oo7P3oo`400ooo00`3
oookJP;oo`2/0_oonfX00olTo`3o09goo`2Mo`02o`0]o`;ooe@00_ooQP000olVo`3oo`3Kool0f`03
oookJP;ol@3o0_oonfX2o`18o`;oo`380_oo5P02oookJP?o7Ol00_oonfX3o`3oK003oookJ_ofo`3o
m_l000;om_l02OoonfX00ol0003o09koo`2No`0?o`2No`[ooo]Z0_ofo`02oookJP?o0?m/00Cooo]Z
oago0?lMo`3o7Ol00_oonfX2oolF00;oo`380_l0B?l2oookJP03oo40oooonf[ooo]Z00;ooo]Z00?o
o`3KobKo0?lVo`000_ooQP02oomD00;o02go00?oocP0o`2MoolTo`000_oonfX2ool0[0Cooo]Z0_oo
00`2ool10003oolN0?ook03oon`000;ooo]Z00?oonh0oookJ_oonfX00ooonfX01_oo03kof_l0o`2B
ool0T_oo`03oo`3oF@;ooo]Z00?oo`3=o`0gooooa@000_oo07<2oookJP03oomC0?oc0?ool`3o00;o
o`3`00Oo0?oPoookJ_l0oe?o0?mCoookJ_oo00?oT?l000;oo`2h0_oSo`02oomA0003o`1GoomE0?oo
E@3o00;ooah00_oonfX2oolT0003oookJ_l0oaSooo]Z00;oo`2@00Gooo]ZomGo0?ooh`3oon<0oomd
0002oookJP03o`12oooo047ooo]Z00;o0?o_00?o0;KooeGo0?oonfX00_oonfX00ooohP3ooo]Zoook
JP06oookJP;oo`3b0ooonfX01?m_0?oooo]Zoonj0?l0]ol2o`3oH0?oo`1W0ooonfX00ooo0:oooo]Z
oookJP0@oookJP03o`3o2Ooonf[ooo]Z03;ooo]Z0014oookJP;o0?l94OoonfX2ool0[`?ooo]Z0_oo
06L00ooonf[o0?mPo`3oH002oonj00;oK`3o0_oonfX2ool0lP03ool0QOoonf[ooo]Z00Gooo]Z0_oo
hP02oookJP;oEOl000?oA?l0o`3oo_m4o`000ol0/?l2oookJP05oomd0?ooh`3oon<0o`3oGOl0n?l0
0_oo09000ol0oaSoiOl0oookJP02oolT00;ooo]Z0_oo7P000omE0?oo0?ononGo0002oomA00;o00oo
00Co0?onool0^?l03ooo00oo1?oUo`001?l0oegoiOl0oo<0oooc0?l2oomC0003oookJ_oo07?oo`1c
00?o03Oo0_oo0002o`3oF@03onGo0?l0/?oo0;3o00?o0;3o00KoiOl0o`3o3?l0o`co0?l<ooo^0?l0
o``2ooo/00;o0;3o0ol0ooh2o`2`o`04oookJ_l03ooo00ooo`0?o`?oiOl000Co09goo`0]ool0;Ooo
02go0_ooE002oon600;o9_l01?oonfX2oo40o`03oookJ_oo003oo`0000Coo`0000?o0?l[oago0?oo
:0000ooo:004oiCo0004o`3o[Oofo`3om_l0ooKo00Oooo]Z2Ol0W_l;oookJPGo09ko2OoonfX3ooKo
00;ooo]Z0_l0of`01?oonf[o7Ol0oago0?lMo`02oookJP;ooaH00_oo0<P00ol03ooo04SooookJP02
oo40o`03oookJ_oo:03oobP000;oobP00_lVo`02oiCo0007oolX0?l0;Ooo02goo`0]ool0WOooobP0
onGo0002oookJP;oo`2/0ooonfX2ool03003ool10?l03ooo00oo00;oon`000?ooo]Zooo^0?ookP00
1OoonfX01Ooo03kof_l0oookJ_l0T_oo`03o00;o0?mI0_l0ooh01?nDo`3o0?n]o`3o[Ol0ojd3oiCo
0006o`3o[OnDo`3oU?l0oiCo0?l0on3o0;3o0_l0oe<3o`3oG@04ool0^?l0Gooo0?mMo`3oG@;ooe40
00Go05OooookJ_oo:03ooo]ZoolN0002oookJP03ool00?oo903oo`0000;oo`000_oo09001Ooio`3o
o`1AoooS0?ooh`3oog@000;oogT01?oo0002oomi0003o`3o3?oob@3oolT000;oolT00ooo:002oook
JP;o00oo1?l0Gol2o`0?o`CoU?l000Go0?n]oiCo0?nDo`3oU?l0o`3ooP03oookJP03o`3oGOoonf[o
oo]Z00oooo]Z00?o05ooo`3oGOoUo`00LooonfX2o`3o2A;ooo]Z00?oo`2_oookJ_oonfX00_oonfX0
2?oo06Oooo]Zo`3oH?l0of3o0;Oooonj0?oonf[oK`3o0ooonfX00ooo0?;oo`25oookJP07oookJP03
oooR0?oonf[ooo]Z00;oEOl000Ko0;Koo`3okol0onoooo]Zool0@Ol0@_l2oookJP;oog@000?oon<0
omGo0?oEo`000_oo09000ooonf[o0?lHoookJP02oolT00;ooo]Z0_oo7P000omE0?oo0?lfo`1Go`02
oomA0007on?o0?ooJ03oo`2hool0^?l0oi7oo`03oookJP02o`3oD`03oookJ_l0on3oo`3`00?ol`3o
00?ooe<0oookJ_oo07<00_oo07<2o`0go`09ool0cOoonf[o0?mIo`3oFOo00?oo09;ooookJ_oJo`3o
o`0n00Gooo]Z00?oonh0oookJ_lX0?l00_ook0000ooo7P3oo`40ool10002ool030?ooo]Z0_oo0:`3
oookJP;o09go0_l0;Ol2oomD00;oohH00_lVo`001?oo0=_ooo]ZoookJ_oonfX2oo40o`;ooo]Z00Co
04Soool0b?oo0<Soo`380_oo5P001?oonf[o7Ol0oago0?lMo`02oookJP?o0?m/00?ooo]ZooKo0?of
o`000_ofo`07oookJPWo09ko2_oonfX6o`2No`Wooo]Z0_ofo`02oookJP?o0?m/00?ooo]Zoago0?lM
o`000_oonfX01?l0ob_ooaH0ool0b?oo0<P2o`18o`;ooo]Z00?ol@3ooookJ_oonfX00_oonfX00ooo
0=_o9_l0obKo0002oon600;ooe@00_l0;Ol00ol0WOoo9?l0oookJP02oookJP;oo`2/0ooonfX01Ol0
A?ooo`0<ool10?oo0@3ooah000;oon`000Co:03ooookJ_ookP3oonh01?oonfX01Ooo03kof_l0oook
J_l0T_oo0?lU00;o0?mI00Kooo]Zool0cOl0=ooo03Ooooo50?oo07<2oookJP;ooe<000Col`3oool0
l?oo0?3o0?oP0_oonfX01?l0oe?ooo]ZoookJ_l0oi42ool0^006oomX0?oSo`3ooo]ZoomA0?l0Eooo
0?lf0_mE0?l02?oo7P3ooo]ZoookJ_oonf[oob@0oookJ_l0oaSooo]Z0_oo09000ooio`3oeOl0ool0
D@02oooS00;ooo]Z00?o04;oool0@OoonfX00_l0onl00ooo08KoEOl0oookJP02oookJP;oon801ooo
nfX3ool0lP;ooo]Z0_m_0?l2oonj00;o0?mP00?ooo]Zool0Iooo06L00ooonfX00ooo0:oooo]Zoook
JP0@oookJP03o`3o2Ooonf[ooo]Z03;ooo]Z0014oookJP;o0?l94OoonfX2ool0[`;ooo]Z0ooo06L0
0ooonf[o0?mPoonj0002oonj00;oK`3o0_oonfX00ooo0?;oo`25oookJP06oookJP?oon8000?ooo]Z
oeGo0?mEo`000_m4o`000ol0ooko0;3oo`2`o`02o`2`o`08oookJ_oUo`3oon<0oooS0?oo057o0?mM
ooWo0?oo0902onGo0003o`3o6?oonf[oob@000;ooo]Z0_oo7P02oeD0o`07o`1GooooD@3ooe40oolX
0?l03oooo`2ho`3ooP02o`0?o`CoiOl000Ko0?mMonGo0?oUo`3ol`3oo`0?ooooD`02oookJP04ool0
Loooa@3o03Ooo`0go`;oo`000_l0oeT00ooUo`3o0;3oo`2`o`04o`2`o`;ooo]Z00CoolT0ooo^0?l0
o`co0?l/0_ook0001?l0/?oo0?ono`3oo_l0ooh3o`2`o`Co00oo0_oUo`001?l0WOooocP0o`0]ool0
;Ol2oomD00;oohH00_lVo`04oookJP;ol@3o1ooo00001?oonf[o7Ol0oago0?lMo`03oolX00?oU?l0
0_ofo`06oookJP?o0;3o0ol0W_l3oookJPCo00003ooonfX4o`2No`03oookJ_ooN@3ooo]Z00Gooo]Z
0oofo`000ooonf[o0?m/o`3oK002onGo00;o7Ol000Cooo]ZoolF0?oo5P3ooaH00_oo0<P2o`18o`05
oookJ_oa0?ool@3ooookJ_oo:0000_nDo`03obKo0003oiCo0?oo:03oolT000;o02go0_l0WOl00onD
o`3oobP0oolX0002ool0[0Cooo]Z0_oo00`01_oo0@3o00ooo`0?ooook03o:03ooookJP;oonh01?oo
nfX2ool0?P03oookJ_l0T_oo09;o00;o0?mI00?oiOl0o`3o[Ol0ojd01?l0ojd3oiCo0005o`3o[OnD
o`3oU?l0o`3oh?l0/?l00_l0oe<3o`3oG@04ool0^?l0Gooo0?mMo`3oG@;ooe4000Ko05OooookJ_oo
:03ooo]ZoolN0?oonfX6ool000;oo`2@00GonOl0ool0DOooh`3oon<0oomd0004ool000CoolT000?o
0?l<ooo90?oob@000_oob@03oolX00?ooo]Z0_l03ol3o`1Oo`;oolT01?nDo`001Ol0ojgoU?l0oiCo
0?nDo`3o0?on00?ooo]Z00?o0?mMoookJ_oonfX03ooonfX00ol0Gooo0?mMo`3oG@02o`3oGG7ooo]Z
0_l0o`TAoookJP;oo`2_0ooonfX2ool0I`03oookJ_l0of3o0?mP00;ookX00_m_0?l2oookJP;oo`3b
00?oo`25oookJ_oonfX01OoonfX2oooR0004oookJ_mEo`3oEOl0oeGo00;o0?o_0_oonfX2o`12o`;o
oo]Z00Koog@0oooS0?oo057oeOl0ooWo0?oo0902oookJP05o`3o6?oonf[oob@0oolT0?oonfX00_oo
7P02oeD0o`03o`3o=_l0Eooooe4000;ohol00ooo0;P01Ol0oi7ooo]Zo`3oDol0oe?ooo]Z00;o0?oP
00Coo`3`oo<0oooc0?oooe<00_oonfX2ool0L`04ooo50?l0=oooo`3=ool0c@;o0?mI00Go`03oo`2B
ool0T_oof_l0ool0?P05oookJP;oonh000Kooo]Zooo/0?ook03ooah0oh_o0?oo0@02ool030?ooo]Z
0_oo0:`3oookJP;o09go00CoocP0o`0]ooooE03ooe@00_ooQP02obKo0004ool0fooonf[ooo]Zoook
JP;ol@3o0_oonfX00ol0B?ooo`38ool0b003oolF0004oookJ_lMo`3o7Ol0oago00;ooo]Z0_l0of`0
1?oonf[om_l0ooKo0?ofo`07oookJPGo09ko0_oonfX4o`00013ooo]Z1?l0W_l8oookJP;om_l00_oo
nfX2o`3oK003oookJ_lMo`3o7Ol000;ooo]Z0_oo5P02ool0b0;o04So0_oonfX01?oa0?oooo]Zoook
J_oonfX2ool0f`;o9_l000SoohH0o`07ooooE03ooe@0o`0]oooo>03o09goobCo00;ooo]Z0_oo0:`4
oookJP05o`14oooo00coo`40ool10?oo7P000_ook0000olX0?oooo]Zooo^0005oookJP07ool0?_oo
nf[o09;oo`2Booo00?oo0?mIoookJP02ool0c@05o`0gooooa@3oo`1cool0LooonfX00_ooD`02oo<0
o`08ool0l?l0on3o0?oPoookJ_l0oe?oo`0KoookJ_l0oi42ool0^006oon<0?oSo`3ohol0oomA0?l0
Eooo0?lf0_mE0?l01_oo7P3ooo]ZoookJ_oonf[oob@0oookJP;o0?lH0_oo09000ooio`3oeOl0ool0
D@02oooS00;ooo]Z0_l0@_l2oookJP04o`3okooo08KoEOl0oeGo00;ooo]Z0_oohP08oookJP;oo`3b
0ooonfX00om_0?oookX0oonj0002o`3oH003oookJ_oo06Ooo`1W00?ooo]Z0_oo0:lAoookJP03o`3o
2Ooonf[ooo]Z03;ooo]Z0013oookJP;o0?l94OoonfX2ool0[`?ooo]Z0_oo06L2oookJP03o`3oH?oo
^P3ookX000;oK`3o0_oonfX2ool0lP03ool0QOoonf[ooo]Z00Gooo]Z0_oohP02oookJP;oEOl000?o
A?l0o`3oo_l0/?l01?l0/?l01_oUo`3oog@0oooS0?ooh`3o0?mMo`3ho`;oo`2@0_oUo`001?oonf[o
0;3ooolT0?oonfX2oolN0003oomi0?mE0?ooogT000?ooe4000Cohol0o`3o[Ol0ooko0?on1?l03ol2
onGo0009o`3oGOoUo`3ol`3ooo<0ooooD`3o00oooookJ_oo07?oolD000?o03Oo00Coo`00o`3oFOl0
oeWo0?mI1_l0/?l01_oUo`3ooo]Zooo90?ookP3oolT0o`3o30;oon`000?o0;3oo`3oo_l0ooh00_l0
ooh2o`2`o`Co00oo0_oUo`02o`2Mo`;o02go0_ooE002oon600;o9_l000Coo`3KoookJ_oonf[ooo]Z
2Ooo00001Ooonf[o7Ol0oago0?lMo`3ooo]Z00?oobP000?o0;3ooiCo0?ofo`000ooonfX6o`2`o`So
oo]Z1?l0000BoookJPCo09ko00?ooo]ZodCo0?oonfX00ooonfX3ooKo0003oookJ_oUo`3oiOl000;o
iOl00_lMo`000ooonf[ooaH0oolF0003ool0b0;o04So00?ooo]Zoo40oooonfX01?nDo`000olVo`3o
olT0ooo90003ooo90003o`0]oooo:03oobP000?oobP000?ooo]Zool0[?oo0:`00ooonfX00ol0A?oo
o`0<ool10002o`0?o`;oon`000?ooo]Zooo^0?ookP001?oonfX2ool0?P06om[o0?oonf[o09;ool00
ool0oeWoiOl01Ol0ojd01Ol03oooU?l0oiCo0?nDo`3o0?n]00;oU?l00_l0on000ooonf[o0?mConGo
0002o`3oG@;oo`2h0_l0oed2oomA0005o`1Gool0ocKoobP0oookJ_oo7P001ooo0002ool0T005ooWo
0?oEo`3oolT0oooS0?ooM0001?oo0005ooo90005o`3o3?oob@3oolT0ooo90?l0ojd00_oo:0000ooo
nf[oolT0ooo90002ooo900?o05oo0_oob@001Om4o`3oU?l0oiCo0?nDo`3o0?n]00?oU?l000Go0?on
oookJ_oonf[ooo]Zo`3oG@0>oookJPCo0?mM00Co05ooo`3oGOl0oego0?mML?oonfX2o`3o2A;ooo]Z
0_oo0:l3oookJP;oo`1W00?ooo]Zo`3oH?l0of000_oo^P001?m_0?oooo]ZoookJ_oonfX2ool0lPSo
oo]Z00?oon80oookJ_oonfX00_mEo`001?l0]_oo0?o_o`3okooonfX2o`12o`;ooo]Z0_ooM0000ooo
h`3oo`1AomGo0002ool0T003oookJ_l0oaSooo]Z00;oob@00_oonfX01Ooo7P3ooo]ZoeD0ool0ocKo
05Oo00;ooe4000Kohol0oomX0?oo0;Soo`2ho`3oTOoo00<3o`3oD`;o0?oP00Koo`3`oo<0oooc0?oo
l`3ooomC0?oonfX2ool0L`04ooo50?l0=ooo03Ooool0c@?o0?mI0_l0T_l00ooonf[oo`0nool0?P04
oookJP;oonh000Kooo]Zooo/0?ook03ooah0oh_o0?oo0@02ool030?ooo]Z0_oo0:`3oookJP;o09go
00KoocP0o`0]ooooE03ooe@0o`07ooooQP02obKo0004ool0fooonf[ooo]ZoookJP;ol@3o00?ooo]Z
o`18ool0B?l00_oo0<P2oolF00;ooo]Z0_lMo`02oookJP;o0?m/00Cooo]ZooKo0?ofo`3om_l01_oo
nfX3o`2No`Oooo]Z1?l0000CoookJP?o09ko1ooonfX2ooKo00;ooo]Z0_l0of`00ooonf[o7Ol0oago
0002oookJP;ooaH00_oo0<P2o`18o`03oookJ_oa0?ool@3o00?ooo]Z00Goo`3KobKo0?lVo`3ooo]Z
oon60002oomD00;o02go0_l0WOl3oookJP;oo`2/1?oonfX2ool03006ool10?oo7P3oon`0ooo/0?lX
0?oooo]Z0_ookP04oookJP06ool0?_oJo`3ooo]Zo`2Bool0obGo0?mI0_oonfX00ooo0<go03Ooo`0g
o`02ool0L`;ooo]Z0_ooD`003?oc0?ooo`3`ool0l?l0on3ooo]Zo`3oDooo01_ooo]Zo`3oTOn@o`3o
o`2hoon<00;ohol000?ooe40o`1Gool0Eol00_mE0?l01_oo7P3ooo]ZoookJ_oonf[oob@0oookJP;o
0?lH0_oo09000ooio`3oeOl0ool0D@02oooS00;ooo]Z0_l0@_l01_oo047ooo]Zo`3okol0onoo0;Ko
oeGo00;ooo]Z0_oohP08oookJP;oo`3b0ooonfX00om_0?oookX0oonj0002o`3oH003oookJ_oo06Oo
o`1W00?ooo]Z0_oo0:lAoookJP;o0?l9<ooonfX004?ooo]Z0_l0o`TAoookJP;oo`2_0ooonfX2ool0
I`03oookJ_l0of3o0?mP00;ookX00_m_0?l2oookJP03ool0l_oo08Goo`2500Kooo]Z0ooohP02oook
JP;oEOl000?oA?l0o`3oo_l0/?l01?l0/?l01ooonf[oon<0oooS0?oo057o0?SoooWo0?oo09000_oU
o`000ol0oaSooo]Zo`2`o`02oookJP;ooah00_mE0?l01Ol0Eooooe40oomA0?oSo`3o0?n]00?o0?on
0ol03ol00ol0oe?oobP0o`3oG@02onGo0003oo<0ooooD`3ooe<000;ooo]Z00Soo`1cooo50?l0=ooo
03Ooool00?oonf[o0?ono`3oF@Oo0;3o00SoiOl0ooo90?ookP3oonh0ooo90?l0obcoon`0o`2`o`Go
0?on0_l0/?l4o`0?o`03oookJ_l0WOoo09go00;o02go0_ooE002oon600;o9_l000?oo`3KoookJ_oo
nfX02ooo0002oago00;ooo]Z00?o0?m/o`2`oooo:0003?l0/?l8oookJQ7o0;7o1ooonfX2oomi00?o
09ko1_oonfX00oofo`3oiOl0onGo0002onGo00;o0?mM0_lMo`000ooonf[ooaH0oolF0003ool0b004
o`18oooonf[ooo]Zoo40o`?oU?l01_oob@07oolX00;ooo]Z00?oo`2/oookJ_oonfX00_oonfX00ooo
00co04Cooh_o0002o`0?o`03ooo/0?lX0?oooo]Z00;oonh01?oonfX2ool0?P03oookJ_ooN@3oogT0
00;o0?mI00?oogT0o`3o[Ol0ojd00_l0ojd01?l03ooo0?n]oiCo0?nDo`05o`3o[@03oookJ_l0oe?o
0?mC00;o0?mM0_oo0;P3o`3oG@;ooe4000?o05OooolX0?mE0?l00_oo7P06ool000;oo`2@00GonOl0
omGo0?oob@3oon<0oomd0005ool000CoolT000Go0?l<ooo90?oob@3oolT0o`3o[@02oolX0003oook
J_oob@3oolT000?oolT00_l0Gol3odCo00?oU?l000Go0?n]o`0?oonDo`3oU?l0o`3ooP03oookJP03
o`3oGOoUo`3oiOl000;oiOl02_oonfX4o`3oG@04o`1Oool0oego0?mMo`3oGG3ooo]Z0_l0o`TAoook
JP;oo`2_1?oonfX01_oo06Oooo]Zo`3oH?l0of3o0;Oooonj00;oK`3o0_oonfX2ool0lP03ool0QOoo
nf[ooo]Z00Gooo]Z0_oohP02oookJP;oEOl00ol0onl00ooonf[o04;oo`12o`02oookJP06oomd0?oo
h`3oon<0omGo0?oio`3oo`2@0_oonfX01Ol0oaSooo]ZoolT0?oo903ooo]Z00;ooah00_mE0?l2o`1G
o`04oomA0?oSo`3ohol0oon<00;oo`2h00Go0?nAoookJ_l0oe?o0?mCoookJP02o`3oh004ool0l?oc
0?ool`3ooomC00;ooo]Z0_oo07<01?ooa@3o03Ooool0cOoonfX2o`3oF@05ol00ool0T_oooo]Zom[o
0?oo03h01OoonfX00oookP3ooo]ZobP0o`02ooo/0005oolN0?oo0@3oo`40ool03?l0A?l00ooonfX2
ool0[0;ooo]Z0_l0WOl01_oo>03o02gooookJ_ooE03o00Oooon600;o9_l000Coo`3KoookJ_oonf[o
oo]Z0_oa0?l00ooonf[o04Soo`18o`02ool0b0;ooaH00_oonfX2oago00;ooo]Z00?o0?m/oookJ_oo
nfX00_ofo`05oookJPCo09ko2OoonfX@o`2ao`Wooo]Z1?l0W_l6oookJP;om_l000Cooo]Zo`3oK?l0
ofcooo]Z0_lMo`02oookJP;ooaH00_oo0<P00ol0B?oooo]ZoookJP02oo40o`?ooo]Z00?oo`3KobKo
0?lVo`000_ooQP02oomD00;o02go0_l0WOl3oookJP03ool0[?oonf[ooo]Z00;ooo]Z00?o04Coool0
3?oo0@000_oo7P001Oook03o0?l/obP0oooonf[oonh000Cooo]Z0_oo03h00ooonf[o09;oo`3o9@02
o`3oF@06oookJ_oo0<go03Ooo`0gooooa@3oo`1c0_oonfX2oomC0005oo<0oooo0?3oo`3`o`3oh?oo
nfX00_l0oe<2oookJP03o`3oTOoo0;Soo`2h00;ohol00_ooD@000ol0Eooo0?lfoeD0o`02oolN00;o
oo]Z00Coob@0oookJ_l0oaSo0?lH0ooo09001?oEo`3oo`1AoooS0?ooh`03oookJP03o`12oooo047o
oo]Z00;o0?o_00Co0;KooeGo0?oonf[ooo]Z0_oohP08oookJP;oo`3b0ooonfX00om_0?oookX0oonj
0002o`3oH004oookJ_oo06Ooo`1Wool0I`;ooo]Z0_oo0:lAoookJP;o0?l9<ooonfX004?ooo]Z0_l0
o`TAoookJP;oo`2_0_oonfX3ool0I`04oookJ_l0of3ookX0oonj00;oK`3o0ooonfX00ooo0?;oo`25
oookJP06oookJP;oon800_oonfX2oeGo0003odCo0?l0ooko0;3o00Go0;3o00Goog@0oooS0?ooh`3o
o`1Ao`3ho`02ool0T003onGo0?l0oaSooo]Z00;o0;3o00Oooo]ZoolN0?oo7P3oogT0oeD0ooooN@3o
05Oo00;ooe4000?o0?n]o`3oo_l0ooh00_l0ooh01ooonf[o0?mCo`0?oooo:03o0?oPonGo0?oo0?00
0_oc0?l01OooD`3o00oooookJ_oo07?oolD000;o03Oo00Goo`00oookJ_l0oeWo0?onol00o`07o`2`
o`05ooo90?ookP3oonh0ooo90?l0o``00_ook005o`3ooP;o0;3o1Ol03ol01?oonf[o09goo`0]ool0
;Ol2oomD00;oohH00_lVo`000ooo0=_ooo]ZoookJP0;ool000;o7Ol000?ooo]Zo`3oK?l0/?l03_l0
/?l5oookJPSo0;7o00?o0000oookJ_oonfX01_oonfX8o`2ao`;ooo]Z1?ooN@001Om4o`3o09koo`2N
ool0W_oo0?on00?ooo]Z1?oUo`04o`3oG@;o7Ol000?ooo]ZoolF0?oo5P000_oo0<P2o`18o`;ooo]Z
00?ol@3ooiCo0?oob@001Ooob@08oolX0004o`3oGOoonf[oo`2/ool0[0Cooo]Z00Coo`0<ool10?n;
o`3o00oo0_ook0000ooonf[oonh0ooo^0004oookJP03ool0?_ooN@3oogT000;oogT00_l0oeT00ooo
N@3o0?n]o`3o[@02o`3o[@03o`0?ool0ojgo0?n]00?o0?n]00Co00ooo`3o[Ol0ojgooo]Z0_l0oe<3
o`3oG@04ool0^?l0oego0?mMo`1Oo`;ooe4000?o05OooookJ_nDo`000ooo:005ool00005oookJ_oo
093onOl0omGo0?oob@000_ooh`05ool000CoolT000Ko0?l<ooo90?oob@3oolT0o`3o[Ooo:003oook
JPCoolT00_l0Gol4odCo00;oU?l000Co0?n]o`0?oonDo`3oU?l01?oUo`000ol0oegoiOl0onGo0002
onGo00_ooo]Z0ol0oed01?l0Gooo0?mMo`3oGOl0oee`oookJP;o0?l94OoonfX2ool0[`?ooo]Z0_oo
06L00ooonf[o0?mPo`3oH002oonj0004ofl0oooonf[ooo]ZoookJP;oo`3b00?oo`25oookJ_oonfX0
1OoonfX00ooohP3ooo]ZoookJP03oeGo00;o0?o_00Gooo]Zo`12ool0@_oo04;ooookJP02oomd0003
oooS0?oo057oeOl000;oo`2@00?ooo]Zo`3o6?l0oaP00_oo90001ooonf[ooah0oolN0?oonf[oE@3o
o`3o=_l0Eol00_ooD@001_oSo`3oofP0ool0^?oo0;So0?nAool00`?o0?mC0_l0on02ool0l0;ol`3o
00Gooe<0oookJ_oo07?oo`1cooo50002o`0go`04ool0cOl0oeWo0?mIol00o`;o09;o00?ooo]Zool0
?_oo03h01?oonfX00oookP3ooo]ZoookJP02ooo/0005oolN0?oo0@3oo`40ool03?l0A?l00ooonfX2
ool0[0?ooo]Z00Oo09gooolh0?l0;Ooo02gooomD0?l01oooohH000;o9_l000Coo`3KoookJ_oonf[o
oo]Z0_oa0?l00ooonf[o04Soo`18o`02ool0b004oolF0?l0ob_ooo]ZoookJP;o7Ol000Cooo]Zo`3o
K?l0ofcooo]Z0_ofo`05oookJP?o09ko1ooonfX8o`2ao`03o`000?oonf[ooo]Z00Oooo]Z1ol0/Ol7
oookJPCo09ko1OoonfX2ooKo0004oookJ_l0ofco0?m/oookJP;o7Ol00_oonfX2oolF0003ool0b?l0
B?oo04So00;ooo]Z0_oa0?l2oookJP;oo`3K0_lVo`000oooQP3o00OooomD0003o`0]o`04o`2Moooo
nf[ooo]ZoookJP;oo`2/1?oonfX2ool03007ool10?oo7P3oon`0ooo/0?lX0?oooo]Zooo^0005oook
JP07ool0?_oonf[o09;oo`2Booo00?oo0?mIoookJP02ool0c@05o`0gooooa@3oo`1cool0LooonfX0
0_ooD`02oo<0o`05ool0l?l0on3o0?oPoookJ_l0oe<00_oonfX01?l0oi7oo`2hool0^?ooS002on?o
0003oomA0?l0Eooo0?lf00;oE@3o00?ooah0oookJ_oonfX00_oo90000ooonf[o0?lHoookJP02ool0
T005oookJ_oo057oo`1AoooS0?ooM0000_oonfX00ol0@_ooo`11oookJP02o`3ok`03o`2foomEo`3o
oo]Z00;ooo]Z00?oon80oookJ_oonfX01_oonfX3ool0lP;ooo]Z00?oK`3ooonj0?oo^P000_l0of00
1?oonf[oo`1Wool0Iooo06L2oookJP;oo`2_4OoonfX2o`3o2C?ooo]Z0012oookJP;o0?l94OoonfX2
ool0[`?ooo]Z0_oo06L2oookJP03o`3oH?oo^P3ookX000;oK`3o0_oonfX2ool0lP03ool0QOoonf[o
oo]Z00Gooo]Z0_oohP001Ooonf[oA?l0oeGo0?mEo`3oA?l000Oo0;3o0_ooh`000ooo057o0?SoooWo
0002ool0T003onGo0?l0oaSo0;3o00;o0;3o00?ooo]ZoolN0?oo7P000_mE0?l01Ol0Eooooe40oomA
0?oSo`3o0?n]00?o0?on00Oo0?n]oookJ_l0oe?o0?mCoolX0?oUo`3oo`3`00;ol`3o0_ooD`001?oo
nf[oo`1cool0Loooa@02o`0go`04ool00?oonf[o0?ono`3ooPOo0;3o00GoiOl0ooo90?ookP3oonh0
o`3o3002ooo/00Ko0?on0_l0/?l4o`0?o`06oookJ_l0WOooocP0o`0]oooUo`3ooe@00_ooQP02obKo
0004ool0fooonf[ooo]ZoookJP_oo`000_oonfX2o`2`o`?o0?l<2_l0/?l4oookJPGo0;7o0ooonfX4
o`0000kooo]Z1?l0/Ol3oomi00?oA?l000?o0?ono`2Nool0W_l00_oonfX4onGo00Ko0?mM0_lMo`00
0ooonf[ooaH0oolF0002ool0b0;o04So00?ooo]Zoo40oooa0?l01_oob@08oolX00;o05oo00?ooo]Z
ool0[?oonfX00ooonfX01_oo00coo`40oh_o0?oo7P3o0?l/ooo/00;ooo]Z0_ookP03oookJP03ool0
?_ooN@3oogT000?oogT000?o0?mIoomi0?ooN@002Ol0ojd01?l03ooo0?n]o`3o[Ol0on02o`3oD`;o
0?mM00?o05ooool0^?oo0;P00_l0Gol2oomA00;oobP000CoU?l0oolX0?oo:03oobP01Ooo00001Ooo
nf[oo`2@ooWo0?oEo`3oo`1A00;oon<01_oo0003ooo90006o`3o3?oob@3oolT0ooo90?l0ojgoobP0
0ooonfX4ooo90003ool0l_l0GoooolT000?oA?l00_nDo`001?l0ojgo00oooiCo0?nDo`05onGo0004
o`3oGOoUo`3oiOl0onGo00_ooo]Z0ol0oed01?l0Gooo0?mMo`3oGOl0oee_oookJP;o0?l94_oonfX2
ool0[`?ooo]Z0_oo06L01_oonf[o0?mPo`2goooo^P3ooo]Zofl0o`;ooo]Z0_oo0?800ooo08Gooo]Z
oookJP06oookJP03oooR0?oonf[ooo]Z00;oEOl000Co0;Koo`3okol0onoooo]Z0_l0@_l2oookJP05
oomd0?ooh`3oon<0omGo0?oio`000_oo09000ooonf[o0?lHoookJP02oolT0005oookJ_oo7P3ooah0
oookJ_mE0?l00_l0Eol01?ooD@3ohol0on?o0?ooS002ool0^005o`3oTOoonf[o0?mCo`3oDooonfX0
0_l0on001?oo0?3ol`3ooo<0ooooD`02oookJP06ool0Loooa@3oolD0o`0goooo0<gooo]Z0_l0oeT0
0oo00?oo09;ooookJP02ool0?PCooo]Z0_ookP001?oonf[oon`0ooo/0?oo7P02ool100;oo`0<0ooo
nfX2ool0[0?ooo]Z00Co09gooolh0?oo>03o02go0_ooE0001?ooQP3o9_l0obKo0?oo0=/3oookJP;o
l@3o0_oonfX01_l0B?ooo`38ool0b?oo5P3o0?l[oookJP;o7Ol00_oonfX00ol0ofcooo]ZoookJP02
ooKo00Cooo]Z0ol0W_l6oookJPGo0;7o0ooonfX4o`0000oooo]Z1?l0/Ol6oookJP?o09ko1OoonfX2
ooKo0004oookJ_l0ofco0?m/oookJP;o7Ol000Gooo]Zo`3o:ooo5P3ooaH0ool0b002o`18o`03oook
J_oa0?ool@3o00?ooo]Z0_oo0=/01OlVo`3ooo]Zoon60?l01ooooe@000;o02go0_l0WOl3oookJP03
ool0[?oonf[ooo]Z00;ooo]Z00?o04Coool03?oo0@000_oo7P000oook03o0?l/oookJP02ooo^00Co
oo]Z00Koo`0nom[o0?oonf[o09;oo`3o9Ol0oeT2oookJP05ool0cOl0=ooo03Ooooo50?oo07<00_oo
nfX2oomC0009oo<0oooo0?3oo`3`o`3oh?oonf[o0?mCool06ooonf[o0?nA00;oo`2h00Kooh`0on?o
0?oSo`3ooe40o`1Gool0ocH2oeD0o`08oolN0?oonf[ooo]ZoookJ_oo903ooo]Zo`3o6?oonfX2ool0
T005o`3hoooEo`3oo`1AoooS0?ooM0000_oonfX2o`12o`;ooo]Z00Co0?o_o`2foomEo`3oEOl00_oo
nfX2oooR00Oooo]Z0ooo0?82oookJP06ofl0oooo^P3ookX0oonj0?l0of3ooo]Z0ooo06L2oookJP;o
o`2_4OoonfX2o`3o2C?ooo]Z0012oookJP;o0?l94OoonfX2ool0[`?ooo]Z0_oo06L00ooonf[o0?mP
oookJP02oonj00;oK`3o0_oonfX00ooo0?;oo`25oookJP06oookJP?oon800_m4o`000omEo`3oA?l0
o`3ooP06o`2`o`0:oomd0?ooh`3oon<0ool0DOl0n?oonOl0ool0T?oUo`3o0?lHoookJP?o0;3o0_oo
7P001?oonf[oE@3oodCo0?l0Eol2oomA0003o`3o[Ol0ooko0?on00;o0?on00Oo0?n]ool06ol0oe?o
0?n]o`3oh?oUo`3oo`3`00;ol`3o00Gooe<0oookJ_oonf[oo`1cooo50002o`0go`04ool00?oonf[o
0?ono`3ooPSo0;3o00Kooo]Zooo^0?ookP3oolT0o`3o;?ook006o`3ooP?o0;3o1?l03ol2o`2Mo`03
o`0]oooonf[ooe@000;oohH000?ooo]ZobKo0?oo0=/00ooonfX2oo40o`[oo`001?l0/?l4o`3o30So
0;3o0_oonfX3o`2ao`Sooo]Z1?l0000AoookJP?oogT00om4o`04o`3ooP;o09ko0_oonfX00ooUo`3o
0?mMo`3oG@03o`3oG@?o05oo0_lMo`000ooonf[ooaH0o`3o:`02ool0b005o`18oooonf[ooo]Zoo40
ool0ojd01?oob@02o`3o30KoobP00onDo`000ooonf[oo`2/ool0[004oookJP07ool03?oo0@3oRol0
oolN0?ook03o:03ooookJP02ooo^00Cooo]Z00?oo`0noomi0?ooN@000_ooN@02o`3oF@;oogT00ol0
ojd00ol03ooo0?n]o`3o[@02o`3o[@06o`0?ool0ojgo0?n]o`3oh?oonf[o0?mC0ol0Gol2ool0^0;o
05oo00GoobP0oomA0?oo:03oobP0oiCo0003oolX00Goo`0000Gooo]Zool0T?oio`3o0?Soooo90002
oooS00Koo`000ooob@001Ol0o`co0;3oooo90?oob@3o0?n]00CoU?l000Cooo]Zooo90?oob@3oolT0
0_oo0?801?oob@3oA?l0odCo0?m4o`02oiCo0005o`3o[Ol03oooU?l0oiCo0?oo06L01?oUo`001?l0
oegoiOl0onGo0?oUo`0;oookJP?o0?mM00Co05ooo`3oGOl0oego0?mMKooonfX2o`3o2A7ooo]Z0_oo
0:l4oookJP06ool0Iooonf[o0?mPo`3oH?l0]ooookX00_m_0?l2oookJP;oo`3b00?oo`25oookJ_oo
nfX01OoonfX2oooR00;ooo]Z0_mEo`02o`3ok`;ooo]Z0_l0@_l02Ooonf[oog@0oomd0?ooh`3oo`1A
omGo0?oio`3oo`2@oookJP02o`3o6009oookJ_oo903ooo]ZoookJ_oo7P3ooo]ZoeD0ool0ocKo05Oo
00;ooe4000Oohol0oomX0?oo0;Soo`2ho`3oTOoo00?oo`0K00;o0?mC00CobP3oo`3oh?oo0?3oo`3`
0_oc0?l01OooD`3ooo]Zool0Looo07?oolD000;o03Oo00Coo`3=oookJ_l0oeWo`03o0_l0T_l3ool0
?PCooo]Z00Coonh0oookJ_l0obcoon`00_oo7P001?oo0@3oo`0<ool03?l0A?l2oookJP?oo`2/0_oo
nfX2o`2Mo`04oolh0?l0;Ooooe@0oomD00;oohH000?o9_l0ool0fooo0=/00_oonfX2oo40o`;ooo]Z
00?o04Soool0b?oo0<P00_oo5P001?oonf[o7Ol0oago0?oonfX2o`3oK003oookJ_ofo`3om_l000Co
oo]Z0ol0W_l5oookJPCo0;7o1ooonfX4o`0001;ooo]Z1?l0/Ol5oookJP?o09ko1?oonfX2ooKo0004
oookJ_l0ofco0?m/oookJP;o7Ol000?ooo]Zo`3o:ooo5P000_oo0<P2o`18o`03oookJ_oa0?ool@3o
00?ooo]Z00?oo`3KobKo0?lVo`000_ooQP001OooE03o02goo`0]ool0;Ooo09go00?ooo]Z0_oo0:`4
oookJP;oo`0<00Ooo`40oolN0?ook03o0?l/obP0oooonf[oonh000Cooo]Z0_oo03h00ooonf[o09;o
o`3o9@02o`3oF@06oookJ_oo0<go03Ooo`0gooooa@3oo`1c0_oonfX2oomC0005oo<0oooo0?3oo`3`
o`3oh?oonfX00_l0oe<01Ooonf[o0?nAo`3oTOoo0;Sooh`000;ohol00_ooD@000ol0EoooE@3ooeD0
o`02oolN00;ooo]Z00Coob@0oookJ_l0oaSooo]Z0_oo09001Ooio`3oeOl0ool0DOooh`3oog@000;o
oo]Z0_l0@_l2oookJP04o`3okooonP3oEOl0oeGo00;ooo]Z0_oohP07oookJP?oo`3b0_oonfX2ofl0
o`;ookX000?o0?mPoookJ_oo06L00_oo06L3oookJP;oo`2_4?oonfX2o`3o2C?ooo]Z0012oookJP;o
0?l94?oonfX3ool0[`?ooo]Z00Coo`1WoookJ_oonf[o0?mP0_oo^P02ofl0o`;ooo]Z00?oon@0ool0
l_oo08D01ooonfX2oooR00;ooo]Z0_mEo`000om4o`3o0;3oo`2`o`05o`2`o`05oomd0?ooh`3oo`1A
onGo0?oio`000_oo0902o`3o60?o0;3o00?ooo]ZoolN0?oo7P000_mE0?l2o`1Go`;ooe401Ol0ooh0
1_l0ojgo0?mCo`3oDol0on3oiOl0ool0l0;ol`3o0_ooD`001ooonf[oo`1cool0Loooa@3o03Ooool0
0?oo0<d00ol0ooh00ol0T_oo0;3oo`2`o`05o`2`o`05oookJ_ookP3ooo]Zooo90?ook0001ol0ooh0
0ol0o`co0;3oo`0?o`03o`0?o`04o`3oo_l0WOoo02goo`0]o`;ooe@000CoohH0oookJ_lVo`3oo`3K
0ooonfX2oo40o`;o05oo2?oo0004o`2`o`;oolT00ol0o``7o`2`o`04oookJ_l0/Ooo0;7oo`2ao`[o
oo]Z3oooX`05oookJP?oogT00om4o`06o`3ooP03oookJ_l0W_oooo]Z00Go0?mM1Ol0Gol01_lMo`3o
oo]ZoookJ_oo5P3ooo]Zool0b0;o04So0_oonfX2o`3o[@03ooo90?l0o`co0?l<00?o0?l<0_oo:006
oiCo00;ooo]Z00?oo`2/oookJ_oonfX00_oonfX01?oo00coo`40oh_o0?oo7P02ooo/0003oookJ_oo
kP3oonh000Cooo]Z0_oo03h3oomi00;o0?mI00?oogT0o`0?ool03ol00ol03ol4o`3o[@06o`0?ool0
ojgo0?n]o`3oh?oonf[o0?mC0ol0Gol2ool0^0;o05oo00GoobP0oomA0?oo:03oobP0oiCo0003oolX
00Goo`0000Sooo]Zool0T?oo093o0?Soooo90?l0o`coon<0oomd00Goo`0000Go0?o_ooo90?oob@3o
0?l<o`2`o`02ooo90003o`3o[OnDo`3oU?l000;oU?l000Cooo]Zooo90?oob@3oolT00_oo0?800ooo
b@3ooo]ZodCo0002odCo0004oiCo0?l0ojgo00oooiCo00;oo`1W1?oUo`001?l0GoooiOl0onGo0?oU
o`0<oookJP;o0?mM00Co05ooo`3oGOl0oego0?mMKooonfX2o`3o2A7ooo]Z0_oo0:l3oookJP;oo`1W
00?ooo]Zo`3oH?l0of000_oo^P001?m_0?oooo]ZoookJ_ooi002ool0lPSooo]Z00?oon80oookJ_oo
nfX00_mEo`001?l0]_oo0?o_o`3okooonfX2o`12o`;ooo]Z00Goog@0oooS0?ooh`3oeOl0ooWo0002
ool0T003oookJ_l0oaSooo]Z00;oob@000?ooo]ZoolN0?oo7P000_mE0?l01_l0ocKo05OooomA0?oo
D@3ohol0oon<00;oo`2h00Go0?nAoookJ_l0oe?o0?mCoookJP02o`3oh004ool0l?oc0?ool`3ooomC
00;ooo]Z00Koo`1cooo50?l0=ooo03Ooool0cOoonfX2o`3oF@;o09;o00?ooo]Zool0?_oo03h01?oo
nfX2ooo^0005oookJ_ook03oon`0oolN0?oo0@000_oo00`01?l0A?oooo]ZoookJ_oonfX2ool0[0;o
oo]Z0_l0WOl01?oo>03o02gooomD0?ooE002oon60003obKo0?oo0=_oo`3K00;ooo]Z0_oa0?l2oook
JP03o`18oooo0<Soo`3800;ooaH000Cooo]Zoago0?lMo`3ooo]Z0_l0of`00ooonf[om_l0ooKo0004
oookJP?o09ko1?oonfX4o`2ao`Wooo]Z00?o0000oonS0?ooX`003OooX`09oookJP?o0;7o1OoonfX2
o`2No`Cooo]Z0_ofo`001Ooonf[o0?m/o`3oK?oonf[o7Ol000;ooo]Z00Co0?l[oolF0?oo0<Soo`38
0_l0B?l00ooonf[ol@3ooo40o`03oookJP03ool0folVo`3ooo]Z00;oohH000?ooe@0o`0]ool0;Ol0
0_l0WOl3oookJP03ool0[?oonf[ooo]Z00;ooo]Z00?o04Coool03?oo0@000_oo7P001?ook03o:03o
oookJ_ookP05oookJP07ool0?_oonf[ooo]Zo`2Booo00?oo0?mIoookJP02ool0c@03o`0gooooa@3o
o`1c00;ooo]Z0_ooD`001Ooc0?ooo`3`ool0l?l0on3ooo]Z00;o0?mC00Oooo]Zool00ol0oi7oo`2h
oon<0?ooJ03ohol000;ooe4000?o05OooookJ_mE0?l00_oo7P02oookJP;oob@00_l0oaP2ool0T005
ooWo0?oEo`3oo`1AoooS0?ooM0000_oonfX2o`12o`;ooo]Z00Co0?o_oooj0?mEo`3oEOl00_oonfX2
oooR00Oooo]Z0ooo0?82oookJP;oK`3o0_oo^P000ol0of3ooo]ZoookJP02ool0I`?ooo]Z0_oo0:lA
oookJP03o`3o2Ooonf[ooo]Z037ooo]Z0012oookJP03o`3o2Ooonf[ooo]Z00oooo]Z0_oo0:l3oook
JP;oo`1W0_oonfX00ol0of3ookX0oonj0002ofl0o`;ooo]Z0_oo0?800ooo08Gooo]ZoookJP05oook
JP;oon800_oonfX2oeGo00So0;3o0_ooh`001_oo057o0?SoooWo0?oo093ooo]Zo`3o60Co0;3o00Ko
oo]ZoolN0?oonf[oE@3oodCo0?l0Eol2oomA00Ko0?on00Oo0?n]o`3oDol0oe?oiOl0o`3oh?oo0?3o
l`3o00?ooe<000?ooo]Zool0Loooa@000_l0=ol00ooo0<go0?ono`3ooP02o`3ooP?o0?l<1Ol0/?l2
ooo^0003oookJ_l0o`co0?on00Oo0?on00?o0?l<o`0?ool03ol00_l03ol2o`3ooP;o02go0_ooE000
0oooQP3ooo]ZobKo0002ool0f`;ooo]Z0_oa0?l3o`1Oo`03ool0b?oo003oo`0000Coo`001?l0/?l3
ooo900Co0?l<1?l0/?l2oookJP;o0;7o1OoonfX5o`0?o`Kooj<02?oonfX7oonS00?ooo]Z0om4o`08
o`3ooP05oookJ_l0W_oooo]ZoookJ_l0oed02?l0Gol01_lMo`3ooo]ZoookJ_oo5P3ooo]Zool0b0;o
04So00Cooo]Zoo40ool0ojgo0?n]1Ol0o``8oiCo00;ooo]Z00?oo`2/oookJ_oonfX00_oonfX2ool0
3006oookJ_oo7P3ooah0ooo/0?lX0?oooo]Z0_ookP03oookJP;oo`0n1?ooN@000ol0oeWoA?l0o`0?
o`05o`0?o`Co0?n]00Co00ooo`3o[Ol0on3obP3o0_l0oe<2o`1Oo`03oi3o0?oo0;So05oo00;o05oo
00Cooe40oolX0?oo:03oU?l00ooo:005ool00008oookJ_oo093oo`2@ooWo0?oob@3o0?l<oooS0?oo
:005ool00008odCo0?oob@3oolT0o`3o3?l0/?ooolT0odCo0?l0ojd4oiCo0004oookJ_oob@3oolT0
ooo900;oo`3b00?oolT0oookJ_m4o`000_m4o`001?nDo`3o0?n]o`0?oonDo`02ool0I`05oookJ_oU
o`3oiOl0onGo0?l0Gol00_oUo`0=oookJP;o0?mM00Co05ooo`3oGOl0oego0?mMKooonfX00ol0o`Wo
oo]ZoookJP0?oookJP;oo`2_1?oonfX02?oo06Oooo]ZoookJ_l0of3o0;Oooonj0?oonf[oK`3o0_oo
nfX2ool0lP03ool0QOoonf[ooo]Z00Gooo]Z0_oohP02oookJP;oEOl000Co0;Koo`3okol0onoooo]Z
0_l0@_l2oookJP07oomd0?ooh`3oo`1AomGo0?oio`3oo`2@oookJP02o`3o6004oookJ_oo903ooo]Z
oookJP;ooah00_mE0?l02_l0Eooooe40oomA0?oSo`3oofP0oi3o0?oo0;So0?nAool00ooonfX2o`3o
D`?o0?oP0_oc0?l2oomC0004oookJ_oo07?oo`1cooo500;o03Oo00Koo`3=o`3oFOl0oeWo`03oo`2B
oooonfX3ool0?P?ooo]Z0_ookP001Ooonf[o0?l/ooo/0?oo7P3oRol000?oo`0<0ooonfX2ool0[0?o
oo]Z00Go09gooolh0?l0;Ooo02gooomD0002oon60003obKo0?oo0=_oo`3K00;ooo]Z0ooa0?l01?oo
nf[o04Soool0b?oo0<P2oolF0005oookJ_lMo`3o7Ol0oookJ_l0of`00_oonfX00oofo`3ooo]Zoook
JP02oookJP?o09ko1OoonfX3o`2ao`Oooo]Z2?ooX`09oookJPKooj<01ooonfX3o`2ao`Gooo]Z0_l0
W_l4oookJP;om_l000Gooo]Zo`3oK?l0ofcooo]Zoago0002oookJP;ooaH00_oo0<P2o`18o`03oook
J_oa0?oooo]Z00;ooo]Z00?oo`3KobKo0?lVo`000_ooQP02oomD00;o02go00Go09gooookJ_oonf[o
oo]Zool0[004oookJP03o`14oooo00coo`4000;ooah000?oon`0o`3o;?oonfX00_ookP04oookJP06
ool0?_oJo`3ooo]Zo`2Booo00?oo0?mI0_oonfX00ooo0<go03Ooo`0go`02ool0L`03oookJ_ooD`3o
oe<000;ol`3o00Soo`3`o`3oh?l0on3ooo]Zo`3oDooo01_ooo]Zo`3oT@;oo`2h00OoofP0on?o0?oo
D@3ooe40o`1Gool0ocKoE@3o00;ooah00_oonfX2oolT00;o0?lH00Kooo]Zool0T?oio`3o0?Soool0
DOooh`02oomd0003oookJ_l0@_oo04;o00;ooo]Z00Co0?o_ool0Q_mEo`3oEOl00_oonfX2oooR00Oo
oo]Z00?oo`25ool0l_oo0?800_oonfX2ofl0o`;ookX000?o0?mPoookJ_oonfX00_oo06L3oookJP;o
o`2_4OoonfX00ol0o`Wooo]ZoookJP0aoookJP00@OoonfX2o`3o2A7ooo]Z0_oo0:l3oookJP;oo`1W
00Cooo]Zo`3oH?oonf[ookX00om_0?l2oookJP03ool0l_oo08Gooo]Z00Kooo]Z0_oohP02oookJP;o
EOl000CoogT0o`3oo_ooN@3o0?l<1?l0/?l01OooM03oon<0oooS0?oUo`3o0?So00;oo`2@00?o0?lH
o`2`ool0/?l00ol0/?l2oolN00;oE@3o0_l0Eol2oomA00Ko0?on0_l0oe<01Ol0on3oiOl0o`3oh?oo
0?3ol`3o00;ooe<000Kooo]Zool0Looo07?oolD0o`0goooo0<d5o`3ooP;o0?l<00?o0;3oo`3o3?l0
/?l00_l0/?l2ooo^0003oookJ_l03ooo0?on00Oo0?on00?o0?l<o`0?ool03ol00_l03ol2o`3ooP06
oolh0?l0;Ooooe@0oomD0?ooQP3ooo]Z0_lVo`001Ooo0=_ooo]ZoookJ_oonf[ol@3o00?o05oo0_oo
0<P6ool000Co0;3o1?oob@03o`3o30?o0;3o00?ooo]Zo`2aool0/Ol02_l03ol2oonS00;ooo]Z1?l0
000>oookJPCooj<00_oonfX9o`3ooP;ooo]Z00?o09kooookJ_l0Gol02?l0Gol2oago0006oookJ_oo
5P3o0?l[oookJ_oo0<So04So0_oonfX00ooa0?oo00ooo`0?o`04o`3o30SoU?l00ooonfX00ooo0:co
oo]ZoookJP02oookJP04ool03?oo0@3oRol0oolN00;oon`000?ooo]Zooo^0?ookP001?oonfX00ooo
03koA?l0odCo0002odCo00;o0?mI00?oA?l0o`0?ool03ol00ol03ol4o`3o[@06o`0?ool0ojgo0?oP
o`3oh?oo01_o0?mC0ol0Gol2ool0^0;o05oo0_ooD@02oolX0003oiCo0?oo:03oobP000Coo`000_l0
oaP01Ooonf[oo`2@ooWo0?oob@3o0?l<00;oon<000?oolT0ool00?oo00000_oo00002?m4o`3o0?o_
ooo90?l0o`co0;3oooo90?m4o`3o0?n]1?nDo`02oookJP;oolT00_oo0?800ooob@3ooo]ZodCo0002
odCo0004o`3oo_nDo`3o00oooiCo00;oo`1W00Gooo]ZonGo0?oUo`3oiOl0o`1Oo`02onGo00kooo]Z
00?o0?mMo`1Oool0oed00_l0oee^oookJP;o0?l94OoonfX2ool0[`?ooo]Z0_oo06L00ooonf[o0?mP
o`3oH002oonj00;oK`3o0_oonfX2ool0lP03ool0QOoonf[ooo]Z00Gooo]Z00Coon80oookJ_oonf[o
oo]Z0_mEo`02o`3ok`06oookJ_oo047o04;oo`12oooonf[oog@00_ooh`001Ooo057oeOl0ool0T?oo
093ooo]Z00;o0?lH0_oo9002oookJP05oolN0?mE0?ooE@3oo`3o=_l0Eol00_ooD@001_oSo`3oofP0
ool0^?oo0;So0?nAoookJP;o0?mC00Cooo]Zo`3oh?l0on3oo`3`0_oc0?l01OooD`3ooo]Zool0Looo
07?oolD000;o03Oo00Coo`3=oookJ_l0oeWo0?mI0_l0T_l00ooonf[oo`0nool0?P03oookJP?oonh0
00Go:03oooo/0?oo7P3ooah0ool10002ool030?ooo]Z0_oo0:`3oookJP05o`2Moooo>03oocP0o`0]
ooooE0000_ooQP02obKo0004ool0fooonf[ooo]ZoookJP;ol@3o00Cooo]Zo`18ool0B?ooo`380_oo
5P001Ooonf[o7Ol0oago0?oonf[o0?m/00;ooo]Z0_ofo`03oookJP;o09ko1OoonfX3o`2ao`Kooo]Z
1OooX`02oookJPCo00003_oonfX4oonS00Kooo]Z0_l0/Ol6oookJP03o`2Noooonf[ooo]Z00;ooo]Z
0_ofo`000ooonf[o0?m/oookJP02oago0004oookJ_l0ob_ooaH0o`3o:`;oo`3800Co04SooookJ_oa
0?ool@3o0ooonfX01?oo0=_o9_l0oookJ_ooQP02oomD00;o02go00?o09goobCo0?oonfX00_oonfX0
0ooo0:cooo]ZoookJP02oookJP;oo`0<00Ooo`40oolN0?ook03oon`0obP0oooonf[oonh000Cooo]Z
0_oo03h00ooonf[o09;oo`3o9@02o`3oF@04oookJ_oo0<go03Ooo`0go`;oo`1c0_oonfX00oooD`3o
o`3Goo<0o`02ool0l006o`3oh?oonf[o0?mCo`3oDooonf[o0?nA0_oo0;P02OooS03ohol0oookJ_oo
D@3o05Ooo`3o=_mE0?oooo]ZoolN0002oookJP;oob@00_l0oaP01Ooonf[oo`2@ooWo0?l0n?ooo`1A
00;oon<000Coog@0oookJ_l0@_oo04;o0_oonfX2o`3ok`;oEOl00_oonfX2oooR00Oooo]Z00?oo`25
ool0l_oo0?800_oonfX2ofl0o`;ookX00_l0of000ooonf[oo`1Wool0I`03oookJP;oo`2_4OoonfX0
0ol0o`Wooo]ZoookJP0aoookJP00@OoonfX2o`3o2A3ooo]Z0ooo0:l3oookJP04ool0Iooonf[ooo]Z
o`3oH0;ookX00_m_0?l2oookJP;oo`3b00?oo`25oookJ_oonfX01OoonfX2oooR00;ooo]Z0_mEo`00
0ol0ookoA?l0oomi0002o`3o300;o`2`ool0o`co0;3ooomd0?ooh`3oo`1AonGo0?oio`3oo`2@oook
J_l0oaP01Ol0/?l2oolN0003oeD0ool0ocKo05Oo00;ooe401ol0ooh2o`3oD`03onGo0?l0on3oo`3`
00;ol`3o0_ooD`000ooonf[oo`1cooo50002o`0go`Ko0?on00?o0?l<o`2`ool0o``00_l0o``01Ooo
nf[o0;3oooo^0?oonf[o00oo00Wo0?on00Co0?l<o`0?ool03ooo00oo0ol0ooh2o`0]o`;ooe@000Co
ohH0oookJ_lVo`3oo`3K0ooonfX2oo40o`;o05oo0_oo0<P6ool000Ko0;3o0ooob@04o`3o3003o`2`
ool03ooo00oo00_o00oo1OoonfX4o`00017ooo]Z0oooX`02oookJPSo0?on00Cooo]Zo`2Nool0W_oo
oo]Z2?l0Gol01ooonf[o7Ol0oookJ_oonf[ooaH0oookJ_oo0<P00_l0B?l00ooonf[ol@3oo`0?o`02
o`0?o`;o0?l<0_l0/?l6oiCo00?o0?n]00?ooo]Zool0[?oonfX00ooonfX01?oo00co04Cooh_o0?oo
7P02ooo/0003oookJ_ookP3oonh000Cooo]Z00?oo`0nodCo0?m4o`000_m4o`02o`3oF@03odCo0?l0
3ooo00oo00Co00oo0ol0ojd4o`0?o`;oolT00ol0Gol2ool0^0;o05oo0_ooD@02oolX0003oiCo0?oo
:03oobP000Coo`000_l0oaP01Ooonf[oo`2@ooWo0?oob@3o0?l<00;oon<000?oolT0ool00?oo0000
0_oo00001Om4o`3o0?o_ooo90?l0o`co0;3o00?o0?l<00Co0?n]oiCo0?nDo`3oU?l00_oonfX2ooo9
00;oo`3b00?oolT0oookJ_oonfX00_m4o`000ol0ookoU?l0o`0?o`04o`3o[@?oiOl000?o05ooonGo
0?oUo`003_oonfX01?l0oego05ooo`3oGOl0oee_oookJP;o0?l94OoonfX2ool0[`?ooo]Z0_oo06L0
0ooonf[o0?mPo`3oH002oonj0004ofl0oooonf[ooo]ZoooT00;oo`3b2?oonfX00ooohP3ooo]Zoook
JP02oeGo0004o`2fool0onoo0?o_oookJP;o04;o0_oonfX01OooM03oon<0oooS0?oEo`3onOl000;o
o`2@00Cooo]Zo`3o6?oonf[oob@00_oonfX2oolN00;oE@3o00?o05OooomA0?ooD@000_oSo`001On@
o`3oo`2ho`3oTOoo00?ooo]Z00;o0?mC0ol0on02oo<0o`;ooe<000Cooo]Zool0Looo07?oolD00_l0
=ol01_oo0<go0?mIo`3oFOo00?oo09;ooookJP;oo`0n1?oonfX2ooo^0005obP0ooook03oon`0oolN
0?oo0@000ooo00`2oookJP?oo`2/0_oonfX2o`2Mo`04oolh0?l0;Ooooe@0oomD00;oohH000?o9_l0
ool0fooonfX00_oonfX2oo40o`04oookJ_l0B?oo04Soool0b0;ooaH000Gooo]Zoago0?lMo`3ooo]Z
o`3oK002oookJP;om_l00ooonfX2o`2No`Cooo]Z0ol0/Ol6oookJPCooj<01OoonfX4o`00017ooo]Z
0oooX`06oookJP;o0;7o1?oonfX2o`2No`Cooo]Z00Kom_l0oookJ_l0ofco0?m/oookJ_lMo`02oook
JP04o`3o:ooo5P3oo`38ool0b0;o04So00?ooo]Zoo40oooonfX00_oonfX00ooo0=_o9_l0obKo0002
oon600;ooe@000?o02gooookJ_l0WOl00ooonfX00ooo0:cooo]ZoookJP02oookJP03o`14oooo00co
o`4000;ooah000?oon`0obP0oooonfX00_ookP03oookJP;oo`0n00?ooo]Zo`2Bool0T_l00_l0oeT0
1_oonf[oo`3=o`0gool0=oooolD0ool0L`;ooo]Z0_ooD`001Ooc0?ooo`3`ool0l?l0on3ooo]Z00;o
0?mC00Gooo]Zo`3oTOoo0;Soo`2hoon<0002on?o0006oomA0?l0Eooo05OooeD0oooonf[ooah00_oo
nfX2oolT00?o0?lH00?oo`2@ooWo0?l0n?l00_oo05400oooh`3oog@0oookJP02o`12o`04ool0@Ooo
nf[o0?o_o`3ok`;oEOl00_oonfX3oooR00Kooo]Z00?oo`25ool0l_oo0?800_oonfX2ofl0o`;ookX0
0_l0of000ooonf[oo`1Wool0I`03oookJP;oo`2_4OoonfX00ol0o`Wooo]ZoookJP0aoookJP00@Ooo
nfX2o`3o2A3ooo]Z0_oo0:l3oookJP;oo`1W00?ooo]Zo`3oH?l0of000_oo^P02ofl0o`;ooo]Z0_oo
0?88oookJP;oon8000Kooo]ZoeGo0?mEo`3oogT0o`3oo_m4o`02o`3o3004o`2`ool0o`co0?l<oomd
00;oon<000Goo`1Ao`3hoooo093oo`2@oookJP06o`2`o`03oolN0?mE0?ooE@3o00;o05Oo0_ooD@07
o`3ooP06o`3oDonDo`3o0?oPo`3oh?oo0?3ol`3o0_ooD`001Ol0ojgoo`1cool0Loooa@3o03Oo00Ko
0?on0_l0o``01Ol0/?oo0?l<o`3o3?l0o`cooo]Z00;oonh00_l03ol00oook03oA?l0o`3ooP05o`3o
oP;o0?l<0_l0ojd3o`3ooP;o02go0_ooE0001?ooQP3ooo]ZobKo0?oo0=/3oookJP;ol@3o0_l0Gol2
ool0b0Ooo`0000?o0?l<o`2`ool0/?l00ol0/?l3ooo900?o0?l<0_l0ojd;o`0?o`Oooo]Z1?l00000
1?oonf[oiOl0onGo0?oonfX2o`3oG@03o`1Ooooonf[ooo]Z00[ooo]Z0oooX`000ooonf[o0?ono`3o
oP06o`3ooP04oookJ_l0W_oo09kooookJP?o05oo0_oUo`02o`1Oo`03o`3oK?oonf[o7Ol000;ooo]Z
00CooaH0oookJ_oo0<So04So0_oonfX00ooa0?oo00ooo`0?o`05o`2`o`;oU?l01_l0ojd00ooonf[o
o`2/ool0[003oookJP03o`14oooo00coo`4000;ooah000Coon`0obP0oooonf[oonh01?oonfX2ool0
?PCoA?l000?o0?mIodCo0?m4o`003?l03ol2ooo900?o05oo0_oo0;P2o`1Oo`;ooe400_oo:0001?nD
o`3oobP0oolX0?oonfX3ool00005oookJ_l0oaSooo]Zool0T?oio`000_oob@02oooS0003ooo90?m4
o`3oo`0000;oo`001?l0o``01Ol0/?oo0?l<o`3o3?l0o`co0?n]00;oU?l01?oonfX00ooob@3oo`3b
ool0lP03o`3o30Co0?n]00?o00ooo`3o[Ol0ojd00_l0ojd01?oonf[oiOl0onGo0?l0Gol2onGo00ko
oo]Z00Co0?mMo`1Oool0oego0?mMKooonfX2o`3o2A3ooo]Z0_oo0:l4oookJP06ool0Iooonf[ooo]Z
o`3oH?l0]ooookX00_m_0?l2oookJP03oooT0?oo0?;oo`2500Oooo]Z0_oohP02oookJP;oEOl000Co
o`26o`3okol0onooo`110_l0@_l2oookJP;oon<000Goo`1AomGo0?oo093oo`2@oookJP02o`3o60;o
ob@00_oonfX01Ooo7P3oE@3ooeD0ool0ocKo05Oo00;ooe4000Kohol0oomX0?oo0;Soo`2ho`3oTOoo
nfX2o`3oD`04oookJ_l0on3o0?oPool0l0;ol`3o00?ooe<0oookJ_oo07<00_oo07<2o`0go`04ool0
cOoonf[o0?mIol00o`;o09;o00?ooo]Zool0?_oo03h00ooonfX3ooo^0005obP0ooook03ooah0oolN
0?oo0@000_oo00`3oookJP;oo`2/0_oonfX01?lTo`3o09gooolh0?l0;Ol2oomD00;oohH000?o9_l0
ool0fooonfX00_oonfX2oo40o`;ooo]Z00Go04Soool0b?oo5P3ooaH0o`3o:`02oago0004oookJ_l0
ofcooo]ZoookJP;om_l00ooonfX2o`2No`Cooo]Z0ol0/Ol5oookJP?ooj<02?oonfX4o`0001Cooo]Z
0_ooX`05oookJP;o0;7o1?oonfX2o`2No`Cooo]Z00Kom_l0oookJ_l0ofco0?m/oookJ_lMo`02oook
JP;ooaH00_oo0<P01?l0B?oooo]ZoookJ_oa0?l3oookJP04ool0folVo`3ooo]Zoon600;ooe@00_l0
;Ol01?l0WOoo9?l0oookJ_oonfX2ool0[0?ooo]Z00So04Coool03?oo00coRol0oolN0?ook03o:03o
oookJP;oonh01?oonfX01_oo03kof_l0oookJ_l0T_oo`03oo`3oF@;ooo]Z00?oo`3=o`0gooooa@00
0_oo07<00ooonf[ooe<0oomC0002oo<0o`03ool0l?l0on3o0?oP00;o0?mC00Gooo]Zool00on@o`3o
o`2hoon<0002on?o0003oomA0?l0Eooo05Oo00;oE@3o00?ooah0oookJ_oonfX00_oo90000ooonf[o
0?lHo`3o6002ool0T006o`3hoooo057oo`1AoooS0?ooM03ooo]Z0_l0@_l01_oo047ooo]Zo`3okol0
onoo0;KooeGo00;ooo]Z0ooohP06oookJP03ool0QOoo0?;oo`3b00?ooo]Z00?oK`3ooonj0?oo^P00
0_l0of000ooonf[oo`1Wool0I`03oookJP;oo`2_4OoonfX00ol0o`Wooo]ZoookJP0aoookJP00@?oo
nfX2o`3o2A7ooo]Z0_oo0:l3oookJP;oo`1W00Gooo]Zo`3oH?oo^P3ookX0oookJP02ofl0o`04oook
J_oo0?;oo`3bool0lPOooo]Z0_oohP02oookJP;oEOl000?o0?onodCo0?l0o``00_l0o``02?l0/?oo
0?l<o`3o3?ooM03o0?onoooS0?oUo`3onOl00_oo0906o`2`o`;ooah00_mE0?l00ol0Eooooe40oomA
0007o`3ooP;o0?mC0_l0on000ooo0?3ol`3ooo<0o`02oomC0004oookJ_oo07?oolD0ooo500Oo0?on
00?o0?l<o`2`ool0o``00ol0o``01Ooonf[oonh0oookJ_lX0?ooon`000?oA?l01Ol0ooh00ol0o`co
0?n]o`3o[@03o`3ooP;o02go0_ooE002oon60003obKo0?oo0=_ooo]Z00;ooo]Z0_oa0?l2o`1Oo`03
ool00?oo0<Soo`0000Koo`000_l0o``5o`2`o`05o`2Noooob@3oolT0ooo90?l0o``00ol0ojd:o`0?
o`Sooo]Z1?l000001?oonf[oiOl0onGo0?oUo`02o`3oG@;o05oo3OoonfX2oonS00;ooo]Z1_l0ooh2
oookJP;o09ko00?ooo]ZonGo0?oUo`000_oUo`03o`1Oo`06oookJ_lMo`3o7Ol0oookJ_oo5P3oogT0
0_oo0<P01Ol0B?oooo]ZoookJ_oa0?oo00oo00Go0;3o2?l0ojd2oookJP03ool0[?oonf[ooo]Z00;o
oo]Z00Ooo`0<ool10?n;o`3ooah0ooo/0?l0obcooo]Z00;oonh01?oonfX00ooo03koA?l0odCo0002
odCo0003o`3oFOm4o`3oA?l000co00oo0_oob@000ol0oe?o05ooo`1Oo`02ool0^0?o05oo00Oooe40
oolX0?oo:03oU?l0o`3o[Ooo:03ooo]Z00?oo`0000?ooo]Zo`3o6?oonfX00_oo0902ooo900;oon<0
00?oolT0odCo0?oo00000_oo0004o`3o3005o`2`ool0o`co0?l<o`3o3?l03ol00_nDo`000ooonf[o
0?l<o`3o3002o`3o3003o`2`oooo0?;o0?l<00;o0?l<1?l0ojd00ol03ooo0?n]o`3o[@02o`3o[@04
oookJ_oUo`3oiOl0o`1Oo`;oiOl03ooonfX00ol0Gooo0?mMo`3oG@1^oookJP;o0?l94OoonfX2ool0
[`?ooo]Z0_oo06L00ooonf[o0?mPo`3oH002oonj00;oK`3o0_oonfX2ool0lP03ool0QOoonf[ooo]Z
00Gooo]Z0_oohP02oookJP;oEOl00_l0onl01_oonf[oo`11o`12ool0@_oooo]Zoomd00;oon<000Oo
eOl0o`3hoooo093oo`2@oookJ_l0oaSooo]Z00;oob@000?ooo]ZoolN0?oo7P000_mE0?l2o`1Go`08
oomA0?oSo`3ohol0oon<0?oo0;SoT?l0ool00ooonfX2o`3oD`?o0?oP0_oc0?l00ooonf[ooe<0oook
JP02ool0L`07ooo50?l0=oooo`3=oookJ_o00?oo0?mIol00o`02o`2Bo`;oo`0n1?oonfX2ooo^0005
obP0ooook03oon`0oolN0?oo0@000_oo00`00ol0A?oooo]ZoookJP02ool0[0?ooo]Z0_l0WOl2o`0]
o`03oomD0?ooQP3oohH000;o9_l000Goo`3KoookJ_oonf[ooo]Zoo40o`02oookJP05o`18oooo0<So
o`38oolF0?l0ob/00_lMo`001?oonf[o0?m/o`3oK?oonfX2ooKo00?ooo]Z0_l0W_l4oookJP;o0;7o
1?oonfX3oonS00_ooo]Z1?l0000EoookJP?ooj<01?oonfX2o`2ao`Cooo]Z0_l0W_l4oookJP03ooKo
0?oonf[o0?m/00;ooo]Z00Co7Ol0oookJ_oonf[ooaH00_oo0<P2o`18o`03oookJ_oa0?ool@3o00;o
oo]Z00?oo`3KobKo0?lVo`000_ooQP000oooE03o02goo`0]o`02o`2Mo`?ooo]Z00?oo`2/oookJ_oo
nfX00_oonfX2ool03007ool10?oo7P3oon`0ooo/0?lX0?oooo]Zooo^0004oookJP06ool0?_oJo`3o
oo]Zo`2Booo00?oo0?mI0_oonfX00ooo0<go03Ooo`0go`02ool0L`03oookJ_ooD`3ooe<000;ol`3o
00goo`3`o`3oh?l0on3ooo]Zo`3oDooonf[oo`03o`3oTOoo0;Sooh`0oomX0?oSo`3ooe4000;o05Oo
00?ooo]ZoeD0oooo7P000_oonfX2oolT0003oookJ_l0oaSo0?lH00;oo`2@00Go0?SoomGo0?oo057o
on<0oomd0002oookJP03o`12oooo047ooo]Z00;o0?o_00?o0;KooeGo0?oonfX00_oonfX2oooR00Oo
oo]Z0_oo0?83oookJP03ofl0oooo^P3ookX000;o0?mP00?ooo]Zool0Iooo06L00ooonfX2ool0[a7o
oo]Z00?o0?l9oookJ_oonfX0<OoonfX0043ooo]Z0_l0o`TAoookJP03ool0[ooonf[ooo]Z00;ooo]Z
0_oo06L01?oonf[o0?mPoonj0?oo^P02ofl0o`;ooo]Z0_oo0?800ooo08Gooo]ZoookJP05oookJP;o
on800_oonfX2oeGo0003oomi0?m4o`3o0?l<00;o0?l<00[o0;3oo`3o3?ooM03oog@0o`3oo_oo057o
iOl0ooWo0?oo093ooo]Z1_l0/?l01Ooo7P3ooo]ZoeD0ool0ocKo05Oo00;ooe4000?oU?l0o`3oo_l0
ooh01?l0ooh01_l0oe?oU?l0o`3oh?l0on3oo`3`oo<0o`;ooe<000Cooo]Zool0Looo07?oolD02?l0
ooh6o`3o30;oonh000?ooo]Zooo90?m4o`000_m4o`000ol0ookoA?l0odCo0003o`3ooP;o0?n]0ol0
ooh00ol0Gooo02goo`0]o`02oomD0004oon60?lVo`3o9_l0ool0f`;ooo]Z00Ko05oooo40ool0Gooo
05ooool00?oo0<P7ool000Co0?l<0ol0/?l00ol0W_oooo]Zooo90002ooo900;oU?l00ol0ojd7o`0?
o`Wooo]Z0_l0ojd2o`0?o`04o`000?oonf[oiOl0onGo00;o0?mM1?l0Gol=oookJP;ooj<00ooonfX5
o`3ooP;ooo]Z1_oUo`02o`3oG@03o`1Oool0ofcooo]Z00GoogT000Goo`38o`18ool0B?ooolT0oo40
o`02o`0?o`Co0;3o2?l0ojd2oookJP;oo`2/0ooonfX2ool03005oh_o0?oo7P3oon`0ooo/0?oonfX0
0_ookP04oookJP03ool0?_oJo`3oA?l000;oA?l00_l0oeT00om4o`3oo`3=o`0?o`0:o`0?o`;oolT0
00Go0?mCo`1Oool0GoooT?l0ool0^002o`1Oo`03oiCo0?ooD@3ooe4000;oU?l000Co0?n]oiCo0?nD
o`3oU?l00_oo00000ooonf[o0?lHoookJP02ool0T0;oolT00_ooh`000ooob@3oA?l0odCo0002ool0
0005odCo0?l0o`co0?l<o`3o3?l0/?l00ol0o``01?l03oooU?l0oiCo0?oonfX4o`3o3003o`2`oooo
0?;o0?l<00?o0?on0ol0ojd01Ol03ooo0?n]o`3o[Ol0ojgoo`1W00;ooo]Z00CoiOl0o`1OoooUo`3o
iOl03ooonfX00ol0Gooo0?mMo`3oG@1^oookJP;o0?l94OoonfX2ool0[`?ooo]Z0_oo06L00ooonf[o
0?mPo`3oH002oonj0004ofl0oooonf[ooo]ZoookJP;oo`3b1ooonfX2oooR00?ooo]Z00GoEOl0o`2f
ool0onoo0?o_oookJP02o`12o`;ooo]Z00Goog@0oooS0?oo057oeOl0ooWo0002ool0T004oookJ_l0
oaSooo]ZoolT00;ooo]Z0_oo7P02oeD0o`05o`1GooooD@3ooe40on?o0?ooJ0000_oo0;P01Ol0oi7o
o`03oookJ_l0oe?ooo]Z00;o0?oP00Goo`3`oo<0oooc0?oooe<0oookJP03ool0L`;o03Oo00Coo`3=
oookJ_l0oeWo0?mI0_l0T_l00ooonf[oo`0nool0?P04oookJP07ooo^0?oonf[o:03oooo/0?oo7P3o
Rol0ool10002ool030?ooo]Z0_oo0:`2oookJP04obCo0?l0WOooocP0o`0]o`;ooe@000CoohH0obKo
0?lVo`3oo`3K0ooonfX2oo40o`06oookJ_l0B?ooo`38ool0b?oo5P3o0?l[0_lMo`001?oonf[o0?m/
o`3oK?oonfX2ooKo00?ooo]Z0_l0W_l4oookJP03o`2aoooonf[ooo]Z00;ooo]Z0oooX`0=oookJPCo
00005ooonfX2oonS00Gooo]Z00?o0;7ooookJ_oonfX00_oonfX2o`2No`?ooo]Z0_ofo`001?oonf[o
0?m/oookJ_lMo`02oookJP03o`3o:ooo5P3oo`3800;o04So0_oonfX02?oa0?oooo]ZoookJ_oonf[o
o`3KobKo0?oonf[oohH00_ooE0000ol0;OooocP0o`2Mo`03oookJP;oo`2/0ooonfX00ol0A?ooo`0<
ool10002oolN0004ooo/0?lX0?oooo]Zooo^00Cooo]Z0_oo03h00ooonf[o09;oo`2Bo`02o`3oF@04
oookJ_oo0<go03Ooo`0go`;oo`1c0_oonfX01?ooD`3ol`3ooo<0oooo0?02o`3oh009oookJ_l0oe?o
oo]Zool00ol0oi7oo`2hoi3o0?ooJ03ohol000;ooe4000Co05Ooo`3o=_mE0?oooah00ooonfX02ooo
903ooo]Zo`3o6?l0oaSooo]Zool0T?l0n?ooeOl0ool0DOooh`3oog@000;ooo]Z0_l0@_l01?oonf[o
0?o_o`3okooonP02oeGo00;ooo]Z0_oohP07oookJP;oo`3b0ooonfX00om_0?oookX0oonj0002o`3o
H003oookJ_oo06Ooo`1W00?ooo]Z0_oo0:lAoookJP03o`3o2Ooonf[ooo]Z037ooo]Z0010oookJP;o
0?l94OoonfX01?oo0:oooo]ZoookJ_oonfX2ool0I`03oookJ_l0of3o0?mP00;ookX00_m_0?l2oook
JP;oo`3b00?oo`25oookJ_oonfX01OoonfX2oooR0005oookJ_mEo`3oEOl0oomi0?m4o`000ol0o``0
1?l0/?oo0?l<o`3o3?ooM002o`3ooP04onGo0?oio`3oo`2@ool0T0Oo0;3o00Cooah0oeD0oomE0?oo
05Oo0_ooD@001OnDo`3oA?l0odCo0?l0ookoA?l000?o0?on00Co0?mCo`3oh?l0on3oo`3`0_oc0?l2
oomC0003oookJ_oo07?oo`1c00Wo0?on1Ol0o``2ooo^0003oookJ_lX0?ooA?l000OoA?l000?o0?on
o`3o[Ol0ojd01?l0ooh2o`0]o`;ooe@000CoohH0o`0?oolVo`3oo`3K0_oonfX00ol0Goool@3oo`1O
o`02o`1Oo`;oo`381ooo00000ooob@3o0?l<o`3o3002o`3o3006o`2`ool0W_oooo]ZoookJ_l03ooo
olT00onDo`03o`3o[@Ko00oo1_oonfX2oolX00;oU?l00_l0ojd4o`0?o`;oiOl000?o0?mMo`1Oool0
Gol01?l0Gol>oookJP04oonS0?oonf[ooo]ZoookJP;o0?on0_ooN@000ooonf[oiOl0onGo0002onGo
00Go0?mM00?o05oooomi0?ooN@001OooN@02ool0b0?oolT000?ol@3oo`0?ool03ol01?l0/?l7o`3o
[@;ooo]Z0_oo0:`3oookJP;oo`0<00Coo`40oolN0?ook03oon`00_oonfX00oookP3ooo]ZoookJP02
oookJP;oo`0n0om4o`02o`3oF@;o0?on2ol03ol2ooo90005o`3oDol0Gooo05oooi3o0?oo0;P00_l0
Gol00onDo`3ooe40oomA0002oiCo0004o`3o[OnDo`3oU?l0oiCo00;oo`0000?ooo]Zo`3o6?oonfX0
0_oo0902ooo900;oon<00ol0o``2ool00005odCo0?l0o`co0?l<o`3o3?l0/?l00ol0o``00ol03ooo
U?l0oiCo0002oookJP?o0?l<00?o0;3oool0l_oo0?800ol0ooh3o`3o[@05o`0?ool0ojgo0?n]o`3o
[Ooo06L00_oonfX01?oUo`3o05ooonGo0?oUo`0?oookJP03o`1Oool0oego0?mM06kooo]Z0_l0o`TA
oookJP03ool0[ooonf[ooo]Z00;ooo]Z00Goo`1WoookJ_l0of3o0?mPo`2go`02oonj0004ofl0oooo
nf[ooo]ZoooT00;oo`3b1ooonfX2oooR00;ooo]Z0_mEo`001?oo08Ko0?o_oookJ_oo0442o`12o`;o
oo]Z0_ooh`001Ooo057o0?Soool0T?oo093ooo]Z00;o0?lH0_oo9002oookJP06oolN0?mE0?ooE@3o
o`3o=_l0Eooooe400_oSo`001OooJ03oo`2hool0^?l0oi7ooo]Z00;o0?mC00?ooo]Zo`3oh?l0on00
0_oc0?l00ooonf[ooe<0oookJP02ool0L`03ooo50?l0=oooo`3=00;ooo]Z00Co0?mIol00ool0T_oo
09;o0_oo03h4oookJP;oonh000Co:03oooo/0?ook03ooah00_oo0@001?oo00co04CooookJ_oonfX2
ool0[0?ooo]Z0_l0WOl2o`0]o`05oomD0?ooQP3oohH0obKo0?oo0=/00ooonfX2oo40o`04oookJ_l0
B?ooo`38ool0b0;ooaH000?ooo]Zoago0?lMo`000_l0of`00ooonf[om_l0ooKo0003oookJP;o09ko
1?oonfX00ol0/Ooooo]ZoookJP02oookJP?ooj<03_oonfX4o`0001Sooo]Z0_ooX`04oookJP;o0;7o
0ooonfX2o`2No`Cooo]Z0_ofo`02o`3oK005oookJ_lMo`3ooo]ZoookJ_oo5P000_oo0<P2o`18o`03
oookJ_oa0?ool@3o00;ooo]Z00?oo`3KobKo0?lVo`000_ooQP001OooE03o02goo`0]ool0WOoo9?l0
00;ooo]Z0_oo0:`3oookJP08o`14oooo00coo`40oh_o0?oo7P3oon`0obP0oooonfX2ooo^00?ooo]Z
0_oo03h00ooJo`3o09;oo`2Bo`02o`3oF@04oookJ_oo0<go03Ooo`0go`?oo`1c00Gooo]ZoomC0?oc
0?ool`3oool0l002o`3oh00>oookJ_l0oe?oo`0Kool00ol0oi7oo`2hoi3o0?ooJ03ohol0oookJ_oo
D@3o05Ooo`3o=_mE0?l2oolN00;ooo]Z0_oo9002o`3o6007oookJ_oo093o0?SoomGo0?oo057oon<0
oomd0002oookJP;o04;o0_oonfX2o`3ok`;oEOl00_oonfX2oooR00Oooo]Z00?oo`25ool0l_oonfX0
0_oonfX2ofl0o`03oonj0?l0of3o0?mP00;ooo]Z00Coo`1WoookJ_oonf[ooo]Z0_oo0:lAoookJP;o
0?l9<_oonfX003oooo]Z0_l0o`TAoookJP;oo`2_0ooonfX2ool0I`03oookJ_l0of3o0?mP00;ookX0
0_m_0?l01?oonf[oo`3bool0l_oo0?88oookJP03oooR0?oonf[ooo]Z00;oEOl000?oogT0odCo0?l0
o``00_l0o``00ol0/?oo0?l<o`3o3003o`3ooP04onGo0?oio`3oo`2@ool0T0Ko0;3o0_oo7P000omE
0?oo0?lfo`1Go`02oomA00;oA?l000Oo0?onodCo0?m4o`3oU?l0oookJ_l0ookoU?l000;o0?oP00Co
o`3`oo<0ooooD`3ooe<00_oonfX01?oo07?oolD0o`1Oool0Gol7o`3ooP03o`3o3?oob@3o0?l<00;o
0?l<00?o05ooooo^0?lX0?l02Om4o`000ooob@3oU?l0o`3ooP03o`3ooP04o`1Oool0;Ooo02gooomD
00;oohH000Go9_l0ool0fooo0=_ooo]Zo`1Oo`02oo40o`?o05oo00?oo`38oolF0?oo00001Ooo0003
ooo900?o0?l<0_l0W_l2o`0?o`?oobP00onDo`02o`3o[@Go00oo1ooonfX2oolX00;oU?l00_l0ojd6
o`0?o`03o`3oGOl0Gooo05oo00Go05oo00?ooo]Zoomi0?oonfX02ooonfX00oooX`3ooo]ZoookJP04
oomi0003o`3oo_oUo`3oiOl000Oo0?mM00?o05oooomi0?ooN@001OooN@000om4o`3oo`38ool0b002
ooo90003oo40oooonf[o00oo00Co0;3o1?l0ojd5o`0?o`03oookJ_oo0:cooo]Z00?ooo]Z00Koo`0<
ool10?oo7P3ooah0ooo90?l0ob`3ooo900?ooo]Z0_oo03h4o`3ooP04o`3oFOl0ooko0?ono`3ooP[o
00oo0_oob@001Ol0oe?o05ooo`1Oool0Goooo`2h00;o05oo00?ohol0oomA0?ooD@000_nDo`001?l0
ojgoU?l0oiCo0?nDo`02ool00003oookJ_l0oaSooo]Z00;oo`2@00Go0?Soo`3o3?ooh`3oon<0oomd
0002o`3o3003o`12oooo003oA?l000?o0?l<00Go0;3oo`3o3?l0o`coU?l0o`0?o`02oiCo00;ooo]Z
0ol0o``01?l0/?ooo`3bool0l_l0o``2o`3ooP?o0?n]00Co00ooo`3o[Ol0ojgo0?n]1?l0oed00ol0
Gooo0?mMo`3oG@02o`3oG@[ooo]Z2?l0Gom[oookJP;o0?l94_oonfX01?oo0:oooo]ZoookJ_oonfX2
ool0I`03oookJ_l0of3o0?mP00;ookX00_m_0?l2oookJP;oo`3b00?oo`25oookJ_oonfX01OoonfX2
oooR00;ooo]Z00KoEOl0o`2fool0onoo0?o_oookJ_oo0442o`12o`06oookJ_ooM03oon<0oooS0?oE
o`3o0?So0_oo09000ooonf[o0?lHoookJP02oolT0003oookJ_oo7P3ooah000;oE@3o0_l0Eol00ooo
D@3ohol0oomX0002ool0^005o`3oTOoo00?ooo]Zo`3oDooonfX00_l0on000ooo0?3ol`3ooo<0o`02
oomC0003oookJ_oo07?oo`1c00;o03Oo00Coo`3=oookJ_l0oeWo0?mI0_l0T_l00ooonf[oo`0nool0
?P04oookJP05ooo^0?oonf[oon`0ooo/0?oo7P000_oo0@02ool030?ooo]Z00Coo`2/oookJ_oonf[o
oo]Z0_l0WOl00ooo>03o02gooomD0002oon600;o9_l000?oo`3KoookJ_oonfX00_oa0?l2oookJP05
o`18oooo0<Soo`38oolF0?oonfX00_lMo`02o`3oK003oookJ_ofo`3om_l000Cooo]Z00?o09kooook
J_oonfX00_oonfX00ol0/Ooooo]ZoookJP02oookJP;ooj<04?oonfX4o`0001Wooo]Z0_ooX`04oook
JP;o0;7o0ooonfX2o`2No`?ooo]Z0_ofo`000ooonf[o0?m/oookJP02oago0003oookJ_l0ob_ooaH0
00;oo`3800Co04SooookJ_oa0?ool@3o0ooonfX01?oo0=_o9_l0oookJ_ooQP02oomD0003o`0]oooo
>03o09go00?ooo]Z00?oo`2/oookJ_oonfX00_oonfX2ool03005ool10?oo7P3oon`0ooo/0?lX0?l0
0_ookP04oookJP06ool0?_oJo`3ooo]Zo`2Booo00?oo0?mI0_oonfX2o`0go`05ooo50?oo07?oo`1c
oookJ_ooD`000_oc0?l02?oo0?3o0?oPo`3oh?oonf[o0?mCool06ooonf[o0?nA0_oo0;P01oooJ03o
hol0oookJ_ooD@3o05Ooo`3o=_mE0?l00_oo7P02oookJP;oob@00_l0oaP01ooonf[oo`2@ooWo0?oE
o`3oo`1AoooS0?ooM0000_oonfX2o`12o`;ooo]Z0_l0onl2oeGo00;ooo]Z0_oohP07oookJP03ool0
QOoo0?;ooo]Z00;ooo]Z0_m_0?l00ooo^P3o0?mPo`3oH002oookJP04ool0Iooonf[ooo]ZoookJP;o
o`2_4OoonfX2o`3o2C;ooo]Z000ooookJP;o0?l94OoonfX00ooo0:oooo]ZoookJP02oookJP;oo`1W
00Kooo]Zo`3oH?oo^P3ookX0oookJ_m_0?l2oookJP;oo`3b00?oo`25oookJ_oonfX01OoonfX2oooR
0005oookJ_ooN@3oEOl0oeGo0?ooN@001?l0o``00ol0/?oo0?l<oomd0003o`3ooP06omGo0?oio`3o
o`2@oookJ_l0oaSo0?l<1?l0/?l01?oo7P3ooo]ZoeD0ooooN@02oomA0004oiCo0?m4o`3oA?l0o`3o
oP;oA?l000?oU?l0o`3oDol0oe<00ol0on001Ooo0?3ol`3ooomC0?ooD`3ooo]Z00;oo`1c0ol0Gol2
odCo00Co0?on00Wo0?l<ooo90?oob@3oolT0oookJ_l0o`co05oooookJ_l0ojd00_ook007odCo0003
oiCo0?l0ooko0?on00;o0?on00?o05ooo`0]ool0;Ol00_ooE0001OooQP3o9_l0obKo0?oo0=_ooo]Z
00;o05oo00Gol@3oo`1Oool0Gooo05ooool0b002oolF0003oookJ_oo003oo`0000?oo`001?oob@00
0ol0o`co09koo`2No`03o`0?o`?oobP00onDo`03o`3o[@;o00oo2OoonfX2oolX00;oU?l000?o0?n]
o`0?ool03ol01ol03ol6o`1Oo`;oogT00_m4o`0:oookJP03oonS0?ooN@3oogT000CoogT00_m4o`07
o`3oG@?o05oo0oooN@04odCo00;oo`380_oob@001?oonf[ol@3ooookJ_l03ol3o`2`o`Wo00oo00?o
oo]Zool0[?oo0:`00ooonfX2ool03003oh_o0?oob@3oolT000CoolT00ooonfX2ool0?PCo0?on00Co
0?mIo`3oo_l0ooko0?on2_l03ol01?l0on3ooo]Zooo90?l0oe<2o`1Oo`04ool0^?l0Gooo05ooon?o
00;ooe400_nDo`002Ol0ojgoU?l0oiCo0?nDo`3ooo]Zool00?oonf[o0?lHoookJP02ool0T005ooWo
0?l0o`co0;3ooooS0?ooM0000_l0o``2o`12o`05o`3oo_l0onoo0?l<o`3o3?l0/?l00_l0o``00onD
o`3o00ooo`3o[@03o`3o[@?o0?l<00Co0;3oool0l_oo0?;o0?l<0ol0ooh2o`3o[@04o`0?ool0ojgo
0?n]o`3o[@Co0?mM00?o05ooo`3oGOl0oed00_l0oed:oookJPSo05ooJooonfX2o`3o2A7ooo]Z0_oo
0:l3oookJP;oo`1W00?ooo]Zo`3oH?l0of000_oo^P02ofl0o`;ooo]Z0_oo0?87oookJP;oon800ooo
nfX01OmEo`3o0;Koo`3okol0onooo`1100;o04;o0_oonfX01OooM03oon<0ool0DOoEo`3onOl000;o
o`2@00Cooo]Zo`3o6?oo903oob@00_oonfX2oolN00;oE@3o00Go05OooomA0?ooD@3ohol0oomX0002
ool0^005o`3oTOoonf[o0?mCo`3oDooonfX00_l0on001Ooo0?3ol`3ooo<0ooooD`3ooo]Z00;oo`1c
00?oolD0o`0goooo0<d00_oonfX01_l0oeWo`03oo`2Bool0T_oof_l0ool0?PCooo]Z0_ookP001?oo
nf[oon`0ooo/0?oo7P02ool10004ool03?oonf[ooo]ZoookJP;oo`2/0_oonfX01?lTo`3o09gooolh
0?l0;Ol2oomD00;oohH000?o9_l0ool0fooonfX00_oonfX2oo40o`06oookJ_l0B?ooo`38ool0b?oo
5P3ooo]Z0_lMo`02o`3oK003oookJ_ofo`3om_l000Cooo]Z00?o09kooookJ_oonfX00_oonfX00ol0
/Ooooo]ZoookJP02oookJP03oonS0?oonf[ooo]Z013ooo]Z1?l0000JoookJP;ooj<01?oonfX2o`2a
o`?ooo]Z00?o09kooookJ_oonfX00_oonfX2ooKo0004oookJ_l0ofcooo]Zoago00;ooo]Z00?ooaH0
ool0b?oo0<P00_l0B?l00ooonf[ol@3ooookJP02oookJP04ool0folVo`3o9_l0oon600;ooe@00_l0
;Ol01?l0WOoo9?l0oookJ_oonfX2ool0[0?ooo]Z00?o04Coool03?oo0@000_oo7P001?ook03o:03o
oookJ_ookP04oookJP06ool0?_oJo`3ooo]Zo`2Booo00?oo0?mI0_oonfX00ooo0<go03Ooooo50002
ool0L`04oookJ_ooD`3ooe<0oo<0o`;oo`3`00Ko0?oPoookJ_l0oe?o0?mCoookJ_l0oi42ool0^009
oon<0?oSo`3ooo]ZoomA0?l0Eooo0?lfoeD0oooonf[ooah000;ooo]Z0_oo9002o`3o6007oookJ_oo
093onOl0o`3hoooo057oon<0oomd0002oookJP;o04;o0_oonfX2o`3ok`;oEOl00_oonfX2oooR00Oo
oo]Z00?oo`25ool0l_oonfX00_oonfX2ofl0o`03oonj0?l0of3o0?mP00;ooo]Z00Coo`1WoookJ_oo
nf[ooo]Z0_oo0:lAoookJP;o0?l9<_oonfX003oooo]Z0_l0o`TAoookJP04ool0[ooonf[ooo]Zoook
JP;oo`1W00?ooo]Zo`3oH?l0of000_oo^P02ofl0o`;ooo]Z0_oo0?800ooo08Gooo]ZoookJP05oook
JP03oooR0?oonf[ooo]Z00;oEOl000?o0;Koo`3o3?l0o``00_l0o``00ol0/?oo0?l<o`3o3004o`3o
oP04ooWo0?oo093oo`2@o`3o60?o0?l<00Co0;3oo`3o3?oo7P3ooah00_mE0?l00ol0Eooooe40oomA
0002odCo0005o`3oo_m4o`3oA?l0odCo0?nDo`000_l0oe<2o`3oh008ool0l?oc0?ool`3ooomC0?nD
o`3ooo]Zool0Loooa@02o`1Oo`;oA?l000?o0?onodCo0?l0ooh00_l0ooh01Ol0o`coolT0ooo90?oo
b@3ooo]Z00;o05oo00?o0?n]ooo/0?ook0000oooN@05odCo00Co0?on0_l0Gol01?l0;Ooo0?onoomD
0?ooQP02obKo0005ool0fooonf[o05ooo`1Ooooa0?l00ol0Gol01_oo0<SooaH0oolF0?l0ob_ooo]Z
oago00?oo`0000?om_l0ooo90?oob@000_oob@02o`2No`Go00oo0ooo:002oiCo00?o0?n]00?o00oo
oookJ_oonfX02?oonfX2oolX0003oiCo0?l0ojgo0?n]00_o00oo0ol0Gol2oomi00?oA?l00_l0ooh8
oookJPCoogT01Om4o`04o`3oG@Ko05oo00?ooo]ZodCo0?m4o`001Om4o`001ooo0<So0?l<o`3o3?l0
o`col@3ooookJ_l03ol00ol0/?l9o`0?o`03oookJ_oo0:coo`2/00?ooo]Z0_oo00`7ooo900Cooo]Z
00?oo`0nom[o0?l0ooh00_l0ooh01Ol0oeWo0?ono`3oo_l0ooko03Oo00Wo00oo00Co0?oPo`3o3?l0
o`co0?l<0_oob@02ool0^004o`1OoooSo`3ooe40oomA00;oU?l000Oo0?n]oiCo0?nDo`3oU?l0oook
J_oo903ooo]Z00;o0?lH0_oo09000ooio`3o0?l<o`2`o`02oooS00;o0?l<0_l0@_l01Ol0ooko0?o_
o`3o3?l0o`co0;3o00;o0?l<00?o0?ono`0?ool0ojd00ol0ojd01?oonf[o0?l<o`3o3?l0/?l2ool0
lP04o`3o3?l0ooko0?ono`3ooP;o0?n]00Go00ooo`3o[Ol0ojgo0?n]ool0I`03o`3oG@03o`1Oool0
oego0?mM00;o0?mM2_oonfX8o`1Oof_ooo]Z0_l0o`TAoookJP;oo`2_0ooonfX01Ooo06Oooo]Zo`3o
H?l0of3o0;Oo00;ookX000CoK`3ooookJ_oonf[ooo]Z0_oo0?87oookJP;oon800_oonfX2oeGo0004
oookJ_l0onoooo]Zool0@@;o04;o0_oonfX2oooS0007ool0DOl0n?ooo`2@ool0T?oonf[o0?lHoook
JP02oolT00;ooo]Z00Kooah0oeD0oomE0?oo0?lfo`1GooooD@02on?o0005oon<0?oo0;Soo`2hool0
0ooonfX00_l0oe<00ooonf[o0?oPool0l002oo<0o`;ooe<000?ooo]Zool0Looo07<00_l0=ol01?oo
0<gooo]Zo`3oFOl0oeT2o`2Bo`03oookJ_oo03koo`0n00Cooo]Z00Goonh0oookJ_ook03oon`0oolN
0002ool10003ool03?l0A?oooo]Z00;ooo]Z00Coo`2/oookJ_oonf[ooo]Z0_l0WOl2o`0]o`03oomD
0?ooQP3oohH000;o9_l00ooonfX2oo40o`0;oookJ_l0B?oo04Soool0b?oo5P3o0?l[oookJ_lMo`3o
oo]Zo`3oK?oonfX00oofo`03oookJP03o`2Noooonf[ooo]Z00;ooo]Z00?o0;7ooookJ_oonfX00_oo
nfX00oooX`3ooo]ZoookJP0AoookJPcoa_l04ooonfX2oonS00Cooo]Z0_l0/Ol2oookJP;o09ko1?oo
nfX01oofo`3ooo]Zo`3oK?l0ofcooo]Zoago0?oonfX00_oo5P02ool0b004o`18oooonf[ol@3ooo40
o`;ooo]Z0_oo0=/01?lVo`3oohH0oon60?ooE002o`0]o`04o`2MoolTo`3ooo]ZoookJP;oo`2/0ooo
nfX00ol0A?ooo`0<ool10002oolN0004ooo/0?lX0?oooo]Zooo^00Cooo]Z00Koo`0nom[o0?oonf[o
09;oo`3o9Ol0oeT2oookJP03ool0cOl0=oooolD000;oo`1c00?ooo]ZoomC0?ooD`000_oc0?l00ooo
0?3o0?oPoookJP02o`3oD`05oookJ_oo00?oT?l0ool0^?ooS0000_oSo`001_ooD@3o05Ooo`3o=_mE
0?oooo]ZoolN00;ooo]Z0_oo90001ooonf[o0?lHo`3o6?oo093onOl0o`3hoooo05400_ooh`02oook
JP;o04;o0_oonfX2o`3ok`;oEOl00_oonfX2oooR00Oooo]Z00?oo`25ool0l_oonfX00_oonfX2ofl0
o`03oonj0?l0of3o0?mP00;ooo]Z00Coo`1WoookJ_oonf[ooo]Z0_oo0:lAoookJP;o0?l9<_oonfX0
03oooo]Z00?o0?l9oookJ_oonfX04?oonfX01?oo0:oooo]ZoookJ_oonfX2ool0I`03oookJ_l0of3o
0?mP00;ookX00_m_0?l2oookJP;oo`3b2?oonfX00ooohP3ooo]ZoookJP02oeGo0003o`2foom4o`3o
oo]Z00;o0?l<00?o0;3oo`3o3?l0o``01?l0ooh00ooio`3oo`2@oookJP03o`3o3008o`2`ool0o`co
0?l<oolN0?oonf[oE@3oo`3o=_l0Eol2oomA00;oA?l000Oo0?onodCo0?m4o`3oA?l0oiCo0?l0oe?o
obP000;o0?oP00Goo`3`oo<0ooooD`3ooe<0oiCo0002ool0L`;o05oo0om4o`001Ol0ookoA?l0odCo
0?oob@3o0?on00CoolT00ol0Gol00olX0?ooon`0oomi0003oomi00CoA?l01?l0ooh2o`1Oo`;o02go
00Cooe@0oon60?ooQP3o9_l00_oo0=/2oookJP;ol@3o0_l0Gol2ool0b007oolF0?l0ob_ooo]Zoago
0?oonf[o0?m/ool00002ooKo0003oookJ_oob@3oolT000;o09ko1_l03ol3oolX00?oU?l000?o0?n]
oolX0?oonfX02_oonfX00ooo:03oU?l0oiCo0002o`3o[@go00oo0_ooN@03odCo00?o0?on2?oonfX2
oomi00OoA?l000?o0?ono`3oGOl0Gol01ol0Gol00ooonf[oA?l0odCo0005odCo00;oo`381?ooN@00
0ooonf[o00ooo`2`o`02o`2`o`So00oo00?ooo]Zool0[?oo0:`00ooonfX2ool030OoolT01?oonfX0
0ooo03kof_l0o`3ooP02o`3ooP05o`3oFOl0ooko0?ono`3oo_l0=ol00ol03ol00ooonf[o00ooo`0?
o`02o`0?o`03o`2`ool0on3o0?l<00;o0?l<0_oob@001?n@o`3oo`2ho`1OoooSo`02oomA00;oU?l0
00?o0?n]oiCo0?nDo`000_oonfX02Ooo903ooo]Zo`3o6?l0oaSooo]Zool0T?oio`3o0?l<o`2`o`02
oooS0006o`3o3?l0ooko04;oo`12ool0ooko0?o_0_l0o``01Ol0/?oo0?l<o`3o3?l0ooko00oo00Co
0?n]00Cooo]Zo`3o3?l0o`co0;3o0_oo0?801?l0o`cooo]Zo`3oo_l0ooh2o`3o[@03o`0?ool0ojgo
0?n]00;oo`1W0ol0oed01?l0Gooo0?mMo`3oGOl0oed<oookJPKo05ooK?oonfX00ol0o`Wooo]Zoook
JP0@oookJP03ool0[ooonf[ooo]Z00;ooo]Z00Koo`1WoookJ_l0of3o0?mPo`2goooo^P02ofl0o`;o
oo]Z0_oo0?800ooo08Gooo]ZoookJP05oookJP;oon800_oonfX01_mEo`3o0;Koo`3okol0onoooo]Z
ool0@@;o04;o00Kooo]Zoomd0?ooh`3oon<0omGo0?l0n?l2ool0T003oookJ_l0oaSoob@000;oob@0
00?ooo]ZoolN0?oo7P000_mE0?l2o`1Go`03oomA0?oSo`3oofP000;oo`2h00Go0?nAool00ooonf[o
0?mCoookJP02o`3oh004ool0l?oc0?ool`3ooomC00;ooo]Z00Soo`1cooo50?l0=ooo03Ooool0cOoo
nf[o0?mIol00o`;o09;o00?of_l0ool0?_oonfX00ooonfX2ooo^0005oookJ_ook03oon`0oolN0?oo
0@000_oo00`3oookJP;oo`2/0_oonfX01?lTo`3o09gooolh0?l0;Ol2oomD0004oon60?lVo`3o9_l0
ool0f`?ooo]Z00Gol@3ooookJ_oonf[o04Soool0b002oolF0005oookJ_lMo`3ooo]Zo`3oK?oonfX0
0oofo`03oookJP;o09ko0ooonfX00ol0/Ooooo]ZoookJP02oookJP03oonS0?oonf[ooo]Z00kooo]Z
1_o6o`02o`0000Kooo]Z1_o6o`0?oookJP;ooj<01?oonfX2o`2ao`?ooo]Z0_l0W_l3oookJP;om_l0
00?ooo]Zo`3oK?oonfX00_lMo`001?oonf[ooaH0ool0b?oo0<P2o`18o`03oookJ_oa0?oooo]Z00;o
oo]Z00Woo`3KobKo0?oonf[oohH0oomD0?oonf[o02gooolh0?lTo`000_oonfX2ool0[0?ooo]Z00Wo
04Coool03?oo0@3oo`40oolN0?ook03o:03ooookJ_ookP001?oonfX2ool0?P04oookJ_l0T_oo09;o
o`3oF@;ooo]Z00?oo`3=o`0gool0=ol00_oo07<00ooonf[ooe<0oomC0002oo<0o`0:ool0l?l0on3o
0?oPoookJ_l0oe?ooo]Zool00on@o`3oo`2hoon<00;ohol000?ooe40o`1Gool0Eol00_mE0?l00ooo
7P3ooo]ZoookJP02oolT0007oookJ_l0oaSo0?lHool0T?oio`3o0?Soool0D@02oooS00;ooo]Z0_l0
@_l2oookJP;o0?o_0_mEo`02oookJP;oon801ooonfX00ooo08Goo`3boookJP02oookJP;oK`3o00?o
okX0o`3oH?l0of000_oonfX01?oo06Oooo]ZoookJ_oonfX2ool0[a7ooo]Z0_l0o`TboookJP00?_oo
nfX2o`3o2A7ooo]Z0_oo0:l3oookJP;oo`1W00Kooo]Zo`3oH?l0]ooookX0oookJ_m_0?l2oookJP;o
o`3b00?oo`25oookJ_oonfX01OoonfX2oooR00;ooo]Z0_mEo`001om4o`3oogT0oookJ_oob@3o0?l<
o`2`ool0o``01Ol0ooh00ooio`3oo`2@oookJP03o`3o3007o`2`ool0o`cooo]ZoolN0?oonf[oE@3o
o`3o=P02oomA00?oA?l000Co0?onodCo0?m4o`3oA?l00_l0oe<2o`3oh003ool0l?oc0?ool`3o00;o
oe<000Cooo]Zool0Looo07?o05oo0om4o`001?l0ookoA?l0odCo0?m4o`06ooo900?o05oo00?oon`0
oomi0?ooN@000_ooN@001Om4o`3oogT0oomi0?ooN@3oA?l000;oU?l000?o0?ono`1Oool0Gol00_l0
;Ol00ol0Gooooe@0oon60002obKo0003ool0fooonf[ooo]Z00;ol@3o00Co0?mMo`1Oool0Goooo`38
0_oo5P001?oonf[o7Ol0oookJ_l0of`2oookJP04ooKo0?oonf[ooo]Zo`0?o`;o09ko1ol03ol00ooo
nf[oobP0oolX0003oiCo0003oolX0?oonf[ooo]Z00Oooo]Z0ooo00001?oo:03oU?l0oiCo0?l0ojd@
o`0?o`03odCo0?l0ooko0?on00Co0?on2?oonfX5odCo00Go0?on2Ol0Gol00ooo003oA?l0odCo0002
odCo00SoogT00_oonfX00ol03ooo0;3oo`2`o`08o`0?o`;ooo]Z00Coo`2/oookJ_oonf[ooo]Z0_oo
00`7ooo900Cooo]Z0_oo03h3o`3ooP;o0?mI00Co0?onool0cOl0=oooolD00_l03ol00ooonf[o00oo
o`0?o`02o`0?o`03o`2`ool0on3o0?l<00;o0?l<0_oob@001?n@o`3oo`2ho`1OoooSo`02oomA00;o
U?l000?o0?n]oiCo0?nDo`000_oonfX01Ooo903ooo]Zo`3o6?l0oaSooo]Z00;oo`2@00Ko0?l<o`2`
ooooh`3oon<0o`3o3?l0ooh2o`12o`05o`3oo_l0onoo0?o_o`3o3?l0/?l00_l0o``00ol0ooko00oo
o`3o[@03o`3o[@;ooo]Z00Ko0?l<o`2`oooo0?;oo`3bo`3o3?oonfX3o`3ooP04o`3o[Ol03ooo0?n]
o`3o[@;oo`1W0ol0oed01?l0Gooo0?mMo`3oGOl0oed<oookJPKo05ooJooonfX2o`3o2A7ooo]Z0_oo
0:l3oookJP;oo`1W00?ooo]Zo`3oH?l0of000_oo^P02ofl0o`;ooo]Z0_oo0?88oookJP09oooR0?oo
nf[ooo]ZoookJ_mEo`3o0;Koo`3okooonf[oo`1100;o04;o0_oonfX01OooM03oon<0ool0DOoEo`3o
nOl000;oo`2@00Cooo]Zo`3o6?oo903oob@00_oonfX2oolN0004oeD0ool0ocKo05OooomA00;ohol0
00GoofP0ool0^?oo0;So0?nAoookJP02o`3oD`04oookJ_l0on3o0?oPool0l0;ol`3o00Cooe<0oook
J_oo07?oo`1c0_l0=ol01ooo0<gooo]Zo`3oFOl0oeWo0?lUo`2BoooonfX00_oo03h4oookJP;oonh0
00Go0?l/ooo/0?oo7P3ooah0ool10002ool030?ooo]Z00Coo`2/oookJ_oonf[ooo]Z0_l0WOl2o`0]
o`05oomD0?ooQP3oohH0obKo0?oo0=/00ooonfX2oo40o`06oookJ_l0B?oo04Soool0b?oo5P3ooo]Z
0_lMo`02o`3oK003oookJ_ofo`3om_l000?ooo]Z0_l0W_l3oookJP;o0;7o0ooonfX2oonS00kooo]Z
1?o6o`000ooonf[o0<coo`3<o`0=o`3<o`03oookJ_o6o`3oa_l000;oa_l03OoonfX2oonS00Cooo]Z
0_l0/Ol3oookJP03o`2Noooonf[ooo]Z00;ooo]Z00Oom_l0oookJ_l0ofco0?m/oookJ_lMo`3ooo]Z
00;ooaH000Goo`38o`18ool0B?oooo]Zoo40o`03oookJP04ool0folVo`3o9_l0oon600;ooe@000?o
02gooolh0?l0WOl00ooonfX00ooo0:cooo]ZoookJP02oookJP04ool03?oo0@3oo`40oolN00;oon`0
00?ooo]Zooo^0?ookP000ooonfX2ool0?P03om[o0?l0T_oo09;o00;o0?mI00Cooo]Zool0cOl0=ooo
03Oo0_oo07<00ooonf[ooe<0oomC0002oo<0o`0:ool0l?l0on3o0?oPoookJ_l0oe?ooo]Zool00ol0
oi7oo`2hoon<00;ohol000?ooe40o`1Gool0Eol00_mE0?l00ooo7P3ooo]ZoookJP02oolT0003oook
J_l0oaSo0?lH00;oo`2@00Co0?SoomGo0?ooh`3oon<00_oonfX2o`12o`04ool0@Ooonf[o0?o_o`3o
k`;oEOl00_oonfX2oooR00Oooo]Z00?oo`25ool0l_oonfX00_oonfX2ofl0o`03oonj0?l0of3o0?mP
00;ooo]Z00Coo`1WoookJ_oonf[ooo]Z0_oo0:lAoookJP;o0?l9<_oonfX003kooo]Z0_l0o`TAoook
JP04ool0[ooonf[ooo]ZoookJP?oo`1W00Cooo]Zo`3oH?oo^P3ookX00_m_0?l2oookJP;oo`3b00?o
o`25oookJ_oonfX01OoonfX2oooR0006oookJ_mEo`3oEOl0o`2foom4o`3oogT00_oob@000ol0/?oo
olT0o`3ooP04o`3ooP03ooWo0?oo093oo`2@00Co0?l<00Oo0;3oo`3o3?oo7P3ooah0oeD0oooonf[o
0?lf00;ooe400_m4o`000ol0ookoA?l0odCo0002odCo00;o0?mC0_l0on002?oo0?3ol`3oool0eooo
D`3o00oooookJ_oo07?o05oo1?m4o`001Ol0ookoA?l0odCo0?m4o`3oo`0n00CoolT00ol0Gol00olX
0?ooogT0oomi0007oomi0004oiCo0?oo:03oA?l0odCo00;o05oo0_l0;Ol01?l0GoooohH0oon60?lV
o`02ool0f`03oookJ_l0oegol@3o00?o0?mM00[oo`38o`1Ooooo5P3o05oooookJ_lMo`3ooo]Zo`3o
K?oonf[om_l00ooonfX00ol03ooo09koo`0?o`07o`0?o`;oo`000_oo:0001?nDo`3oobP0oookJ_oo
nfX;ool00004oolX0?nDo`3oU?l0o`3o[A7o00oo00?o0<coo`3oo_l0ooh00ol0ooh8oookJP?oA?l0
1ol0ooh00ol0oego05ooo`1Oo`06o`1Oo`03ool00?l0ooko0?on00;o0?on2?ooN@02oookJP04o`0?
ool0/?oo0;3oo`2`o`Oo00oo0_oonfX00ooo0:cooo]ZoookJP02oookJP;oo`0<0_oob@001Ol0o`co
olT0ooo90?oob@3oonh000?ooo]Z0_oo03h00ooJo`3o0?ono`3ooP02o`3oF@04o`3oo_oo0<go03Oo
o`0go`;o00oo00?ooo]ZoomC0?l03ol00_l03ol00ol0/?oo0?oPo`3o3002o`3o30;oogT000?oT?l0
ool0^?l0Gol00_oSo`02oomA0004oiCo0?l0ojgo00oooiCo00;ooo]Z00Goob@0oookJ_l0oaSo0?lH
oookJP02ool0T006o`3o3?l0/?ooon<0oooS0?l0o`co0?on0_l0@_l9o`2`o`?o0?n]0ooonfX01_l0
o`co0;3oool0l_oo0?;o0?l<oookJP?o0?on00Co0?n]o`0?ool0ojgo0?n]0_oo06L01?oonf[o0?mM
o`3oGOl0Gol3o`3oG@cooo]Z1_l0Gom[oookJP;o0?l94OoonfX2ool0[`?ooo]Z0_oo06L00ooonf[o
0?mPo`3oH002oonj0004ofl0oooonf[ooo]ZoookJP;oo`3b1ooonfX2oooR00;ooo]Z0_mEo`001?oo
nf[o0?o_oookJ_oo0442o`12o`;ooo]Z0_ooh`001Ooo057o0?Soool0T?oo093ooo]Z00;o0?lH0_oo
9002oookJP06oolN0?mE0?ooE@3oo`3o=_l0Eooooe400_oSo`001OooS03oo`2hool0^?oo00?ooo]Z
00;o0?mC00?obP3oo`3oh?oo0?000_oc0?l2oomC0003oookJ_oo07?oo`1c00;o03Oo00Coo`3=oook
J_l0oeWo0?mI0_l0T_l00ooJo`3oo`0noookJP03oookJP;oonh000Gooo]Zooo/0?ook03ooah0ool1
0002ool030?ooo]Z0_oo0:`2oookJP;o09go00?oocP0o`0]ooooE0000_ooQP02obKo0005ool0fooo
nf[ooo]ZoookJ_oa0?l00_oonfX02Ol0B?ooo`38oolF0?l0ob_ooo]Zoago0?oonf[o0?m/oookJP02
ooKo00Cooo]Z00Co09kooookJ_oonf[ooo]Z0_l0/Ol3oookJP;ooj<03OoonfX3olKo00Ko0<co2onn
0?l5o`3<o`?oa_l03OoonfX2oonS00Cooo]Z00Co0;7ooookJ_oonf[ooo]Z0_l0W_l3oookJP;om_l0
0_l0of`01Ooonf[o7Ol0oago0?oonf[ooaH000;oo`3800Co04SooookJ_oa0?ool@3o0_oonfX00ooo
0=_ooo]ZobKo0002oon60005oomD0?l0;Ooo02goo`2MoolTo`000_oonfX00ooo0:cooo]ZoookJP02
oookJP;oo`0<00Goo`40oolN0?ook03oon`0oookJP02ooo^00Cooo]Z00Coo`0nom[o0?oonf[o09;o
0_l0oeT01_oonf[oo`3=o`0gool0=oooolD0ool0L`;ooo]Z00Cooe<0oo<0oooc0?ooo`3`0_l0on00
2Ooonf[o0?mCoookJ_oo00?o0?nAool0^?n@o`3oofP0on?o0002oomA0004o`1GoomE0?ooE@3ooolN
00;ooo]Z0_oo90000ooonf[o0?lHo`3o6002ool0T004o`3hoooEo`3oon<0oooS00;ooo]Z0_l0@_l0
1?oo047ooo]Zo`3okol0onl2oeGo00;ooo]Z0_oohP07oookJP03ool0QOoo0?;ooo]Z00;ooo]Z0_m_
0?l01_oo^P3o0?mPo`3oH?l0of3ooo]Zool0I`?ooo]Z0_oo0:lAoookJP;o0?l9<_oonfX003kooo]Z
0_l0o`TAoookJP04ool0[ooonf[ooo]ZoookJP;oo`1W00?ooo]Zo`3oH?l0of000_oo^P02ofl0o`;o
oo]Z0_oo0?800ooo08Gooo]ZoookJP05oookJP03oooR0?oonf[ooo]Z00;oEOl000?o0;KoodCo0?oo
N@000_oob@000ol0/?ooolT0o`3ooP04o`3ooP03ooWo0?oo093oo`2@00?o0?l<00?o0;3oo`3o3?l0
o``00_oo7P000omE0?oo0?lfo`1Go`02oomA0003oolX0?ooN@3o0?on00CoA?l000?o0?mCo`0?ool0
on000_oo0?001?oc0?oooe<0oomC0?oonfX2ool0L`CoA?l000?o0?onodCo0?m4o`000_m4o`000ooo
03koolT0ooo90002ooo900?o05oo00?oU?l0ooo/0?nDo`001oooN@000ooo:03oA?l0odCo0002o`1O
o`;o02go0_l0Gol01_ooQP3o9_l0obKo0?oo0=_ooo]Zo`3oG@;ol@3o0_l0oed2ool0b007o`1Oool0
ob_ooo]Zoago0?oonf[o0?m/oookJP02ooKo00;ooo]Z00?o0?n]o`2Nool03ol01ol03ol3ool000?o
obP00ooonfX;ool00003oolX0?nDo`3oU?l000;oU?l00ooo:0000ol0003ooo]ZoookJP03oookJP?o
_P3o0_m4o`001?l0ooko0<coo`3<ool0c?l4o`3ooPWooo]Z00?oA?l0o`3oo_l0ooh01_l0ooh00ooo
nf[o05ooo`1Oo`05o`1Oo`;om_l01Ol0ooh7oomi0004oo40oooonf[ooo]Zo`0?o`;o0;3o1ol03ol2
oookJP;oo`2/0ooonfX2ool030;oolT01Ol0o``4oookJP03ool0?_oJo`3o0?on00;o0?on00?o0?mI
o`3oo_oo0<d00_l0=ol01?l0ooko00oooookJ_ooD`03o`0?o`03o`2`ool0on3o0?l<00;o0?l<0_oo
N@001On@o`3oo`2hoon<0?oSo`3o0?n]00;ooe400_l0ojd01?l03ooo0?n]o`3o[Ol0ojd2oolT00;o
0?lH00?ooo]Zool0T?oo:0000_oo:002oooS00?oobP000?o04;oo`2`ool0/?l01ol0/?l3o`3o[@?o
oo]Z00Oo0?l<o`2`oooo0?;oo`3bo`3o3?oonf[oK`3o00;o0?on0_l0ojd01Ol03ooo0?n]ool0Iooo
06Oooo]Z00;o0?mM00Co05ooo`3oGOl0oego0?mM3?oonfX6o`1Oof_ooo]Z0_l0o`TAoookJP;oo`2_
0ooonfX02?oo06Oooo]Zo`3oH?l0of3o0;Oooonj0?oonf[oK`3o0ooonfX2ool0lPOooo]Z0_oohP02
oookJP06oeGo0?l0]_ooo`26o`3okooonf[oo`110_l0@_l01_oonf[oog@0oooS0?ooh`3oeOl0o`3h
o`;oo`2@00?ooo]Zo`3o6?oonfX00_oo90000ooonf[ooah0oolN0002oeD0o`09o`1GooooD@3ooe40
on?o0?ooJ03oT?l0ool0^?l0oi7oo`0300;o0?mC00Cooo]Zo`3oh?l0on3oo`3`0_oc0?l02?ooD`3o
oo]ZoookJ_oo07?oolD0o`0goooo0<gooo]Z0_l0oeT01Oo00?oo09;oo`2BoooJo`3oo`0n00Cooo]Z
0_ookP001OlX0?ooon`0oolN0?oo7P3oo`4000;oo`0<0ooonfX01?oo0:cooo]ZoookJ_oonfX2o`2M
o`04o`0]ool0Hooooe@0oon600;o9_l000Coo`3KoookJ_oonf[ooo]Z0_oa0?l00ooonf[o04Soool0
b002oolF0005oookJ_lMo`3ooo]Zo`3oK?oonfX00oofo`03oookJP04o`2Noooonf[ooo]ZoookJP;o
0;7o0ooonfX2oonS00cooo]Z0oo6o`04o`3<o`Go_P3o0_l00006oookJPGo_P3o1?l0c?l00ooonf[o
a_l0olKo000<oookJP;ooj<00ooonfX2o`2ao`?ooo]Z00?o09kooookJ_oonfX00_oonfX01?ofo`3o
oo]Zo`3oK?oonfX2oago0005oookJ_oo5P3oo`38ool0b?l0B?l00_oonfX01_oa0?oooo]ZoookJ_oo
nf[oo`3KobKo00;oohH000Gooe@0o`0]ool0;Ooo09goobCo0002oookJP;oo`2/0ooonfX00ol0A?oo
o`0<ool10002oolN0004ooo/0?lX0?oooo]Zooo^00Cooo]Z00Koo`0nom[o0?oonf[o09;ool00ool0
oeT2oookJP04ool0cOl0=oooolD0ool0L`;ooo]Z00Cooe<0oo<0oooc0?ooo`3`0_l0on002Ooonf[o
0?mCool06ooo00?o0?nAool0^?n@o`3oofP0on?o0002oomA0004o`1GoomE0?ooE@3ooolN00;ooo]Z
0_oo90000ooonf[o0?lHo`3o6002ool0T004o`3hoooEo`3oon<0oooS00;ooo]Z0_l0@_l01_oo047o
oo]Zo`3okol0onoo0;KooeGo00;ooo]Z0_oohP07oookJP03ool0QOoo0?;oon@000;ooo]Z0_m_0?l0
1_oo^P3o0;Ooo`3oH?l0of3ooo]Zool0I`?ooo]Z0_oo0:lAoookJP;o0?l9<_oonfX003kooo]Z00?o
0?l9oookJ_oonfX03ooonfX2ool0[`?ooo]Z0_oo06L00ooonf[o0?mPo`3oH002oonj0006ofl0oooo
nf[ooo]ZoookJ_oo0?;oo`251ooonfX2oooR00;ooo]Z0_mEo`001_m4o`3oogT0ooo90?oob@3o0?l<
o`2`o`Ko0?on00?onOl0ool0T?l0o``00ol0o``01?l0/?oo0?l<o`3o3?oo7P02oeD0o`07o`3o=_l0
Eooooe40on?o0?ooN@3o0?onodCo0002oomi00;oA?l000Co0?mCo`3oh?l0on3oo`3`0_oc0?l01?oo
D`3o00oooookJ_oo07<3o`1Oo`KoA?l000Kof_l0ooo90?oonf[ooo]Zo`1Ooooob@03o`1Oo`;oon`0
0_nDo`05oomi0003oolX0?m4o`3oA?l000?o05oo0_l0;Ol01Ol0GoooohH0oon60?lVo`3oo`3K00?o
oo]Z00Sol@3oo`3oGOl0oego0?mMool0b?oo5P3o05oooookJP;o7Ol00_l0of`01Ooonf[om_l0oook
J_oonf[o0?n]00;o09ko00?o0?n]o`0?ool03ol00ol03ol4ool000;ooo]Z00?oobP0oookJ_oonfX0
0_oonfX;ool000?oobP00_oonfX4o`0000[ooo]Z00CoA?l0o`3oo_l0ooko0?on0_l0c?l3o`3ooPWo
oo]Z2?l0ooh00ol0/Ooooo]Zo`1Oo`05o`1Oo`;om_l000?oo`00o`3oo_l0ooh00_l0ooh4oomi00Co
A?l00ooonfX3o`2`o`Ko00oo0_oonfX2ool0[0?ooo]Z0_oo00`7o`3o30Cooo]Z00?oo`0nom[o0?l0
ooh00_l0ooh00ol0oeWo0?onool0c@02o`0go`03ooo50?oo07?ooo]Z00;ooe<00_l03ol03?l0/?oo
0?oPo`3o3?oob@3o0?l<ooo90?ooN@3oT?l0ool0^?ooS03ohol0o`3o[@;ooe400_l0ojd01?l03ooo
0?n]o`3o[Ol0ojd2oolT00;o0?lH00?ooo]Zool0T?oo:0000_oo:002oooS00?oobP000?o04;oo`3o
o_l0/?l01ol0/?l3o`3o[@Cooo]Z00?o0?l<ool0l_oo0?800ol0/?l8o`0?o`04oookJ_l0oego0?mM
o`1Oo`?o0?mM3OoonfX5o`1Oof_ooo]Z00?o0?l9oookJ_oonfX04?oonfX01?oo0:oooo]ZoookJ_oo
nfX2ool0I`03oookJ_l0of3o0?mP00;ookX00_m_0?l2oookJP03oooT0?oo0?;oo`2500Oooo]Z0_oo
hP02oookJP05oeGo0?l0]_oo0?o_o`3okooonfX00_l0@_l2oookJP05oomd0?ooh`3oon<0omGo0?oi
o`000_oo09001?oonf[o0?lHoolT0?oo9002oookJP;ooah000CoE@3oo`3o=_l0Eooooe400_oSo`00
1OooJ03oo`2hool0^?l0oi7ooo]Z00;o0?mC00Gooo]Zo`3oh?l0on3oo`3`oo<0o`02oomC0003oook
J_oo07?oo`1c00;o03Oo00Ooo`3=oookJ_l0oeWo0?mIo`3o9Ol0T_oof_l000;oo`0n1?oonfX02Ooo
kP3ooo]Zo`3o;?ook03ooah0oh_o0?oo0@3oo`0<o`14o`02oookJP;oo`2/0_oonfX2o`2Mo`03oolh
0?l0;Ooooe@000;oohH00_lVo`04oookJP07oo40oooonf[o04Soo`18oooo0<SooaH0oookJP02oago
00;o0?m/00?ooo]ZooKo0?ofo`000ooonfX01?l0W_oooo]ZoookJ_oonfX2o`2ao`?ooo]Z0_ooX`0<
oookJP;oa_l000?ooo]Zo`3<ool0c?l00onn0?l3oookJPCo00002_oonfX3okh0o`04oookJ_l0c?oo
0<cooookJP;oa_l03?oonfX00oooX`3ooo]ZoookJP02oookJP;o0;7o0_oonfX2o`2No`?ooo]Z0_of
o`02o`3oK003oookJ_lMo`3ooo]Z00;ooaH00_oo0<P00ol0B?oooo]Zoo40o`03oookJP09ool0folV
o`3ooo]Zoon60?ooE03ooo]Zo`0]oooo>03o9?l000?ooo]Z00Ooo`2/oookJ_oonf[ooo]Zo`14oooo
00coo`4000;ooah000Coon`0obP0oooonf[oonh01?oonfX01_oo03kof_l0oookJ_l0T_oo`03oo`3o
F@;ooo]Z00Coo`3=o`0gooooa@3oo`1c0_oonfX01?ooD`3ol`3ooo<0oooo0?02o`3oh005oookJ_l0
oe?oo`0KoookJ_l0oi400_oo0;P01OooJ03ohol0oomA0?ooD@3o05Oo00;oE@3o0_oo7P02oookJP04
oolT0?oonf[o0?lHo`3o60;oo`2@00Co0?SoomGo0?ooh`3oon<00ooonfX00ol0@_ooo`11oookJP02
o`3ok`04o`2foomEo`3ooo]ZoookJP;oon801ooonfX00ooo08Goo`3boooT0002oookJP;oK`3o00Go
okX0o`2gool0of3o0?mPoookJP02ool0I`?ooo]Z00?oo`2_oookJ_oonfX03ooonfX2o`3o2C;ooo]Z
000noookJP03o`3o2Ooonf[ooo]Z00oooo]Z0_oo0:l2oookJP?oo`1W00?ooo]Zo`3oH?oo^P000_oo
^P000om_0?oooo]ZoookJP02ool0lP03ool0QOoonf[ooo]Z00Gooo]Z0_oohP02oookJP;oEOl000Ko
0?o_oomi0?oob@3oolT0o`2`oooob@06o`3ooP;oo`2@1?l0o``01?l0/?oo0?l<oolN0?oo7P02oeD0
o`03o`1GooooD@3ooe4000?oogT000KoA?l0oomi0?ooN@3oobP0o`3oDooonfX2o`3oh007ool0l?oc
0?ooo`3GoomC0?l03ooo05ooool0L`03o`1Oo`;oogT01?m4o`000ooo03koolT0oookJP06o`1Oo`;o
on`00_nDo`000oooN@3oo`0<oomi0002oomi00;oA?l00ol0Gol2o`0]o`;o05oo00CoohH0obKo0?l0
ojgoo`3K0_oonfX2oo40o`04onGo0?l0oegoo`38ool0b0;o05oo00Kooo]Zoago0?oonf[o0?m/oook
J_ofo`03oookJP;o09ko0ol0ojd3o`0?o`Goo`002?oonfX9ool00003okh0oooonf[ooo]Z00?ooo]Z
1?l0000;oookJP04odCo0?l0ooko0?ono`3ooP;o0<co0_l0ooh00oo6o`3ooo]ZoookJP07oookJPOo
0?on00?o0;7ooookJ_oonfX01Ol0Gol00ooonf[om_l0ool00004o`3ooPSoA?l00ooonfX00ooo0=_o
0;3oo`2`o`05o`0?o`05obCo0?oonf[ooo]ZoookJ_oo0:`00ooonfX2ool030Oo0?l<1?oonfX00ooo
03kof_l0o`2Bo`02o`3ooP03o`3oFOl0ookoo`3=00;o03Oo00?oolD0ool0LooonfX00_ooD`02o`0?
o`08o`2`ool0on3o0?oPooo90?l0o`coolT0oomi0?n@o`02ool0^0;ohol00_ooD@02o`3o[@04o`0?
ool0ojgo0?n]o`3o[@;oob@00_l0oaP00ooonf[oo`2@oolX0002oolX00;oon<00ooo:0000ol0@_oo
0?ono`2`o`06o`2`o`05o`0?ool0ojgo0?n]o`3o[OoonfX01Ol0/?l01?oo0?;o0;3oo`2`ool0/?l8
o`0?o`;ooo]Z00Co0?mMo`1Oool0oego0?mM3_oonfX4o`1Oofcooo]Z00?o0?l9oookJ_oonfX03ooo
nfX2ool0[`?ooo]Z0_oo06L00ooonf[o0?mPo`3oH002oonj00;oK`3o0_oonfX2ool0lPOooo]Z0_oo
hP02oookJP;oEOl000Co0;Koo`3okooonf[ooo]Z0_l0@_l2oookJP;oon<000Gooo]Zo`3hoooio`3o
o`2@oookJP02o`3o60;oob@00_oonfX00ooo7P3oE@3ooeD0o`02o`1Go`04oomA0?oSo`3oofP0oon<
00;oo`2h00Ooo`03oookJ_l0oe?oo`0KolX0ool0on3oo`3`00;ol`3o00?ooe<0oookJ_oonfX00_oo
07<2o`0go`04ool0cOoonf[o0?mIo`3oF@;o09;o00?of_l0ool0?_oonfX00ooonfX2ooo^0005oook
J_ook03oon`0oolN0?oo0@000_oo00`3oookJP04ool0[?oonf[ooo]ZoookJP;o09go00Co02goo`1S
ooooE03oohH00_lVo`001Ooo0=_ooo]ZoookJ_oonf[ol@3o00;ooo]Z00Wo04Soool0b?oo5P3ooaH0
oookJ_lMo`3ooo]Zo`3oK?oonfX00_ofo`03oookJP;o09ko0ooonfX00ol0/Ooooo]ZoookJP02oook
JP03oonS0?oonf[ooo]Z00Wooo]Z0_o6o`000ooonf[o0<coo`3<o`03okh0o`Gooo]Z1?l0000=oook
JP;o_P3o0_l0c?l00ooonf[oa_l0olKo000;oookJP;ooj<00ooonfX2o`2ao`?ooo]Z0_l0W_l2oook
JP;om_l000?ooo]Zo`3oK?oonfX00_lMo`001ooonf[ooaH0ool0b?oo0<So04SooookJ_oa0?l00ooo
nfX02Ooo0=_o9_l0obKo0?ooQP3ooe@0oookJ_l0;OooocP0obCo0003oookJP03ool0[?oonf[ooo]Z
00;ooo]Z00Soo`0<ool10?oo0@3ooah0ooo/0?lX0?oooo]Zooo^00Cooo]Z00Koo`0nom[o0?oonf[o
09;oo`3o9Ol0oeT2oookJP04ool0cOl0=oooolD0ool0L`;ooo]Z0_ooD`001Ooc0?ooo`3`o`3oh?l0
on3ooo]Z00;o0?mC00Kooo]Zo`3oTOoo0;Soo`2hoomX0?oSo`02oomA0003o`1GoomE0?ooE@3o00;o
oah00_oonfX01?oo903ooo]Zo`3o6?l0oaP2ool0T005o`3hoooEo`3oon<0oooS0?ooM0000_oonfX0
0ol0@_ooo`11oookJP02o`3ok`04o`2foomEo`3ooo]ZoookJP;oon801ooonfX00ooo08Goo`3bool0
lP02oookJP;oK`3o0_oo^P02o`3oH003oookJ_oo06Ooo`1W00?ooo]Z00?oo`2_oookJ_oonfX03ooo
nfX2o`3o2C;ooo]Z000moookJP;o0?l94OoonfX01?oo0:oooo]ZoookJ_oonfX2ool0I`03oookJ_l0
of3o0?mP00;ookX00_m_0?l2oookJP;oo`3b00?oo`25oookJ_oonfX01OoonfX2oooR0005oookJ_mE
o`3oEOl0o`2fool0onl00ooob@000ol0o`co0?ono`3ooP05o`3ooP;oo`2@00Co0?lHo`3o3?l0o`co
0;3o0_l0o``2oolN0003oeD0ool0ocKo05Oo00;ooe400_ooN@002?m4o`3oogT0oomi0?ooN@3oobP0
o`3oDooonf[o0?oP0_oo0?001?oc0?oo0?n]oomC0?l03ol2ool0L`;o05oo0oooN@001om4o`3oogT0
oomi0?m4o`3oolT0ool0?_oonfX01_l0Gol01Oook03oobP0oolX0?ooN@3oo`0<00;oU?l000?ooo]Z
oomi0?oo:0001?l0Gol2o`0]o`;o05oo00?oohH0obKo0?oo0=/00_oonfX00ooUo`3ol@3oonGo0002
onGo0006ool0b?l0Gooo05oooookJ_lMo`3ooo]Z0_l0of`2ooKo00;ooo]Z0_l0W_l2oiCo00?o0?n]
1_oo0009oookJPOoo`0000?o00oooookJ_oonfX01OoonfX4o`0000cooo]Z00CoA?l0o`3oo_l0ooko
0?on0_l0c?l00ol0ookoa_l0olKo0008oookJP03odCo0?l0ooko0?on00Co0?on00?ooo]Zo`2aoooo
nfX01Ol0Gol01?oonf[om_l0ooKo0?oo0003o`3ooPSoA?l000Ool@3ooookJ_oonf[oo`3KobKo0?l0
/?ooohH000Co00oo00Go09gooookJ_oonf[ooo]Zool0[003oookJP;oo`0<1ol0o``4oookJP03ool0
?_oJo`3ooo]Z00;o0?on00?o0?mIo`3oo_oo0<d00_l0=ol00oooa@3oo`1coookJP02oomC00;o00oo
00So0;3oo`3oh?l0on3oolT0o`3o3?oob@3oogT0oi3o00;oo`2h0_oSo`02oomA00;o0?n]00Co00oo
o`3o[Ol0ojgooo]Z0_oo9002o`3o6003oookJ_oo093oo`2@00;oobP00_ooh`02oolX0003o`3oo_l0
@_oo0?on00Oo0;3o00Go00ooo`3o[Ol0ojgo0?n]oookJP05o`2`o`04ool0l_l0/?oo0;3oo`2`o`So
00oo0_oonfX01?l0oego05ooo`3oGOl0oed>oookJPCo05ooJooonfX2o`3o2A7ooo]Z0_oo0:l3oook
JP03ool0Iooonf[o0?mP00;o0?mP00?ookX0oookJ_m_0?l00ooonfX2ool0lPOooo]Z0_oohP02oook
JP;oEOl000Coo`26o`3okooonf[oo`110_l0@_l01_oonf[oog@0oooS0?ooh`3oeOl0o`3ho`;oo`2@
00?ooo]Zo`3o6?oonfX00_oo90000ooonf[ooah0oolN0002oeD0o`09o`1GooooD@3ooe40on?o0?oo
J03ooh`0ool0^?l0oi7oo`0300;o0?mC00Cooo]Zo`3oh?l0on3oo`3`0_oc0?l02?ooD`3ooo]Zoook
J_oo07?oolD0o`0goooo0<gooo]Z0_l0oeT00oo00?oo09;oom[o0002ool0?PCooo]Z00Woonh0oook
J_lX0?ooon`0oolN0?n;o`3oo`40ool03?l0A?l00ooonfX02_oo0:cooo]ZoookJ_oonf[o09gooolh
0?l0;Ooooe@0o`07ooooQP02obKo0006ool0fooonf[ooo]ZoookJ_oa0?oooo]Z0_l0B?l00ooo0<So
oaH0oookJP02oago00;o0?m/00?ooo]ZooKo0?oonfX00_oonfX2o`2No`?ooo]Z00?o0;7ooookJ_oo
nfX00_oonfX00oooX`3ooo]ZoookJP09oookJP;oa_l000Cooo]Zo`3<ool0c?oo_P3o2?oonfX4o`00
00kooo]Z0_nn0?l00ooonf[o0<cooookJP02olKo00_ooo]Z00?ooj<0oookJ_oonfX00_oonfX2o`2a
o`;ooo]Z0_l0W_l3oookJP03ooKo0?oonf[o0?m/00;ooo]Z00?o7Ol0oookJ_oo5P000_oo0<P01?l0
B?oooo]Zoo40oooa0?l2oookJP04ool0fooonf[o9_l0oon600;ooe@00_l0;Ol01Ol0WOoo9?l0oook
J_oonf[oo`2/00Cooo]Z00Coo`0<ool10?oo0@3ooah00_ook0000ooonf[oonh0oookJP03oookJP;o
o`0n00Cooo]Zo`2Bool0T_oo0?mI0_oonfX01?oo0<go03Ooooo50?oo07<2oookJP;ooe<000Gol`3o
ool0l?oo0?3o0?oPoookJP02o`3oD`06oookJ_l0oi7oo`2hool0^?ooS03ohol00_ooD@000ol0Eooo
E@3ooeD0o`02oolN00;ooo]Z00Coob@0oookJ_l0oaSo0?lH0_oo09001Ooio`3oeOl0oooS0?ooh`3o
og@000;ooo]Z00?o04;oool0@OoonfX00_l0onl01?l0]_ooEOl0oookJ_oonfX2oooR00Oooo]Z00?o
o`25ool0l_oo0?800_oonfX2ofl0o`;ookX00_l0of000ooonf[oo`1Wool0I`03oookJP03ool0[ooo
nf[ooo]Z00oooo]Z0_l0o`TboookJP00?OoonfX2o`3o2A7ooo]Z00Coo`2_oookJ_oonf[ooo]Z0_oo
06L00ooonf[o0?mPo`3oH002oonj00;oK`3o0_oonfX2ool0lP03ool0QOoonf[ooo]Z00Gooo]Z00?o
on80oookJ_oonfX00_mEo`001Ol0]_ooolT0ooo90?oob@3o0?l<00So0?on00?oo`2@oookJ_l0oaP0
0_oob@001?l0/?oo0?l<o`3o3?oo7P02oeD0o`04o`3o=_l0Eooooe40oomA00;oogT000WoA?l0oomi
0?ooN@3oogT0oolX0?l0oe?ooo]Zo`3oh?oo0?000_oc0?l01?ooD`3oobP0o`1Ooooo07<2o`1Oo`?o
ogT000OoA?l0oomi0?ooN@3oogT0om[o0?oo03kooo]Z00Ko05oo0_ook002oolX00;oo`0<00CoobP0
oiCo0?oonf[oobP01?l0Gol3o`0]o`;o05oo0_lVo`000ooo0=_ooo]ZonGo0002oo40o`;oiOl00_oo
0<P2o`1Oo`06oookJ_lMo`3o0?m/o`3oK?oonf[om_l00ooonfX2o`2No`?oU?l000?o0?n]ool00?oo
00001Ooo0009oookJPKoo`0000?o00oooookJ_oonfX01_oonfX4o`0000kooo]Z1?l0ooh00ol0c?oo
0?onolKo0009oookJPKo0?on00Cooo]Zo`2aoooonf[ooo]Z1Ol0Gol00ooonf[om_l0ool00004o`3o
oPOoA?l000Col@3ooookJ_oonf[oo`3K0_lVo`000oooQP3o00ooo`0?o`02o`0?o`05o`2Moooonf[o
oo]ZoookJ_oo0:`00ooonfX00ol0A?ooo`0<o`3o3002o`3o3004o`2`ool0o`co0?l<o`3o30Cooo]Z
0_oo03h00ooonf[o0?ono`3ooP02o`3oF@;oo`3=00Co03Ooooo50?oo07?ooo]Z0_ooD`000ooc0?oo
00ooo`2`o`02o`3oh0;o0;3o0_l0o``01On@o`3oo`2hool0^?ooJ03ohol000;ooe400_l0ojd01?l0
3ooo0?n]o`3o[OoonfX2oolT0003oookJ_l0oaSooo]Z00;oo`2@0ooo:0001Oooh`3oobP0oolX0?l0
ooko04;o00;o0?on1_l0/?l00ol03ooo0?n]o`3o[@02oookJPGo0;3o00Goo`3bo`2`ool0/?oooo]Z
ofl0o`06o`0?o`05ool0Iooonf[ooo]Zo`3oGOl0Gol00_l0oed?oookJP?o05ooJooonfX2o`3o2A7o
oo]Z0_oo0:l3oookJP06ool0Iooonf[o0?mPo`3oH?l0]ooookX00_m_0?l3oookJP;oo`3b1ooonfX2
oooR00;ooo]Z00OoEOl0o`2fool0onoo0?o_oookJ_oo047o04;o00;ooo]Z00Goog@0oooS0?ooh`3o
eOl0ooWo0002ool0T003oookJ_l0oaSooo]Z00;oob@000Kooo]ZoolN0?oo7P3oE@3oo`3o=_l0Eol2
oomA0006on?o0?ooS03oo`2hool0^?l0oi7ooo]Z0_l0oe<01Ooonf[o0?oPo`3oh?oo0?3ol`3o00;o
oe<000Oooo]Zool0Looo07?oolD0o`0goooo0<gooo]Z00;o0?mI00?o0?lUo`2BoooJo`000_oo03h4
oookJP05ooo^0?oonf[o0?l/ooo/0?oo7P000_oo0@001?oo00cooo]ZoookJ_oonfX2ool0[0;ooo]Z
0_l0WOl2o`0]o`05oomD0?ooQP3o9_l0obKo0?oo0=/00ooonfX01Ooa0?oooo]ZoookJ_l0B?ooo`38
00;ooaH000Gooo]Zoago0?l0ofco0?m/oookJP02ooKo00?ooo]Z00Co09kooookJ_oonf[ooo]Z0_l0
/Ol3oookJP;ooj<02_oonfX2olKo00;o0<co0_nn0?l9oookJPCo00003ooonfX2okh0o`04oookJ_l0
c?oooo]ZolKo00cooo]Z00Cooj<0oookJ_oonf[ooo]Z0_l0/Ol2oookJP;o09ko0ooonfX2ooKo00;o
0?m/00?ooo]Zoago0?oonfX00_oo5P001Ooo0<So04SooookJ_oonf[ol@3o00;ooo]Z0_oo0=/01?lV
o`3oohH0oon60?ooE002o`0]o`05o`2MoolTo`3ooo]ZoookJ_oo0:`01?oonfX2ool03005ool10?oo
7P3oon`0ooo/0?oonfX00_ookP03oookJP;oo`0n00?of_l0o`2Bool0T_l00_l0oeT01Ooonf[oo`3=
o`0gool0=oooo`1c00;ooo]Z0_ooD`001Ooc0?ooo`3`ool0l?l0on3ooo]Z00;o0?mC00Kooo]Zo`3o
TOoo0;Soo`2hoon<0?oSo`02oomA0003o`1Gool0ocKoE@3o00;ooah00_oonfX01?oo903ooo]Zo`3o
6?l0oaP2ool0T005ooWo0?oEo`3oo`1AoooS0?ooM0000_oonfX00ol0@_ooo`11oookJP02o`3ok`03
o`2foomEo`3ooo]Z00;ooo]Z00?oon80oookJ_oonfX01OoonfX00ooo08Goo`3bool0lP02oookJP;o
K`3o0_oo^P02o`3oH003oookJ_oo06Ooo`1W00;ooo]Z0_oo0:lAoookJP;o0?l9<_oonfX002[ooo]Z
0ol007l5oookJPGo001o1_oonfX2o`3o2A7ooo]Z00Coo`2_oookJ_oonf[ooo]Z0_oo06L00ooonf[o
0?mPo`3oH002oonj00;oK`3o00Cooo]Zool0l_oo0?;oo`251ooonfX2oooR00;ooo]Z0_mEo`001Ol0
onooolT0ooo90?oob@3o0?l<00;oolT000?oog@0o`3oo_l0ooh00ol0ooh00ooo093o001oooo90002
ooo90004o`2`oooob@3ooah0oolN00;oE@3o0_l0Eol01OooD@3oogT0oomi0?ooN@3oA?l000?oogT0
00SoobP0oookJ_l0on3o0?oPool0l?oc0?ooo`3GoomC00;o05oo00?oo`1co`1Oool0Gol00oooN@00
1?m4o`3oogT0oomi0?ooN@02ool0?POo05oo00Ooon`0oolX0?oo:03oU?l0ool03?l0A?ooobP000;o
oo]Z00?oo`2/oomi0?ooN@000_l0Gol2o`0]o`?o05oo00?o9_l0ool0fooonfX00_oonfX01Ooa0?oo
iOl0onGo0?oUo`3oo`3800?o05oo00Co7Ol0oookJ_l0ofco0?m/0_ofo`02oookJP;o09ko00CoobP0
oiCo0?nDo`3oU?l01ooo0008oookJP;o00oo1Ooo00000ol03ooooo]ZoookJP07oookJPCo00003ooo
nfX3o`3ooP;o0<co00?ooo]ZolKo0?oonfX02?oonfX5o`3ooP04oookJ_l0/Ooo0;7ooookJPGo05oo
00Cooo]ZooKo0?ofo`3oo`002ol0ooh3oookJP;o9_l00_ooQP03o`0?o`04o`2Moooonf[ooo]Zoook
JP;oo`2/0ooonfX01Ooo00co0?l<o`3o3?l0o`co0;3o00;o0?l<0_ookP03oookJP05ool0?_oo003o
oo]Zo`2Bool0ooh00_l0oeT01?oonf[oo`3=o`0gooooa@02ool0L`;ooe<00_oc0?l00ol0/?oo0?oP
o`3oh002o`2`o`;o0?l<00GoT?l0ool0^?oo0;SoofP0on?o0002oomA00;o0?n]00Co00ooo`3o[Ol0
ojgooo]Z0_oo90000ooonf[o0?lHoookJP02ool0T0?oobP000Goon<0oolX0?oo:03o0?ono`12o`02
o`3ooPKo0;3o00?o00ooo`3o[Ol0ojd00ooonfX4o`2`o`05ool0l_l0/?oo0;3ooookJ_m_0?l01_l0
3ol01Ooo06Oooo]ZoookJ_oonf[o05oo00;o0?mM3ooonfX3o`1Oo`Kooo]Z0ol007l5oookJPGo001o
A_oonfX3o`00O`Gooo]Z1Ol007l5oookJP;o0?l94OoonfX00ooo0:oooo]ZoookJP02oookJP06ool0
Iooonf[o0?mPo`3oH?l0]ooookX00_m_0?l2oookJP;oo`3b00?oo`25oookJ_oonfX01OoonfX01_oo
hP3ooo]ZoookJ_oonf[oEOl0o`2fo`;o0?o_00?o001oo`12ool0@_l00_oonfX01oooM03oon<0ool0
DOoEo`3onOl0ool0T?l007l00_l0oaP2oolT00;ooo]Z00?ooah0oeD0oomE0?l00_l0Eol01?ooD@3o
hol0on?o0?ooS002ool0^007o`3oTOoonf[o0?mCo`3oDooonf[o0?oPool0l002oo<0o`03oomC0?oo
nf[ooo]Z00;oo`1c0_l0=ol01?oo0<gooo]Zo`3oFOl0oeT2o`2Bo`03om[o0?oo03kooo]Z00?ooo]Z
0_ookP001OlX0?ooon`0ooo/0?oo7P3oo`4000;oo`0<0ooonfX01?oo0:cooo]ZoookJ_oonfX2o`2M
o`04o`0]ooooE03ooe@0oon600;o9_l000Ooo`3KoookJ_oonf[ooo]Zoo40oooonf[o04So00;oo`38
00CooaH0oookJ_lMo`3o7Ol00_l0of`00ooonf[om_l0oookJP02oookJP;o09ko0ooonfX01?l0/Ooo
oo]ZoookJ_oonfX2oonS00[ooo]Z0_o6o`02o`3<o`03okh0oooonf[ooo]Z00Wooo]Z1?l0000Aoook
JP05okh0ool0c?oo0<cooookJ_o6o`002ooonfX01?ooX`3ooo]ZoookJ_oonfX2o`2ao`?ooo]Z0_l0
W_l3oookJP04ooKo0?oonf[o0?m/oookJP;o7Ol00_oo5P02ool0b003o`18oooonf[ol@3o00?ooo]Z
00Goo`3KobKo0?oonf[oohH0oomD0002o`0]o`04o`2MoolTo`3ooo]ZoookJP;oo`2/0ooonfX2ool0
3005ool10?oo7P3oon`0ooo/0?lX0?l00_ookP03oookJP;oo`0n00?of_l0o`2Bool0T_l00_l0oeT0
1?oonf[oo`3=o`0gool0=ol2ool0L`04oookJ_ooD`3ooe<0oo<0o`;oo`3`00Ko0?oPoookJ_l0oe?o
0?mCoookJ_l0oi42ool0^007oon<0?oSo`3ooe40oomA0?l0Eooo0?lfoeD0o`02oolN00;ooo]Z00Co
ob@0oookJ_l0oaSo0?lH0_oo09002_oio`3oeOl0ool0DOooh`3oog@0oookJ_l007oo04;oool0@Ol0
07l2o`3ok`03o`2foomEo`3ooo]Z00;ooo]Z00?oon80oookJ_oonfX01OoonfX00ooo08Goo`3bool0
lP02oookJP;oK`3o0_oo^P02o`3oH003oookJ_oo06Ooo`1W00;ooo]Z0_oo0:lAoookJP;o0?l91ooo
nfX3o`00O`Gooo]Z1Ol007lNoookJP00:_oonfX3o`00O`Cooo]Z1ol007l4oookJP;o0?l94OoonfX2
ool0[`;ooo]Z0ooo06L00ooonf[o0?mPoonj0002oonj0003ofl0oooonf[ooo]Z00;oo`3b00?oo`25
oookJ_oonfX01OoonfX2oooR00;ooo]Z00?oEOl0o`2foooob@000ooob@000ol0o`coolT0ooo90002
odCo0006o`3oo_m4o`3o0?ono`3oo_oo093o0?lH0_oob@000ol0/?oo0?l<ooo90002oolN00;oE@3o
00?o05OooomA0?ooD@000_ooN@000om4o`3oogT0oomi0002oomi0009o`3oDooonf[o0?oPo`3o[Ooo
0?3ol`3oo`3o[OooD`3ooo]Z00;oo`1c00Go05oooomi0?ooN@3oogT0odCo0003oomi0003om[o0?oo
03ko05oo00Oo05oo00?oon`0oolX0?oo:0000_oo00`2oolX0004oookJ_oo0:coogT0oomi00?o0?mM
0_l0;Ol2o`1Oo`;o9_l000?oo`3KoookJ_oonfX00_oa0?l01?oonf[o04Soool0b?oo0<P2o`1Oo`;o
7Ol00_l0of`01Ooonf[om_l0oookJ_oonf[oobP000;o09ko0_oo:009ool000Gooo]Z1Ol03ol00ol0
c?ooo`00ool00002o`0?o`[ooo]Z1?l0000:oookJPCoogT00_oonfX3o`3ooP;o0<co0_o6o`08oook
JPKo0?on00Cooo]Zo`2aoooonf[ooo]Z1?l0Gol01?oonf[om_l0ooKo0?oo000;o`3ooP?ooo]Z00Co
o`3KobKo0?lVo`3oohH00ol03ol01?l0WOoooo]ZoookJ_oonfX2ool0[0?ooo]Z00?oo`0<o`2`ool0
/?l01_l0/?l3oookJP05ool0?_oo003ooo]Zo`2Bool0ooh00_l0oeT01?oonf[oo`3=o`0gooooa@02
ool0L`05o`2`ooooD`3ol`3ooo<0ool0/?l00_l0on02o`2`o`03o`3o3?m4o`3oA?l000;oo`2h00Co
ofP0on?o0?ooD@3ooe400_l0ojd01?l03ooo0?n]o`3o[OoonfX2oolT0003oookJ_l0oaSooo]Z00;o
o`2@0ooo:0001Oooh`3oobP0oolX0?l0ooko04;o00;o0?on1_l0/?l5o`0?o`03oookJ_l0/?oo0;3o
00;o0;3o00Goo`3bo`2`ool0/?oooo]Zofl0o`06o`0?o`Wo05oo3OoonfX3o`1Oo`Kooo]Z0ol007l4
oookJPOo001oAOoonfX3o`00O`Cooo]Z1ol007l3oookJP;o0?l94OoonfX2ool0[`?ooo]Z0_oo06L0
0ooonf[o0?mPo`3oH002oonj00;oK`3o0_oonfX2ool0lP03ool0QOoonf[ooo]Z00Cooo]Z0_oohP02
oookJP;oEOl000Co0;Koo`3okooonf[o001o0_l0@_l02Ooonf[oog@0oooS0?ooh`3oo`1Ao`3hoooi
o`3oo`2@o`00O`02o`3o60;oob@00_oonfX01?oo7P3oE@3ooeD0ool0Eol2oomA0009on?o0?ooJ03o
oh`0ool0^?l0oi7oo`03oookJ_l0oe?ooo]Z00;o0?oP00Coo`3`oo<0oooc0?oooe<00_oonfX01Ooo
07?oolD0o`0goooo0<gooo]Z00;o0?mI00?o`03oo`2BoooJo`000_oo03h4oookJP09ooo^0?oonf[o
:03oooo/0?oo7P3oRol0ool10?oo00co04Co00?ooo]Z00Soo`2/oookJ_oonf[o9?l0o`2Moooo>03o
02gooomD00;oohH000?o9_l0ool0fooonfX00_oonfX2oo40o`03oookJ_l0B?ooo`3800;ooaH000Go
oo]Zoago0?l0ofco0?m/oookJP02ooKo00;ooo]Z0_l0W_l3oookJP04o`2aoooonf[ooo]ZoookJP;o
oj<02_oonfX2olKo00;o0<co0_nn0?l;oookJPCo00004_oonfX00onn0?oo0<coo`3<o`02olKo00_o
oo]Z00Cooj<0oookJ_oonf[ooo]Z0_l0/Ol2oookJP;o09ko0ooonfX00oofo`3ooo]Zo`3oK002oook
JP03oago0?oo5P3ooaH000;oo`3800?o04SooookJ_oa0?l00ooonfX01Ooo0=_o9_l0obKo0?ooQP3o
oe@000;o02go00CoocP0obCo0?oonf[ooo]Z0_oo0:`3oookJP;oo`0<00Goo`40oolN0?ook03oon`0
obP0o`02ooo^00?ooo]Z0_oo03h00ooJo`3o09;oo`2Bo`02o`3oF@04oookJ_oo0<go03Ooo`0go`;o
o`1c0_oonfX01_ooD`3ol`3oool0l?oo0?3o0?oPoookJP;o0?mC00Kooo]Zo`3oTOoo0;Soo`2hoon<
0?oSo`02oomA0003o`1Gool0ocKoE@3o00;ooah00_oonfX02ooo903ooo]Zo`3o6?l0oaSo001oool0
T?oio`3oeOl0ool0DOooh`3oog@000;o001o00?o04;oool0@Ol007l00_l0onl00ol0]_ooEOl0oook
JP02oookJP03oooR0?oonf[ooo]Z00Gooo]Z00?oo`25ool0l_oo0?800_oonfX2ofl0o`;ookX00_l0
of000ooonf[oo`1Wool0I`02oookJP;oo`2_4OoonfX2o`3o2@Oooo]Z0ol007l4oookJPOo001o7Ooo
nfX002[ooo]Z0ol007l3oookJPCo001o00Cooo]Zo`00Ool007oo001o1?oonfX2o`3o2A7ooo]Z0_oo
0:l2oookJP;oo`1W0_oonfX00ol0of3ookX0oonj0002ofl0o`;ooo]Z0_oo0?800ooo08Gooo]Zoook
JP05oookJP;oon800_oonfX00omEo`3o0;Kooomi0002oookJP06o`3o3?oob@3oolT0ooo90?m4o`3o
0?on0_m4o`000ooio`3oo`2@ool0T003ooo90003o`3o3?oob@3oolT000;ooah000?oE@3oo`3o=_l0
Eol00_ooD@02oomi0003odCo0?ooN@3oogT000;oogT000Ko0?mCo`3o[Ol0on3oo`3`o`0?oooc0?l2
oomC0003oookJ_oo07?o0?mM00SoogT000Cof_l0ool0?_oonf[ooo]Z1Ol0Gol2ooo/00;oobP00_oo
00`00ooo:03ooo]ZoookJP02oomi00?o0?mM0_l0;Ol3o`1Oo`03obKo0?oo0=_oo`3K00;ooo]Z00Go
l@3ooookJ_oonf[o04Soool0b003o`1Oo`06oago0?oonf[o0?m/o`3oK?oonf[om_l00_oonfX2o`2N
o`;oobP02Ooo0004oookJPKo00oo00?o0<coo`0?oooo00000_l03ol;oookJPCo00001_oonfX5oomi
00GoA?l000Kooo]Zo`3oo_l0ooko0?ono`3<oooonfX2olKo00Sooo]Z1Ol0ooh01?oonf[o0;7ooook
J_oonfX4o`1Oo`03oookJ_ofo`3om_l000;oo`002_l0ooh01?oa0?oooo]ZoookJ_oo0=/2obKo0006
oon60?ooE03o00ooo`0?ool0WOoo9?l00_oonfX2ool0[0?ooo]Z00?oo`0<o`2`ool0/?l01_l0/?l3
oookJP05ool0?_oo003ooo]Zo`2Bool0ooh00_l0oeT01?oonf[oo`3=o`0gooooa@02ool0L`05oomi
0?ooD`3ol`3ooo<0ool0/?l00_l0on02o`2`o`03o`3o3?m4o`3oA?l000;oo`2h00CoofP0on?o0?oo
D@3ooe400_l0ojd01?l03ooo0?n]o`3o[OoonfX2oolT0003oookJ_l0oaSooo]Z00;oo`2@00Co0?So
oolX0?oo:03oon<00_oo:0001Ol007oo04;oo`3oo_l0ooko0?o_00Co0;3o1_l03ol00ooonf[o0;3o
o`2`o`02o`2`o`05ool0l_l0/?oo0;3ooookJ_m_0?l01_l03ol9o`1Oo`gooo]Z0_l0Gol7oookJP?o
001o0ooonfX4o`00O`04oookJ_l007oo001oo`00OdGooo]Z0ol007l3oookJPCo001o00Cooo]Zo`00
Ool007oo001o0ooonfX2o`3o2A7ooo]Z0_oo0:l3oookJP03ool0Iooonf[ooo]Z00;o0?mP00?ookX0
oookJ_m_0?l00ooonfX2ool0lPOooo]Z0_oohP02oookJP;oEOl00_l0onl01_oonf[oo`11o`12ool0
07oooo]Zoomd00;oon<000OoeOl0ooWo0?oo093oo`2@o`00Ool0oaSo001o00;oob@000?ooo]ZoolN
0?oo7P000_mE0?l01?l0Eooooe40oomA0?oSo`02oon<0003ool0^?l0oi7ooo]Z00;o0?mC00Cooo]Z
o`3oh?l0on3oo`3`0_oc0?l02?ooD`3ooo]Zool0Looo07?oolD0o`0goooo0<gooo]Z0_l0oeT00ol0
obGo09;oom[o0002ool0?P?ooo]Z0_ookP001Ooonf[oon`0ooo/0?oo7P3oo`4000;oo`0<0ooonfX0
1?oo0:cooo]ZoookJ_l007l2o`2Mo`;o02go00Gooe@0oon60?lVo`3o9_l0ool0f`03oookJP03oo40
oooonf[o04So00;oo`3800CooaH0oookJ_lMo`3o7Ol00_l0of`00ooonf[om_l0oookJP02oookJP;o
09ko0ooonfX00ol0/Ooooo]ZoookJP02oonS00[ooo]Z0_o6o`02o`3<o`;o_P3o3?oonfX4o`0001?o
oo]Z00?o_P3oo`3<oooonfX00_o6o`0:oookJP04oonS0?oonf[ooo]ZoookJP;o0;7o0_oonfX2o`2N
o`?ooo]Z0_ofo`02o`3oK004oookJ_lMo`3ooo]ZoolF00;oo`3800Co04SooookJ_oa0?ool@3o0_oo
nfX02Ooo0=_o9_l0obKo0?ooQP3ooe@0oookJ_l0;OooocP0obCo0003oookJP04ool0[?oonf[ooo]Z
oookJP;oo`0<00Goo`40oolN0?ook03oon`0obP0o`02ooo^00?ooo]Z0_oo03h00ooJo`3o09;oo`2B
o`02o`3oF@04oookJ_oo0<go03Ooo`0go`;oo`1c0_oonfX01_ooD`3ol`3ooo<0oooo0?3o0?oPoook
JP;o0?mC00Gooo]Zo`3oTOoo0;Soo`2hoon<0002on?o0006oomA0?l0Eooo0?lfoeD0oooonf[ooah0
0_oonfX02ooo903ooo]Zo`3o6?l0oaSo001oool0T?oio`3oeOl0ool0DOooh`3oog@000;o001o00?o
04;oool0@Ol007l00_l0onl01?l0]_ooEOl0oookJ_oonfX2oooR00Oooo]Z00?oo`25ool0l_oo0?80
0_oonfX2ofl0o`;ookX00_l0of000ooonf[oo`1Wool0I`02oookJP;oo`2_4OoonfX2o`3o2@Oooo]Z
0ol007l3oookJPCo001o00Cooo]Zo`00Ool007oo001o7OoonfX001[ooo]Z2_l007l6oookJP?o001o
0ooonfX3o`00O`?ooo]Z0ol007l3oookJP;o0?l94OoonfX01?oo0:oooo]ZoookJ_oonfX2ool0I`03
oookJ_l0of3o0?mP00;ookX00_m_0?l2oookJP;oo`3b00?ooo]Zo`00Ool007l01?l007l2oooR00;o
001o0_mEo`001ooo08KoogT0oookJ_oonf[o0?l<ooo90?l007l00_m4o`000ol0ookoA?l0odCo0002
ool0T006oookJ_oob@3oolT0ooo90?l0o`coolT00_oo7P02oeD0o`07o`3o=_l0Eooooe40ool00?oS
o`3oogT0odCo0004oomi00;o0?n]00So0?oPool0l?oc0?ooo`3GoomC0?l0ojgo05ooool0L`;o0?mM
00?o05ooo`3oGOooN@001?ooN@02ool0?P;ooo]Z0_l0oed3o`1Oo`03ooo/0?oo:03oobP000;oo`0<
0_oo:002o`00O`03ool0[?l0oego0?mM00;o0?mM0_l0;Ol2o`3oG@;o9_l000?oo`3KoookJ_oonfX0
0_oa0?l01?oonf[o04Soo`1Ooooo0<P2o`1Oo`;o7Ol000Cooo]Zo`2`oooonf[om_l00ooonfX00ol0
W_oooo]ZoookJP0:ool000Cooo]Z1Ol03ol2o`3<o`So00oo1ooonfX4o`0000Kooo]Z00?oogT0odCo
0?m4o`000om4o`05o`3ooP07oookJ_l0ooko0?ono`3oo_l0c?oooo]ZolKo0009oookJPCo0?on00?o
oo]Zo`2aool0/Ol00_oonfX3o`1Oo`;ooo]Z00?om_l0ool00?oo00002Ol0ooh2oo40o`;ooo]Z00Go
o`3KobKo0?lVo`3oohH0oomD0002o`0?o`;o09go0_oonfX2ool0[0?ooo]Z0_oo00`7o`2`o`?ooo]Z
00?oo`0nool00?oonfX00_l0T_l2o`3oF@04oookJ_oo0<go03Ooooo500;oo`1c00GoogT0oomC0?oc
0?ool`3oo`2`o`02o`3oh0;o0;3o00?o0?l<odCo0?m4o`000_oo0;P01?ooJ03ohol0oomA0?ooD@02
o`3o[@04o`0?ool0ojgooah0oookJP;oob@000?ooo]Zo`3o6?oonfX00_oo09001Ol0n?ooobP0oolX
0?ooh`3oobP000;o001o00Co04;oo`3oo_oonf[o0?o_1?l0/?l6o`0?o`;ooo]Z0ol0/?l01_oo0?;o
0;3ooookJ_oonf[oK`3ooonj00Go00oo2Ol0Gol=oookJP03o`3o2Ol0Gooooo]Z00Kooo]Z0ol007l3
oookJP?o001o0ooonfX3o`00OcCooo]Z2_l007l6oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l2
oookJP;o0?l94OoonfX2ool0[`?ooo]Z00Koo`1WoookJ_l0of3o0?mPo`2goooo^P02ofl0o`;ooo]Z
00?oon@0ool0l_oo08D01ol007l2oooR0004o`00Oooonf[oEOl0o`2fo`;o0?o_00Kooo]Zool0@Ol0
@_oo001ooookJ_ooM002oooS0004omGo0?oio`3oo`2@oookJP;o0?lH00Go001ooolT0?oonf[ooo]Z
oolN0002oeD0o`03o`3o=_l0Eooooe4000;ohol000Gooh`0ool0^?oo0;So0?nAoookJP02o`3oD`03
oookJ_l0on3oo`3`00;ol`3o00?ooe<0oookJ_oonfX00_oo07<2o`0go`04ool0cOoonf[o0?mIo`3o
F@;o09;o00?of_l0ool0?_oonfX00ooonfX00oookP3ooo]ZobP0o`02ooo/0004oolN0?oo0@3oo`0<
ool030?o001o00Ooo`2/oookJ_oonf[o001oo`2Moooo>03o02go00;ooe@000CoohH0obKo0?lVo`3o
o`3K0_oonfX2oo40o`0:oookJ_l0B?ooo`38ool0b?oo5P3ooo]Zoago0?oonf[o0?m/oookJP;om_l0
0_oonfX2o`2No`?ooo]Z00Co0;7ooookJ_oonf[ooo]Z0_ooX`09oookJP;oa_l000Cooo]Zo`3<oonn
0?oo_P3o3OoonfX4o`0001?ooo]Z0_nn0?l00ol0c?oooo]ZolKo000:oookJP;ooj<00_oonfX2o`2a
o`?ooo]Z00Co09kooookJ_oonf[ooo]Z0_ofo`002_oonf[o0?m/oookJ_lMo`3ooo]ZoolF0?l0ob_o
o`38o`18oooonfX2oo40o`;ooo]Z00Coo`3KobKo0?lVo`3oohH00_ooE0001?l0;OooocP0o`2Mool0
07l2oookJP04ool0[?oonf[ooo]ZoookJP;oo`0<00Goo`40oolN0?oo7P3oon`0obP0o`02ooo^00?o
oo]Z0_oo03h00ooJo`3ooo]Zo`2Bo`02o`3oF@04oookJ_oo0<go03Ooo`0go`;oo`1c0_oonfX01_oo
D`3ol`3ooo<0oooo0?3o0?oPoookJP;o0?mC00Gooo]Zool00ooo0;Soo`2hoon<0002on?o0006oomA
0?l0Eooo0?lfoeD0oooonf[ooah00_oonfX02ooo903ooo]Zo`3o6?l0oaSo001oool0T?oio`3oeOl0
ool0DOooh`3oog@000;o001o00Oo04;oool0@Ooonf[o001oo`3okol0]_ooEOl000;ooo]Z0_oohP07
oookJP03ool0QOoo0?;oo`3b00;ooo]Z0_m_0?l2oonj00;o0?mP00?ooo]Zool0Iooo06L00_oonfX2
ool0[a7ooo]Z0_l0o`T7oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007lLoookJP006_oonfX:o`00
O`Kooo]Z0ol007l9oookJP?o001o0ooonfX2o`3o2A3ooo]Z0_oo0:l3oookJP;oo`1W00?ooo]Zo`3o
H?l0of000_oo^P02ofl0o`;ooo]Z00?oo`3bool0QOoonfX01_l007l2oooR00;o001o0_mEo`001ooo
08KoogT0oookJ_oo047o0?l<ooo90?l007l00_m4o`000ol0ookoA?l0odCo0002ool0T0CoolT000Co
0?l<ooo90?oo7P3ooah00_mE0?l2o`1Go`07oomA0?oo003oofP0odCo0?ooN@3o0?nAool00`02oomi
000<oookJ_l0on3o0?oPool0l?oc0?oo0?n]oomC0?l0ojgo0?mMool0Lol0oego05oo0_l0oed00ol0
oeWoogT0o`1Oo`02oomi0003ool0?_oonf[ooo]Z00?o0?mM00Ko05ooo`3oGOl0oegoon`0oolN0?oo
0@02ool030;oobP000?o001oool0[?l0oed01?l0oed01?l0;Ooo0?mMo`3oGOl0oed2obKo0003ool0
fooonf[ooo]Z00;ol@3o00?ooo]Zo`1Ooooo0<P00ol0Gol2oago0004o`3oK?l0/?oooo]ZooKo00;o
oo]Z0_l0W_l3oookJP03oolX0?oo003oo`0000Goo`001?oonfX2o`3o[@?o00oo0_l0c?l3o`0?o`03
o`3o[Ol03ooo00oo00_o00oo0ol00007oookJP03odCo0?l0ooko0?on00Oo0?on0_oonfX2o`3ooP;o
0<co0_o6o`08oookJPCo0?on0_oonfX01?l0/Ooooo]ZoookJ_oonfX2o`1Oo`;ooo]Z00Com_l0oook
J_oo003oo`002?l0ooh2oo40o`;ooo]Z00Woo`3KobKo0?lVo`3oohH0oomD0?l0;Ooo00oooolh0?l0
WOl00_oonfX2ool0[0?ooo]Z0_oo00`6o`2`o`03ooo^0?oo003oo`0000Koo`000_l0oeT01?oonf[o
o`3=o`0gooooa@02ool0L`05oomi0?ooD`3ooe<0oo<0ool0/?l00_l0on02o`2`o`;o0?l<00GoA?l0
ool0^?oo0;SoofP0on?o0002oomA00Ko00oo0_oo90001?oonf[o0?lHoookJ_oo0904oiCo0008oooS
0?nDo`3oU?l0oiCo0?l0@_oo0?onoookJ_l0onl4o`2`o`Go00oo0ooonfX3o`2`o`06ool0l_l0/?oo
oo]ZoookJ_m_0?oookX01?l03ol2ool0I`Oo05oo3_oonfX00ol0o`Wo05oooookJP06oookJP?o001o
2OoonfX3o`00OcCooo]Z2_l007l6oookJP?o001o2OoonfX3o`00O`;ooo]Z0_l0o`T@oookJP;oo`2_
1?oonfX01?oo06Oooo]Zo`3oH?l0of02oonj00;oK`3o0_oonfX2ool0lP03ool0QOl007oo001o00Go
001o00?oon80o`00Ool007l00_mEo`002?l0]_oo0?o_o`3okooonf[oo`11o`12ool007ooog@00_oo
h`001Ooo057oeOl0ooWo0?oo093ooo]Z00;o0?lH0_oo9002oookJP03oolN0?mE0?ooE@3o00;o05Oo
00Sooe40on?o0?ooJ03ooh`0ool0^?l0oi7oo`03oookJP;o0?mC0_l0on001?oo0?3ol`3ooo<0oooo
D`02oookJP;oo`1c0_l0=ol01?oonf[o0?mIo`3oFOo00?l2o`2Bo`;oo`0n1?oonfX02OookP3ooo]Z
obP0ooook03ooah0oh_o0?oo0@3oo`0<o`14o`02o`00O`;oo`2/0_oonfX01OlTo`3o09goo`0]ool0
;Ooooe@000;oohH000?o9_l0ool0fooonfX00_oonfX00ooa0?oooo]Zo`18o`02ool0b004oolF0?l0
ob_ooo]Zoago00;o0?m/00?ooo]ZooKo0?oonfX00_oonfX2o`2No`;ooo]Z0_l0/Ol2oookJP;ooj<0
2_oonfX00oo6o`3ooo]Zo`3<o`02okh0o`kooo]Z1?l0000DoookJP05okh0ool0c?oo0<cooookJ_o6
o`002_oonfX01OooX`3ooo]ZoookJ_oonf[o0;7o00?ooo]Z00Co09kooookJ_oonf[ooo]Z0_ofo`00
0ooonf[o0?m/oookJP02oago00;ooaH000?oo`38o`18oooonfX00_oa0?l2oookJP04ool0folVo`3o
9_l0oon600;ooe@000Co02gooolh0?l0WOoo001o0_oonfX01ooo0:cooo]ZoookJ_oonf[o04Coool0
3?oo0@000_oo7P001?ook03o:03oooo^0?ookP04oookJP04ool0?_oJo`3ooo]Zo`2Bo`;o0?mI00Co
oo]Zool0cOl0=ooo03Oo0_oo07<2oookJP06oomC0?oc0?ool`3oool0l?l0on3ooo]Z0_l0oe<01Ooo
nf[oo`03o`3oTOoo0;Sooh`000;ohol000Kooe40o`1Gool0ocKoE@3ooookJ_oo7P02oookJP0;oolT
0?oonf[o0?lHo`3o6?l007ooo`2@ooWo0?oEo`3oo`1AoooS0?ooM0000_l007l00ol0@_ooo`11oook
JP02o`3ok`04o`2foomEo`3ooo]ZoookJP;oon801ooonfX00ooo08Goo`3bool0lP02oookJP;oK`3o
0_oo^P02o`3oH003oookJ_oo06Ooo`1W00;ooo]Z0_oo0:lAoookJP;o0?l91ooonfX3o`00O`Wooo]Z
0ol007lLoookJP00:_oonfX3o`00O`Wooo]Z0ol007l3oookJP03o`3o2Ooonf[ooo]Z00oooo]Z0_oo
0:l3oookJP;oo`1W00?ooo]Zo`3oH?l0of000_oo^P000om_0?oooo]ZoookJP02ool0lP03ool0QOoo
nf[ooo]Z00Gooo]Z0_oohP02oookJP08oeGo0?l0]_ooogT0o`3okooonf[o0?l<o`12oooob@03odCo
0003o`3oo_m4o`3oA?l000;oo`2@0ooob@000ol0o`coolT0ooo90002oolN00;oE@3o00co05OooomA
0?ooD@3oo`00oon<0?ooN@3oT?l0o`3oTOoonf[oo`0Ko`3oDooonfX2o`3oh005ool0l?oc0?ooU?l0
oomC0?l0Gol00_oo07<01_l0oego05ooo`3oGOl0oegoogT0ol00o`;o05oo00Cof_l0ool0?_oonf[o
oo]Z0ol0oed01_l0Gooo0?mMooo/0?ook03ooah0oolX00;oo`0<00Cooo]ZoolX0?oonf[oo`2/0_oo
nfX2o`3oG@;o02go0_l0oed01?ooQP3o9_l0ool0fol007l2oookJP05o`3oo_oonf[o05ooo`1Ooooo
0<P00ol0Gol01?lMo`3ooo]Zo`2`ool0/?l2ooKo00;ooo]Z00?o09kooookJ_oonfX00_oonfX00ol0
/OooobP0ool00005ool000Cooo]Z0ol0ojd00ol03ooo0<coo`3<o`03o`0?o`03oiCo0?l0ojgo00oo
013o00oo1?oo01P2oookJP03oomi0?l0ooko0?on00Oo0?on0ooonfX00ol0ooko0<coo`3<o`08ool0
00?ooo]Z0ol0ooh2oookJP04o`2aoooonf[ooo]ZoookJP;o05oo0_oonfX2ooKo00;oo`002?l0ooh2
oo40o`;ooo]Z00Goo`3KobKo0?lVo`3oohH0oomD0002o`0]o`03oolh0?l0WOoooo]Z00;ooo]Z00Co
o`2/oookJ_oonf[ooo]Z0_oo00`6o`2`o`03ooo^0?oo003oo`0000Koo`000_l0oeT01?oonf[oo`3=
o`0gooooa@02ool0L`04oomi0?ooD`3ooe<0oo<0o`;o0;3o00?o0?oPo`2`ool0/?l00_l0o``01Om4
o`3oo`2hool0^?ooJ03ohol000;ooe401_l03ol2oolT0004oookJ_l0oaSooo]Zool0T0CoU?l000Wo
on<0oiCo0?nDo`3oU?l0o`12ool0ookooo]Zo`3okol0ooh00ol0/?l5o`0?o`?ooo]Z0ol0/?l01_oo
0?;o0;3ooookJ_oonf[oK`3ooonj00Co00oo0_oo06L7o`1Oo`kooo]Z0_l0o`T7oookJP?o001o2Ooo
nfX3o`00OdCooo]Z0ol007l9oookJP?o001o0_oonfX00ol0o`Wooo]ZoookJP0?oookJP;oo`2_0ooo
nfX2ool0I`03oookJ_l0of3o0?mP00;ookX000CoK`3ooookJ_oonf[ooo]Z0_oo0?800ooo08Gooo]Z
oookJP05oookJP03oooR0?oonf[ooo]Z00;oEOl00ol0onl01Ooo047o04;oo`12ool007ooog@000;o
on<000Goo`1AooWo0?l0n?ooo`2@oookJP02o`3o60;oob@00_oonfX01?oo7P3oE@3ooeD0ool0Eol2
oomA0009on?o0?ooJ03ooh`0ool0^?l0oi7oo`03oookJ_l0oe?ooo]Z00;o0?oP00Goo`3`oo<0oooc
0?oooe<0oookJP02ool0L`04ooo50?l0=oooo`3=oookJP;o0?mI00?o0?lUo`2BoooonfX00_oo03h3
oookJP;oonh000Gooo]Zooo/0?ook03ooah0ool10002ool030?ooo]Z0_oo0:`2oookJP06o`2Moooo
>03o02goo`0]ooooE03oohH00_lVo`000ooo0=_ooo]ZoookJP02oo40o`08oookJ_l0B?ooo`38ool0
b?oo5P3ooo]Zoago0?oonfX2o`3oK0;om_l00_oonfX2o`2No`?ooo]Z00Go0;7ooookJ_oonf[ooo]Z
oonS000:oookJP05olKo0?oonf[o0<coo`3<oonn0?l03ooonfX9ool060oooo]Z0_nn0?l00ol0c?oo
oo]ZolKo000:oookJP;ooj<00_oonfX2o`2ao`;ooo]Z0_l0W_l3oookJP04ooKo0?oonf[o0?m/o`3o
K0;o7Ol00_oo5P02ool0b003o`18oooonf[ol@3o00;ooo]Z0_oo0=/02?lVo`3oohH0oomD0?ooE03o
02gooolh0?l0WOoo9?l00_oonfX2ool0[0;ooo]Z00?o04Coool03?oo0@000_oo7P001?ook03o:03o
oookJ_ookP04oookJP08ool0?_oJo`3ooo]Zo`2Booo00?oo0?mIoookJ_oo0<d2o`0go`;oo`1c0_oo
nfX01_ooD`3ol`3ooo<0oooo0?3o0?oPoookJP;o0?mC00Gooo]Zool00ol0oi7oo`2hoon<0002on?o
0006oomA0?l0Eooo0?lfoeD0oooonf[ooah00_oonfX03?oo903ooo]Zo`3o6?l0oaSo001oool0T?oi
o`3oeOl0ool0DOooh`3oog@0o`00O`;o04;o00Coo`11oookJ_l0onoo0?o_0_mEo`02oookJP;oon80
1ooonfX00ooo08Goo`3bool0lP02oookJP;oK`3o0_oo^P000ol0of3ooo]ZoookJP02ool0I`;ooo]Z
0_oo0:lAoookJP;o0?l91ooonfX3o`00O`Wooo]Z0ol007lLoookJP00:_oonfX3o`00O`Cooo]Z0_l0
07l2oookJPCo001o0ooonfX00ol0o`Wooo]ZoookJP0?oookJP;oo`2_0ooonfX01_oo06Oooo]Zo`3o
H?l0of3o0;Oooonj00;oK`3o0_oonfX2ool0lP03ool0QOoonf[ooo]Z00Cooo]Z0ooohP02oookJP03
oeGo0?l0]_ooogT000;ooo]Z00?o0?l<o`12oooob@000_m4o`001?l0ookoA?l0odCo0?m4o`02ool0
T0?oolT000Co0?l<ooo90?oob@3ooah00omE0?l03_l0Eooooe40ool00?oo003ooh`0oomi0?n@o`3o
o`03oookJ_l0oe?oo`0KoookJ_l0on3oo`3`0_oc0?l2oomC0005o`3oGOoo07?o0?mMo`3oGOl0Gol0
0_l0oed01?ooN@3o`03oo`1Oool0Gol2ool0?P05oookJ_l0oego0?mMo`3oGOl0Gol00_l0oed01Ooo
k03ooah0oh_o0?oo0@3oo`0<00?ooo]Z0_oo0:`01?oonf[oiOl0onGo0?oUo`02o`0]o`;o0?mM0_lV
o`001Ooo0=_o001ooookJ_oa0?oo0?on00;o05oo0_oo0<P2o`1Oo`;o7Ol00ol0/?l00oofo`3ooo]Z
oookJP02o`2No`?ooo]Z00Coo`00oookJ_oonf[oobP01?oo0004oookJP;oU?l00_l0ojd00ol03ooo
0<coo`0?o`02o`0?o`03oolX0?nDo`3o0?n]00oo00oo00Co0000oookJ_oonf[ooo]Z1?oo01P00ooo
N@3o0?ono`3ooP06o`3ooPGooo]Z00?o0?ono`3<ool0c?l01ooo0003oookJP?o0?on0_oonfX2o`2a
o`;ooo]Z00Co09koo`1Ooooonf[ooo]Z0_ofo`000ooonf[oo`00oookJP07o`3ooP05oookJ_oa0?oo
oo]ZoookJ_oo0=/00_lVo`001_ooQP3ooe@0o`0]ool0;OooocP0o`2Mo`?ooo]Z00Coo`2/oookJ_oo
nf[ooo]Z0_oo00`6o`2`o`03ooo^0?oo003oo`0000Koo`000_l0oeT01?oonf[oo`3=o`0gooooa@02
ool0L`04oomi0?ooD`3ooe<0oo<0o`;o0;3o00?o0?oPo`2`ool0/?l00_l0o``01Om4o`3oo`2hool0
^?ooJ03ohol000;ooe401_l03ol2oolT0004oookJ_l0oaSooo]Zool0T0CoU?l000Woon<0oiCo0?nD
o`3oU?l0o`12oooo047ooo]Zo`3okol0]_l00ol0/?l5o`0?o`?ooo]Z0ol0/?l01Ooo0?;ooo]Zoook
J_oonf[oK`3o00;ookX00ol03ol2ool0I`Oo05oo3_oonfX2o`3o2@Oooo]Z0ol007l4oookJP;o001o
0_oonfX4o`00OdCooo]Z0ol007l4oookJP;o001o0_oonfX4o`00O`;ooo]Z00?o0?l9oookJ_oonfX0
3ooonfX2ool0[`?ooo]Z0_oo06L01_oonf[o0?mPo`2goooo^P3ooo]Zofl0o`?ooo]Z0_oo0?87oook
JP;oon800_oonfX2oeGo00;o0?o_00Kooo]Zool0@Ol0@_oo04;oo`00OoooM002oooS0004o`00Oooi
o`3onOl0ool0T0;o0?lH00?o001ooolT0?l007l00_oonfX3oeD0o`09o`1GooooD@3ooo]Zon?o0?oo
S03oT?l0ool0^?l0oi7ooo]Z00;o0?mC00?ooo]Zo`3oh?oo0?000_oc0?l2oomC0007oookJ_oo07?o
o`1cooo50?l0=oooo`3=oookJP02o`3oF@;o09;o00?of_l0ool0?_oonfX00ooonfX2ooo^0005obP0
ooook03oon`0oolN0?oo0@000_oo00`3oookJP07ool0[?oonf[ooo]ZoookJ_l0WOooocP0o`0]o`02
oomD0004oon60?lVo`3oo`3Kool0f`;ooo]Z00Gol@3ooookJ_l0B?oo04Soool0b002oolF0006oook
J_lMo`3o0?m/o`3oK?oonf[om_l00ooonfX2o`2No`;ooo]Z0_l0/Ol2oookJP;ooj<02OoonfX2olKo
0003oookJ_l0c?oo_P3o00kooo]Z1?oo01P2o`0000Cooo]Z1?oo01P=oookJP03okh0ool0c?oo0<co
00;oa_l02OoonfX2oonS00;ooo]Z0_l0/Ol3oookJP06o`2Noooonf[ooo]ZoookJ_ofo`3ooo]Z0_l0
of`2oago00;ooaH00_oo0<P00ol0B?oooo]Zoo40o`02oookJP;oo`3K00Co9_l0oon60?ooE03ooe@0
0_l0;Ol01?l0WOoo9?l0oookJ_oonfX2ool0[0?ooo]Z00Soo`0<ool10?oo7P3ooah0ooo/0?lX0?oo
oo]Zooo^00Cooo]Z00Soo`0nom[o0?oonf[o09;ool00ool0oeWooo]Zool0c@;o03Oo00GoolD0ool0
Looonf[ooo]ZoomC0002oo<0o`03ool0l?l0on3ooo]Z00;o0?mC00Gooo]Zool00ol0oi7oo`2hoon<
0002on?o0006oomA0?l0Eooo0?lfoeD0oooonf[ooah00_oonfX03?oo903ooo]Zo`3o6?l0oaSo001o
ool0T?oio`3oeOl0ool0DOooh`3oog@0o`00O`;o04;o00Coo`11oookJ_l0onoo0?o_0_mEo`02oook
JP;oon801ooonfX00ooo08Goo`3boookJP02oookJP03ofl0oooonf[ookX000;o0?mP0_oonfX01?oo
06Oooo]ZoookJ_oonfX2ool0[a7ooo]Z0_l0o`T7oookJP?o001o1?oonfX2o`00O`;ooo]Z1?l007lL
oookJP00:_oonfX3o`00O`Cooo]Z1ol007l3oookJP;o0?l94OoonfX00ooo0:oooo]ZoookJP02oook
JP04ool0Iooonf[o0?mPo`3oH0;ookX00_m_0?l2oookJP;oo`3b1ooonfX3oooR00;ooo]Z00?oEOl0
o`2fool0onl00_oonfX00ol0@_ooolT0odCo0002odCo000:o`3oo_m4o`3oA?l0odCo0?oo093ooo]Z
o`3o6?oonf[oolT0o`3o30;oolT000Kooah0oeD0oomE0?oo05Ooool00?ooD@02ool00007oon<0?oo
N@3oT?l0ool00ooonf[o0?mCoookJP02o`3oh004ool0l?oc0?oo05oooomC00;o0?mM00?oo`1co`3o
GOl0Gol00ol0oed01?ooN@3o05ooo`1Oool0Gol2ool0?POo0?mM00?oon`0oolN0?oo0@000_oo00`3
oookJP03ool0[?oonf[ooo]Z00?oiOl000Co02goonGo0?oUo`3o0?mM0_lVo`001?oo0=_ooo]Zoook
J_l0ooh3o`1Oo`06ool0b?l0Gooo05ooo`1OoolMo`3o05oo0_l0/?l2ooKo00;ooo]Z0_l0W_l3oook
JP05ool00?oonf[ooo]ZoookJ_ooX`000ooo0003oookJP06oolX0?nDo`3oU?l0oiCo0?l0ojgo0<co
0ol03ol01Ol0ojgoobP0oiCo0?nDo`3o0?n]00_o00oo1?l00006oookJP;oo`0H00?oA?l0o`3oo_l0
ooh01Ol0ooh5oookJP03okh0ool0c?oo0<co00Ooo`001?oonfX2o`3ooP;ooo]Z0_l0/Ol2oookJP;o
09ko0_oonfX2ooKo0003oookJ_l0ofcooo]Z00Oo0?on00?ooo]Zoo40oooonfX00_oonfX2obKo0006
oon60?l01ooooe@0o`0]oooo>03o09go0ooonfX01?oo0:cooo]ZoookJ_oonfX2ool030Ko0;3o00?o
onh0oookJ_oo00001Ooo00001oooN@3o0?mIo`3oFOoonf[oo`3=o`0gooooa@000_oo07<01?ooN@3o
oe<0oomC0?oc0?l2o`2`o`03o`3oh?l0/?oo0;3o00;o0;3o00?oA?l0ool0^?oo0;P00_oSo`02oomA
00Go00oo00?ooo]ZoolT0?oo90000_l0oaP00ooonf[oo`2@ool0T003oiCo0003oooS0?nDo`3oU?l0
00;o04;o00Coo`11oookJ_l0onoo0;Ko0_l0/?l6o`0?o`Cooo]Z00?o0;3oool0l_oo0?800_oonfX2
ofl0o`;ookX00ol03ol2ool0I`Oo05oo3_oonfX2o`3o2@Oooo]Z0ol007l4oookJPOo001oAOoonfX3
o`00O`Cooo]Z1ol007l3oookJP03o`3o2Ooonf[ooo]Z00oooo]Z0_oo0:l3oookJP04ool0Iooonf[o
oo]Zo`3oH0;ookX000?ooo]Zofl0oooonfX00_oonfX00ooo0?;oo`25oookJP06oookJP;oon800_oo
nfX2oeGo00;o0?o_00?ooo]Zool0@Ol0@_l00_l007l01OooM03oon<0oooS0?oEo`3onOl000;oo`2@
0_l0oaP01Ol007ooob@0o`00Oooonf[ooah000;oE@3o0_l0Eol01?ooD@3ohol0on?o0?ooS002ool0
^007o`3oTOoonf[o0?mCo`3oDoo:0?oo0?oPool0l002oo<0o`03oomC0?oonf[ooo]Z00;oo`1c0_l0
=ol01?oo0<gooo]Zo`3oFOo00?l2o`2Bo`03om[o0?oo03kooo]Z00?ooo]Z00Woonh0oookJ_l0obco
on`0oolN0?n;o`3oo`40ool03?l0A?l00_oonfX2ool0[0;ooo]Z00Go9?l0o`2Mool0;Ooo02gooomD
0002oon60003obKo0?oo0=_ooo]Z00;ooo]Z00?ol@3ooookJ_l0B?l00_oo0<P01?oo5P3o0?l[oago
0?lMo`02o`3oK0;om_l00ooonfX01Ol0W_oooo]ZoookJ_oonf[o0;7o00?ooo]Z00?ooj<0oookJ_oo
nfX02?oonfX01?o6o`3ooo]Zo`3<oonn0?l=oookJP?oo`0H00?ooo]Zo`000?l000000_l00006oook
JP?oo`0H3?oonfX2okh0o`03o`3<oooonf[oa_l000[ooo]Z00?ooj<0oookJ_oonfX00_l0/Ol3oook
JP06o`2Noooonf[ooo]ZoookJ_ofo`3ooo]Z0_l0of`01?oonf[o7Ol0oookJ_oo5P02ool0b003o`18
oooonf[ol@3o00?ooo]Z00Goo`3KobKo0?ooQP3oohH0oomD0002o`0]o`04o`2MoolTo`3ooo]Zoook
JP;oo`2/0ooonfX02?oo00coo`40oh_o0?oo7P3oon`0obP0oooonf[oonh01?oonfX02?oo03kof_l0
oookJ_l0T_oo`03oo`3oFOoonf[oo`3=0_l0=ol01Oooa@3oo`1coookJ_oonf[ooe<000;ol`3o00?o
o`3`o`3oh?oonfX00_l0oe<01Ooonf[oo`03o`3oTOoo0;Sooh`000;ohol000Kooe40o`1GoomE0?oo
E@3ooookJ_oo7P02oookJP0<oolT0?oonf[o0?lHo`3o6?l007ooo`2@ooWo0?oEo`3oo`1AoooS0?oo
M03o001o0_l0@_l01?oo047ooo]Zo`3okol0onl2oeGo00;ooo]Z0_oohP07oookJP;oo`3b0ooonfX0
0om_0?oooo]Zoonj0002o`3oH003oookJ_oo06Ooo`1W00?ooo]Z0_oo0:lAoookJP;o0?l91ooonfX3
o`00O`Cooo]Z1ol007lMoookJP00:_oonfX3o`00O`Cooo]Z1_l007l4oookJP;o0?l94OoonfX01?oo
0:oooo]ZoookJ_oonfX2ool0I`03oookJ_l0of3o0?mP00;ookX00_m_0?l2oookJP;oo`3b1ooonfX2
oooR00?ooo]Z00OoEOl0ool0Q_l0onoooo]Zool0@Ol0@_ooolT000?oA?l000_o0?onodCo0?m4o`3o
A?l0ool0T?oonf[o0?lHoookJ_oo903o0?l<o`00O`02oolN00;oE@3o00co05Ooool00?ooD@3oo`00
oon<0?ooN@3oo`2ho`3oTOoo00?oo`00o`3oDooonfX2o`3oh005ool0l?oc0?oo05oooomC0?l0Gol0
0_oo07<4o`3oG@06oomi0?l0oeWo05ooo`1OoooJo`3oo`0n0_oonfX00ooUo`3o0?mMo`3oG@02o`3o
G@;oon`000Cooah0ool10?oo00coo`0<0ooonfX00ooo0:cooo]ZonGo0003onGo0006o`0]oooUo`3o
iOl0onGo0?lVo`3oo`3K0_oonfX3o`3ooP03o`3oGOl0Goooo`3800?o05oo00Go7Ol0o`2`ool0/?oo
0;3oooKo0003oookJP04o`2Noooonf[ooo]ZoookJP;oo`000ooonfX00oooX`3ooo]Zool00003oook
JP?oobP00_nDo`02o`3<o`03o`3o[Ol03ooo0?n]00;ooo]Z00?oobP0oiCo0?l0ojd02?l03ol3oook
JPCo00002?oonfX00oooN@3o0?ono`3ooP05o`3ooPGooo]Z0_nn0?l00ol0c?ooo`00ool00004ool0
00Gooo]Z00?ooj<0o`3oo_oonfX00_oonfX01Ol0/Ooooo]ZoookJ_oonf[o09ko00;ooo]Z0_ofo`00
1?oonf[o0?m/o`3oK?lMo`05o`3ooP03o`18oooonf[ol@3o00?ooo]Z0_lVo`02oon60004oomD0?l0
;OooocP0o`2Mo`?ooo]Z00Coo`2/oookJ_oonf[ooo]Z0_oo00`5o`2`o`;oonh000?ooo]Zool00?oo
00001?oo00001oooN@3o0?mIo`3oFOoonf[oo`3=o`0gooooa@000_oo07<01?ooN@3ooe<0oomC0?oc
0?l2o`2`o`03o`3oh?l0/?oo0;3o00;o0;3o00?oA?l0ool0^?oo0;P00_oSo`02oomA00Go00oo00?o
oo]ZoolT0?oo90000_l0oaP00ooonf[oo`2@ool0T002oiCo00;oon<00_nDo`02o`12o`06ool0@Ooo
nf[o0?o_o`2foomEo`3o0;3o1Ol03ol5oookJP03o`2`oooo0?;oo`3b00;ooo]Z0_m_0?l2oonj00?o
00oo0_oo06L00ooonf[o05ooo`1Oo`03o`1Oo`oooo]Z0_l0o`T7oookJP?o001o1?oonfX6o`00OdKo
oo]Z0ol007l4oookJPKo001o0ooonfX2o`3o2A7ooo]Z0_oo0:l2oookJP;oo`1W0_oonfX01Ol0of3o
okX0oonj0?oonf[oK`3o00;ooo]Z00?oon@0ool0l_oo08D01ooonfX01_oohP3ooo]ZoookJ_oonf[o
EOl0o`2fo`;o0?o_0_oo04402_l0@_oo001oo`00OoooM03oon<0ool0DOoEo`3onOl0ool0T?oonfX2
o`3o6005o`00Oooo903o001ooookJ_oo7P000_mE0?l2o`1Go`0:oomA0?oSo`3ohol0oon<0?oo0;So
0?nAool00ooonf[o0?mCoookJP;o0?oP00Coo`3`oo<0oooc0?oooe<00_oonfX01Ooo07?oolD0o`0g
ool0=ooooo]Z00;o0?mI00?o0?lUo`2BoooonfX00_oo03h4oookJP06ooo^0?oonf[o0?l/ooo/0?oo
7P3oRol00_oo00`3oookJP;oo`2/0_oonfX01_l0WOooocP0o`0]ool0;Ooooe@0oon600;o9_l000?o
o`3KoookJ_oonfX00_oa0?l02?oonf[o04Soool0b?oo0<SooaH0oookJ_lMo`3ooo]Z0_l0of`01?of
o`3ooo]ZoookJ_oonfX2o`2No`;ooo]Z0_l0/Ol3oookJP03oonS0?oonf[ooo]Z00Oooo]Z0_o6o`02
o`3<o`03okh0oooonf[ooo]Z00[ooo]Z0_oo01P3oookJPCo00002?oonfX2ool060cooo]Z00Co_P3o
o`3<oooonf[oa_l02_oonfX01OooX`3ooo]ZoookJ_oonf[o0;7o00?ooo]Z00Co09kooookJ_oonf[o
oo]Z0_ofo`02o`3oK004oookJ_lMo`3ooo]ZoolF00;oo`3800?o04SooookJ_oa0?l00ooonfX01Ooo
0=_o9_l0oon60?ooQP3ooe@000;o02go00Co09goobCo0?oonf[ooo]Z0_oo0:`3oookJP08ool03?oo
0@3oRol0oolN0?ook03o:03ooookJ_ookP04oookJP08ool0?_oJo`3ooo]Zo`2Booo00?oo0?mIoook
J_oo0<d2o`0go`03ooo50?oo07?ooo]Z00;ooe<00_oc0?l00ooo0?3o0?oPoookJP02o`3oD`05oook
J_oo00?oT?l0ool0^?ooS0000_oSo`001_ooD@3o05OooeD0oomE0?oooo]ZoolN00;ooo]Z00Soob@0
oookJ_l0oaSo0?lHo`00Oooo093onOl0omGo00;oon<000Koog@0o`00Ool0@_oo04;oool0@OoonfX2
o`3ok`;oEOl00_oonfX2oooR00Oooo]Z0_oo0?83oookJP03ofl0oooo^P3ookX000;o0?mP00?ooo]Z
ool0Iooo06L00ooonfX2ool0[a7ooo]Z00?o0?l9oookJ_oonfX01_oonfX3o`00O`Cooo]Z1_l007lN
oookJP009ooonfX6o`00O`Cooo]Z0_l007l8oookJP03o`3o2Ooonf[ooo]Z013ooo]Z00Coo`2_oook
J_oonf[ooo]Z0_oo06L3o`3oH0;ookX000Cooo]Zofl0oooonf[ooo]Z0_oo0?87oookJP;oon800_oo
nfX2oeGo0005ool0Q_l0onoo001oool0@Ol0@_l00om4o`000ol0ookoA?l0odCo0002odCo0007ool0
T?l0oaSo0?lHoookJ_l0o`coob@0o`00O`02oolN00;oE@3o00Wo05OooomA0?ooD@3oo`00oon<0?oo
N@3oT?l0o`3oTOoonfX00_l0oe<01OnDo`3o0?oPo`3oh?oo0?3ol`3o00;ooe<000Go05ooool0Looo
07?oiOl0o`3oG@02onGo0004o`3oFOo00?oo05ooo`1Oo`;oo`0n0_oonfX2onGo0003o`3oGOoUo`3o
0?mM00;oon`000Cooah0ool10?oo00coo`0<0_oonfX2ool0[0CoiOl00_l0;Ol2onGo0003oolX0?lV
o`3oo`3K00;ooo]Z0ol0ooh01Ol0oegoo`38ool0b?l0oego05oo00;o7Ol00ol0/?l00oofo`3ooo]Z
oookJP02o`2No`;ooo]Z0ooo0002oookJP03oonS0?oonf[ooo]Z00Cooo]Z0_l0/?l2oolX0003oiCo
0?l0c?oo0?n]00;o0?n]00KoobP0oookJ_oonf[oobP0oiCo0?l0ojd5o`0?o`03o`3o[Ooo003oo`00
00?ooo]Z1?l00009oookJPOo0?on1_oonfX00onn0?ooogT0oomi0003oomi00;oo`001OoonfX2oonS
00?ooo]Z00Go0;7ooookJ_oonf[ooo]Zo`2No`03oookJP04ooKo0?oonf[o0?m/o`3oK0;o7Ol01?l0
ooh00ol0B?oooo]Zoo40o`03oookJP08ool0folVo`3oohH0oon60?ooE03o02gooolh0?l0WOl3oook
JP04ool0[?oonf[ooo]ZoookJP;oo`0<1Ol0/?l2ooo^0003oookJ_oo003oo`0000Coo`0000OoogT0
o`3oFOl0oeWooo]Zool0cOl0=oooolD000;oo`1c00CoA?l0oomC0?ooD`3ol`3o0_l0/?l00ol0on3o
0;3oo`2`o`03o`3ooP;oo`2h0_oSo`02oomA00Go00oo00?ooo]ZoolT0?oo90000_l0oaP00ol007oo
o`2@ooWo0002oiCo00;oon<00_nDo`02o`12o`06ool0@Ooonf[o0?o_o`2foomEo`3o0;3o1Ol03ol5
oookJP03o`2`oooo0?;oo`3b00;ooo]Z0_m_0?l2oonj00;o00oo00Cooo]Zool0Iooo06Oooo]Z1Ol0
Gol?oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z1_l007l4oookJP;o001oAooonfX6o`00O`Cooo]Z0_l0
07l7oookJP03o`3o2Ooonf[ooo]Z013ooo]Z00Coo`2_oookJ_oonf[ooo]Z0_oo06L00ooonf[o0?mP
o`3oH002oonj00;oK`3o0_oonfX00oooi03oo`3bool0Q@07oookJP03oooR0?oonf[ooo]Z00;oEOl0
00?o0;Koo`3okol0onl00_oo04400ol0@_oo001oo`00O`02oooS0005ool0DOoEo`3onOl0ool0T?oo
nfX00_l0oaP2oolT0003o`00Oooonf[ooah000;oE@3o0_l0Eol01_ooD@3ohol0on?o0?ooS03oo`2h
o`3oT@;ooo]Z00Go0?mCoookJ_l0on3o0?oPool0l002oo<0o`08oomC0?oonf[oo`1cool0Loooa@3o
03Ooool0cOoonfX2o`3oF@;o09;o00?ooo]Zool0?_oo03h00ooonfX2ooo^0005oookJ_ook03oon`0
oolN0?oo0@000_oo00`3oookJP07ool0[?oonf[ooo]ZoookJ_l0WOooocP0o`0]o`02oomD0004oon6
0?lVo`3oo`3Kool0f`;ooo]Z00Gol@3ooookJ_l0B?oo04Soool0b002oolF0006oookJ_lMo`3o0?m/
o`3oK?oonf[om_l00ooonfX01Ol0W_oooo]ZoookJ_oonf[o0;7o00?ooo]Z00?ooj<0oookJ_oonfX0
2?oonfX01?o6o`3ooo]Zo`3<oonn0?l<oookJP03ool06?oonf[ooo]Z00?ooo]Z1?l00009oookJP;o
o`0H2ooonfX2okh0o`03o`3<oooonf[oa_l000Wooo]Z00Gooj<0oookJ_oonf[ooo]Zo`2ao`03oook
JP04o`2Noooonf[ooo]ZoookJP;om_l000Kooo]Zo`3oK?oonf[o7Ol0oookJ_oo5P02ool0b004o`18
oooonf[ol@3ooo40o`;ooo]Z00Goo`3KobKo0?l007ooohH0oomD0002o`0]o`04o`2MoolTo`3ooo]Z
oookJP;oo`2/0ooonfX02?oo00coo`40oh_o0?oo7P3oon`0obP0oooonf[oonh01?oonfX02?oo03ko
f_l0oookJ_l0T_oo`03oo`3oFOoonf[oo`3=0_l0=ol00oooa@3oo`1coookJP02oomC00;ol`3o00?o
o`3`o`3oh?oonfX00_l0oe<01_oonf[oo`03oi3o0?oo0;Sooh`0on?o00;ooe4000Go05OooeD0oomE
0?oooo]ZoolN0002oookJP04oolT0?l007oo0?lHo`3o60;oo`2@00KonOl0ool0DOooh`3oon<0oomd
0?l007l2o`12o`04ool0@Ooonf[o0?o_o`3ok`;oEOl00_oonfX2oooR00Oooo]Z0_oo0?83oookJP03
ofl0oooo^P3ookX000;o0?mP00?ooo]Zool0Iooo06L00ooonfX00ooo0:oooo]ZoookJP0@oookJP03
o`3o2Ooonf[ooo]Z00?ooo]Z1_l007l4oookJP;o001o8_oonfX002Oooo]Z1_l007l4oookJP;o001o
2?oonfX00ol0o`Wooo]ZoookJP0?oookJP;oo`2_0ooonfX00ooo06Oooo]Zo`3oH002o`3oH003oonj
0?m_0?ooK`3o00;ooo]Z0ooo0?87oookJP;oon800_oonfX02omEo`3o0;Koo`3okol0onoo001oool0
@Ol0@_ooolT0o`2`ooooN@3o0?on00CoA?l000Ooo`2@o`3o6?l0oaSo001oo`3o3?l007oooo]Z00;o
oah00_mE0?l02Ooo003ooe40oomA0?oo003ooh`0oomi0?n@o`3o0?nAool00002o`3oD`03oiCo0?l0
on3oo`3`00;ol`3o0_ooD`001?l0Goooo`1conGo0?l0oed3onGo0004o`3oFOo00?oo05ooo`1Oo`;o
o`0n00Gooo]ZonGo0?oUo`3oiOl0o`3oG@02onGo0005ooo/0?l0oegoo`40o`14oooo00`00ooonfX2
ool0[0;ooo]Z0_oUo`001?l0;OooiOl0onGo0?oUo`02obKo0003ool0fooonf[o0?on00;o0?on0_l0
oed01_oo0<So0?mMo`3oGOl0oego7Ol0o`1Oo`;o0;3o0_ofo`02oookJP04o`2Noooonf[ooo]Zoook
JP?oo`000_oonfX00oooX`3ooo]ZoookJP03oookJPCo0;3o00KoobP0o`1Oool0c?ooU?l0o`3o[OnD
o`04oookJP;oU?l00_l03ol00ol0ojgoU?l0oolX0002ool000Cooo]Z1?l00009oookJP03odCo0?l0
ooko0?on00?o0?on1ooonfX01?nn0?ooA?l0odCo0?m4o`05oomi00Gooo]Z00Gooj<0oookJ_oonf[o
oo]Zo`2ao`03oookJP06o`2Noooonf[ooo]ZoookJ_ofo`3ooo]Z0_l0of`2oago0007oookJ_l0ooko
0?ono`3oo_l0B?oooo]Zoo40o`03oookJP08ool0folVo`3oohH0oon60?ooE03o02gooolh0?l0WOl3
oookJP04ool0[?oonf[ooo]ZoookJP;oo`0<1Ol0/?l2ooo^0003oookJ_oo003oo`0000Coo`0000?o
ogT0o`3oFOl0oeT00_ooN@002?l0=oooogT0ool0Looo07?oA?l0oomC0?m4o`3ol`3o0_l0/?l00ol0
on3o0;3oo`2`o`03o`3ooP;oo`2h0_oSo`000oooD@3o00ooo`0?o`04o`0?o`03oookJ_oo903oob@0
00;o0?lH00?o001oool0T?oio`000_nDo`02oooS00;oU?l00_l0@_l01?oonf[o001oo`3okol0]_l2
oeGo00Go00oo1OoonfX00ooo08Goo`3bool0lP02oookJP;oK`3o0_oo^P000ol0of3o00oooookJP02
ool0I`03oookJ_l0Gooo05oo00?o05oo3ooonfX00ol0o`Wooo]ZoookJP03oookJPKo001o1?oonfX2
o`00OdOooo]Z1_l007l4oookJP;o001o1ooonfX00ol0o`Wooo]ZoookJP0?oookJP;oo`2_0ooonfX2
ool0I`03oookJ_l0of3o0?mP00;ookX000CoK`3ooookJ_oonf[ooo]Z0_oo0?800ooo08Gooo]Zoook
JP05oookJP03oooR0?oonf[ooo]Z00;oEOl000?oo`26o`3okol007l00_oo04400ol0@_oo001oo`00
O`02oooS0005ool0DOl0n?oonOl0ool0T?l007l00_l0oaP2oolT0003oookJ_oo7P3ooah000;oE@3o
00go05OooomA0?ooD@3ohol0oomX0?n@o`3oo`2ho`3oTOoonf[oo`0Ko`3oDooonf[o0?oP00;oo`3`
00Col`3ooomC0?ooD`3ooo]Z0_oo07<01?ooa@3o03Ooool0cOoonfX2o`3oF@;o09;o00?of_l0ool0
?_oonfX00ooonfX2ooo^0007obP0ooook03oon`0oolN0?oo0@3oo`0<o`14o`03oookJP0<ool0[?oo
nf[ooo]ZoookJ_l0WOooocP0o`0]ooooE03o00Oooon60?lVo`3oo`3K0ooonfX00ooa0?oooo]Zo`18
o`02ool0b004oolF0?l0ob_o7Ol0oago00;o0?m/0_ofo`02oookJP;o09ko0ooonfX01Ol0/Ooooo]Z
oookJ_oonf[ooj<000Wooo]Z00?oa_l0oookJ_l0c?l00_nn0?l;oookJP03ool06?oonf[ooo]Z00Co
oo]Z1?l0000:oookJP03ool06?oonf[ooo]Z00Wooo]Z0_nn0?l00ol0c?oooo]ZolKo0009oookJP;o
oj<00_oonfX2o`2ao`;ooo]Z00Co09kooookJ_oonf[ooo]Z0_ofo`002_oonf[o0?m/oookJ_lMo`3o
oo]ZoolF0?oonf[oo`38o`18oooonfX2oo40o`;ooo]Z00Goo`3KobKo0?l007ooohH0oomD0002o`0]
o`04o`2MoolTo`3ooo]ZoookJP;oo`2/0ooonfX02?oo00coo`40oh_o0?oo7P3oon`0obP0oooonf[o
onh01?oonfX02?oo03kof_l0o`2Bool0T_oo`03oo`3oFOoonf[oo`3=0_l0=ol00oooa@3oo`1coook
JP02oomC00;ol`3o00?oo`3`o`3oh?oonfX00_l0oe<01_oonf[o0?nAoi3o0?oo0;Sooh`0on?o00;o
oe4000Go05OooeD0oomE0?oooo]ZoolN0002oookJP04oolT0?l007oo0?lHo`3o60;oo`2@00KonOl0
ool0DOooh`3oon<0oomd0?l007l2o`12o`04ool0@Ol007oo0?o_o`3ok`;oEOl00_oonfX2oooR00Oo
oo]Z0_oo0?83oookJP03ofl0oooo^P3ookX000;o0?mP00?ooo]Zool0Iooo06L00ooonfX00ooo0:oo
oo]ZoookJP0@oookJP03o`3o2Ooonf[ooo]Z00?ooo]Z1_l007l4oookJP;o001o8_oonfX002Wooo]Z
1?l007l5oookJPOo001o0_oonfX00ol0o`Wooo]ZoookJP0?oookJP;oo`2_0ooonfX01_oo06Oooo]Z
o`3oH?l0of3o0;Oooonj00;oK`3o0_oonfX2ool0lP03ool0QOoonf[ooo]Z00Gooo]Z0_oohP02oook
JP03oeGo0?l0]_oo0?o_00;ooo]Z00?oo`11ooo90?l007l00_ooN@001ol0ookoA?l0oomi0?oio`3o
o`2@o`00Ool0oaP00_l007l02Ooob@3o001ooookJ_oo7P3ooo]ZoeD0ool0ocKoo`00oomA0002ool0
0007oomi0?oo0;SoT?l0ool00ooo003o0?mCoiCo0002o`3oh003ool0l?oc0?ool`3o00;ooe<00_oo
07<00ooUo`3o0?mMonGo0002onGo0004o`3oFOo00?oo05ooo`1Oo`;oo`0n00Cooo]ZonGo0?oUo`3o
0?mM0ooUo`001Oook03ooah0ool10?l0A?ooo`0<00?ooo]Z00Coo`2/oookJ_oonf[ooo]Z0_l0WOl0
1_l0;OooiOl0onGo0?oUo`3o9_l0ool0f`;o001o0_l0ooh3o`3oG@05ool0b?l0oego0?mMo`3oGOlM
o`000ol0/?l01Oofo`3ooo]ZoookJ_oonf[o09ko00;ooo]Z0ooo0002oookJP;ooj<01?oonfX6o`2`
o`05o`1Oool0c?ooU?l0oiCo0?oo:0001?oonfX01Ooo:03oU?l0o`3o[OnDo`3oobP000?oo`001Ooo
nfX4o`0000Wooo]Z00?oogT0o`3oo_l0ooh00ol0ooh7oookJP03okh0oom4o`3oA?l000CoA?l00_oo
N@05oookJP05oonS0?oonf[ooo]ZoookJ_l0/Ol00ooonfX01_l0W_oooo]ZoookJ_oonf[om_l0oook
JP;o0?m/00?ooo]Zoago0?oonfX00ol0ooh00ol0B?oooo]Zoo40o`03oookJP08ool0folVo`3oohH0
oon60?ooE03o02gooolh0?l0WOl3oookJP04ool0[?oonf[ooo]ZoookJP;oo`0<00?oo`40o`2`ool0
/?l00_l0/?l2ooo^0003oookJ_oo003oo`0000?oo`000_ooN@02o`3oF@;oogT000Ko03Oooomi0?oo
07?oo`1codCo0?ooD`02oo<0o`;o0;3o00?o0?oPo`2`ool0/?l00ol0ooh2ool0^0;ohol000?ooe40
o`0?ool03ol00ol03ol2oookJP;oob@00_l0oaP00ol007ooo`2@ooWo0002oiCo00;oon<000CoU?l0
o`00Ool0@_oo04;o0_l007l01Ol0onoo0;KooeGo0?mEo`3ooo]Z00?o00oo1_oonfX00ooo08Goo`3b
ool0lP02oookJP;oK`3o0_oo^P000ol0of3o00oooookJP02ool0I`;ooo]Z0ol0Gol@oookJP03o`3o
2Ooonf[ooo]Z00Gooo]Z1?l007l5oookJPOo001o@ooonfX4o`00O`Gooo]Z1ol007l00ooonf[o0?l9
oookJP0@oookJP;oo`2_0ooonfX2ool0I`03oookJ_l0of3o0;Oo00;ookX000KoK`3ooookJ_oonf[o
oo]Zool0l_oo08D8oookJP03oooR0?oonf[ooo]Z00;oEOl00_l0onl01_oonf[oo`11o`12ool0@_oo
001ooomd00;oon<000CoeOl0ooWo0?oo093oo`2@0_l0oaP01?l007ooob@0oolT0?oonfX2oolN00;o
E@3o00Go05OooomA0?oSo`3ohol0oomX0002ool0^004o`3oTOoonf[o0?mCo`3oD`;o0?oP00?oo`3`
oo<0oooc0?l00_ooD`000ooonf[oo`1cool0L`02o`0go`04ool0cOoonf[o0?mIo`3oF@;o09;o00?o
f_l0ool0?_oonfX00ooonfX2ooo^0007obP0ooook03oon`0oh_o0?oo0@3oo`0<o`14o`03oookJP09
ool0[?oonf[ooo]ZobCo0?l0WOooocP0o`0]ooooE03oohH000;o9_l000Ooo`3Ko`00Ool007oooo]Z
oo40oooonf[o04So00;oo`3800CooaH0oookJ_lMo`3ooo]Z0_l0of`01?ofo`3ooo]ZoookJ_oonfX2
o`2No`;ooo]Z0_l0/Ol2oookJP;ooj<02OoonfX01?o6o`3o0<coo`3<oonn0?l;oookJP03ool06?oo
nf[ooo]Z00Gooo]Z1?l0000:oookJP;oo`0H2ooonfX01?nn0?oo0<cooookJ_o6o`09oookJP;ooj<0
0_oonfX2o`2ao`;ooo]Z0_l0W_l2oookJP;om_l000[ooo]Zo`3oK?oonf[o7Ol0oookJ_oo5P3ooo]Z
ool0b?l0B?oooo]Z0_oa0?l2oookJP05ool0folVo`3o001ooon60?ooE0000_l0;Ol01?l0WOoo9?l0
oookJ_oonfX2ool0[0?ooo]Z00Soo`0<ool10?n;o`3ooah0ooo/0?lX0?oooo]Zooo^00Cooo]Z00So
o`0nom[o0?l0T_oo09;ool00ool0oeWooo]Zool0c@;o03Oo00CoolD0ool0Looonf[ooe<00_oc0?l2
ool0l00:o`3oh?oonf[o0?mCool06ooo00?o0?nAoi3o0?oo0;Sooh`0on?o00;ooe4000?o05OooeD0
oomE0?l00_oo7P02oookJP04oolT0?oonf[o0?lHo`3o60;oo`2@00KonOl0ool0DOooh`3oon<0oomd
0?l007l2o`12o`04ool0@Ol007oo0?o_o`3ok`;oEOl00_oonfX2oooR00Oooo]Z0_oo0?83oookJP03
ofl0oooo^P3ookX000;o0?mP00?ooo]Zool0Iooo06L00ooonfX00ooo0:oooo]ZoookJP0?oookJP;o
0?l91ooonfX4o`00O`Gooo]Z1ol007lLoookJP00:_oonfX3o`00O`Gooo]Z1ol007l2oookJP03o`3o
2Ooonf[ooo]Z00oooo]Z00?oo`2_oookJ_oonfX00_oonfX01_oo06Oooo]Zo`3oH?l0of3o0;Oooonj
00;oK`3o0_oonfX2ool0lP03ool0QOoonf[ooo]Z00Gooo]Z00Ooon80oookJ_oonf[ooo]ZoeGo0?l0
]_oo0?o_00;ooo]Z00Ko04;oooo90?l0/?ooogT0o`3oo_m4o`02oomi0007ooWo0?oo093o001oo`3o
6?l007ooob@0ooo90002oookJP03oolN0?mE0?ooE@3o00;oo`0000Oooe40ool00?oo003oogT0ool0
^?l0oi7oo`0300;o0?mC00Sooo]Zo`3oh?l0on3oo`3`oo<0ool0Gooooe<0o`1Oo`;oo`1c00CoiOl0
o`3oGOoUo`3oiOl00_l0oeT2o`1Oo`03om[o0?oo03ko05oo00OoiOl000?oon`0oolN0?oo0@000_oo
00`3oookJP05ool0[?oonf[ooo]ZoookJ_l0WOl00_l0;Ol2oomD0004onGo0?lVo`3oo`3Ko`00O`Co
0?on00?oiOl0o`3oGOoo0<P00ol0oed01OlMo`3o0;3oo`2`ool0/?oom_l000;ooo]Z0_l0W_l00ooo
nf[oo`00ool00002ool000;ooo]Z00?ooj<0oookJ_oonfX00_oonfX6o`2`o`;o05oo00?oobP0oiCo
0?oo:0000ooonfX2ool00003oolX0?nDo`3oobP000Coo`001_oonfX4o`0000[ooo]Z1Ol0ooh8oook
JP;o0?on1_m4o`05oookJP05oonS0?oonf[ooo]ZoookJ_l0/Ol00ooonfX01Ol0W_oooo]ZoookJ_oo
nf[om_l000CoobP000?o7Ol0oookJ_l0ooh00_l0ooh4onGo00;ooo]Z00Soo`3KobKo0?ooQP3oohH0
oomD0?l0;OooocP0o`2Mo`?ooo]Z00Coo`2/oookJ_oonf[ooo]Z0_oo00`00ooo0@3o0;3oo`2`o`02
o`2`o`;oonh00_oonfX4ool00005oomi0?m4o`3o0?mIo`3oFOooN@000_l0=ol01Om4o`3oo`1cool0
Lom4o`3ooe<000;ol`3o00?o0;3oo`3oh?l0on000ol0/?l2o`3ooP06ool0^?ooS03ohol0on?o0?oo
D@3o05Oo1?l03ol2oookJP0=oolT0?oonf[o0?lHo`3o6?oonf[oo`2@ooWo0?oEo`3oU?l0oooS0?oU
o`3oU?l0oookJP02o`12o`;o001o00Go0?o_o`2foomEo`3oEOl0oookJP03o`0?o`Kooo]Z00?oo`25
ool0l_oo0?800_oonfX2ofl0o`;ookX00_l0of000ooonf[oo`1Wool0I`02oookJP?o05oo4?oonfX0
0ol0o`Wooo]ZoookJP06oookJP?o001o1OoonfX7o`00OdCooo]Z0ol007l5oookJPOo001o00?ooo]Z
o`3o2OoonfX04?oonfX2ool0[`?ooo]Z0_oo06L01_oonf[o0?mPo`2goooo^P3ooo]Zofl0o`;ooo]Z
00?oon@0ool0l_oo08D01ooonfX2oooR00;ooo]Z0_mEo`02o`3ok`03oookJ_oo047o04;o00;o001o
00Goog@0oooS0?oo057oeOl0ooWo0002ool0T0;o0?lH00Go001ooolT0?oonf[ooo]ZoolN0002oeD0
o`03o`3o=_l0Eooooe4000;ohol000Gooh`0ool0^?oo0;So0?nAoookJP02o`3oD`;o0?oP00Coo`3`
oo<0oooc0?oooe<00_oonfX03?oo07?oolD0o`0gool0=oooo`3=oookJ_l0oeWo`03oo`2Boooonf[o
f_l0ool0?PCooo]Z00Koonh0oookJ_l0obcoon`0oolN0?n;o`02ool030?ooo]Z0_oo0:`2oookJP;o
09go00Oo02gooookJ_ooE03oohH0obKo0?l007ooo`3K00;o001o0_oa0?l2o`18o`;oo`3800OooaH0
oookJ_lMo`3ooo]Zo`3oK?oonf[om_l000?ooo]Z00Go09kooookJ_oonf[ooo]Zo`2ao`03oookJP03
oonS0?oonf[ooo]Z00Oooo]Z00?oa_l0oookJ_l0c?l00_nn0?l:oookJP;oo`0H1ooonfX4o`0000_o
oo]Z0_oo01P:oookJP03okh0ool0c?oo0<co00;oa_l02?oonfX2oonS00;ooo]Z0_l0/Ol2oookJP;o
09ko0ooonfX02oofo`3ooo]Zo`3oK?oonf[o7Ol0oookJ_oo5P3ooo]Zool0b?l0B?oooo]Z00;ol@3o
0_oonfX01Ooo0=_o9_l0o`00OoooQP3ooe@000;o02go00Co09goobCo0?oonf[ooo]Z0_oo0:`3oook
JP08ool03?oo0@3oRol0oolN0?ook03o:03ooookJ_ookP04oookJP04ool0?_oJo`3o09;oo`2Bo`;o
0?mI00?ooo]Zool0cOl0=ol00_ooa@000ooo07?ooo]ZoomC0002oo<0o`08ool0l?l0on3o0?oPoook
J_l0oe?oo`0Kool00ol0oi42ool0^005oon<0?oSo`3ooe40oomA0?l0Eol00_mE0?l2oolN0004oook
J_oo903oob@0oookJP;o0?lH0_oo09001_oio`3oo`1AoooS0?ooh`3oog@0oookJP;o04;o00Coo`11
o`00Ool0onoo0?o_0_mEo`02oookJP;oon801ooonfX2ool0lP?ooo]Z00?oK`3ooonj0?oo^P000_l0
of000ooonf[oo`1Wool0I`03oookJP03ool0[ooonf[ooo]Z00oooo]Z0_l0o`T8oookJP?o001o1Ooo
nfX7o`00Oacooo]Z000koookJP03o`3o2Ooonf[ooo]Z00oooo]Z00?oo`2_oookJ_oonfX00_oonfX0
1_oo06Oooo]Zo`3oH?l0of3o0;Oooonj00;oK`3o0_oonfX2ool0lPOooo]Z0_oohP02oookJP;oEOl0
00Koo`26o`3okooonf[oo`11o`12oooob@02oomi0006o`3oo_m4o`3oogT0oomi0?oio`3oo`2@0_l0
oaP00ooonf[oolT0oolT0002oookJP04oolN0?mE0?ooE@3oool000;ooe400_oo0002ool0^005o`3o
TOoo003o00ooo`3oDooo00000_l0on02oo<0o`03o`1OooooD`3o05oo00;oo`1c00Co0?mMonGo0?oU
o`3oiOl00_l0oeT01Ol0Gooo0?mMom[o0?oo03ko05oo00KoiOl00_ook0001?oo7P3oo`40ool03?oo
00`2oookJP;oo`2/0_oonfX02OlTo`3o09goo`0]ool0;Ooooe@0oon60?oonf[o9_l0ool0f`05o`3o
oP05onGo0?oo0<Soo`38onGo0?l0oed00_lMo`02o`2`o`;om_l00_oonfX2o`2No`Goo`000_oonfX0
1?ooX`3ooo]ZoookJ_oonfX6o`2`o`?o05oo00?oo`00oolX0?oonfX01_oo00000ooo:03oo`00ool0
0002ool000Oooo]Z1?l0000:oookJPCo0?on2OoonfX5o`3ooP?oA?l01OoonfX01OooX`3ooo]Zoook
J_oonf[o0;7o00?ooo]Z00Go09kooookJ_oonf[ooo]ZooKo0004oolX0004oago0?oo:03o0?ono`3o
oPOoiOl000Soo`3KobKo0?ooQP3oohH0oomD0?l0;OooocP0o`2Mo`?ooo]Z00Coo`2/oookJ_oonf[o
oo]Z0_oo00`00ooo0@3o0;3oo`2`o`02o`2`o`;oonh00_oonfX4ool00005oomi0?m4o`3o0?mIo`3o
FOooN@000_l0=ol01Om4o`3oo`1coomi0?m4o`3ooe<000;ol`3o00?o0;3oo`3oh?l0on000ol0/?l2
o`3ooP06ool0^?ooS03ohol0on?o0?ooD@3o05Oo1?l03ol2oookJP06oolT0?oonf[o0?lHo`3o6?oo
nf[oo`2@0ol0ojd01oooh`3oiOl0oiCo0?oonf[o04;oool0@OoonfX00_l0onl01?l0]_ooEOl0oook
J_oonfX3o`0?o`Kooo]Z00?oo`25ool0l_oo0?800_oonfX2ofl0o`;ookX00_l0of000ooonf[oo`1W
ool0I`02oookJP?o05oo4?oonfX00ol0o`Wooo]ZoookJP1YoookJP03o`3o2Ooonf[ooo]Z00oooo]Z
0_oo0:l3oookJP08ool0Iooonf[ooo]Zo`3oH?l0]ooookX0oookJ_m_0?l2oookJP03oooT0?oo0?;o
o`2500Oooo]Z00?oon80oookJ_oonfX00_mEo`001_l0]_oo0?o_o`3okooonf[oo`11o`12o`;ooo]Z
00Goog@0oooS0?oo057oeOl0ooWo0002ool0T0;o0?lH0_oo9002oookJP04oolN0?mE0?ooE@3oo`3o
=P;ooe400_oSo`001oooS03oo`2hool0^?oo00?ooo]Zo`3oDooonfX00_l0on001?oo0?3ol`3ooo<0
ooooD`02oookJP05ool0Loooa@3o03Ooool0cOoonfX00_l0oeT01Ol0obGo09;ooookJ_oJo`3oo`0n
00Cooo]Z00Koonh0oookJ_ook03oon`0oolN0?n;o`02ool030?ooo]Z00Ooo`2/oookJ_oonf[ooo]Z
o`2Moooo>03o02go00;ooe@000CoohH0obKo0?oo0=_oo`3K0_oonfX00ooa0?oooo]Zo`18o`02ool0
b004oolF0?l0ob_o7Ol0oago00;o0?m/0_ofo`02oookJP;o09ko0ooonfX01Ol0/Ooooo]ZoookJ_oo
nf[ooj<000Wooo]Z00Coa_l0o`3<ool0c?oo_P3o2_oonfX2ool060Sooo]Z1?l0000;oookJP;oo`0H
2_oonfX2okh0o`03o`3<ooo6o`3oa_l000Sooo]Z0_ooX`02oookJP;o0;7o0_oonfX2o`2No`?ooo]Z
00_om_l0oookJ_l0ofcooo]Zoago0?oonf[ooaH0oookJ_oo0<So04SooookJP02oo40o`;ooo]Z00Go
o`3KobKo0?ooQP3oohH0oomD0002o`0]o`04o`2MoolTo`3ooo]ZoookJP;oo`2/0ooonfX02?oo00co
o`40oolN0?oo7P3oon`0obP0oooonf[oonh01?oonfX01?oo03kof_l0o`2Bool0T_l2o`3oF@04oook
J_oo0<go03Ooooo500;oo`1c00Gooo]ZoomC0?oc0?ool`3oool0l002o`3oh005oookJ_l0oe?oo`0K
ool00ol0oi400_oo0;P01OooJ03ohol0oomA0?ooD@3o05Oo00;oE@3o0_oo7P001?oonf[oob@0oolT
0?oonfX2o`3o60;oo`2@00KonOl0ool0DOooh`3oon<0oomd0?oonfX2o`12o`04ool0@Ooonf[o0?o_
ool0QP;oEOl00_oonfX2oooR00Oooo]Z0_oo0?83oookJP03ofl0oooo^P3ookX000;o0?mP00?ooo]Z
ool0Iooo06L00ooonfX00ooo0:oooo]ZoookJP0?oookJP;o0?l9<ooonfX003[ooo]Z0_l0o`TAoook
JP03ool0[ooonf[ooo]Z00;ooo]Z00Coo`1WoookJ_l0of3o0?mP0_oo^P02ofl0o`;ooo]Z0_oo0?87
oookJP;oon800_oonfX2oeGo00;o0?o_00Cooo]Zool0@Ol0@_ooolT00oooN@000om4o`3oogT0oomi
0002ool0T0;o0?lH00?ooo]Zooo90?oo90000_oonfX01?oo7P3oE@3ooeD0oooo0002oomA00;oo`00
0_oo0;P01ol0oi7oo`00o`0?ool0oe?oo`00o`3oh?oo0?000_oc0?l2oomC0004onGo0?oo07?oo`1c
o`3oG@?oiOl000Ko0?mIol00ool0Gooo0?mMom[o0?oo03h7onGo0006ooo/0?oo7P3oRol0ool10?oo
00co04Co0_oonfX01ooo003ooo]ZoookJ_oonf[o9?l0o`2Mool0;Ol00_ooE0001?ooQP3ooo]ZobKo
0?oo0=/4o`3ooP;oiOl000Koo`38onGo0?oUo`3oiOl0oago0?l0oed2o`2`o`04ooKo0?l0/?oooo]Z
oookJP;o09ko1Ooo00000ooonf[ooj<0oonS0002oookJPOo0;3o0ol0Gol=ool000Sooo]Z1?l0000;
oookJP?o0?on2OoonfX7o`3ooPKooo]Z00Gooj<0oookJ_oonf[ooo]Zo`2ao`03oookJP05o`2Noooo
nf[ooo]ZoookJ_ofo`000ooo:002oago0003oolX0?oo5P3o0?on00OoiOl00_lVo`001_ooQP3o00Oo
oomD0?l0;OooocP0o`2Mo`?ooo]Z00Coo`2/ool00?oo003oo`000_oo00`00ooo0@3o0;3oo`2`o`02
o`2`o`;oonh00_oonfX3ool000;oogT000Co`03oo`3oFOooN@3oogT00_l0=ol01Om4o`3oo`1coomi
0?m4o`3ooe<000;ol`3o00?o0;3oo`3oh?l0on000ol0/?l2o`3ooP06ool0^?ooS03ohol0on?o0?oo
D@3o05Oo0ol03ol01Ooo7P3ooo]ZoookJ_oo903ooo]Z00;o0?lH00?ooo]Zool0T?l0ojd00_l0ojd0
0oooh`3oiOl0o`3o[@02o`3o[@06ool0@Ooonf[o0?o_o`3okol0]_ooEOl00_oonfX3o`0?o`Kooo]Z
00?oo`25ool0l_oo0?800_oonfX2ofl0o`05oonj0?l0of3o0?mPo`3oH?oonfX00_oo06L2oookJP?o
05oo4?oonfX00ol0o`Wooo]ZoookJP1XoookJP;o0?l94OoonfX2ool0[`?ooo]Z00Soo`1WoookJ_oo
nf[o0?mPo`2goooo^P3ooo]Zofl0o`;ooo]Z00?oon@0ool0l_oo08D01ooonfX00ooohP3ooo]Zoook
JP02oeGo00;o0?o_0_oonfX02ooo047o04;ooookJ_oonf[oog@0oooS0?oo057o0?SoooWo0?oo093o
oo]Z00;o0?lH0_oo9002oookJP04oolN0?mE0?ooE@3oo`3o=P;ooe400_oSo`001on@o`3oo`2ho`3o
TOoo00?oo`0Ko`3oDooonfX00_l0on001?oo0?3ol`3oool0eoooD`02oookJP05ool0Loooa@3o03Oo
ool0cOoonfX00_l0oeT00ol0obGo09;ooookJP02ool0?PCooo]Z00Soonh0oookJ_ook03oon`0oolN
0?oo0@3oo`0<o`14o`?ooo]Z00_oo`2/oookJ_oonf[ooo]Zo`2Moooo>03o02gooomD0?l01oooohH0
obKo0002ool0f`;ooo]Z00?ol@3ooookJ_l0B?l00_oo0<P01?oo5P3ooo]Zoago0?oonfX2o`3oK0;o
m_l00_oonfX2o`2No`;ooo]Z0_l0/Ol2oookJP;ooj<02?oonfX2olKo00;o0<co00?o_P3ooookJ_oo
nfX02?oonfX00ooo01Sooo]ZoookJP07oookJPCo00003?oonfX00ooo01Sooo]ZoookJP08oookJP;o
_P3o00?o0<cooookJ_o6o`002?oonfX2oonS00?ooo]Z00Go0;7ooookJ_oonf[ooo]Zo`2No`03oook
JP07ooKo0?oonf[o0?m/oookJ_lMo`3ooo]ZoolF0002ool0b004o`18oooonf[ol@3ooo40o`;ooo]Z
00Goo`3KobKo0?ooQP3oohH0oomD0002o`0]o`04o`2MoolTo`3ooo]ZoookJP;oo`2/0ooonfX00ooo
00coo`40oolN0002ooo/0003obP0oooonf[oonh000Cooo]Z00Coo`0nom[o0?l0T_oo09;o0_l0oeT0
1?oonf[oo`3=o`0gooooa@02ool0L`05oookJ_ooD`3ol`3ooo<0oooo0?000_l0on001Ooonf[o0?mC
ool06ooo00?o0?nA00;oo`2h00OoofP0on?o0?ooD@3ooe40o`3o=_mE0?oooo]Z00;ooah000Cooo]Z
oolT0?oo903ooo]Z0_l0oaP2ool0T004omGo0?oo057oon<0oooS00;ooo]Z0_l0@_l01Ooo047o0?o_
o`3okooo08KoEOl000?ooo]Z0_oohP06oookJP03ool0QOoo0?;oo`3b00;ooo]Z0_m_0?l2oonj00;o
0?mP00?ooo]Zool0Iooo06L00ooonfX00ooo0:oooo]ZoookJP0?oookJP;o0?l9<ooonfX003[ooo]Z
00?o0?l9oookJ_oonfX04?oonfX01?oo0:oooo]ZoookJ_oonfX2ool0I`05oookJ_l0of3o0?mPoonj
0?oonfX00_m_0?l2oookJP;oo`3b1ooonfX2oooR00;ooo]Z0_mEo`02o`3ok`03oookJ_oo047oolT0
00CoogT000?oA?l0oomi0?ooN@000_oo0902o`3o6004oookJ_oob@3ooo]ZoookJP;ooah00_mE0?l0
0ooo003ooe40oomA0002ool000;oo`2h00Oo0?nAo`0?ool03ooo0?mCool00?l0on3oo`3`00;ol`3o
0_ooD`000ol0Goooo`1cool0L`04onGo0004o`3oFOo00?oo05ooo`3oG@;oo`0n1?oonfX3onGo0005
ooo/0?oo7P3oo`40ool10?oo00`00ooonfX01ooo003ooo]ZoookJ_oonf[o9?l0o`2Mool0;Ol00_oo
E0001?ooQP3o9_l0obKo0?oo0=/3o`3ooP?oiOl000Goo`38onGo0?oUo`3oiOl0oago0003o`2`o`05
ooKo0?oonf[ooo]ZoookJ_l0W_l01_oo00000ooonf[ooj<0oookJP03oookJP03o`3o3?l0/?oo0;3o
00;o0;3o1?l0Gol=ool000Sooo]Z1?l0000;oookJP?o0?on2OoonfX8o`3ooPGooo]Z00Gooj<0oook
J_oonf[ooo]Zo`2ao`03oookJP06o`2Noooonf[ooo]ZoiCo0?ofo`3oU?l00_oo:002oago00;ooaH0
00?o0?ononGo0?oUo`001?oUo`002Ooo0=_o9_l0obKo0?ooQP3o00OooomD0?l0;OooocP0o`2Mo`02
oookJP;oo`2/0ooo0002ool030;oo`0000?o0;3oooo/0?l0/?l00_ookP02oookJP?oo`000_ooN@00
2Oo00?oo0?mIoookJ_ooN@3o03Oooomi0?m4o`3oo`1coomi0002oomC00;ol`3o00?oo`3`o`3oh?l0
on000ol0/?l2o`3ooP06ool0^?ooS03ohol0o`3oo_ooD@3o05Oo0ol03ol01_oo7P3ooo]ZoookJ_oo
903ooo]Zo`3o60;ooo]Z00Koo`2@o`3o[Ol0ojgo0?n]oooS0?oUo`03o`3o[@04ool0@Ooonf[o0?o_
o`3ok`;oEOl00ooonfX00ol03ooooo]ZoookJP05oookJP03ool0QOoo0?;oo`3b00;ooo]Z00?oK`3o
oonj0?oo^P000_l0of001?oonf[oo`1Wool0Iooo06L2oookJP03ool0[ol0Gooooo]Z013ooo]Z00?o
0?l9oookJ_oonfX0J?oonfX2o`3o2A7ooo]Z00Coo`2_oookJ_oonf[ooo]Z0_oo06L2oookJP03o`3o
H?oo^P3ookX000;oK`3o0_oonfX2ool0lP03ool0QOoonf[ooo]Z00Gooo]Z00?oon80oookJ_oonfX0
0_mEo`02o`3ok`;ooo]Z0_l0@_l2oookJP07oomd0?ooh`3ooo]Zo`3hoooio`3oo`2@oookJP02o`3o
60;oob@00_oonfX01?oo7P3oE@3ooeD0ool0Eol2oomA00;ohol000OoT?l0ool0^?l0oi7ooo]Zool0
6ol0oe?ooo]Z00;o0?oP00Coo`3`oo<0oooonf[ooe<00_oonfX01Ooo07?oolD0o`0goooo0<gooo]Z
00;o0?mI00?o0?lUo`2BoooonfX00_oo03h3oookJP;oonh000Oo:03oooo/0?ook03ooah0ool10?oo
00co04Co00?ooo]Z00Woo`2/oookJ_oonf[ooo]Zo`2Moooo>03o02gooomD0?ooQP000_lVo`001ooo
0=_ooo]ZoookJ_oonf[ol@3ooookJ_l0B?l00_oo0<P01_oo5P3ooo]Zoago0?oonf[o0?m/oookJP;o
m_l00_oonfX2o`2No`;ooo]Z0_l0/Ol2oookJP;ooj<02?oonfX2olKo0003o`3<oonn0?oo_P3o00Wo
oo]Z0_oo01P9oookJPCo00003?oonfX00ooo01Sooo]ZoookJP09oookJP04okh0ool0c?oooo]ZolKo
00Sooo]Z0_ooX`03oookJP05o`2aoooonf[ooo]ZoookJ_l0W_l00_oonfX2ooKo0006oookJ_l0ofco
oo]Zoago0?oonf[ooaH00_oo0<P00ol0B?oooo]Zoo40o`03oookJP05ool0folVo`3oohH0oon60?oo
E0000_l0;Ol01?l0WOoo9?l0oookJ_oonfX2ool0[0;ooo]Z0_oo00`01ooo0@3ooah0ooo/0?ook03o
:03ooookJ_ookP001?oonfX01?oo03kof_l0o`2Bool0T_l2o`3oF@04oookJ_oo0<go03Ooooo500;o
o`1c00Gooo]ZoomC0?oc0?ool`3oool0l002o`3oh005oookJ_l0oe?oo`0Kool00ol0oi400_oo0;P0
1oooJ03ohol0oomA0?ooD@3o0?lfoeD0oooonfX00_oo7P001_oonf[oob@0oolT0?oonf[o0?lHoook
JP;oo`2@00CoeOl0ool0DOooh`3oon<00_oonfX2o`12o`05ool0@Ol0onoo0?o_ool0Q_mEo`000ooo
nfX2oooR00Kooo]Z00?oo`25ool0l_oo0?800_oonfX2ofl0o`;ookX000?o0?mPoookJ_oonfX00_oo
06L2oookJP;oo`2_4OoonfX2o`3o2C?ooo]Z000joookJP03o`3o2Ooonf[ooo]Z00oooo]Z0_oo0:l3
oookJP03ool0Iooonf[ooo]Z00;o0?mP00?ookX0oookJ_m_0?l00ooonfX2ool0lPOooo]Z0_oohP02
oookJP;oEOl00_l0onl00ooonf[oo`11ooo90003oomi0003odCo0?ooN@3oogT000;oogT000Goo`2@
o`3o6?l0oaSooo]Zooo90002oookJP0<oolN0?oonf[oE@3oo`3o=_l0Eooooe40ool00?oSo`3ooh`0
ool0^?n@o`3oo`000ol03ol00ooo003o0?oPool0l002oo<0o`;ooe<000_o05ooool0Lol0GoooiOl0
o`0gool0oegoiOl0o`3oFOo00?oo0?mMom[o0002ool0?P?ooo]Z00WoiOl0ooo^0?oonf[o00ooooo/
0?oo7P3oo`40o`14oooo00`00_oonfX2ool000?ooo]Z0_l0WOl01Ol0;Ooooe@0oomD0?ooQP3o9_l0
00;oo`3K1_l0ooh00ooo0<SoiOl0onGo0002oago00?o0;3o00Gom_l0oookJ_oonf[ooo]Zo`2No`06
ool00003oookJ_ooX`3ooo]Z00;ooo]Z1?l0o``2o`2`o`Co05oo00?oo`00oookJ_oonfX02Ooo0009
oookJPCo00002ooonfX3o`3ooPWooo]Z2?l0ooh5oookJP05oonS0?oonf[ooo]ZoookJ_l0/Ol00ooo
nfX01Ol0W_oooo]ZoookJ_nDo`3om_l000?oU?l00_lMo`02oolF0004ool0b?l0oego0?mMo`3oG@?o
iOl000Coo`3KobKo0?lVo`3oohH00_ooE0000ol0;Ooo09goo`2Mo`02oookJP;oo`2/0ooo00001?oo
00coo`00ool00?oo0003o`2`o`;oonh00_oonfX3ool000;oA?l000Go`03oo`3oFOoonf[oogT0o`0g
o`02oomi0004ool0Lol0ookooe<0oomC00;ol`3o00?oo`3`o`3oh?l0on000ol0/?l01Ol0ookoT?l0
ool0^?ooS03ohol000;ooe4000Go05Ooo`0?ool03ooo00oooolN0002oookJP04oolX0?oonf[o0?lH
oookJP;oo`2@0ol0ojd01ooUo`3o0?n]o`3o[Ol0ojgo04;oool0@OoonfX00_l0onl2oeGo00?ooo]Z
00?o00oooookJ_oonfX01OoonfX00ooo08Goo`3boookJP02oookJP03ofl0oooo^P3ookX000;o0?mP
00?ooo]Zool0Iooo06L00ooonfX00ooo0:oo05oooookJP0?oookJP;o0?l9J_oonfX2o`3o2A3ooo]Z
0_oo0:l3oookJP;oo`1W00?ooo]Zo`3oH?l0of000_oo^P001?m_0?oooo]ZoookJ_oonfX2ool0lP03
ool0QOoonf[ooo]Z00Gooo]Z00?oon80oookJ_oonfX00_mEo`02o`3ok`;ooo]Z0_l0@_l2oookJP;o
on<000OoeOl0o`3hoooio`3oo`2@oookJ_l0oaSooo]Z00;oob@00_oonfX01?oo7P3oE@3ooeD0ool0
Eol2oomA0009on?o0?ooS03oT?l0ool0^?l0oi7ooo]Zool06ol0oe?ooo]Z00;o0?oP00Goo`3`oo<0
ooooD`3ooe<0oookJP02ool0L`04o`3o_Ol0=oooo`3=oookJP;o0?mI0_l0T_l00ooJo`3oo`0noook
JP03oookJP03ooo^0?oonf[o:03o00;oon`000CoRol0ool10?oo00co04Co0ooonfX02Ooo0:cooo]Z
oookJ_lTo`3o09gooolh0?l0;Ooooe@0oon60002obKo0003ool0fooonf[ooo]Z00;ol@3o0_l0B?l2
ool0b007oolF0?lMo`3o7Ol0oookJ_l0ofcooo]ZooKo0003oookJP05o`2Noooonf[ooo]ZoookJ_l0
/Ol00ooonfX00oooX`3ooo]ZoookJP07oookJP04olKo0?oonf[o0<cookh0o`[ooo]Z0_oo01P9oook
JPCo00003?oonfX2ool060[ooo]Z00Co_P3oo`3<oooonf[oa_l02?oonfX2oonS00;ooo]Z0_l0/Ol3
oookJP03o`2Noooonf[ooo]Z00;om_l00_l0of`01?oonf[o7Ol0oookJ_oo5P02ool0b003o`18oooo
nf[ol@3o00?ooo]Z00?oo`3KobKo0?ooQP000_ooE002o`0]o`04o`2MoolTo`3ooo]ZoookJP;oo`2/
0_oonfX2ool03005ool10?oo7P3oon`0ooo/0?lX0?l00_ookP03oookJP;oo`0n00?ooo]Zo`2Bool0
obD00_l0oeT01?oonf[oo`3=o`0gooooa@02ool0L`05oookJ_ooD`3ol`3ooo<0oooo0?000_l0on00
1Ooonf[o0?mCoookJ_oo00?o0?nA00;oo`2h00OoofP0on?o0?ooD@3ooe40o`3o=_mE0?oooo]Z00;o
oah000?ooo]ZoolT0?oo90000_l0oaP01ooonf[oo`2@ool0T?oEo`3oo`1AoooS0?ooM0000_oonfX2
o`12o`05ool0@Ol0onoo0?o_ool0Q_mEo`000ooonfX2oooR00Kooo]Z00?oo`25ool0l_oonfX00_oo
nfX01Om_0?oooo]Zoonj0?oo^P3o0?mP00;ooo]Z0_oo06L2oookJP;oo`2_4OoonfX2o`3o2C?ooo]Z
000joookJP03o`3o2Ooonf[ooo]Z00oooo]Z0_oo0:l3oookJP08ool0Iooonf[ooo]Zo`3oH?l0]ooo
okX0oookJ_m_0?l3oookJP03ool0l_oo08Gooo]Z00Kooo]Z00Koon80oookJ_oonf[ooo]ZoeGo0?l0
]_l2o`3ok`;oo`1100Go0;3ooomi0?ooN@3oogT0odCo0004oomi0005oookJ_l0oaSo0?lHooo90?oo
90000_oonfX03?oo7P3ooo]ZoeD0ool0ocKo05OooomA0?oo003ohol0oon<0?oo0;SoT?l0ool000?o
00oo00?oo`00o`3oh?oo0?000_oc0?l01oooD`3o05ooo`1Ooooo07?o0?mMonGo0?l0=ol00_l0oed0
1_l0oeWo`03oo`3oGOoJo`3oo`0no`3oG@?ooo]Z00OoiOl0ooo^0?oonf[o00ooooo/0?oo7P3oo`40
00;oo`0<0_oonfX3ool00003oookJ_lTo`3o09go00;o02go0_ooE0000oooQP3o9_l0ool0f`06o`3o
oP;oo`3800CooaH0o`3o3?lMo`3o7Ol00_l0/?l2ooKo00?ooo]Z00?o09koool00?oo00001?oo0002
oonS00Cooo]Z00CoolT0o`3o3?l0o`co0?l<1Ol0Gol01?oo003ooo]ZoookJ_oonfX7ool000[ooo]Z
1?l0000<oookJP03o`3oo_oonf[ooo]Z00Sooo]Z1ol0ooh6oookJP05oonS0?oonf[ooo]ZoookJ_l0
/Ol00ooonfX01Ol0W_oooo]ZoookJ_nDo`3om_l000?oU?l00_lMo`02oolF0003ool0b?l0oego0?mM
00Co0?mM00Goo`3KobKo0?lVo`3oohH0oomD0002o`0]o`;o09go0_oonfX2ool0[0?oo`0000Goo`0<
ool00?oo003oo`00ooo/0002o`2`o`05ooo^0?oonf[ooo]ZoookJ_m4o`000_oo0002odCo0009ol00
ool0oeWoA?l0odCo0?l0=oooogT0odCo0?oo07?o0?on00;ooe<00_oc0?l00ooo0?3o0?oPo`3oh003
o`2`o`05o`3oTOn@o`3oo`2hoon<0?oSo`000_ooD@001Ol0Eooooo]Zo`0?ool03ooooah000;ooo]Z
00CoobP0oookJ_l0oaSooo]Z0_oo0902o`3o[@03oooS0?oUo`3o0?n]00;o0?n]00?o04;oool0@Ooo
nfX00_l0onl2oeGo00?ooo]Z00?oon80oookJ_oonfX01OoonfX00ooo08Goo`3boookJP02oookJP03
ofl0oooo^P3ookX000;o0?mP00?ooo]Zool0Iooo06L00ooonfX2ool0[a3ooo]Z0_l0o`UZoookJP;o
0?l94?oonfX2ool0[`?ooo]Z0_oo06L00ooonf[o0?mPo`3oH002oonj0006ofl0oooonf[ooo]Zoook
J_oo0?;oo`251ooonfX2oooR00;ooo]Z0_mEo`02o`3ok`04oookJ_oo047o04;oo`12o`;ooo]Z0_oo
h`001_oEo`3o0?SoooWo0?oo093ooo]Zo`3o60?oob@00_oonfX01?oo7P3oE@3ooookJ_l0Eol2oomA
000:on?o0?ooS03oT?l0ool0^?l0oi7ooo]Zool06ol0oe?ooo]Zo`3oh0;oo`3`00Col`3ooomC0?oo
nf[ooo]Z0_oo07<01?l0okgo03Ooool0cOoonfX2o`3oF@04o`2Boooonf[of_l0ool0?PCooo]Z00So
onh0oookJ_lX0?ooon`0oolN0?n;o`3oo`40ool030?ooo]Z0_oo0:`2oookJP;o09go00Co02gooook
J_ooE03oohH00_lVo`000ooo0=_ooo]ZoookJP02oo40o`;o04So00?oo`38oolF0?oo5P000_lMo`00
1?oonf[o0?m/oookJ_ofo`03oookJP05o`2Noooonf[ooo]ZoookJ_l0/Ol00ooonfX00oooX`3ooo]Z
oookJP06oookJP;oa_l00_l0c?l00onn0?oooo]ZoookJP08oookJP03ool06?oonf[ooo]Z00Sooo]Z
1?l0000<oookJP;oo`0H2_oonfX01?nn0?oo0<cooookJ_o6o`08oookJP;ooj<00_oonfX2o`2ao`;o
oo]Z0_l0W_l2oookJP;om_l00_l0of`01?oonf[o7Ol0oookJ_oo5P02ool0b003o`18oooonf[ol@3o
00?ooo]Z00?oo`3KobKo0?ooQP000_ooE002o`0]o`05o`2MoolTo`3ooo]ZoookJ_oo0:`00ooonfX2
ool03005ool10?oo7P3oon`0ooo/0?oonfX00_ookP03oookJP;oo`0n00Cooo]Zo`2Bool0obGo0?mI
0_oonfX00ooo0<go03Ooooo50002ool0L`05oookJ_ooD`3ol`3ooo<0oooo0?000_l0on001Ooonf[o
0?mCoookJ_oo00?o0?nA00;oo`2h00OoofP0on?o0?ooD@3o05Ooo`3o=_mE0?oooo]Z00;ooah000?o
oo]ZoolT0?oo90000_l0oaP01?oonf[oo`2@ooWo0?oEo`02oooS0003oomd0?oonf[ooo]Z00;o04;o
00Goo`11o`3okol0onoo0;KooeGo0003oookJP;oon801_oonfX00ooo08Goo`3boookJP02oookJP05
ofl0oooonf[ookX0o`2gool0of000_oonfX01?oo06Oooo]ZoookJ_oonfX2ool0[a7ooo]Z0_l0o`Tc
oookJP00:?oonfXBo`000003o`3o2Ol0003o000000oo00000_oo0:l3o`000008ool0Iol0003o0000
o`3oH?l0]ooookX0o`000?m_0?l2o`000003oooT0?oo0?;oo`2500Oo000000Soon80o`000?l0003o
0000oeGo0?l0]_oo0?o_o`0000;oo`111?ooN@000om4o`3oogT0oomi0002oomi0005o`000?l0oaSo
0?lHooo90?oo90000_l000002?oo7P3o0000oeD0ool0ocKo05OooomA0?oo003ohol00_oo0;P00on@
o`3o00ooo`0?o`02o`0?o`03o`1Oool0on3oo`3`00;ol`3o00Kooe<0o`1Ooooo07?oo`1co`3oGOoU
o`02o`3oG@;o0?mI0_l0oed00ooJo`3oo`0no`3oG@03o`0000;oonh000Go00ooooo/0?ook03ooah0
ool10002ool030;o00000ooo00000ol0003o9?l0o`2Mo`02o`0]o`05oomD0?ooQP3oohH0obKo0?oo
0=/01_l0ooh2ool0b004oolF0?l0o`co7Ol0oago00;o0?l<0_ofo`02o`0000;o09ko1_oo0002oonS
00?o00000ooob@000ol0o`co05ooo`1Oo`03o`1Oo`03o`3oGOoo003o000000?o00001Ooo00000ooo
01So0000o`00000Ho`000003o`3oo_l0003o000000So00001_l0ooh3oolX00Co000000Gooj<0o`00
0?l0003o0000o`2ao`03o`000003o`2Nool0003o000000;om_l00onDo`02oago0003oolF0?oo0<So
o`3800Ko0?mM00Goo`3KobKo0?lVo`3oohH0oomD0002o`0]o`04o`2MoolTo`3o0000o`0000;oo`2/
0ooo00002?oo00coo`00ool00?oo003oon`0o`2`ool0003oogT00ol000000om4o`3oo`00om[o0002
odCo00;o0?mI0_m4o`001OooN@3oA?l0odCo0?oo07?o0?on00;ooe<000?ol`3oool0l?oo0?000_l0
on02o`2`o`06o`000?l0oi7oo`2hool0^?ooS03ohol00_ooD@000ol0Eooo0000o`0?o`02oolN000<
o`000?oo903oobP0o`000?l0oaSo0000ool0T?oio`3o0?Soo`3o[Oooh`3oiOl00ol0ojd00ooo:03o
o`11o`000002o`3ok`;oEOl00_l00002oooR00Oo00000_oo0?82o`0000;oK`3o0_oo^P02o`3oH003
o`000?oo06Ooo`1W00?o00000_oo0:l@o`0000;o0?l94?l00018oookJQ;o000000?o0?l9o`000?l0
00003ol00002ool0[`?o000000Soo`1Wo`000?l0003o0?mPo`2goooo^P3o0000ofl0o`?o000000?o
o`3bool0QOl000001_l00002oooR00;o000000OoEOl0o`2fool0onoo0?o_o`000?oo047o04;o00?o
00000_ooh`001_oEo`3o0?Soool0T?oo093o0000o`3o60;oob@00_l00002oolN0003oeD0ool0003o
05Oo00;ooe4000Kohol0oon<0?oo0;Soo`2ho`3oTOl00002o`3oD`03o`000?l0on3oo`3`00;ol`3o
00Gooe<0o`000?l0003oo`1cooo50002o`0go`08ool0cOl0003o0?mIo`3o9Ol0T_oo0000om[o0?oo
03h4o`000006ooo^0?l0003oon`0ooo/0?oo7P3oRol00_oo00`3o`0000;oo`2/0_l000000ol0WOoo
ocP0o`0]o`02oomD0004oon60?lVo`3o9_l0ool0f`;o00000_oa0?l2o`18o`03ool0b?oo5P3o0?l[
00;o7Ol00_l0of`01?l0003om_l0o`000?l00002o`2No`?o000000?o0;7oo`000?l000000_ooX`08
o`0000;oa_l000?o0<cookh0oonn0?l02Ol00002ool061_o000000?oo`0Ho`000?l000001ol00002
okh0o`03o`3<ooo6o`3oa_l000So00000_ooX`02o`0000;o0;7o0_l00002o`2No`;o00000_ofo`02
o`3oK0;o7Ol000Oo0000oolF0?oo0<Soo`38o`18ool0003ol@3o00?o00000_lVo`001_ooQP3ooe@0
oomD0?l0;OooocP0o`2Mo`?o000000Coo`2/o`000?l0003o00000_oo00`01Ooo0@3ooah0ooo/0?oo
k03o000000;oonh00ol00002ool0?P05o`000?l0T_oo0?lUo`3oFOl000000_oo0<d01_l0=oooolD0
ool0Looo07?o0000oomC00;ol`3o00?oo`3`o`3oh?l0on000_l0oe<03Ol0003o0?nAo`3oTOoo0;So
oh`0oomX0?oSo`3ooe40o`1Gool0ocKoE@3oo`000?oo7P000_l00002oolT00;o0?lH0_oo09001Ooi
o`3oeOl0oooS0?ooh`3oog@000;o00000_l0@_l01Ol0003o0?o_o`3okol0]_ooEOl000;o00000ooo
hP06o`000003ool0QOoo0?;o000000;o000000GoK`3oo`000?oo^P3o0;Ooo`3oH002o`000004ool0
Iol0003o0000o`0000;oo`2_4Ol00002o`3o2A3o00008ooonfX002Sooo]Z4_l000000ol0o`Wo0000
o`00000?o`000004ool0[ol0003o0000o`0000;oo`1W00?o0000o`3oH?l0of000_oo^P02ofl0o`;o
00000_oo0?800ooo08Go0000o`000005o`00000:oooR0?l0003o0000o`000?mEo`3o0;Koo`3okol0
003oo`11o`12o`Co0;3o00?oA?l0oomi0?ooN@000_ooN@000ol0003o0?lHo`3o6002oolT000:o`00
0?oo7P3ooah0o`000?mE0?oo0?lfo`1GooooD@3oo`00on?o00;oo`2h00?oT?l0o`0?ool03ol00_l0
3ol2o`3oh005ool0l?oc0?oo0?mMoomC0?l0Gol00_oo07<01?oUo`3o03OoonGo0?l00002o`3oF@05
onGo0?l0oegof_l0ool0?_l0oed00ol00002ooo^00;o00oo00Koon`0oolN0?oo0@3oo`0<o`14ool0
0004ool00003o`000?lTo`3o09go00;o02go00Kooe@0oon60?l0003o9_l0ool0fom4o`05o`3ooP;o
o`3800?ooaH0o`3o3?lMo`000ol0o``2ooKo0004o`000?oo003o09koo`2No`Goo`0000?o0000oonS
0?l000000_l00004ooo90003ool00?l0Gooo05oo00?o05oo00?o0?mMool00?l000001?l00003ool0
0003o`1Oool0003o000001Wo000000?oo`0Ho`000?l000002?l00006o`3ooPCoobP00ol000000ooo
X`3o0000o`000002o`2ao`?o000000?o09koo`000?l000000_ofo`001_l0ojgoU?l0oomi0?lMo`3o
ogT0oolF00;oo`381_l0oed01Ooo0=_o9_l0oon60?ooQP3ooe@000;o02go00Co09goobCo0?l0003o
00000_oo0:`3ool00008ool03?oo003oo`00oolN0?ook03o0;3oo`000?ooN@03o`000005odCo0?oo
003of_l0odCo0?l0ooh00_l0oeT2odCo0005oomi0?m4o`3oo`1cool0Lol0ooh00_ooD`001Ooc0?oo
o`3`o`3oh?l0on3o000000;o0;3o00Koo`03o`3oTOoo0;Soo`2hoon<0?oSo`02oomA0004o`1Gool0
003o00oooolN00;o000000_oobP0oolT0?l0003o0?lHo`000?oo093onOl0o`3hool0ojgoon<0onGo
0002o`3o[@04o`000?oo:03o0000o`0000;o0?o_0_mEo`02o`000003oooR0?l0003o000000Ko0000
0_oo0?82o`0000;oK`3o0_oo^P02o`3oH003o`000?oo06Ooo`1W00?o000000?oo`2_o`000?l00000
3ol00002o`3o2A3o0000B?oonfXBo`000003o`3o2Ol0003o000000oo00000_oo0:l2o`0000;oo`1W
0_l000001Ol0of3ookX0oonj0?l0003oK`3o00?o000000?oo`3bool0QOl000001_l00002oooR00;o
000000OoEOl0o`2fool0onoo0?o_o`000?oo047o04;o00?o00000_ooh`001_oEo`3o0?Soool0T?oo
093o0000o`3o60;oob@00_l00002oolN0004oeD0ool0ocKo05OooomA00;ohol000Gooh`0ool0^?n@
o`3o0?nAo`000002o`3oD`;o0?oP00Coo`3`oo<0oooc0?oooe<00_l000001Ooo07?oolD0o`0gool0
=ooo000000;o0?mI00Go0?lUo`2Bool0003of_l0ool0?P04o`000006ooo^0?l0003oon`0ooo/0?oo
7P3oo`400_oo00`3o`000007ool0[?l0003o0000o`000?l0WOooocP0o`0]o`02oomD0004oon60?lV
o`3oo`3Kool0f`;o000000?ol@3oo`000?l0B?l00_oo0<P01?oo5P3o0000oago0?lMo`02o`3oK0;o
m_l00_l00002o`2No`;o00000_l0/Ol2o`0000;ooj<02?l00002olKo0003o`3<oonn0?oo_P3o00Wo
00000_oo01PJo`0000;oo`0H2Ol00002okh0o`03o`3<ooo6o`3oa_l000So00000_ooX`02o`0000;o
0;7o0_l00002o`2No`;o000000Com_l0o`000?l0ofco0?m/0_lMo`02oolF0003ool0b?l0B?oo04So
00;ol@3o0ol00002obKo0006oon60?ooE03ooe@0o`0]oooo>03o09go0ol000001?oo0:co0000o`00
0?l00002ool03005ool10?oo7P3oon`0ooo/0?l000000_ookP03o`0000;oo`0n00Ko0000o`2Booo0
0?oo0?mIo`000?oo0<d2o`0go`05ooo50?oo07?oo`1co`000?ooD`000_oc0?l00ooo0?3o0?oPolX0
o`02o`3oD`0;o`000?l0oi7o0?nAool0^?ooS03oofP0on?o0?ooD@3o05Ooo`3o=_mE0?l00_oo7P02
o`0000;oob@00_l0oaP2ool0T005ooWo0?oEo`3oon<0oooS0?ooM0000_l00002o`12o`03o`000?l0
onoo0?o_00;oEOl00_l00002oooR00Oo000000?oo`25ool0l_l000000_l000001_m_0?oookX0oonj
0?l0]ooo0?mPo`0000;oo`1W0ol00002ool0[a7o00000_l0o`T@o`0002?ooo]Z000XoookJQ;o0000
00?o0?l9o`000?l000003ol000001?oo0:oo0000o`000?l00002ool0I`03o`000?l0of3o0?mP00;o
okX00_m_0?l2o`0000;oo`3b00?oo`25o`000?l000001Ol000002OoohP3o0000o`000?l0003oEOl0
o`2fool0onoo0000ool0@@05o`2`o`08odCo0?l0/?oo0;3oo`2`oooo093o0000o`3o6?l00002oolT
0003o`000?oo7P3ooah000;oE@3o00Go0?lfo`1GooooD@3oo`00on?o0002ool0^003o`1Oool03ooo
00oo00;o00oo00Oo0?oPool0l?oc0?ool`3oo`3oGOooD`3oiOl000;oo`1c00[oiOl0o`0goooUo`3o
0000o`3oFOo00?ooiOl0o`3oGOoJo`3oo`0n1?l00002ooo^00;o00oo00Coon`0o`0?oooo0@3oo`0<
0_l00004ool00003o`000?lTo`3o09go00;o02go00Gooe@0oon60?lVo`3o9_l0ool0f`05odCo0006
o`3oo_oo0<SooaH0oolF0?l0o`co7Ol00ol0o``01?ofo`3o0?l<o`000?l00002o`2No`Goo`0000?o
0000oonS0?l000001?l000000ooob@3oo`00o`1Oo`05o`1Oo`;oo`001_l000000ooo003o0000o`1O
o`0Ko`000003ool06?l0003o000000So00001Ol0ooh3oiCo00;oobP00_l00002oonS00;o00000_l0
/Ol2o`0000;o09ko0_l00002ooKo00;o0?n]00CoogT0oago0?ooN@3oogT00_oo0<P2o`1Oo`Co0?mM
00Goo`3KobKo0?ooQP3oohH0oomD0002o`0]o`06o`2MoolTo`3o0000o`000?oo0:co00000ooo0000
0ooo00coo`00ool00002ooo/0003oomi0?l0003oogT000?o000000GoA?l0ool0?_oJo`3oA?l0o`3o
oP02o`3oF@?oogT000CoA?l0ool0Lol0ooko0?on0_ooD`001Ooc0?ooo`3`o`3oh?l0on3o000000;o
0;3o00Koo`03o`3oTOoo0;SoT?l0oomX0?oSo`02oomA0004o`1GoomE0?ooE@3ooolN00;o000000_o
obP0oolT0?l0003o0?lHo`000?oo093onOl0o`3hool0ojgoon<0onGo0002o`3o[@03o`12oooo:03o
000000?o0?o_0_mEo`02o`000003oooR0?l0003o000000Go000000?oo`25ool0l_oo0?800_l00002
ofl0o`;ookX00_l0of000ol0003oo`1Wool0I`03o`000003ool0[ol0003o000000oo000000?o0?l9
o`000?l000003ol00018oookJQ;o000000?o0?l9o`000?l000003ol00002ool0[`;o00000_oo06L2
o`000003o`3oH?oo^P3ookX000;oK`3o0_l00002ool0lP03ool0QOl0003o000000Go000000Koon80
o`000?l0003o0000oeGo0?l0]_l2o`3ok`03o`000?oo047o04;o00;o000000Goog@0oooS0?ooh`3o
eOl0ooWo0002ool0T0;o0?lH0_oo9002o`000006oolN0?mE0?ooE@3oo`3o=_l0Eooooe400_oSo`00
0oooS03oo`2ho`3oT@02o`000008o`3oDol0003o0?oPo`3oh?oo0?3ol`3oool0eoooD`02o`000005
ool0Loooa@3o03Ooool0cOl000000_l0oeT00ol0obGo09;oo`000002ool0?PCo000000Koonh0o`00
0?ook03oon`0oolN0?oo0@02ool030?o000000Ooo`2/o`000?l0003o0000o`2Moooo>03o02go00;o
oe@000CoohH0obKo0?oo0=_oo`3K0_l000000ooa0?oo0000o`18o`02ool0b004oolF0?l0003o7Ol0
o`0000;o0?m/0_ofo`02o`0000;o09ko0_l00002o`2ao`;o00000_ooX`08o`0000;oa_l000?o0<co
okh0oonn0?l02Ol000000ooo01So0000o`00000Io`0000;oo`0H2Ol000000onn0?oo0<coo`3<o`02
olKo00So00000_ooX`02o`000004o`2aool0003o0000o`0000;o09ko0_l000001?ofo`3o0000o`3o
K?l00002oago00;ooaH000?oo`38o`18ool0B?l00_oa0?l2o`000007ool0folVo`3o9_l0oon60?oo
E03o0000o`0]o`02o`2Mo`;o00000_oo0:`3o`0000;oo`0<00Goo`40oolN0?ook03o0?l/o`000002
ooo^00?o00000_oo03h01_l0003o09;ool00ool0oeWo0000ool0c@;o03Oo0_oo07<00ol0003ooe<0
oomC0002oo<0o`03ool0l?l0on3obP3o00;o0?mC00Go0000o`3oTOoo0;Soo`2hoomX0002on?o0004
oomA0?l0EoooE@3ooeD0o`;ooah00_l000001?oo903o0000o`3o6?l0oaP2ool0T006ooWo0?oEo`3o
on<0oooS0?ooM03o00000ol0@_l00ol0003o0?o_o`3ok`02oeGo00;o00000_oohP07o`000004ool0
QOoo0?;o0000o`0000;oK`3o0_oo^P02o`3oH003o`000?oo06Ooo`1W00?o000000?oo`2_o`000?l0
00004?l000000ol0o`Wo0000o`00000?o`0002?ooo]Z000XoookJQ7o00000_l0o`T@o`0000;oo`2_
0ol00002ool0I`03o`000?l0of3o0?mP00;ookX00_m_0?l2o`0000;oo`3b1ol00002oooR00?o0000
00GoEOl0o`2fool0onoo0000ool0@@02o`12o`04o`000?l0o`coA?l0oomi00?o0;3o00Coo`2@o`3o
6?l0oaSo00000_oo90000ol0003ooah0oolN0002oeD0o`05o`1GooooD@3ooe40ool00?ooJ0000_oo
0;P00ol0Gooo00ooo`0?o`02o`0?o`04o`3oh?l03oool`3ooo<0o`;ooe<000?oiOl0ool0Looo07<0
0_l0=ol01_oUo`3o0000o`3oFOo00?oo0?mMonGo00;oo`0n1?l000002?ookP3o00ooo`0?ool03ooo
on`0o`0?oooo003oo`0<0_l00004ool00004o`000?l0WOoo09goo`0]o`;ooe@000CoohH0obKo0?lV
o`3oo`3K1_m4o`001Ol0GooooaH0oolF0?oob@3o7Ol000?o0?l<00Gom_l0o`3o3?l0003o0000o`2N
o`03o`0000?oo`0000?o0000oonS0?l000001_l00006o`1Oo`03ool00?l0003o000000Oo000000?o
05ooo`000?l000006?l00002ool060Wo00001_l0ooh2o`3o[@;oU?l00ol00002oonS00;o00000_l0
/Ol2o`0000;o09ko0_l00002ooKo00;o0?n]00CoogT0oago0?ooN@3oogT00_oo0<P2oomi00?o05oo
00?o0?mMool0folVo`000_ooQP001?ooE03o02gooolh0?l0WOl3o`000004ool0[?l0003oo`00ool0
00;oo`0<0_oo0002ooo/00CoogT00_l00002ool0?P03om[o0?m4o`3o0?on00;o0?mI0_ooN@000om4
o`3oogT0ool0L`02oomi0004oomC0?l0ookol`3oool0l0;o0?oP00Oo0000o`2`oooo01_oo`03o`3o
TOoo0;SoT?l000;ohol00_ooD@001?l0ocKoE@3ooeD0oooo7P02o`00000;oolX0?l0003o0000o`3o
6?l0003oo`2@ooWo0?l0n?oo0?n]onGo0?l0oed00_l0ojd00ooo:03o04;oo`000002o`3ok`03o`2f
oomEo`3oEOl000;o000000?oon80o`000?l000001Ol000000ooo08Goo`3bool0lP02o`0000;oK`3o
00KookX0o`2gool0of3o0?mPo`000?oo06L4o`000003ool0[ol0003o000000oo000000?o0?l9o`00
0?l000003ol00018oookJQ7o00000_l0o`TAo`000004ool0[ol0003o0000o`0000;oo`1W00?o0000
o`3oH?l0of000_oo^P02ofl0o`;o00000_oo0?800ooo08Go0000o`000005o`000006oooR0?l0003o
0000o`000?mEo`3o0;Ko0_l0onl00ol0003oo`11o`12o`02o`0000;oon<000Go0000omGo0?oio`3o
o`2@o`000002o`3o60;oob@00_l000001?oo7P3oE@3ooeD0ool0ocH2oomA00;ohol000?ooh`0ool0
^?l0oi400_l000002?l0oe?o0000o`3oh?l0on3oo`3`oo<0oooo0=Oooe<00_l000001Ooo07?oolD0
o`0goooo0<go000000;o0?mI00?o0?lUo`2Bool000000_oo03h3o`0000;oonh000Go:03oooo/0?oo
k03ooah0ool10002ool030?o000000Soo`2/o`000?l0003o9?l0o`2Moooo>03o02gooomD00;oohH0
00?o9_l0ool0fooo0=/00_l000000ooa0?oo0000o`18o`02ool0b004oolF0?l0003o7Ol0o`0000;o
0?m/0_ofo`02o`000004o`2Nool0003o0000o`0000;o0;7o0_l000000oooX`3o0000o`000007o`00
0004olKo0?l0003o0<cookh0o`[o000000?oo`0Ho`000?l000006Ol000000ooo01So0000o`000008
o`000003okh0ool0c?oo0<co00;oa_l02?l000001OooX`3o0000o`000?l0003o0;7o00?o000000So
09koo`000?l0003o0000ooKo0?l0003o0?m/o`0000;o7Ol00_oo5P000ooo0<So04Soo`18o`02oo40
o`;o000000Goo`3KobKo0?lVo`3oohH0oomD0002o`0]o`04o`2MoolTo`3o0000o`0000;oo`2/0ol0
00002?oo00co04Coool10?oo7P3oon`0obP0ool0003oonh01?l00002ool0?P;o09;o00Co`03oo`3o
FOl0003oo`3=0_l0=ol2ool0L`03o`000?ooD`3ooe<000;ol`3o00?oo`3`o`3oh?o:0?l00_l0oe<0
2Ol0003o0?nAool0^?oo0;SoofP0on?o0?l0003ooe40o`3o=P02oeD0o`;ooah000Co0000oolT0?oo
903o00000_l0oaP2ool0T006ooWo0?l0003oon<0oooS0?ooM03o00000_l0@_l01?oo047o0000o`3o
kooo08H2oeGo00;o00000_oohP07o`0000;oo`3b0_l00002ofl0o`;ookX00_l0of000ol0003oo`1W
ool0I`03o`000003ool0[ol0003o000000oo00000_l0o`TAo`0002?ooo]Z000ZoookJP03o`000?oo
nf[ooo]Z00cooo]Z0_l0o`T@oookJP;oo`2_0ooonfX2ool0I`03oookJ_l0of3o0?mP00;ookX00_m_
0?l2oookJP;oo`3b1ooonfX2oooR00;ooo]Z0_mEo`001?l0]_oo0?o_oookJ_oo0442o`12o`;o0?l<
00CoA?l0o`3o3?oEo`3onOl00_oo0902o`3o6004oookJ_oo903oob@0oookJP;ooah00_mE0?l01Ol0
Eooooe40ool00?oSo`3oofP000;oo`2h0_l0Gol3o`0?o`04o`3oh?l03oool`3ooo<0o`;ooe<000?o
iOl0ool0Looo07<00_l0=ol2onGo0004o`3oFOo00?oo0?mMonGo00;oo`0n1?oonfX00oookP3o00oo
o`0?o`03o`0?o`;oo`0<00?ooo]Zool00?oo00001?oo0002o`2Mo`04o`0]ooooE03ooe@0oon600;o
9_l000?oo`3KodCo0?m4o`001?m4o`001Ol0GooooaH0oolF0?oob@3o7Ol000?oolT000Gom_l0o`3o
3?oonf[ooo]Zo`2No`03oookJP05o`2aoooonf[oo`00oookJ_ooX`001_oonfX7o`1Oo`03ool00?oo
nf[ooo]Z00Kooo]Z0ol0Gol:oookJPCo00002ooonfX2ool060Wooo]Z1Ol0ooh4o`3o[@04oiCo0?oo
nf[ooo]ZoookJP;ooj<00_oonfX2o`2ao`;ooo]Z0_l0W_l2oookJP06ooKo0?l03ooo0?n]o`3o[Ooo
N@3o7Ol00_ooN@02ool0b0;oogT01?l0Gol02?oo0=_o9_l0oon60?l01ooooe@0o`0]oooo>03o09go
0ooonfX01?oo0:cooo]ZoookJ_oo0002ool03004ool00?oo7P3oon`0ooo/00KoogT00_oo03h00om4
o`3o0?onodCo0002o`3oF@;oogT000?oA?l0oomi0?oo07<00_ooN@001?ooD`3ol`3ooo<0oooo0?02
o`3oh008oookJ_l0oe?ooo]Zool00ol0oi7oo`2hoon<0?oSo`03oomA0004o`3o=_mE0?oooo]ZoolN
00;ooo]Z00GoobP0oookJ_l0oaSo0?lHool0T004o`0?o`07onGo0?l0oego0?n]o`000?oo:03oo`11
oookJP02o`3ok`03o`2foomEo`3ooo]Z00;ooo]Z00?oon80oookJ_oonfX01OoonfX00ooo08Goo`3b
ool0lP02oookJP;oK`3o00KookX0o`3oH?l0of3o0?mPoookJ_oo06L3oookJP;oo`2_4OoonfX00ol0
o`Wooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX03?oonfX2o`3o
2A7ooo]Z00Coo`2_oookJ_oonf[ooo]Z0_oo06L00ooonf[o0?mPo`3oH002oonj00;oK`3o0_oonfX2
ool0lP03ool0QOoonf[ooo]Z00Gooo]Z00?oon80oookJ_oonfX00_mEo`002?l0]_oo0?o_o`3okooo
nf[oo`11o`12oooonf[o00000_ooh`001ooonf[o0?SoooWo0?oo093ooo]Zo`3o6?oonfX00_oo9002
oookJP04oolN0?mE0?ooE@3oo`3o=P;ooe4000Wohol0oomX0?n@o`3oo`2ho`3oTOoonf[oo`0Ko`3o
DooonfX00_l0on001?oo0?3ol`3ooomC0?ooD`02oookJP05ool0Loooa@3o03Ooool0cOoonfX00_l0
oeT2o`2Bo`03om[o0?oo03koo`0n00?ooo]Z0_ookP001OlX0?ooon`0ooo/0?oo7P3oo`4000;oo`0<
0_oonfX2ool0[0;ooo]Z00Go9?l0o`2Mool0;Ooo02gooomD0002oon60003obKo0?oo0=_ooo]Z00;o
oo]Z00?ol@3ooookJ_l0B?l00_oo0<P01_oo5P3ooo]Zoago0?oonf[o0?m/oookJP;om_l00_oonfX0
1Ol0W_oooo]ZoookJ_oonf[o0;7o00?ooo]Z00?ooj<0oookJ_oonfX01ooonfX01?o6o`3ooo]Zo`3<
oonn0?l:oookJP03ool06?oonf[ooo]Z00Wooo]Z1?l0000;oookJP;oo`0H2_oonfX01?nn0?oo0<co
o`3<ooo6o`08oookJP;ooj<00ooonfX01Ol0/Ooooo]ZoookJ_oonf[o09ko00;ooo]Z0_ofo`001Ooo
nf[o0?m/oookJ_lMo`3ooo]Z00;ooaH000?oo`38o`18oooonfX00_oa0?l2oookJP05ool0folVo`3o
9_l0oon60?ooE0000_l0;Ol01?l0WOoo9?l0oookJ_oonfX2ool0[0?ooo]Z00Koo`0<ool10?oo0@3o
oah0ooo/0?oonfX2ooo^00Cooo]Z00Coo`0noookJ_l0T_oo0?lU0_l0oeT01?oonf[oo`3=o`0gool0
=ol2ool0L`03oookJ_ooD`3oo`3G00;ol`3o00?oo`3`o`3oh?oonfX00_l0oe<01_oonf[o0?nAool0
^?oo0;SoofP0on?o00;ooe4000?o0?lfoeD0oooonfX00_oo7P001?oonf[oob@0oolT0?oonfX2o`3o
60;oo`2@00KoeOl0ool0DOooh`3oon<0oookJ_l00002o`12o`05ool0@Ooonf[o0?o_o`2foomEo`00
0ooonfX2oooR00Kooo]Z00?oo`25ool0l_oo0?800_oonfX2ofl0o`;ookX00_l0of000ooonf[oo`1W
ool0I`02oookJP;oo`2_4OoonfX2o`3o2@oooo]Z00?o0000oookJ_oonfX08_oonfX003Wooo]Z0_l0
o`T@oookJP;oo`2_0ooonfX2ool0I`03oookJ_l0of3o0?mP00;ookX000KoK`3ooookJ_oonf[oon@0
ool0l_oo08D7oookJP;oon800_oonfX2oeGo00;o0?o_00Cooo]Zool0@Ol0@_oo04;o0_l0o``01?oo
N@3o0?l<o`3o3?oio`02ool0T0;o0?lH00Cooo]ZoolT0?oo903ooo]Z0_oo7P001omE0?oo0?lfo`1G
ooooD@3oo`00on?o0?ooS0000_oo0;P2o`1Oo`?o00oo00Co0?oPo`0?oooc0?ool`3o0_ooD`000ol0
oegoo`1co`3oG@02o`0go`;oiOl000Co0?mIol00ool0oegoiOl00_oo03h01OoUo`3ooo]ZoookJ_oo
nf[oonh000Go00oo0_oo00`00ooonf[oo`00ool00004ool00003o`2Moooo>03o02go00;ooe@000Co
ohH0obKo0?lVo`3oo`3K1_m4o`000ol0GooooaH0o`3o:`02oago00?oolT000Gom_l0ooo90?oonf[o
oo]Zo`2No`03oookJP05o`2aoooonf[ooo]ZoookJ_ooX`001OoonfX8o`1Oo`03ool00?oonf[ooo]Z
00Kooo]Z0ol0Gol:oookJPCo00002ooonfX00ooo01Sooo]ZoookJP08oookJPCo0?on0_l03ol4o`3o
[@?ooo]Z00Gooj<0oookJ_oonf[ooo]Zo`2ao`03oookJP05o`2Noooonf[ooo]ZoookJ_ofo`000ol0
3ol2oago00;oogT000?oo`38oomi0?ooN@001Ol0Gol2obKo0006oon60?l01ooooe@0o`0]oooo>03o
09go0ooonfX01?oo0:cooo]ZoookJ_oo0002ool03004ool00?oo7P3oon`0ooo/00KoogT000?oo`0n
om[o0?l0ooh00_l0ooh2o`3oF@;oogT000CoA?l0oomi0?oo07?oogT00_ooD`02oo<0o`03ool0l?l0
on3o0?oP00;o0?mC00Kooo]Zo`3oTOl0oi7oo`2hoon<0?oSo`03oomA0004o`3o=_mE0?oooo]ZoolN
00;ooo]Z00GoobP0oookJ_l0oaSooo]Zool0T004o`0?o`03onGo0?l0oego00oo00;o00oo00Koo`11
oookJ_l0onoo0?o_o`2foomEo`03oookJP03oooR0?oonf[ooo]Z00Gooo]Z00?oo`25ool0l_oo0?80
0_oonfX2ofl0o`04oonj0?l0of3o0?mPo`3oH0;oo`1W0ooonfX2ool0[a7ooo]Z00?o0?l9oookJ_oo
nfX0J?oonfX2o`3o2A7ooo]Z00Coo`2_oookJ_oonf[ooo]Z0_oo06L00ooonf[o0?mPo`3oH002oonj
00;oK`3o0_oonfX2ool0lPSooo]Z00?oon80oookJ_oonfX00_mEo`001?oo08Ko0?o_oookJ_oonfX2
o`12o`;ooo]Z0_ooh`001ooonf[o0?SoooWo0?oo093ooo]Zo`3o6?oonfX00_oo9002oookJP04oolN
0?mE0?ooE@3oo`1Go`;ooe4000Wohol0oon<0?n@o`3oo`2ho`3oTOoonf[oo`0Ko`3oDooonfX00_l0
on001Ooo0?3ol`3ooomC0?ooD`3ooo]Z00;oo`1c00CoolD0o`0goooo0<gooo]Z0_l0oeT2o`2Bo`03
om[o0?oo03koo`0n00?ooo]Z0_ookP001olX0?ooon`0oolN0?oo7P3oo`40ool03?l0A?l00_oonfX2
ool0[0;ooo]Z00Ko9?l0o`2Mool0;Ooo02gooomD0?ooQP02obKo0003ool0fooonf[ooo]Z00;ol@3o
00[ooo]Zo`18oooo0<Soo`38oolF0?oonf[o7Ol0oookJ_l0ofcooo]Z0_ofo`02oookJP05o`2Noooo
nf[ooo]ZoookJ_l0/Ol00ooonfX00oooX`3ooo]ZoookJP07oookJP04olKo0?oonf[o0<cookh0o`[o
oo]Z0_oo01P:oookJPCo00002ooonfX2ool060Wooo]Z0_nn0?l00ol0c?oooo]ZolKo0008oookJP;o
oj<00_oonfX2o`2ao`?ooo]Z00?o09kooookJ_oonfX00_ofo`001_oonf[o0?m/oookJ_lMo`3ooo]Z
oolF00;oo`3800?o04SooookJ_oa0?l00ooonfX01Ooo0=_o9_l0oon60?ooQP3ooe@000;o02go00Co
09goobCo0?oonf[ooo]Z0_oo0:`3oookJP03ool03?oo0@3ooah000;oon`000?ooo]Zooo^0?ookP00
0ooonfX2ool0?P03oookJ_l0T_oo0?lU00;o0?mI00Cooo]Zool0cOl0=ooo03Oo0_oo07<00ooonf[o
oe<0ool0e`02oo<0o`03ool0l?l0on3o0?mC00;o0?mC00Kooo]Zo`3oTOoo0;Soo`2hoomX0?oSo`02
oomA0003o`3o=_mE0?oooo]Z00;ooah000Kooo]ZoolT0?oo903ooo]Zo`3o6?oonfX2ool0T004omGo
0?oo057oon<0oooS00;ooo]Z0_l0@_l2oookJP03o`3okol0]_ooEOl000?ooo]Z00?oon80oookJ_oo
nfX01OoonfX00ooo08Goo`3bool0lP02oookJP;oK`3o0_oo^P02o`3oH003oookJ_oo06Ooo`1W00;o
oo]Z0_oo0:lAoookJP;o0?l9=?oonfX003Wooo]Z0_l0o`T@oookJP;oo`2_0ooonfX2ool0I`03oook
J_l0of3o0;Oo00;ookX000KoK`3ooookJ_oonf[oon@0ool0l_oo08D7oookJP;oon800_oonfX01Ol0
3ooo0;Koo`3okol0onoooo]Z00;o04;o00Cooo]Zo`3o3?l0o`coogT00_l0o``00ooio`3oo`2@ool0
T002o`3o6004oookJ_oo903ooo]ZoookJP;ooah000Wo0;3oo`3o=_l0Eooooe40ool00?oSo`3ooh`0
ool0^?n@o`000_l0Gol3o`0?o`04o`3oh?l03oool`3ooo<0o`;ooe<000?o0?mMool0LooUo`000_l0
=ol2onGo0004o`3oFOo00?ooiOl0onGo00;oo`0n00GoiOl0oookJ_oonf[ooo]Zooo^0004o`0?o`04
ool00?oo00coo`0<oookJPKoo`0000?o09gooolh0?l0;Ol00_ooE0001?ooQP3o9_l0ool0fooo0=/3
oomi00;oA?l00ol0Gol00ol0ob_o7Ol0oago0003ooo90005ooKo0?oob@3ooo]ZoookJ_l0W_l00ooo
nfX01Ol0/Ooooo]ZoookJ_oonf[ooj<000Kooo]Z0_l0oed5o`1Oo`Wooo]Z0ol0Gol:oookJPCo0000
2_oonfX2ool060[ooo]Z1?l0ooh3o`0?o`;o0?n]1?oonfX01OooX`3ooo]ZoookJ_oonf[o0;7o00?o
oo]Z00Go09kooookJ_oonf[ooo]ZooKo0003o`0?o`;o7Ol00_m4o`000ooo0<SoogT0oomi0004o`1O
o`05ool0folVo`3o9_l0oomi0?ooE0000_l0;Ol2o`2Mo`;ooo]Z0_oo0:`2oookJP05ool00?oo00co
o`0<ool00?oo7P000_ook0000oooN@3oA?l0oomi0002oomi0003o`3oo_oo03kof_l000?o0?on00Go
0?mIoomi0?ooN@3oA?l0oomi0002ool0L`04oomi0?ooD`3ooe<0oo<0o`;oo`3`0_l0on02o`3oD`06
oookJ_l0oi7oT?l0ool0^?ooS03ohol00_ooD@003?l0Eooooo]ZoeD0oooonf[ooah0oookJ_oo:03o
U?l0oookJ_l0oaSooo]Zool0T0CoiOl000?o0?mMo`0?ool03ol00_l03ol01_oo047ooo]Zo`3okol0
onoo0;KooeGo00;ooo]Z0_oohP07oookJP03ool0QOoo0?;oo`3b00;ooo]Z00?oK`3ooonj0?oo^P00
0ol0of02ool0I`?ooo]Z00?oo`2_oookJ_oonfX03ooonfX2o`3o2F[ooo]Z0_l0o`TAoookJP04ool0
[ooonf[ooo]ZoookJP;oo`1W00?ooo]Zo`3oH?l0of000_oo^P02ofl0o`;ooo]Z0_oo0?88oookJP05
oooR0?oonf[ooo]ZoeGo0?l0]_l00_l0onl2oookJP;o04;o0_oonfX2oooS0007omGo0?l0n?oonOl0
ool0T?oonf[o0?lHoookJP02oolT00;ooo]Z00Cooah0oeD0oomE0?oo05Oo0_ooD@002_oSo`3ooh`0
oi3o0?oo0;So0?nAoookJ_oo01_o0?mCoookJ_l0on02ool0l004oo<0ooooD`3ooe<0oookJP;oo`1c
00CoolD0o`0goooo0<gooo]Z0_l0oeT2o`2Bo`03om[o0?oo03koo`0n00?ooo]Z0_ookP001olX0?oo
on`0oolN0?n;o`3oo`40ool03?l0A?l00_oonfX2ool0[0;ooo]Z00Ko9?l0o`2Mool0;Ooo02gooomD
0?ooQP02obKo0003ool0fooonf[ooo]Z00;ol@3o00?ooo]Zo`18oooo0<P00_oo5P001_oonf[o7Ol0
oookJ_l0ofcooo]ZooKo00?ooo]Z00Go09kooookJ_oonf[ooo]Zo`2ao`03oookJP03oonS0?oonf[o
oo]Z00Oooo]Z00Coa_l0oookJ_l0c?oo_P3o2_oonfX2ool060[ooo]Z1?l0000;oookJP03ool06?oo
nf[ooo]Z00Sooo]Z00?o_P3oo`3<ool0c?l00_o6o`08oookJP;ooj<00_oonfX2o`2ao`;ooo]Z0_l0
W_l2oookJP;om_l00_l0of`2oago0007oookJ_oo5P3oo`38ool0b?l0B?oooo]Zoo40o`03oookJP03
ool0folVo`3oohH000;ooe@00_l0;Ol01?l0WOoo9?l0oookJ_oonfX2ool0[0;ooo]Z0_oo00`01Ooo
0@3ooah0ooo/0?ook03ooo]Z00;oonh00ooonfX2ool0?P04oookJ_l0T_oo0?lUo`3oF@;ooo]Z00?o
o`3=o`0gool0=ol00_oo07<01Ooonf[ooe<0oo<0oooc0?ooo`3`00;o0?oP0ol0oe<02ooo00?o0?nA
ool0^?oo0;SoofP0on?o0?ooD@3o05Ooo`3o=_mE0?oooo]Z00;ooah000Kooo]ZoolT0?oo903ooo]Z
o`3o6?oonfX2ool0T004omGo0?oo057oon<0oomd00;ooo]Z0_l0@_l01Ooonf[o0?o_o`3okol0]_oo
EOl000;ooo]Z0_oohP07oookJP03ool0QOoo0?;oo`3b00;ooo]Z0_m_0?l2oonj00;o0?mP00?ooo]Z
ool0Iooo06L00_oonfX2ool0[a7ooo]Z0_l0o`TdoookJP00>OoonfX2o`3o2A3ooo]Z0_oo0:l3oook
JP;oo`1W00?ooo]Zo`3oH?l0]ol00_oo^P001_m_0?oooo]ZoookJ_l03oooo`3bo`0?o`Oooo]Z0_oo
hP02oookJP05o`0?ool0]_oo0?o_o`3okooonfX00_l0@_l3o`3o3004oomi0?l0o`co0?l<ooWo00;o
o`2@0_l0oaP2oolT00;ooo]Z00Kooah0oookJ_l0/?oo0?lfo`1OooooD@02on?o0003oon<0?oo0;So
T?l000;o05oo0_l03ol2o`3oh003o`0?oooc0?ool`3o00;ooe<000Co0?mMool0LooUo`3o03Oo0_oU
o`02o`3oF@03ol00oooUo`3oiOl000;oo`0n00?oiOl0oookJ_oonfX00_ookP04o`0?o`03ool00?oo
00coo`0<00Ooo`0000?o09gooolh0?l0;Ol00_ooE0001?ooQP3o9_l0ool0fooo0=/5oomi00?o05oo
00?ooo]Zoago0?lMo`000_l0of`00ooonf[om_l0ooo90002oookJP05o`2Noooonf[ooo]ZoookJ_l0
/Ol00ooonfX00oooX`3ooo]ZoookJP03oookJPKo0?mM0_l0Gol9oookJP?o05oo00?o0?mMoookJ_oo
nfX01ooonfX4o`0000[ooo]Z0_oo01P9oookJP04okh0ool0ooko0?ono`3ooPGo00oo1OoonfX00ooo
X`3ooo]ZoookJP02o`2ao`?ooo]Z00?o09kooookJ_oonfX00_ofo`03o`0?o`;o7Ol00_m4o`000ooo
0<SoA?l0odCo0004o`1Oo`03ool0folVo`3o9_l000;oogT00_l0;Ol2o`2Mo`;ooo]Z00Koo`2/oook
J_oonf[ooo]Zool00?oo00`2ool000;oon`00_ooN@001om4o`3oogT0oomi0?ooN@3o0?onool0?_oJ
o`000_l0ooh2o`3oF@;oogT000GoA?l0oomi0?oo07?oo`1co`3ooP02oomC0009oo<0oooo0?3oo`3`
o`3oh?oob@3o0?mCool06ooonf[o0?nA00;oo`2h00Oooh`0on?o0?ooD@3ooe40o`1Goooonf[oE@3o
00;ooah000Oooo]ZoolX0?nDo`3ooo]Zo`3o6?oonf[oo`2@00CoiOl000Wo0?mMonGo0?oUo`3oiOl0
oolX0?oo047ooo]Zo`3okooo08H00_mEo`02oookJP;oon801ooonfX00ooo08Goo`3boookJP02oook
JP03ofl0oooo^P3ookX000;o0?mP00?ooo]Zool0Iooo06L00ooonfX00ooo0:oooo]ZoookJP0?oook
JP;o0?l9J_oonfX2o`3o2A7ooo]Z00Coo`2_oookJ_oonf[ooo]Z0_oo06L00ooonf[o0?mPo`3oH002
oonj00;oK`3o0_oonfX2ool0lPSooo]Z00Goon80oookJ_oonf[oEOl0o`2fo`02o`3ok`;ooo]Z00Co
04;ooookJ_oonf[ooo]Z0_ooh`001ooEo`3o0?SoooWo0?oo093ooo]Zo`3o6?oonfX00_oo9002oook
JP04oolN0?mE0?ooE@3oo`1Go`;ooe4000Kohol0oon<0?oo0;Soo`2ho`3oTOoonfX2o`3oD`03oook
J_l0on3oo`3`00;ol`3o0_ooD`000ooonf[oo`1cool0L`02o`0go`04ool0cOoonf[o0?mIol00o`;o
09;o00?of_l0ool0?_oo03h00ooonfX2ooo^0007obP0ooook03ooah0oh_o0?oo0@3oo`0<o`14o`02
oookJP;oo`2/0_oonfX01_lTo`3o09goo`0]ool0;Ooooe@0oon600;o9_l000?oo`3KoookJ_oonfX0
0_oa0?l00ooonf[o04Soool0b002oolF0006oookJ_lMo`3ooo]Zo`3oK?oonf[om_l00ooonfX01Ol0
W_oooo]ZoookJ_oonf[o0;7o00?ooo]Z00?ooj<0oookJ_oonfX01ooonfX00oo6o`3ooo]Zo`3<o`02
okh0o`[ooo]Z00?oo`0HoookJ_oonfX02?oonfX4o`0000[ooo]Z0_oo01P:oookJP03okh0ool0c?oo
0<co00;oa_l02?oonfX01OooX`3ooo]ZoookJ_oonf[o0;7o00?ooo]Z0_l0W_l2oookJP04ooKo0?oo
nf[o0?m/o`3oK0;o7Ol00_oo5P02ool0b003o`18oooonf[ol@3o00?ooo]Z00Goo`3KobKo0?ooQP3o
oe@0oookJP02o`0]o`03o`2MoolTo`3ooo]Z00;oo`2/0ooonfX2ool03005ool10?oo7P3oon`0o`3o
;?oonfX00_ookP03oookJP;oo`0n00Gooo]Zo`2Booo00?oo0?mIoookJP02ool0c@06o`0gooooa@3o
o`1cool0Looonf[ooe<00_oc0?l00ooo0?3o0?oPolX0o`02o`3oD`03oookJ_oo00?o0?nA00;oo`2h
00OoofP0on?o0?ooD@3o05Ooo`3o=_mE0?oooo]Z00;ooah000?ooo]ZoolT0?oo90000_l0oaP01ooo
nf[oo`2@ooWo0?oEo`3oo`1AoooS0?ooM0000_oonfX00ol0@_ooo`11oookJP02o`3ok`;oEOl00_oo
nfX2oooR00Oooo]Z00?oo`25ool0l_ooi0000_oonfX2ofl0o`;ookX000?o0?mPoookJ_oonfX00_oo
06L2oookJP;oo`2_4OoonfX00ol0o`Wooo]ZoookJP0coookJP00>?oonfX2o`3o2A3ooo]Z0ooo0:l3
oookJP;oo`1W00Kooo]Zo`3oH?l0]ooookX0oookJ_m_0?l2oookJP03o`0?oooo0?;o00oo00Kooo]Z
0_oohP03oookJP05o`0?ool0]_oo0?o_o`3okooonfX00_l0@_l3o`3o3006oomi0?l0o`co0?l<ooWo
0?oo093ooo]Z0_l0oaP2oolT00;ooo]Z00Kooah0oookJ_l0/?oo0?lfo`1GooooD@02on?o0003oon<
0?oo0;SoT?l000Co00oo0_l0on000ol03oool`3oo`3oG@02oomC0006o`3oGOoo07?oiOl0o`0goooo
0<gooo]Z0_l0oeT01_o00?ooiOl0onGo0?oo03kof_l0onGo00;ooo]Z0_ookP04o`0?o`03ool00?oo
00coo`0<00Ooo`0000?o09gooolh0?l0;Ol00_ooE0000oooQP3o9_l0ool0f`06oomi00?o05oo00?o
oo]Zoago0?lMo`000_l0of`00ooonf[om_l0oookJP02oookJP05o`2Noooonf[ooo]ZoookJ_l0/Ol0
0ooonfX00oooX`3ooo]ZoookJP04oookJP;oiOl01Ol0oed8oookJPGo05oo2OoonfX4o`0000[ooo]Z
00?oo`0Hooo90?oob@001ooonfX00ooob@3o_P3oo`3ooP02o`3ooPKo00oo0ooonfX2oonS00;ooo]Z
0_l0/Ol2oookJP04o`2Noooo003oo`00oookJP;om_l00ol03ol00olMo`3oA?l0odCo0002ool0b0?o
A?l00ol0Gol00ooo0=_o9_l0obKo0002oomi0003o`0]ooooN@3oogT000;oogT000?ooo]Zool0[?oo
nfX00_oonfX2ool03007ool10?oo003oon`0ooo/0?m4o`3oogT0odCo0002oomi0004oookJ_l0ooko
o`0nom[o00;o0?on0_l0oeT01?m4o`3oogT0odCo0?ooN@02ool0L`05o`3oo_ooD`3ooe<0oo<0oooo
0?000_l0on001Ooob@3o0?mCool06ooonf[o0?nA00;oo`2h00Gooh`0on?o0?ooD@3ooe40o`1Go`02
oeD0o`;ooah00_oo:0001OnDo`3ooo]Zo`3o6?oonf[oo`2@00CoiOl000[o0?mMonGo0?oUo`3oiOl0
o`12oooo047ooo]Zo`3okol0]_ooEOl00ooonfX2oooR00Kooo]Z00?oo`25ool0l_oo0?800_oonfX2
ofl0o`;ookX00_l0of000ooonf[oo`1Wool0I`03oookJP03ool0[ooonf[ooo]Z00oooo]Z00?o0?l9
oookJ_oonfX0J?oonfX3o`3o2A3ooo]Z0_oo0:l3oookJP;oo`1W00Gooo]Zo`3oH?l0of3ookX0oook
JP02ofl0o`;ooo]Z0_oo0?87oookJP;oon800_oonfX01omEo`3o0;Koo`3okol0onoooo]Zool0@Ol0
@_l00ooonfX2oooS0007omGo0?l0n?oonOl0ool0T?oonf[o0?lHoookJP02oolT0003oookJ_oo7P3o
oah000;oE@3o00Go05OooomA0?ooD@3ohol0oon<0002ool0^007o`3oTOoonf[o0?mCo`3oDooonf[o
0?oPool0l002oo<0o`;ooe<000?ooo]Zool0Looo07<00_l0=ol01?oo0<gooo]Zo`3oFOo00?l2o`2B
o`03om[o0?oo03kooo]Z00?ooo]Z0_ookP001_lX0?ooon`0oolN0?n;o`3oo`40ool030?ooo]Z0_oo
0:`2oookJP03obCo0?l0WOoo02go00;ooe@000CoohH0obKo0?lVo`3oo`3K0_oonfX2oo40o`03oook
J_l0B?ooo`3800;ooaH000Kooo]Zoago0?oonf[o0?m/oookJ_ofo`03oookJP05o`2Noooonf[ooo]Z
oookJ_l0/Ol00ooonfX2oonS00Sooo]Z00?oa_l0oookJ_l0c?l00_nn0?l:oookJP03ool06?oonf[o
oo]Z00Sooo]Z1?l0000:oookJP03ool06?oonf[ooo]Z00Wooo]Z00Co_P3oo`3<oooonf[oa_l02Ooo
nfX01OooX`3ooo]ZoookJ_oonf[o0;7o00?ooo]Z00Ko09kooookJ_oonf[ooo]ZooKo0?oonfX2o`3o
K007oago0?oonf[ooaH0oolF0?oo0<So04SooookJP02oo40o`?ooo]Z0_lVo`001_ooQP3ooe@0o`0]
ool0;Ooo09goobCo00;ooo]Z0_oo0:`3oookJP07ool03?l0A?ooo`40oolN0?ook03o:03ooookJP02
ooo^00?ooo]Z0_oo03h01_oonf[o09;ool00ool0oeWooo]Zool0c@;o03Oo00GoolD0ool0Looonf[o
oo]ZoomC0002oo<0o`03ool0l?l0on3obP3o00;o0?mC00Gooo]Zo`3oTOl0oi7oo`2hoon<0002on?o
0006oomA0?l0EoooE@3ooeD0oooonf[ooah00_oonfX2oolT00;o0?lH00Cooo]Zool0T?oio`3oeOl0
0_ooh`002?ooM03ooo]Zo`12ool0@_ooo`11oookJ_l0onooo`260_mEo`02oookJP;oon801ooonfX2
ool0lP;ooo]Z0_m_0?l2oonj00;o0?mP00Cooo]Zool0Iooo06Ooo`1W0_oonfX2ool0[a7ooo]Z00?o
0?l9oookJ_oonfX0<ooonfX003Sooo]Z0_l0o`T@oookJP?oo`2_0ooonfX02?oo06Oooo]ZoookJ_l0
of3o0;Oooonj0?oonf[oK`3o0_oonfX00ol03oooo`3bo`0?o`06oookJP;oon800_oonfX3o`0?o`;o
0?o_00?ooo]Zo`12ool0@_l00ol0o``00oooN@3o0?l<o`3o3002ool0T003oookJ_l0oaSo0?lH00;o
ob@00_oonfX01_oo7P3o0;3oo`2`ool0/?oo05OooomA00;ohol000?ooh`0ool0^?n@o`001?l03ol2
o`3oh003o`0?oooc0?oo0?mM00;ooe<000Kooo]Zool0LooUo`3o03Ooool0cOoonfX2o`3oF@04ol00
oooUo`3of_l0ool0?PCooo]Z0_ookP05o`0?o`;oo`0<1ooo00001?l0WOooocP0o`0]ooooE002oon6
0003obKo0?oo0=_oogT000GoogT00ol0Gol00ooonf[o7Ol0oago0002o`3oK003oookJ_ofo`3ooo]Z
00;ooo]Z00Go09kooookJ_oonf[ooo]Zo`2ao`03oookJP03oonS0?oonf[ooo]Z00?ooo]Z1_oUo`02
o`3oG@03okh0oooonf[ooo]Z00Gooo]Z1Ol0Gol9oookJPCo00002?oonfX00ooo01SoolT0ooo90002
o`3o30Oooo]Z00CoolT0okh0ool0ooko0?on1Ol03ol5oookJP05oonS0?oonf[ooo]ZoookJ_l0/Ol0
0ooonfX00ol0W_ooo`00ool00002ool00005ooKo0?l03ooo00ooo`3oo_lMo`000_m4o`02ool0b0?o
A?l00_l0Gol00ooonf[o9_l0obKo0003oomi0003o`0]ooooN@3oogT000?oogT000Coo`2/oookJ_oo
nf[ooo]Z0_oo00`01?oo0@3ooah0ooo/0?ook004odCo0005oomi0?oonf[oo`0nool0?_oJo`000_l0
ooh2o`3oF@CoA?l000?oo`1co`3oo_l0ooh00_ooD`002Ooc0?ooo`3`o`3oh?l0on3oolT0o`3oDooo
nf[oo`03o`3oT@02ool0^005oon<0?oSo`3ooe40oomA0?l0Eol00_mE0?l2oolN0003oolX0?nDo`3o
obP000;oobP00_oo0904onGo000:o`3oGOoUo`3oiOl0o`0?oonDo`3oo`11oookJ_l0onoo0;KooeGo
00?ooo]Z0_oohP06oookJP03ool0QOoo0?;oo`3b00;ooo]Z0_m_0?l01_oo^P3o0;Ooo`3oH?l0of3o
oo]Zool0I`Cooo]Z00?oo`2_oookJ_oonfX03ooonfX00ol0o`Wooo]ZoookJP1XoookJP;o0?l94Ooo
nfX2ool0[`?ooo]Z00?oo`1WoookJ_oonfX00_l0of000ooo^P3ooo]Zofl0o`03oookJP;oo`3b1ooo
nfX2oooR00;ooo]Z00OoEOl0o`2fool0onoo0?o_oookJ_oo047o04;o00?ooo]Z0_ooh`001ooEo`3o
0?Soool0T?oo093ooo]Zo`3o6?oonfX00_oo90000ooonf[ooah0oolN0002oeD0o`05o`1GooooD@3o
oo]Zon?o0?ooS0000_oo0;P01ol0oi7ooo]Zo`3oDol0oe?obP3oo`3oh?oo0?000_oc0?l2oomC0003
oookJ_oo07?oo`1c00;o03Oo00Soo`3=oookJ_l0oeWo`03oo`2Boooonf[of_l0ool0?PCooo]Z00So
onh0oookJ_lX0?ooon`0oolN0?n;o`3oo`40ool030?ooo]Z00Ooo`2/oookJ_oonf[ooo]ZobCo0?l0
WOoo02go00;ooe@000CoohH0obKo0?lVo`3oo`3K0_oonfX2oo40o`03oookJ_l0B?ooo`3800;ooaH0
00Kooo]Zoago0?oonf[o0?m/oookJ_ofo`03oookJP;o09ko0_oonfX01?l0/Ooooo]ZoookJ_oonfX2
oonS00Sooo]Z0_o6o`02o`3<o`03okh0oooonf[ooo]Z00Sooo]Z0_oo01P9oookJPCo00002OoonfX2
ool060[ooo]Z00?o_P3oo`3<ool0c?l00_o6o`08oookJP04oonS0?oonf[ooo]ZoookJP;o0;7o0ooo
nfX00ol0W_oooo]ZoookJP02ooKo000;oookJ_l0ofcooo]Zoago0?oonf[ooaH0o`3o:ooo0<So04So
oookJ_oa0?l00ooonfX01Ooo0=_o9_l0oon60?ooQP3ooe@000;o02go00Co09goobCo0?oonf[ooo]Z
0_oo0:`3oookJP08ool03?oo0@3oo`40oolN0?ook03o:03ooookJ_ookP04oookJP;oo`0n0_l0T_l2
o`3oF@04oookJ_oo0<go03Ooo`0go`;oo`1c00Sooo]ZoomC0?ooD`3ol`3ooonQ0?oo0?3o0?oPoook
JP;o0?mC00Kooo]Zo`3oTOoo0;Soo`2hoon<0?oSo`02oomA0005o`1GoomE0?ooE@3ooookJ_oo7P00
0_oonfX2oolT0006o`3o6?oonf[oo`2@ool0T?l0n?ooeOl00_ooh`02oookJP;o04;o00Coo`11oook
J_l0onooo`260_mEo`02oookJP;oon801ooonfX2ool0lP;ooo]Z0_m_0?l2oonj00;o0?mP00?ooo]Z
ool0Iooo06L00ooonfX2ool0[a7ooo]Z00?o0?l9oookJ_oonfX0<ooonfX003Sooo]Z0_l0o`T@oook
JP;oo`2_1?oonfX02?oo06Oooo]ZoookJ_l0of3o0;Oooonj0?oonf[oK`3o0_oonfX00ol03oooo`3b
o`0?o`06oookJP04o`2`oooohP3ooo]ZoookJP?o00oo0_l0onl00ooonf[o04;oo`12o`03o`3o3006
oomi0?l0o`co0?l<o`3o3?oo093ooo]Z0_l0oaP2oolT00;ooo]Z00Cooah0o`2`ool0/?oo0;3o0_oo
D@02on?o0003oon<0?oo0;So0?mM00Co00oo0_l0on002ol03oool`3ooomC0?ooD`3oiOl0oookJ_oo
07?oolD0o`0goooo0<gooo]Z00;o0?mI00Co`03oo`2BoooJo`3oo`0n1?oonfX2ooo^00Go00oo00?o
o`0<o`14oooo00001_oo00001?l0WOooocP0o`0]ooooE002oon60003obKo0?oo0=_ooo]Z00;ooo]Z
00?ol@3ooomi0?l0Gol01Ol0Gol01OlMo`3o0?m/o`3oK?oonf[om_l000?ooo]Z00Go09kooookJ_oo
nf[ooo]Zo`2ao`03oookJP03oonS0?oonf[ooo]Z00Kooo]Z1OoUo`000onn0?oooo]ZoookJP05oook
JPGo05oo00?o0?mMoookJ_oonfX01_oonfX4o`0000Oooo]Z00?oolT0o`3o3?l0o``00_l0/?l00ol0
o`cooo]ZoookJP04oookJP04o`3o3?oob@3oolT0o`3ooPGo00oo1_oonfX01OooX`3ooo]ZoookJ_oo
nf[o0;7o00?ooo]Z00?o09koool00?oo00000ooo0002o`0?o`;o7Ol00_l0ooh2ool0b0;oA?l00ol0
Gol00ooo0=_o9_l0obKo0003oomi0003o`0]ooooN@3oogT000?oogT000Coo`2/oookJ_oonf[ooo]Z
0_oo00`01?oo0@3ooah0ooo/0?ook006odCo00;oo`0n0ol0ooh2o`3oF@;oA?l000Ko0?onodCo0?oo
07?oA?l0o`3oo_ooD`02oo<0o`0:ool0l?l0on3o0?oPoookJ_l0oe?ooo]Zool00ol0oi7oo`2hoon<
00;ohol000?ooe40o`1Gool0Eol00_mE0?l01?oo7P3oobP0oolX0?nDo`03oolX00;oo`2@0ooUo`00
1ol0oegoiOl0onGo0?oUo`3oobP0oiCo0?oonfX00_l0onl00ol0]_ooEOl0oookJP02oookJP;oon80
1_oonfX00ooo08Goo`3bool0lP02oookJP;oK`3o00KookX0o`2gool0of3o0?mPoookJ_oo06L4oook
JP03ool0[ooonf[ooo]Z00oooo]Z00?o0?l9oookJ_oonfX0J?oonfX2o`3o2A7ooo]Z0_oo0:l3oook
JP03ool0Iooonf[ooo]Z00;o0?mP00?ookX0oookJ_m_0?l00ooonfX00ooo0?;oo`25oookJP06oook
JP;oon800_oonfX01omEo`3o0;Koo`3okol0onoooo]Zool0@Ol0@_l00ooonfX2oooS0007omGo0?l0
n?ooo`2@ool0T?oonf[o0?lHoookJP02oolT0003oookJ_oo7P3ooah000;oE@3o00Go05OooomA0?oo
nf[ohol0oon<0002ool0^007o`3oTOoonf[o0?mCo`3oDoo:0?oo0?oPool0l002oo<0o`03oomC0?oo
nf[ooo]Z00;oo`1c0_l0=ol02?oo0<gooo]Zo`3oFOo00?oo09;ooookJ_oJo`3oo`0n1?oonfX02?oo
kP3ooo]ZobP0ooook03ooah0oh_o0?oo0@3oo`0<0ooonfX01ooo0:cooo]ZoookJ_oonf[o9?l0o`2M
ool0;Ol00_ooE0001?ooQP3o9_l0obKo0?oo0=/2oookJP;ol@3o00?ooo]Zo`18oooo0<P00_oo5P00
1_oonf[o7Ol0oookJ_l0ofcooo]ZooKo00?ooo]Z0_l0W_l2oookJP;o0;7o0_oonfX2oonS00Sooo]Z
0_o6o`02o`3<o`03okh0oooonf[ooo]Z00Wooo]Z00?oo`0HoookJ_oonfX01ooonfX4o`0000Sooo]Z
0_oo01P;oookJP04okh0ool0c?oo0<coolKo00Wooo]Z00Gooj<0oookJ_oonf[ooo]Zo`2ao`04oook
JP03o`2Noooonf[ooo]Z00;om_l000Kooo]Zo`3oK?lMo`3o7Ol0oookJ_oo5P02ool0b003o`18oooo
nf[ol@3o00?ooo]Z00Goo`3KobKo0?ooQP3oohH0oomD0002o`0]o`04o`2MoolTo`3ooo]ZoookJP;o
o`2/0ooonfX00ooo00coo`40oolN0002ooo/0003oookJ_ookP3oonh000Cooo]Z00Coo`0nom[o0?l0
T_oo09;o0_l0oeT01?oonf[oo`3=o`0gool0=ol2ool0L`0<oookJ_ooD`3ol`3ooo<0ooooX@3oo`3`
o`3oh?oonf[o0?mCool06ooonf[o0?nA0_oo0;P01OooJ03ohol0oomA0?ooD@3o05Oo00;oE@3o0_oo
7P02oookJP04oolT0?oonf[o0?lHoookJP;oo`2@00Co0?Soool0DOooh`3oog@00_oonfX2o`12o`;o
oo]Z00Co0?o_o`2foomEo`3oEOl00_oonfX2oooR00Oooo]Z0_oo0?82oookJP;oK`3o0_oo^P02o`3o
H003oookJ_oo06Ooo`1W00?ooo]Z0_oo0:l@oookJP;o0?l9=OoonfX003Sooo]Z0_l0o`T@oookJP03
o`3oo_oo0:oooo]Z00;ooo]Z0_oo06L2oookJP07o`3oH?oo^P3ookX0oookJ_m_0?oooo]Zo`0?o`02
ool0lP;o00oo1OoonfX01?l0/?ooon80oookJ_oonfX3o`0?o`;o0?o_00?ooo]Zo`12ool0o``00_l0
o``00oooN@3oon<0o`3o3002o`3o3004ool0T?oonf[o0?lHoookJP;oob@00_oonfX01?oo7P3o0;3o
o`2`ool0/?l2oomA0005on?o0?ooJ03ooh`0ool0^?l0oed00_l0ojd01_l03ooo0?n]o`3oh?l0on3o
00oooo<0o`;ooe<000OoiOl0ool0Looo07?oolD0o`0goooo0<gooo]Z00;o0?mI00CoiOl0o`2BoooJ
o`3oo`0n1?oonfX00oookP3o00ooo`0?o`04o`0?o`03ool03?l0A?ooo`0000Koo`0000Co09gooolh
0?l0;Ooooe@00_ooQP000olVo`3oo`3KoookJP02oookJP03oo40oooonf[o05oo00Go05oo00Go7Ol0
o`3oK?l0ofcooo]ZooKo0003oookJP05o`2Noooonf[ooo]ZoookJ_l0/Ol00ooonfX00ol0Gooooj<0
oookJP07oookJP;oa_l00_oUo`000onn0?oooo]ZoookJP04oookJPOo05oo2?oonfX4o`0000Gooo]Z
00?oolT0o`3o3?l0/?l01?l0/?l00ol0o`coolT0oookJP03oookJP03ooo90?l0/?ooolT000;o0<co
1?l03ol6oookJP;ooj<00ooonfX01Ol0/Ooooo]ZoookJ_l0W_oooo]Z00Ooo`0000?o7Ol0o`3oo_l0
ooh00_oo0<P2o`3ooP?o05oo00Kooo]Zool0folVo`3o9_l0odCo0?ooN@02o`0]o`CoogT00_oo0:`3
oookJP;oo`0<00CoRol0oolN0?ook03oon`01_m4o`000ooo03kof_l0o`3ooP02o`3ooP;o0?mI0_m4
o`001?l0ookoo`1cool0Lom4o`02oomC00;ol`3o00?oo`3`o`3oh?l0on000_l0oe<01_oonf[o0?nA
o`3oTOoo0;Sooh`0on?o00;ooe4000Go05Ooo`3o=_mE0?ooE@3ooolN0002oolX0004oiCo0?oo:03o
obP0oolX00;oo`2@0ooUo`001ol0oegoiOl0onGo0?l03oooobP0oiCo0?oonfX00_l0onl01?l0]_oo
EOl0oookJ_oonfX2oooR00Oooo]Z00?oo`25ool0l_oonfX00_oonfX2ofl0o`03oonj0?l0of3o0?mP
00;ooo]Z00Coo`1WoookJ_oonf[ooo]Z0_oo0:lAoookJP03o`3o2Ooonf[ooo]Z06Sooo]Z0_l0o`TA
oookJP;oo`2_0ooonfX01?oo06Oooo]ZoookJ_l0of02oonj0003oookJ_m_0?oooo]Z00;ooo]Z00?o
o`3bool0QOoonfX01_oonfX2oooR00;ooo]Z00OoEOl0o`2fool0onoo0?o_oookJ_oo047o04;o00;o
oo]Z00Goog@0oooS0?ooh`3oeOl0ooWo0002ool0T0;o0?lH00Gooo]ZoolT0?oo903ooo]ZoolN0002
oeD0o`03o`3o=_l0Eooooe4000;ohol000Gooh`0ool0^?oo0;So0?nAoookJP02o`3oD`03olX0ool0
on3oo`3`00;ol`3o00?ooe<0oookJ_oonfX00_oo07<2o`0go`08ool0cOoonf[o0?mIo`3o9Ol0T_oo
oo]Zom[o0?oo03h4oookJP08ooo^0?oonf[o:03oooo/0?oo7P3oRol0ool10?oo00`3oookJP07ool0
[?oonf[ooo]ZoookJ_lTo`3o09goo`0]o`02oomD0004oon60?lVo`3o9_l0ool0f`;ooo]Z0_oa0?l0
0ooonf[o04Soool0b002oolF0006oookJ_lMo`3ooo]Zo`3oK?oonf[om_l00ooonfX2o`2No`;ooo]Z
0_l0/Ol2oookJP;ooj<02OoonfX01?o6o`3ooo]Zo`3<oonn0?l<oookJP03ool06?oonf[ooo]Z00Ko
oo]Z1?l00006oookJP?oo`0H2ooonfX2okh0o`03o`3<ooo6o`3oa_l000Wooo]Z00Gooj<0oookJ_oo
nf[ooo]Zo`2ao`03oookJP06o`2Noooonf[ooo]ZoookJ_ofo`3ooo]Z0_l0of`01OlMo`3ooo]ZoolF
0?oo5P3oo`3800;o04So00?ooo]Zoo40oooonfX00_oonfX01Ooo0=_o9_l0oon60?ooQP3ooe@000;o
02go00Go09goobCo0?oonf[ooo]Zool0[003oookJP;oo`0<00Goo`40oolN0?ook03oon`0oookJP02
ooo^00?ooo]Z0_oo03h00ooonf[o09;oo`3o9@02o`3oF@04oookJ_oo0<go03Ooooo500;oo`1c00Co
oo]ZoomC0?oc0?ool`3o0_oo0?001_l0on3o0?mCo`3oDooo01_oo`03o`3oT@;oo`2h00GoofP0on?o
0?ooD@3ooe40o`3o=P02oeD0o`03oolN0?oonf[ooo]Z00;oob@000Wooo]Zo`3o6?oonf[oo`2@ooWo
0?l0n?ooo`1AoooS0?ooM0000_oonfX2o`12o`;ooo]Z00Go0?o_o`2foomEo`3oEOl0oookJP02oooR
00Oooo]Z00?oo`25ool0l_oo0?800_oonfX2ofl0o`;ookX00_l0of000ooonf[oo`1Wool0I`02oook
JP?oo`2_4?oonfX2o`3o2CGooo]Z000hoookJP;o0?l94?oonfX00ol0ookoo`2_oookJP02oookJP;o
o`1W0_oonfX00ol0of3ookX0oonj0002ofl0o`04oookJ_l03oooo`3bool0lP;o00oo1OoonfX2o`2`
o`;ooo]Z0ol03ol01?l0onoo05oooookJ_l0@_l3o`3o3003oomi0?ooh`3o0?l<00;o0?l<00Coo`2@
oookJ_l0oaSooo]Z0_oo9002oookJP04oolN0?l0/?oo0;3oo`2`o`;ooe4000Gohol0oomX0?oo0;So
o`2ho`3oG@02o`3o[@06o`0?ool0ojgo0?oPo`3oh?l03oool`3o0_ooD`001ooUo`3oo`1cool0Looo
a@3o03Ooool0cOoonfX00_l0oeT01?oUo`3o09;oom[o0?oo03h4oookJP03ooo^0?l03ooo00oo00Co
00oo00?oo`0<o`14oooo00000_oonfX02?oo0:cooo]ZoookJ_oonf[o09gooolh0?l0;Ooooe@00_oo
QP000olVo`3oo`3KoookJP02oookJP03oo40oooonf[o05oo00Ko05oo00Cooo]Zo`3oK?oonf[om_l0
0ooonfX2o`2No`;ooo]Z00Ko0;7ooookJ_oonf[ooo]Zo`1OooooX`08oookJP;oa_l00_l0c?l00onn
0?oooo]ZoookJP04oookJPOo05oo00?oo`0HoookJ_oonfX01OoonfX4o`0000Cooo]Z2?l0/?l00ol0
o`coolT0oookJP03oookJP04o`3o3?l0/?oo0?l<o`3<o`;oolT00_l03ol7oookJP05oonS0?oonf[o
oo]ZoookJ_l0/Ol00ooonfX00ol0W_ooo`00ool00005ool00004o`3oo_lMo`3o0?ono`3ooP;oo`38
0ol0ooh2o`1Oo`04oookJ_oo0=_o9_l0obKo00;oA?l00_l0;Ol3oomi0003oookJ_oo0:cooo]Z00?o
oo]Z00Goo`0<ool10?n;o`3ooah0ooo/0002odCo0007o`3oo_m4o`3oA?l0odCo0?oonf[oo`0nom[o
0002o`3ooP03ol00ool0oeWo0?mI00;oA?l000Co0?onool0Looo07?o0?on0_ooD`001Ooc0?ooo`3`
ool0l?l0on3ooo]Z00;o0?mC00Kooo]Zo`3oTOoo0;Soo`2hoon<0?oSo`02oomA0003o`1Gool0ocKo
E@3o00;ooah00_oo:0001?nDo`3oobP0oolX0?oo:002ool0T0?oiOl000Oo05ooonGo0?oUo`3ooo]Z
oiCo0?l0@_oooo]Z00;o0?o_00Co0;KooeGo0?oonf[ooo]Z0_oohP07oookJP03ool0QOoo0?;ooo]Z
00;ooo]Z00?oK`3ooonj0?oo^P000_l0of000ooonf[oo`1Wool0I`03oookJP;oo`2_4?oonfX2o`3o
2F[ooo]Z0_l0o`TAoookJP;oo`2_0_oonfX2ool0I`;ooo]Z00?o0?mPoonj0?oo^P000_m_0?l2oook
JP;oo`3b00?oo`25oookJ_oonfX01OoonfX2oooR00;ooo]Z00OoEOl0o`2fool0onoo0?o_oookJ_oo
047o04;o00;ooo]Z00Goog@0oooS0?ooh`3oeOl0ooWo0002ool0T0;o0?lH00Gooo]ZoolT0?oo903o
oo]ZoolN0002oeD0o`03o`3o=_l0Eooooe4000;ohol000Gooh`0ool0^?oo0;So0?nAoookJP02o`3o
D`;o0?oP00Coo`3`oo<0oooc0?oooe<00_oonfX03?oo07?oolD0o`0gool0=oooo`3=oookJ_l0oeWo
0?lUo`2Boooonf[of_l0ool0?PCooo]Z00Soonh0oookJ_lX0?ooon`0oolN0?n;o`3oo`40ool030?o
oo]Z00Ooo`2/oookJ_oonf[ooo]ZobCo0?l0WOoo02go00;ooe@000CoohH0obKo0?lVo`3oo`3K0_oo
nfX2oo40o`03oookJ_l0B?ooo`3800;ooaH000Gooo]Zoago0?oonf[o0?m/oookJP02ooKo00;ooo]Z
0_l0W_l2oookJP;o0;7o0ooonfX00oooX`3ooo]ZoookJP07oookJP03olKo0?oonf[o0<co00;o_P3o
3?oonfX00ooo01Sooo]ZoookJP05oookJPCo00001OoonfX2ool060gooo]Z00?o_P3oo`3<ool0c?l0
0_o6o`08oookJP04oonS0?oonf[ooo]ZoookJP;o0;7o0ooonfX03ol0W_oooo]ZoookJ_oonf[om_l0
oookJ_l0ofcooo]Zoago0?oonf[ooaH0o`3o:ooo0<So04SooookJP02oo40o`;ooo]Z00Ooo`3KobKo
0?lVo`3oohH0oomD0?oonf[o02go00;o09go0_oonfX2ool0[0?ooo]Z0_oo00`01_oo0@3ooah0ooo/
0?ook03ooo]Zooo^00Cooo]Z0_oo03h00ooonf[o09;ool00o`02o`3oF@;oo`3=00?o03Ooooo50?oo
07<00_oonfX01?ooD`3ol`3ooo<0oooo0?02o`3oh0;o0?mC00Oooo]Zool00ol0oi7oo`2hoon<0?oo
J03ohol000;ooe4000Co0?lfoeD0oooonf[ooah00_oonfX2oolT00;o0?lH00Oooo]Zool0T?oio`3o
0?Soool0DOooh`3oog@000;ooo]Z0_l0@_l01?oonf[o0?o_o`3okol0]_l2oeGo0003oookJ_oohP3o
on8000Oooo]Z00?oo`25ool0l_ooi0000_oonfX2ofl0o`;ookX00_l0of000ooonf[oo`1Wool0I`02
oookJP03ool0[ooonf[oo`2_013ooo]Z0_l0o`TeoookJP00>?oonfX2o`3o2A3ooo]Z0_l0ooh3oook
JP;oo`1W00Gooo]Zo`3oH?l0of3o05oooonj0002ofl0o`04oookJ_l03oooo`3bool0lP;o00oo1?oo
nfX3o`2`o`03oookJ_l03ooo00oo00;o00oo00?o0?o_o`1Oool0Gol00_l0@_l01_oonf[oolT0oomi
0?ooh`3oolT0o`3ho`;oo`2@00?ooo]Zo`3o6?oonfX00_oo9002oookJPCo0;3o0_ooD@001?oSo`3o
ofP0ool0^?oo0;P2o`3oG@03o`3o[Ol03ooo00oo00;o0?oP00Go00oooo<0ooooD`3ooe<0onGo0002
ool0L`04ooo50?l0=oooo`3=oookJP;o0?mI0_l0T_l00ooJo`3oo`0noookJP03oookJP03ooo^0?l0
3ooo00oo00Co00oo00?oo`0<o`14oooo00000_oonfX01ooo0:cooo]ZoookJ_oonf[o09gooolh0?l0
;Ol00_ooE0001?ooQP3o9_l0ool0fooo0=/2oookJP03oo40ool0Gooo05oo00Ko05oo00Cooo]Zo`3o
K?oonf[om_l00ooonfX2o`2No`;ooo]Z0_l0/Ol2oookJP;o05oo2OoonfX01?o6o`3ooo]Zo`3<oonn
0?l6oookJPOo05oo00?o0?mMool06?oo01P01OoonfX4o`000003oookJ_l0/?oo0;3o00Wo0;3o0_l0
o``3oookJP05o`3o3?l0/?oo0;3oo`3<ool0o``00ooob@08oookJP05oonS0?oonf[ooo]ZoookJ_l0
/Ol00ooonfX00ol0W_ooo`00ool00005ool000;o7Ol00_l0ooh2ool0b0?o0?on00Go05oooookJ_oo
0=_oo`3KobKo0003odCo0007o`0]oom4o`3oA?l0odCo0?ooN@3ooo]Zool0[003oookJP;oo`0<00Co
o`40oh_o0?ook03oon`00_m4o`001?l0ookoA?l0odCo0?m4o`02ool0?P03om[o0?l0ooko0?on00;o
0?mI0_m4o`002Ol0ookoA?l0ool0Looo07?o0?l<oomC0?l0o`col`3oool0l002o`3oh007oookJ_l0
oe?o0?mCoookJ_l0oi7oo`2honGo0002on?o00;ooe4000?o05OooeD0oomE0?l00_oo7P000ooo:03o
U?l0oolX0002oolX0003o`3o6?oo093oo`2@00?oiOl000Go05ooonGo0?oUo`3oobP0oiCo0002oook
JP04o`3okooo08KoEOl0oeGo00;ooo]Z0_oohP06oookJP;oo`2500Goo`3boookJ_oonf[ooo]Zofl0
o`02oonj00;o0?mP00?ooo]Zool0Iooo06L00ooonfX00ooo0:oooo]ZoookJP0?oookJP;o0?l9J_oo
nfX2o`3o2A7ooo]Z0_oo0:l2oookJP;oo`1W00?ooo]Zo`3oH?l0of000_oo^P02ofl0o`;ooo]Z0_oo
0?800ooo08Gooo]ZoookJP05oookJP;oon8000Cooo]ZoeGo0?mEo`3o0;Ko0_l0onl00ooonf[oo`11
o`12o`02oookJP05oomd0?ooh`3oon<0omGo0?oio`000_oo0902o`3o6005oookJ_oo903oob@0oook
J_oo7P000_mE0?l00ol0ocKo05OooomA0002on?o0005oon<0?oo0;Soo`2ho`3oTOoonfX00_l0oe<2
o`3oh004ool0l?oc0?ool`3ooomC00;ooo]Z00Coo`1cooo50?l0=oooo`3=0_oonfX01_l0oeWo0?lU
o`2Boooonf[of_l0ool0?PCooo]Z00Soonh0oookJ_lX0?ooon`0oolN0?n;o`3oo`40ool030?ooo]Z
00Koo`2/oookJ_oonf[ooo]ZobCo0?l0WOl2o`0]o`05oomD0?ooQP3o9_l0obKo0?oo0=/00_oonfX2
oo40o`03oookJ_l0B?ooo`3800;ooaH000Gooo]Zoago0?lMo`3o0?m/oookJP02ooKo00?ooo]Z00Go
09kooookJ_oonf[ooo]Zo`2ao`03oookJP03oonS0?oonf[ooo]Z00Oooo]Z00Goa_l0oookJ_l0c?oo
oo]Zokh0o`0=oookJP?oo`0H1?oonfX4o`0000?ooo]Z0ooo01P=oookJP;o_P3o00?o0<coolKo0?o6
o`002OoonfX01OooX`3ooo]ZoookJ_oonf[o0;7o00?ooo]Z0_l0W_l2oookJP;om_l000_ooo]Zo`3o
K?lMo`3o7Ol0oookJ_oo5P3o0?l[ool0b?l0B?oooo]Zoo40o`03oookJP05ool0folVo`3o9_l0oon6
0?ooE0000_l0;Ol01?l0WOoo9?l0oookJ_oonfX2ool0[0?ooo]Z00Soo`0<o`14oon;o`3ooah0ooo/
0?l0obcooo]Zooo^00Cooo]Z00Coo`0nom[o0?oonf[o09;o0_l0oeT01ooonf[oo`3=o`0gool0=ooo
olD0ool0LooonfX00_ooD`02oo<0o`03ool0l?l0on3o0?oP00;o0?mC00Kooo]Zool00ol0oi7oo`2h
oon<0?oSo`02oomA0005o`1GoomE0?ooE@3ooookJ_oo7P000_oonfX03?oo903ooo]Zo`3o6?l0oaSo
oo]Zool0T?oio`3oeOl0ool0DOooh`3oog@0oookJP;o04;o00Coo`11oookJ_l0onooo`260omEo`00
0ooonf[oon80oooR0007oookJP03ool0QOoo0?;oon@000;ooo]Z00?oK`3ooookJ_oo^P000_l0of02
oookJP;oo`1W0_oonfX2ool0[a7ooo]Z0_l0o`TeoookJP00>?oonfX2o`3o2@oooo]Z0ol0ooh3oook
JP;oo`1W00Gooo]Zo`3oH?l0of3o05oooonj0002ofl0o`;o00oo0_oo0?83o`0?o`?ooo]Z0ol0/?l0
0ooonf[o00ooo`0?o`03o`0?o`;o05oo0_l0@_l2ooo90004oomi0?ooh`3oolT0o`3ho`;oo`2@00?o
oo]Zo`3o6?oonfX00_oo9002oookJPCo0;3o0_ooD@001?oSo`3oofP0ool0^?oo0;P2o`3oG@04o`3o
[Ol03ooo00ooo`3oh0;o00oo00Col`3ooomC0?ooD`3oiOl00_oo07<01?ooa@3o03Ooool0cOoonfX2
o`3oF@;o09;o00?of_l0ool0?_oo03h00ooonfX00oookP3o00ooo`0?o`04o`0?o`03ool03?l0A?oo
o`0000;ooo]Z0_oo0:`2oookJP03o`2Moooo>03o02go00;ooe@000CoohH0obKo0?lVo`3oo`3K0_oo
nfX00ooa0?oo05ooo`1Oo`06o`1Oo`04oookJ_l0ofcooo]ZooKo00?ooo]Z0_l0W_l2oookJP;o0;7o
0_oonfX2o`1Oo`Wooo]Z0_o6o`000ol0c?oooo]Zo`1Oo`05oookJPOo05oo00?o0?mMoookJ_oo01P0
0ooo01P2oookJP;o00003ol0/?l01?l0o`coolT0oookJ_l0o``2o`2`o`;o0<co00?o0;3oo`3o3?oo
b@000_oob@06oookJP;ooj<00_oonfX2o`2ao`;ooo]Z00?o09kooookJ_oo00001_oo00001OlMo`3o
0?ono`3oo_l0ookoo`3800?o0?on0_l0Gol01?oonf[oo`3KobKo0?lVo`03odCo0003o`0]oom4o`3o
A?l000;oA?l00_oo0:`3oookJP;oo`0<00Koo`40o`3oo_ook03oon`0odCo0?l0ooh3odCo0004oook
J_oo03koo`0nom[o00;o0?on0_l0oeT2odCo0006o`3oo_m4o`3oo`1co`3oo_l0o`cooe<00_oc0?l0
1Ooo0?3o0?oPo`3oh?l0o`co0?mC00;ooo]Z00?o0?nAool0^?oUo`000_oSo`000oooD@3o05Ooo`3o
=P02oeD0o`;ooah000?oobP0oiCo0?oo:0000_oo:0002ooonf[oo`2@ool0T?oEo`3oiOl0o`3oGOl0
GoooiOl0o`0?oooo:03oU?l000?oobP000?o0;KooeGo0?oonfX00_oonfX2oooR00Kooo]Z00?oo`25
ool0l_oo0?800_oonfX2ofl0o`;ookX00_l0of000ooonf[oo`1Wool0I`03oookJP03ool0[ooonf[o
oo]Z00oooo]Z0_l0o`UZoookJP;o0?l94OoonfX2ool0[`;ooo]Z0_oo06L00ooonf[o0?mPo`3oH002
oonj00;oK`3o0_oonfX2ool0lP03ool0QOoonf[ooo]Z00Gooo]Z0_oohP001?oonf[oEOl0oeGo0?l0
]_l2o`3ok`03oookJ_l0@_oo04;o00;ooo]Z00Goog@0oooS0?ooh`3oeOl0ooWo0002ool0T0;o0?lH
00Gooo]ZoolT0?oonf[ooo]ZoolN0002oeD0o`03o`3o=_l0Eooooe4000;ohol000Gooh`0ool0^?l0
oi7o0?nAoookJP02o`3oD`;o0?oP00Coo`3`oo<0oooc0?oooe<00_oonfX01?oo07?oolD0o`0goooo
0<d2oookJP06o`3oFOl0obGo09;ooookJ_oJo`3oo`0n1?oonfX02?ookP3ooo]ZobP0ooook03ooah0
oh_o0?oo0@3oo`0<0ooonfX2ool0[0;ooo]Z00Ko9?l0o`2Mool0;Ooo02gooomD0?ooQP02obKo0003
ool0fooonf[ooo]Z00;ol@3o00Kooo]Zo`18oooo0<Soo`38oolF0?oonfX2oago0004o`3oK?oonf[o
m_l0ooKo00?ooo]Z00Go09kooookJ_oonf[ooo]Zo`2ao`03oookJP03oonS0?oonf[ooo]Z00Sooo]Z
00?oa_l0o`3<ool0c?l00_nn0?l=oookJPCoo`0H0_oonfX4o`000003oookJ_oo01Soo`0H00;oo`0H
3_oonfX00onn0?oo0<coolKo0002olKo00Sooo]Z0_ooX`03oookJP05o`2aoooonf[ooo]ZoookJ_l0
W_l00ooonfX01_ofo`3ooo]Zo`3oK?l0ofco7Ol0oookJP;ooaH00_oo0<P00ol0B?oooo]Zoo40o`03
oookJP05ool0folVo`3oohH0oon60?ooE0000_l0;Ol01Ol0WOoo9?l0oookJ_oonf[oo`2/00Cooo]Z
00?oo`0<ool10?oo7P000_ook0000olX0?ooonh0ooo^0004oookJP04ool0?_oJo`3o09;oo`2Bo`;o
0?mI00Cooo]Zool0cOl0=ooo03Oo0_oo07<01_oonf[ooe<0oo<0oooc0?oooj40ool0l0;o0?oP00Co
0?mCool06ooonf[o0?nA0_oo0;P01OooJ03ohol0oomA0?ooD@3o05Oo00;oE@3o00Oooo]ZoolN0?oo
nf[ooo]ZoolT0?oonf[o0?lH00;ooo]Z00?oo`2@o`3hoooEo`000_ooh`02oookJP;o04;o00Coo`11
oookJ_l0onooo`260_mEo`02oookJP;oon801ooonfX2ool0lP06oooT0?oonf[oK`3oofl0oooonf[o
okX00_l0of02oookJP04ool0Iooonf[ooo]ZoookJP;oo`2_4OoonfX2o`3o2CGooo]Z000hoookJP;o
0?l93ooonfX3o`3ooP?ooo]Z0_oo06L01Ooonf[o0;3oo`3oH?l0GooookX000;oK`3o0_l03ol2ool0
lP?o00oo0ooonfX4o`2`o`Go00oo0_l0Gol2o`12o`;oolT00_ooh`002?oob@3o0?Soool0T?oo093o
oo]Zo`3o6?oonf[oob@00_oonfX00ooo7P3o0;3oo`2`o`02o`2`o`;ooe4000Cohol0oomX0?oo0;So
o`2h0_l0oed01?l0ojgo00ooo`0?ool0on02o`0?o`04oo<0ooooD`3ooe<0onGo00;oo`1c00CoolD0
o`0goooo0<gooo]Z0_l0oeT00ol0Gooo09;oom[o0002ool0?P?ooo]Z1ol03ol2ool03003ool00?oo
nf[ooo]Z00;oo`2/0_oonfX2o`2Mo`04o`0]ooooE03ooe@0oon600;o9_l000Coo`3KoookJ_oonf[o
l@3o2Ol0Gol2o`3oK0;om_l00_oonfX2o`2No`;ooo]Z0_l0/Ol2oookJP?o05oo2?oonfX2olKo00;o
0<co0_l0Gol3oookJPWo05oo00?oiOl0oookJ_oonfX01Ooo01P@o`2`o`03o`3o3?oob@3oolT000?o
0;3o00?o0<coo`2`ool0/?l00_l0o``8oookJP05oonS0?oonf[ooo]ZoookJ_l0/Ol00ooonfX00ol0
W_oooo]Zool00006ool00003oago0?l0ooko0?on00;oo`380_l0ooh2o`1Oo`;ooo]Z00?oo`3KobKo
0?lVo`000_m4o`02o`0]o`CoA?l00_oo0:`3oookJP05ool03?oo0@3oRol0o`3oo_ook0001Ol0ooh0
1?m4o`3ooo]Zool0?_oJo`03o`3ooP;o0?mI00Wo0?onodCo0?l0ookoA?l0ool0Looonf[o0?l<oomC
0?oc0?l00_oo0?02o`3oh0;o0?mC00Gooo]Zo`3oTOl0oi7oiOl0oon<0002on?o0005oomA0?l0Eooo
0?lfoeD0oooonfX00_oo7P001_oo:03oU?l0o`3o[Ooo:03o0?lHool0T0?o0?mM00KoiOl0o`1OoooU
o`3oiOl0oolX0?nDo`04oolX0003o`2foomEo`3ooo]Z00;ooo]Z00?oon80oookJ_oonfX01OoonfX0
0ooo08Goo`3bool0lP02oookJP;oK`3o00KookX0o`2gool0of3o0?mPoookJ_oo06L4oookJP03ool0
[ooonf[ooo]Z00oooo]Z00?o0?l9oookJ_oonfX0JOoonfX2o`3o2A7ooo]Z0_oo0:l2oookJP;oo`1W
00?ooo]Zo`3oH?l0of000_oo^P02ofl0o`;ooo]Z0_oo0?800ooo08Gooo]ZoookJP05oookJP;oon80
00Cooo]ZoeGo0?mEo`3oooX00_l0onl00ooonf[o04;oo`12o`02oookJP05oomd0?ooh`3oon<0omGo
0?oio`000_oo0902o`3o60;oob@00_oonfX01_oo7P3oE@3ooeD0ool0ocKo05OooomA00;ohol000Oo
oh`0ool0^?l0oi7oo`03oookJ_l0oe?ooo]Z00;o0?oP00Coo`3`oo<0oooc0?oooe<00_oonfX01?oo
07?oolD0o`0goooo0<d2oookJP06o`3oFOl0obGo09;ooookJ_oJo`3oo`0n1?oonfX02?ookP3ooo]Z
obP0ooook03ooah0oh_o0?oo0@3oo`0<0ooonfX2ool0[0;ooo]Z00Ko9?l0o`2Mool0;Ooo02gooomD
0?ooQP02obKo0007ool0fooonf[ooo]ZoookJ_oa0?oooo]Zo`18o`02ool0b004oolF0?oonf[o7Ol0
oago00;o0?m/0_ofo`03oookJP05o`2Noooonf[ooo]ZoookJ_l0/Ol00ooonfX2oonS00Wooo]Z00?o
a_l0oookJ_l0c?l00_nn0?l@oookJP[oo`0H3ooonfX00onn0?oo0<coo`3<o`02olKo00Wooo]Z00Go
oj<0oookJ_oonf[ooo]Zo`2ao`04oookJP0:o`2Noooonf[ooo]ZoookJ_ofo`3ooo]Zo`3oK?oonf[o
7Ol0oookJP;ooaH000?oo`38o`18ool0B?l00_oa0?l2oookJP04ool0folVo`3o9_l0oon600;ooe@0
00?o02gooolh0?l0WOl00ooonfX01?oo0:cooo]ZoookJ_oonfX2ool03005ool10?oo7P3oon`0ooo/
0?oonfX00_ookP03oookJP;oo`0n00?ooo]Zo`2Bool0T_l00_l0oeT01?oonf[oo`3=o`0gooooa@02
ool0L`04oookJ_ooD`3ol`3ooo<0o`;oo`3`00?o0?oPoookJ_l0oe<00_oonfX01Ol0oi7oo`2hool0
^?ooJ03ohol000;ooe4000?o0?lfoeD0oooonfX00_oo7P02oookJP04oolT0?oonf[o0?lHoookJP;o
o`2@00Co0?Soool0DOooh`3oog@00_oonfX2o`12o`;ooo]Z00Co0?o_ool0Q_mEo`3oEOl00_oonfX0
0ooohP3ooo]ZoookJP06oookJP;oo`3b0_oonfX2ofl0o`;ookX00_l0of000ooonf[oo`1Wool0I`03
oookJP;oo`2_4?oonfX2o`3o2CKooo]Z000hoookJP;o0?l93ooonfX4o`3ooP;ooo]Z0_oo06L00ooo
nf[o0;3oo`3oH002o`1Oo`;oK`3o0_l03ol2ool0lP?o00oo0ooonfX3o`2`o`Ko00oo0_l0Gol2o`12
o`;oolT00_ooh`02ooo900;oo`2@00Cooo]Zo`3o6?oonf[oob@00_oonfX5o`2`o`;ooe4000Gohol0
oomX0?oo0;Soo`2hool00002o`3o[@;o00oo00Co0?oPo`0?ool03oool`3o0_ooD`001ooonf[oo`1c
ool0Loooa@3o03Ooool0cOoonfX00_l0oeT00ol0Gooo09;oom[o0002ool0?P?ooo]Z1ol03ol2ool0
30;oo`0000?ooo]Zool0[?oo0:`00_oonfX2o`2Mo`04o`0]ooooE03ooe@0oon600;o9_l000Coo`3K
oookJ_oonf[ol@3o2Ol0Gol2o`3oK0;om_l00ooonfX01Ol0ookooo]ZoookJ_oonf[o0;7o00;ooo]Z
0ol0Gol9oookJP03olKo0?oonf[o0<co00?o05oo0_oonfX9o`1Oo`03o`3oGOoonf[ooo]Z00Cooo]Z
1?l00002oookJP_o0;3o00?o0?l<oookJ_l0/?l00_l0/?l00ol0c?oo0;3oo`2`o`02o`2`o`;o0?l<
1_oonfX2oonS0004ooo90?oonf[o0;7oo`2ao`;ooo]Z0_l0W_l00ooonf[oo`00ool00004ool000;o
7Ol00_l0ooh2ool0b003o`3oo_l0Gooo05oo00;ooo]Z0_oo0=/01OlVo`3o0?ono`3oo_m4o`3o02go
00CoA?l000?ooo]Zool0[?oonfX00ooonfX01Ooo00coo`40oh_o0?l0ookoon`000Oo0?on00Koo`0n
om[o0?l0ooko0?onol00oooUo`04o`3ooP;oo`1c00Cooo]ZoomC0?ooD`3ol`3o0_oo0?02o`3oh0;o
0?mC00Gooo]Zo`3oTOoo0;SoiOl0oon<0002on?o0004oomA0?l0Eooo0?lfoeD0o`;ooah00_oo:000
1OnDo`3o0?n]oolX0?l0oaSoo`2@00Co0?mM00Go05ooo`3oGOl03oooobP0oiCo0003oolX0003o`3o
kol0]_ooEOl000;ooo]Z0_oohP07oookJP03ool0QOoo0?;oo`3b00;ooo]Z0_m_0?l01_oo^P3o0?mP
o`3oH?l0of3ooo]Zool0I`?ooo]Z0_oo0:lAoookJP03o`3o2Ooonf[ooo]Z06Wooo]Z0_l0o`TAoook
JP;oo`2_0_oonfX2ool0I`03oookJ_l0of3o0?mP00;ookX00_m_0?l2oookJP;oo`3b00?oo`25oook
J_oonfX01OoonfX00ooohP3ooo]ZoookJP02oeGo0004oooj0?l0onoo0?o_oookJP;o04;o0_oonfX0
1OooM03oon<0oooS0?oEo`3onOl000;oo`2@0_l0oaP2oolT00;ooo]Z00Kooah0oeD0oomE0?oo0?lf
o`1GooooD@02on?o0007oon<0?oo0;So0?nAool00ooonf[o0?mCoookJP02o`3oh004ool0l?oc0?oo
l`3ooomC00;ooo]Z00Coo`1cooo50?l0=oooo`3=0_oonfX01_l0oeWo0?lUo`2Boooonf[of_l0ool0
?PCooo]Z00?oonh0oookJ_lX0?l00_ook0000on;o`3oo`40ool03003oookJP;oo`2/0_oonfX01OlT
o`3o09goo`0]ool0;Ooooe@000;oohH000?o9_l0ool0fooonfX00_oonfX00ooa0?oooo]Zo`18o`02
ool0b004oolF0?oonf[o7Ol0oago00;o0?m/00?ooo]ZooKo0?oonfX00_oonfX2o`2No`;ooo]Z0_l0
/Ol2oookJP;ooj<02OoonfX2olKo00;o0<co00?o_P3ooookJ_oonfX04OoonfX4o`00017ooo]Z00?o
_P3oo`3<ool0c?l00_o6o`09oookJP;ooj<00ooonfX01?l0/Ooooo]ZoookJ_oonfX2o`2No`;ooo]Z
0_ofo`02o`3oK0;o7Ol000Kooo]ZoolF0?oo0<Soo`38o`18oooonfX2oo40o`;ooo]Z00Goo`3KobKo
0?lVo`3oohH0oomD0002o`0]o`04o`2MoolTo`3ooo]ZoookJP;oo`2/0ooonfX2ool03005ool10?oo
7P3oon`0ooo/0?oonfX00_ookP03oookJP;oo`0n00Kooo]Zo`2Booo00?oo0?mIoookJ_oo0<d2o`0g
o`05ooo50?oo07?oo`1coookJ_ooD`000_oc0?l00ooo0?3o0?oPo`3oh002o`3oD`07oookJ_oo00?o
0?nAool0^?ooS03oofP0on?o0002oomA0004o`3o=_mE0?oooo]ZoolN00;ooo]Z0_oo90002Ooonf[o
0?lHoookJ_oo093onOl0o`3hoooo057oon<0oomd0002oookJP03o`12oooo047ooo]Z00;o0?o_00Co
0;KooeGo0?mEo`3ooo]Z0_oohP07oookJP03ool0QOoo0?;oo`3b00;ooo]Z0_m_0?l01Ooo^P3o0;Oo
o`3oH?l0of3ooo]Z00;oo`1W0_oonfX2ool0[a7ooo]Z0_l0o`TfoookJP00>?oonfX2o`3o2@oooo]Z
1?l0ooh2oookJP;oo`1W00?ooo]Zo`2`ool0/?l00_l0Gol2ofl0o`;o00oo0_oo0?83o`0?o`?ooo]Z
0ol0/?l6o`0?o`;o05oo0_l0@_l2ooo900;oon<00_oob@02ool0T004oookJ_l0oaSooo]ZoolT00;o
oo]Z1Ol0/?l2oomA0005on?o0?ooJ03oo`2hool0^?oo00000_l0ojd2o`0?o`04o`3oh?l03ooo00oo
oo<0o`;ooe<000Oo00ooool0Looo07?oolD0o`0goooo0<gooo]Z00;o0?mI00?o05ooo`2BoooonfX0
0_oo03h3oookJP05ooo^0?l0ojgo0?n]o`3o[Ol03ol00_l0ojd2ool030;oo`0000?ooo]Zool0[?oo
0:`00_oonfX2o`2Mo`;o02go00Gooe@0oon60?lVo`3o9_l0ool0f`02oookJP_o05oo00?o0?m/ooKo
0?ofo`000ooonfX01?l0ookooo]ZoookJ_oonfX2o`2ao`03oookJ_l0Gooo05oo00;o05oo2?oonfX2
olKo00;o0<co0ol0Gol2oookJPWo0?mM1_oonfX4o`0000Wooo]Z1?l0/?l01Ooonf[o0;3oo`2`ool0
/?oo0<co00Ko0;3o1_oonfX2oonS0004oookJ_oob@3oolT0o`2ao`;oo`0000?ooo]Zo`2NoooonfX0
1_oo00000ol03ooo7Ol0o`3ooP02o`3ooP03ool0b?l0ookooo]Z00;o05oo0_oonfX00ooo0=_o9_l0
obKo0003o`3ooP05o`0]ool0ookoA?l0odCo0?oonfX00_oo0:`3oookJP;oo`0<00Coo`40oolN0?oo
k03oon`01_l0ooh2ool0?P05om[o0?l0ooko0?ono`3oFOoUo`001?l0ooh01ooo07?o0?ono`3oo_oo
D`3o0?l<oo<0oooo0?000_l0on002Ol0o`co0?mCool06ooonf[o0?nAool0^?oUo`3oofP0on?o0002
oomA0003o`1Goooonf[oE@3o00;ooah000OoU?l0oolX0?l0ojgoobP0o`3o6?oonf[oo`2@00Co0?mM
00Go05ooo`3oGOl0oego0?mMoiCo0003oolX0003ool0Q_mEo`3oEOl000;ooo]Z0_oohP07oookJP03
ool0QOoo0?;oo`3b00;ooo]Z00?oK`3ooonj0?oo^P000ol0of02ool0I`?ooo]Z0_oo0:l@oookJP;o
0?l9JooonfX2o`3o2A7ooo]Z00Coo`2_oookJ_oonf[ooo]Z0_oo06L00ooonf[o0?mPo`3oH002oonj
00;oK`3o0_oonfX2ool0lP03ool0QOoonf[ooo]Z00Cooo]Z0_oohP02oookJP;oEOl000CoooX0o`3o
kol0onoooo]Z0_l0@_l2oookJP07oomd0?ooh`3oo`1AomGo0?oio`3oo`2@oookJP02o`3o60;oob@0
0_oonfX01_oo7P3oE@3ooeD0ool0ocKo05OooomA00;ohol000Oooh`0ool0^?n@o`3oo`03oookJ_l0
oe?oo`0K00;o0?oP00?oo`3`oo<0oooc0?l00_ooD`001Ooonf[oo`1cooo50?l0=oooo`3=00;ooo]Z
00Ko0?mIol00ool0T_oooo]Zom[o0?oo03h4oookJP03ooo^0?oonf[o:03o00;oon`000?ooah0ool1
0?oo00`00ooonfX2ool0[0;ooo]Z00Go9?l0o`2Mool0;Ooo02gooomD0002oon60003obKo0?oo0=_o
oo]Z00;ooo]Z00?ol@3ooookJ_l0B?l00_oo0<P2oolF0006oookJ_lMo`3o0?m/o`3oK?oonf[om_l0
0ooonfX2o`2No`;ooo]Z0_l0/Ol3oookJP03oonS0?oonf[ooo]Z00Oooo]Z0_o6o`02o`3<o`03oook
J_nn0?oooo]Z017ooo]Z1?l0000@oookJP05okh0ool0c?oo0<cooookJ_o6o`002_oonfX01?ooX`3o
oo]ZoookJ_oonfX2o`2ao`?ooo]Z00Ko09kooookJ_oonf[ooo]ZooKo0?oonfX2o`3oK004oago0?oo
nf[ooaH0oolF00;oo`3800?o04SooookJ_oa0?l00ooonfX01Ooo0=_o9_l0oon60?ooQP3ooe@000;o
02go00Co09goobCo0?oonf[ooo]Z0_oo0:`3oookJP03ool03?oo0@3ooah000;oon`000?o0?l/ooo^
0?ookP001?oonfX2ool0?P;o09;o0_l0oeT01ooonf[oo`3=o`0gool0=oooolD0ool0LooonfX00_oo
D`02oo<0o`03ool0l?l0on3o0?oP00;o0?mC00gooo]Zo`3oTOl0oi7oo`2hoon<0?ooJ03ohol0oomA
0?l0Eooo0?lfoeD0oooonf[ooah000;ooo]Z0_oo9002o`3o6004oookJ_oo093onOl0omGo00;oon<0
00Koog@0oookJ_l0@_oo04;oool0@OoonfX2o`3ok`04o`2foomEo`3oEOl0oookJP;oon801ooonfX0
0ooo08Goo`3bool0lP02oookJP;oK`3o00GookX0o`2gool0of3o0?mPoookJP02ool0I`;ooo]Z0_oo
0:lAoookJP;o0?l9=_oonfX003Sooo]Z0_l0o`T?oookJPCo0?on0_oonfX2ool0I`?o0;3o0_l0Gol0
1?m_0?oo00ooo`0?ool03ol2ool0lPCo00oo00?ooo]Zo`2`ool0/?l00_l0/?l6o`0?o`;o05oo0_l0
@_l2ooo900;oon<00_oob@02ool0T004oookJ_l0oaSooo]ZoolT00;ooo]Z1Ol0/?l2oomA0005on?o
0?ooJ03oo`2hool0^?oo00000_l0ojd2o`0?o`04o`3oh?l03ooo00oooo<0o`;ooe<000Oo00ooool0
Looo07?oolD0o`0goooo0<gooo]Z00;o0?mI0_l0Gol00ooonf[oo`0nool0?P03oookJP05ooo^0?l0
ojgo0?n]o`3o[Ol03ol00_l0ojd2ool030;oo`0000?ooo]Zool0[?oo0:`00_oonfX01_oo003o09go
o`0]ool0;Ooooe@0oon600;o9_l000?oo`3KoookJ_oonfX02ol0Gol00ol0ofcooo]ZooKo0003oook
JP;o0?on0_oonfX2o`2ao`03oookJ_l0Gooo05oo00;o05oo2OoonfX01?o6o`3ooo]Zo`3<ool0c?l3
o`1Oo`03oookJ_l0oego0?mM00;o0?mM1_oUo`05oookJPCo00003OoonfX3o`2`o`;o0<co1?l0/?l8
oookJP;ooj<01?oob@03ool00003o`2Noooonf[oo`0000Coo`0000?o00oooago0?lMo`000_l0ooh2
ool0b0;oogT000Oo05oooo40oooonf[ooo]Zool0folVo`3oohH000;o0?on0_l0;Ol3o`3ooP03oook
J_oo0:coo`2/00;oolT000Kooo]Zool03?oo00coRol0oolN0?ook007o`3ooP;oo`0n00Gooo]Zo`3o
o_l0ookoiOl0o`3oF@04o`3ooP04ool0Lol0ooko0?onoomC00;ol`3o00[oo`3`o`3oh?l0on3ooo]Z
o`3oDooonf[oo`03o`3oTOoUo`3oo`2h0_oSo`000oooD@3o05Ooo`3o=P02oeD0o`;ooah00_nDo`00
1Ol0ojgoU?l0o`3o6?oonf[oo`2@00?o0?mM00?o05ooo`3oGOl0oed00_l0oed01OnDo`3oobP0oolX
0?l0onoo0;Ko00;oEOl00_oonfX2oooR00Oooo]Z00?oo`25ool0l_oonfX00_oonfX00om_0?oookX0
oonj0002o`3oH003oookJ_oo06Ooo`1W00?ooo]Z0_oo0:l@oookJP;o0?l9JooonfX2o`3o2A7ooo]Z
00Coo`2_oookJ_oonf[ooo]Z0_oo06L00ooonf[o0?mPo`3oH002oonj00;oK`3o0_oonfX2ool0lP03
ool0QOoonf[ooo]Z00Cooo]Z0_oohP02oookJP;oEOl000Coo`26o`3okol0onoooo]Z0_l0@_l2oook
JP07oomd0?ooh`3oo`1AomGo0?oio`3oo`2@oookJP02o`3o60;oob@00_oonfX01_oo7P3oE@3ooeD0
ool0ocKo05OooomA00;ohol000Oooh`0ool0^?n@o`3oo`03oookJ_l0oe?oo`0K00;o0?oP00?oo`3`
oo<0oooc0?l00_ooD`001Ooonf[oo`1cooo50?l0=oooo`3=00;ooo]Z00Ko0?mIol00ool0T_oooo]Z
om[o0?oo03h4oookJP03ooo^0?oonf[o:03o00;oon`000?ooah0ool10?oo00`00ooonfX2ool0[0;o
oo]Z00Co9?l0o`2Moooo>03o02go0_ooE0001?ooQP3o9_l0ool0fooo0=/2oookJP05oo40oooonf[o
oo]Zo`18oooo0<P00_oo5P001Ooonf[o7Ol0oookJ_l0ofcooo]Z00;om_l00ooonfX01Ol0W_oooo]Z
oookJ_oonf[o0;7o00?ooo]Z00?ooj<0oookJ_oonfX02?oonfX01_o6o`3ooo]Zo`3<ool0c?oooo]Z
okh0oa7ooo]Z1?l0000?oookJP05okh0ool0c?oo0<cooookJ_o6o`002_oonfX2oonS00?ooo]Z00Co
0;7ooookJ_oonf[ooo]Z0_l0W_l2oookJP;om_l00_l0of`01?oonf[o7Ol0oookJ_oo5P02ool0b0;o
04So0_oa0?l2oookJP04ool0folVo`3o9_l0oon600;ooe@000?o02gooolh0?lTo`000ooonfX01?oo
0:cooo]ZoookJ_oonfX2ool03005ool10?oo7P3oon`0ooo/0?lX0?l00_ookP03oookJP;oo`0n00?o
oo]Zo`2Bool0T_l00_l0oeT01?oonf[oo`3=o`0gool0=ol2ool0L`03oookJ_ooD`3ooe<000;ol`3o
00Coo`3`o`3oh?oonf[o0?mC0_oonfX01Ol0oi7oT?l0ool0^?ooJ03ohol000;ooe4000?o05OooeD0
oomE0?l00_oo7P02oookJP04oolT0?oonf[o0?lHoookJP;oo`2@00Co0?Soool0DOooh`3oon<00_oo
nfX2o`12o`06ool0@Ooonf[o0?o_ool0Q_l0]_ooEOl00_oonfX2oooR00Oooo]Z00?oo`25ool0l_oo
nfX00_oonfX2ofl0o`05oonj0?l0]ooo0?mPo`3oH?oonfX00_oo06L2oookJP;oo`2_4OoonfX00ol0
o`Wooo]ZoookJP0eoookJP00>?oonfX2o`3o2@kooo]Z1_l0ooh00ooonf[oo`1Wool0I`03o`2`o`;o
05oo00CoK`3oo`0?ool03ooo00oo0_oo0?84o`0?o`03oookJ_l0/?oo0;3o00;o0;3o1ol03ol00ol0
Gooo04;oooo90002ooo900;oon<00_oob@02ool0T004oookJ_l0oaSooo]ZoolT00;ooo]Z1Ol0/?l2
oomA00;ohol00_oo0;P02ooo003oiOl0oiCo0?l0ojgoU?l0o`3oh?l0ojgo00oooo<0ool0ojgooe<0
00;ooo]Z00?oo`1cooo50?l0=ol00_oo0<d2o`3oF@;o05oo00?ooo]Zool0?_oo03h00ooonfX00ooo
kP3o0?n]o`3o[@04o`3o[@;oo`0<1?oonfX02?oo0:cooo]ZoookJ_lTo`3o09goo`2`ool0;Ooooe@0
0_ooQP000olVo`3oo`3KoookJP02oookJP03oo40ool0oego0?mM00Co0?mM0ol0Gol00ol0ofcooo]Z
ooKo0003oookJP?o0?on00Cooo]Zo`2aool0/Ooooo]Z1Ol0Gol9oookJP03olKo0?oonf[o0<co00Co
05oo00?ooo]ZonGo0?oUo`000_oUo`0:oookJPCo00003?oonfX3o`2`o`;o0<co0_l0/?l:oookJP;o
oj<000Co0?l<ooo90?oob@3oolT01Ooo00000ooonf[oo`00ool00003ool00003oookJ_lMo`3o0?on
00;o0?on0_oo0<P2oomi0003oo40oooonf[ooo]Z00;oo`3K00Go9_l0o`3oo_l0ooko0?ono`0]o`05
o`3ooP03ool0[?oonf[oolT000;oolT000Goo`0<ooo90?n;o`3ooah0ooo/0006o`3ooP04oookJ_oo
:03oiOl0onGo00;o0?on00?oiOl0o`3oo_l0ooh00ol0ooh01Ooo07?o0?onoomC0?ooD`3ol`3o00;o
o`3`0_l0on001ooo01_o0?mCoookJ_oo00?oo`2honGo0?ooS0000_oSo`001OooD@3o05Ooo`3o=_mE
0?oooo]Z00;ooah00_nDo`001Ol0ojgoU?l0oiCo0?nDo`3oo`2@00?o0?mM00Ko05ooo`3oGOl0oego
0?mMoiCo0?l0ojd2oolX0003o`3okol0]_ooEOl000?ooo]Z0_oohP06oookJP03ool0QOoo0?;oo`3b
00;ooo]Z0_m_0?l2oonj00;o0?mP00?ooo]Zool0Iooo06L00ooonfX00ooo0:oooo]ZoookJP0?oook
JP;o0?l9JooonfX2o`3o2A3ooo]Z0_oo0:l3oookJP;oo`1W00?ooo]Zo`3oH?l0of000_oo^P02ofl0
o`;ooo]Z0_oo0?800ooo08Gooo]ZoookJP04oookJP;oon800_oonfX2oeGo0004ool0Q_l0onoo0?o_
oookJP;o04;o0_oonfX01oooM03oon<0ool0DOoEo`3onOl0ool0T?oonfX00_l0oaP2oolT00;ooo]Z
00Kooah0oeD0oomE0?oo0?lfo`1GooooD@02on?o0007oon<0?oo0;SoT?l0ool00ooonf[o0?mCool0
6`02o`3oh003ool0l?oc0?ool`3o00;ooe<000Cooo]Zool0Looo07?o03Oo0_oo0<d01ooonf[o0?mI
o`3oFOl0T_oooo]Zom[o0?oo03h01?oonfX00oookP3ooo]ZobP0o`02ooo/0004oolN0?oo0@3oo`0<
o`14o`?ooo]Z00Ooo`2/oookJ_oonf[ooo]Zo`2Moooo>03o02go00;ooe@000CoohH0obKo0?oo0=_o
o`3K0_oonfX2oo40o`03oookJ_l0B?ooo`3800;ooaH000Gooo]Zoago0?oonf[o0?m/oookJP02ooKo
00?ooo]Z00Go09kooookJ_oonf[ooo]Zo`2ao`03oookJP;ooj<02_oonfX00oo6o`3ooo]Zo`3<o`02
oookJP03okh0oooonf[ooo]Z00kooo]Z1?l0000=oookJP;o_P3o0_l0c?l2olKo00_ooo]Z00Cooj<0
oookJ_oonf[ooo]Z0_l0/Ol3oookJP04o`2Noooonf[ooo]ZoookJP;om_l00_l0of`01?lMo`3ooo]Z
oolF0?oo5P02ool0b004o`18oooonf[ol@3ooo40o`;ooo]Z00Goo`3KobKo0?oonf[oohH0oomD0002
o`0]o`04o`2MoolTo`3ooo]ZoookJP;oo`2/0ooonfX2ool03005ool10?oo7P3oon`0ooo/0?oonfX0
0_ookP03oookJP;oo`0n00Kooo]Zo`2Bool0obGo0?mIoookJ_oo0<d2o`0go`05ooo50?oo07?oo`1c
oookJ_ooD`000_oc0?l2ool0l003o`3oh?oonf[o0?mC00;ooo]Z00Go0?nAool0^?oo0;SoofP0on?o
0002oomA0003o`3o=_mE0?ooE@3o00;ooah00_oonfX01?oo903ooo]Zo`3o6?oonfX2ool0T004o`3h
oooo057oon<0oomd00;ooo]Z0_l0@_l01?oo047ooo]Zo`3okooo08H2oeGo00;ooo]Z0_oohP07oook
JP;oo`3b0_oonfX2ofl0o`04oookJ_oo^P3o0?mPo`3oH0;ooo]Z0_oo06L2oookJP;oo`2_4?oonfX2
o`3o2COooo]Z000goookJP?o0?l93_oonfX6o`3ooP03oookJ_oo06Oooo]Z00Co0;3o0_l0Gol3oook
JP;oo`3b00?o0?n]oookJ_oonfX00_oonfX3o`2`o`So00oo00?o05ooo`12oooob@000_oob@02oooS
00?oolT000Koo`2@oookJ_l0oaSooo]ZoolT0?oonfX6o`2`o`;ooe400_oSo`02ool0^0;oo`0000Wo
U?l0o`3o[OnDo`3o0?oPo`3o[Ol03oool`3oo`3o[OooD`000_oonfX01ooo07?oolD0o`0gool0=ooo
o`3=o`1Oool0oeT00_l0Gol00ooonf[oo`0nool0?P03oookJP03ooo^0?l0ojgo0?n]00Co0?n]0_oo
00`4oookJP08ool0[?oonf[ooo]ZobCo0?l0WOoo0;3oo`0]ooooE002oon60003o`0?oooo0=_ooo]Z
00;ooo]Z00?ol@3oo`3oGOl0oed01?l0oed4o`1Oo`03o`3oK?ofo`3ooo]Z00;ooo]Z0ol0ooh2oook
JP;o0;7o1Ol0Gol9oookJP;oa_l000?o05ooo`3<ool0Gol00ol0Gol>oookJPCo00002ooonfX2o`2`
o`;o0<co0_l0/?l00oo6o`3ooo]ZoookJP09oookJP04oonS0?l0o`co0?l<o`3o30;oolT02_oo0000
0ol0ofco7Ol0oago0002o`3ooP;oo`380_ooN@02oo40o`03oomi0?oonf[oo`3K00;o9_l00ol0ooh0
0ol0;Ooo0?ono`3ooP03o`3ooP04ool0[?oonf[oolT0ooo900;oo`0<0_oob@000oook03o0?ono`3o
oP05o`3ooP03ool0?_oo:03oiOl000CoiOl01?l0ooh2ool0L`05o`2`ooooD`3o0;3ooo<0oooo0?00
0ol0on02onGo0005oookJ_l0oi7oo`2ho`3oGOooS0000_oSo`001_ooD@3o05Ooo`3o=_mE0?oooo]Z
oolN00;oU?l000Co0?n]oiCo0?nDo`3oU?l00_oo0903o`3oG@0;o`1Oool0oego0?mMo`3oGOnDo`3o
0?n]oolX0?l0onooiOl0o`2foomEo`000ooonfX00ooohP3ooo]ZoookJP05oookJP03ool0QOoo0?;o
o`3b00;ooo]Z0_m_0?l01_oo^P3o0?mPo`3oH?l0of3ooo]Zool0I`Cooo]Z00?oo`2_oookJ_oonfX0
3ooonfX2o`3o2F_ooo]Z0_l0o`T@oookJP;oo`2_0ooonfX2ool0I`03oookJ_l0of3o0?mP00;ookX0
0_m_0?l2oookJP;oo`3b00?oo`25oookJ_oonfX01?oonfX2oooR00;ooo]Z0_mEo`001?oo08Ko0?o_
oookJ_oonfX2o`12o`;ooo]Z00Ooog@0oooS0?oo057oeOl0ooWo0?oo093ooo]Z00;o0?lH0_oo9002
oookJP06oolN0?mE0?ooE@3oo`3o=_l0Eooooe400_oSo`001oooS03oo`2hoi3o0?oo00?ooo]Zo`3o
Dooo01/00_l0on000ooo0?3ol`3ooo<0o`02oomC0003oookJ_oo07?oo`1c00;o03Oo00Soo`3=oook
J_l0oeWo0?mIo`2Boooonf[of_l0ool0?PCooo]Z0_ookP001Ooonf[oon`0ooo/0?oo7P3oo`4000;o
o`0<0ooonfX01ooo0:cooo]ZoookJ_oonf[o09gooolh0?l0;Ol00_ooE0001?ooQP3o9_l0obKo0?oo
0=/2oookJP;ol@3o00Kooo]Zo`18oooo0<Soo`38oolF0?oonfX2oago00;o0?m/0_ofo`03oookJP03
o`2Noooonf[ooo]Z00;ooo]Z00Go0;7ooookJ_oonf[ooo]ZoonS000:oookJP;oa_l000Gooo]Zo`3<
ool0c?oooo]Zokh0o`0?oookJPCo00003?oonfX2okh0o`;o0<co0_o6o`0;oookJP;ooj<00ooonfX0
1?l0/Ooooo]ZoookJ_oonfX2o`2No`;ooo]Z0_ofo`02o`3oK006oookJ_lMo`3ooo]ZoolF0?l0ob_o
o`380_l0B?l2oo40o`;ooo]Z00?oo`3KobKo0?lVo`000_ooQP001OooE03o02goo`0]ool0WOoo9?l0
00;ooo]Z0_oo0:`3oookJP03ool03?oo0@3ooah000;oon`000?o:03oooo^0?ookP001?oonfX2ool0
?P06oookJ_l0T_oo`03oo`3oFOoonf[oo`3=0_l0=ol00oooa@3oo`1cool0L`02oomC00;ol`3o00?o
o`3`o`3oh?l0on000_l0oe<01ooonf[o0?nAo`3oTOoo0;Sooh`0oomX0?oSo`000_ooD@001?l0ocKo
E@3ooookJ_oo7P02oookJP;oob@00_l0oaP01ooonf[oo`2@ooWo0?l0n?ooo`1AoooS0?ooM0000_oo
nfX2o`12o`04oookJ_l0onoo0?o_ool0QP;oEOl00_oonfX00ooohP3ooo]ZoookJP06oookJP;oo`3b
0_oonfX2ofl0o`;ookX00_l0of000ooonf[oo`1Wool0I`03oookJP03ool0[ooonf[ooo]Z00oooo]Z
0_l0o`TgoookJP00=ooonfX3o`3o2@kooo]Z1_l0ooh00ooonf[oo`1WoookJP04o`2`o`;o05oo0ooo
nfX01?oo0?;o00ooo`3o[Ol0ojd3oookJP?o0;3o2?l03ol00ol0Gooo04;oooo90002ooo900;oon<0
0ooob@001_oo093ooo]Zo`3o6?l0oaSoob@0oookJPKo0;3o0_ooD@001?oSo`3oo`00ool0^?oo0;P2
ool00003oiCo0?l0ojgoU?l000;o0?oP00Co00oooo<0ool0ojgooe<00_oonfX01ooo07?oolD0o`0g
ool0=oooo`3=o`1Oool0oeT00ol0Gol00ooJo`3oo`0noookJP02oookJPSo0?n]00?oo`0<oookJ_oo
nfX00_oonfX01Ooo0:cooo]ZoookJ_lTo`3o09go00;o0;3o00Cooe@0o`0?ooooQP3o00oo0_oo0=/2
oookJPSo0?mM0ol0Gol00ol0ofcooo]ZooKo0002oookJPCo0?on00?ooo]Zo`2aool0/Ol01_l0Gol9
oookJP03olKo0?oonf[o05oo00;o0<co0ol0Gol00ooUo`3ooo]ZoookJP0:oookJPCo00002_oonfX2
o`2`o`;o0<co00?ooo]ZolKo0?o6o`002ooonfX00oooX`3o0;3oo`2`o`03o`3o30[oo`0000Co0?m/
oookJ_lMo`3ooo]Z0_l0ooh2ool0b0;oogT000Ool@3ooomi0?ooN@3ooo]Zool0folVo`3oohH000;o
0?on0_l0;Ol4o`3ooP03onGo0?oonf[ooo]Z00;oolT00_oo00`2ooo90003ooo/0?l0ooko0?on00Co
0?on00?ooo]ZoolX0?oo03h01ooUo`02o`3ooP04ool0Lol0ooko0;3ooomC00;ol`3o00Coo`3`o`3o
h?l0on3o0;3o1OoUo`000ol0oegooh`0on?o0002oomA0003o`1Goooonf[oE@3o00;ooah00_nDo`00
1_l0ojgoU?l0oiCo0?nDo`3oo`2@ooWo00;o0?mM00Ko05ooo`3oGOl0oego0?mMoolX0?l0ojd2oolX
0004o`3okooUo`3oEOl0oeGo00;ooo]Z0_oohP07oookJP03ool0QOoo0?;ooo]Z00;ooo]Z00?oK`3o
oonj0?oo^P000_l0of02oookJP04ool0Iooonf[ooo]ZoookJP;oo`2_4OoonfX2o`3o2F_ooo]Z0_l0
o`T@oookJP;oo`2_0ooonfX2ool0I`03oookJ_l0of3o0?mP00;ookX00_m_0?l2oookJP;oo`3b1ooo
nfX2oooR00;ooo]Z0_mEo`001?oo08Ko0?o_oookJ_oonfX2o`12o`;ooo]Z00Ooog@0oooS0?oo057o
eOl0ooWo0?oo093ooo]Z00;o0?lH0_oo9002oookJP06oolN0?oonf[oE@3oo`3o=_l0Eooooe400_oS
o`002?ooS03oo`2hool0^?oo00?ooo]Zo`3oDooo01_ooo]Z0_l0on02oo<0o`;ooe<000?ooo]Zool0
Looo07<00_l0=ol01?oo0<gooo]Zo`3oFOl0oeT2o`2Bo`03om[o0?oo03koo`0n00?ooo]Z0_ookP00
1Ooonf[oon`0ooo/0?oo7P3oo`4000;oo`0<0ooonfX01ooo0:cooo]ZoookJ_oonf[o09gooolh0?l0
;Ol00_ooE0001?ooQP3o9_l0obKo0?oo0=/2oookJP;ol@3o00Kooo]Zo`18oooo0<Soo`38oolF0?oo
nfX2oago0003oookJ_l0ofcooo]Z00;om_l00ooonfX01Ol0W_oooo]ZoookJ_oonf[o0;7o00?ooo]Z
00?ooj<0oookJ_oonfX02OoonfX2olKo0004oookJ_l0c?oo0<cooookJP;o_P3o3OoonfX4o`0000_o
oo]Z00Co_P3oo`3<ool0c?oooo]Z0_o6o`0;oookJP;ooj<00ooonfX01?l0/Ooooo]ZoookJ_oonfX2
o`2No`?ooo]Z00Com_l0oookJ_l0ofco0?m/0_lMo`001_oonf[ooaH0ool0b?oo0<So04SooookJP;o
l@3o0_oonfX01?oo0=_o9_l0oookJ_ooQP02oomD0003o`0]ool0WOoo9?l000;ooo]Z0_oo0:`3oook
JP;oo`0<00Goo`40oolN0?ook03oon`0obP0o`02ooo^00?ooo]Z0_oo03h00ooonf[o09;oo`2Bo`02
o`3oF@04oookJ_oo0<go03Ooo`0go`;oo`1c00?ooo]ZoomC0?ooD`000_oc0?l02_oo0?3o0?oPolX0
ool0oe?oo`0KoookJ_l0oi7oT?l0ool0^?ooS002on?o0006oomA0?l0Eooo0?lfoeD0oooonf[ooah0
0_oonfX2oolT00;o0?lH00Cooo]Zool0T?oio`3oeOl00_ooh`001_ooM03ooo]ZoookJ_l0@_ooo`11
oookJP;o0?o_00Co0;KooeGo0?mEo`3ooo]Z0_oohP07oookJP03ool0QOoo0?;oo`3b00;ooo]Z0_m_
0?l01Ooo^P3o0;Ooo`3oH?l0of3ooo]Z00;oo`1W0_oonfX2ool0[a7ooo]Z0_l0o`TgoookJP00=ooo
nfX3o`3o2@kooo]Z1ol0ooh00ooo06Oooo]Zo`2`o`03o`2`o`;o05oo0ooonfX01?oo0?;o00ooo`3o
[Ol0ojd3oookJPCo0;3o00Ko05ooo`3o[Ol0ojgo00ooo`3o[Ol0onl2o`1Oo`;o04;o00Ko05ooo`3o
[Oooh`3oon<0o`3o[Ol0n?l2ool0T003oookJ_l0oaSo0?lH00;oob@000Kooo]ZoolN0?l0o`co0?l<
o`2`ool0o``2oomA0003on?o0?oo003oo`0000;oo`2h00Coo`00onGo0?l0ojgoU?l00_l0on002?l0
3oool`3ooo<0ooooD`3oo`00oookJ_oo07?oolD00_l0=ol2o`1Oo`06o`3oFOl0Gooo05ooo`1OoooJ
o`3oo`0n0ooonfX8o`3o[@03ool03?oonf[ooo]Z00;ooo]Z00Goo`2/oookJ_oonf[ooo]Zo`2Mo`02
o`2`o`;ooe@000CoohH0o`0?ool03oooo`3K0_oonfX8o`3oG@Co05oo00Cooo]ZooKo0?oonf[ooo]Z
1?l0ooh00ooonf[o0;7oo`2ao`06o`1Oo`03o`3oGOoonf[ooo]Z00Oooo]Z00?oa_l0o`1Oool0Gol0
0_l0c?l3o`1Oo`03onGo0?oonf[ooo]Z00Wooo]Z1?l00009oookJP04o`2`ool0c?oo0<cooookJP?o
a_l02ooonfX2oonS00?o0;3o0_l0o``9ool000;o0?m/0_lMo`02o`3ooP;oo`380_m4o`02oo40o`03
oomi0?oonf[oo`3K00;o9_l000CoohH0o`3oo_l0ooko02go1?l0ooh2onGo00;ooo]Z00?oolT0ool0
3?oo00`00ooob@001?ook03o0?ono`3oo_l0ooh2oolX00;ooo]Z00?oobP0om[o0?oUo`000_oUo`00
0ol0oegoiOl0onGo0002onGo0003o`3oo_oo07?ooo]Z00;ooe<00_oc0?l01?oo0?3o0?oPo`3oh?l0
/?l4onGo0005o`3oGOoUo`3oiOl0onGo0?ooD@000_l0Eol2oeD0o`;ooah00_nDo`001_l0ojgoU?l0
oiCo0?nDo`3oo`2@ooWo00;o0?mM00[o05ooo`3oGOl0oego0?mMoolX0?l0ojgoobP0oookJ_oUo`3o
0;Ko0_mEo`02oookJP;oon801ooonfX00ooo08Goo`3boookJP02oookJP03ofl0oooo^P3ookX000;o
0?mP00?ooo]Zool0Iooo06L00ooonfX2ool0[a3ooo]Z0_l0o`U/oookJP;o0?l94?oonfX2ool0[`?o
oo]Z0_oo06L00ooonf[o0?mPo`3oH002oonj00;oK`3o0_oonfX2ool0lPOooo]Z0_oohP02oookJP;o
EOl000Coo`26o`3okol0onoooo]Z0_l0@_l2oookJP07oomd0?ooh`3oo`1AomGo0?oio`3oo`2@oook
JP02o`3o60?oob@000Oooo]ZoolN0?oonf[oE@3oo`3o=_l0Eooooe4000;ohol000Gooh`0ool0^?oo
0;Soo`03oookJP02o`3oD`05oookJ_l0on3o0?oPool0l?oc0?l00_ooD`000ooonf[oo`1cool0L`02
o`0go`04ool0cOoonf[o0?mIo`3oF@;o09;o00?of_l0ool0?_oo03h00ooonfX2ooo^0005oookJ_l0
obcoon`0oolN0?oo0@000_oo00`3oookJP06ool0[?oonf[ooo]ZoookJ_lTo`3oocP00_l0;Ol01Ooo
E03oohH0obKo0?lVo`3oo`3K00?ooo]Z00Gol@3ooookJ_l0B?oo04Soool0b002oolF00;o7Ol000?o
oo]Zo`3oK?oonfX00_ofo`03oookJP05o`2Noooonf[ooo]ZoookJ_l0/Ol00ooonfX2oonS00_ooo]Z
0_o6o`001?oonf[o0<coo`3<oooonfX2okh0o`cooo]Z1?l00009oookJP;o_P3o0_l0c?l00ooonf[o
a_l0olKo000<oookJP04oonS0?oonf[ooo]ZoookJP;o0;7o0ooonfX2o`2No`;ooo]Z0_ofo`02o`3o
K006oookJ_lMo`3ooo]ZoolF0?l0ob_oo`380_l0B?l01?oonf[ol@3ooookJ_oonfX2ool0f`04obKo
0?ooQP3oohH0oomD00;o02go00Co09goobCo0?oonf[ooo]Z0_oo0:`3oookJP;oo`0<00Goo`40oolN
0?ook03oon`0oookJP02ooo^00?ooo]Z0_oo03h01?oonf[o09;oo`3o9Ol0oeT2oookJP03ool0cOl0
=ooo03Oo00;oo`1c00Cooo]ZoomC0?ooD`3ol`3o0_oo0?001_l0on3ooo]Zo`3oDooo01_ooo]Zo`3o
T@;oo`2h00GoofP0on?o0?ooD@3ooe40o`1Go`02oeD0o`;ooah00_oonfX01?oo903ooo]Zo`3o6?oo
nfX2ool0T006o`3hoooo057oon<0oooS0?ooM03ooo]Z0_l0@_l01Ooo047ooo]Zo`3okol0onoo0;Ko
00;oEOl000?ooo]ZoooR0?oohP001ooonfX00ooo08Goo`3bool0lP02oookJP05ofl0oooonf[ookX0
o`2gool0of000_oonfX2ool0I`;ooo]Z0_oo0:lAoookJP;o0?l9=ooonfX003Oooo]Z00?o0?ono`3o
2Ol0o`T03_oonfX7o`3ooP03ool0Iol0/?oo0;3o00Co0;3o0_l0Gol01?oonf[o0?n]ool0l_oo0?82
o`3o[@;ooo]Z1Ol0/?l01_l0Gooo0?n]o`3o[Ol03ooo0?n]o`3ok`;o05oo0_l0@_l01?l0Gooo0?n]
oooS0?ooh`02o`3o[@;oo`2@00?ooo]Zo`3o6?l0oaP00_oo90001_oonf[ooah0o`3o3?l0o`co0;3o
o`3o30;ooe4000?ohol0ool00?oo00000_oo0;P2ool000;o0?n]0_l0on002?l03oool`3ooo<0oooo
D`3oo`00oookJ_oo07?oolD00_l0=ol2o`1Oo`06o`3oFOl0Gooo05ooo`1OoooJo`3oo`0n1?oonfX0
1?ookP3oU?l0oiCo0?l0ojd3oiCo0003ool03?l0A?oooo]Z00;ooo]Z00Goo`2/oookJ_oonf[ooo]Z
o`2Mo`03o`2`o`05oomD0?l03ooo00ooo`0?oooo0=/00_oonfX4o`3oG@CoiOl01?l0Gol01?oonf[o
m_l0oookJ_oonfX5o`3ooP03oookJ_l0/Ooo05oo00Ko05oo2_oonfX3o`1Oo`;o0<co0ol0Gol00ooU
o`3ooo]ZoookJP08oookJPCo00001_oonfX2okh0o`04o`2`ool0c?oo0<cooookJP;oa_l03?oonfX2
oonS00Go0;3o00?o0?l<ool00?oo00001_oo00000ooonf[o0?m/oookJP02oago00;o0?on0_oo0<P2
odCo00;ol@3o0_oonfX01Ooo0=_o9_l0obKo0?ooQP3o0?on00;o02go0ol0ooh2onGo0004ool0[?oo
nf[oolT0ooo900;oo`0<0_oob@000oook03o0?ono`3ooP02o`3ooPGoobP000Gof_l0onGo0?oUo`3o
iOl0o`3oG@04onGo00;oo`1c00Gooo]ZoomC0?ooD`3ol`3oool0l002o`3oh003o`2`ool0oe?oiOl0
00?oiOl000Oo0?mMonGo0?oUo`3oiOl0oomA0?l0Eooo0?lf00;oE@3o0_oo7P000onDo`3o0?n]oiCo
0002oiCo0003oookJ_oo093onOl000;o0?mM00?o05ooo`3oGOl0oed00_nDo`001_l0ojgoobP0oook
J_oUo`3o0;KooeGo00?ooo]Z00?oon80oookJ_oonfX01OoonfX00ooo08Goo`3bool0lP03oookJP03
ofl0oooo^P3o0;Oo00;o0?mP00?ooo]Zool0IooonfX00ooonfX2ool0[a3ooo]Z0_l0o`U/oookJP;o
0?l94?oonfX2ool0[`?ooo]Z0_oo06L00ooonf[o0?mPo`3oH002oonj00;oK`3o0_oonfX2ool0lP03
ool0QOoonf[ooo]Z00Cooo]Z0_oohP02oookJP;oEOl000Coo`26o`3okol0onoooo]Z0_l0@_l2oook
JP07oomd0?ooh`3oo`1AomGo0?oio`3oo`2@oookJP02o`3o6004oookJ_oo903oob@0oookJP;ooah0
00CoE@3oo`3o=_l0Eooooe400_oSo`001OooS03oo`2hool0^?l0oi7ooo]Z00;o0?mC00Gooo]Zo`3o
h?l0on3oo`3`oo<0o`02oomC0003oookJ_oo07?oo`1c00;o03Oo00Coo`3=oookJ_l0oeWo0?mI0_l0
T_l00ooJo`3oo`0nool0?P03oookJP;oonh000Gooo]Zo`3o;?ook03ooah0oh_o0002ool030?ooo]Z
0_oo0:`2oookJP05obCo0?l0WOoo02goo`0]ooooE0000_ooQP000olVo`3oo`3KoookJP02oookJP05
oo40oooonf[o04Soo`18oooo0<P00_oo5P001Ooonf[o7Ol0oookJ_l0ofcooo]Z00;om_l00ooonfX0
0ol0W_oooo]ZoookJP02oookJP04o`2aoooonf[ooo]ZoookJP;ooj<02ooonfX3olKo0003oookJ_l0
c?oo0<co00;o_P3o2ooonfX4o`0000Oooo]Z0_nn0?l2o`3<o`03oookJ_o6o`3oa_l000gooo]Z00?o
oj<0oookJ_oonfX00_oonfX01?l0/Ooooo]ZoookJ_oonfX2o`2No`?ooo]Z00Com_l0oookJ_l0ofco
0?m/0_lMo`001_oonf[ooaH0ool0b?oo0<So04SooookJP;ol@3o0_oonfX00ooo0=_o9_l0obKo0002
oon60005oomD0?l0;OooocP0o`2MoolTo`000_oonfX02?oo0:cooo]ZoookJ_oonf[o04Coool03?oo
0@3ooah00_ook0000olX0?ooonh0ooo^0004oookJP08ool0?_oJo`3o09;oo`2Booo00?oo0?mIoook
J_oo0<d2o`0go`05ooo50?oo07?oo`1coookJ_ooD`000_oc0?l00ooo0?3o0?oPo`3oh002o`3oD`07
oookJ_l0oi7o0?nAool0^?n@o`3oofP0on?o0002oomA0003o`3o=_mE0?ooE@3o00;ooah000Kooo]Z
oolT0?oo903ooo]Zo`3o6?oonfX2ool0T004o`3hoooo057oon<0oomd00;ooo]Z0_l0@_l01?oo047o
oo]Zo`3okooo08H2oeGo00;ooo]Z00?oon80oookJ_oonfX01_oonfX3ool0lP;ooo]Z00GoK`3ooonj
0?oo^P3o0;Ooo`3oH002oookJP04ool0Iooonf[ooo]ZoookJP;oo`2_4OoonfX00ol0o`Wooo]Zoook
JP0foookJP00=ooonfX00ol0ooko0?l9o`3o2@0=oookJPSo0?on00?oo`1Wo`2`ool0/?l01?l0/?l2
o`1Oo`04oookJ_l0ojgoo`3bool0lP?o0?n]00?ooo]Zo`2`ool0/?l00ol0/?l01?l0Gooo0?n]o`3o
[Ol03ol2o`3o[@;o05oo0_l0@_l01?l0Gooo0?n]oooS0?ooh`02o`3o[@;oo`2@00?ooo]Zo`3o6?l0
oaP00_oo9002oookJP;o0?l<00Go0;3oo`3o3?ooD@3ooe40on?o0002ool000;oo`2h0_oo0002o`3o
[@;o0?oP00?o00oooo<0oooc0?l00_ooD`000ooonf[oo`1cooo50002o`0go`;o05oo00?o0?mIo`1O
ool0Gol00_l0Gol00ooo03kooo]ZoookJP02oookJP04ooo^0?nDo`3oU?l0o`3o[@?oU?l00_oo00`3
oookJP;oo`2/0_oonfX01Ol0WOoo0;3oo`2`ool0/?oooe@000Co00oo0ooonfX7onGo00Co05oo00Co
0?mMoookJ_ofo`3ooo]Z1_l0ooh00ol0/Ooo05ooo`1Oo`05o`1Oo`03o`3oGOoonf[ooo]Z00Sooo]Z
1?l0Gol2o`3<o`;o05oo0_oUo`08oookJPCo00001?oonfX3okh0o`;o0<co00?ooo]ZolKo0?o6o`00
3OoonfX2oonS00Ko0;3o2?oo00000ooonf[o0?m/o`3oK002oago00?o0?on00?oo`38odCo0?m4o`00
0_oa0?l01_m4o`3ooo]Zool0fooo0=_o9_l0oon600;o0?on0_l0;Ol2o`3ooP;oiOl000OoolT0oook
J_l0o`co0?l<ooo90?oo00co0?l<00;oolT000?oon`0o`3oo_l0ooh00_l0ooh5oolX00?oiOl000?o
0?mMonGo0?oUo`000_oUo`001Ol0ookoo`1coookJ_oonf[ooe<000;ol`3o00Goo`3`o`3oh?l0on3o
oo]Zooo90004onGo0003o`3oGOoUo`3oiOl000;ooe4000Go05Ooo`3o=_mE0?oooo]ZoolN0002oiCo
0004o`0?oonDo`3oU?l0oiCo00?o05oo0_l0oed01Ol0Gooo0?mMoiCo0?nDo`3o0?n]00?oU?l000?o
iOl0o`2foomEo`000ooonfX00ooohP3ooo]ZoookJP05oookJP03ool0QOoo0?;oon@000;ooo]Z0_m_
0?l01_oo^P3o0?mPo`3oH?l0of3ooo]Zool0I`Cooo]Z00?oo`2_oookJ_oonfX03ooonfX2o`3o2Fco
oo]Z0_l0o`T@oookJP;oo`2_0ooonfX2ool0I`03oookJ_l0of3o0?mP00;ookX00_m_0?l2oookJP;o
o`3b00?oo`25oookJ_oonfX01?oonfX2oooR00;ooo]Z0_mEo`001?l0]_oo0?o_o`3okooonfX2o`12
o`;ooo]Z00Ooog@0oooS0?oo057oeOl0ooWo0?oo093ooo]Z00;o0?lH00Cooo]ZoolT0?oo903ooo]Z
0_oo7P001?mE0?oo0?lfo`1GooooD@02on?o0005oon<0?oo0;Soo`2ho`3oTOoonfX00_l0oe<02?oo
nf[o0?oPo`3oh?oo0?3ol`3ooookJ_ooD`3ooo]Z0_oo07<2o`0go`04ool0cOoonf[o0?mIo`3oF@;o
09;o00?of_l0ool0?_oo03h00ooonfX2ooo^0005oookJ_l0obcoon`0oolN0?n;o`000_oo00`4oook
JP05ool0[?oonf[ooo]ZobCo0?l0WOl00_l0;Ol01OooE03o00Oooon60?lVo`3oo`3K00?ooo]Z00Co
l@3ooookJ_l0B?oo04So0_oo0<P00ooo5P3ooo]Zoago0002oookJP04o`3oK?oonf[om_l0ooKo00?o
oo]Z00Go09kooookJ_oonf[ooo]Zo`2ao`03oookJP;ooj<03OoonfX2olKo0004oookJ_l0c?oo0<co
oookJP?o_P3o2?oonfX4o`0000Gooo]Z0_nn0?l3o`3<o`?oa_l03OoonfX2oonS00?ooo]Z0_l0/Ol3
oookJP06o`2Noooonf[ooo]ZoookJ_ofo`3ooo]Z0_l0of`01ooonf[o7Ol0oookJ_oo5P3o0?l[ool0
b?l0B?l00_oonfX03Ooa0?oooo]ZoookJ_oonf[oo`3KobKo0?oonf[oohH0oomD0?oonf[o02goo`2M
oolTo`000_oonfX2ool0[0?ooo]Z0_oo00`01Ooo0@3ooah0ooo/0?ook03o:03o00;oonh00ooonfX2
ool0?P03oookJ_l0T_oo09;o00;o0?mI00Cooo]Zool0cOl0=ooo03Oo0_oo07<00ooonf[ooe<0oomC
0002oo<0o`03ool0l?l0on3o0?oP00;o0?mC00Gooo]Zo`3oTOl0oi7oo`2hoon<0002on?o0006oomA
0?l0Eooo0?lfoeD0oooonf[ooah00_oonfX2oolT00;o0?lH00Oooo]Zool0T?oio`3oeOl0ool0DOoo
h`3oog@000;ooo]Z00?o04;oool0@Ooo04400_l0onl00ol0]_ooEOl0oeGo0002oookJP03oooR0?oo
nf[ooo]Z00Kooo]Z0_oo0?83oookJP03ofl0oooo^P3ookX000;o0?mP00?ooo]Zool0Iooo06L00ooo
nfX2ool0[a3ooo]Z0_l0o`ThoookJP00=ooonfX2o`3ooP03o`3o2Ooonf[ooo]Z00_ooo]Z2Ol0ooh6
o`2`o`;o05oo00Cooo]Zo`3o[Ooo0?;oo`3b0ol0ojd00ooonf[o0;3oo`2`o`03o`2`o`?o0?n]00?o
00ooo`3o[Ol0ojd00_l0Gol2o`12o`;o0?n]0_ooh`02o`3o[@03ooWo0?oo093ooo]Z00;o0?lH0_oo
9002oookJP;o0?l<00Go0;3oo`3o3?l0o`cooe40on?o0002ool000;oo`2h0_oo0002o`3o[@;o0?oP
00?o0?n]o`2`oooc0?l00_ooD`001Ooonf[oo`1cooo50?ooa@3o03Oo00;o05oo00?o0?mIo`1Oool0
Gol00_l0Gol2ool0?P?ooo]Z1onDo`02ool030?ooo]Z0_oo0:`2oookJP03o`2Mool0/?oo0;3o00;o
0;3o1?l03ol00ooo0=_ooo]ZoookJP08onGo00Co05oo00Cooo]ZooKo0?oonf[ooo]Z1Ol0ooh00ooo
nf[o05ooo`1Oo`06o`1Oo`03onGo0?oonf[ooo]Z00Oooo]Z1Ol0Gol3o`3<o`03o`1OoooUo`3oiOl0
00;o_P3o1OoonfX4o`000003okh0oooob@3oolT000?oolT00_l0c?l3olKo00gooo]Z0_ooX`000ooo
nf[o0;3oo`2`o`04o`2`o`Koo`000_ofo`02o`3oK0?o7Ol00_oo5P02ool0b0;oA?l00_oa0?l2oook
JP05ool0folVo`3o9_l0oon60?l0ooh00_l0;Ol2o`3ooP;o0?mM00?oolT0onGo0?oUo`000_l0o``0
1?oo00coiOl0o`3o3?oob@02ooo/00Co0?on0ooo:0000onDo`3oobP0onGo0002onGo0005o`3oGOoU
o`3oiOl0onGo0?l0ooh00_oo07<00ooob@3ooe<0oomC0002oo<0o`05ool0l?l0on3o0?oPoookJ_oo
b@000ooUo`001?l0oegoiOl0onGo0?oUo`02oomA0003o`1GoomE0?ooE@3o00;ooah00_nDo`001?l0
3oooU?l0oiCo0?oonfX7o`1Oo`;oU?l000Go0?n]oiCo0?nDo`3oU?l0ool0QP02oeGo00?ooo]Z00?o
on80oookJ_oonfX01OoonfX00ooo08Goo`3boookJP02oookJP03ofl0oooo^P3ookX000;o0?mP0_oo
nfX01?oo06Oooo]ZoookJ_oonfX2ool0[a7ooo]Z0_l0o`U/oookJP;o0?l94?oonfX2ool0[`?ooo]Z
0_oo06L00ooonf[o0?mPo`3oH002oonj00;oK`3o0_oonfX2ool0lP03ool0QOoonf[ooo]Z00Cooo]Z
0_oohP02oookJP;oEOl000Co0;Koo`3okol0onoooo]Z0_l0@_l2oookJP05oomd0?ooh`3oo`1AomGo
0?oio`000_oo0902o`3o6004oookJ_oo903oob@0oookJP;ooah000?oE@3oo`3o=_l0Eol00_ooD@00
1_oSo`3ooh`0ool0^?oo0;So0?nAoookJP;o0?mC00Oooo]Zo`3oh?l0on3oo`3`oo<0oooonf[ooe<0
00;ooo]Z00Coo`1cooo50?l0=oooo`3=0_oonfX01?l0oeWo09;oo`2BoooJo`02ool0?P?ooo]Z0_oo
kP001ooonf[o0?l/ooo/0?oo7P3oRol0ool10?oo00`01?oonfX01Ooo0:cooo]ZoookJ_lTo`3o09go
00;o02go0_ooE0001?ooQP3o9_l0ool0fooo0=/2oookJP;ol@3o00Kooo]Zo`18ool0B?ooo`38oolF
0?l0ob/2oago0003oookJ_l0ofcooo]Z00;om_l00ooonfX01?l0W_oooo]ZoookJ_oonfX2o`2ao`?o
oo]Z0_ooX`0=oookJP;oa_l000?ooo]Zo`3<ool0c?l00_l0c?l4okh0o`Gooo]Z1?l00005okh0o`?o
0<co00?ooo]ZolKo0?o6o`003_oonfX2oonS00?ooo]Z0_l0/Ol3oookJP04o`2Noooonf[ooo]Zoook
JP;om_l00ol0of`2oago00;ooaH00_oo0<P01?l0B?oooo]Zoo40oooa0?l2oookJP03ool0folVo`3o
9_l000;oohH000Gooe@0o`0]oooo>03o09goobCo0002oookJP;oo`2/0_oonfX02?l0A?ooo`0<ool1
0?oo0@3ooah0ooo/0?l0obcooo]Z0_ookP03oookJP;oo`0n00Cooo]Zo`2Bool0obGo0?mI0_oonfX0
0ooo0<go03Ooo`0go`02ool0L`04oookJ_ooD`3oo`3Goo<0o`;oo`3`00Ko0?oPoookJ_l0oe?oo`0K
oookJ_l0oi42ool0^005oomX0?oSo`3ooe40oomA0?l0Eol00_mE0?l2oolN00;ooo]Z0_oo9002o`3o
6004oookJ_oo093onOl0omGo00;oon<000Koog@0oookJ_oonf[o04;oool0@OoonfX2o`3ok`03o`2f
oomEo`3oEOl000;ooo]Z00?oon80oookJ_oonfX01OoonfX00ooo08Goo`3bool0lP02oookJP05ofl0
oooonf[ookX0oonj0?l0of000_oonfX2ool0I`?ooo]Z00?oo`2_oookJ_oonfX03ooonfX2o`3o2CSo
oo]Z000goookJP;o0?on00?o0?l9oookJ_oonfX02ooonfX4o`3ooP05odCo0?oonf[ooo]ZoookJ_oo
06L01ol0/?l00ol0Gooooo]Zo`3o[@02ool0lP?o0?n]0ooonfX2o`3o3005o`2`ool0ojgo0?n]o`3o
[Ol03ol00_l0ojd2o`3oG@;o04;o0_l0ojd2oooS00;o0?n]00?onOl0ool0T?oonfX00_l0oaP2oolT
00;ooo]Z0_l0o``01?l0/?oo0?l<o`3o3?ooD@03ool000;oo`2h0_oo0002oiCo00;o0?oP00?oU?l0
o`2`oooc0?l00_ooD`001Ooonf[oo`1cool0Loooa@3o03Oo00;o05oo0_l0oeT3o`1Oo`;oo`0n0ooo
nfX8oiCo0004ool03?oonf[ooo]ZoookJP;oo`2/0_oonfX00olTo`3o0;3oo`2`o`03o`2`o`Co00oo
0_oonfX5onGo0003ool0b?l0Gooo05oo00Go0?mM0_ofo`000ooonf[o0?ono`3ooP04o`3ooPGo05oo
1?l0oed9oookJPOo05oo00?o0<coo`2`ool0/?l03ol0/?l01?l0o`coolT0ooo90?oonfX2olKo00_o
oo]Z0_oob@001?oonf[ooj<0oonS0?oonfX6o`2`o`Goo`000_oonfX01?ofo`3ooo]Zo`3oK?oonfX2
oago0004o`3oo_oo5P3oo`38ool0b0;o0?on00GoA?l0oo40oooonf[ooo]Zool0f`02obKo00;o05oo
00?o0?ono`0]ool0ooh00_l0ooh3o`3oG@CoiOl000Koo`0<onGo0?l0o`co0?l<ooo/0?l0ob`3o`3o
oP04oookJ_oo:03oobP0oolX00;o0?mM0ooUo`001Ol0oegoiOl0onGo0?oUo`3o0?on00;oo`1c00Go
olT0oomC0?ooD`3ol`3oool0l002o`3oh003oookJ_l0oe?oolT000?oiOl000Oo0?mMonGo0?oUo`3o
iOl0oomA0?l0Eooo0?lf00;oE@3o0_oo7P001_l0ojgo00ooo`3o[OnDo`3o0?lHoookJPWo05oo00Ko
0?n]oiCo0?nDo`3oiOl0o`2foomEo`03oookJP03oooR0?oonf[ooo]Z00Kooo]Z00?oo`25ool0l_oo
nfX00_oonfX00om_0?oookX0oonj0002o`3oH003oookJ_oo06Ooo`1W00?ooo]Z0_oo0:l@oookJP?o
0?l9K?oonfX2o`3o2A3ooo]Z0_oo0:l3oookJP;oo`1W00?ooo]Zo`3oH?l0of000_oo^P02ofl0o`;o
oo]Z0_oo0?800ooo08Gooo]ZoookJP05oookJP;oon8000Cooo]ZoeGo0?mEo`3o0;Ko0_l0onl00ooo
nf[o04;oo`12o`02oookJP05oomd0?ooh`3oo`1AomGo0?oio`000_oo0902o`3o6004oookJ_oo903o
ob@0oookJP;ooah000?oE@3ooookJ_l0Eol00_ooD@001_oSo`3ooh`0ool0^?oo0;So0?nAoookJP;o
0?mC00Oooo]Zo`3oh?l0on3oo`3`oo<0oooonf[ooe<000;ooo]Z00Coo`1cooo50?l0=ooo03Oo0_oo
nfX00ol0oeWo09;oo`2Bo`02om[o0003ool0?_oonf[ooo]Z00;ooo]Z00?oonh0oookJ_lX0?l00_oo
k0001?n;o`3oo`40ool03?oo00`3oookJP06ool0[?oonf[ooo]ZobCo0?l0WOooocP00_l0;Ol01Ooo
E03oohH0obKo0?lVo`3oo`3K00?ooo]Z00Gol@3ooookJ_l0B?oo04Soool0b002oolF0003oookJ_lM
o`3ooo]Z00;o0?m/0_ofo`03oookJP;o09ko0ooonfX00ol0/Ooooo]ZoookJP02oookJP03oonS0?oo
nf[ooo]Z00gooo]Z0_o6o`000ooonf[o0<coo`3<o`02o`3<o`go_P3o00Gooo]Zo`3<ool0c?oo0<co
oookJP02olKo00oooo]Z0_ooX`04oookJP04o`2aoooonf[ooo]ZoookJP;o09ko0ooonfX02oofo`3o
oo]Zo`3oK?l0ofcooo]Zoago0?oonf[ooaH0o`3o:ooo0<So04So00;ooo]Z00Kol@3ooookJ_oonf[o
oo]Zool0folVo`02oon60005oomD0?l0;Ooo02goo`2MoolTo`000_oonfX2ool0[0?ooo]Z0_oo00`0
1Ooo0@3ooah0ooo/0?ook03o:03o00;oonh01?oonfX01?oo03kof_l0o`2Bool0T_l2o`3oF@06oook
J_oo0<go03Ooo`0gooooa@3oo`1c0_oonfX01?ooD`3ol`3ooo<0oooo0?02o`3oh0;o0?mC00?ooo]Z
ool00ol0oi400_oo0;P01OooJ03ohol0oomA0?ooD@3o05Oo00;oE@3o0_oo7P001?oonf[oob@0oolT
0?oonfX2o`3o60;oo`2@00?onOl0ool0DOooh`000_ooM0001Ooonf[o04;oo`12oooo047ooo]Z00;o
0?o_0_mEo`02oookJP;oon801ooonfX00ooo08Goo`3bool0lP02oookJP05ofl0oooo^P3ookX0oonj
0?l0of000_oonfX2ool0I`;ooo]Z0_oo0:lAoookJP;o0?l9>?oonfX003Oooo]Z0_l0ooh@oookJP04
odCo0?l0ookoA?l0odCo00;ooo]Z00?oo`1Wo`2`ool0/?l01Ol0/?l2o`1Oo`03o`3o[Ooo0?;oo`3b
00?o0?n]0ooonfX2o`3o3005o`2`ool0ojgo0?n]o`3o[Ol03ol00ol0ojd00ol0oego04;oo`12o`02
o`3o[@07ooo90?ooh`3o0?n]o`3o[Ooio`3oo`2@oookJP02o`3o60;oob@000Gooo]Zo`3o3?l0o`co
0?l<o`2`o`02o`3o3004oomA0?oo003oo`00ool000;oo`2h0ooo00001?nDo`3o0?oPo`3oh?nDo`02
o`2`o`;ooe<000Co05ooool0Looo07?oolD00ol0Gol2o`3oF@Co05oo00Coo`0noookJ_oonf[ooo]Z
2?nDo`001?oo00cooo]ZoookJ_oonfX2ool0[0?ooo]Z1Ol0/?l4o`0?o`;ooo]Z0_oUo`02o`3o[@;o
o`381ol0oed00ooonf[om_l0oookJP06o`3ooP;o05oo2?l0oed8oookJPGo05oo0ol0oed2onGo00oo
0;3o00Co0?l<ooo90?oob@3oa_l02ooonfX2o`3o30;oolT000Cooj<0oookJ_oonf[ooo]Z1_l0/?l4
ool000;ooo]Z00[om_l0oookJ_l0ofco0?m/oago0?oonf[o7Ol0oolF0?l0ookoo`380ol0ooh2oo40
o`;ooo]Z00?oo`3KobKo0?lVo`000_l0Gol01?l0ooko02goo`3oo_l0ooh3o`3oG@03oolX0?oUo`3o
iOl000?oiOl00ol0o``00oook03o0?l<o`3ooP02o`3ooP?oobP000?oU?l0o`3oGOl0oed00ol0oed3
onGo00;o0?on00Coo`1coookJ_oob@3ooe<00_oc0?l01_oo0?3o0?oPo`3oh?oonf[o0?mCooo900;o
iOl000Co0?mMonGo0?oUo`3oiOl00_ooD@001Ol0Eooo0?lfoeD0oomE0?oooah000;o0?n]00Go00oo
o`3o[Ol0ojgo0?n]ool0T009o`1Oo`?oU?l000?oiOl0o`2foomEo`000ooonfX00ooohP3ooo]Zoook
JP05oookJP03ool0QOoo0?;oo`3b00;ooo]Z0_m_0?l2oonj00;o0?mP00?ooo]Zool0Iooo06L00ooo
nfX00ooo0:oooo]ZoookJP0?oookJP;o0?l9KOoonfX00ol0o`Wooo]ZoookJP0@oookJP04ool0[ooo
nf[ooo]ZoookJP;oo`1W00?ooo]Zo`3oH?l0of000_oo^P02ofl0o`;ooo]Z0_oo0?800ooo08Gooo]Z
oookJP05oookJP;oon8000Cooo]ZoeGo0?mEo`3o0;Ko0_l0onl00ooonf[o04;oo`12o`02oookJP05
oomd0?ooh`3oon<0omGo0?oio`000_oo09000ooonf[o0?lHoookJP02oolT0003oookJ_oo7P3ooah0
00;oE@3o00Go05OooomA0?ooD@3ohol0oomX0002ool0^005o`3oTOoonf[o0?mCo`3oDooonfX00_l0
on001?oo0?3ol`3ooo<0ooooD`02oookJP04ool0Loooa@3o03Ooo`0go`;ooo]Z00Ko0?mIo`3o9Ol0
T_oooo]Zom[o0?oo03h4oookJP07ooo^0?oonf[o:03oo`3o;?ook03ooah0ool10002ool030?ooo]Z
00Koo`2/oookJ_oonf[ooo]ZobCo0?l0WOl2o`0]o`05oomD0?ooQP3ooo]ZobKo0?oo0=/00ooonfX0
1?oa0?oooo]Zo`18ool0B?l2ool0b003oolF0?oonf[o7Ol000;ooo]Z00Co0?m/oookJ_ofo`3om_l0
0ooonfX01?l0W_oooo]ZoookJ_oonfX2o`2ao`?ooo]Z0_ooX`0?oookJPCoa_l000?ooo]Zo`3<ool0
c?l01?l0c?l2oookJP;o00001Ol0c?l00ooonf[oa_l0olKo0002olKo00kooo]Z0_ooX`05oookJP04
o`2aoooonf[ooo]ZoookJP;o09ko0ooonfX00oofo`3ooo]Zo`3oK002o`3oK0;o7Ol000?ooaH0o`3o
:ooo0<P00_l0B?l00ooonf[ol@3ooo40o`02oookJP03ool0folVo`3o9_l000;oohH000Gooe@0o`0]
ool0;Ooo09goobCo0002oookJP;oo`2/0ooonfX2ool03005ool10?oo7P3oon`0ooo/0?oonfX00_oo
kP03oookJP;oo`0n00?ooo]Zo`2Bool0T_l00_l0oeT01?oonf[oo`3=o`0gool0=ol2ool0L`06oook
J_ooD`3ooe<0oo<0oooo0=Ooo`3`0_l0on02o`3oD`05oookJ_l0oi7oo`2hool0^?ooS0000_oSo`00
0oooD@3o05Ooo`3o=P02oeD0o`03oolN0?oonf[ooo]Z00;oob@00_l0oaP01_oonf[oo`2@ooWo0?oE
o`3oo`1AoooS00;oog@000Cooo]Zo`12ool0@_ooo`110ol0onl2oeGo00;ooo]Z00?oon80oookJ_oo
nfX01_oonfX3ool0lP;ooo]Z00KoK`3ooonj0?oo^P3o0;Ooo`3oH?oonfX2ool0I`?ooo]Z0_oo0:lA
oookJP03o`3o2Ooonf[ooo]Z03Oooo]Z000foookJPCo0?on3ooonfX01?m4o`3o0?onodCo0?m4o`02
oookJPSo0;3o0_l0Gol00ol0ojgoo`3bool0lP04o`3o[@;ooo]Z0_l0o``01Ol0/?oo0?n]o`3o[Ol0
ojgo00oo00?o0?n]00co0?mMo`12ool0@_oo0?mMoookJ_oob@3oon<0o`3o[OnDo`3onOl0ool0T?oo
nfX2o`3o60;oob@000Gooo]Zo`3o3?l0o`co0?l<o`2`o`02o`3o3004oomA0?l0o`coo`00ool000;o
o`2h0ooo0002oiCo00;o0?oP0_l0/?l2oomC0004o`1Ooooo07?oo`1cooo500?o05oo0_l0oeT4o`1O
o`04ool0?_oonf[ooo]ZoookJPGoU?l00ooo:0000ooo00cooo]ZoookJP02oookJP04ool0[?oonf[o
oo]ZoookJPKo0;3o1?l03ol2oookJP;ol@3o0_nDo`000ooo0<So0?mMo`3oG@06o`3oG@Wo0?on00?o
oo]Zo`3oGOl0oed00ol0oed4onGo00Sooo]Z0ol0Gol3o`3oG@;oiOl00ol0ooh=o`2`o`03o`3o3?oo
b@3oolT000_ooo]Z0ol0o``3ooo900;ooo]Z1_l0/?l4ool00007oolX0?oonf[om_l0ooKo0?oonf[o
0?m/oookJP02oago0004o`3o:ooo5P3oo`38ool0b0;o0?on0_oa0?l00ol0ookooo]Zool0f`02obKo
0004oon60?l0Gooo05ooo`0]o`;o0?on1?l0oed8onGo00;oon`000?o0?l<o`3oo_l0ooh00_nDo`02
oolX0003oiCo0?l0oego0?mM00Go0?mM0_l0ooh2ool0L`04oookJ_ooD`3ooe<0oo<0o`;oo`3`00?o
0?oPolX0oooob@000_l0oed2onGo0004o`1OoooUo`3oiOl0onGo00;ooe4000?o05OooeD0oomE0?l0
0_oo7P02o`3o[@05o`0?ool0ojgo0?n]o`3o[Ooo09002?l0Gol01Ol03oooU?l0oiCo0?oUo`3o0?o_
00;oEOl00ooonfX00ooohP3ooo]ZoookJP05oookJP03ool0QOoo0?;ooo]Z00;ooo]Z00?oK`3ooonj
0?oo^P000ol0of000ooonf[oo`1WoookJP02oookJP;oo`2_4OoonfX2o`3o2Fgooo]Z00?o0?l9oook
J_oonfX04?oonfX2ool0[`;ooo]Z0_oo06L00ooonf[o0?mPo`3oH002oonj00;oK`3o0_oonfX2ool0
lP03ool0QOoonf[ooo]Z00Gooo]Z0_oohP001?oonf[oEOl0oeGo0?l0]_l2o`3ok`03oookJ_l0@_oo
04;o00;ooo]Z00?oog@0oooS0?ooh`000_oEo`02ool0T003oookJ_l0oaSooo]Z00;oob@000?ooo]Z
oolN0?oo7P000_mE0?l01Ol0Eooooe40oomA0?oSo`3oofP000;oo`2h00So0?nAoookJ_oonf[o0?mC
oookJ_o:0?oo0?oPool0l0;ol`3o00Gooe<0oookJ_oonf[oo`1cooo50002o`0go`;ooo]Z00Ko0?mI
ol00ool0T_oo09;oom[o0?oo03h4oookJP07ooo^0?oonf[o:03oo`3o;?ook03ooah0oookJP02ool0
30?ooo]Z0_oo0:`2oookJP05obCo0?l0WOoo02goo`0]ooooE0000_ooQP000olVo`3oo`3Kool0f`02
oookJP;ol@3o00Kooo]Zo`18ool0B?ooo`38oolF0?l0ob/2oago0003oookJ_l0ofcooo]Z00;om_l0
0ooonfX2o`2No`?ooo]Z0_l0/Ol3oookJP;ooj<04?oonfX6olKo00Wo0<co1_o6o`0?oookJP;ooj<0
1?oonfX2o`2ao`?ooo]Z0_l0W_l3oookJP;om_l000?ooo]Zo`3oK?l0of`00_lMo`001_oonf[ooaH0
ool0b?oo0<So04SooookJP;ol@3o0ooonfX01Ooo0=_o9_l0oon60?ooQP3ooe@000;o02go00?o09go
obCo0?oonfX00_oonfX01?oo0:cooo]ZoookJ_oonfX2ool03007ool10?oo7P3ooah0ooo/0?l0obco
oo]Zooo^0004oookJP06ool0?_oJo`3ooo]Zo`2Booo00?oo0?mI0_oonfX00ooo0<go03Ooooo50002
ool0L`04oookJ_ooD`3ol`3ooo<0o`;oo`3`00Ko0?oPoookJ_l0oe?oo`0KoookJ_l0oi42ool0^007
oon<0?oSo`3ooe40oomA0?l0Eooo0?lfoeD0o`02oolN00;ooo]Z0_oo9002o`3o6004oookJ_oo093o
nOl0omGo00;oon<000Koog@0oookJ_oonf[o04;oool0@OoonfX2o`3ok`03o`2foomEo`3oEOl000;o
oo]Z00?oon80oookJ_oonfX01OoonfX00ooo08Goo`3bool0lP02oookJP;oK`3o0_oo^P02o`3oH003
oookJ_oo06Ooo`1W00?ooo]Z00?oo`2_oookJ_oonfX03ooonfX2o`3o2CWooo]Z000foookJPCo0?on
3ooonfX2odCo0004o`3oo_m4o`3ooo]ZoookJPWo0;3o0_l0ojd2ool0lPCo0?n]0_oonfX2o`3o3005
o`2`ool0ojgo0?n]o`3o[Ol03ol00ol0ojd03?l0oego04;oo`12ool0oegooo]Zooo90?ooh`3o0?n]
oiCo0?oio`3oo`2@oookJP;o0?lH00?ooo]ZoolT0?oonfX00ol0o``01ol0/?oo0?l<o`3o3?ooD@3o
0?l<on?o0?ooJ0000_oo0;P00ol0ookoobP0oolX0002oiCo00;o0?oP0ol0/?l01OooD`3o05ooo`2`
oooo07?oolD000?o05oo0_l0oeT01Ol0Gooo0?mMo`3oGOoJo`3oo`0n00Cooo]Z00Coonh0oolX0?oo
:03oU?l00ooo:002ool030?ooo]Z0_oo0:`2oookJPKo0;3o1?l03ol2oookJP;ol@3o0_nDo`02ool0
b0;o0?mM1OoUo`0:o`3ooP;o0?mM2?oUo`07oookJP04o`1Oool0oego0?mMo`3oG@?oiOl01Ol0ooh;
o`2`o`;o0?l<0_oob@0:oookJP;o0;3o0ol0o``2ooo90003oookJ_l0/?oo0;3o00Go0;3o0_oo0004
oolX0004ooKo0?oonf[o0?m/oookJP;o7Ol000Cooo]ZoolF0?oo0<Soo`380ol0ooh01Ooa0?oooo]Z
oookJ_oonf[oo`3K00;o9_l00_l0Gol00ol0ooko02goo`3ooP03o`1Oo`03o`3oGOl0o`coiOl000So
iOl000Co0?l<oookJ_l0ookooo]Z1?nDo`000ooo:03o0?mMo`3oG@02o`3oG@06o`1Oool0oego0?mM
o`3oGOl0ookoo`1c0_oonfX2oomC0006oo<0oooo0?3o0?oPo`3oh?oob@3o0?mC1?l0oed01ol0Gooo
iOl0onGo0?oob@3ooe40o`1Gool0ocH00_mE0?l01?oo7P3o0?n]o`3o[Ol03ol3o`3o[@;oo`2@1ol0
Gol01_nDo`3o00oooiCo0?nDo`3o0?mMo`2fo`;oEOl00_oonfX2oooR00Oooo]Z00?oo`25ool0l_oo
nfX00_oonfX00om_0?oookX0oonj0002o`3oH003oookJ_oo06Ooo`1W00?ooo]Z0_oo0:lAoookJP;o
0?l9KOoonfX00ol0o`Wooo]ZoookJP0@oookJP;oo`2_0_oonfX2ool0I`05oookJ_l0of3o0?mPo`2g
oooo^P000_m_0?l2oookJP;oo`3b00?oo`25oookJ_oonfX01OoonfX2oooR0004oookJ_mEo`3oEOl0
o`2fo`;o0?o_00?ooo]Zo`12ool0@_l00ooonfX2oooS00;oeOl00_oo09000ooonf[o0?lHoookJP02
oolT0003oookJ_oo7P3ooah000;oE@3o01;o05OooomA0?ooD@3ohol0oomX0?ooS03oo`2ho`3oTOoo
00?ooo]Zo`3oDooonf[obP3oo`3oh?oo0?3oo`3Goo<0ooooD`02oookJP04ool0Loooa@3o03Ooo`0g
o`;ooo]Z00Ko0?mIol00ool0T_oo09;oom[o0?oo03h4oookJP;oonh000Go:03oo`3o;?ook03ooah0
oookJP02ool030Cooo]Z00Goo`2/oookJ_oonf[o9?l0o`2Mo`02o`0]o`;ooe@000CoohH0obKo0?lV
o`3oo`3K0_oonfX2oo40o`04oookJ_l0B?oo04Soool0b0;ooaH000?ooo]Zoago0?lMo`000_l0of`0
0ooonf[om_l0ooKo0003oookJP03o`2Noooonf[ooo]Z00;ooo]Z00?o0;7ooookJ_oonfX00_oonfX3
oonS017ooo]Z3oo6o`0@oookJP?ooj<01?oonfX2o`2ao`?ooo]Z0_l0W_l3oookJP;om_l000?ooo]Z
o`3oK?l0of`00_lMo`001?oonf[ooaH0o`3o:ooo0<P2o`18o`03oookJ_oa0?oooo]Z00;ooo]Z00Co
o`3KobKo0?lVo`3oohH00_ooE002o`0]o`04o`2MoolTo`3ooo]ZoookJP;oo`2/0ooonfX2ool03005
ool10?oo7P3oon`0ooo/0?oonfX00_ookP03oookJP;oo`0n00?of_l0o`2Bool0T_l00_l0oeT01?oo
nf[oo`3=o`0gool0=ol2ool0L`;ooo]Z00Cooe<0oo<0oooc0?ooo`3`0_l0on02o`3oD`03oookJ_oo
00?o0?nA00;oo`2h00?oofP0on?o0?ooD@000_l0Eol2oeD0o`03oolN0?oonf[ooo]Z00;oob@000?o
oo]Zo`3o6?l0oaP00_oo09001Ooio`3oeOl0oooS0?ooh`3oog@000;ooo]Z00?o04;oool0@OoonfX0
0_l0onl2oeGo00;ooo]Z0_oohP07oookJP03ool0QOoo0?;oo`3b00;ooo]Z00GoK`3ooookJ_oo^P3o
okX0o`3oH002oookJP;oo`1W0ooonfX00ooo0:oooo]ZoookJP0?oookJP;o0?l9>OoonfX003Kooo]Z
1?l0ooh?oookJP;oA?l000Co0?onodCo0?m4o`3ooo]Z2Ol0/?l2o`3o[@;oo`3b00?oU?l0oookJ_oo
nfX00ooonfX2o`3o30Co0?n]00?o00ooo`3o[Ol0ojd00_l0ojd02ol0oego04;oo`3oGOoonf[oolT0
oooS0?l0ojgoU?l0ooWo0?oo093ooo]Z00;o0?lH00?ooo]ZoolT0?oonfX00ol0o``01ol0/?ooolT0
ooo90?ooD@3oiOl0on?o0?ooJ0000_oo0;P3oolX00;oU?l00_l0on03o`2`o`05oomC0?l0Gooo0;3o
ool0Loooa@000_l0=ol01?l0oego0?mIo`3oFOl0Gol2o`3oG@03om[o0?oo03kooo]Z00?ooo]Z00?o
onh0oolX0?oo:0001?oo:002ool030?ooo]Z0_oo0:`2oookJPOo0;3o1?l03ol2oookJP05oo40oonD
o`3oU?l0oiCo0?oo0<P01ooUo`000ooonf[o0?ono`3ooP05o`3ooP;oA?l000?ooo]Zo`1OoooUo`00
1OoUo`000oooX`3ooo]ZoookJP08oookJP04o`3oGOoUo`3oiOl0onGo00So0?on2Ol0/?l00ol0o`co
olT0ooo9000:oookJP?o0;3o0ol0o``3ooo900Go0;3o00Cooo]Zo`2Noooo003oU?l01Ooo:002o`3o
K0;o7Ol000?ooo]ZoolF0?oo5P000_oo0<P2o`3ooP;ol@3o0_oonfX01?oo0=_o9_l0obKo0?oo0002
o`1Oo`03o`0]ool0ooko05oo00Co05oo0_l0oed2onGo0003o`3oGOoUo`3oiOl000;oiOl000Goon`0
oookJ_ookP3oonh0oookJP05oiCo00Co0?mM00Co05ooo`3oGOl0oego0?mM0_oo07<00ooonf[oolT0
oomC0002oo<0o`05ool0l?l0on3obP3oooo90?l0oe<00ol0oed01?l0Gooo0?mMo`3oGOl0oed2oomA
0005o`1GoomE0?ooE@3ooookJ_oo7P000_l0ojd01?l03ooo0?n]o`3o[OoonfX2ool0T0Oo05oo00Oo
00oooiCo0?nDo`3ooo]Zo`3oGOl0]_ooEOl000?ooo]Z00?oon80oookJ_oonfX01OoonfX00ooo08Go
o`3bool0lP02oookJP;oK`3o0_oo^P02o`3oH003oookJ_oo06Ooo`1W00?ooo]Z0_oo0:l@oookJP;o
0?l9K_oonfX2o`3o2A7ooo]Z0_oo0:l3oookJP08ool0Iooonf[o0?mPo`3oH?l0]ooookX0oookJ_m_
0?l2oookJP03oooT0?oo0?;oo`2500Oooo]Z0_oohP02oookJP07oeGo0?l0]_oo0?o_o`3okooonf[o
o`11o`12o`03oookJP;oon<000Oooo]ZomGo0?oo093oo`2@oookJ_l0oaSooo]Z00;oob@00_oonfX0
1?oo7P3oE@3ooeD0ool0Eol2oomA0004on?o0?ooJ03ooh`0ool0^0;o0?nA00Sooo]Zo`3oDol0oe?o
oo]Zo`3oh?oo0?3oo`3Goo<0o`;ooe<000?ooo]Zool0Looo07<00_l0=ol01?oo0<gooo]Zo`3oFOl0
oeT2o`2Bo`03om[o0?oo03koo`0n00?ooo]Z0_ookP001ooonf[o0?l/ooo/0?oo7P3oRol0ool10?oo
00`01?oonfX01ooo0:cooo]ZoookJ_lTo`3o09gooolh0?l0;Ol00_ooE0001?ooQP3o9_l0obKo0?oo
0=/3oookJP04oo40oooonf[ooo]Zo`18o`;oo`3800GooaH0oookJ_lMo`3o7Ol0oookJP02o`3oK0;o
m_l01?oonfX00ol0W_oooo]ZoookJP02oookJP03o`2aoooonf[ooo]Z00?ooo]Z0_ooX`0DoookJPOo
a_l000?o0000oookJ_oonfX04?oonfX3oonS00Cooo]Z0_l0/Ol3oookJP;o09ko1?oonfX01Oofo`3o
oo]Zo`3oK?l0ofcooo]Z00;o7Ol00_oo5P02ool0b004o`18oooonf[ol@3ooo40o`;ooo]Z00?oo`3K
obKo0?lVo`000_ooQP001OooE03o02goo`0]ool0WOoo9?l000?ooo]Z00Goo`2/oookJ_oonf[ooo]Z
o`14o`02ool03005ool10?oo7P3oon`0obP0oooonfX00_ookP03oookJP;oo`0n00?ooo]Zo`2Bool0
T_l00_l0oeT01?oonf[oo`3=o`0gooooa@02ool0L`0<oookJ_ooD`3ooe<0oo<0ooooX@3oo`3`o`3o
h?oonf[o0?mCool06ooonf[o0?nA0_oo0;P01?ooS03ohol0on?o0?ooD@02o`1Go`;oE@3o00?ooah0
oookJ_oonfX00_oo9002o`3o6006oookJ_oo093onOl0omGo0?oo057oon<00_ooM0001Ooonf[o04;o
o`12oooo047ooo]Z00;o0?o_0_mEo`02oookJP03oooR0?oonf[ooo]Z00Kooo]Z0ooo0?82oookJP05
ofl0oooo^P3ookX0oonj0?l0of000_oonfX2ool0I`;ooo]Z0_oo0:lAoookJP;o0?l9>OoonfX003Ko
oo]Z1Ol0ooh>oookJP;oA?l000Co0?onodCo0?m4o`3ooo]Z0_oo06L01ooonf[o0?l<o`2`ool0oego
05ooo`3oGOm_0?l00_oonfX2ool0lP03o`3o[Ooonf[ooo]Z00?ooo]Z0_l0o``4o`3o[@03o`0?ool0
ojgo0?n]00;o0?n]00_o0?mMo`12ool0oego0?mMooo90?ooh`3o0?n]oiCo0?oio`3oo`2@oookJP02
o`3o6004oookJ_oo903oob@0oookJP;oolT000?o0;3oooo90?oob@000_ooD@001?oSo`3oofP0ool0
^?oo0;P3oolX00;oU?l00_l0on04o`2`o`04oomC0?l0/?oo0;3oooo500;o03Oo00Co0?mMo`3oFOl0
oeWo05oo0ol0oed2ool0?P?ooo]Z00?oonh0oolX0?oo:0001Ooo:0000ooo00cooo]ZoookJP02oook
JP03ool0[?oonf[ooo]Z00Oo0;3o1?l03ol01_l0/?oooo]Zoo40oooa0?ooU?l0oolX00;oo`381ooU
o`04o`3ooPKoA?l000Go05ooonGo0?oUo`3oiOl0o`1Oo`02oookJP;ooj<02ooonfX00ooUo`3ooo]Z
oookJP09o`3ooPOo0;3o00?o0?l<ooo90?oob@002?oonfX5o`2`o`Co0?l<0_oob@000ol0/?ooobP0
o`2`o`02oookJP03o`2Noooo003oU?l000;oU?l01Ooo:0000ooonf[o7Ol0oookJP02oolF00;oo`38
0_l0ooh2oo40o`;ooo]Z0_oo0=/01?lVo`3oo`00ool00?l0Gol2o`0]o`Go05oo00Ko0?l<o`3oGOl0
oego0?mMonGo0?l0oed3onGo00;oon`000?ooo]Zooo^0?oonfX00onDo`000ol0ojgoU?l0o`3oG@03
o`3oG@05o`1Oool0oego0?mMo`3oGOl0=ol00_oo07<01?oonf[ooe<0oomC0?oc0?l2ool0l004o`3o
h?o:0?oo0?mCo`3oD`?o0?mM00Oo05ooo`3oGOl0oego0?mMoomA0?l0Eooo0?lf00;oE@3o0_oo7P00
0ol0ojgo00ooo`3o[@02o`3o[@03oookJ_oo093oo`2@00Ko05oo00SoU?l0o`0?oonDo`3oU?l0o`3o
GOl0onoo0;KooeGo00?ooo]Z00?oon80oookJ_oonfX01OoonfX00ooo08Goo`3bool0lP02oookJP04
ofl0oooo^P3ookX0o`2go`;o0?mP00?ooo]Zool0IooonfX00ooonfX00ooo0:oooo]ZoookJP0?oook
JP;o0?l9K_oonfX2o`3o2A7ooo]Z0_oo0:l3oookJP08ool0Iooonf[o0?mPo`3oH?l0]ooookX0oook
J_m_0?l2oookJP03oooT0?oo0?;oo`2500Oooo]Z0_oohP02oookJP;oEOl000Coo`26o`3okooonf[o
o`110_l0@_l2oookJP;oon<000Kooo]ZomGo0?oo093oo`2@oookJ_l0oaP2oookJP04oolT0?oonf[o
oo]ZoolN00;oE@3o0_l0Eol02?ooD@3ohol0oomX0?ooS03oo`2hoi3o0?l0oi7ooo]Z0_l0oe<02?oo
nf[o0?oPool0l?ooX@3ol`3ooookJ_ooD`3ooo]Z0_oo07<2o`0go`04ool0cOoonf[o0?mIo`3oF@;o
09;o00?of_l0ool0?_oo03h01?oonfX00oookP3ooo]ZobP0o`02ooo/0004oh_o0?oo0@3oo`0<ool0
30?ooo]Z0_oo0:`2oookJP;o09go0_l0;Ol01?ooE03oohH0oon60?lVo`02ool0f`;ooo]Z0_oa0?l0
1?oonf[o04Soo`18oooo0<P2oolF0003oookJ_lMo`3o7Ol000;o0?m/00?ooo]ZooKo0?ofo`000ooo
nfX2o`2No`Cooo]Z00?o0;7ooookJ_oonfX00ooonfX2oonS01Oooo]Z1?l0000AoookJP?ooj<01?oo
nfX2o`2ao`?ooo]Z0_l0W_l4oookJP05ooKo0?oonf[ooo]Zo`3oK?oonfX00_lMo`001_oonf[ooaH0
ool0b?oo0<So04SooookJP;ol@3o0ooonfX01?oo0=_o9_l0obKo0?ooQP02oomD0003o`0]ool0WOoo
09go00?ooo]Z0_oo0:`3oookJP;oo`0<00Goo`40oolN0?ook03oon`0oookJP02ooo^00Cooo]Z00Co
o`0nom[o0?l0T_oo09;o0_l0oeT2oookJP04ool0cOl0=oooolD0ool0L`;ooo]Z00Kooe<0oo<0oooc
0?ooo`3`olX0ool0on02o`3oD`03oookJ_oo00?o0?nA00;oo`2h00Oooh`0on?o0?ooD@3ooe40o`1G
oooonf[oE@3o00;ooah00_oonfX02?oo903ooo]Zo`3o6?l0oaSooo]Zool0T?oio`3oeOl00_ooh`00
1_ooM03ooo]ZoookJ_l0@_ooo`11oookJP?o0?o_0_mEo`02oookJP03oooR0?oonf[ooo]Z00Kooo]Z
0_oo0?82oookJP;oK`3o0_oo^P02o`3oH003oookJ_oo06Ooo`1W00?ooo]Z00?oo`2_oookJ_oonfX0
4?oonfX2o`3o2CWooo]Z000foookJPGo0?on3_oonfX2odCo0004o`3oo_m4o`3oA?l0oookJP;oo`1W
0_l0o``00ol0/?oo0?l<o`1Oo`02o`3oG@;ooo]Z0_oo0?800ol0ojgoU?l0oookJP02oookJP?o0?l<
1?l0ojd01?l03oooU?l0o`3okol0onl2o`3oG@08o`12ool0oego0?mMooo90?ooh`3o0?n]oiCo0?oi
o`02ool0T0;o0?lH00Cooo]ZoolT0?oo903ooo]Z0_oob@000ol0o`coolT0ooo90002oomA0005on?o
0?ooJ03oo`2hool0^?n@o`000_oo:002oiCo00;o0?oP1?l0/?l01_ooD`3o0;3oo`2`ool0/?ooolD0
o`0go`;o0?mM0_l0oeT3o`3oG@;oo`0n1?oonfX7oolX00;oo`0<0ooonfX00ooo0:cooo]ZoookJP08
o`2`o`Co00oo00Gooo]Zoo40oooa0?oooo]ZoolX0002ool0b0CoiOl000?o7Ol0o`3oK?l0of`00ol0
ooh8odCo0003onGo0?l0Gooo05oo00?o05oo00Cooo]ZoonS0?ooX`3ooj<03OoonfX8o`3ooP;oA?l0
1Ol0/?l00ol0o`coolT0ooo90007oookJPOo0;3o0ol0o``2ooo900;oobP00_oonfX00ol0W_oooo]Z
o`3o[@04oiCo00CoobP00_lMo`000ol0ob_ooaH0ool0b002ool0b0;o0?on00Gol@3ooookJ_oonf[o
oo]Zool0f`02obKo00;oo`0000?o05ooo`0]oooo>0001?l0Gol00ol0o`co0?mMo`3oG@04o`3oG@;o
iOl00_ook0001?oonf[oonh0ooo^0?oonfX3oiCo0003o`3o[Ol0Gooo05oo00?o0?mM00Wo05ooo`3o
GOl0oego03Ooooo50?oo07?ooo]Zo`3o3?ooD`000_oc0?l01?oo0?3o0?oPo`3oh?oob@02o`3o30;o
0?mM00?o05ooo`3oGOl0oed00_l0oed00oooD@3o05Ooo`3o=P02oeD0o`04oolN0?l0ojgo0?n]o`0?
o`;o0?n]00Co0?lHool0T?oo093oo`2@1_l0Gol01_l03ooo0?n]oiCo0?oonf[o0?mMo`2fo`;oEOl0
0_oonfX2oooR00Oooo]Z00?oo`25ool0l_ooi0000_oonfX00om_0?oookX0oonj0002o`3oH003oook
J_oo06Ooo`1W00?ooo]Z0_oo0:lAoookJP;o0?l9K_oonfX2o`3o2A7ooo]Z0_oo0:l3oookJP08ool0
Iooonf[ooo]Zo`3oH?l0]ooookX0oookJ_m_0?l3oookJP03ool0l_oo08Gooo]Z00Kooo]Z0_oohP02
oookJP;oEOl000Coo`26o`3okooonf[oo`110_l0@_l2oookJP;oon<000Kooo]ZomGo0?oo093oo`2@
oookJ_l0oaP2oookJP04oolT0?oonf[ooo]ZoolN00;oE@3o0_l0Eol02?ooD@3ohol0on?o0?ooS03o
o`2hoi3o0?l0oi7ooo]Z0_l0oe<01ooonf[o0?oPool0l?ooX@3ol`3ooookJ_ooD`000_oonfX01?oo
07?oolD0o`0goooo0<d2oookJP03o`3oFOl0obGo09;o00;of_l000?oo`0noookJ_oonfX00_oonfX0
0oookP3ooo]ZobP0o`02ooo/0004oolN0?oo0@3oo`0<ool030?ooo]Z0_oo0:`2oookJP04obCo0?l0
WOoo02goo`0]o`;ooe@000CoohH0obKo0?lVo`3oo`3K0_oonfX2oo40o`04oookJ_l0B?oo04Soool0
b0;ooaH00_oonfX01?lMo`3ooo]Zo`3oK?l0of`2ooKo00Cooo]Z00?o09kooookJ_oonfX00ooonfX2
o`2ao`Cooo]Z0_ooX`0FoookJPCo00003ooonfX3oonS00Cooo]Z0ol0/Ol3oookJP;o09ko0ooonfX3
ooKo00;o0?m/00Cooo]Zoago0?lMo`3ooo]Z0_oo5P02ool0b004o`18oooonf[ol@3ooo40o`;ooo]Z
00?oo`3KobKo0?lVo`000_ooQP000oooE03o02goo`0]o`02o`2Mo`?ooo]Z00Goo`2/oookJ_oonf[o
oo]Zo`14o`02ool030;ooah000Coon`0obP0oooonf[oonh01?oonfX2ool0?P03om[o0?l0T_oo09;o
00;o0?mI00Cooo]Zool0cOl0=oooolD00_oo07<00ooonf[ooe<0oomC0002oo<0o`07ool0l?l0on3o
0?oPo`3oDooo01_ooo]Zool00`02ool0^004oon<0?ooJ03ohol0oomA00;o05Oo0_mE0?l00ooo7P3o
oo]ZoookJP02oolT0003oookJ_l0oaSooo]Z00;oo`2@00GonOl0omGo0?ooh`3oon<0oomd0002oook
JP03o`12oooo047ooo]Z00;o0?o_0omEo`000ooonf[oon80oooR0007oookJP03ool0QOoo0?;oo`3b
00;ooo]Z0_m_0?l2oonj00;o0?mP00?ooo]Zool0Iooo06L00ooonfX00ooo0:oooo]ZoookJP0?oook
JP;o0?l9>_oonfX003Kooo]Z1Ol0ooh>oookJP;oA?l000Co0?onodCo0?m4o`3oA?l00_oo06L2o`3o
3003o`2`ool0o`co05oo00;o0?mM00Kooo]ZoiCo0?oo0?;oo`3bo`3o[OnDo`03oookJP?o0?l<00Go
0;3oo`3oGOl0oegoU?l0o`0?o`02oiCo0004o`3okol0oego0?mMo`12o`;o0?mM00GoolT0oooS0?oo
h`3oU?l0ooWo0002ool0T0;o0?lH00Cooo]ZoolT0?oo903ooo]Z0_oob@001Ol0o`coolT0ooo90?oo
b@3ooe4000;ohol00_oo0;P00on@o`3oobP0oolX0002oiCo00;o0?oP2?l0/?l01?ooa@3o03Ooo`3o
GOl0oed2o`3oF@?o0?mM00?of_l0ool0?_oonfX00ooonfX5oolX0004oolN0?oo0@3oo`0<ool030?o
oo]Z0_oo0:`00ooonf[o0;3oo`2`o`03o`2`o`;o0?l<1Ol03ol01?l0/?oooo]Zoo40oooonfX2oolX
00;oo`380_oo5P000ooo:03o7Ol0oookJP02o`3oK0;o0?on1Om4o`03oomi00Oo05oo0_oonfX2oonS
00gooo]Z1_l0ooh2odCo00;oogT00ol0/?l01?oonf[o0?l<oookJ_oob@05oookJPWo0;3o0ol0o``2
oiCo00?oobP000?o09kooookJ_l0ojd00_l0ojd4oiCo00;oobP00_lMo`000ooonf[ooaH0oolF0002
ool0b0;o0?on00Col@3ooookJ_oonf[ooo]Z0_oo0=/01?lVo`3oo`00ool00?l0Gol2o`0]o`Co05oo
0_l0o``7o`3oG@05oolX0?ook03oon`0oookJ_ookP000_oonfX2oiCo0003o`3o[OnDo`3o05oo00Co
05oo0_l0oed2o`0go`;oo`1c00Cooo]ZoomC0?ooD`3ol`3o0_oo0?001?ooN@3obP3ooookJ_l0o``3
o`3oG@04o`1Oool0oego0?mMo`3oG@;ooe4000Go05OooeD0oomE0?oo00oooolN0002o`3o[@04o`0?
ool0ojgo0?n]oookJP;oo`2@00?o0?Soo`1Oool0Gol00ol0Gol02?l0ojgo00ooo`3o[Ol0ojgo0?mM
onGo0?l0]_ooEOl00ooonfX00ooohP3ooo]ZoookJP06oookJP;oo`3b0_oonfX2ofl0o`;ookX00_l0
of000ooonf[oo`1Wool0I`03oookJP;oo`2_4OoonfX00ol0o`Wooo]ZoookJP1]oookJP;o0?l94Ooo
nfX2ool0[`?ooo]Z00Soo`1WoookJ_oonf[o0?mPo`2goooo^P3ooo]Zofl0o`?ooo]Z00?oo`3bool0
QOoonfX01_oonfX2oooR00;ooo]Z0_mEo`001?oo08Ko0?o_oookJ_oonfX2o`12o`;ooo]Z0_ooh`00
1Ooo057oeOl0ooWo0?oo093ooo]Z00;o0?lH00Gooo]ZoolT0?oonf[ooo]ZoolN0002oeD0o`;o05Oo
0_ooD@001_oSo`3ooh`0ool0^?n@o`3o0?nAoookJP;o0?mC00Cooo]Zo`3oh?l0on3oo`3`0_oc0?l0
1OooD`3ooo]ZoookJ_oo07?oolD000;o03Oo0_oonfX01_l0oeWo0?lUo`2Boooonf[of_l0ool0?PCo
oo]Z00Ooonh0oookJ_oonf[o0?l/ooo/0?oo7P3oRol000;oo`0<0ooonfX2ool0[0?ooo]Z0_l0WOl0
1_l0;Ooooe@0oomD0?ooQP3ooo]ZobKo00;oo`3K0_oonfX2oo40o`04oookJ_l0B?oo04Soool0b0;o
oaH000?ooo]Zoago0?lMo`000_l0of`00ooonf[om_l0ooKo0004oookJP03o`2Noooonf[ooo]Z00?o
oo]Z0_l0/Ol5oookJP;ooj<05?oonfX4o`0000gooo]Z0oooX`05oookJP;o0;7o1?oonfX2o`2No`?o
oo]Z0oofo`02o`3oK0;ooo]Z00Co7Ol0oookJ_oo5P3ooaH00_oo0<P01?l0B?oooo]Zoo40oooa0?l2
oookJP;oo`3K0_lVo`001?ooQP3ooe@0oomD0?l0;Ol2o`2Mo`?ooo]Z0_oo0:`3oookJP;oo`0<00Go
o`40oolN0?ook03oon`0obP0o`02ooo^00Cooo]Z0_oo03h2o`2Bo`07ol00ool0oeWooo]ZoookJ_oo
0<go03Ooooo50002ool0L`04oookJ_ooD`3ol`3ooo<0o`;oo`3`00Ko0?oPoookJ_l0oe?oo`0Koook
J_l0oi42ool0^004oon<0?oSo`3ohol0oomA00;o05Oo00?oE@3ooookJ_oo7P000_oonfX2oolT00;o
0?lH00Oooo]Zool0T?oio`3oeOl0ool0DOooh`3oog@000;ooo]Z0_l0@_l01?oo047ooo]Zo`3okol0
onl2oeGo00;ooo]Z00?oon80oookJ_oonfX01_oonfX00ooo08Goo`3boookJP02oookJP05ofl0oooo
^P3ookX0oonj0?l0of000_oonfX2ool0I`;ooo]Z0_oo0:lAoookJP;o0?l9>_oonfX003Kooo]Z1_l0
ooh=oookJP;oA?l000Co0?onodCo0?m4o`3oA?l00_oo06L2o`3o3003o`2`ool0o`co05oo00;o0?mM
00Kooo]ZoiCo0?oo0?;oo`3bo`3o[OnDo`03oookJP?o0?l<00Go0;3oo`3oGOl0oegoU?l0o`0?o`02
oiCo0007o`3okol0oego0?mMo`12ool0oegoU?l0ooo90002oooS0005oiCo0?oio`3onOl0ool0T?oo
nfX00_l0oaP2oolT0005oookJ_oob@3oolT0ooo90?l0o``00_oob@000oooD@3ooo]Zon?o0003ool0
^0;o0?on00CoobP0o`3oDooo:03o0?oP2Ol0/?l00ol0=ooo0?mMo`3oG@02o`3oF@Co0?mM00?oo`0n
oookJ_oonfX00_oonfX2oolX0005obP0ooook03oobP0oolN0?oo0@000_oo00`4oookJP04ool0[?oo
nf[o0;3oo`2`o`Ko0?l<1Ol03ol00ol0/?ool@3ooo40o`02oolX00;oo`3800?oobP0oolF0?oonfX0
0_lMo`001?oonf[o0?m/o`3oo_l0ooh2odCo00OoogT01ol0Gol2oookJP?ooj<03?oonfX4o`3ooP;o
A?l00oooN@02o`000003o`2`oooonf[ooo]Z00Kooo]Z2_l0/?l2o`3o30?oU?l00ooo:0000ooonf[o
00ooo`3o[@03o`3o[@CoU?l00_lMo`000ooonf[ooaH0oolF0002ool0b004o`3oo_oonf[ooo]Zoo40
o`?ooo]Z00Goo`3KobKo0?oo003oo`00oomD0002o`0]o`04oolh0?l0Gooo05ooo`1Oo`;o0;3o00?o
U?l0o`3oGOl0oed01_l0oed01?ook03ooo]Zooo^0?ookP02o`3o[@;oU?l000?o0?n]oiCo0?l0Gol0
1Ol0Gol01?l0oego03Ooooo50?oo07<2oookJP09oomC0?l0o`col`3oool0l?l0on3oogT0oookJ_l0
oe?o0?l<00;o0?mM00?o05ooo`3oGOl0oed00_l0oed00oooD@3o05Ooo`3o=P02oeD0o`04oolN0?l0
3ooo00ooo`0?o`;o0?n]00Go0?lHoookJ_oo093oo`2@o`3ho`04o`1Oo`;o0?n]00Co00ooo`3o[Ol0
ojgo0?n]0_oUo`001OmEo`3ooo]ZoookJ_oonf[oon8000Oooo]Z00?oo`25ool0l_oo0?800_oonfX0
1Om_0?oookX0oonj0?oo^P3o0?mP00;ooo]Z0_oo06L3oookJP;oo`2_4?oonfX2o`3o2Foooo]Z0_l0
o`TAoookJP;oo`2_0ooonfX02?oo06Oooo]ZoookJ_l0of3o0;Oooonj0?oonf[oK`3o0ooonfX00ooo
0?;oo`25oookJP06oookJP;oon800_oonfX2oeGo0004o`2fool0onoooo]ZoookJP;o04;o0_oonfX2
oooS0003ool0DOoEo`3onOl000;oo`2@0_l0oaP01?oonf[oob@0oookJ_oonfX2oolN0003oeD0oooo
nf[o05Oo00;ooe4000Kohol0oomX0?oo0;Soo`2ho`3oTOoo00<2o`3oD`04oookJ_l0on3o0?oPool0
l0;ol`3o00Gooe<0oookJ_oonf[oo`1cooo50002o`0go`;ooo]Z00Ko0?mIol00ool0T_oo09;oom[o
0?oo03h4oookJP;oonh000Gooo]ZobP0ooook03ooah0oh_o0002ool030Cooo]Z00Coo`2/oookJ_oo
nf[ooo]Z0_l0WOl2o`0]o`04oomD0?ooQP3oohH0obKo00;oo`3K0ooonfX01ooa0?oooo]Zo`18ool0
B?ooo`38o`3o:ooo5P000_oonfX01_lMo`3ooo]Zo`3oK?l0ofcooo]ZooKo00Gooo]Z00?o09kooook
J_oonfX00ooonfX2o`2ao`Gooo]Z0_ooX`0CoookJPCo00003?oonfX3oonS00Gooo]Z0_l0/Ol4oook
JP03o`2Noooonf[ooo]Z00;ooo]Z0oofo`02o`3oK0;ooo]Z00Co7Ol0oookJ_oo5P3ooaH00_oo0<P0
0ol0B?oooo]ZoookJP02oo40o`;ooo]Z00Soo`3KobKo0?lVo`3oohH0o`07ooooE03o02gooolh00;o
09go0_oonfX2ool0[0?ooo]Z0_oo00`01Ooo0@3ooah0oolN0?ook03o:03o00?oonh00ooonfX2ool0
?P03om[o0?l0T_oo09;o00;o0?mI00Cooo]Zool0cOl0=oooolD00_oo07<00ooonf[ooe<0oomC0002
oo<0o`03ool0l?l0on3o0?oP00;o0?mC00?ooo]Zool00ol0oi400_oo0;P01OooJ03ohol0oomA0?oo
D@3o05Oo00;oE@3o00Kooah0oookJ_oonf[ooo]ZoolT0?oonfX2o`3o6004oookJ_oo093onOl0omGo
00;oon<000Koog@0oookJ_oonf[o04;oool0@OoonfX2o`3ok`03o`2foomEo`3oEOl000;ooo]Z00?o
on80oookJ_oonfX01_oonfX2ool0lP?ooo]Z00?oK`3ooonj0?oo^P000_l0of000ooonf[oo`1Wool0
I`03oookJP;oo`2_4OoonfX2o`3o2C[ooo]Z000foookJPKo0?on3?oonfX3odCo0004o`3oo_m4o`3o
A?l0odCo00;oo`1W0_l0o``00ol0/?oo0?l<o`3o3003o`3oG@04oiCo0?oo0?;oo`3bo`3o[@;oU?l0
0_oonfX3o`3o3005o`2`ool0o`coU?l0oiCo0?l03ol00onDo`02o`3oG@04o`12oooUo`3oU?l0oomd
00;oon<000GoU?l0ooWo0?oio`3oo`2@oookJP02o`3o60;oob@000Gooo]Zooo90?oob@3oolT0o`3o
3002ooo90004oomA0?oonf[ohol0o`3ooP;oo`2h0_l0ooh01?l0oe?oobP0oolX0?l0on09o`2`o`05
o`0gool0oego0?mMo`3oGOl0oeT00ooUo`000ooJo`3oo`0nool0?P03oookJP;oonh000Kooo]Zo`3o
;?oo:03ooah0oh_o0?oo0@02ool030?ooo]Z00Coo`2/oookJ_oonf[ooo]Z1ol0o``01?l03ooo0?n]
o`3o[Ol0ojd2o`2`o`04oo40oooo:03oobP0o`18o`;oo`380_oo5P001?oonf[o7Ol0oago0?l0of`3
o`3ooPKoogT000?o09kooookJ_l0Gol02?l0Gol01?oonf[ooj<0oonS0?ooX`0<oookJP?o0?on0_m4
o`02oomi00?o00002?oonfX;o`2`o`;o0?n]1?nDo`03oolX0003o`0?ool0ojgo0?n]00;o0?n]0onD
o`02oago0003oookJ_oo5P3ooaH000;oo`3800Co0?onoookJ_oonf[ol@3o0ooonfX00ooo0=_o9_l0
obKo0002ool00003oomD0?l0;OooocP000?o05oo0_l0/?l2o`1Oo`;o0?mM00?o05ooo`3oGOl0oed0
0_l0oed01Oook03oobP0oookJ_ookP3ooo]Z00Co0?n]00?oU?l0o`1Oool0Gol01_l0Gol03?l0=ooo
o`1cool0Looonf[o0?l<oomC0?oc0?ooo`3Gool0l?ooN@3obP3oo`3o30;o05oo0_l0oed02?l0Gooo
0?mMo`3oGOl0oego0?l<oomA0?l0EoooiOl00_mE0?l00ooo7P3o00ooo`0?o`03o`0?o`05o`3o6?oo
093oo`2@ooWo0?m4o`001?l0Gol00ol0ojgo00ooo`3o[@03o`3o[@05onGo0?mEo`3oEOl0onGo0?oo
nfX00_oohP07oookJP03ool0QOoo0?;oo`3b00;ooo]Z00?oK`3ooonj0?oo^P000_l0of000ooonf[o
o`1Wool0I`03oookJP;oo`2_4OoonfX2o`3o2Foooo]Z0_l0o`TAoookJP;oo`2_0ooonfX02?oo06Oo
oo]ZoookJ_l0of3o0;Oooonj0?oonf[oK`3o0ooonfX00ooo0?;oo`25oookJP06oookJP;oon800_oo
nfX2oeGo0004o`2fool0onoooo]ZoookJP;o04;o0_oonfX2oooS0003ool0DOoEo`3onOl000;oo`2@
00Cooo]Zo`3o6?oonf[oob@00_oonfX2oolN00;oE@3o00Go05OooomA0?ooD@3ohol0oomX0002ool0
^008o`3oTOoo00?o0?mCo`3oDooonf[obP3oo`3oh?oo0?02oo<0o`;ooe<000?ooo]Zool0Looo07<0
0_l0=ol01?oo0<gooo]Zo`3oFOl0oeT2o`2Bo`03om[o0?oo03koo`0n00?ooo]Z0_ookP001_oonf[o
:03oooo/0?ook03ooah0ool100;oo`0<0ooonfX2ool0[0;ooo]Z00Co9?l0o`2Moooo>03o02go0_oo
E0001?ooQP3o9_l0obKo0?oo0=/3oookJP04oo40oooonf[ooo]Zo`18o`;oo`380_oo5P001?oonf[o
7Ol0oago0?oonfX2o`3oK0;om_l01OoonfX00ol0W_oooo]ZoookJP03oookJP;o0;7o1OoonfX3oonS
017ooo]Z1?l0000:oookJP?ooj<01OoonfX2o`2ao`Cooo]Z0_l0W_l4oookJP?om_l00_l0of`2oook
JP04oago0?oonf[ooaH0oolF00;oo`3800?o04SooookJ_oonfX00_oa0?l2oookJP03ool0folVo`3o
9_l000;oohH000?ooe@0o`0]ool0;Ol00_l0WOl3oookJP;oo`2/0_oonfX01_l0A?ooo`0<ool03?oo
0@3ooah0ooo/00;o:03o0_ookP04oookJP06ool0?_oJo`3ooo]Zo`2Booo00?oo0?mI0_oonfX00ooo
0<go03Ooooo50002ool0L`04oookJ_ooD`3ol`3ooo<0o`;oo`3`00Ko0?oPoookJ_l0oe?oo`0Koook
J_l0oi42ool0^004oon<0?oSo`3ohol0oomA00;o05Oo0_mE0?l00ooo7P3ooo]ZoookJP02oolT0003
oookJ_l0oaSo0?lH00;oo`2@00ConOl0omGo0?ooh`3oon<00_oonfX2o`12o`04ool0@Ooonf[o0?o_
o`3ok`;oEOl00_oonfX2oooR00Sooo]Z0_oo0?82oookJP;oK`3o0_oo^P02o`3oH003oookJ_oo06Oo
o`1W00?ooo]Z00?oo`2_oookJ_oonfX03ooonfX3o`3o2C[ooo]Z000eoookJPOo0?on3?oonfX3odCo
0003o`3oo_m4o`3oA?l000;oA?l000Coo`1Wo`3o3?l0o`co0;3o0_l0o``3o`3oG@04oiCo0?oo0?;o
o`3bo`3o[@;oU?l01?oonfX00ooob@3o0;3oo`3o3002oiCo0004o`0?oonDo`3oU?l0oiCo00;oiOl0
00?o04;oonGo0?nDo`000_ooM0001_ooh`3oU?l0oiCo0?oio`3oo`2@oookJP;o0?lH0_oo90001Ooo
nf[oolT0ooo90?oob@3o0?l<00;oolT00_ooD@001?oSo`3o0?onool0^?oo0;P2o`3ooP04ool06ooo
:03oobP0o`3oh0[o0;3o00Co03OoonGo0?oUo`3o0?mI1?oUo`02ool0?PCooo]Z00?oonh0oookJ_lX
0?l00_ook0001?oo7P3oo`40ool03?oo00`3oookJP;oo`2/0_oonfX7o`3o30Go0?n]00Co0;3ooo40
oooa0?oooo]Z0_l0B?l00ooo0<Sooo]ZoolF0002oookJP03oago0?oonf[o0?m/00?o0?on0oooN@00
1Ol0ookooo]ZoookJ_l0W_oooo]Z00Wo05oo00?o0?mMoookJ_ooX`000_ooX`0;oookJP03o`3oo_oo
nf[oA?l000;ooo]Z00CoogT0o`000?l0003o00001_oonfX<o`2`o`?o0?n]1?nDo`04oolX0003o`0?
ool0ojgo0?n]00;o0?n]00CoU?l0oago0?lMo`3ooo]Z0_oo5P02ool0b004o`3oo_oonf[ooo]Zoo40
o`?ooo]Z00Ooo`3KobKo0?lVo`3oohH0ool00?ooE03o02go00;oocP00_l0Gol3o`2`o`?o05oo00?o
0?mMo`1Oool0oed00_l0oed2ooo/0004oolX0?ookP3oonh0oookJPGo0?n]2?l0Gol01?l0=oooo`1c
oookJ_oonfX2oomC0006oo<0oooo0?3o0?oPoomi0?l0o`co0?mC1Ol0Gol3o`3oG@;ooe4000?o0?lf
oeD0oomE0?l00_oo7P06o`0?o`;oo`2@00?o0?SoodCo0?l0Gol00_l0Gol2o`3o[@04o`0?ool0ojgo
0?n]o`3o[@;oiOl000CoEOl0onGo0?oUo`3ooo]Z0_oohP07oookJP;oo`3b0_oonfX2ofl0o`;ookX0
0_l0of000ooonf[oo`1Wool0I`03oookJP;oo`2_4OoonfX2o`3o2Foooo]Z0_l0o`TAoookJP;oo`2_
0ooonfX02?oo06Oooo]ZoookJ_l0of3o0;Oooonj0?oonf[oK`3o0ooonfX00ooo0?;oo`25oookJP07
oookJP03oooR0?oonf[ooo]Z00;oEOl000Co0;Koo`3okooonf[ooo]Z0_l0@_l2oookJP05oomd0?oo
h`3oon<0omGo0?oonfX00_oo09000ooonf[o0?lHoookJP02oolT0003oookJ_oo7P3ooah000;oE@3o
017o05OooomA0?ooD@3ohol0oomX0?ooS03oo`2ho`3oTOoo00?ooo]Zo`3oDooo01_obP3oo`3oh?oo
0?3oo`3Goo<0o`02oomC0003oookJ_oo07?oo`1c00;o03Oo00Ooo`3=oookJ_l0oeWo0?mIo`3o9Ol0
T_oooo]Z00;oo`0n1?oonfX00oookP3ooo]ZoookJP02ooo/0004oolN0?oo0@3oo`0<ool030?ooo]Z
0_oo0:`3oookJP;o09go00?o02gooookJ_ooE0000_ooQP000olVo`3oo`3Kool0f`03oookJP04oo40
oooonf[o04Soo`18o`;oo`3800?ooaH0oookJ_oonfX00_lMo`02o`3oK004oookJ_ofo`3om_l0ooKo
00Cooo]Z0_l0W_l4oookJP?o0;7o1OoonfX3oonS00oooo]Z1?l00008oookJP?ooj<01_oonfX2o`2a
o`Cooo]Z0_l0W_l4oookJP;om_l000?ooo]Zo`3oK?l0of`00_oonfX01_lMo`3ooo]ZoolF0?oo5P3o
oo]Zool0b0;o04So00?ooo]Zoo40oooa0?l00_oonfX2ool0f`03obKo0?ooQP3oohH000;ooe@000?o
02gooolh0?l0WOl00ooonfX2ool0[0?ooo]Z0_oo00`01Ooo0@3ooah0oolN0?ook03o:03o00?oonh0
0ooonfX2ool0?P03om[o0?l0T_oo09;o00;o0?mI00Cooo]Zool0cOl0=ooo03Oo0_oo07<00ooonf[o
oe<0oomC0002oo<0o`03ool0l?l0on3o0?oP00;o0?mC0_oonfX01Ol0oi7oo`2hool0^?ooS03ohol0
00;ooe4000?o05Ooo`3o=_mE0?l00_oo7P02oookJP0;oolT0?oonf[o0?lHo`3o6?oonf[oo`2@ooWo
0?oEo`3oo`1AoooS0?ooM0000_oonfX2o`12o`04ool0@Ol0onoo0?o_o`3ok`;oEOl00_oonfX2oooR
00Oooo]Z00?oo`25ool0l_oonfX00_oonfX01?m_0?oookX0oonj0?l0]ol2o`3oH003oookJ_oo06Oo
oo]Z00;ooo]Z0_oo0:lAoookJP?o0?l9>_oonfX003Gooo]Z2?l0ooh;oookJP?oA?l000?o0?onodCo
0?m4o`000_m4o`001?oo06Oo0?l<o`3o3?l0/?l2o`3o30?o0?mM00CoU?l0ool0l_oo0?;o0?n]0onD
o`03oookJP03ooo90?l0/?oo0?l<00;oU?l000?o0?n]oiCo0?nDo`000_nDo`000ooUo`3o04;oo`12
o`02oiCo0007oomd0?ooh`3oU?l0oolX0?oio`3oo`2@oookJP02o`3o60;oob@000Gooo]Zooo90?oo
b@3oolT0o`3o3002ooo900;ooe4000Cohol0o`3oo_oo0;Soo`2h0_l0ooh01?oo01_oobP0oolX0?l0
on0;o`2`o`;oiOl00_l0oeT3onGo00;oo`0n1?oonfX2ooo^0007obP0ooook03oon`0oolN0?n;o`3o
04Coool03003oookJP;oo`2/0_oonfX8o`3o30Go0?n]00Go0;3ooo40oooa0?oooo]Zo`18o`02ool0
b003o`3o:ooo5P3ooo]Z00;o7Ol000Gooo]Zo`3oo_l0ooko0?onoomi0004o`3ooP;ooo]Z00?o09ko
o`1Oool0Gol02?l0Gol01?l0oegooo]ZoookJ_oonfX3oonS00gooo]Z1?l00005oookJP[o0;3o0_l0
/Ol2o`0?o`?o0?n]1?nDo`03oolX00;o00oo0ol0ojd2oago0003oookJ_oo5P3ooaH000;oo`3800?o
0?ono`18oooonfX00_oa0?l2oookJP;oo`3K0_lVo`001Ooo003ooe@0o`0]ool0;OooocP000;o05oo
0ol0/?l6o`1Oo`;o0?mM00KoU?l0ooo/0?oo:03oobP0ooo^0?oonfX4o`3o[@03o`0?ool0ojgo05oo
00Ko05oo00?o03Ooooo50?oo07<00_oonfX02?ooD`3ol`3ooo<0oooo0?3oogT0olX0ool0o`co0?mC
1ol0Gol01?l0o`cooe40o`1GoooUo`02oeD0o`03oolN0?l03ooo00oo00?o00oo00KoogT0ool0T?oo
093onOl0odCo0?oonfX3o`1Oo`03o`3o[Ol03ooo0?n]00;o0?n]00Ko0?mMonGo0?oUo`3oEOl0onGo
0?oonfX2oooR00Oooo]Z00?oo`25ool0l_oo0?800_oonfX01Om_0?oookX0oonj0?oo^P3o0?mP00;o
oo]Z0_oo06L3oookJP;oo`2_4OoonfX00ol0o`Wooo]ZoookJP1^oookJP;o0?l94OoonfX2ool0[`?o
oo]Z00Goo`1WoookJ_oonf[o0?mPo`2go`02oonj0006ofl0oooonf[ooo]ZoookJ_oo0?;oo`252?oo
nfX00ooohP3ooo]ZoookJP02oeGo0004o`2fool0onoo0?o_oookJP;o04;o0_oonfX00oooM03oon<0
oooS0002omGo00;oo`2@00?ooo]Zo`3o6?oonfX00_oo90000ooonf[ooah0oolN0002oeD0o`03o`1G
ooooD@3ooe4000;ohol000Gooh`0ool0^?n@o`3oo`03oookJP02o`3oD`05oookJ_l0on3oo`3`ool0
eooc0?l00_ooD`001_oonf[oo`1cool0Loooa@3o03Ooool0c@;ooo]Z00Ko0?mIol00ool0T_oooo]Z
om[o0?oo03h4oookJP;oonh000Oooo]Zo`3o;?ook03ooah0oh_o0?oo0@3oo`0<00Cooo]Z00Koo`2/
oookJ_oonf[ooo]ZobCo0?l0WOl2o`0]o`;ooe@000CoohH0obKo0?lVo`3oo`3K0ooonfX2oo40o`07
oookJ_l0B?ooo`38ool0b?l0ob_ooaH0oookJP03oago00;o0?m/00Cooo]ZooKo0?ofo`3om_l01?oo
nfX2o`2No`Gooo]Z0_l0/Ol6oookJPCooj<03?oonfX4o`0000Gooo]Z0oooX`07oookJP?o0;7o1?oo
nfX2o`2No`Cooo]Z0_ofo`000ooonf[o0?m/o`3oK002oookJP04oago0?oonf[ooaH0oolF00;oo`38
0_l0B?l2oookJP03oo40oooonf[ooo]Z00;oo`3K0_lVo`02oon60004oomD0?l0;Ooo02goo`2Mo`Co
oo]Z00Goo`2/oookJ_oonf[ooo]Zo`14o`02ool03005oh_o0?oo7P3oon`0obP0oooonfX00_ookP04
oookJP06ool0?_oJo`3o09;oo`2Booo00?oo0?mI0_oonfX00ooo0<go03Ooooo50002ool0L`03oook
J_ooD`3ooe<000;ol`3o00?oo`3`o`3oh?oonfX00_l0oe<00ooonf[o0?nAo`3oT@02ool0^003oomX
0?oSo`3ooe4000;o05Oo0_mE0?l01_oo7P3ooo]ZoookJ_oonf[oob@0oookJP;o0?lH0_oo09001Ooi
o`3oeOl0oooS0?ooh`3oog@000;ooo]Z00?o04;oool0@OoonfX00_l0onl00ol0]_ooEOl0oeGo0002
oookJP03oooR0?oonf[ooo]Z00Kooo]Z0_oo0?82oookJP;oK`3o0_oo^P02o`3oH003oookJ_oo06Oo
o`1W00?ooo]Z0_oo0:lAoookJP;o0?l9>ooonfX003Gooo]Z2?l0ooh;oookJP?oA?l000Ko0?onoomi
0?oonf[ooo]Zo`1Ooooo06L2o`3o3004o`2`ool0o`co0?l<o`3o30?o0?mM0ooo0?83oiCo00?ooo]Z
00?oolT0o`2`ool0o``00_nDo`000ol0ojgoU?l0oiCo0002oiCo0003onGo0?l0@_oo04;o00;oiOl0
00Goog@0oooS0?nDo`3oobP0ooWo0002ool0T0;o0?lH00?ooo]ZoolT0?oonfX00ooob@000ol0o`co
0?lfo`1Go`02oomA0004on?o0?l0ookoT?l0ool0^0?o0?on0ooo:00;o`2`o`;oiOl00_l0oeT4onGo
00;oo`0n0ooonfX2ooo^0006oookJ_ook03oon`0oolN0?n;o`3oo`400_oo00`3oookJP;oo`2/00?o
oo]Zo`3o3?l0o``00ol0o``3ooo900?o0?n]00KoU?l0o`2`ool0/?oo0;3ooo40oooonfX2o`18o`03
ool0b?oonf[ooaH000;ooo]Z00?o7Ol0oookJ_l0ooh02?l0ooh2oookJP;o09ko1_l0Gol4o`3oG@04
onGo0?oonf[ooo]ZoookJPOooj<01ooonfX4o`000004oookJ_ooX`3ooj<0oonS00Co0;3o1?oonfX3
o`2ao`04oookJ_l03ooo00ooo`0?o`?o0?n]1?nDo`04oolX0003o`0?ool0ojgo0?n]00;o7Ol000?o
oo]ZoolF0?oo5P000_oo0<P00ol0ooko04SooookJP02oo40o`;ooo]Z0_oo0=/2obKo0005oon60?oo
003ooe@0o`0]oooo>0000_l0Gol4o`2`o`Oo05oo00GoU?l0ooo/0?ook03oobP0ooo^0002oolX00Co
0?n]00?o00ooo`3o[Ol0Gol01Ol0Gol2o`0go`;oo`1c00Cooo]ZoomC0?ooD`3ol`3o0_oo0?000ooo
N@3obP3oool06`08o`1Oo`;ooe4000Go05OooeD0oomE0?oo00oooolN0005o`0?o`06oomi0?oo093o
o`2@ooWo0?m4o`3oo`1A0_l0Gol2o`3o[@04o`0?ool0ojgo0?n]o`3o[@;oiOl00_mEo`02oookJP;o
on801ooonfX00ooo08Goo`3bool0lP02oookJP03ofl0oooo^P3ookX000;o0?mP00Cooo]Zool0Iooo
06Ooo`1W0_oonfX2ool0[a7ooo]Z0_l0o`U`oookJP;o0?l94_oonfX01Ooo0:oooo]ZoookJ_oonf[o
o`1W00;ooo]Z00Co0?mPo`2goooo^P3ookX00_m_0?l2oookJP;oo`3b00?oo`25oookJ_oonfX01Ooo
nfX00ooohP3ooo]ZoookJP02oeGo0006o`2fool0onoo0?o_oookJ_oo047o04;o0ooonfX2oooS0007
oookJ_oEo`3oo`2@ool0T?oonf[o0?lHoookJP02oolT00;ooo]Z00Cooah0oeD0oomE0?oo0?lf0_oo
D@02on?o0005oon<0?oo0;SoT?l0o`3oTOoonfX00_l0oe<01?oonf[o0?oPo`3oh?oo0?02oo<0o`05
oomC0?oonf[ooo]Zool0Loooa@000_l0=ol01?oo0<gooo]Zo`3oFOl0oeT2o`2Bo`03om[o0?oo03ko
o`0n00?ooo]Z0_ookP001_oonf[o:03oooo/0?ook03ooah0ool100;oo`0<0ooonfX2ool0[0;ooo]Z
00_o9?l0o`2Mool0WOoo02gooookJ_ooE03oohH0oookJ_lVo`3ooo]Zool0f`03oookJP04oo40oooo
nf[o04Soo`18o`;oo`3800?ooaH0oookJ_oonfX00_lMo`001?oonf[o0?m/o`3oK?oonfX3ooKo00Co
oo]Z0_l0W_l5oookJP?o0;7o1_oonfX8oonS00Kooo]Z1?l000000ooonf[ooj<0oonS0003oonS00Oo
oo]Z0ol0/Ol4oookJP;o09ko1OoonfX2ooKo0004oookJ_l0ofco0?m/oookJP;o7Ol000?ooo]ZoolF
0?oo5P000_oo0<P2o`18o`;ooo]Z00?ol@3ooookJ_oonfX00_oo0=/2obKo00;oohH000?ooe@0o`0]
ool0;Ol00_l0WOl3oookJP;oo`2/0ooonfX2ool03005ool10?oo7P3o0?l/ooo/0?lX0?l00_ookP04
oookJP;oo`0n00?of_l0o`2Bool0T_l00_l0oeT01?oonf[oo`3=o`0gool0=ol3ool0L`04oookJ_oo
D`3ol`3ooo<0o`;oo`3`00Ko0?oPoookJ_l0oe?oo`0KoookJ_l0oi42ool0^009oon<0?oSo`3ooe40
oomA0?l0Eooo0?lfoeD0oooonf[ooah000;ooo]Z0_oo90000ooonf[o0?lHo`3o6002ool0T004ooWo
0?oo057oon<0oooS00;ooo]Z0_l0@_l01?oo047ooo]Zo`3okol0onl2oeGo00;ooo]Z0_oohP08oook
JP;oo`3b0_oonfX2ofl0o`;ookX00_l0of000ooonf[oo`1Wool0I`03oookJP03ool0[ooonf[ooo]Z
013ooo]Z0_l0o`TkoookJP00=OoonfX5o`3ooQ3ooo]Z00?oogT0o`3oo_ooN@000_oonfX01Ol0Gooo
0?l<o`3o3?l0o`co0;3o00?o0?l<0ol0oed3ool0lP?oU?l00_oonfX2ooo90003o`2`ool0o`coU?l0
00;oU?l000ko0?n]oiCo0?nDo`3oU?l0onGo0?l0oego04;oonGo0?oo:03oog@0oooS0?nDo`3oobP0
ooWo00;oo`2@0_l0oaP01?oonf[oob@0oolT0?oonfX2oolN0003o`3o3?oob@3o05Oo00;ooe400ol0
ooh01?oo0;So0?ono`3oo_l0ooh3oolX00co0;3o0_oUo`000ol0oeWoiOl0onGo0002onGo00;oo`0n
1?oonfX00oookP3ooo]ZobP0o`02ooo/0004oolN0?oo0@3oo`0<ool030?ooo]Z0_oo0:`00ooonf[o
0?l<o`3o3007ooo900CoU?l00ol0/?l02ooa0?oooo]Zo`18ool0B?ooo`38oookJ_oo5P3oo`00oook
J_lMo`3ooo]Z00Wo0?on0_oonfX2o`2No`Co05oo1?l0oed3onGo00Kooo]Z4OooX`07oookJP?o0;7o
00?ooo]Zo`0?ool03ol00ol03ol4o`3o[@?oU?l000?oobP0o`0?ool03ol00ol03ol00olMo`3ooo]Z
oookJP02oolF00;oo`380_l0B?l00ooonf[ol@3ooo40o`03oookJP08ool0folVo`3o9_l0oon60?oo
003ooe@0o`0]oooo>002o`1Oo`Co0;3o00?o0?n]o`1Oool0Gol01_l0Gol01?ook03oobP0oolX0?oo
kP02o`0?o`?o0?n]00?o00ooo`3o[Ol0Gol01Ol0Gol2o`0go`05ooo50?oo07?o0;3oo`2`ooooN@00
0_oc0?l01Ooo0?3oogT0o`3oh?oonf[o0;3o00So05oo00?ooe40o`1GoooUo`000_mE0?l2oolN00Go
00oo00[oogT0ool0T?oo093o0?Sooomi0?ooh`3o05oooomd0?l0ojgo00oo0ol0ojd01Ol0oego05oo
onGo0?mEo`3oiOl000;ooo]Z0_oohP07oookJP;oo`3b0_oonfX2ofl0o`;ookX00_l0of000ooonf[o
o`1Wool0I`03oookJP;oo`2_4OoonfX2o`3o2G3ooo]Z0_l0o`TBoookJP04ool0[ooonf[ooo]Zoook
JP;oo`1W00Gooo]Zo`3oH?l0of3o0;Oooonj0002ofl0o`;ooo]Z0_oo0?800ooo08Gooo]ZoookJP05
oookJP06oooR0?oonf[ooo]ZoookJ_mEo`3o0;Ko0_l0onl00ooonf[oo`11o`12o`03oookJP;oon<0
00Goo`1AomGo0?oo093oo`2@oookJP02o`3o60;oob@00_oonfX01_oo7P3oE@3ooeD0ool0ocKo05Oo
oomA00;ohol000Cooh`0ool0^?oo0;So0?nA0_oonfX01Ol0oe?ooo]Zo`3oh?l0on3oo`3`00;ol`3o
00?ooe<0oookJ_oonfX00_oo07<2o`0go`04ool0cOoonf[o0?mIo`3oF@;o09;o00?of_l0ool0?_oo
03h01?oonfX01oookP3ooo]ZobP0ool0obcoon`0oolN0?n;o`000_oo00`4oookJP06ool0[?oonf[o
oo]ZoookJ_lTo`3o09go0_l0;Ol00oooE03oohH0oon60002obKo0004ool0fooonf[ooo]ZoookJP;o
l@3o00?ooo]Zo`18ool0B?l00_oo0<P00ooo5P3ooo]ZoookJP02oago0004oookJ_l0ofco0?m/oook
JP?om_l01?oonfX2o`2No`Gooo]Z1?l0/Ol8oookJQ7ooj<02?oonfX3o`2ao`Cooo]Z0ol0W_l4oook
JP;om_l000Gooo]Zo`3oK?l0ofco0?m/oookJP02oago0003oookJ_oo5P3ooaH000;oo`380_l0B?l2
oookJP05oo40oooonf[ooo]ZoookJ_oo0=/00_lVo`02oon60005oomD0?oonf[o02gooookJ_l0WOl0
1?oonfX01?oo0:cooo]ZoookJ_oonfX2ool03006ool10?n;o`3ooah0ooo/0?lX0?oooo]Z0_ookP04
oookJP06ool0?_oJo`3o09;oo`2Booo00?oo0?mI0_oonfX00ooo0<go03Ooooo50002ool0L`03oook
J_ooD`3ooe<000;ol`3o00?oo`3`o`3oh?l0on000_l0oe<00ooonf[oo`03o`3oT@02ool0^005oon<
0?oSo`3ooe40oomA0?l0Eol00_mE0?l2oolN00;ooo]Z00_oob@0oookJ_l0oaSo0?lHoookJ_oo093o
nOl0omGo0?oo057oon<0oomd0002oookJP;o04;o00Cooo]Zo`3okol0onoo0;Ko0_mEo`02oookJP;o
on801ooonfX00ooo08Goo`3boookJP02oookJP03ofl0oooo^P3ookX000?o0?mP00?ooo]Zool0Iooo
nfX00_oonfX2ool0[a7ooo]Z0ol0o`TkoookJP00>?oonfX00om4o`3o0?onoookJP0?oookJP03oomi
0?l0ookoA?l000;ooo]Z00Go05ooo`3o3?l0o`co0?l<o`2`o`03o`3o30;oK`3o0_nDo`02ool0lPCo
U?l000Gooo]Zooo90?oob@3o0;3oo`3o3003oiCo0003o`3o[OnDo`3oU?l000;oU?l000Go0?mMo`12
oooUo`3oobP0oomd0002oooS0004oolX0?l0n?ooo`2@ool0T0;o0?lH00?ooo]ZoolT0?oo90000_oo
nfX01?oo7P3oE@3oooo90?l0Eol3oomA00;o0?on0_oo0;P2o`3ooP?oobP01?l0/?l3o`3o30Go0;3o
0_oUo`02o`3oF@CoiOl000?oo`0noookJ_oonfX00_oonfX2ooo^0007oookJ_ook03oon`0oolN0?n;
o`3oo`40ool03004oookJP04ool0[?oonf[ooo]ZoookJPSoolT01?nDo`000ol0o`col@3ooo40o`02
oookJP08o`18oooo0<Soo`38ool00?oo5P3oo`00oookJ_lMo`07o`3ooP?oA?l000?oogT0oookJ_l0
W_l00_l0W_l00ol0Gooo0?mMo`3oG@02o`3oG@CoiOl04?oonfX4o`0000Sooo]Z1?l0/Ol00ooonf[o
00ooo`0?o`05o`0?o`?o0?n]1?nDo`03o`0?o`;o7Ol000Co00oooookJ_oo5P3ooaH00_oo0<P2o`18
o`03oookJ_oa0?ool@3o00?ooo]Z00Ooo`3KobKo0?lVo`3oohH0o`07ooooE03o02go00;oocP000?o
05oooookJ_l0/?l00ol0/?l7o`1Oo`06oolN0?ook03oU?l0oolX0?ookP3oobP00ol03ol01?l0ojgo
00ooo`3o[Ol0ojd5o`1Oo`03ool0cOl0=oooolD000;oo`1c00Co0;3ooomC0?ooN@3ol`3o0_ooN@00
1?m4o`3obP3ooookJ_l0/?l8o`1Oo`06oomA0?l0EoooE@3ooeD0oooonf[ooah01_l03ol2ool0T003
ooWo0?m4o`3oo`1A00;oon<00_l0ojd01_l03ooo0?n]o`3o[Ol0ojgoiOl0o`1Oo`;oEOl00_oonfX2
oooR00Oooo]Z00?oo`25ool0l_oo0?800_oonfX01Om_0?oookX0oonj0?oo^P3o0?mP00;ooo]Z0_oo
06L3oookJP03ool0[ooonf[ooo]Z013ooo]Z00?o0?l9oookJ_oonfX0L?oonfX00ol0o`Wooo]Zoook
JP0@oookJP04ool0[ooonf[ooo]ZoookJP;oo`1W00Oooo]Zo`3oH?l0of3o0;Oooonj0?oonf[oK`3o
00;ooo]Z00?oon@0ool0l_oo08D01ooonfX2oooR00;ooo]Z00KoEOl0o`2foooo08Ko0?o_oookJ_oo
0442o`12o`;ooo]Z0_ooh`001Ooo057oeOl0ool0T?oo093ooo]Z00;o0?lH00Gooo]ZoolT0?oonf[o
oo]ZoolN0002oeD0o`06o`3o=_l0Eooooe40oomA0?oSo`3ooh`00_oo0;P01?l0oi7oo`03oookJ_l0
oe<2oookJP04o`3oh?oo0?3ol`3ooo<0o`;ooe<000kooo]Zool0Looo07?oolD0o`0goooo0<gooo]Z
ol00ool0oeWo`03oo`2Boooonf[of_l0ool0?PCooo]Z0_ookP002?oonf[o0?l/ooo/0?oo7P3oRol0
ool10?oo00co04Co0ooonfX2ool0[0;ooo]Z00Ko9?l0o`2Moooonf[o02gooookJ_ooE002oon600;o
9_l000Goo`3KoookJ_oonf[ooo]Zoo40o`02oookJP04o`18oooo0<Soo`38o`3o:`;ooaH000Cooo]Z
oago0?lMo`3ooo]Z0_l0of`01?oonf[om_l0ooKo0?ofo`04oookJP?o09ko1OoonfX3o`2aoa7ooo]Z
1?l00009oookJP?o0;7o1OoonfX2o`2No`Gooo]Z0_ofo`001Ooonf[o0?m/o`3oK?l0ofcooo]Z00;o
7Ol000?ooo]ZoolF0?oo5P000_oo0<P2o`18o`03oookJ_oa0?ool@3o00?ooo]Z0_oo0=/00olVo`3o
oo]Zoon60002oomD0003o`0]oooo>03o09go00Cooo]Z00Koo`2/oookJ_oonf[ooo]Zo`14oooo00`2
ool10004oolN0?ook03o:03oobP0o`;oonh01?oonfX2ool0?P03om[o0?l0T_oo09;o00;o0?mI00Co
oo]Zool0cOl0=ooo03Oo0ooo07<01?oonf[ooe<0oo<0oooc0?l2ool0l006o`3oh?oonf[o0?mCo`3o
Dooonf[o0?nA0_oo0;P01_ooS03ohol0on?o0?ooD@3o05Ooo`3o=P;oE@3o00?ooah0oookJ_oonfX0
0_oo90000ooonf[o0?lHo`3o6002ool0T004ooWo0?oEo`3oon<0oooS00;ooo]Z0_l0@_l01_oo047o
oo]Zo`3okol0onoo0;KooeGo00;ooo]Z0_oohP08oookJP;oo`3b0_oonfX2ofl0o`;ookX00_l0of00
0ooonf[oo`1Wool0I`03oookJP;oo`2_4OoonfX2o`3o2Ccooo]Z000goookJP;oA?l000?o0?onodCo
0?oonfX03_oonfX01_ooN@3o0?onodCo0?ooN@3ooo]Zo`1Oo`Co0?l<00Go0;3oo`3o3?l0o`co0?l<
ofl0o`02oookJP;oo`3b00?oobP0oookJ_oonfX00_oonfX3ooo90006o`3o3?nDo`3oU?l0oiCo0?l0
ojgoU?l00_l0onl01?oUo`3o0?mMo`12oooUo`02oolX00;oon<000CoobP0o`3hoooo093oo`2@0_l0
oaP00ooonf[oob@0oolT0002oookJP03oolN0?mE0?ooolT000;o05Oo0_ooD@02o`3ooP;oo`2h0_l0
ooh2o`3oD`05oookJ_l0on3o0?oPo`3o3?l0/?l00ol0o``6o`2`o`06onGo0?l0oeWo0?mIonGo0?l0
T_oooo]Z0_oo03h5oookJP03ooo^0?oonf[oon`000;oon`000CoRol0ool10?oo00coo`0<0ooonfX2
ool0[0;ooo]Z1_oob@07oiCo0004o`3o3?oa0?ool@3ooookJP;o04So0_oo0<P2oolF00;oo`000_lM
o`03o`3ooPKoA?l000?oogT0o`1Oool0W_l00_l0W_l3o`3oG@CoiOl00ol0/Ol>oookJPCo00001Ooo
nfX4o`2ao`;ooo]Z2Ol03ol3o`3o[@03oiCo0?l03ooo00oo00?o00oo0_lMo`02oookJP04oolF0?l0
ob_oo`38ool0b0;o04So00?ooo]Zoo40oooa0?l00ooonfX00ooo0=_o9_l0obKo0002oon600;ooe@0
00?o02gooolh0?l0Gol00_oonfX2o`2`o`;o00oo1_l0Gol01?l0ojgoon`0ooo/0?oo:002ooo^00Ko
00oo0_l0ojd4o`1Oo`08ool0cOl0=ooo03Ooooo50?oo07?ooo]Zo`2`ooooD`02oo<0o`;oogT000Co
A?l0oomi0?ooN@3o0;3o1ol0Gol2oomA0003o`1GoomE0?ooE@3o00;ooah01Ol03ol01Ol0oaSoo`2@
ool0T?l0n?ooogT000?oon<000?o00ooo`3o[Ol03ol00_l0ojd00ol0oego05ooonGo0002oeGo00;o
oo]Z0_oohP07oookJP;oo`3b0ooonfX02Om_0?oookX0oonj0?oo^P3o0?mPoookJ_oo06Oooo]Zool0
I`02oookJP;oo`2_4OoonfX2o`3o2G;ooo]Z00?o0?l9oookJ_oonfX04?oonfX00ooo0:oooo]Zoook
JP02oookJP08ool0Iooonf[o0?mPo`3oH?l0]ooookX0oookJ_m_0?l2oookJP03oooT0?oo0?;oo`25
00Oooo]Z0_oohP02oookJP;oEOl000Coo`26o`3okooonf[ooo]Z0_l0@_l2oookJP;oon<000Goo`1A
omGo0?oio`3oo`2@oookJP02o`3o6005oookJ_oo903ooo]ZoookJ_oo7P000_mE0?l01_oonf[o05Oo
oomA0?ooD@3ohol0oomX00;oo`2h00?o0?nAool00ooonfX00_l0oe<01Ooonf[o0?oPool0l?oo0?3o
l`3o00;ooe<00_oonfX01?oo07?oolD0o`0gool0=ol2oookJP06o`3oFOo00?oo09;oo`2BoooJo`3o
o`0n1OoonfX00oookP3ooo]ZobP0o`02ooo/0004oolN0?oo0@3oo`0<ool030?ooo]Z0_oo0:`3oook
JP07obCo0?l0WOoo02goo`0]ooooE03o00Oooon60002obKo00;oo`3K0ooonfX01?oa0?oooo]Zoook
J_l0B?l2ool0b0?ooaH000Cooo]Zoago0?lMo`3ooo]Z0ol0of`3ooKo00Gooo]Z0_l0W_l7oookJPCo
0;7o3OoonfX4o`0000Gooo]Z1Ol0/Ol5oookJP?o09ko1?oonfX3ooKo0005oookJ_l0ofco0?m/o`3o
K?oonfX00_lMo`000ooonf[ooaH0o`3o:`02ool0b0;o04So00?ooo]Zoo40oooa0?l00ooonfX2ool0
f`03obKo0?oonf[oohH000;ooe@00_l0;Ol00ol0WOoooo]ZoookJP02oookJP03ool0[?oonf[ooo]Z
00;ooo]Z0_oo00`01_oo0@3ooah0ooo/0?ook03o:03ooookJP;oonh00ooonfX2ool0?P07om[o0?l0
T_oo09;ool00ool0oeWooo]Zool0c@02o`0go`04ooo50?oo07?oo`1coookJP;ooe<000?ol`3oool0
l?oo0?000_l0on02o`3oD`03oookJ_oo00?o0?nA00;oo`2h00Oooh`0on?o0?ooD@3ooe40o`1Gool0
ocKoE@3o00;ooah00_oonfX2oolT00;o0?lH00Gooo]Zool0T?oo093oeOl0ool0D@02oooS00;ooo]Z
0_l0@_l2oookJP04o`3okooo08KoEOl0oeGo00;ooo]Z0_oohP07oookJP03ool0QOoo0?;ooo]Z00;o
oo]Z0_m_0?l2oonj00;o0?mP00?ooo]Zool0Iooo06L00ooonfX00ooo0:oooo]ZoookJP0@oookJP;o
0?l9??oonfX003Oooo]Z0_m4o`000ol0ookoA?l0oookJP0>oookJP06oomi0?l0ookoA?l0oomi0?oo
nf[o05oo1?l0o``01Ol0/?ooolT0o`1OoooUo`3oK`3o00;ooo]Z0_oo0?82oolX00?ooo]Z0ooob@00
1Ol0o`coU?l0oiCo0?oo:03o0?n]00;oobP000Go0?o_onGo0?l0oego04;oonGo0002oolX00;oon<0
00CoobP0o`3hoooo093oo`2@0ol0oaP01?oonf[oob@0oookJ_oonfX2oolN0003ooo90?l0ocKo05Oo
00;ooe400ol0ooh01_oo0;So0?ono`3oo_l0ooko0?mCoookJP;o0?oP00?o0?l<o`2`ool0o``00ol0
o``6o`2`o`;o0?mI00Co`03oo`2Boooonf[of_l00_oo03h4oookJP03ooo^0?oonf[o:03o00;oon`0
00Cooah0oh_o0?l0A?ooo`0<1?oonfX2ool0[007oookJ_oob@3oolT0ooo90?oo>03o02goooo90005
oiCo00?oobP000Co0?l<oo40oooa0?oooo]Z0_l0B?l2ool0b0;ooaH00_oo0002oago0003o`3oo_m4
o`3oA?l000?oA?l01?ooN@000ol0Gooo09koo`2No`02o`2No`CoiOl00ooonfX5o`2ao`[ooo]Z0ol0
0007o`2ao`Cooo]Z2_l03ol4o`3o[@Co00oo0_lMo`001?oonf[ooaH0oolF0?oonfX2ool0b003o`18
oooonf[ooo]Z00;ol@3o0ooonfX00ooo0=_o9_l0obKo0002oon600;ooe@000Go02gooolh0?l0WOoo
ogT0oookJP03o`2`o`;o00oo1Ol0Gol00ol0ojgooah0ooo/0002oiCo0003ooo^0?oonf[o00oo00Ko
00oo1Ol0Gol00ooo0<go03Ooo`0go`02ool0L`04o`2`ooooD`3oogT0oo<0o`;oogT000?oA?l0oomi
0?ooN@000_ooN@06o`1Oo`03oomA0?ooN@3o05Oo00;oE@3o00?ooo]ZoolN0?l03ol01?l03ol01_l0
oaSoo`2@ool0T?oio`3oA?l0ool0D@;oon<01Ol03ol00ooUo`3o0?mMo`1Oo`02oeGo00;ooo]Z0_oo
hP07oookJP03ool0QOoo0?;oo`3b00;ooo]Z0_m_0?l2oonj0003o`3oH?oonf[ooo]Z00;oo`1W0ooo
nfX2ool0[a7ooo]Z0_l0o`UboookJP03o`3o2Ooonf[ooo]Z013ooo]Z00?oo`2_oookJ_oonfX00_oo
nfX02?oo06Oooo]ZoookJ_l0of3o0;Oooonj0?oonf[oK`3o0ooonfX00ooo0?;oo`25oookJP06oook
JP;oon800_oonfX2oeGo0004ool0Q_l0onoooo]ZoookJP;o04;o0_oonfX2oooS0005ool0DOoEo`3o
nOl0ool0T?oonfX00_l0oaP01?oonf[oob@0oolT0?oonfX2oolN0005oeD0oooonf[o05Ooo`1Goooo
D@000_oSo`001OooS03oo`2hoi3o0?l0oi7ooo]Z00;o0?mC00Gooo]Zo`3oh?l0on3oo`3`oo<0o`02
oomC00;ooo]Z00Koo`1cooo50?l0=ooo03Ooool0cOoonfX2o`3oF@;o09;o00?of_l0ool0?_oo03h0
1?oonfX02_ookP3ooo]ZoookJ_l0obcoon`0oolN0?n;o`3o04Coool03?l0A?l3oookJP;oo`2/0_oo
nfX01_lTo`3o09goo`2Mool0;Ooooo]ZoomD00;oohH00_lVo`001?oo0=_ooo]ZoookJ_oonfX2oo40
o`;ooo]Z00?o04Soool0b?oo0<P00ooo5P001?oonf[o7Ol0oago0?oonfX3o`3oK004oookJ_ofo`3o
m_l0ooKo00Cooo]Z0ol0W_l7oookJPKo0;7o2OoonfX3o`0000So0;7o1_oonfX3o`2No`Gooo]Z0_of
o`000ooonf[o0?m/o`3oK002o`3oK0?o7Ol00_oo5P000ooonf[oo`38ool0b002o`18o`03oookJ_oa
0?ool@3o00?ooo]Z0_oo0=/01OlVo`3ooo]Zoon60?ooQP3ooe@000;o02go0_l0WOl3oookJP;oo`2/
0ooonfX2ool03006ool10?n;o`3ooah0ooo/0?lX0?oooo]Z0_ookP04oookJP;oo`0n00?of_l0o`2B
ool0T_l00_l0oeT01?oonf[oo`3=o`0gool0=ol2ool0L`;ooo]Z00Oooe<0oo<0oooc0?ooo`3`olX0
ool0on3ooo]Z00;o0?mC00Gooo]Zo`3oTOoo0;Soo`2hoon<0002on?o00;ooe4000Co0?lfoeD0oomE
0?oooah00_oonfX2oolT0003oookJ_l0oaSo0?lH00;oo`2@00GonOl0omGo0?ooh`3oon<0oomd0002
oookJP03o`12oooo047ooo]Z00;o0?o_00?o0;KooeGo0?oonfX00_oonfX00ooohP3ooo]ZoookJP06
oookJP;oo`3b0ooonfX00om_0?oooo]Zoonj0002o`3oH0;ooo]Z00Coo`1WoookJ_oonf[ooo]Z0_oo
0:lAoookJP;o0?l9?OoonfX003Oooo]Z0_m4o`000ol0ookoA?l0odCo000=oookJP;oogT000Co0?on
odCo0?ooN@3oogT01?l0Gol01?oob@3o0;3oooo90?l0Gol2onGo00;ooo]Z0_oo0?82oolX00?ooo]Z
0ooob@001Ol0o`coolT0onGo0?oo:03o0?n]00;oobP000?o0?o_onGo0?oUo`000_l0@_l2oolX00;o
on<000?oobP0o`3hoooio`000_oo0902o`3o6004oookJ_oo903ooo]ZoookJP;ooah000?oolT0oeD0
ool0Eol00_ooD@03o`3ooP04ool0^?l0ooko0?ono`3ooP;o0?mC00Go00ooo`3oh?l0o`co0?l<o`2`
o`03o`3o30?o0;3o0_l0o``01?l0GoooA?l0o`3oFOl0oeT2o`2Bo`03oookJ_oo03koo`0n00Cooo]Z
0_ookP001ooonf[oon`0ooo/0?oo7P3oRol0ool10?oo00`01?oonfX2ool0[005oookJ_oob@3oA?l0
o`2Moooo>0000_l0;Ol3oiCo00KoobP000Co0?l<oo40oooonf[ooo]Z0_l0B?l2ool0b0;ooaH00_oo
0002oago00CoA?l01?ooN@04oookJPCo09ko00?oiOl0oookJ_oonfX01_oonfXAo`2ao`Oooo]Z4?l0
3ol01Ooonf[o7Ol0oago0?lMo`3ooo]Z00;ooaH000Cooo]Zool0b?oo0<So04So0_oonfX2oo40o`;o
oo]Z0_oo0=/2obKo00;oohH00_ooE0000ol0;OooocP0o`2Mo`03oomi00;o0;3o0_l03ol5o`1Oo`08
o`3o[Ooo7P3oon`0ooo/0?nDo`3oonh0oiCo0?oonfX7o`0?o`Co05oo00?oo`3=o`0gool0=ol00_oo
07<00ooonf[o0;3ooomC0002oo<0o`03oomi0?m4o`3oogT000?oogT01_l0Gol01?l0/?oooe40oomi
0?l0Eol2oeD0o`;ooah01?l03ol01_ooN@3o0?lHool0T?oo093o0?SoodCo00?oon<01ol03ol00ooU
o`3oEOl0oeGo0002oookJP;oon801ooonfX00ooo08Goo`3boookJP02oookJP05ofl0oooo^P3ookX0
oonj0?l0of000_oonfX2ool0I`?ooo]Z0_oo0:lAoookJP03o`3o2Ooonf[ooo]Z077ooo]Z0_l0o`TA
oookJP03ool0[ooonf[ooo]Z00;ooo]Z00Soo`1WoookJ_oonf[o0?mPo`2goooo^P3ooo]Zofl0o`?o
oo]Z00?oo`3bool0QOoonfX01_oonfX2oooR00;ooo]Z0_mEo`001_l0]_oo0?o_oookJ_oonf[oo`11
o`12o`;ooo]Z0_ooh`000ooo057oeOl0ooWo0002ool0T003oookJ_l0oaSooo]Z00;oob@000?ooo]Z
oolN0?oo7P000_mE0?l2o`1Go`04oomA0?oSo`3ohol0oon<00;oo`2h00So0?nAoookJ_oo01_o0?mC
oookJ_o:0?oo0?oPool0l0;ol`3o0_ooD`000ooonf[oo`1cool0L`02o`0go`09ool0cOoonf[o`03o
o`3oFOo00?oo09;ooookJ_oJo`3oo`0n00Cooo]Z0_ookP000ooonf[o:03oooo/0002oolN0003ool1
0?oo00co04Co00?ooo]Z0_oo0:`3oookJP04obCo0?l0WOoo02goo`0]o`;ooe@000?oohH0oookJ_lV
o`000_oo0=/3oookJP;ol@3o0_oonfX00ol0B?ooo`38ool0b003oolF0004oookJ_lMo`3o7Ol0oook
JP?o0?m/00Cooo]ZooKo0?ofo`3om_l01OoonfX3o`2No`Wooo]Z4Ol0/Ol9oookJP?o09ko1OoonfX3
ooKo0005oookJ_l0ofco0?m/o`3oK?oonfX00olMo`02oolF0003oookJ_oo0<Soo`3800;o04So00?o
oo]Zoo40oooa0?l00_oonfX2ool0f`;o9_l00oooQP000oooE03o02goo`0]o`02o`2Mo`?ooo]Z0_oo
0:`4oookJP04ool03?l0A?ooo`40oolN00;oon`000?o:03oooo^0?ookP001?oonfX2ool0?P07om[o
0?l0T_oo09;ool00ool0oeWooo]Zool0c@02o`0go`04ooo50?oo07?oo`1coookJP;ooe<000Gol`3o
ool0l?oo0?3o0?oPolX0o`02o`3oD`07oookJ_oo00?o0?nAool0^?ooS03oofP0on?o0002oomA0005
o`1Gool0ocKoE@3ooeD0oooo7P000_oonfX2oolT0003oookJ_l0oaSooo]Z00;oo`2@00CoeOl0ool0
DOooh`3oon<00_oonfX2o`12o`;ooo]Z0_l0onl01?l0]_ooEOl0oookJ_oonfX2oooR00Sooo]Z0_oo
0?82oookJP;oK`3o0_oo^P02o`3oH0;ooo]Z00Coo`1WoookJ_oonf[ooo]Z0_oo0:lAoookJP;o0?l9
?OoonfX003Oooo]Z0_m4o`000ol0ookoA?l0odCo000=oookJP;oogT000Co0?onodCo0?ooN@3oogT0
1?l0Gol01?oob@3o0;3oooo90?l0Gol2onGo0004oookJ_oo:03oo`3bool0lP?oobP00_oonfX3ooo9
0005o`3o3?oob@3oobP0oolX0?l0ojd00ooo:0001?l0onooiOl0o`12ool0@_l2oolX0005oomd0?oo
h`3oU?l0oolX0?oio`000_oo0902o`3o6004oookJ_oo903oob@0oookJP;ooah000?oolT0oeD0ool0
Eol00_ooD@03o`3ooP;oo`2h0ol0ooh00ol0oe?o00ooo`3oh002o`3o3003o`2`ool0o`co0?l<00;o
0?l<00Co0;3oo`3o3?l0o`co0?l<0_l0Gol2o`3oF@05o`3o9Ol0T_oooo]Zom[o0?oo03h01OoonfX0
0oookP3ooo]ZobP0o`02ooo/0004oolN0?oo0@3o04Coool030Cooo]Z0_oo0:`01ooonf[oA?l0odCo
0?l0WOooocP0o`0]oonDo`002Ooo:002oo40o`;ooo]Z0_l0B?l3ool0b003oolF0?oo003oo`0000;o
7Ol000?oA?l0oomi0?ooN@000oooN@02ooKo00Cooo]Z0_oUo`03o`2No`gooo]Z1Ol0/Ol4o`0000Oo
oo]Z3Ol03ol2ooo900;o0?m/00Cooo]Zoago0?lMo`3ooo]Z0ooo5P02ool0b0;o04So00Cooo]Zoo40
oooa0?ool@3o0_oonfX2ool0f`;o9_l00_ooQP001?ooE03o02goo`0]oooo>002o`2Mo`;oogT00ol0
/?l2o`0?o`Co05oo00Go0?n]oolN0?ook03oon`0oiCo0002ooo^0003odCo0?l03ooo00oo00Ko00oo
0ol0Gol01?oonf[oo`3=o`0gool0=ol2ool0L`03oookJ_ooD`3ooe<000;ol`3o00?oogT0odCo0?oo
N@000oooN@05o`1Oo`09o`2`ooooD@3oogT0o`1Gool0oegoE@3ooookJ_oo7P3ooo]Z00Co00oo0_l0
oaP01?oo093onOl0o`3hoooo0542oooS00So00oo00?o0?mMoeGo0?oonfX00_oonfX00ooohP3ooo]Z
oookJP06oookJP;oo`3b0ooonfX00om_0?oookX0oonj0002o`3oH003oookJ_oo06Ooo`1W00?ooo]Z
0_oo0:lAoookJP;o0?l9LooonfX2o`3o2A7ooo]Z00?oo`2_oookJ_oonfX00_oonfX01Ooo06Oooo]Z
oookJ_l0of3o0;Oo00;ookX000CoK`3ooookJ_oonf[ooo]Z0_oo0?87oookJP;oon800ooonfX01omE
o`3o0;Koo`3okol0onoooo]Zool0@Ol0@_l00_oonfX02?ooM03oon<0oooS0?oo057o0?SoooWo0?oo
093ooo]Z0_l0oaP2oolT0003oookJ_oo7P3ooah000;oE@3o00Ko0?lfo`1GooooD@3ooo]Zon?o0?oo
J002ool0^00:o`3oTOoonf[ooo]Zo`3oDooo01_ooo]Zo`3oh?oo0?3ooj40oo<0o`;ooe<00_oonfX0
1?oo07?oolD0o`0gool0=ol2oookJP06o`3oFOo00?oo09;oo`2BoooJo`3oo`0n1OoonfX02OookP3o
oo]ZobP0ool0obcoon`0oolN0?n;o`3oo`40ool03004oookJP;oo`2/0ooonfX2o`2Mo`;o02go00Go
oe@0oon60?ooQP3ooo]ZobKo0002ool0f`?ooo]Z0_oa0?l2oookJP04o`18oooo0<Soo`38ool0b0;o
oaH000Cooo]Zoago0?lMo`3ooo]Z1?l0of`01?oonf[om_l0ooKo0?ofo`05oookJPCo09ko3?oonfX5
o`2ao`Co00002?oonfX5o`2No`Cooo]Z0oofo`02oookJP?o0?m/00Cooo]Zoago0?lMo`3ooo]Z0_oo
5P000ooonf[oo`38oookJP02o`18o`03oookJ_oa0?ool@3o00;ooo]Z0_oo0=/2obKo00?oohH000Go
oe@0o`0]ool0;OooocP0o`2Mo`04oookJP;oo`2/0ooonfX2ool03007ool10?oo7P3oon`0ooo/0?lX
0?oooo]Zooo^0005oookJP;oo`0n00?of_l0o`2Bool0obD00_l0oeT01?oonf[oo`3=o`0gool0=ol2
ool0L`03oookJ_ooD`3ooe<000;ol`3o00?oo`3`o`3oh?l0on000_l0oe<00ooo01_ooo]Zo`3oT@02
ool0^006oon<0?oSo`3ohol0oomA0?l0Eooo0?lf0_mE0?l00ooo7P3ooo]ZoookJP02oolT0003oook
J_l0oaSo0?lH00;oo`2@00GonOl0omGo0?ooh`3oon<0oomd0002oookJP06o`12oooo047ooo]Zoook
J_l0onoo0;Ko0_mEo`02oookJP03oooR0?oonf[ooo]Z00Kooo]Z00?oo`25ool0l_oonfX00_oonfX2
ofl0o`06oonj0?l0]ooo0?mPo`3oH?oonf[oo`1W1?oonfX00ooo0:oooo]ZoookJP0@oookJP;o0?l9
?OoonfX003Oooo]Z0_m4o`000ol0ookoA?l0odCo000=oookJP;oogT000?o0?onodCo0?ooN@000_oo
N@03o`1Oo`04ooo90?l0/?ooolT0ooo900?oiOl00_oo:002ool0lP;oobP00_oonfX3ooo90006o`3o
3?oob@3oobP0oolX0?l0ojgoU?l00_oo:0001?l0onoooo]Zo`12ool0@_l2oolX0005oomd0?ooh`3o
U?l0oolX0?oio`000_oo0902o`3o6003oookJ_oo903oob@000;ooo]Z00Cooah0oookJ_oob@3o0?lf
0oooD@02o`3ooP;oo`2h0om4o`000ol0oe?o00ooo`3oh002o`3o3003o`2`ool0o`co0?l<00Oo0?l<
00Co05ooo`3oFOl0oeWo`03o0_l0T_l00ooJo`3oo`0nool0?P04oookJP;oonh000Kooo]Zooo/0?oo
k03o0;3ooh_o0?oo0@02ool030?ooo]Z0_oo0:`2oookJP;oA?l000?o09goo`0]ool0;Ol01ooo:003
ooo900;ol@3o0_oonfX2o`18o`?oo`380_oo5P001?oo003o7Ol0oago0?oo0003oomi00;ooo]Z0oof
o`03oookJP04onGo0?oonf[ooo]ZoookJP?o09ko3ooonfX4o`0000Cooo]Z0_l0W_l:o`0?o`03ooKo
0?l03ooo00oo00?oolT00_oonfX2oago0004oookJ_oo5P3ooaH0oolF00;oo`380_l0B?l01?oonf[o
l@3ooo40oooa0?l2oookJP;oo`3K0_lVo`02oon60004oomD0?l0;Ooo02goo`0]o`;o09go0oooN@02
o`2`o`?o00oo0ol0Gol2o`0?o`07oolN0?ook03o0?n]oiCo0?ookP3oU?l0odCo0007o`0?o`05ol00
ool0Gooo05oooookJ_oo0<d00_l0=ol2ool0L`03oookJ_ooD`3ooe<000;ol`3o00?oogT0odCo0?oo
N@000oooN@000ol0/?oo05ooo`1Oo`03o`1Oo`04o`2`ooooD@3oogT0o`3oG@;oE@3o0_oo7P001_oo
nf[o00ooo`0?ool03oooogT0odCo00;oo`2@00GonOl0odCo0?oo057oon<0oomd0007o`0?o`05o`3o
GOmEo`3oEOl0o`3oGOoonfX00_oohP07oookJP03ool0QOoo0?;oo`3b00;ooo]Z0_m_0?l2oonj0003
o`3oH?oonf[ooo]Z00;oo`1W0ooonfX2ool0[a7ooo]Z0_l0o`UcoookJP;o0?l94OoonfX2ool0[`?o
oo]Z0_oo06L00ooonf[o0?mPo`2go`02oonj00;oK`3o0_oonfX2ool0lP03ool0QOoonf[ooo]Z00Co
oo]Z0ooohP02oookJP07oeGo0?l0]_oo0?o_o`3okooonf[oo`11o`12o`02oookJP08oomd0?ooh`3o
on<0ool0DOoEo`3onOl0ool0T?oonfX2o`3o6004oookJ_oo903ooo]ZoookJP;ooah000?oE@3oo`3o
=_l0Eol00_ooD@001ooSo`3oofP0oon<0?oo0;So0?nAool00ooonfX00_l0oe<01Ooonf[o0?oPool0
l?oo0?3ol`3o00;ooe<00_oonfX02?oo07?oolD0o`0gool0=oooo`3=oookJ_l0oeWo`03o0_l0T_l0
0ooJo`3oo`0nool0?P04oookJP;oonh000Kooo]Zo`3o;?ook03ooah0oh_o0?oo0@02ool030?ooo]Z
0_oo0:`3oookJP04obCo0?l0WOoo02goo`0]o`;ooe@00_ooQP02obKo00;oo`3K0ooonfX2oo40o`;o
oo]Z00Co04Soool0b?oo0<Soo`380_oo5P02oookJP03oago0?oonf[ooo]Z00?o0?m/0_oonfX3ooKo
00Kooo]Z1?l0W_l>oookJPCo00001?oonfX6o`2No`Gooo]Z1?ofo`001Ooonf[o0?m/o`3oK?l0ofco
oo]Z00?o7Ol00ooo5P02ool0b0;o04So0_oonfX2oo40o`;ooo]Z0_oo0=/2obKo00;oohH000Ko00Oo
oomD0?l0;Ooo02gooolh0?l0WOl4oookJP;oo`2/0ooonfX2ool030;oo`4000Cooah0ooo/0?lX0?oo
:03o0_ookP04oookJP;oo`0n00?of_l0o`2Bool0T_l00_l0oeT01_oonf[oo`3=o`0gool0=oooolD0
ool0L`;ooo]Z0_ooD`001Ooc0?ooo`3`ool0l?l0on3obP3o00;o0?mC00Coo`0Kool00ol0oi7oo`2h
0_ooS0001OoSo`3ooe40oomA0?l0Eooo0?lf00;oE@3o00?ooah0oookJ_oonfX00_oo90000ooonf[o
0?lHoookJP02ool0T005o`3hoooo057oon<0oooS0?ooM0000_oonfX00ol0@_ooo`11oookJP02o`3o
k`04o`2foomEo`3ooo]ZoookJP;oon802?oonfX2ool0lP;ooo]Z0_m_0?l2oonj00;o0?mP0_oonfX0
1?oo06Oooo]ZoookJ_oonfX2ool0[a7ooo]Z0_l0o`TnoookJP00=ooonfX2odCo0004o`3oo_m4o`3o
A?l0odCo00cooo]Z0_ooN@000ol0ookoA?l0oomi0002oomi00;o05oo0_oob@001?l0/?ooolT0ooo9
0?l0oed2onGo00;oobP000?o0?onool0l_oo:0000_oo:0001_oonf[oolT0ooo90?oonf[oon80o`3o
30?oobP000GoU?l0oolX0?oo:03oobP0oookJP02o`12o`?oobP00_ooh`001OoEo`3onOl0ool0T?oo
093ooo]Z00;o0?lH00Cooo]ZoolT0?oonf[ooo]Z0_oo7P000ooob@3ooo]Zo`1Go`02oomA00;oA?l0
00?o0?onool0^?m4o`000_m4o`02o`3oD`03o`3oh?l0o`co0?l<00?o0?l<00?oolT0o`3o3?l0/?l0
1?l0o``2o`1Oo`;o0?mI0_l0T_l00ooonf[of_l0ool0?P05oookJP03ooo^0?oonf[oon`000;oon`0
00Co0;3oool10?oo00coo`0<1?oonfX2ool0[003oookJ_m4o`3oA?l000;o09go0_l0;Ol4oolX0003
obKo0?oob@3oolT000?oolT00_oa0?l2oookJP;o04So0ooo0<P2oolF0005ool00?lMo`3o7Ol0ool0
0?ooN@000_l0of`2oookJP?om_l02OoonfX6o`2No`Wooo]Z1?l00005o`2No`Co00oo1?oonfX3ooKo
0003oookJ_l0o`co0?l<00CoolT000?o7Ol0oookJ_oonfX00_oo5P001?l0ob_oo`38o`18ool0B?l2
oookJP03oo40ooooN@3ol@3o00;ooo]Z0_oo0=/2obKo0003oon60?ooE03ooe@000?o02go0_l0WOl0
1_m4o`3oogT0oomi0?oonf[o0;3oool0[0;o00oo0ol0Gol3o`0?o`03ooo/0?l0ojgoU?l000;oonh0
0_m4o`06o`0?o`05ol00ool0Gooo05oooookJ_oo0<d00_l0=ol01_ooa@3oo`1cool0Looonf[ooe<0
odCo00;ol`3o00?oogT0odCo0?ooN@000_ooN@000ooonf[o0;3oo`1Oo`03o`1Oo`09o`2`ooooD@3o
ogT0o`1Gool0oegoE@3oonGo0?oo7P3oogT000?o00oo00OoogT0odCo0?m4o`3oo`2@ooWo0?l0n?oo
0?on00;oon<000?oog@0o`0?ool03ol01?l03ol01_l0Gooo0?mMoeGo0?mEo`3o0?mMoookJP;oon80
1ooonfX2ool0lP?ooo]Z00KoK`3ooonj0?oo^P3o0;Ooo`3oH?oonfX2ool0I`Cooo]Z0_oo0:l@oook
JP;o0?l9M?oonfX2o`3o2A7ooo]Z0_oo0:l3oookJP;oo`1W00?ooo]Zo`3oH?oonfX00_oo^P02ofl0
o`;ooo]Z0_oo0?800ooo08Gooo]ZoookJP05oookJP;oon800_oonfX01omEo`3o0;Koo`3okol0onoo
oo]Zool0@Ol0@_l00ooonfX2oooS0004ool0DOoEo`3onOl0ool0T0;ooo]Z00?o0?lHoookJ_oo9000
0_oonfX2oolN0008oeD0oooonf[o05Ooo`1GooooD@3ohol0oomX0?ooS002ool0^005o`3oTOoonf[o
o`0Ko`3oDooonfX00_l0on001?oo0?3ol`3oool0eoooD`02oookJP0=ool0Loooa@3o03Ooo`0goooo
0<gooo]Zol00ool0oeWo`03oo`2Boooonf[of_l0ool0?P05oookJP03ooo^0?oonf[o:03o00;oon`0
00Cooah0ool10?oo00coo`0<1?oonfX2ool0[0?ooo]Z0_l0WOl2o`0]o`;ooe@000GoohH0oookJ_lV
o`3ooo]Zool0f`04oookJP;ol@3o0_oonfX01?l0B?ooo`38ool0b?oo0<P2oolF00;ooo]Z0_lMo`00
1?oonf[o0?m/o`3oK?l0of`2oookJP?om_l02?oonfX6o`2No`Wooo]Z1?l00007o`2No`Oooo]Z0oof
o`001?oonf[o0?m/o`3oK?l0of`2oookJP;o7Ol000Cooo]ZoolF0?oo5P3o0?l[0_oo0<P2o`18o`;o
oo]Z0_oa0?l2oookJP;oo`3K0_lVo`02oon600;ooe@00_l0;Ol00ooo>03o09goobCo0003oookJP;o
o`2/0ooonfX3ool03007ool10?oo7P3oon`0ooo/0?lX0?oooo]Zooo^0004oookJP;oo`0n00Cof_l0
o`2Bool0T_oo`03o0_l0oeT01?oonf[oo`3=o`0gooooa@02ool0L`03oookJ_ooD`3ooe<000;ol`3o
00?oo`3`o`3oh?l0on000_l0oe<00ooo01_ooo]Zo`3oT@02ool0^006oon<0?oSo`3ohol0oomA0?l0
Eooo0?lf0_mE0?l00ooo7P3ooo]ZoookJP02oolT0003oookJ_l0oaSo0?lH00;oo`2@00GonOl0omGo
0?oo057oon<0oomd0002oookJP;o04;o0_oonfX01?l0onoo0;KooeGo0?mEo`02oookJP;oon801ooo
nfX00ooo08Goo`3boookJP02oookJP;oK`3o0_oo^P02o`3oH003oookJ_oo06Ooo`1W00?ooo]Z0_oo
0:lAoookJP;o0?l9?_oonfX003Oooo]Z0_m4o`001?l0ookoA?l0odCo0?m4o`0<oookJP?oogT000Co
A?l0oomi0?ooN@3oogT00_l0Gol2ooo90004o`2`oooob@3oolT0ooo900?oiOl000?oobP0o`3oo_oo
0?800ooo:005oookJP05o`3o3?oo:03oobP0oolX0?nDo`000ooo:0001?oonf[o04;oo`12ool0@_l2
oookJP04oomd0?ooh`3ooo]ZomGo00;oo`2@00Gooo]Zo`3o6?l0oaSooo]ZoolT0002oookJP;ooah0
00?oolT0oookJ_l0Eol00_ooD@001?oSo`3oA?l0odCo0?oo0;P3odCo00;o0?mC00Go00ooo`3o3?l0
o`coolT0o`3o3003ooo90003o`3o3?l0/?oo0?l<00?o0?l<00So05ooo`3oFOl0oeWo0?lUo`2Boooo
nf[of_l0ool0?PGooo]Z0_ookP000olX0?ooon`0ooo/0002o`2`o`03ool10?oo00coo`0<00Cooo]Z
00Soo`2/oookJ_m4o`3ooo]Zooo90?l0WOooocP0o`0]o`?oobP000?oolT0obKo0?lVo`000_oob@03
oookJP;ol@3o0_oonfX00ol0B?ooo`00ool0b002ool0b0;ooaH00_oo0002oago0004oookJ_l0ofco
0?m/o`3oK0;ooo]Z1?ofo`09oookJQ7o09ko2_oonfX3ooKo00;o0;3o0ol0o``4ooo90004oookJ_oo
5P3ooaH0oolF00;oo`380_l0B?l2oookJP;ol@3o00?oogT0oookJ_oonfX00_oo0=/00olVo`3ooo]Z
oon60002oomD00?o02go0_l0WOl3odCo0003oookJ_l0/?ooo`2/00?o00oo0_l0Gol3o`0?o`03ooo/
0?l0ojgo0?n]00;oonh000?ooo]ZodCo0?l03ol01Ol03ol00oooN@3o`03oo`1Oo`02oookJP03ool0
cOl0=oooolD000;oo`1c00?ooo]ZoomC0?ooD`000_oc0?l2odCo0004o`3oo_ooN@3oogT0o`3oD`;o
0;3o0ol0Gol2o`2`o`03oomi0?ooD@3o05Oo00;oE@3o0_oo7P001_ooN@3o00ooo`0?ool03oooogT0
odCo00;oo`2@00?onOl0o`3hoooo05400_ooh`06o`0?o`06o`1Oool0oegoEOl0oeGo0?l0oegooo]Z
0_oohP07oookJP03ool0QOoo0?;oo`3b00?ooo]Z00?oK`3ooonj0?oo^P000_l0of000ooonf[oo`1W
ool0I`03oookJP;oo`2_4OoonfX2o`3o2GCooo]Z0_l0o`TAoookJP;oo`2_0ooonfX2ool0I`03oook
J_l0of3o0?mP00;ookX00_m_0?l2oookJP;oo`3b00?oo`25oookJ_oonfX01OoonfX2oooR00;ooo]Z
0_mEo`02o`3ok`04oookJ_oo047o04;oo`12o`;ooo]Z00Koog@0oooS0?oo057oeOl0ooWo0?oo0902
oookJP05o`3o6?oonf[oob@0oolT0?oonfX00_oo7P002?mE0?oooo]Zo`1Gool0Eooooe40oookJ_oS
o`3ooh`00_oo0;P01?l0oi7ooo]ZoookJ_l0oe<2oookJP04o`3oh?oo0?3oo`3Goo<0o`;ooe<00_oo
nfX01?oo07?oolD0o`0gool0=ol2oookJP05o`3oFOo00?oo09;oo`2BoooJo`000_oo03h4oookJP;o
onh000Kooo]Zo`3o;?ook03ooah0oh_o0?oo0@02ool030Cooo]Z00?oo`2/oookJ_oonfX00_oonfX0
2ol0WOooocP0o`0]ool0;Ooooe@0o`07ooooQP3ooo]ZobKo0?oonf[oo`3K00Cooo]Z0_oa0?l2oook
JP04o`18oooo0<Soo`38ool0b0?ooaH000?ooo]Zoago0?lMo`000_oonfX3o`3oK0;ooo]Z1?ofo`08
oookJQ;o09ko2OoonfX4ooKo00;ooo]Z0_l0of`2oookJP;o7Ol00_oonfX2oolF00?oo`3800?o04So
oookJ_oonfX00_oa0?l3oookJP;oo`3K0_lVo`02oon600;ooe@00_l0;Ol00ooo>03o09goobCo0003
oookJP;oo`2/0ooonfX01Ol0A?ooo`0<ool03?oo0@3ooah000;oon`000?o:03ooookJ_ookP001Ooo
nfX01Ooo03kof_l0o`2Bool0T_oo0?lU00;o0?mI00Kooo]Zool0cOl0=ooo03Ooooo50?oo07<2oook
JP03oomC0?oc0?ool`3o00;oo`3`00So0?oPoookJ_l0oe?o0?mCool06ooo00?o0?nAool0^0;ooh`0
00Cohol0oomA0?ooD@3o05Oo0_mE0?l2oolN00;ooo]Z0_oo90000ooonf[o0?lHoookJP02ool0T005
ooWo0?oEo`3oon<0oooS0?ooM0000_oonfX00ol0@_ooo`11oookJP02o`3ok`03o`2foomEo`3ooo]Z
00;ooo]Z00?oon80oookJ_oonfX01_oonfX2ool0lP?ooo]Z00CoK`3ooonj0?oo^P3o0;Oo0_l0of00
0ooonf[oo`1WoookJP02oookJP;oo`2_4_oonfX00ol0o`Wooo]ZoookJP0moookJP00=ooonfX3odCo
0004o`3oo_m4o`3oA?l0odCo00_ooo]Z0oooN@000om4o`3oogT0oomi0002oomi0005o`1Ooooob@3o
olT0o`2`ool0o``00_oob@03onGo0003oolX0?l0ooko0?on00CoobP01?oonfX01Ol0o`coobP0oolX
0?oo:03oU?l000CoobP000?o0?mMo`12ool0@_l00_oonfX01?ooM03oon<0oookJ_oEo`03ool0T0;o
0?lH00Cooo]ZoolT0?oonf[ooo]Z0_oo7P02oeD0o`04o`1GooooD@3ooe40on?o00;oA?l00_oo0;P0
1Om4o`3oogT0o`3oDol0oe?o00oo00;o0?oP0_oob@001Ol0o`coolT0ooo90?l0o`co0;3o00Go0?l<
0_l0oeT01?o00?oo09;oo`2BoooJo`02ool0?PCooo]Z0_ookP000ooonf[oo`00ooo/0002o`2`o`03
ool10?oo00coo`0<00Cooo]Z0_oo0:`2oookJP06oomi0?l0WOoo09gooolh0?l0;Ooooe@00ooob@02
obKo00;oo`3K0ooonfX2oo40o`;ooo]Z00?o0;3oool00?oo00000_oo0<P3oolF0005oookJ_lMo`3o
7Ol0oago0?oonfX00ol0of`2oookJPGom_l03?oonfX5o`2No`03oookJ_l0003o000000;o00002?oo
nfX4ooKo00Co0;3o0ol0o``5ooo90004oolF0?oo0<Soo`38ool0b0;o04So00Cooo]Zoo40oooa0?oo
l@3o0oooN@02ool0f`03obKo0?oonf[oohH000;ooe@00ol0;Ol2o`2Mo`CoA?l00_oo0:`01Ooonf[o
00ooo`0?ool03ooo05oo00?o00oo0_ook0000ol0ojgoonh0ooo^0002oookJP03odCo0?l03ooo00oo
00?o00oo00KoA?l0ol00ool0oeWo0?mIoookJ_oo0<d2o`0go`;oo`1c0_oonfX00oooD`3oA?l0oo<0
o`03odCo0005o`3oo_m4o`3o0?mCooo90?l0/?l00ol0Gol2o`2`o`04oomA0?ooN@3o05OoonGo00;o
E@3o00?ooah0oookJ_ooN@000_l03ol2oomi0005odCo0?oo093onOl0o`3hool0ooh00_ooh`000ooo
M03o00ooo`0?o`04o`0?o`04o`1Oool0oegoEOl0oeGo00;ooo]Z0_oohP07oookJP03ool0QOoo0?;o
o`3b00;ooo]Z00GoK`3ooookJ_oo^P3o0;Ooo`3oH002oookJP;oo`1W0ooonfX2ool0[a7ooo]Z0_l0
o`UdoookJP;o0?l94OoonfX2ool0[`?ooo]Z0_oo06L00ooonf[o0?mPo`3oH002oonj00;oK`3o0_oo
nfX2ool0lP03ool0QOoonf[ooo]Z00Gooo]Z0_oohP02oookJP;oEOl00_l0onl01?oonf[oo`11ool0
@Ol0@_l2oookJP03oomd0?ooh`3oon<000;oeOl00_oo09000ooonf[o0?lHoookJP02oolT00;ooo]Z
00?ooah0oeD0oomE0?l00_l0Eol2oomA0007on?o0?ooJ03oo`2hool0^?l0oi7oo`03oookJP02o`3o
D`05oookJ_l0on3oo`3`ool0l?oc0?l00_ooD`02oookJP06ool0Loooa@3o03Ooo`0goooo0<gooo]Z
0_l0oeT00ol0obGo09;oom[o0002ool0?PCooo]Z0_ookP001_oonf[o:03oooo/0?ook03ooah0ool1
00;oo`0<00Co04CooookJ_oonf[ooo]Z0_oo0:`3oookJP04obCo0?l0WOooocP0o`0]o`;ooe@000Co
00Oooon60?oonf[o9_l00ooo0=/3oookJP;ol@3o0_oonfX2o`18o`;oo`380ooo5P001?oonf[o7Ol0
oago0?lMo`02oookJP?o0?m/0_oonfX5ooKo00_ooo]Z1_l0W_l4o`0000Wooo]Z1?ofo`000ooonf[o
0?m/o`3oK002o`3oK005oookJ_lMo`3o7Ol0oago0?oonfX00_oo5P001Ol0ob_oo`38ool0b?oo0<So
04So00;ooo]Z0_oa0?l3oookJP;oo`3K0_lVo`02oon600;ooe@00_l0;Ol2o`2Mo`04obCo0?oonf[o
oo]ZoookJP;oo`2/0ooonfX01Ol0A?ooo`0<ool03?oo0@3ooah000?oon`000?ooo]Zooo^0?ookP00
1?oonfX2ool0?P03om[o0?l0T_oo09;o00?o0?mI00Gooo]Zool0cOl0=oooolD0ool0L`02oookJP;o
oe<000?ol`3oool0l?oo0?000_l0on02o`3oD`03ool06ooonf[o0?nA00;oo`2h00Kooh`0on?o0?oS
o`3ooe40o`1Gool0ocH2oeD0o`03oolN0?oonf[ooo]Z00?oob@00_l0oaP2ool0T004ooWo0?oEo`3o
o`1AoooS00;oog@000?ooo]Zo`12ool0@_l00_oonfX01?l0onooo`26oeGo0?mEo`02oookJP;oon80
2?oonfX2ool0lP;ooo]Z0_m_0?l2oonj00;o0?mP0_oonfX01?oo06Oooo]ZoookJ_oonfX2ool0[a7o
oo]Z0_l0o`TooookJP00=_oonfX4odCo0004o`3oo_m4o`3oA?l0odCo00_ooo]Z0oooN@000om4o`3o
ogT0o`1Oo`03o`1Oo`;oolT000?o0;3oo`3o3?oob@000_oob@03onGo00;o0?on1?oo:004oookJP05
o`3o3?oo:03oobP0oolX0?nDo`001?oo:0000ooo047o04;oo`12o`02oookJP05oomd0?ooh`3oo`1A
omGo0?oio`000_oo0902o`3o6003oookJ_oo903oob@000;ooo]Z00Oooah0oookJ_mE0?oo0?lfo`1G
ooooD@3ohol000;oA?l000OoT?l0ool0^?m4o`3oA?l0oomi0?l0oe?o00oo00;o0?oP0_oob@001?l0
o`coolT0ooo90?oob@04o`3o3003o`0gool0Gooo05oo00;o0?mI0_l0T_l00ooonf[of_l0ool0?P05
oookJP05ooo^0?oonf[oo`00ooo/0?oo00000_l0/?l00ooo0@3oo`0<ool03004oookJP03ool0[?oo
nf[ooo]Z00;oogT00_l0WOl2o`0]o`04oomD0?oob@3oohH0oon600;o9_l00_oo0=/3oookJP?ol@3o
00Co0;3oool00?oo003oo`000_oo0<P3oolF00;ooo]Z0_lMo`02oookJPCo0?m/00?ooo]ZooKo0?of
o`001?ofo`0?oookJPCo00001OoonfX4ooKo00;ooo]Z1Ol0/?l4o`3o30CoolT00_oo0<P3o`18o`04
oookJ_oa0?ool@3oodCo00CoogT00_lVo`001?oonf[oohH0oomD0?ooE002o`0]o`03oolh0?l0WOoo
09go00CoA?l00_oo0:`01Ooonf[o00ooo`0?ool03ooo05oo00;o00oo0_oo7P001?ook03o00ooo`3o
[OookP02o`3o[@;oA?l01?l03ol2odCo00;o0?mI00Kooo]Zool0cOl0=ooo03Ooooo50?oo07<2oook
JP;ooe<00_oc0?l2odCo0006o`3oo_m4o`3oA?l0odCo0?oob@3o0;3o0_ooN@02o`2`o`04ooo90?oo
N@3ooe40o`1Go`;oE@3o0_oo7P000oooN@3oob@0o`0?o`02oomi0006odCo0?oo093oo`2@ooWo0?l0
ookoo`1A0_ooh`06o`0?o`03o`1Oool0oegoEOl000;oEOl00_oonfX2oooR00Kooo]Z00?oo`25ool0
l_oo0?800ooonfX00om_0?oookX0oonj0002o`3oH003oookJ_oo06Ooo`1W00Cooo]Z00?oo`2_oook
J_oonfX03ooonfX3o`3o2GCooo]Z0_l0o`TBoookJP04ool0[ooonf[ooo]ZoookJP;oo`1W00Cooo]Z
o`3oH?l0of3o0;Oo0_oo^P001?m_0?oooo]ZoookJ_ooi002ool0lPOooo]Z0_oohP03oookJP07oeGo
0?l0]_oo0?o_o`3okooonf[oo`11o`12o`03oookJP;oon<000Goo`1AomGo0?oio`3oo`2@oookJP02
o`3o6004oookJ_oo903ooo]ZoookJP;ooah000?oE@3oo`3o=_l0Eol00_ooD@001ooSo`3oofP0oon<
0?oo0;SoT?l0o`3oTOoonfX00_l0oe<01?oonf[o0?oPo`3oh?oo0?02oo<0o`03oomC0?oonf[ooo]Z
00;oo`1c0_l0=ol02?oo0<gooo]ZoookJ_l0oeWo`03oo`2Boooonf[of_l00_oo03h4oookJP08ooo^
0?oonf[o:03oo`3o;?ook03ooah0oh_o0?oo0@02ool030Cooo]Z0_oo0:`3oookJP04obCo0?l0WOoo
02goo`0]o`;ooe@00_ooQP000ooonf[o9_l0ool0f`02ool0f`?ooo]Z0ooa0?l00ooonf[o04Soo`18
o`02ool0b0CooaH000Gooo]Zoago0?lMo`3o7Ol0oookJP05o`3oK003oookJ_ofo`3om_l000Com_l0
3_oonfX4o`0000Kooo]Z1?ofo`02oookJPCo0?m/00Gooo]Zoago0?lMo`3o7Ol0oookJP03oolF0003
oookJ_oo0<Soo`3800;o04So00Cooo]Zoo40oooa0?ool@3o0ooonfX2ool0f`;o9_l00_ooQP02oomD
00;o02go0_l0WOl01?lTo`3ooo]ZoookJ_oonfX2ool0[0?ooo]Z00Co04Coool03?oo00coo`400_oo
7P02ooo/0003oookJ_ookP3oonh000Gooo]Z00Goo`0nom[o0?l0T_oo09;ool00o`02o`3oF@04oook
J_oo0<go03Ooooo500;oo`1c00?ooo]ZoomC0?ooD`000_oc0?l01?oo0?3o0?oPo`3oh?oonfX2o`3o
D`07oookJ_l0oi7o0?nAool0^?ooS03oofP0on?o0002oomA0005o`1GoomE0?ooE@3ooeD0oooo7P00
0_oonfX2oolT00;o0?lH00Gooo]Zool0T?oo093o0?SooookJP02oooS0006oomd0?oonf[ooo]Zo`12
oooo047ooo]Z0_l0onl00ol0]_ooEOl0oeGo0002oookJP;oon801ooonfX2ool0lP?ooo]Z0_m_0?l2
oonj00;o0?mP00?ooo]Zool0Iooo06L00ooonfX00ooo0:oooo]ZoookJP0@oookJP;o0?l9?ooonfX0
03Kooo]Z1?m4o`001?l0ookoA?l0odCo0?m4o`0;oookJP;oogT000?ooo]ZodCo0?ooN@001?l0Gol3
ooo90005o`3o3?oob@3oolT0ooo90?l0Gol00_oo:003o`3ooPCoobP00ooonfX01Ol0o`coobP0oolX
0?oo:03oU?l000GoobP00_l0@_l3oookJP;oon<000GoeOl0ooWo0?oo093oo`2@oookJP02o`3o6004
oookJ_oo903ooo]ZoookJP;ooah000?oE@3oo`3o=_l0Eol00_ooD@02odCo0003o`3oo_oo0;SoA?l0
00;oA?l00_l0oe<01Ol03ooo0?oPooo90?oob@3o0?l<00?oolT000?o0?l<ooo90?l0o``00_oob@02
o`1Oo`;o0?mI00Co`03oo`2Bool0T_oooo]Z0_oo03h4oookJP;oonh01?oo00001?l0/?ooo`40ool1
0?oo00`4oookJP;oo`2/0_oonfX02?ooN@3o09goo`2Moooo>03o02goo`2`ooooE03o00Oo0_ooQP02
obKo00;oo`3K0ooonfX3oo40o`03o`2`oooo003oo`0000;oo`0000Koo`38oolF0?oo5P3ooaH0o`3o
:ooonfX3oago00?ooo]Z0ol0of`2oookJPOom_l02ooonfX3oomi0003o`000?ofo`3om_l000Com_l0
0_oonfX00ol0ofco0;3oo`2`o`06o`2`o`?o0?l<0_oob@03ool0b0;o04So00Cooo]Zoo40oooa0?oo
l@3o0_m4o`03oomi00;o9_l00_ooQP02oomD00;o02go00CoocP0o`2Mool0ooko0?on0om4o`02ool0
[0;ooo]Z0_l03ol00ooo00co00ooo`0?o`02oolN0006ooo/0?l03ooo0?n]ooo^0?l0ojgooo]Z0_l0
ooh4o`0?o`;oA?l000?o`03oo`3oFOo00?l00_oo0<d2o`0go`;oo`1c0_oonfX00oooD`3oo`3Goo<0
o`02odCo0004o`3oo_m4o`3oA?l0odCo00;oolT000Wo0;3ooomi0?ooN@3oogT0ooo90?ooD@3oA?l0
o`1GoooUo`000_mE0?l00ooo7P3ooo]Zoomi0002oolT0007oomi0?m4o`3oA?l0ool0T?oio`3o0?So
o`3ooP02oooS0003oomd0?l03ooo00oo00?o00oo00?o0?mMo`1Oool0oed00_mEo`02oookJP;oon80
1ooonfX00ooo08Goo`3bool0lP02oookJP;oK`3o00GookX0o`2gool0of3o0?mPoookJP02ool0I`?o
oo]Z0_oo0:lAoookJP;o0?l9MOoonfX2o`3o2A;ooo]Z00Coo`2_oookJ_oonf[ooo]Z0_oo06L01?oo
nf[o0?mPo`3oH?l0]ol2oonj00;oK`3o00Cooo]ZoooT0?oo0?;oo`3b1ooonfX2oooR00?ooo]Z00Oo
EOl0o`2fool0onoo0?o_oookJ_oo047o04;o00?ooo]Z0_ooh`001?oo057oeOl0ooWo0?oo0902oook
JP03o`3o6?oonf[oob@000;ooo]Z0_oo7P001OmE0?oooo]Zo`1Gool0Eooooe4000;ohol000Sooh`0
ool0^?oo0;So0?nAoookJ_oo01_o0?mCoookJP;o0?oP00?oo`3`oo<0oooc0?l00_ooD`02oookJP06
ool0Loooa@3o03Ooo`0goooo0<gooo]Z0_l0oeT00ol0obGo09;ooookJP02ool0?PCooo]Z0_ookP00
1Ooonf[o:03oooo/0?ook03ooah000;oo`400_oo00`3oookJP;oo`2/0ooonfX00olTo`3o09goo`2M
o`02o`0]o`05oomD0?l01oooohH0oon60?oonfX00_lVo`02ool0f`?ooo]Z0ooa0?l01?oonf[o04So
o`18ool0B?l2ool0b0?ooaH000Cooo]Zoago0?lMo`3o7Ol00ooonfX4o`3oK0;ooo]Z1_ofo`0;oook
JPCo000000?ooo]ZooKo0?ofo`001?ofo`02oookJPCo0?m/0_oonfX3oago00;ooo]Z0_oo5P000ooo
nf[oo`38ool0b002o`18o`;ooo]Z0_oa0?l4oookJP04ool0folVo`3o9_l0oookJP;oohH00_ooE002
o`0]o`;o09go00Co9?l0oookJ_oonf[ooo]Z0_oo0:`4oookJP;oo`0<00?oo`40oh_o0?oo7P000_oo
k0000olX0?ooonh0ooo^0005oookJP05ool0?_oJo`3ooo]Zo`2Booo00?l00_l0oeT01_oonf[oo`3=
o`0gool0=oooolD0ool0L`;ooo]Z0_ooD`001Ooc0?ooo`3`ool0l?l0on3obP3o00;o0?mC00?oo`0K
oookJ_l0oi400_oo0;P01_ooS03ohol0on?o0?ooD@3o05Ooo`3o=P;oE@3o00?ooah0oookJ_oonfX0
0ooo9002o`3o60;oo`2@00GonOl0omGo0?oo057oon<0oomd0002oookJP;o04;o0_oonfX2o`3ok`;o
EOl00_oonfX2oooR00Sooo]Z0_oo0?83oookJP03ofl0oooo^P3ookX000?o0?mP00?ooo]Zool0Iooo
nfX00_oonfX2ool0[a7ooo]Z0_l0o`U0oookJP00=_oonfX4odCo0003o`3oo_m4o`3oA?l000;oA?l0
3OoonfX00om4o`3oogT0o`1Oo`03o`1Oo`?oolT000Go0?l<ooo90?oob@3oolT0o`1Oo`02oolX00?o
0?on0_l0/?l5oookJP07oooR0?oo:03oobP0oolX0?nDo`3oobP0onGo0002o`3ok`03oookJ_oUo`3o
04;o00?ooo]Z00Coog@0oooS0?oonf[onOl00_oo09001Ooonf[o0?lHo`3o6?oonf[oob@000;ooo]Z
0_oo7P02oeD0o`03o`1GooooD@3ooe4000;oA?l000?o0?onool0^?oo0;P00_m4o`001?oo01_o0?mC
o`0?ool0on03ooo90003o`3o3?oob@3oolT000;oolT000Co0?l<ooo90?oob@3o03Oo0_l0Gol01Ol0
oeWo`03oo`2Bool0T_oooo]Z00;oo`0n1OoonfX01?ookP3ooo]Zool00?ook002ool00004o`2`oooo
0@3o04Coool030Cooo]Z0_oo0:`00ooonf[oogT0o`2`o`02o`2Mo`03oolh0?l0;Ooo02go00;ooe@0
0_ooQP02obKo00;oo`3K1?oonfX2oo40o`?oo`000_l0/?l2ool0b0?ooaH00_oonfX3oago00Cooo]Z
1ol0oohDooKo00;ooo]Z0_l0of`7o`2`o`;oolT000Go0;3oo`3o3?l0o`co0?l<ooo90002ool0b0;o
olT000Kooo]Zoo40oooa0?oo0?onoo40oooUo`03odCo0003oomi0?lVo`3o9_l000;oogT00_ooE002
o`0]o`03oolh0?l0WOoo0?on00?o0?on00?ooo]Zool0[?oo0:`00_oonfX2o`0?o`03ool03?l03ooo
o`4000;ooah000?oon`0o`0?ool0ojd00_ookP02oookJP;o0?on0ol03ol2odCo0005ol00ool0oeWo
0?mIoookJ_oo0<d00_l0=ol01oooa@3oo`1coookJ_oonf[ooe<0oookJ_oc0?l00_m4o`001?l0ooko
A?l0odCo0?m4o`03ooo90003ool0^?ooN@3oogT000?oogT000CoA?l0o`1OoomE0?ooE@3o0_oo7P00
0ooonf[oob@0oolT0002oomi0009odCo0?oo093oo`2@ooWo0?l0ookoo`1AoooS0?ooM03oA?l000Co
00oo00Co0?mMo`1Oool0oego0?mM0_mEo`02oookJP;oon801_oonfX01?oo08Goo`3bool0l_ooi002
oookJP05ofl0oooonf[ookX0o`2gool0of000_oonfX00ooo06Oooo]ZoookJP02oookJP03ool0[ooo
nf[ooo]Z013ooo]Z0_l0o`UeoookJP;o0?l94_oonfX00ooo0:oooo]ZoookJP02oookJP;oo`1W0_l0
of000ol0]ooookX0oonj0002ofl0o`04oookJ_ooi03oo`3bool0lPOooo]Z00?oon80oookJ_oohP00
0_oonfX2oeGo00;o0?o_00Cooo]Zool0@Ol0@_oo04;o0_oonfX01OooM03oon<0ool0DOoEo`3onOl0
00;oo`2@00?ooo]Zo`3o6?oonfX00_oo9002oookJP05oolN0?mE0?ooE@3oo`3o=_l0Eol00_ooD@00
1ooSo`3ooh`0ool0^?oo0;So0?nAool00ooonfX00_l0oe<01ooonf[o0?oPool0l?oo0?3ol`3ooook
J_ooD`000_oonfX01_oo07?oolD0o`0gool0=oooo`3=oookJP;o0?mI00?o0?lUo`2BoooonfX00_oo
03h5oookJP0:ooo^0?oonf[ooo]Zo`3o;?ook03ooah0oh_o0?oo0@3o04Coool030Cooo]Z0_oo0:`3
oookJP03obCo0?l0WOooocP000;o02go0_ooE002oon60003oookJ_lVo`3o9_l000;oo`3K0ooonfX3
oo40o`;ooo]Z0_l0B?l2ool0b0CooaH000Cooo]Zoago0?lMo`3o7Ol01?oonfX4o`3oK0Cooo]Z4oof
o`02oookJPKo0?m/00?ooo]Zoago0?lMo`000olMo`03oolF0003oookJ_oo0<Soo`3800?o04So00Co
oo]Zoo40oooa0?ool@3o1?oonfX00ooo0=_o9_l0obKo0002oon60003o`07ooooE03o02go00;o02go
0_l0WOl01?lTo`3ooo]ZoookJ_oonfX2ool0[0Cooo]Z0_oo00`2ool10005oolN0?ook03oon`0obP0
oooonfX00_ookP04oookJP03ool0?_oJo`3ooo]Z00;o09;o0_l0oeT2oookJP04ool0cOl0=oooolD0
ool0L`;ooo]Z0_ooD`02oo<0o`08ool0l?l0on3o0?oPoookJ_l0oe?oo`0KoookJ_l0oi42ool0^003
oon<0?ooJ03ohol000;ooe4000Go0?lfoeD0oomE0?ooE@3ooolN0002oookJP;oob@00_l0oaP00ooo
nf[oo`2@ooWo0002omGo00;oon<000Koog@0oookJ_oonf[o04;oool0@OoonfX2o`3ok`03o`2foomE
o`3oEOl000;ooo]Z0_oohP07oookJP?oo`3b0_oonfX2ofl0o`;ookX00_l0of000ooonf[oo`1Wool0
I`03oookJP;oo`2_4OoonfX2o`3o2D3ooo]Z000foookJPCoA?l000?o0?onoookJ_oonfX03ooonfX0
0ooo0:ooA?l0o`1Oo`03o`1Oo`?oolT000?o0?l<ooo90?oob@000_oob@02o`2`o`Co0?on0_l0/?l4
oookJP03oooR0?oob@3ooo]Z00;ooo]Z00KoU?l0onGo0?l0onoo0?o_oookJ_oUo`02o`12o`;ooo]Z
00Goog@0oooS0?oonf[oeOl0ooWo0002ool0T0;o0?lH00Cooo]ZoolT0?oonf[ooo]Z0_oo7P02oeD0
o`;o05Oo00Cooe40odCo0?m4o`3oA?l00_oo0;P3odCo0003o`3oDol03ooo00oo00?oolT000?o0?l<
ooo90?oob@000_oob@001?l0o`coolT0ooo90?oob@03o`1Oo`03o`3oFOo00?oo09;o00;ooo]Z0_oo
03h5oookJP03ooo^0?oo003oo`0000?oo`0000Co0;3oool10?oo00co04Co1?oonfX2ool0[003oook
J_l0/?oo0;3o00;o09go00?oocP0o`0]ool0;Ol00_ooE002oon600;o9_l00_oo0=/4oookJP?ol@3o
1Ol0/?l2ool0b0?ooaH00_oonfX4oago00?ooo]Z3?l0ooh7ooKo00;oogT000?o0000oookJ_l0of`0
0ol0of`6o`2`o`;o0?l<0ooob@000ol0/?oo0?l<ool0b002ool0b0;oo`000_oonfX2oo40o`;o0?on
0_oUo`03odCo00;o9_l01?ooN@02o`0]o`03oolh0?l0WOoo0?on00Co0?on0_oo0:`3oookJP04o`0?
oooo00coo`0<ool100;ooah00_ook0000ol03ooo0?n]ooo^0002oookJP?o0?on0_l03ol2odCo0005
o`3o9Ol0oeWo0?mIoookJ_oo0<d00_l0=ol01Oooa@3oo`1cool0Looonf[ooe<000;o0?on00Col`3o
odCo0?m4o`3o0?on0_m4o`03ooo90003o`2`ooooN@3oogT000?oogT000CoA?l0oomi0?mE0?ooE@3o
0_oo7P02oookJP;oob@000?oogT0odCo0?ooN@000_oo09001_l0n?oo0?onoooS0?ooh`3oA?l0oook
JP?o00oo00Co05ooo`3oGOl0Gooo0?mM0_mEo`02oookJP;oon801ooonfX00ooo08Goo`3bool0lP02
oookJP;oK`3o0_oo^P02o`3oH003oookJ_oo06Ooo`1W00?ooo]Z0_oo0:lAoookJP?o0?l9M_oonfX0
0ol0o`Wooo]ZoookJP0@oookJP;oo`2_0ooonfX2ool0I`03oookJ_l0of3o0?mP00;ookX00_m_0?l2
oookJP;oo`3b1ooonfX3oooR00;ooo]Z0_mEo`001_oo08Ko0?o_oookJ_oonf[oo`11o`12o`;ooo]Z
00?oog@0oooS0?ooh`000_oEo`02ool0T003oookJ_l0oaSooo]Z00;oob@00_oonfX01Ooo7P3oE@3o
oeD0ool0ocKo05Oo00;ooe4000Cohol0oomX0?oo0;Soo`2h0_l0oi401?oonf[o0?mCo`3oDooonfX2
o`3oh004ool0l?oc0?ool`3ooomC00;ooo]Z0_oo07<00oooa@3o03Ooool0c@02oookJP05o`3oFOo0
0?oo09;oo`2BoooonfX00_oo03h5oookJP08ooo^0?oonf[o:03oo`3o;?ook03ooah0oh_o0?oo0@02
ool030Cooo]Z0_oo0:`3oookJP03obCo0?l0WOooocP000;o02go0_ooE002oon60003oookJ_lVo`3o
9_l000;oo`3K0ooonfX4oo40o`04oookJ_l0B?oo04Soo`18o`;oo`380ooo5P03oookJP?o7Ol01?oo
nfX5o`3oK0Kooo]Z2?ofo`02o`000003oookJ_l0ofco0?m/00Go0?m/00?ooo]Zoago0?lMo`000olM
o`001?oonf[ooaH0oolF0?oo5P04ool0b0;o04So0_oonfX2oo40o`Cooo]Z0_oo0=/2obKo00;oohH0
00?o00OooomD0?l0;Ol00_l0;Ol2o`2Mo`04obCo0?oonf[ooo]ZoookJP;oo`2/1?oonfX2ool030;o
o`4000Gooah0ooo/0?ook03o:03ooookJP02ooo^00Cooo]Z0_oo03h01?oJo`3o09;oo`2Booo00?l2
o`3oF@04oookJ_oo0<go03Ooo`3o_@;oo`1c00Gooo]ZoomC0?ooD`3oo`3Goo<0o`02ool0l005o`3o
h?o:0?oo0?mCo`3oDooonfX00_l0oi42ool0^006oon<0?oSo`3ooe40oomA0?l0Eooo0?lf0_mE0?l0
0ooo7P3ooo]ZoookJP02oolT000:oookJ_l0oaSo0?lHoookJ_oo093onOl0omGo0?oo057oon<0oomd
00;ooo]Z0_l0@_l01?oo047ooo]Zo`3okol0onl2oeGo00;ooo]Z0_oohP08oookJP;oo`3b0ooonfX0
1?m_0?oookX0oonj0?oo^P02o`3oH003oookJ_oo06Ooo`1W00;ooo]Z0_oo0:lBoookJP;o0?l9@?oo
nfX003Wooo]Z00?oogT0o`3oo_m4o`004OoonfX01Om4o`3ooo]ZoookJ_oonf[o0?mM00?oolT000Go
0?l<ooo90?l0oegookX0o`1Oo`02o`2`o`Co0?on1ooonfX02_oob@3ooo]ZoookJ_oonf[oU?l0oolX
0?l03ooo0?o_oookJ_oUo`02o`12o`;ooo]Z00Goog@0oooS0?oo057oeOl0ooWo0002ool0T003oook
J_l0oaSo0?lH00;oob@00_oonfX01Ooo7P3ooo]ZoeD0ool0ocKo05Oo00;ooe400_m4o`000ol0ooko
o`2hoi3o0002oomi00;o0?mC00?o00ooooo90?oob@001ooob@001?l0o`coolT0ooo90?oob@02o`1O
o`05o`3oFOo00?oo05ooo`2BoooonfX00_oo03h5oookJP;oonh01Ooo00000ooo0@3o04Coool03004
oookJP;oo`2/0_oonfX2o`2`o`;o09go00?oocP0o`0]ool0;Ol00_ooE002oon600;oo`000_oo0=/5
oookJP;ol@3o1Ol0/?l3ool0b0Go0;3o1?lMo`03oookJPgo0?on0om4o`03oomi00Go0?m/1Ol0/?l4
o`3o30?oolT00ooo0<P2o`3o30?oo`000_oa0?l2o`3ooPCoiOl00_lVo`001Om4o`3oogT0oomi0?oo
N@3ooe@000;o02go00?oocP0o`2Mool0ooh01?l0ooh2ool0[0;ooo]Z00GoogT0o`0?oooo00coo`0<
ool10002oolN00;oon`00_l03ol01?ookP3ooo]ZoookJ_oonfX2o`3ooP;o00oo0_l0ooh01?l0T_oo
`03oo`3oFOoonfX2ool0c@;o03Oo00[oolD0ool0Looonf[ooo]ZoomC0?l0ookol`3oo`3oo_m4o`3o
0?on0_m4o`001Ol0oe?oolT0ooo90?l0oi7oo`2h00CoogT000GoA?l0oomi0?ooN@3oogT0oeD0o`02
oolN0006oookJ_oo903oob@0oomi0?l0ookoA?l00_oo09001Ooio`3o0?Soool0DOooh`3oog@000;o
oo]Z0ol03ol3o`1Oo`03o`3oGOmEo`3oEOl000;ooo]Z00?oon80oookJ_oonfX01_oonfX00ooo08Go
o`3boooT0002oookJP05ofl0oooonf[ookX0o`2gool0of000_oonfX00ooo06Oooo]ZoookJP02oook
JP03ool0[ooonf[ooo]Z013ooo]Z0_l0o`UgoookJP;o0?l94OoonfX2ool0[`?ooo]Z0_oo06L00ooo
nf[o0?mPo`3oH002oonj00;oK`3o0_oonfX2ool0lP03ool0QOoonf[ooo]Z00Gooo]Z0_oohP03oook
JP07oeGo0?l0]_oo0?o_o`3okooonf[oo`11o`12o`03oookJP;oon<000Goo`1AomGo0?oio`3oo`2@
oookJP02o`3o6004oookJ_oo903ooo]ZoookJP;ooah000GoE@3oo`3o=_l0Eooo05OooomA0002on?o
0004oon<0?oo0;Soo`2ho`3oT@;ooo]Z00Go0?mCoookJ_l0on3o0?oPool0l002oo<0o`06oookJ_oo
D`3ooo]ZoookJ_oo07?oolD00_l0=ol01ooo0<gooo]Zo`3oFOl0oeWo0?lUo`2BoooonfX00_oo03h5
oookJP;oonh000Gooo]Zo`3o;?ook03oon`0oolN0002ool10003ool03?l0A?oooo]Z00?ooo]Z00?o
o`2/oookJ_oonfX00_oonfX2o`2Mo`03oolh0?l0;Ooo02go00;ooe@00_ooQP000ooonf[o9_l0obKo
0002ool0f`Cooo]Z0ooa0?l2oookJP;o04So0ooo0<P3oolF0003o`3o:ooonf[ooo]Z00Co7Ol01?oo
nfX7o`3oK0Kooo]Z2_l0of`00ooonf[o7Ol0oago0002oago00?ooo]Z0ooo5P04ool0b0;o04So0_oo
nfX3oo40o`Cooo]Z0_oo0=/01_lVo`3ooo]Zoon60?ooQP3o00OooomD00?o02go0_l0WOl01?lTo`3o
oo]ZoookJ_oonfX2ool0[0Cooo]Z00Go04Coool03?oo0@3oo`40oolN0002ooo/0004obP0oooonf[o
onh0ooo^00Cooo]Z0_oo03h01?oJo`3o09;oo`2Booo00?l2o`3oF@06oookJ_oo0<go03Ooo`0goooo
a@3oo`1c0_oonfX2oomC0003oo<0ooooX@3oo`3`00;o0?oP0_l0oe<00ooo01_ooo]Zo`3oT@02ool0
^006oon<0?oSo`3ohol0oomA0?l0Eooo0?lf0_mE0?l2oolN0004oookJ_oo903oob@0oolT00;o0?lH
00Gooo]Zool0T?oo093onOl0omGo0002oooS0006oomd0?oonf[ooo]Zo`12oooo047ooo]Z0_l0onl0
0ol0]_ooEOl0oeGo0002oookJP;oon802?oonfX2ool0lP;ooo]Z0_m_0?l2oonj00;o0?mP00?ooo]Z
ool0Iooo06L00ooonfX2ool0[a7ooo]Z0_l0o`U1oookJP00>OoonfX00oooN@3o0?onodCo000Aoook
JP06odCo0?oonf[ooo]ZoookJ_l0oego05oo0_l0oed01Ol0o`coolT0onGo0?l0oego05oo00;o0;3o
1Ol0ooh6oookJP07ooo90?oonf[ooo]ZoookJ_nDo`3oobP0o`0?o`02o`3ok`03oookJ_l0@_oo04;o
00?ooo]Z0_ooh`001OoEo`3onOl0ool0T?oo093ooo]Z00;o0?lH00Cooo]ZoolT0?oonf[ooo]Z0_oo
7P000omE0?oooo]Zo`1Go`02oomA0003odCo0?ooN@3oogT000;oo`2h0_ooN@000ooo01_o0?mCo`0?
o`02ooo900;oo`3`00?oolT0oomC0?oob@000_oob@000ol0o`coolT0ooo90002ooo900;o05oo00Go
0?mIo`3o9Ol0T_oooo]Zom[o0002ool0?PGooo]Z00?oonh0ool00?l0/?l01?oo00000ooo0@3oo`0<
ool03004oookJP;oo`2/00Cooo]Zo`2`ool0/?oo0;3o0_l0WOl00ooo>03o02goo`0]o`02oomD0003
oon60?oo003oo`0000?oo`001OoonfX3oo40o`Go0;3o0ooo0<P6o`2`o`Ko7Ol02_l0ooh4odCo00?o
ogT000?o0000oookJ_lMo`001ol0/?l4o`3o30CoolT000?oo`38ool00?oo00001?oo00000ooa0?oo
0?mMo`3oG@05onGo0005obKo0?m4o`3oA?l0odCo0?ooE0000ol0;Ol00ooo>03o09goo`3ooP03o`3o
oP?oo`2/0ooonfX01?ooN@3oo`0<ool03?oo0@02oomi00;oon`00_l03ol01?ookP3o00ooo`0?oooo
nfX2o`3ooP03ool0?_l03ooo0?on00;o0?on00Go`03oo`3oFOl0oeWooo]Zool0c@02o`0go`07ooo5
0?oo07?ooo]ZoookJ_ooD`3o0?onoo<0o`04o`3ooP05odCo0?l0oe?o0?l<o`3o3?oob@000_oo0;P3
oomi0003odCo0?ooN@3oogT000;oogT00_oo7P02odCo00;oob@000?oogT0o`3oo_l0ooh00_oo0900
1_l0n?oo0?onoooS0?ooh`3oog@0oookJP?o00oo1?l0Gol2oeGo00;ooo]Z0_oohP07oookJP05ool0
QOoo0?;oo`3boooT0?oonfX00_m_0?l2oonj00;o0?mP00?ooo]Zool0Iooo06L01?oonfX00ooo0:oo
oo]ZoookJP0?oookJP?o0?l9MooonfX2o`3o2A;ooo]Z00Coo`2_oookJ_oonf[ooo]Z0_oo06L01Ooo
nf[o0?mPo`3oH?l0]ooookX000;oK`3o0_oonfX00oooi03oo`3bool0lP07oookJP;oon800ooonfX0
1_mEo`3o0;Koo`3okol0onoooo]Zool0@@;o04;o0_oonfX2oooS0005ool0DOoEo`3onOl0ool0T?oo
nfX00_l0oaP00ooonf[oob@0oolT0002oookJP05oolN0?mE0?ooE@3oo`3o=_l0Eol00_ooD@001ooS
o`3ooh`0ool0^?oo0;So0?nAool00ooonfX00_l0oe<01?oonf[o0?oPool0l?oo0?02oo<0o`03oomC
0?oonf[ooo]Z00;oo`1c00?oolD0o`0goooo0<d00_oonfX01Ol0oeWo`03oo`2Bool0T_oooo]Z00;o
o`0n1OoonfX01oookP3ooo]ZobP0ool0obcoon`0oolN0?n;o`000_oo0@000ooo00cooo]ZoookJP03
oookJP03ool0[?oonf[ooo]Z00;ooo]Z0_l0WOl01Ooo>03o02goo`0]ool0;Ooooe@000?oohH00_lV
o`02ool0f`Gooo]Z0_oa0?l3oookJP;o04So0ooo0<P4oolF00?ooo]Z1_lMo`03oookJPko0?m/00?o
oo]Zoago0?lMo`001?lMo`03oookJPCooaH01?oo0<P2o`18o`;ooo]Z1?oa0?l3oookJP;oo`3K0_lV
o`000ooonf[oohH0o`07o`02oomD00?o02go0_l0WOl4oookJP;oo`2/1?oonfX2ool03003ool10?oo
7P3ooah000;oon`000Co0?l/oookJ_ookP3oonh01?oonfX2ool0?P04om[o0?l0T_oo09;oo`2Bo`?o
0?mI0_oo0<d00ol0=oooolD0ool0L`02oookJP;ooe<00_oc0?l02?oo0?3o0?oPo`3oh?oonf[o0?mC
ool06ooonf[o0?nA0_oo0;P2oon<0005on?o0?ooD@3ooe40o`1Gool0ocH00_mE0?l00ooo7P3ooo]Z
oookJP02oolT0003oookJ_l0oaSo0?lH00;oo`2@00GonOl0omGo0?oo057oon<0oomd0002oookJP;o
04;o00Coo`11oookJ_l0onoo0?o_0_mEo`03oookJP03oooR0?oonf[ooo]Z00Kooo]Z0_oo0?801?oo
i03ooo]ZoookJ_m_0?l3oonj00;o0?mP00?ooo]Zool0Iooo06L00ooonfX2ool0[a7ooo]Z0_l0o`U1
oookJP00>OoonfX01?ooN@3o0?onodCo0?ooN@0@oookJP06odCo0?ooN@3ooo]ZoookJ_l0oego05oo
0_l0oed01?l0o`coolT0oonj0?l0oed3o`1Oo`Go0?on1_oonfX01ooob@3oon80oookJ_oonf[oU?l0
oolX0?oUo`000_l0onl00ooonf[o04;oo`12o`03oookJP;oon<000?ooo]ZomGo0?oio`000_oo0902
o`3o6004oookJ_oo903ooo]ZoookJP;ooah00_mE0?l2o`1Go`;ooe400_ooN@02ool0^0?oogT000Co
0?mCool06ol03ooo0?oP0_oo0?000ooc0?ooolT0ooo90005ooo90004o`0gool0Gooo0?mMo`3oG@;o
0?mI00Co0?lUo`2Boooonf[of_l00_oo03h4oookJP;oonh01_oo00000ol0A?ooo`0<ool03004oook
JP;oo`2/00Cooo]Zo`2`ool0/?oo0;3o0_l0WOl00ooo>03o02goo`0]o`02oomD00Ooo`001?oonfX0
0ol0/?ool@3ooo40o`05o`2`o`Coo`382?l0/?l:oago0003ooo90?l0ookoA?l000So7Ol02?l0/?l4
o`3o30CoolT000?o0;3oool00?oo00001?oo0003o`3oG@KoiOl00om4o`03o`0]o`;o09go0ol0ooh0
1?oonf[oo`2/ool0[?oo0:`3oookJP06o`14oooo00coo`0<ool10?ooN@3ooah00_ook002o`0?o`03
ooo^0?l03ooooo]Z00;ooo]Z00?o0?onool0?_oo03h00ol0ooh01Ol0obGo0?mIo`3oFOoonf[oo`3=
00;o03Oo00CoolD0ool0Looo07?ooo]Z0_ooD`02oo<0o`Go0?on00Co0?mCo`3o3?l0o`coolT00_oo
0;P3oomi0005odCo0?ooN@3oogT0oomi0?l0oed00_oo7P001?m4o`3oob@0oolT0?ooN@02o`3ooP;o
o`2@00GonOl0o`3hoooo057oon<0oomd0002oookJP;o00oo00?o04;oo`1Oool0Gol00_l0Gol01OmE
o`3o05oooookJ_oonf[oon8000Sooo]Z00?oo`25ool0l_ooi0000_oonfX2ofl0o`06oonj0?l0]ooo
0?mPo`3oH?oonf[oo`1W1?oonfX2ool0[a7ooo]Z0_l0o`UhoookJP;o0?l94_oonfX01?oo0:oooo]Z
oookJ_oonfX2ool0I`04oookJ_l0of3o0?mPo`2go`;ookX000CoK`3ooookJ_oonf[ooo]Z0_oo0?87
oookJP?oon800_oonfX2oeGo00;o0?o_0_oonfX2o`12o`;ooo]Z0_ooh`000ooo057oeOl0ooWo0002
ool0T003oookJ_l0oaSooo]Z00;oob@00_oonfX01Ooo7P3oE@3ooeD0ool0ocKo05Oo00;ooe4000Co
hol0oomX0?oo0;Soo`2h0_l0oi401?oonf[o0?mCo`3oDooonfX2o`3oh003ool0l?oc0?ool`3o00;o
oe<000Cooo]Zool0Looo07?oolD00_l0=ol01_oo0<gooo]Zol00ool0oeWo`03oo`2Bo`;ooo]Z0_oo
03h4oookJP;oonh000Gooo]Zo`3o;?ook03oon`0oolN0002ool100;oo`0<1OoonfX00ooo0:cooo]Z
oookJP02oookJP;o09go00CoocP0o`0]ool0;Ooo02go0_ooE002oon600?o9_l000?oo`3KoookJ_oo
nfX00ooonfX3oo40o`?ooo]Z0_l0B?l4ool0b0?ooaH000Co0?l[oookJ_oonf[ooo]Z2_lMo`03oook
JP_o7Ol00_oonfX6oolF00Coo`380ol0B?l00ooonf[ol@3ooo40o`02oo40o`Cooo]Z0_oo0=/2obKo
00;oohH000?o00OooomD0?l0;Ol00ol0;Ol2o`2Mo`Cooo]Z0_oo0:`3oookJP04o`14oooo00coo`0<
ool100;ooah00_ook0001?l0obcooo]Zooo^0?ookP04oookJP?oo`0n00?ooo]Zo`2Bool0T_l00ol0
oeT01?oonf[oo`3=o`0gooooa@02ool0L`03oookJ_ooD`3ooe<000;ol`3o0_oo0?02o`3oh0;o0?mC
00?ooo]Zool00ol0oi400_oo0;P01_ooS03ohol0on?o0?ooD@3o05Ooo`3o=P;oE@3o0_oo7P001?oo
nf[oob@0oolT0?oonfX2o`3o6005oookJ_oo093oo`2@ooWo0?oo05400_ooh`03oookJP;o04;o00Co
oo]Zo`3okol0onoo0;Ko0_mEo`02oookJP;oon802?oonfX2ool0lP?ooo]Z00?oK`3ooonj0?oo^P00
0_l0of000ooonf[oo`1Wool0I`03oookJP;oo`2_4OoonfX2o`3o2D;ooo]Z000ioookJP04oomi0?l0
ookoA?l0oomi013ooo]Z00KoA?l0oomi0?oonf[ooo]Zo`3oGOl0Gol3o`3oG@04o`3o3?oo^P3o0?mM
o`3oG@;o05oo1_l0ooh5oookJP07ooo90?oohP3ooo]ZoookJ_mEo`3oobP0onGo0002o`3ok`04oook
J_oUo`3o04;oo`12o`;ooo]Z00Goog@0oooS0?oo057oeOl0ooWo0002ool0T003oookJ_l0oaSo0?lH
00;oob@00_oonfX01Ooo7P3ooo]ZoeD0oooonf[o05Oo00;ooe400oooN@001?oo0;SoT?l0oomi0?oo
N@02o`3oD`05o`0?ool0on3o0?oPool0l?oc0?l01?oob@000ooonf[oolT0ooo50002o`0go`05o`1O
ool0oego0?mMo`3oFOl0obD00_l0T_l00ooJo`3oo`0nool0?P05oookJP03ooo^0?oo003oo`0000Go
o`000_oo00`00ol0/?oooo]ZoookJP02oookJP;oo`2/1?l0/?l2o`2Mo`03oolh0?l0;Ooo02go00;o
oe@02Ooo0002oookJP04o`2`oooa0?ool@3ooo40o`Go0;3o00?o0?l<ool0b?oo0<P00_oo0<P:o`2`
o`oo7Ol00_oonfX7o`2`o`Co0?l<1?oob@04ool000;o05oo1Ol0oed6onGo0004odCo0?l0;Ooo02go
oolh00;o09go00CoobP0o`3oo_oonf[ooo]Z0_oo0:`4oookJP06o`14oooo00coo`0<ool10?ooN@3o
oah00_ook002o`0?o`;oonh00ooonfX00ol0ookoo`0nool0?P03o`3ooP05o`2Bool0oeWo0?mIoook
J_oo0<d00ol0=ol2ool0L`;ooo]Z00?ooe<0oo<0oooc0?l01ol0ooh01?l0o`coolT0ool0^?oo0;P3
oomi0005odCo0?ooN@3oogT0oomi0?mE0?l00_oo7P002ooonf[oA?l0oolT0?oo903o0?onodCo0?l0
ookoiOl0ool0T?l0n?oo0?on00;oon<000Goog@0oookJ_oonf[o00ooo`12o`04o`1Oo`;oEOl000Co
05oooookJ_oonf[oon801ooonfX01Ooo08Goo`3bool0l_ooi03ooo]Z00;oK`3o0_oo^P02o`3oH0;o
oo]Z00?oo`1WoookJ_oonfX00_oonfX00ooo0:oooo]ZoookJP0?oookJP?o0?l9NOoonfX00ol0o`Wo
oo]ZoookJP0@oookJP03ool0[ooonf[ooo]Z00;ooo]Z0_oo06L00ooonf[o0?mPo`2go`02oonj00;o
K`3o0_oonfX2ool0lP03ool0QOoonf[ooo]Z00Gooo]Z0_oohP02oookJP;oEOl00_l0onl2oookJP07
ool0@Ol0@_oooo]ZoookJ_ooM03oon<0ool0D@02omGo00;oo`2@00?ooo]Zo`3o6?l0oaP00_oo9002
oookJP;ooah000?oE@3ooookJ_l0ocH00_ooD@02on?o0004oon<0?oo0;Soo`2ho`3oT@;ooo]Z00Co
0?mCoookJ_o:0?oo0?oP0_oo0?000ooc0?ooo`3GoomC0002oookJP;oo`1c00OoolD0o`0goooo0<go
o`3=oookJ_l0oeWo`03o00;o09;o00?ooo]Zool0?_oo03h01OoonfX2ooo^0005oookJ_l0obcoon`0
ooo/0?oo7P000_oo0@02ool030Cooo]Z0_oo0:`4oookJP;o09go00CoocP0o`0]ool0;Ooo02go0_oo
E002oon600?o9_l00_oo0=/5oookJP;ol@3o0ooonfX4o`18o`Coo`381Ooo5P05oookJPko7Ol00ooo
nfX6oolF00Coo`381?l0B?l00ooonf[ol@3ooo40o`03oo40o`?ooo]Z0_oo0=/2obKo0003oookJ_oo
QP3oohH000;ooe@00ol0;Ol3o`2Mo`?ooo]Z0_oo0:`4oookJP04o`14oooo00coo`0<ool100;ooah0
0_ook0001?l0obcooo]Zooo^0?ookP04oookJP?oo`0n00Cof_l0o`2Bool0T_oo`03o0_l0oeT01_oo
nf[oo`3=o`0gool0=oooolD0ool0L`;ooo]Z00?ooe<0oo<0oooc0?l00_oo0?02o`3oh0;o0?mC0_oo
nfX01?l0oi7oo`2hool0^?ooS002on?o00;ooe4000Go05OooookJ_mE0?ooE@3ooolN0002oookJP;o
ob@000?ooo]Zo`3o6?oonfX00_oo09000ooio`3oeOl0oooS0002oooS00;ooo]Z0_l0@_l2oookJP;o
0?o_0_mEo`03oookJP;oon801ooonfX3ool0lP;ooo]Z00CoK`3ooonj0?oo^P3ookX00_l0of000ooo
nf[oo`1Wool0I`03oookJP;oo`2_4OoonfX2o`3o2D;ooo]Z000ioookJP03oomi0?l0ookoA?l000;o
ogT03ooonfX01?m4o`3oogT0oookJ_oonfX2o`3oG@09o`1Oool0oego0?mMo`3o3?oo^P3o0?mMoonj
0?l0oego05oo00Ko0?on1_oonfX01_oob@3ooo]ZoookJ_oonf[oobP0onGo00;o0?o_00Co00ooonGo
0?l0@_oo04;o0_oonfX01OooM03oon<0oooS0?oEo`3onOl000;oo`2@00?ooo]Zo`3o6?l0oaP00_oo
9002oookJP;ooah000GoE@3ooookJ_l0Eooo0?onoomA0003oomi00;oo`2h0oooN@001?l0oe?oo`0K
o`3o[Ol0on02ool0l0;oolT00_ooD`001?oonf[oolT0ool0Loooa@02o`0go`;o0?mM0_l0oeT01?l0
obGo09;ooookJ_oJo`02ool0?PCooo]Z00?oo`00ooo^0?l0/?l01_oo0002ool030Gooo]Z0_oo0:`4
o`2`o`;o09go00?oocP0o`0]ool0;Ol00_ooE00:ool00003oookJ_l0/?oo0;3o00?ol@3o0_l0/?l4
o`3o3003ooo90?l0/?ooo`3800?oo`381Ol0/?l4o`3o30?oolT01?m4o`05oolF00Wo0;3o1Ol0o``4
ooo900;oo`000ol0Gol5o`3oG@;oogT00ooUo`03o`0]o`03oolh0?l0WOooobP000;oobP00_oonfX2
ool0[0?ooo]Z00GoA?l0o`14oooo00coo`0<ool10002oomi0004ooo/0?l0obco00ooo`0?o`;oonh0
1?oonfX00ol0ookoo`0nool0?P02o`3ooP04o`2Bool0oeWo0?mIoookJP;oo`3=0_l0=ol2ool0L`;o
oo]Z00Cooe<0oookJ_oc0?ool`3o1Ol0ooh2o`3o3004o`3oTOn@o`3oA?l0odCo00;oogT000Wo0?on
oomi0?ooN@3oogT0oeD0ool0oegooah0oookJ_m4o`000_oo90002_m4o`3o0?ono`3oo_oo093oiOl0
ooWo0?l0ookoo`1AoooS0?ooM002oookJP?o04;o1?l0Gol01?mEo`3o05oooookJ_oonfX2oooR00Oo
oo]Z00?oo`25ool0l_ooi0000_oonfX2ofl0o`;ookX00_l0of000ooonf[oo`1WoookJP03oookJP;o
o`2_4OoonfX2o`3o2G[ooo]Z00?o0?l9oookJ_oonfX04?oonfX2ool0[`?ooo]Z0_oo06L00ooonf[o
0?mPoookJP02oonj00;oK`3o0_oonfX2ool0lP03ool0QOoonf[ooo]Z00Gooo]Z0_oohP02oookJP;o
EOl000Go0;Koo`3okooonf[ooo]Zool0@@02o`12o`09oookJ_ooM03oon<0oooS0?oo057oeOl0ooWo
0?oo093ooo]Z00;o0?lH0ooo90000ooonf[ooah0oolN0002oeD0o`06o`3o=_l0Eooooe40oomA0?oS
o`3oofP00_oo0;P00ol0oi7oo`03oookJP02o`3oD`04oookJ_l0on3o0?oPool0l0;ol`3o0_ooD`00
1?oonf[oo`1cool0Loooa@02o`0go`06ool0cOoonf[o0?mIo`3oFOo00?oo09;o0_oonfX2ool0?PGo
oo]Z00Goonh0oookJ_oonf[o0?l/ooo/0002oolN0004ool10?oo00coo`0<ool030Cooo]Z0_oo0:`4
oookJP03obCo0?l0WOoo09go00?o02go0_ooE002oon60003oookJ_lVo`3o9_l000?oo`3K1OoonfX2
oo40o`?ooo]Z1Ol0B?l5ool0b0WooaH01ooonfX:oolF00Goo`381?l0B?l00ooonf[ol@3ooo40o`03
oo40o`Cooo]Z0_oo0=/2obKo00;oohH000?o00OooomD0?ooE0000ol0;Ol2o`2Mo`Cooo]Z0_oo0:`4
oookJP04o`14oooo00coo`0<ool100;ooah00_ook0000ol0obcooo]Zooo^0002ooo^00Cooo]Z0_oo
03h01?oJo`3o09;oo`2Booo00?l2o`3oF@06oookJ_oo0<go03Ooo`0gooooa@3oo`1c0_oonfX2oomC
00;ol`3o00Coo`3`o`3oh?l0on3ooo]Z0_l0oe<00ooonf[o0?nAo`3oT@02ool0^006oomX0?oSo`3o
oe40oomA0?l0Eooo0?lf0_mE0?l00ooo7P3ooo]ZoookJP02oolT0004oookJ_l0oaSo0?lHoookJP;o
o`2@00CoeOl0ool0DOooh`3oon<00ooonfX2o`12o`04oookJ_l0onoo0?o_o`3ok`;oEOl00_oonfX2
oooR00Sooo]Z0_oo0?83oookJP03ofl0oooo^P3ookX000;o0?mP00?ooo]Zool0Iooo06L00ooonfX3
ool0[a3ooo]Z0_l0o`U3oookJP00>OoonfX2oomi0003o`3oo_ooN@3oogT000oooo]Z00Coo`2_oomi
0?oonf[ooo]Z0_l0oed02Ol0Gooo0?mMo`3oGOl0o`coolT0onGo0?oo^P3o0?mMo`1Oo`07o`3ooPGo
oo]Z00OoolT0oooR0?oonf[ooo]ZoeGo0?oo:03o00oo00;o0?o_00?o00ooo`12ool0@_l00_oonfX0
0oooM03oon<0oooS0002omGo0003ooWo0?oo093oo`2@00;o0?lH00?ooo]ZoolT0?oo90000_oonfX0
1Ooo7P3ooo]ZoeD0ool0ocKo05Oo00;ooe400_ooN@000on@o`3oo`2hoi3o0003oomi0007o`3oDol0
ojgo0?oPo`3oh?oo0?3ol`3oooo90002oomC00;ooo]Z00CoolT0ooo50?l0=ooo03Oo0ol0oed01Ol0
oeWo`03oo`2Bool0T_oof_l000;oo`0n1OoonfX2ooo^00Ooo`000_oo00`5oookJP;oo`2/0_l0/?l2
o`3o30;o09go00CoocP0o`0]ool0;Ooo02go0_ooE00;ool000;o0;3o0ooa0?l3o`3o30CoolT00_l0
/?l6ool0b0?o0?l<1?oob@06oolF00go0;3o1?l0o``4ooo90003ool00?l0Gooo05oo00?o05oo0ol0
oed3oomi00;oiOl00ol0;Ol2o`2Mo`GoobP00_oo0:`4oookJP04o`14oooo00coo`0<ool100;oA?l0
00Coon`0oomi0?ooN@3o00oo0_ookP04oookJP03o`3oo_oo03koo`0n00;o0?on00?o09;oo`3oFOl0
oeT00_oonfX01?oo0<go03Ooo`0gooooa@02ool0L`03oookJ_ooD`3ooe<000;ol`3o1Ol0ooh2o`3o
3003ool00ol0oi7oo`2h00?oA?l000CoogT0o`3oo_ooN@3oogT00_mE0?l2oolN000;oookJ_oo903o
ob@0oolT0?l0ookoA?l0ool0T?oUo`3oo`2@o`3hool0ooh00_ooh`000ol0ookooo]ZoookJP02o`12
o`Co05oo0_mEo`03oookJP03oooR0?oonf[ooo]Z00Gooo]Z00?oo`25ool0l_oo0?800_oonfX2ofl0
o`;ookX00ol0of000ooonf[oo`1WoookJP03oookJP03ool0[ooonf[ooo]Z013ooo]Z0_l0o`Ujoook
JP03o`3o2Ooonf[ooo]Z013ooo]Z0_oo0:l3oookJP;oo`1W00?ooo]Zo`3oH?l0of000_oo^P02ofl0
o`;ooo]Z0_oo0?800ooo08Gooo]ZoookJP05oookJP;oon800ooonfX2oeGo00;o0?o_00Cooo]Zool0
@Ol0@_oo04;o0_oonfX2oooS0003ool0DOoEo`3onOl000;oo`2@0_l0oaP00ooonf[oob@0oolT0002
oookJP;ooah000?oE@3ooookJ_l0ocH00_ooD@02on?o0004oon<0?oo0;Soo`2ho`3oT@;ooo]Z00Co
0?mCoookJ_o:0?oo0?oP0_oo0?000ooc0?ooo`3GoomC0002oookJP04ool0Loooa@3oolD0o`0go`;o
o`3=00?ooo]Zo`3oFOo00?l00_l0T_l00ooonf[oo`0nool0?P05oookJP;oonh000Oooo]ZobP0ool0
obcoon`0oolN0?n;o`3oo`4000;oo`0<00?o04CooookJ_oonfX00_oonfX2ool0[0Cooo]Z00?o9?l0
o`2Mool0WOl00ol0;Ol2oomD0003o`07ooooQP3oohH000?o9_l00ooo0=/4oookJPCol@3o0ooonfX5
o`18o`Ooo`383ooo5P000ol0ob_oo`38ool0b004ool0b0Go04So0_oonfX4oo40o`Gooo]Z0_oo0=/3
obKo00;oohH00_ooE004o`0]o`;o09go1?oonfX2ool0[0Cooo]Z00Co04Coool03?oo00coo`400_oo
7P02ooo/0003obP0oooonf[oonh000;oonh01?oonfX2ool0?P04om[o0?l0T_oo09;oo`2Bo`;o0?mI
00Gooo]Zool0cOl0=ooo03Ooooo50002ool0L`;ooo]Z00?ooe<0oo<0oooc0?l00_oo0?001ol0on3o
oo]Zo`3oDol0oe?ooo]Zool00ol0oi400_oo0;P00oooS03ohol0on?o0002oomA0005o`3o=_mE0?oo
E@3ooeD0oooo7P000_oonfX2oolT0003oookJ_l0oaSooo]Z00;oo`2@00?onOl0omGo0?ooh`000_oo
h`02oookJP;o04;o0_oonfX2o`3ok`?oEOl00_oonfX2oooR00Oooo]Z0ooo0?82oookJP04ofl0oooo
^P3ookX0o`2go`;o0?mP00?ooo]Zool0Iooo06L00ooonfX2ool0[a7ooo]Z0_l0o`U3oookJP00>Ooo
nfX2oomi0004o`3oo_m4o`3oogT0oomi00kooo]Z00Coo`2_oomi0?oonf[ooo]Z0_l0oed01ol0Gooo
0?mMo`3oGOl0o`coolT0onGo0?oo^P000_l0oed7o`3ooPGooo]Z00OoolT0oooR0?oonf[ooo]ZoeGo
0?oo:03o0;Ko00;o0?o_00?o00ooool0@Ol0@_l00ooonfX2oooS0003ool0DOoEo`3onOl000;oo`2@
0_l0oaP00ooonf[oob@0oolT0002oookJP05oolN0?oonf[oE@3ooookJ_l0Eol00_ooD@03oomi0004
ool0^?n@o`3oogT0onGo00;o0?mC00Coo`0Ko`3oh?l0on3oo`3`0_oc0?l2oomC00;ooo]Z00?oolT0
ool0Lol0=ol00_l0=ol2o`3oG@;o0?mI00Co0?mMo`2Bool0T_oof_l00_oo03h4oookJP03ool00?oo
kP3oo`0000Ooo`000_oo00`5oookJP;oo`2/1?l0o``2o`2Mo`;oocP00_l0;Ol2oomD00_oo`000_l0
/?l01Ol0o`col@3ooo40oooa0?oo0?l<00CoolT000?o04Soo`2`ool0/?l00_l0/?l>ool0b0oo0;3o
1?l0o``3ool000Oo05oo0_m4o`05oomi00;o02go00?oocP0o`2Mool0WOl00_ooN@02oolX00;oo`2/
1OoonfX2ool030;oo`4000?oA?l0oomi0?ook0000oooN@02ooo^00Cooo]Z0ooo03h2o`3ooP06o`2B
ooo00?oo0?mIo`3oFOoonf[oo`3=0_l0=ol01?ooa@3oo`1cool0LooonfX2oomC00?ol`3o1?l0ooh0
1Ol0oe?o0?l<ool00ol0oi7oo`2h00CoA?l000?o0?onodCo0?ooN@000_mE0?l2oolN00;ooo]Z0_oo
90001ol0ookoA?l0odCo0?oUo`3oo`2@ooWo0?l0ooh00_ooh`000oooM03o0?onoookJP02o`12o`Go
05oo00CoEOl0oookJ_oonf[ooo]Z0_oohP07oookJP03ool0QOoo0?;oon@000;ooo]Z0_m_0?l2oonj
00;o0?mP00?ooo]Zool0Iooo06L00ooonfX2ool0[a7ooo]Z0_l0o`UkoookJP;o0?l94OoonfX2ool0
[`?ooo]Z0_oo06L01Ooonf[o0?mPo`3oH?l0]ooookX000;oK`3o0ooonfX2ool0lPSooo]Z0_oohP02
oookJP;oEOl00_l0onl2oookJP;o04;o0_oonfX2oooS0003ool0DOoEo`3onOl000;oo`2@00?ooo]Z
o`3o6?l0oaP00_oo9002oookJP;ooah00_mE0?l01_l0ocKooe40oomA0?ooD@3ohol0oomX00;oo`2h
00?o0?nAoookJ_oonfX00_l0oe<01?oonf[o0?oPool0l?oo0?02oo<0o`;ooe<000Cooo]Zool0Looo
07?oolD00_l0=ol01Ooo0<gooo]Zo`3oFOl0oeWo`03o00;o09;o00?ooo]Zool0?_oo03h01OoonfX2
ooo^0007oookJ_l0obcoon`0ooo/0?oo7P3oRol0ool10002ool03003o`14oooonf[ooo]Z00;ooo]Z
0_oo0:`4oookJP04obCo0?l0WOoo09gooolh00;o02go0oooE002oon60003oookJ_lVo`3o9_l000?o
o`3K1OoonfX4oo40o`?ooo]Z1ol0B?lEool0b0Go04So0ooonfX4oo40o`Kooo]Z0_oo0=/3obKo00;o
ohH00oooE003o`0]o`?o09go1?oonfX00ooo0:cooo]ZoookJP03oookJP?oo`0<00?oo`40oolN0?oo
7P000_ook0000olX0?oooo]Zooo^0002ooo^00Cooo]Z0_oo03h01?oJo`3o09;oo`2Bool0T_l2o`3o
F@03oookJ_oo0<goo`3=00;o03Oo0_oo07<2oookJP09oomC0?oc0?ool`3ooo<0oooo0?3o0?oPolX0
oooonf[o0?mC00;ooo]Z00Co0?nAool0^?oo0;Soo`2h0_oSo`02oomA0005o`1Gool0ocKoE@3ooeD0
oooo7P000_oonfX2oolT0003oookJ_l0oaSooo]Z00;oo`2@00?onOl0omGo0?oo05400_ooh`02oook
JP;o04;o00?oo`11oookJ_l0onl00_l0onl2oeGo00;ooo]Z0_oohP08oookJP;oo`3b0ooonfX00om_
0?oookX0oonj0003o`3oH003oookJ_oo06Oooo]Z00;ooo]Z0ooo0:lAoookJP;o0?l9@ooonfX003Wo
oo]Z0_ooN@001?l0ookoA?l0oomi0?ooN@0?oookJP03ool0[oooN@3ooo]Z00;o0?mM00Oo05ooo`3o
GOl0oego0?mPooo90?oo^P3oiOl000;o0?mM2?l0ooh4oookJP;oon800ooonfX01?oo:03o0;Koo`3o
kol0onl2o`0?o`;o04;o0_oonfX01OooM03oon<0oooS0?oEo`3o05oo00;oo`2@00?ooo]Zo`3o6?l0
oaP00_oo9002oookJP;ooah00_mE0?l2o`1Go`;ooe400_ooN@001On@o`3oo`2hodCo0?m4o`3oiOl0
00;oo`0000Co0?n]o`3oh?l0on3oo`3`0_oc0?l2oomC00;ooo]Z00CoolT0ooo50?l0=ooo03Oo0ol0
oed2o`3oF@;o09;o00Cooo]Zom[o0?oo03koo`0n1?oonfX2ooo^00Soo`000_oo00`5oookJP;oo`2/
1Ol0o``2o`2Mo`04oolh0?l0;Ooo02gooomD00_oo`0000Co0;3ooookJ_oonf[o0?l<1Ooa0?l01?oo
b@3ooo]ZoookJ_oonfX5o`2`o`Co0?l<00?oolT0ool0b?oo0<P01?oo0<P@o`2`o`Co0?l<0_oonfX7
o`1Oo`?oA?l01OooN@02oolh0004o`2MooooN@3oU?l0oiCo00;ooo]Z0_oo0:`4oookJP03o`14oooo
00coo`0<00;oo`4000?oA?l0ooo/0?ook0000oooN@02ooo^00Cooo]Z0ooo03h01?l0ooko09;oo`2B
ooo00?l2o`3oF@05ooo90?oo0<go03Ooo`0gooooa@000_oo07<2oookJP04oomi0?oc0?ool`3ooo<0
o`Co0?on00Ko0?mCo`2`oooonf[oo`03oi3o0?oo0;P3odCo0007o`3oo_m4o`3oA?l0odCo0?mE0?oo
oo]ZoolN0002oookJP;oob@000_oA?l0o`3oo_m4o`3oo`2@onGo0?oio`3o0?onool0DOooh`3oog@0
o`3ooP02oookJP;o04;o1?l0Gol2oeGo00;ooo]Z0_oohP07oookJP03ool0QOoo0?;oo`3b00;ooo]Z
0_m_0?l3oonj00;o0?mP0_oo06L4oookJP03ool0[ooonf[ooo]Z013ooo]Z0_l0o`UkoookJP;o0?l9
4_oonfX01?oo0:oooo]ZoookJ_oonfX2ool0I`04oookJ_l0of3o0?mPo`2go`;ookX000CoK`3ooook
J_oonf[ooo]Z0_oo0?800ooo08Gooo]ZoookJP05oookJP;oon800_oonfX2oeGo0004o`2fool0onoo
oo]ZoookJP;o04;o0_oonfX02?ooM03oon<0oooS0?oo057oeOl0ooWo0?oo093ooo]Z0_l0oaP3oolT
0003oookJ_oo7P3ooah000;oE@3o00Oo0?lfo`1GooooD@3ooe40on?o0?ooJ03ooh`000;oo`2h00Oo
o`03oookJ_oonf[o0?mCoookJ_o:0?oo0?oP00;oo`3`00?ol`3oool0eoooD`000_oonfX01?oo07?o
olD0ooo50?l0=ol2ool0c@03oookJ_l0oeWo0?mI00;o09;o0_oonfX2ool0?PCooo]Z0oookP001ooo
nf[o0?l/ooo/0?ook03ooah0oh_o0?oo0@000_oo00`00ol0A?oooo]ZoookJP02oookJP;oo`2/1Ooo
nfX3o`2Mo`?o02go0_ooE003oon60003oookJ_lVo`3o9_l000?oo`3K1OoonfX4oo40o`Gooo]Z2Ol0
B?l9ool0b0Oo04So1?oonfX4oo40o`Oooo]Z0ooo0=/2obKo00?oohH00oooE002o`0]o`03oolh0?l0
WOoo09go00Cooo]Z0_oo0:`4oookJP05o`14oooo00coo`0<ool03?oo0@000_oo7P02ooo/0003obP0
oooonf[oonh000;oonh01?oonfX2ool0?P04om[o0?l0T_oo09;oo`2Bo`;o0?mI00?ooo]Zool0cOoo
0<d00_l0=ol2ool0L`;ooo]Z00Sooe<0oo<0oooc0?ool`3oool0l?l0on3obP3ooookJP;o0?mC00?o
oo]Zool00ol0oi400_oo0;P01_ooJ03ohol0on?o0?ooD@3o05Ooo`3o=P;oE@3o0_oo7P02oookJP05
oolT0?oonf[o0?lHo`3o6?oonfX00_oo0902omGo00;oon<00ooonfX2o`12o`;ooo]Z0_l0onl3oeGo
0003oookJ_oohP3oon8000Sooo]Z0_oo0?83oookJP04ofl0oooo^P3ookX0oonj00;o0?mP00?ooo]Z
ool0Iooo06L00ooonfX2ool0[a7ooo]Z0_l0o`U4oookJP00>OoonfX2oomi0003o`3oo_m4o`3oogT0
00;oogT03_oonfX00ooo0:ooogT0oookJP02o`3oG@09o`1Oool0oego0?mMo`3oGOoob@3o0?mMonGo
0?oo^P3o0?mM00Go0?on0ol0o``5oookJP;oon800_oonfX00ooo:03o0;Koo`3ok`02o`3ok`;o00oo
00Co04;ooookJ_oonf[oog@00_ooh`000ooo057o05ooool0T002ool0T0;o0?lH00?ooo]ZoolT0?oo
90000_oonfX01Ooo7P3ooo]ZoeD0oooonf[o05Oo00;ooe4000Gohol0o`3oo_ooS03oo`2hoi3o0002
odCo00?oo`000_l0on02ool0l003oo<0ooooD`3ooe<000;ooo]Z0_oo07<3o`0go`?oiOl000Go0?mI
ol00ool0T_oo09;ooookJP02ool0?PGooo]Z00?oonh0ool00?oo00001?oo00000ol0o`coo`40ool1
0002ool030Gooo]Z0_oo0:`3o`3o30;oolT00_l0WOl01?oo>03o02goo`0]ooooE009ool000;oo`3K
0ooonfX01?l0o`cooo]ZoookJ_oa0?l7o`0?o`?o0;3o0ol0o``01?l03oooolT0ooo90?oob@03o`3o
[@CoU?l01?oo:0000ooonf[ol@3oo`2`o`06o`2`o`Gooo]Z1Ol0Gol2o`3ooPGoA?l01OooN@000ol0
WOooU?l0oiCo0003oiCo00;oo`2/1?oonfX00ol0A?ooo`0<ool03002ool10003odCo0?ook03oon`0
00;oogT000?ooo]Zooo^0?ookP001?oonfX3ool0?P04o`3oo_l0T_oo09;ool00o`;o0?mI00Goo`00
ool0cOoo0<go03Ooo`3o_@02ool0L`;ooo]Z00Cooe<0oomi0?oc0?ool`3o1?l0ooh01_l0oe?o0;3o
o`2`ool0o`coT?l0ool0^0?oA?l000?o0?onodCo0?m4o`000om4o`02oolN00;ooo]Z00?oob@0odCo
0?l0ooh00_m4o`001?oUo`3oo`2@ooWo0?l0ooh2oooS0003oomd0?oonf[ooo]Z00;o04;o1Ol0Gol0
1OmEo`3ooo]ZoookJ_oonf[oon8000Sooo]Z00?oo`25ool0l_ooi0000_oonfX2ofl0o`;ookX00_l0
of000ooonf[oo`1Wool0I`03oookJP;oo`2_4OoonfX2o`3o2Gcooo]Z0_l0o`TBoookJP;oo`2_0ooo
nfX00ooo06Oooo]ZoookJP02o`3oH0;ookX00_m_0?l2oookJP;oo`3b00?oo`25oookJ_oonfX01Ooo
nfX2oooR00;ooo]Z0_mEo`001Ol0]_oo0?o_o`3okooonf[oo`1100;o04;o00Oooo]Zoomd0?ooh`3o
on<0ool0DOoEo`3onOl000;oo`2@00?ooo]Zo`3o6?oonfX00_oo9002oookJP;ooah00_mE0?l00ol0
ocKooe40oomA0002on?o0004oon<0?oo0;Soo`2ho`3oT@;ooo]Z00?o0?mCool06ooonfX00_l0on00
0ooo0?3oo`3Goo<0o`02oomC0004oookJ_oo07?oo`1cooo500;o03Oo00Goo`3=oookJ_oonf[o0?mI
ol00o`02o`2Bo`03oookJ_oo03koo`0n00Gooo]Z0_ookP001?oonf[o:03oo`3o;?ook002oolN0005
oh_o0?oo0@3oo`0<ool03?l0A?l01?oonfX2ool0[0Gooo]Z0ol0WOl00ooo>03o02goo`0]o`03oomD
00;oohH00_oonfX2obKo00?oo`3K1_oonfX5oo40o`Kooo]Z3Ol0B?l3o`0000?ooo]Z1ooa0?l7oook
JP;oo`3K0olVo`000ooonf[oohH0oon60003oomD00;o02go00CoocP0o`2Mool0WOoo9?l01?oonfX2
ool0[0Cooo]Z00Go04Coool03?oo00coo`0<ool10002oolN0004ooo/0?l0obco:03ooookJP;oonh0
1OoonfX2ool0?P06om[o0?l0T_oo09;oo`2Booo00?oo0?mI0_oonfX01?oo0<go03Ooo`0gooooa@02
ool0L`03oookJ_ooD`3ooe<000;ol`3o0_oo0?001ol0on3ooo]Zo`3oDol0oe?ooo]Zool00ol0oi40
0_oo0;P01?ooS03ohol0on?o0?ooD@02o`1Go`;oE@3o0_oo7P02oookJP05oolT0?oonf[ooo]Zo`3o
6?oonfX00_oo09000ooio`3oeOl0oooS0002oooS00;ooo]Z0_l0@_l01Ooo047ooo]Zo`3okol0onoo
0;Ko00;oEOl00_oonfX2oooR00Sooo]Z0_oo0?83oookJP03ofl0oooo^P3ookX000?o0?mP00?ooo]Z
ool0Iooo06L00_oonfX3ool0[a7ooo]Z0_l0o`U4oookJP00>OoonfX2oomi0003o`3oo_m4o`3oogT0
00;oogT03_oonfX00ooo0:ooogT0oookJP03o`3oG@08o`1Oool0oego0?mMooo90?l0GoooiOl0oonj
0?l0oed2o`3ooP;oA?l000?o0?onodCo0?l0o``00_l0o``4oookJP;oon800_oonfX00ooo:03oEOl0
o`3ok`02o`3ok`;o00oo00Go04;ooookJ_oonf[ooo]Zoomd0002oooS0004omGo0?oio`3oo`2@ool0
T0;o0?lH00?ooo]ZoolT0?oo90000_oonfX01Ooo7P3ooo]ZoeD0oooonf[o05Oo00?ooe4000Oohol0
odCo0?oo0;Soo`2hoomi0?l03ooooo]Z00?oo`000_l0on000ooo0?3ol`3ooo<0o`02oomC00;ooo]Z
00Goo`1cooo50?l0=ooo03Ooo`3oG@02onGo00;o0?mI00Co05ooo`2Bool0T_oooo]Z0_oo03h5oook
JPKoo`0000Coon`0ooo90?oo0@3oo`400_oo00`5oookJP;oo`2/00?o0?l<ooo90?oob@000_oob@03
o`0?o`?o02go1ooo0003obKo00?oo`3K1?oonfX00ooob@3ooo]Zo`0?o`05o`0?o`05o`2`ool03ooo
00ooo`0?ool0o``00ol03ol01?oob@3o0?n]o`3o[Ol0ojd4oiCo00CoobP01Ooa0?l7oookJPKo05oo
0ol0ooh5odCo00GoogT000CoA?l0oiCo0?nDo`3ooo]Z0ooo0:`4oookJP04o`14oooo00coo`0<ool1
00;o0?on0_ook002odCo0003oookJ_ookP3oonh000Cooo]Z0ooo03h01?l0ooko09;oo`2Booo00?l2
o`3oF@05ool00?oo0<goo`3=o`0gool0okd00_oo07<2oookJP04oomC0?ooN@3ol`3ooo<0o`?o0?on
00?o0;3oo`3oDol0oe<00_l0/?l00ol0o`coo`2hool0^003odCo0007o`3oo_m4o`3oA?l0odCo0?mE
0?oo05oooolN0002o`3ooP;oob@000[o0?onodCo0?m4o`3oiOl0ool0T?oio`3o0?onool0DOooh`3o
og@00_oonfX2o`12o`03ool0@Ol0Gooo05oo00;o05oo00CoEOl0oookJ_oonf[ooo]Z0_oohP07oook
JP03ool0QOoo0?;oo`3b00;ooo]Z0_m_0?l3oonj0004o`3oH?oonf[oo`1Wool0I`Cooo]Z0_oo0:lA
oookJP;o0?l9O?oonfX2o`3o2A;ooo]Z0_oo0:l3oookJP;oo`1W00Gooo]Zo`3oH?l0of3o0;Oooonj
0002ofl0o`?ooo]Z00?oo`3bool0QOoonfX01ooonfX00ooohP3ooo]ZoookJP03oeGo00;o0?o_0_oo
nfX2o`12o`;ooo]Z00?oog@0oooS0?ooh`000_oEo`000ooio`3oo`2@oookJP02o`3o60;oob@00_oo
nfX2oolN00;oE@3o00Ko0?lfo`1GooooD@3ooe40on?o0?ooJ003ool0^007ool00ooonf[ooo]Zo`3o
Dooonf[obP3oo`3oh002ool0l003oo<0oooo0=Oooe<000;ooo]Z00?oo`1cooo50?ooa@000_l0=ol0
1Ooo0<gooo]Zo`3oFOl0oeWo0?lU00;o09;o00?ooo]Zool0?_oo03h01OoonfX2ooo^0003oookJ_lX
0?oo0?l/00;oon`000?ooah0oh_o0?oo0@000_oo00`00ol0A?oooo]ZoookJP02oookJP;oo`2/1Ooo
nfX4o`2Mo`?o02go0oooE002oon60003oookJ_lVo`3o9_l000;o9_l00ooo0=/7oookJPOol@3o3?oo
nfX;oo40o`Oooo]Z0_oo0=/4obKo00?oohH00oooE002o`0]o`05oolh0?l0WOoo09goo`2MoolTo`00
0ooonfX3ool0[0Cooo]Z00Ko04Coool03?oo00coo`0<oh_o0?oo7P02ooo/0003o`3o;?lX0?oooo]Z
00;oonh01OoonfX2ool0?P06om[o0?l0T_oo09;oo`2Booo00?oo0?mI0_oonfX01?oo0<go03Ooo`0g
ooooa@02ool0L`03oookJ_ooD`3ooe<000?ol`3o00?oo`3`o`3oh?o:0?l00ol0oe<01Ooonf[o0?nA
ool0^?oo0;Sooh`000;ohol00_ooD@001?l0EoooE@3ooeD0oomE0?l2oolN0004oookJ_oo903oob@0
oookJP;o0?lH00Gooo]Zool0T?oio`3oeOl0ool0D@02oooS00?ooo]Z0_l0@_l01?oonf[o0?o_o`3o
kol0onl2oeGo00;ooo]Z0_oohP08oookJP;oo`3b0ooonfX01?m_0?oookX0oonj0?oo^P02o`3oH003
oookJ_oo06Ooo`1W00?ooo]Z0_oo0:lAoookJP?o0?l9A?oonfX003Wooo]Z0oooN@000om4o`3oogT0
oomi0002oomi00kooo]Z00KoogT0oookJ_l0oego0?mMonGo0?l0Gol2o`3oG@07o`3oH?oob@3oiOl0
oonj0?l0oego05ooo`3o3002odCo0003o`3oo_m4o`3ooo]Z00Kooo]Z0_oohP03oookJP04oolX0?l0
]_oo0?o_o`3ok`;o00oo00Go04;ooookJ_oonf[ooo]Zoomd0002oooS0005omGo0?l0Goooo`2@ool0
T?oonfX00_l0oaP00ooonf[oob@0oolT0002oookJP03oolN0?mE0?ooE@3o00;o05Oo0_ooD@001?oS
o`3o0?onoomi0?oo0;P2o`3oT@04o`0?oooo003oo`00ool000;o0?oP0_oo0?02oo<0o`06oomC0?oo
nf[ooo]ZoookJ_oo07?oolD00_l0=ol3onGo00;o0?mI0_l0T_l01?l0Goooo`0nool0?_oo03h5oook
JP;oo`000_l0o``3ooo/00;oolT000?oo`40ool03?oo00`01OoonfX3o`1Oo`GoolT00_l03ol4o`0]
o`Coo`000_ooQP001?l0Gooo9_l0obKo0?lVo`04ool0f`Kooo]Z2ol03ol4o`3o[@CoU?l01?oo:00:
oookJP03ool0fol0Gooo05oo00?o05oo1Ol0ooh6odCo00CoogT00_oonfX3ool0[0Gooo]Z0_oo00`0
1?l0A?ooo`40o`3oo_m4o`02ooo/00?oA?l00_ookP04oookJP?oo`0n00?o0?ono`2Bool0T_l00ol0
oeT00ooo003oo`3=ool0c@02o`0go`06ooo50?oo07?ooo]ZoookJ_ooD`3oogT00_oc0?l3o`3ooP03
o`2`ool0oe?o0?mC00;oo`0000Co0?l<o`3oo_l0ookooh`00_m4o`001_l0ookoA?l0odCo0?m4o`3o
E@3oo`1Oo`;ooah00_l0ooh00ooo903oA?l0o`3ooP02odCo0005onGo0?oio`3onOl0o`3oo_ooh`00
0_ooM002oookJP;o04;o00Koo`11o`1Oool0Gooo05ooo`2foomEo`03oookJP03oooR0?oonf[ooo]Z
00Kooo]Z00?oo`25ool0l_ooi0000_oonfX2ofl0o`;ookX00_l0of000ooonf[oo`1Wool0I`03oook
JP;oo`2_4OoonfX2o`3o2Ggooo]Z0_l0o`TBoookJP;oo`2_0ooonfX2ool0I`07oookJ_l0of3o0?mP
o`2goooo^P3ooo]Zofl0o`03oookJP03ool0l_oo08Gooo]Z00Oooo]Z0_oohP02oookJP;oEOl000Co
o`26o`3okooonf[ooo]Z0_l0@_l2oookJP07oomd0?ooh`3oon<0ool0DOoEo`3onOl0ool0T002oook
JP04o`3o6?oonf[oob@0oolT00;ooo]Z00Gooah0oeD0oomE0?oo0?lfo`1Go`02oomA00;ohol000Co
oh`0ool0^?oo0;So0?nA0_oonfX2o`3oD`04oookJ_l0on3o0?oPool0l0;ol`3o0_ooD`02oookJP05
ool0Loooa@3oolD0o`0goooo0<d00_oonfX2o`3oF@;o09;o00Cooo]Zool0?_oo03koo`0n1OoonfX2
ooo^00;ooo]Z00Ko0?l/ooo/0?ook03ooah0oh_o0?oo0@03ool030Cooo]Z0ooo0:`5oookJP?o09go
0ol0;Ol3oomD00?oohH000?ooo]ZobKo0?lVo`000_lVo`04ool0f`Oooo]Z5?oa0?l;oookJP?oo`3K
1?lVo`03oon600?ooe@00ol0;Ol01?oo>03o09goo`2MoolTo`04oookJP;oo`2/1OoonfX3ool03003
ool10?n;o`3ooah000;oon`000?o0?l/oookJ_oonfX00_ookP04oookJP?oo`0n00Cof_l0o`2Bool0
T_oo09;o0_l0oeT2oookJP04ool0cOl0=ooo03Ooooo500;oo`1c0_oonfX02?ooD`3ol`3ooo<0oooc
0?ooo`3`o`3oh?o:0?oooo]Z0_l0oe<01_oonf[oo`03o`3oTOoo0;Sooh`0oomX00;ohol000?ooe40
o`1Gool0Eol00_mE0?l2oolN00;ooo]Z00Goob@0oookJ_l0oaSo0?lHoookJP02ool0T005ooWo0?oE
o`3oon<0oooS0?ooM0000_oonfX2o`12o`05ool0@Ooonf[o0?o_o`3okol0]_l00_mEo`02oookJP03
oooR0?oonf[ooo]Z00Kooo]Z00?oo`25ool0l_oo0?800ooonfX01Om_0?oookX0oonj0?l0]ooo0?mP
00;ooo]Z0_oo06L3oookJP03ool0[ooonf[ooo]Z013ooo]Z0_l0o`U5oookJP00>OoonfX3oomi0003
odCo0?ooN@3ooo]Z013ooo]Z00_oogT0oookJ_oonf[ooo]ZonGo0?l0Gooo0?mMonGo0?l0oegoolT0
onGo0002oonj0003o`1Oool0o`coA?l000;oA?l000?o0?onodCo0?oonfX01_oonfX2oooR00;ooo]Z
00?oobP0o`2fool0onl00_l0onl2o`0?o`04o`12oooonf[ooo]ZoookJP;oon<000?oo`1Ao`1Ooooo
09000_oo0902o`3o6003oookJ_oo903oob@000;ooo]Z00Gooah0oookJ_mE0?oooo]Zo`1Go`02oomA
00;ohol000GoogT0ool0^?oo0;So0?nAo`0?o`03ool000;o0?oP0_oo0?001?oo0=Ool`3ooomC0?oo
D`02oookJP;oo`1c00?oolD0o`0gool0oed00_oUo`02o`3oF@04onGo0?l0T_oo09;oo`1Oo`;oo`0n
1OoonfX01Ooo003oonh0ooo^0?oonf[oolT000?oon`00_oob@000ooo0@3oo`0<ool03004oookJPKo
05oo00?oolT0oookJ_lTo`000ol03ol3o`0]o`;oo`0000?ooe@0o`1OooooQP000_ooQP000ol0Gooo
9_l0obKo0002obKo00Coo`3K1OoonfX9o`0?o`?o0?n]1OnDo`04oolX00Gooo]Z1Ooo0=/5o`1Oo`Oo
0?on1Om4o`05oomi0003ool0[?oonf[oo`2/00Cooo]Z00Co04Coool03?oo00coo`400_l0ooh3ooo/
00?oA?l00_ookP04oookJP?oo`0n00?o0?ono`2Bool0T_l00ol0oeT00ooo003oo`3=ool0c@02o`0g
o`03oomi0?oo07?oo`0000;ooo]Z00CoogT0oo<0oooc0?ooo`3`0_l0ooh01?l0/?oo0?mCo`3oDol0
/?l2ool00006oi3o0?l0ooko0?ono`3oo_m4o`3o0?on0om4o`001?mE0?oo05oooolN0?oo7P02o`3o
oP0<oolT0?l0ooko0?ono`3oo_m4o`3o0?mMool0T?oio`3o0?onool0DOooh`3oog@00_oonfX2o`12
o`06ool0@Ooonf[o05ooo`1Oool0]_ooEOl00ooonfX2oooR00Oooo]Z00Goo`25ool0l_oo0?;oon@0
oookJP02ofl0o`;ookX000?ooo]Zo`3oH?oonfX00_oo06L4oookJP;oo`2_4OoonfX2o`3o2Ggooo]Z
0ol0o`TAoookJP;oo`2_1?oonfX01Ooo06Oooo]ZoookJ_l0of3o0;Oo00;ookX000CoK`3ooookJ_oo
nf[ooo]Z0_oo0?800ooo08Gooo]ZoookJP05oookJP;oon800_oonfX2oeGo0003o`2fool0onoo0?o_
00;ooo]Z0_l0@_l2oookJP;oon<000?oo`1AomGo0?oio`000_oo09000ooonf[o0?lHoookJP02oolT
00;ooo]Z0_oo7P02oeD0o`07o`3o=_l0Eooooe40oomA0?oSo`3oofP0oon<0002ool0^005ool00ooo
nf[ooo]Zo`3oDooonfX00_l0on02ool0l0;ol`3o0_ooD`001?oonf[oo`1cool0Loooa@02o`0go`05
ool0cOoonf[o0?mIo`3oFOo00?l00_l0T_l01?oonf[oo`0nool0?_oo03h5oookJP;oonh00_oonfX0
1_l0obcoon`0ooo/0?oo7P3oRol0ool100?oo`0<1OoonfX2ool0[0Gooo]Z00Co9?l0o`2Mool0WOoo
ocP00ol0;Ol3oomD00?oohH000?ooo]ZobKo0?lVo`000_lVo`05ool0faCooo]Z1?l00006oookJPGo
o`3K1OlVo`02oon600Cooe@00ol0;Ol01?oo>03o09goo`2MoolTo`05oookJP;oo`2/1OoonfX3ool0
3003ool10?oo7P3ooah000;oon`000?o0?l/oookJ_oonfX00_ookP04oookJP?oo`0n00Cof_l0o`2B
ool0T_oo09;o0_l0oeT2oookJP05ool0cOl0=ooo03Ooooo50?oo07<00ooonfX01OooD`3ol`3ooo<0
oooc0?ooo`3`00;o0?oP00Wooo]Zo`3oDol0oe?ooo]Zool00ol0oi7oo`2hoon<0?ooJ0000_oSo`00
0oooD@3o05Ooo`1Go`02oeD0o`;ooah00_oonfX2oolT0003oookJ_l0oaSooo]Z00;oo`2@00?onOl0
omGo0?oo05400_ooh`02oookJP?o04;o00Cooo]Zo`3okol0onoo0;Ko0_mEo`02oookJP;oon802?oo
nfX2ool0lP07oooT0?oonf[ooo]Zofl0oooonf[ookX0o`2go`02o`3oH003oookJ_oo06Ooo`1W00?o
oo]Z0_oo0:lAoookJP?o0?l9AOoonfX003Wooo]Z0_ooN@000ooonf[oogT0odCo000AoookJP0@oomi
0?oo0:oooo]ZoookJ_oUo`3o05ooo`3oGOoUo`3ooo]Zooo90?l0GoooiOl0oonj0?l0oego05ooo`3o
G@;oA?l000?o0?onodCo0?m4o`001_oonfX2oooR00;ooo]Z0_mEo`03o`3ok`03oookJ_oo047o04;o
00?ooo]Z00Goog@0oooS0?ooh`3o05ooooWo0002ool0T003o`1Oool0oaSo0?lH00;oob@00_oonfX2
oolN00;oE@3o00_o0?lfoomA0?ooD@3ooe40on?o0?m4o`3oogT0ool0^?ooN@3o0?nAo`0?o`03ool0
00;o0?oP0_oo0002oo<0o`06oomC0?oonf[ooo]ZoookJ_oo07?oolD00_l0=ol3onGo00;o0?mI0ol0
T_l00ol0Goooo`0nool0?P06oookJP;oonh00_oob@03ooo/00;oolT000Coo`40ool03?oo00co0?on
0ooonfX8o`1Oo`03obCo0?l03ooo00oo00;o00oo0ol0;Ol3o`0?o`03oomD0?ooQP3oohH000;oohH0
00?o05ooobKo0?lVo`000_lVo`04ool0f`Cooo]Z1ol03ol3o`3o[@GoU?l01?oo:0000ooonf[oo`3K
ool0f`03ool0f`?o9_l01?l0Gol9o`3ooPGoA?l00_ooN@000ooonf[oo`2/ool0[002ool0[0Cooo]Z
0ooo00`00ooo0@3o0?ono`3ooP02ooo/00?oA?l000?ooo]Zooo^0?oonfX01?oonfX2ool0?P04om[o
0?l0o`co09;oo`2Bo`?o0?mI00?oo`00ool0cOoo0<d00_l0=ol01_ooN@3oo`1coomi0?ooN@3oo`00
oomi00;ol`3o0_oo0?000ol0ooko0?oPo`2`o`02o`3oD`;oo`0000?o0?l<o`3oo_l0ooh01?l0ooh2
odCo00;oE@3o0_oo7P001?oonf[o0?ononGo0?oUo`03o`3ooP03onGo0?l0oegonOl000;o0?on00?o
on<0oomd0?ooM0000_oonfX2o`12o`04oookJ_l0Gooo05ooo`2fo`;oEOl00_oonfX2oooR00Sooo]Z
00Coo`25ool0l_ooi03ooo]Z0om_0?l2oonj00;o0?mP00?ooo]Zool0Iooo06L00ooonfX2ool0[a;o
oo]Z00?o0?l9oookJ_oonfX0OOoonfX2o`3o2A7ooo]Z0ooo0:l3oookJP03ool0Iooonf[ooo]Z00;o
0?mP00Co0;Oooonj0?m_0?ooK`3o0_oonfX00oooi03oo`3bool0Q@08oookJP03oooR0?oonf[ooo]Z
00?oEOl00_l0onl2oookJP;o04;o0_oonfX02?ooM03oon<0oooS0?oo057oeOl0ooWo0?oo093ooo]Z
0_l0oaP01?oonf[oob@0oookJ_oonfX3oolN0003oeD0ool0ocKo05Oo00;ooe400_oSo`001?ooS03o
o`2hool0^?l0oi42oookJP;o0?mC00Cooo]Zo`3oh?l0on3oo`3`0_oc0?l2oomC00;ooo]Z00?oo`1c
ooo50?ooa@000_l0=ol2oookJP;o0?mI0ol0T_l00ooonf[oo`0nool0?P06oookJP;oonh00_oonfX0
1_l0obcoon`0ooo/0?oo7P3oRol0ool100?oo`0<1OoonfX3ool0[0Cooo]Z0_lTo`02o`2Mo`04oolh
0?l0;Ooo02gooookJP?ooe@01?ooQP000ooonf[o9_l0obKo0003obKo00Coo`3K4OoonfX4o`0000;o
oo]Z1_oo0=/5obKo00?oohH01?ooE003o`0]o`;oocP000?o09goobCo0?lTo`001?oonfX3ool0[0Co
oo]Z0ooo00`00ooo0@3oRol0oolN0003ooo/0004o`3o;?oonf[ooo]Zooo^00Gooo]Z0ooo03h01?oo
nf[o09;oo`2Bool0T_l2o`3oF@03oookJ_oo0<goo`3=00;o03Oo00?oo`3Aool0Looo07<00_oonfX0
1OooD`3ol`3ooo<0oooc0?ooo`3`00;o0?oP00Kooo]Zo`3oDol0oe?ooo]Zool00ol0oi42ool0^003
oon<0?oSo`3ohol000;ooe4000Co05OooeD0oomE0?ooE@3o0_oo7P02oookJP05oolT0?oonf[o0?lH
o`3o6?oonfX00_oo0902omGo00;oon<000?oog@0oookJ_oonfX00_l0@_l2oookJP;o0?o_0_mEo`03
oookJP03oooR0?oonf[ooo]Z00Kooo]Z00?oo`25ool0l_ooi0000_oonfX2ofl0o`;ookX00_l0of02
oookJP03ool0Iooonf[ooo]Z00;ooo]Z00?oo`2_oookJ_oonfX04?oonfX2o`3o2DKooo]Z000loook
JP03o`3o2Om4o`3ooo]Z017ooo]Z00KoogT0oookJ_oonf[oiOl0o`1Oool0oed2onGo0007ooo90?l0
GoooiOl0oonj0?l0oego05ooo`3oG@02odCo0003o`3oo_m4o`3oA?l000Kooo]Z0_oohP02oookJP03
o`0?oomEo`3o0;Ko00;o0?o_00Co0?n]ool0@Ol0@_oo04;o0_oonfX00oooM03oon<0oooS0002o`1O
o`?oo`2@00?o05ooo`3o6?oonfX00_oo9002oookJP05o`2`oooonf[oE@3oo`3o=_l0Eol00_ooD@02
on?o0005oomi0?oo0;Soo`2hoomi0?l03ol00ooo0003o`3oh0;oo`0000Gol`3ooomC0?l0/?oo0;3o
oookJP02ool0L`04ooo50?l0=oooiOl0onGo00;ooo]Z0_l0oeT2o`2Bo`04o`1OoooJo`3oo`0nool0
?PKooo]Z0_ookP02ooo900?oon`000?ooah0o`2`oooo0@000ooo00`2o`3ooP03oookJ_l0Gooo05oo
00Oo05oo1?l03ol01?oo>03o02goo`0]ool0;Ol2o`2`o`03o`0?ool0ojgo0?n]00CoohH01olVo`07
ool0f`;o00oo1?l0ojd2oiCo00Woo`3K1OlVo`000ooonf[oohH0oon60002o`1Oo`[o0?on1_m4o`00
1?oonf[oo`2/ool0[?oo0:`4oookJP03o`14oooo00coo`0<00;oo`400_l0ooh2ooo/00;o0?on00?o
oo]Zooo^0?ookP001OoonfX2ool0?P04om[o0?l0o`co09;oo`2Bo`?o0?mI00?o0?l<ool0cOl0=ol0
0_l0=ol00oooa@3oo`1coomi0002oomi0003odCo0?oo0=Ool`3o00;oo`3`00?o0?ono`3oh?l0/?l0
0_l0oe<01?l0/?ooo`00ool00?oo0;P6o`3ooP05odCo0?mE0?ooE@3ooookJ_oo7P000_oonfX01?l0
ookoiOl0onGo0?oUo`02o`3ooP04o`3oGOoo093o0?Soo`3ooP;oon<000?oog@0oookJ_oonfX00_l0
@_l2oookJP04o`1Ooooo08Ko0;KooeGo00?ooo]Z0_oohP07oookJP05ool0QOoo0?;oo`3boooT0?oo
nfX00_m_0?l2oonj00;o0?mP00?ooo]Zool0Iooo06L01?oonfX2ool0[a7ooo]Z0_l0o`UooookJP;o
0?l94_oonfX2ool0[`?ooo]Z00?oo`1WoookJ_oonfX00_l0of001?l0]ooookX0oookJ_m_0?l2oook
JP03oooT0?oo0?;oo`2500Sooo]Z0_oohP02oookJP;oEOl000Koo`26o`3okooonf[ooo]Zool0@Ol0
@_l2oookJP06oomd0?ooh`3oon<0ool0DOoEo`3onOl00_oo09000ooonf[o0?lHoookJP02oolT00;o
oo]Z0_oo7P02oeD0o`05o`3o=_l0Eooooe40oomA0?oSo`000_ooS002ool0^005ool00ooonf[o0?mC
o`3oDooo01/00ol0on000ooo0?3ol`3ooo<0o`02oomC0004oookJ_oo07?oo`1cooo500;o03Oo00?o
o`3=oookJ_oonfX00_l0oeT2o`2Bo`;ooo]Z0ooo03h5oookJP;oonh00_oonfX00ol0obcoon`0ooo/
0002oolN0003ool10?oo00coo`0<00;oo`0<1?oonfX3ool0[0Gooo]Z0_lTo`02o`2Mo`04oolh0?l0
;Ooo02goo`0]o`?ooe@01OooQP07obKo00Ooo`3K2?oonfX9ool0f`Go9_l000?ooo]Zoon60?ooQP00
0oooQP03oomD0004oolh0?l0;Ooo02goo`0]o`;oocP000?o09goobCo0?lTo`001?oonfX3ool0[0Go
oo]Z0ooo00`00ooo0@3oRol0oolN0003ooo/0004obP0oooonf[oonh0ooo^00Gooo]Z0ooo03h01?oo
nf[o09;oo`2Bool0T_l2o`3oF@03oookJ_oo0<goo`3=00;o03Oo00?oo`3Aool0Looo07<00_oonfX0
1OooD`3oo`3Goo<0oooc0?ooo`3`00;o0?oP0_oonfX03Ol0oe?ooo]Zool00ol0oi7oT?l0ool0^?oo
S03oofP0on?o0?oonf[ooe40o`1Gool0ocH00_mE0?l2oolN00;ooo]Z00Goob@0oookJ_l0oaSo0?lH
oookJP02ool0T003ooWo0?oEo`3oon<000;oon<00_oonfX3o`12o`05oookJ_l0onoo0?o_o`2foomE
o`000ooonfX2oooR00Sooo]Z0_oo0?801?ooi03ooo]ZoookJ_m_0?l2oonj0004o`2gool0of3o0?mP
oookJP;oo`1W0ooonfX2ool0[a7ooo]Z0ol0o`U6oookJP00??oonfX00ol0o`WoA?l0oookJP0Aoook
JP0?oomi0?oonf[ooo]ZoookJ_oUo`3o05ooo`3oGOoUo`3oolT0o`3oH?oUo`3ookX0onGo0?l0Gooo
0?mM00;oA?l000Co0?onodCo0?m4o`3oA?l01OoonfX3oooR00;ooo]Z00?oEOl0o`2fool0onl00_l0
onl00ol0ojgoo`11o`12o`03oookJP;oon<000?oo`1Ao`1Ooooio`000_oo09000ol0Gooo0?lHo`3o
6002oolT00;ooo]Z0_l0/?l2oeD0o`06o`1GooooD@3ooe40oomA0?oSo`3oA?l00_oo0;P00on@o`3o
ogT0ool00003ool000;o0?oP0_oo0002oo<0o`?o0;3o00Sooo]Zool0Loooa@3oolD0o`0goooUo`3o
o`3=oookJP;o0?mI00Go`03oo`2Bool0T_oo05ooom[o0002ool0?PKooo]Z0_ookP02ooo900?oon`0
00?ooah0o`2`oooo0@000_l03ol01?oo00co0?ono`3oo_l0ooh9o`1Oo`Go00oo00?oocP0o`0]ool0
;Ol00_l0;Ol6o`2`o`?oohH03?lVo`08ool0f`So9_l000?ooo]Zoon60?ooQP001?ooQP02oomD00co
0?on0_m4o`02oookJP?oo`2/1OoonfX2ool030?oo`4000Co0?onooo/0?ook03oon`00ol0ooh2ooo^
00Gooo]Z0_oo03h01?oJo`3o0;3oo`2Bool0T_l3o`3oF@03o`3o3?oo0<go03Oo00;o03Oo00?oolD0
ool0Looo07<00_ooN@000om4o`3oogT0oo<0o`02ool0l0;o0?oP00?o0;3oo`3oDol0oe<00ol0/?l2
ool0^0Oo0?on00KoE@3ooookJ_oo7P3ooah0oookJ_l0ooh5onGo0007o`3oGOoo093o0?Soo`3oo_oo
057oon<0oomd0002oookJP;o04;o00Goo`11oookJ_l0onoo0?o_o`2fo`02oeGo00;ooo]Z0_oohP08
oookJP;oo`3b00Coon@0oookJ_m_0?ooK`3o0ooo^P02o`3oH003oookJ_oo06Ooo`1W00?ooo]Z0ooo
0:lAoookJP03o`3o2Ooonf[ooo]Z07kooo]Z0_l0o`TBoookJP;oo`2_1?oonfX02?oo06Oooo]Zo`3o
H?l0of3o0;Oooonj0?oonf[oK`3o0ooonfX2ool0lP03ool0QOoonf[ooo]Z00Gooo]Z0_oohP02oook
JP;oEOl000?o0;Koo`3okol0onl00_oonfX2o`12o`;ooo]Z0oooh`001OoEo`3onOl0ooWo0?oo093o
oo]Z00;o0?lH00Cooo]ZoolT0?oonf[ooo]Z0_oo7P001?oonf[oE@3oo`3o=_l0Eol2oomA00;ohol0
00Cooh`0ool0^?oo0;So0?nA0_oonfX2o`3oD`05oookJ_l0on3o0?oPool0l?ooX@000_oc0?l01?oo
D`3ooo]ZoookJ_oo07<2ooo500;o03Oo00Goo`3=oookJ_oonf[o0?mIol00o`02o`2Bo`;ooo]Z0ooo
03h5oookJP;oonh00_oonfX00ol0obcoon`0ooo/0002oolN0003ool10?oo00coo`0<00;oo`0<1Ooo
nfX2ool0[0Kooo]Z0_lTo`02o`2Mo`04oolh0?l0;Ooo02goo`0]o`Cooe@01OooQP0=obKo00Ooo`3K
2OlVo`07oon600Cooe@01?l0;Ol00ooo>03o09goo`2Mo`02obCo00Gooo]Z0_oo0:`6oookJP;oo`0<
0_oo0@02oolN00?oon`00_oonfX2ooo^00Gooo]Z0ooo03h01?oonf[o09;oo`2Bool0T_l2o`3oF@03
oookJ_oo0<goo`3=00;o03Oo00?oo`3Aool0Looo07<00_oonfX2oomC00;ol`3o0_oo0?002Ol0on3o
bP3ooookJ_l0oe?oo`0KoookJ_l0oi7oT?l0ool0^002oon<0005on?o0?oonf[ooe40o`1Gool0ocH0
0_mE0?l2oolN00;ooo]Z0_oo90000ooonf[o0?lHoookJP02ool0T003ooWo0?oEo`3oo`1A00;oon<0
0ooonfX2o`12o`;ooo]Z0_l0onl2oeGo00;ooo]Z0_oohP08oookJP03ool0QOoo0?;oon@000;ooo]Z
0_m_0?l2oonj00;o0?mP0_oonfX00ooo06Oooo]ZoookJP02oookJP;oo`2_4OoonfX2o`3o2DOooo]Z
000moookJP03odCo0?oonf[ooo]Z013ooo]Z00[oogT0oookJ_oonf[ooo]ZonGo0?l0Gooo0?mMonGo
0?l0of3oolT00ooo^P000ooUo`3o0?mModCo0002odCo0003o`3oo_m4o`3oA?l000Kooo]Z0_oohP02
oookJP;oEOl000?o0;Koo`3okol0onl00_l0ojd01Ol0@_oooo]ZoookJ_oonf[oog@000;oon<00_l0
Gol2ool0T0;o05oo00?o0?lHoolT0?oo90000_oonfX2o`2`o`;oE@3o00Co0?lfo`1GooooD@3ooe40
0_oSo`000oooS03oo`2hool0^002oomi00Coo`000_l0on02ool000;ol`3o0ol0/?l00ooonf[oo`1c
ooo50002o`0go`03onGo0?oo0<gooo]Z00;o0?mI00Go`03oo`2Bool0T_oo05ooom[o0002ool0?PKo
oo]Z0_ookP000ooonf[o0?onooo/0002ooo/0003oolN0?l0ooko00oo00Co00oo0ol0ooh8o`1Oo`Ko
00oo00?o0;3oo`0]ool0;Ol00_l0;Ol8o`2`o`?oohH00ooonfXAobKo00OoohH01?ooE00>o`3ooP;o
oo]Z0ooo0:`6oookJP;oo`0<0ooo0@001?l0ookoon`0ooo/0?ook003o`3ooP;oonh01OoonfX2ool0
?P04om[o0?l0/?oo09;oo`2Bo`?o0?mI00?o0?l<ool0cOl0=ol00_l0=ol3ool0L`;oogT000GoA?l0
oomi0?oc0?ool`3ooomi0002o`3oh005oookJ_l0oe?o0?mCo`2`oooonfX00_l0/?l00ooo0;So0?on
o`3ooP07o`3ooP;ooah00_oonfX00ooo903oiOl0onGo0002onGo0003o`3oGOoUo`3oiOl000;o0?on
00?oon<0oomd0?ooM0000_oonfX01_l0@_ooo`11oookJ_oonf[o0?o_ool0QP;oEOl00_oonfX3oooR
00Oooo]Z00?oo`25ool0l_oo0?800_oonfX2ofl0o`;ookX00_l0of000ooonf[oo`1Wool0I`04oook
JP;oo`2_4OoonfX2o`3o2H7ooo]Z0_l0o`TAoookJP;oo`2_1?oonfX01Ooo06Oooo]ZoookJ_l0of3o
0;Oo00;ookX00_m_0?l2oookJP;oo`3b00?oo`25oookJ_oonfX01_oonfX01?oohP3ooo]ZoookJ_oo
nfX2oeGo0004ool0Q_l0onoooo]ZoookJP;o04;o0_oonfX01oooM03oon<0oooS0?oo057oeOl0ooWo
0?oo09000_oonfX00ol0oaSooo]ZoolT0003oookJP;ooah000CoE@3oo`3o=_l0ocKo05Oo0_ooD@00
0ooSo`3ooh`0oon<0002ool0^003ool00ooonf[o0?mC00;o0?mC0ol0on000ooo0?3ol`3ooo<0o`02
oomC00;ooo]Z00?oo`1cooo50?ooa@000_l0=ol01Ooo0<gooo]ZoookJ_l0oeWo`03o00;o09;o0_oo
nfX3ool0?PGooo]Z0_ookP02oookJP03o`3o;?ook03oon`000;ooah00_oo0@03ool030Kooo]Z0_oo
0:`6oookJP;o9?l00_l0WOl00ooo>03o02goo`0]o`02o`0]o`Cooe@000?o00Oooon60?ooQP001?oo
QP03oookJQ3o9_l01oooQP06oomD00Co02go00?oocP0o`2Mool0WOl00olTo`05oookJP;oo`2/1_oo
nfX3ool030;oo`4000?ooah0ooo/0?ook0000_ook002oookJP;oonh01OoonfX3ool0?P04oookJ_l0
T_oo09;oo`2Bo`;o0?mI00?ooo]Zool0cOoo0<d00_l0=ol00ooo0=7oo`1cool0L`02oookJP;ooe<0
0_oc0?l2ool0l006o`3oh?o:0?oooo]Zo`3oDooo01_ooo]Z0_l0oi400ooo0;Sooh`0oon<0002on?o
0003oomA0?l0Eooo0?lf00;oE@3o00Cooo]ZoolN0?oo7P3ooo]Z0_oo90001_oonf[o0?lHo`3o6?oo
nf[oo`2@ooWo00;oeOl00_ooh`000oooM03ooo]ZoookJP02o`12o`04ool0@Ooonf[o0?o_o`3ok`;o
EOl00ooonfX2oooR00Oooo]Z00?oo`25ool0l_oo0?800ooonfX01Om_0?oookX0oonj0?l0]ooo0?mP
00;ooo]Z0_oo06L3oookJP;oo`2_4OoonfX2o`3o2DSooo]Z000moookJP03odCo0?oonf[ooo]Z013o
oo]Z0_oo0:l2oookJP03onGo0?l0Gooo0?mM00;oiOl000KoolT0o`1Ooooo^P3ookX0onGo0?l0Gol3
odCo0004o`3oo_m4o`3oA?l0odCo00Gooo]Z0_oohP03oookJP04oeGo0?l0]_oo0?o_o`3ok`;o0?n]
0_l0@_l2oookJP03oomd0?ooh`3oon<000;o05oo00?onOl0ool0T?oo09000_l0Gol00ooonf[oob@0
oolT0002oookJP;o0;3o0_mE0?l01_l0Eooo0;3ooomA0?ooD@3ohol0oomi00;oo`2h00?oT?l0o`3o
TOoo00001?oo00000ol0on3oo`00ool00002oo<0o`Go0;3o00Goo`1cooo50?l0=ooo03OoonGo0002
oookJP;o0?mI00Co05ooo`2Bool0T_oo05oo0ooo03h6oookJP;oonh00_l0ooh3ooo/00;ooah01ol0
3ol3o`3ooPKo05oo1_l03ol2o`2`o`Go02go1Ol0/?l4o`3o30CoolT00oooQP02o`00O`;ooo]Z2_oo
QP02oomD00;oo`000oooE0000ol0;Ooo0?ono`3ooP08o`3ooPGooo]Z0ooo0:`6oookJP;oo`0<0ooo
0@02o`3ooP;oon`00_l0ooh00ooonf[oonh0ooo^0005oookJP;oo`0n00?of_l0o`2`ool0/?l00_l0
T_l3o`3oF@03oookJ_oo0<go03Oo00;o03Oo0ooo07<2oomi0005odCo0?oc0?ool`3ooo<0oooo0?00
0_l0on001Ooonf[o0;3oo`3oDol0/?oooo]Z00;o0;3o0_oo0;P7o`3ooP03oeD0oooo7P3ooah000?o
oo]Z00?oob@0onGo0?oUo`000_oUo`001?l0oegoiOl0onGo0?oUo`02oooS0003oomd0?oonf[ooo]Z
00;o04;o0_oonfX2o`3ok`03o`2foomEo`3oEOl000;ooo]Z0_oohP08oookJP;oo`3b00Coon@0oook
J_m_0?ooK`3o0_oo^P001?l0]ooo0?mPo`3oH?oonfX2ool0I`?ooo]Z0ooo0:lAoookJP;o0?l9POoo
nfX2o`3o2A7ooo]Z0ooo0:l3oookJP03ool0Iooonf[ooo]Z00;o0?mP00Co0;Oooonj0?m_0?ooK`3o
0_oonfX00oooi03oo`3bool0Q@08oookJP;oon800_oonfX2oeGo0004ool0Q_l0onoooo]ZoookJP;o
04;o0_oonfX01_ooM03oon<0oooS0?oo057oeOl0ooWo00;oo`2@00Gooo]Zo`3o6?oonf[ooo]ZoolT
0003oookJP04oolN0?oonf[oE@3oo`3o=P;o05Oo00Cooe40on?o0?oSo`3ooh`00_oo0;P00ol0oi7o
oo]ZoookJP02o`3oD`03oookJ_l0on3o0?oP00;oo`3`0_oc0?l2oomC00;ooo]Z00?oo`1cooo50?l0
okd00_l0=ol01Ooo0<gooo]ZoookJ_l0oeWo0?lU00;o09;o0_oonfX3ool0?PGooo]Z0_ookP02oook
JP05o`3o;?ook03oon`0ooo/0?oo7P000_oo0@04ool030Gooo]Z0ooo0:`6oookJP;o9?l00ol0WOl5
o`0]o`Gooe@00_l01ol9oon60003o`00Oooonf[ooo]Z00[oohH02?ooE005o`0]o`03oolh0?l0WOoo
09go00;o9?l01_oonfX2ool0[0Kooo]Z0ooo00`2ool10003oh_o0?oo7P3oon`000;oon`000Co:03o
oookJ_ookP3oonh01OoonfX3ool0?P;ooo]Z0_l0T_l01?o00?oo0?mIo`3oFOoonfX2ool0c@;o03Oo
00?oo`3Aool0Looo07<00_oonfX01?ooD`3ol`3ooo<0oooc0?l2ool0l008o`3oh?o:0?oooo]Zo`3o
Dooo01_ooo]Zool00ol0oi42ool0^003oon<0?ooJ03ohol000;ooe4000Co0?lfoookJ_mE0?oooo]Z
0_oo7P02oookJP06oolT0?oonf[o0?lHo`3o6?oonf[oo`2@0_oio`001?oEo`3oo`1AoooS0?ooM002
oookJP;o04;o00Goo`11oookJ_l0onoo0?o_o`2fo`02oeGo00;ooo]Z0_oohP08oookJP03ool0QOoo
0?;oon@000;ooo]Z0_m_0?l01?oo^P3o0;Ooo`3oH?l0of02oookJP03ool0Iooonf[ooo]Z00;ooo]Z
0_oo0:lAoookJP;o0?l9B?oonfX003gooo]Z00?oA?l0o`3o2OoonfX04OoonfX00ooo0:oooo]Zoook
JP02onGo0005o`3oGOoUo`3oiOl0ooo90?l0of000_oo^P02onGo00?oA?l000?o0?onodCo0?m4o`00
0_m4o`04oookJP?oon800_oonfX2oeGo0003o`2fool0onoo0?o_00;o0?n]00Ko04;ooookJ_oonf[o
oo]Zoomd0?ooh`02o`1Oo`03ooWo0?oo093oo`2@00?o05oo0_oo9002oookJP;o0;3o0_mE0?l01?oo
nf[o05OooomA0?ooD@02on?o0004oon<0?oo0;Soo`2ho`3oT@Goo`000_l0on02ool000;ol`3o1?l0
/?l2ool0L`06ooo50?l0=ooo03Ooool0cOoonf[o05oo0_l0oeT01?l0Gooo09;oo`2Bool0Gol3ool0
?PKooo]Z0_ookP02o`3ooP?oon`00_oo7P09o`0?o`;o0?on1Ol0Gol5o`0?o`;o0?n]0ol0/?l6o`0]
o`Go0?l<1?oob@08oon600Sooe@01Ooo0003o`0]o`Co0?on0_l0WOl2obCo00Kooo]Z1?oo0:`5oook
JP;oo`0<00Gooo]Zool10?oo0@3oRol0o`3ooP02ooo/00;o0?on00Co:03ooookJ_ookP3oonh01Ooo
nfX2ool0?P03om[o0?l0/?oo0;3o00;o09;o0ol0oeT00ol0/?ooo`3=o`0go`02o`0go`?oo`1c0_oo
N@001Om4o`3ol`3ooo<0oooc0?ooo`3`00;o0?oP0_oonfX01Ol0oe?o0;3ooookJ_oo00?o0;3o00;o
o`2h1ol0ooh2oeD0o`;ooah00_oonfX00ooo903oiOl0onGo0002onGo0003o`3oGOoUo`3oiOl000;o
iOl000Coon<0oomd0?oonf[ooo]Z0_l0@_l01Ooo047ooo]Zo`3okol0onoo0;Ko00;oEOl00_oonfX2
oooR00Sooo]Z00?oo`25ool0l_ooi0000_oonfX2ofl0o`;ookX00_l0of001?oonf[oo`1WoookJ_oo
06L3oookJP;oo`2_4OoonfX2o`3o2H;ooo]Z0_l0o`TBoookJP;oo`2_0ooonfX2ool0I`07oookJ_l0
of3o0?mPo`2goooo^P3ooo]Zofl0o`02oookJP04oooT0?oo0?;oo`3bool0Q@Oooo]Z0_oohP03oook
JP;oEOl00_l0onl2oookJP;o04;o0_oonfX02?ooM03oon<0oooS0?oo057oeOl0ooWo0?oo093ooo]Z
0_l0oaP00ooonf[oob@0oookJP02oookJP;ooah00_mE0?l01ol0ocKo05OooomA0?ooD@3ohol0oomX
0?n@o`000_oo0;P00ol0oi7ooo]ZoookJP02o`3oD`?o0?oP00Coo`3`oonQ0?oc0?oooo]Z0_ooD`00
1_oonf[oo`1cool0Loooa@3o0?nmo`0go`;oo`3=00Cooo]Zo`3oFOl0oeWo0?lU0_l0T_l2oookJP?o
o`0n1OoonfX2ooo^00;ooo]Z00Oo0?l/ooo/0?ook03oon`0oolN0?n;o`3oo`4000Coo`0<1_oonfX3
ool0[0Kooo]Z0_lTo`03o`2Mo`03oolh0?l0;Ooo02go00Co02go2OooE008oon600cooe@01_l0;Ol0
1Ooo>03o09goo`2Mool0WOoo9?l000Kooo]Z1?oo0:`5oookJP?oo`0<0_oo0@000on;o`3ooah0ooo/
0002ooo/00;o:03o00?ooo]Zooo^0?ookP001OoonfX3ool0?P;ooo]Z0_l0T_l3o`3oF@03oookJ_oo
0<goo`3=00;o03Oo00?oolD0ool0Looo07<00_oonfX01?ooD`3ol`3ooo<0oooc0?l2ool0l003o`3o
h?o:0?oooo]Z00;o0?mC00?ooo]Zool00ol0oi400_oo0;P00oooS03oofP0on?o0002oomA0004o`1G
ool0ocKoE@3ooeD0o`?ooah000?ooo]ZoolT0?oo90000ol0oaP2ool0T003ooWo0?oEo`3oo`1A00;o
on<00ooonfX2o`12o`04ool0@Ooonf[o0?o_o`2fo`;oEOl00ooonfX00ooohP3ooo]ZoookJP06oook
JP03ool0QOoo0?;oo`3b00?ooo]Z00GoK`3ooonj0?oo^P3o0;Ooo`3oH002oookJP;oo`1W0ooonfX2
ool0[a;ooo]Z00?o0?l9oookJ_oonfX0AooonfX003gooo]Z00?oA?l0oomi0?oonfX04OoonfX00ooo
0:oooo]ZoookJP03onGo0004o`3oGOoUo`3o0?mPo`3oH0?ookX000?oiOl0odCo0?m4o`000_m4o`00
1?l0ookoolT0ooo90?oob@05oookJP;oon800_oonfX2oeGo0003o`2fool0onoo0?o_00;o0?n]0_l0
@_l2oookJP03oomd0?ooh`3oon<000;o05oo00?onOl0ool0T?oo09000_l0oaP01?oonf[oob@0oolT
0?oonfX3o`2`o`;oE@3o00Oo0?lfoomi0?ooD@3ooe40on?o0?ooN@3ooh`000;oo`2h00?o0?nAool0
0?oo00000ooo0002o`3oh004ool00?oc0?ool`3ooo<0o`Co0;3o00?oo`1cooo50?l0=ol00_l0=ol0
1_oo0<gooo]Zo`3oFOl0oeWo`03oo`1Oo`;o09;o00Co0?mMool0?_oo03koo`0n1_oonfX2ooo^00?o
0?on0oook0000ooo7P3o00ooo`0?o`09o`0?o`?o05oo0_l0oed3o`0?o`Co0?n]1ol0/?l8o`0]o`;o
olT03OooE0000ooo003o02goo`0]o`06o`0]o`;oocP00ol0WOl3obCo00Kooo]Z1?oo0:`5oookJP?o
o`0<0ooo0@001on;o`3o0?onooo/0?ook03o0?onobP0oooonfX00oookP05oookJP;oo`0n00Gof_l0
o`2`ool0T_oo09;oo`2`o`03o`3oF@03o`2`oooo0<go03Oo00;o03Oo0ooo07<3odCo00?ol`3o00[o
o`3`o`3oh?l0on3obP3ooookJ_l0oe?oo`00oookJ_oo00?o0;3o0_oo0;P00oooS03o0?ono`3ooP04
o`3ooP;oE@3o0_oo7P02oookJP;oob@00ooUo`000ol0oegoiOl0onGo0002onGo0003oooS0?ooM03o
og@000;ooo]Z00?o04;oool0@OoonfX00_l0onl00ooo08KoEOl0oeGo0002oookJP;oon802?oonfX0
0ooo08Goo`3bool0lP02oookJP;oK`3o0_oo^P001?l0]ooo0?mPo`3oH?oonfX2ool0I`?ooo]Z0_oo
0:lBoookJP;o0?l9P_oonfX2o`3o2A;ooo]Z0_oo0:l4oookJP05ool0Iooonf[o0?mPo`3oH?l0]ol0
0_oo^P02ofl0o`;ooo]Z00?oon@0ool0l_oo08D02?oonfX2oooR00;ooo]Z0_mEo`001?oo08Ko0?o_
oookJ_oonfX2o`12o`;ooo]Z00Koog@0oooS0?ooh`3oo`1AomGo0?oio`02ool0T005oookJ_l0oaSo
0?lHoookJ_oo90000ooonfX00ooo7P3ooo]ZoeD0o`02o`3o=P;ooe400_oSo`001_ooJ03oo`2hool0
^?l0oi7oo`03oookJP;o0?mC00Gooo]Zo`3oh?l0on3o0?oPool0l002oo<0o`04oookJ_ooD`3ooo]Z
oookJP;oo`1c00?oolD0o`0gool0=ol00_oo0<d01?oonf[o0?mIo`3oFOo00?l2o`2Bo`;ooo]Z0ooo
03h5oookJP;oonh00_oonfX01?lX0?oo0?l/ooo/0?ook002oolN00;oo`400ooo00`00ol0A?oooo]Z
oookJP03oookJPCoo`2/1_oonfX3obCo00?o09go0ooo>008o`0]o`oooe@02?l0;Ol2oolh00Co09go
0_lTo`06oookJPCoo`2/1OoonfX4ool030;oo`4000?oRol0oolN0?ook0000_ook0000olX0?oooo]Z
oookJP02ooo^00Gooo]Z0ooo03h01?oonf[o09;oo`2Bool0T_l3o`3oF@03oookJ_oo0<goo`3=00;o
03Oo00?oolD0ool0Looo07<00_oonfX01?ooD`3ol`3ooo<0oooc0?l2ool0l003o`3oh?o:0?oooo]Z
00;o0?mC0_oonfX01_l0oi7oo`2hool0^?ooS03oofP0on?o00;ooe4000Co05Ooo`3o=_mE0?ooE@3o
0ooo7P001?oonf[oob@0oolT0?oonfX2o`3o6005oookJ_oo093onOl0ooWo0?oEo`000_ooh`000ooo
M03ooo]ZoookJP02o`12o`04ool0@Ooonf[o0?o_o`3ok`?oEOl00_oonfX2oooR00Sooo]Z0_oo0?83
oookJP;oK`3o00CookX0o`2gool0of3o0?mP0_oonfX00ooo06Oooo]ZoookJP02oookJP03ool0[ooo
nf[ooo]Z013ooo]Z0_l0o`U9oookJP00?_oonfX00om4o`3ooo]ZoookJP0@oookJP;oo`2_00Gooo]Z
onGo0?oUo`3oiOl0o`3oG@02onGo0005o`3oH?oUo`3ookX0oonj0?oUo`000_m4o`02oomi0003o`3o
o_ooN@3oolT000;oolT01?oonfX2oooR00?ooo]Z0_mEo`001?l0]_oo0?o_o`3o[Ol0ojd2o`12o`?o
oo]Z00Goog@0oooS0?l0Gooo05ooooWo0002ool0T006o`3oGOl0oaSo0?lHoookJ_oo903ooo]Z1?l0
/?l00omE0?oo0;3oo`2`o`02oomA00;ohol000Cooh`0oi3o0?oo0;SoT?l01Ooo0003o`3oh004ool0
0?oc0?ool`3ooo<0o`?o0;3o0_oo07<01_l0/?oo03Ooo`0gool0=ooooo]Zo`1Oo`;o0?mI00Co`03o
o`1Oool0T_oo09;o0_l0/?l2ool0?POooo]Z0_ookP02o`3ooP?oon`000?ooah0o`0?ool03ol02Ol0
3ol2odCo00?o0?mM00?o00ooo`3oGOoUo`001?l0ojd6o`2`o`Go0?l<5_l0;Ol2oolh00;oo`001?l0
WOl2obCo00Oooo]Z0ooo0:`6oookJP03o`14oooo00coo`0<00?oo`4000CoRol0oolN0?ook03oon`0
0_l0ob`2oookJP?oonh01OoonfX2ool0?P05om[o0?l0/?oo09;oo`2Bool0/?l00ol0oeT01Ol0/?oo
o`3=o`0gool0=oooolD000?oo`1c0_m4o`001Ol0ookol`3ooo<0oooc0?ooo`3`00;o0?oP00CobP3o
oookJ_l0oe?o0;3o0ooo0002ool0^003oon<0?l0/?oo0?on00Co0?on0_mE0?l2oolN00;ooo]Z0_oo
90001Ol0ookoiOl0onGo0?l0oego05oo00?oiOl00_ooh`000oooM03ooo]ZoookJP02o`12o`06ool0
@Ooonf[o0?o_o`3okol0]_ooEOl00ooonfX2oooR00Sooo]Z0_oo0?801Oooi03ooo]ZoookJ_m_0?oo
oo]Z00;ookX00_l0of001?oonf[oo`1WoookJ_oo06L3oookJP;oo`2_4OoonfX2o`3o2HCooo]Z00?o
0?l9oookJ_oonfX04?oonfX3ool0[`?ooo]Z00?oo`1WoookJ_oonfX00_l0of001?l0]ooookX0ofl0
oom_0?l2oookJP03oooT0?oo0?;oo`2500Sooo]Z0_oohP02oookJP;oEOl000Co0;Koo`3okol0onoo
oo]Z0ol0@_l2oookJP03oomd0?ooh`3oon<000;oeOl00_oo09001?oonf[o0?lHo`3o6?oonfX2oolT
00;ooo]Z0_oo7P02oeD0o`07o`3o=_l0Eooooe40oomA0?oSo`3oofP0oi3o0002ool0^003o`3oTOoo
nf[ooo]Z00;o0?mC0ol0on02ool0l0;ol`3o0_ooD`001Ooonf[oo`1cool0Looo07?oolD000;o03Oo
00?oo`3=oookJ_oonfX00_l0oeT00oo00?oo09;oo`2Bo`02oookJP?oo`0n1_oonfX2ooo^0003oook
J_lX0?oo0?l/00;oon`00_oo7P03ool100?oo`0<1_oonfX3ool0[0Sooo]Z0_lTo`05o`2Mo`?oocP0
5_l0;Ol2oolh00Oo09go00?o9?l0oookJ_oonfX01OoonfX3ool0[0Oooo]Z0ooo00`2ool10003oh_o
0?oo7P3oon`000;oon`000?o0?l/oookJ_oonfX00oookP05oookJP?oo`0n00Cooo]Zo`2Bool0T_oo
09;o0ol0oeT00ooonf[oo`3=ool0c@02o`0go`03ooo50?oo07?oo`1c00;ooo]Z00Gooe<0oo<0oooc
0?ool`3oool0l002o`3oh004olX0oooonf[o0?mCo`3oD`;ooo]Z00Go0?nAool0^?oo0;Sooh`0oomX
0002on?o00;ooe4000?o0?lfoookJ_mE0?l00ooo7P001?oonf[oob@0oolT0?oonfX2o`3o6008oook
J_oo093onOl0ooWo0?oEo`3oo`1AoooS0?ooM002oookJP;o04;o0_oo04400ooonf[o0?o_o`2fo`02
oeGo00;ooo]Z0_oohP08oookJP03ool0QOoo0?;oo`3b00;ooo]Z0_m_0?l2oonj0004o`2gool0of3o
oo]ZoookJP;oo`1W0ooonfX2ool0[a;ooo]Z0_l0o`U9oookJP00?_oonfX00om4o`3o0?l9oookJP0@
oookJP;oo`2_00Gooo]ZonGo0?oUo`3oiOl0o`3oG@02onGo00;o0?mP0_oo^P000ooUo`3o05ooooo9
0002oomi0003o`3oo_ooN@3oogT000Oooo]Z0_oohP02oookJP;oEOl000Go0;Koo`3okol0onoo0?n]
ool0@@02o`12o`?ooo]Z0_ooh`000ol0GooonOl0ooWo0002ool0T0;o0?lH00Cooo]ZoolT0?oo903o
oo]Z0ol0/?l2oeD0o`;o0;3o0_ooD@000ooSo`3oogT0oon<0002ool0^0Goo`0000?oobP0o`3oh?l0
on000_oo0002oo<0o`Co0;3o0_oo07<01?l0/?oo03Ooo`0goooo0<d2o`1Oo`?o0?mI00?o05ooo`2B
ool0T_l00_l0/?l2ool0?P03o`2`oooonf[ooo]Z00Cooo]Z0_ookP02o`3ooP04o`3o;?ook03oon`0
oolN00[o00oo0ol0ojd3o`3oG@?oiOl00ol0ojd2oiCo00Co0;3o1Ol0o``4ooo90004o`2Moooo>03o
ocP0oolh00Ko02go1Ooo>007ool00003obCo0?oonf[ooo]Z00Oooo]Z1?oo0:`7oookJP;oo`0<0ooo
0@001?n;o`3ooah0oolN0?ook002o`3o;003obP0oooonf[oonh000;oonh01_oonfX01?oo03kof_l0
oookJ_oonfX2o`2Bo`05o`2`ool0oeWo0?mIo`3oFOl0/?l00ol0=ol01?ooa@3oo`1cool0Looo07<2
odCo0005o`3oo_oc0?ool`3ooo<0oooo0?000_l0on001?o:0?oo0?mCo`3oDooonfX3ool000;oo`2h
00?ooh`0o`2`ool0ooh01?l0ooh3oeD0o`04oolN0?oonf[ooo]ZoolT00;o0?mM0ooUo`001?l0oego
05ooonGo0?oUo`02oooS00;oog@000Gooo]Zo`12ool0@_ooo`11oookJP02o`3ok`03ool0Q_mEo`3o
EOl000;ooo]Z0_oohP08oookJP03ool0QOoo0?;oon@000;ooo]Z0_m_0?l2oonj00;o0?mP0_oonfX2
ool0I`?ooo]Z0_oo0:lBoookJP;o0?l9Q?oonfX2o`3o2A;ooo]Z0_oo0:l3oookJP;oo`1W00Oooo]Z
o`3oH?l0of3o0;Oooonj0?oonf[oK`3o00?ooo]Z0_oo0?800ooo08Gooo]ZoookJP05oookJP?oon80
0_oonfX2oeGo00;o0?o_0_oonfX2o`12o`?ooo]Z0_ooh`000ooo057oeOl0ooWo0002ool0T0?o0?lH
0_oo9003oookJP05oolN0?mE0?ooE@3ooookJ_l0ocH00oooD@001?oSo`3oofP0ool0^?oo0;P2o`3o
T@;ooo]Z0_l0oe<3o`3oh0;oo`3`00Gol`3ooookJ_ooD`3ooe<0oookJP03ool0L`04ooo50?l0=ooo
o`3=ool0c@;ooo]Z0_l0oeT00oo00?oo09;oo`2Bo`02oookJP?oo`0n1_oonfX2ooo^0003oookJ_lX
0?oo0?l/00?oon`00_oo7P03ool100?oo`0<1ooonfX3ool0[0[ooo]Z00?o9?l0o`2Mool0WOl01ol0
WOl3oolh00Oo02go1?oo>007o`2Mo`03obCo0?oonf[ooo]Z00Oooo]Z1?oo0:`7oookJP?oo`0<0_oo
0@000on;o`3ooah0oolN0002ooo/0004o`3o;?lX0?oooo]ZoookJP;oonh01_oonfX2ool0?P;ooo]Z
0_l0T_l01_l0obGo0?mIo`3oFOl0oeWooo]Zool0c@?o03Oo00?oolD0ool0Looo07<00_oonfX01Ooo
D`3ol`3ooo<0oooc0?ooo`3`00?o0?oP00?ooo]Zo`3oDol0oe<00_oonfX01Ol0oi7oo`2hool0^?oo
S03oofP000;ohol00_ooD@02o`3o=P;oE@3o0_oo7P001?oonf[oob@0oolT0?oo9002o`3o6007oook
J_oo093oo`2@ooWo0?oEo`3oo`1AoooS0002oomd00;ooo]Z00Ko04;oool0@Ooo047ooo]Zo`3okooo
08H2oeGo00?ooo]Z0_oohP07oookJP03ool0QOoo0?;oo`3b00?ooo]Z0_m_0?l00ooo^P3o0;Ooo`3o
H003oookJP04ool0Iooonf[ooo]ZoookJP;oo`2_4_oonfX2o`3o2D[ooo]Z000noookJP03odCo0?l0
o`Wooo]Z017ooo]Z00Koo`2_oookJ_oUo`3oiOl0oookJ_l0oed2onGo00;o0?mP0ooo^P001ol0Gooo
olT0oomi0?ooN@3o0?onodCo0?ooN@001ooonfX2oooR00;ooo]Z0omEo`001?nDo`3o0?o_oiCo0?oo
nfX2o`12o`?ooo]Z00Goog@0oooS0?oo057o0?mMo`2`o`02ool0T006o`3oGOl0oaSo0?lHoookJ_oo
903ooo]Z1?l0/?l01OmE0?oo0;3oo`2`ool0/?oooe4000;ohol00_ooS0000ooo0;SoT?l0ool00002
ool00003o`3oDooo003oobP000;o0?oP0_oo0002oo<0o`Co0;3o0_oo07<00ol0/?oo03Ooo`0go`02
ool0c@05oookJ_l0oego0?mIo`3oFOl0Gol00_l0T_l2o`2`o`?oo`0n00?o0;3ooookJ_oonfX00ooo
nfX2ooo^00?o0?on0oook008o`0?o`Ko0?n]0_nDo`03onGo0003o`3o[Ooonf[oU?l000;oU?l00ol0
/?l5o`3o30CoolT01_l0WOl@ool000Oooo]Z1?oo0:`7oookJPCoo`0<0ooo0@02oolN00;oon`000Co
0?l/obP0oooonf[ooo]Z0_ookP06oookJP;oo`0n00?of_l0oookJ_oonfX00_l0T_l01Oo00?oo0?mI
o`3oFOl0/?oooo]Z00?o03Oo00CoolD0ool0Looo07?oo`1c0_m4o`001Ol0ookol`3ooo<0oooc0?oo
A?l000;o0?oP00GobP3oo`3oDol0oe?o0?mCoookJP02ool000;oo`2h00?oo`00o`2`ool0/?l00ol0
ooh01?l0EoooE@3ooeD0oomE0?l2oolN00;ooo]Z00Ooob@0o`3oGOl0oego0?mMonGo0?l0oego05oo
00;oiOl000Coo`1AoooS0?ooh`3oog@00_oonfX2o`12o`06oookJ_l0onoo0?o_o`3okol0]_ooEOl0
0ooonfX00ooohP3ooo]ZoookJP07oookJP;oo`3b00Ooon@0oookJ_oonf[oK`3ooookJ_oo^P3o0;Oo
00;o0?mP00Cooo]Zool0Iooonf[oo`1W0_oonfX2ool0[a;ooo]Z0ol0o`V4oookJP;o0?l94_oonfX2
ool0[`?ooo]Z0_oo06L2oookJP04o`3oH?l0]ooookX0oonj00;oK`3o0_oonfX2ool0lP03ool0QOoo
nf[ooo]Z00Kooo]Z0_oohP02oookJP;oEOl000Go0;Koo`3okol0onoooo]Zool0@@02o`12o`;ooo]Z
00?oog@0oooS0?oo05400_oEo`02ool0T004oookJ_l0oaSo0?lHoookJP;oob@00_oonfX2oolN00;o
E@3o00Oo0?lfo`1GooooD@3ooe40on?o0?l0R?oooh`000;oo`2h00?o0?nAoookJ_oonfX00_l0oe<0
0ooonf[o0?oPo`3oh002ool0l004ool0eooc0?oooo]ZoomC00;ooo]Z0_oo07<2ooo50003o`0goooo
0<goo`3=00;ooo]Z0_l0oeT00oo00?oo09;oo`2Bo`02oookJP?oo`0n1_oonfX2ooo^00;ooo]Z00Co
:03oo`3o;?ook03oon`00_oo7P001?n;o`3oo`40ool10?l0A?l3ool030Oooo]Z1?oo0:`<oookJPCo
9?l03ol0WOl3obCo00_ooo]Z1?oo0:`8oookJPCoo`0<0_oo0@000on;o`3ooah0ooo/0002ooo/0003
obP0oooonf[ooo]Z00;oonh01_oonfX3ool0?P;ooo]Z0_l0T_l00oo00?oo0?mIo`3oF@02oookJP05
ool0cOl0=ooo03Ooo`0gooooa@000_oo07<2oookJP05oomC0?oc0?ool`3ooo<0oooo0?000ol0on00
0ooonf[o0?mCo`3oD`02oookJP05o`3oTOoo0;Soo`2hool0^?ooJ0000_oSo`02oomA0004o`1Gool0
ocKoE@3ooeD0o`;ooah00_oonfX2oolT00;o0?lH00Kooo]Zool0T?oo093onOl0omGo0?oo0542oooS
0003oomd0?oonf[ooo]Z00;o04;o00Goo`11oookJ_l0onoo0?o_o`2fo`02oeGo00;ooo]Z0_oohP08
oookJP03ool0QOoo0?;oo`3b00;ooo]Z0_m_0?l2oonj00;o0?mP0_oonfX2ool0I`?ooo]Z00?oo`2_
oookJ_oonfX04OoonfX2o`3o2D[ooo]Z000noookJP03o`3o2OooN@3ooo]Z017ooo]Z0_oo0:l3oook
JP04ool0Iol0oegoiOl0oookJP;o0?mP0_oo^P000ol0GoooolT0onGo0002oomi0003o`3oo_ooN@3o
ogT000Oooo]Z00Coon80oookJ_oonf[o0?n]0_mEo`001Ol0]_oo0?o_o`3okonDo`3oo`1100;o04;o
0_oonfX01?ooM03oon<0oooS0?l0oed2o`2`o`05ool0T?l0oego0?mMo`3o6?oonfX00_oo9004o`2`
o`;oE@3o0_l0/?l2oomA00;ohol000Cooh`0ool0^?oo0;SoT?l00_nDo`001?l0oe?oo`00o`3oDooo
0002o`3oh0;oo`000_oc0?l4o`2`o`;oo`1c00?o0;3oo`0gool0=ol00_oo0<d2o`3oG@;o0?mI00?o
`03oo`2Bool0/?l00_l0/?l3ool0?P;o0;3o1?oonfX3ooo^00?o0?on0_ook007o`0?o`Ko0?n]1?nD
o`001?oUo`3oo`2/ool0[?oo0:`3oiCo0004o`2`oooo:03oobP0oolX00;o0?l<0_oonfX3ooo900Co
001o1_lTo`000ooonf[oo`00ool00009ool000;ooo]Z1_oo0:`8oookJPCoo`0<0ooo0@02oolN00;o
on`00_l0ob`2oookJP?oonh01_oonfX2ool0?P06om[o0?oonf[ooo]Zo`2Bool0/?oo`03o0_l0oeT0
0ooonf[oolT0o`0go`02o`0go`04ooo50?oo07?oo`1co`3ooP;oA?l000Go0?onoo<0oooc0?ool`3o
odCo0002o`3oh004olX0ool0oe?o0?mCo`3oD`?oo`000_oo0;P3ool000?o0?on00Co05OooeD0oomE
0?ooE@3o0_oo7P02oookJP03oolT0?l0oego0?mM00?o0?mM00Co05ooonGo0?oUo`3oo`1A0_ooh`00
0oooM03ooo]ZoookJP02o`12o`06ool0@Ooonf[o0?o_o`3okol0]_ooEOl00ooonfX2oooR00Sooo]Z
00?oo`25ool0l_ooi0000_oonfX2ofl0o`;ookX00_l0of001?oonf[oo`1Wool0Iooo06L3oookJP;o
o`2_4_oonfX2o`3o2HGooo]Z0_l0o`TCoookJP03ool0[ooonf[ooo]Z00;ooo]Z0_oo06L00ooonf[o
0?mPo`3oH002oonj00;oK`3o0ooonfX2ool0lPSooo]Z0_oohP03oookJP;oEOl00_l0onl01?oonf[o
o`11o`12ool0@_l2oookJP06oomd0?ooh`3oon<0ool0DOoEo`3onOl00_oo09000ooonf[o0?lHo`3o
6002oolT00?ooo]Z00Kooah0oeD0oomE0?ooE@3oo`3o=_l0Eol2oomA0003on?o0?ooJ03oo`2h00;o
o`2h00?o0?nAoookJ_oonfX00_l0oe<00ooonf[o0?oPo`3oh002ool0l0;ol`3o0_ooD`02oookJP;o
o`1c0_ooa@02o`0go`03ool0cOoonf[ooo]Z00;o0?mI00?o`03oo`2Bool0T_l00_oonfX3ool0?POo
oo]Z0_ookP000ooonf[o:03oobP0o`02ooo/00?ooah000?oRol0ool10?oo0@001?oo00`7oookJPKo
o`2/2ooonfX5o`00O`Ko9?l00ooonfX4o`0000Sooo]Z1Ooo0:`9oookJPCoo`0<0_oo0@02oolN00?o
on`000Co0?l/oookJ_oonf[ooo]Z0_ookP06oookJP;oo`0n00?of_l0oookJ_oonfX00_l0T_l01?o0
0?oo0?mIo`3oFOoonfX2ool0c@?o03Oo0_oo07<3oookJP05oomC0?oc0?ool`3ooo<0oooo0?000ol0
on001_oonf[o0?mCo`3oDooonf[oo`03o`3oT@?oo`2h00?ooh`0on?o0?oSo`000_ooD@001?l0Eooo
0?lfoeD0oomE0?l2oolN00;ooo]Z0_oo90001_oonf[o0?lHo`3o6?oonf[oo`2@ooWo00;oeOl000?o
o`1AoooS0?ooM0000_oonfX2o`12o`05ool0@Ooonf[ooo]Zo`3okol0]_l00_mEo`02oookJP?oon80
1ooonfX00ooo08Goo`3bool0lP03oookJP05ofl0oooo^P3ookX0o`2gool0of000_oonfX2ool0I`?o
oo]Z0_oo0:lBoookJP;o0?l9BooonfX003oooo]Z00?oogT0oookJ_oonfX04?oonfX2ool0[`Cooo]Z
00?o0?mMoookJ_oonfX00_l0of02oonj0003o`1Oool0oegoiOl000;oogT000Co0?onoomi0?ooN@3o
ogT01_oonfX2oooR00;ooo]Z0omEo`001_l03ooo0?o_oiCo0?oonf[oo`11o`12o`?ooo]Z00Coog@0
oooS0?oo057o0?mM0_l0/?l01ooo093o0?mMo`3oGOl0oaSooo]ZoolT0?oonfX01?l0/?l03?mE0?oo
0;3oo`2`ool0/?oooe40o`2`oooSo`3oogT0oon<0?oo0;SoT?l0o`3oT@;oU?l000Co0?mCool00?oo
01_oo`000_l0on001?oo003o0;3ooo<0oooc0?l4o`2`o`;oo`1c00?oolD0o`0gool0=ol00_oo0<d2
o`3oG@;o0?mI00?o`03oo`2Bool0/?l00ol0/?l2ool0?P?o0;3o0_oonfX01?l0ookoonh0ooo^0?oo
kP02o`3ooP03odCo0?ook03oon`000Go00oo1_l0ojd5oiCo0003oolX0?oonf[ooo]Z00;oo`2/00Co
U?l0ool0[?oo0:coo`2/0_oo:0000ooonf[o0?l<oookJP03oookJP03ooo90?l007oo001o00?o001o
2?oonfX4o`000003oookJ_oo003oo`0000;oo`001Ooo0:`9oookJP?oo`0<00Co04Coool10?oo0@3o
Rol00_oo7P02ooo/00;o0?l/00?o:03ooookJ_ookP000_ookP06oookJP?oo`0n00Gof_l0oookJ_l0
T_oo09;ool00o`02o`3oF@;ooo]Z00GoolT0o`0gool0=ooo03Ooooo50002ool0L`Co0?on0_oc0?l2
odCo00;o0?oP00CobP3oo`3oDol0oe?o0?mC0ooo0002ool0^0Coo`000_l0ooh01?ooN@3o0?lfoeD0
oomE0?l2oolN00;ooo]Z0_oo9004o`3oG@04o`1Oool0oego0?mMomGo00;oon<000Ooog@0oookJ_oo
nf[ooo]Zo`12oooo047ooo]Z00?o0?o_0_mEo`02oookJP;oon802?oonfX01?oo08Goo`3bool0l_oo
i002oookJP05ofl0oooonf[ookX0o`2gool0of000_oonfX2ool0I`?ooo]Z0_oo0:lBoookJP?o0?l9
Q_oonfX00ol0o`Wooo]ZoookJP0AoookJP;oo`2_0ooonfX2ool0I`04oookJ_l0of3o0?mPo`2go`;o
okX000CoK`3ooookJ_oonf[ooo]Z0_oo0?800ooo08Gooo]ZoookJP05oookJP?oon800_oonfX2oeGo
0005o`2fool0onoo0?o_oookJ_oo04400_l0@_l2oookJP03oomd0?ooh`3oo`1A00;oeOl000?onOl0
ool0T?oonfX00_l0oaP00ooonf[oob@0oolT0003oookJP05oolN0?mE0?ooE@3ooookJ_l0Eol00_oo
D@02on?o0003oomX0?oo0;Soo`2h00;o0?nA0_oonfX2o`3oD`03oookJ_l0on3o0?oP00;oo`3`0_oc
0?l2oomC00;ooo]Z0_oo07<2ooo500;o03Oo00?oo`3=oookJ_oonfX00_l0oeT00oo00?oo09;oo`2B
o`02oookJP03om[o0?oo03koo`0n00Oooo]Z0oookP02obP0o`?oon`00ooo7P000on;o`3oo`40ool1
0003ool03003o`14oooonf[ooo]Z00Oooo]Z1_oo0:`7oookJPKo001o2?oonfX4o`0000?ooo]Z1ooo
0:`9oookJPCoo`0<0_oo0@000on;o`3ooah0oolN0003ooo/0004o`3o;?lX0?oooo]ZoookJP;oonh0
1_oonfX3ool0?P06om[o0?oonf[o09;oo`2Bool0obGo`03o0_l0oeT00ooonf[oo`3=ool0c@03o`0g
o`;oo`1c0ooonfX01OooD`3ol`3ooo<0oooc0?ooo`3`00?o0?oP00Kooo]Zo`3oDol0oe?ooo]Zool0
0ol0oi43ool0^003oon<0?oSo`3ohol000;ooe4000Co05Ooo`3o=_mE0?ooE@3o0_oo7P02oookJP;o
ob@000Gooo]Zo`3o6?l0oaSooo]Zool0T002ooWo0005omGo0?oo057oon<0oomd0?oo05L00_oonfX2
o`12o`;ooo]Z0_l0onl3oeGo00;ooo]Z0_oohP08oookJP?oo`3b0_oonfX2ofl0o`;ookX000Go0?mP
oookJ_oonf[ooo]Zool0I`04oookJP03ool0[ooonf[ooo]Z017ooo]Z0_l0o`U;oookJP00?ooonfX0
0oooN@3o0?l9oookJP0@oookJP;oo`2_1?oonfX00ol0oegoiOl0oookJP02o`3oH0?ookX000?o05oo
onGo0?ooN@000_ooN@001?m4o`3oogT0oomi0?ooN@06oookJP04oooR0?oonf[ooo]ZoookJP;oEOl0
00Ko0;Koo`3okol0onooU?l0ool0@Ol0@_l3oookJP04oomd0?ooh`3oo`1Ao`3oG@;o0;3o00Goo`2@
o`2`ool0oego0?mMoookJP02oolT00Co0;3o0_mE0?l3o`2`o`08oomA0?oSo`3ohol0oomX0?ooS03o
o`2hoi3o0?l0oi42oiCo0003ool00?l0oe?oo`0000;o0?oP0_oo00000ol0/?ool`3oo`2`o`02o`2`
o`;o0?l<0_oo07<00oooa@3o03Ooo`0go`02ool0c@;o0?mM0_l0oeT00oo00?oo09;oo`2`o`03o`2`
o`;oo`0n1?l0/?l00ooonf[o0?onooo^0002ooo^00CoA?l000Coon`0o`0?ool03ooo00oo1_l0ojd5
oiCo00KoobP00ooonfX2ool0[003oolX0?oo0:coo`2/00Goo`2/00?o001ooookJ_oonfX02_oonfX0
0ol0003oo`2/ool0[008ool0[0Wooo]Z1?oo00`3ool10003oh_o0?oo7P3ooah000?oon`000Co0?l/
obP0oooonf[ooo]Z0_ookP07oookJP;oo`0n00?of_l0oookJ_oonfX00_l0T_l01?o00?oo0?mIo`3o
FOoonfX2ooo900;o03Oo00Co0?nmooo50?oo07?oo`1c1?l0ooh2oo<0o`05odCo0?oo0?3o0?oPo`3o
h?oonfX00ol0oe<3ool000;oo`2h1?oo00001?ooD@3o0?ono`3o=_l0ocH2oeD0o`;ooah00_oonfX2
oolT00Co0?mM00Co05ooo`3oGOl0oego0?mM0_ooh`001OooM03ooo]ZoookJ_oonf[o04;o00;oo`11
0ol0onl00ol0]_ooEOl0oookJP02oookJP;oon802?oonfX00ooo08Goo`3boooT0002oookJP04ofl0
oooonf[ookX0oonj00;o0?mP00Cooo]Zool0Iooonf[oo`1W0ooonfX2ool0[a7ooo]Z0ol0o`V7oook
JP;o0?l94_oonfX2ool0[`?ooo]Z0_oo06L2oookJP04o`3oH?l0]ooookX0oonj00;oK`3o0_oonfX2
ool0lP03ool0QOoonf[ooo]Z00Kooo]Z0_oohP02oookJP;oEOl000?o0;Koo`3okol0onl00_oonfX2
o`12o`;ooo]Z00Ooog@0oooS0?ooh`3oo`1AomGo0?l0n?ooo`2@00;ooo]Z0_l0oaP00ooonf[oob@0
oookJP02oookJP06oolN0?mE0?oooo]ZoeD0ool0ocKo05Oo0_ooD@02on?o0005oomX0?oo0;Soo`2h
o`3oTOoo00<00_oonfX00ol0oe?oo`0KolX0o`02o`3oh0;oo`3`0_oc0?l2oomC00;ooo]Z0_oo07<2
ooo500;o03Oo00?oo`3=oookJ_oonfX00_l0oeT01_o00?oo09;oo`2Bool0T_oooo]Zom[o00;oo`0n
1ooonfX3ooo^0003oookJ_lX0?oo:03o00?oon`00ooo7P04ool100?oo`0<00?o04CooookJ_oonfX0
2OoonfX:ool0[0cooo]Z0_l00009ool0[0Wooo]Z1?oo00`01?l0A?ooo`40ool10?n;o`02oolN00?o
on`000Co0?l/obP0oooonf[ooo]Z0_ookP07oookJP?oo`0n0_oonfX2o`2Bo`06o`3o9Ol0oeWo0?mI
o`3oFOoonf[oo`3=0ol0=ol00oooa@3oo`1cool0L`02oookJP;ooe<00ooc0?l01Ooo0?3o0?oPo`3o
h?l0on3ooo]Z00;o0?mC00?ooo]Zool00ol0oi400ooo0;P00oooS03ohol0on?o0002oomA0004o`1G
ool0ocKoE@3ooeD0o`;ooah00_oonfX2oolT0005oookJ_l0oaSo0?lHoookJ_oo09000_oio`001OoE
o`3oo`1AoooS0?ooM03oo`1G00;ooo]Z0_l0@_l01Ooo047ooo]Zo`3okol0onoo0;Ko00;oEOl00_oo
nfX3oooR00Oooo]Z00?oo`25ool0l_oo0?800_oonfX2ofl0o`;ookX000Co0;Ooo`3oH?oonf[ooo]Z
0_oo06L3oookJP;oo`2_4_oonfX2o`3o2Dcooo]Z000ooookJP03oomi0?l0o`Wooo]Z017ooo]Z0_oo
0:l3oookJP03o`3oGOoUo`3ooo]Z00?o0?mP0_oo^P000ol0Gooo0?mMoomi0002oomi0003odCo0?oo
N@3oogT000;oogT01OoonfX2oooR00?ooo]Z00CoEOl0o`2fool0onoo0?o_0_nDo`02o`12o`?ooo]Z
00?oog@0oooS0?l0oed00_l0/?l2ool0T005o`2`ool0oego0?mMoookJ_oo90001Ol0/?l2oeD0o`04
o`3o3?l0/?oooe40oomA00;ohol000GoofP0oi3o0?oo0;SoT?l0o`3oT@02oiCo00?oo`000_l0on00
1?oo003o0;3oo`2`oooc0?l2o`2`o`?o0?l<0_oo07<00oooa@3o03Ooo`0go`02ool0c@;o0?mM0_l0
oeT00oo00?oo09;oo`2`o`03o`2`o`?oo`0n0ol0/?l00ooonf[o0?onooo^0003ooo^00CoA?l000?o
00ooooo/0?ook0001Ol0ojd5oiCo00KoobP000?oiOl0oookJ_oonfX01OoonfXCool0[0;oo`000ooo
0:`;oookJPCoo`0<0ooo0@001?n;o`3ooah0oolN0?oo7P03ooo/0004o`3o;?lX0?oooo]ZoookJP;o
onh02?oonfX2ool0?P;ooo]Z0ol0T_l00oo00?oo0?mIo`3oF@02ooo90004ool0cOl0=ooo03Ooooo5
00?oo`1c1?l0ooh2oo<0o`05o`3oo_oo0?3o0?oPo`3oh?oonfX00ol0oe<3ool000;oo`2h1?oo0000
0oooD@3o0?ono`1Go`03oeD0o`;ooah00ooonfX00ooo903ooo]Zo`3oG@02o`3oG@06o`1Oool0oego
0?mMo`3oGOoo057oon<00_ooM002oookJP04o`12oooo047oo`11oookJP;o0?o_00?o0;KooeGo0?mE
o`000_oonfX2oooR00Sooo]Z00?oo`25ool0l_oo0?800_oonfX2ofl0o`05oookJ_oo^P3o0?mPo`3o
H?oonfX00ooo06L3oookJP;oo`2_4_oonfX2o`3o2HSooo]Z0_l0o`TCoookJP04ool0[ooonf[ooo]Z
oookJP?oo`1W00?ooo]Zo`3oH?l0of000_oo^P02ofl0o`?ooo]Z0_oo0?88oookJP?oon800_oonfX2
oeGo0004o`2fool0onoooo]ZoookJP?o04;o0_oonfX01OooM03oon<0oooS0?oo057oeOl000;oo`2@
00Cooo]Zo`3o6?l0oaSooo]Z0_oo9003oookJP05oolN0?mE0?ooE@3ooookJ_l0ocH00oooD@000ooS
o`3oofP0oi3o0002ool0^003o`3oTOoonf[ooo]Z00;o0?mC00Kooo]ZolX0ool0on3ooo]Zool0l?oo
X@02oo<0o`;ooe<00_oonfX2ool0L`;oolD00_l0=ol2ool0c@;ooo]Z00?o0?mIol00ool0obD00_l0
T_l00ooonf[of_l0ool0?P02ool0?PKooo]Z1?ookP000ooonf[o:03oobP0o`03ooo/00?ooah000Co
Rol0ool10?oo0@3oo`401?oo00`00ol0A?oooo]ZoookJP0;oookJQOoo`2/2ooonfX5ool030;oo`40
00CoRol0oolN0?oo7P3ooah00oook002o`3o;0;ooo]Z0oookP07oookJP;oo`0n00?of_l0oookJ_l0
T_l00_l0T_l00oo00?oo0?mIo`3oF@02oookJP05ool0cOl0=ooo03Ooo`0gooooa@000_oo07<2oook
JP;ooe<00ooc0?l01Ooo0?3o0?oPo`3oh?l0on3ooo]Z00;o0?mC00?ooo]Zool00ol0oi400ooo0;P0
0oooS03ohol0on?o0002oomA0006o`1Gool0ocKoE@3ooeD0oooonf[ooah00ooonfX00ooo903ooo]Z
o`3o6002o`3o60;oo`2@00?onOl0omGo0?oo05400_ooh`000oooM03ooo]ZoookJP02o`12o`05ool0
@Ooonf[o0?o_o`3okol0]_l00omEo`001?oonf[oon80oooR0?oohP07oookJP04ool0QOoo0?;oo`3b
ool0lP;ooo]Z0_m_0?l00ooo^P3o0;Ooo`3oH002oookJP;oo`1W0ooonfX2ool0[a?ooo]Z00?o0?l9
oookJ_oonfX0BooonfX003oooo]Z00?oogT0o`3o2OoonfX04OoonfX2ool0[`Cooo]Z00?o0?mMoook
J_oonfX00_l0of02oonj0003onGo0?l0oegoogT000;oogT000?oA?l0oomi0?ooN@000oooN@04oook
JP;oon800ooonfX2oeGo0003oiCo0?l0onoo0?o_00;oU?l000Go04;ooookJ_oonf[ooo]Zoomd0002
oooS0003o`3oGOl0/?oo0;3o00;oo`2@0_l0/?l2oookJPGo0;3o00Ko0?l<oeD0oomE0?oo0?l<o`2`
ooooD@02on?o0008oomX0?ooS03oo`2hool0^?l0oi7oU?l0oolX0?oonfX2ool00003oookJ_l0on3o
0?oP00;o0;3o0_oc0?l00ol0o`co0;3oo`3o3002o`3o30;oo`1c00OoolD0o`0gool0=ooo03Ooool0
cOoonf[oiOl000;o0?mI00?o`03oo`2`ool0/?l01?l0/?l2ool0?P;o0;3o0_l0o``2oookJPCoonh0
00?oA?l0oomi0?ooN@000oook003o`3o[@KoU?l01Ooo:002onGo00cooo]Z1ol007l4oookJPGoo`00
00?o0000oookJ_oonfX01ooonfX00ol0A?ooo`0<ool03003ool030;oo`400_n;o`02oolN00Coon`0
00?o0?l/obP0oooonfX00oookP08oookJP?oo`0n00Gooo]Zo`2Bool0T_oo09;ool00o`02o`3oF@Co
olT00_l0=ol01?ooa@3oo`1cool0LooonfX4o`3ooP;ol`3o0_l0ooh2o`3oh004oookJ_l0oe?o0?mC
o`3oD`?oo`000_oo0;P3ool00004o`2`ooooD@3ooe40o`1Go`?oE@3o0_oo7P02oookJP;oob@000Go
oo]Zo`3o6?l0oego0?mMo`1Oo`03o`3oG@06ool0DOooh`3oon<0oomd0?oob@3ooo]Z0_l0@_l01Ooo
047ooo]Zo`3okol0onoo0;Ko00;oEOl00_oonfX2oooR00Sooo]Z00?oo`25ool0l_oo0?800_oonfX2
ofl0o`03oookJ_oo^P3ookX000;o0?mP00?ooo]Zool0Iooo06L01?oonfX2ool0[a7ooo]Z0ol0o`V9
oookJP03o`3o2Ooonf[ooo]Z017ooo]Z0_oo0:l3oookJP;oo`1W0_oonfX01Ol0of3o0;Oooonj0?oo
^P3oK`3o00?ooo]Z0_oo0?800ooo08Gooo]ZoookJP05oookJP?oon800_oonfX2oeGo0003o`2fool0
onoo0?o_00;ooo]Z0_l0@_l2oookJP06oomd0?ooh`3oon<0ool0DOoEo`3o0?So0_oo09001?oonf[o
0?lHo`3o6?oonfX2oolT00;ooo]Z0_oo7P02oeD0o`04o`3o=_l0Eooooe40oomA00;ohol000GoofP0
oi3o0?oo0;Soo`2hool00`02oookJP;o0?mC00?ooo]ZolX0ool0on000_oo0?02oo<0o`03ool0eooo
D`3ooe<000;ooo]Z0_oo07<2ooo500;o03Oo0_oo0<d2oookJP;o0?mI00Cooo]Zo`2Bool0T_oooo]Z
0_oJo`03ool0?PKooo]Z0oookP02oookJP03obP0ooook03oon`000;oon`00ooo7P001?n;o`3oo`40
ool10?oo0@05ool03003o`14oooonf[ooo]Z00cooo]Z1ol007l6oookJPCo00002_oonfX5ool030;o
o`400_n;o`02oolN00Goon`000?o0?l/obP0oooonfX00oookP07oookJP?oo`0n00Gof_l0oookJ_l0
T_oo09;oo`3o9@03o`3oF@03oookJ_oo0<goo`3=00;o03Oo0_ooa@001?oo07?ooo]ZoookJ_oonfX2
oomC00?ol`3o00?oo`3`o`3oh?l0on000_oonfX2o`3oD`03oookJ_oo00?o0?nA00?oo`2h00?ooh`0
on?o0?oSo`000_ooD@001_l0Eooo0?lfoeD0oomE0?oooo]ZoolN00?ooo]Z00?oob@0oookJ_l0oaP0
0_l0oaP2ool0T0;onOl000CoeOl0oooS0?ooh`3oog@00_oonfX3o`12o`04oookJ_l0onoo0?o_ool0
QP?oEOl00_oonfX2oooR00Sooo]Z0ooo0?82oookJP;oK`3o0_oo^P02o`3oH0;ooo]Z00?oo`1Woook
J_oonfX00_oonfX2ool0[a;ooo]Z0_l0o`U=oookJP00@?oonfX00oooN@3o0?l9oookJP0@oookJP;o
o`2_1?oonfX00ol0oegoiOl0oookJP02o`3oH0?ookX000?o0?mMonGo0?ooN@000_ooN@000om4o`3o
ogT0oomi0007oookJP;oon800_oonfX2oeGo0003o`2fool0onoo0?o_00;oU?l00_l0@_l3oookJP03
oomd0?ooh`3o0?mM00;o0;3o0_oo0903o`2`o`03oookJ_oo903o0;3o00;o0;3o00Co0?l<o`2`ool0
o`coE@3o0_l0o``2oomA00;ohol000GoofP0oon<0?oo0;Soo`2ho`3oT@03oolX0003o`3oDooo01_o
oo]Z00;o0?oP00?o0;3oool0l?oc0?l00_oc0?l01?l0/?oo0?l<o`3o3?l0o``2ool0L`04ooo50?l0
=ooo03Ooo`0go`;oo`3=00CoiOl0o`3oFOl0oeWo0?mI1_l0/?l2ool0?PGo0?l<00?ooo]ZodCo0?oo
kP000_ookP04oomi0005o`3o;?ook03o0?n]ooo/0?ooN@001?nDo`06oolX00?oo`0<2ooonfX7o`00
O`03oookJ_oo003oo`0000Koo`0000?o0000oookJ_oonfX00ooonfX00ol0A?ooo`0<ool03004ool0
30?oiOl000?oRol0oolN0?oo7P001_ook0000olX0?oooo]Zooo^0003ooo^00Oooo]Z1?oo03h01Ooo
nf[o09;oo`2Bool0obGo`03o00;o0?mI0ooob@03o`0go`04ooo50?oo07?oo`1coookJPCo0?on0_oc
0?l01Ol0ooko0?oPo`3oh?l0on3ooo]Z00;o0?mC00Cooo]Zool00?oo003oo`000_oo0;P3ool00004
o`2`ooooD@3ooe40o`1Go`?oE@3o0_oo7P02oookJP04oolT0?l0Gooo05ooo`3o60?o0?mM00Co05oo
o`3oGOl0oegoo`1A0_ooh`001OooM03oolT0ooo90?oob@3o04;o00;oo`110_l0onl00ol0]_ooEOl0
oeGo0003oookJP03oooR0?oonf[ooo]Z00Oooo]Z00?oo`25ool0l_oonfX00_oonfX2ofl0o`;ookX0
0_l0of000ooonf[oo`1Wool0I`04oookJP;oo`2_4_oonfX2o`3o2H[ooo]Z0_l0o`TBoookJP;oo`2_
0ooonfX2ool0I`;ooo]Z00Co0?mPo`2goooo^P3ookX00_m_0?l2oookJP03oooT0?oo0?;oo`3b00So
oo]Z0_oohP02oookJP?oEOl00_l0onl2oookJP?o04;o0_oonfX01OooM03oon<0oooS0?oo057oeOl0
00;oo`2@00Cooo]Zo`3o6?l0oaSooo]Z0_oo9003oookJP;ooah00_mE0?l01?l0ocKooe40o`1Goooo
D@02on?o0005oon<0?n@o`3oo`2hool0^?oo00<00_oonfX2o`3oD`03oookJ_l0on3o0?oP00;oo`3`
0ooc0?l2oomC00;ooo]Z0ooo07<00oooa@3o03Ooo`0go`02ool0c@;ooo]Z0_l0oeT01_oonf[o09;o
o`2Bool0T_oooo]Zom[o00?oo`0n1ooonfX3ooo^00;ooo]Z00?o:03oo`3o;?ook0000_ook0001Ol0
obcooah0oolN0?oo7P3oRol000?oo`401_oo00`;oookJPOo001o1_oonfX4o`0000Kooo]Z1_oo00`3
ool10004oh_o0?oo7P3ooah0oolN00Goon`00_lX0?l01?oonf[oonh0ooo^0?ookP07oookJPCoo`0n
00Gof_l0o`2Bool0T_oo09;ool00o`02o`3oF@;ooo]Z0_oo0<d2o`0go`03ooo50?oo07?oo`1c00?o
oo]Z0_ooD`03oo<0o`0:ool0l?l0on3o0?oPoookJ_oo01_o0?mCool06ooonf[oo`03o`3oT@?oo`2h
00?ooh`0on?o0?oSo`000_ooD@001Ol0Eooo0?lfoeD0oomE0?oooo]Z00;ooah00_oonfX00ooo903o
oo]ZoookJP02o`3o6005oookJ_oo093onOl0ooWo0?oEo`000_ooh`001?ooM03ooo]ZoookJ_oonfX2
o`12o`04ool0@Ooonf[o0?o_ool0QP?oEOl00_oonfX2oooR00Sooo]Z00?oo`25ool0l_oo0?800ooo
nfX01Om_0?oookX0oonj0?l0]ooo0?mP00;ooo]Z0_oo06L3oookJP;oo`2_4_oonfX2o`3o2Dkooo]Z
0010oookJP03oomi0?l0o`Wooo]Z017ooo]Z0_oo0:l3oookJP06ool0IooUo`3ooo]Zo`3oH?oonf[o
0?mP0_oo^P000ooUo`3o0?mMoomi0002oomi0003odCo0?oo08Gooo]Z00Oooo]Z0_oohP03oookJP;o
EOl000?oU?l0o`3okol0onl00_nDo`001Ol0@_oooo]ZoookJ_oonf[oog@000;oon<00ol0/?l2ool0
T0?o0;3o00?ooo]Zo`2`oooo90000_l0o``01?l0/?oo0?l<oeD0oomE0?l2o`3o30;ooe400_oSo`00
0oooJ03oo`2hool0^002o`3oT@?oobP000?o0?mCool06ooonfX00ol0on001Ol0o`col`3ooo<0oooc
0?oo0;3o00?o0?l<0_oo07<01?ooa@3o03Ooo`0gool0=ol2ool0c@05onGo0?l0oeWo0?mIo`3oFOo0
0?l01Ol0/?l3ool0?PCo0?l<00?ooo]ZodCo0?oonfX00oookP04oomi0004o`3o;?ook03oon`0ooo/
00?oU?l01_oo:008ool030_ooo]Z2ooo0002o`14o`Ooo`0<0_l0oed5onGo00Koon`000?o:03ooook
J_oonfX01?ookP08oookJP?oo`0n00Gooo]Zo`2Bool0T_oo09;ool00o`03o`3oF@?oolT00_l0=ol2
ooo500;oo`1c00?ooo]Zo`3oo_l0ooh00_l0ooh00ooc0?oo0?ono`3ooP03o`3oh0?o0?mC00Cooo]Z
ool00?oo003oo`000_oo0;P2ool00005on?o0?l0/?oooe40oomA0?l0Eol00omE0?l2oolN00;ooo]Z
0_oo9003o`1Oo`;o0?mM00Co05ooo`3oGOl0oegoolT00_ooh`001OooM03oolT0ooo90?oonf[o04;o
00;oo`1100?ooo]Zo`3okol0onl00_mEo`03oookJP;oon802?oonfX00ooo08Goo`3bool0lP02oook
JP;oK`3o0ooo^P02o`3oH003oookJ_oo06Ooo`1W00Cooo]Z00?oo`2_oookJ_oonfX04?oonfX2o`3o
2H_ooo]Z0_l0o`TCoookJP04ool0[ooonf[ooo]ZoookJP?oo`1W00Cooo]Zo`3oH?l0of3o0;Oo0_oo
^P001?m_0?oooo]ZoookJ_oonfX2ool0lP03ool0QOoonf[ooo]Z00Kooo]Z0_oohP02oookJP;oEOl0
00Go0;Koo`3okol0onoooo]Zool0@@02o`12o`;ooo]Z00Koog@0oooS0?ooh`3oo`1AomGo0?l0n?l2
ool0T004oookJ_l0oaSo0?lHoookJP;oob@00_oonfX2oolN0004oookJ_mE0?oo0?lfo`1Go`;ooe40
0_oSo`001_ooJ03ooh`0ool0^?oo0;So0?nAool00`;ooo]Z0_l0oe<01Ooonf[o0?oPo`3oh?l0on3o
o`3`00?ol`3o0_ooD`02oookJP?oo`1c00GoolD0o`0gool0=ooo03Ooool0c@02oookJP;o0?mI00Co
`03oo`2Bool0T_oo09;o0_oonfX4ool0?POooo]Z0oookP02oookJP03obP0ool0obcoon`000?oon`0
1?oo7P03ool100Woo`0<4ooonfX4o`000003o`14oooo00coo`0<00Goo`0<1?oo0@001?n;o`3ooah0
oolN0?oo7P05ooo/00;o:03o00?ooo]Zooo^0?ookP000_ookP08oookJP?oo`0n00Gof_l0oookJ_l0
T_oo09;oo`3o9@03o`3oF@03oookJ_oo0<goo`3=00;o03Oo0_ooa@02ool0L`;ooo]Z0oooD`02oo<0
o`;oo`3`0_l0on001ooonf[o0?mCo`3oDooo01_ooo]Zool00ol0oi400ooo0;P00oooS03ohol0on?o
0002oomA0003o`1Gool0ocKoE@3o00;oE@3o0_oo7P02oookJP03oolT0?oonf[ooo]Z00;o0?lH00Oo
oo]Zool0T?oio`3onOl0omGo0?oo057oon<000;oog@00_oonfX2o`12o`04ool0@Ooonf[o0?o_o`3o
k`?oEOl00_oonfX2oooR00Sooo]Z00?oo`25ool0l_oo0?800ooonfX01?m_0?oookX0oonj0?oo^P02
o`3oH0;ooo]Z00?oo`1WoookJ_oonfX00_oonfX2ool0[a;ooo]Z0_l0o`U>oookJP00@?oonfX00ooo
N@3o0?l9oookJP0AoookJP;oo`2_1?oonfX00ooUo`3ooo]ZoookJP02o`3oH0;ookX000?oiOl0o`3o
GOooN@000_oonfX00om4o`3oogT0ool0Q@08oookJP;oon800_oonfX2oeGo0007o`2fool0onoo0?o_
oiCo0?oo:03oo`11o`12o`03oookJP03oomd0?ooh`3oo`0000?o0;3o0_oo0903o`2`o`;oob@00ol0
o``01?l0/?oo0?l<oeD0oomE0?l2o`3o30;ooe400_oSo`000oooJ03oo`2hool0^002o`3oT@;oobP0
0_l0oe<2oookJP?o0?oP00Co0?l<oo<0oooc0?ool`3o0_l0o``2ooo900;oo`1c00CoolD0o`0gool0
=ooo03Oo0_oo0<d2onGo00?o0?mI0ol0/?l2o`3o30Co0?on0_l0o``00ooob@3ooo]ZoookJP02oook
JP04oomi0?ookP3oonh0ooo^00;ooo]Z00Go:03oo`1Oool0obcoon`0oiCo0002ooo/00CoobP00ooU
o`02ool100coo`0<4?oo00000ooo00co05ooo`1Oo`06o`3oG@SoiOl000Co:03ooookJ_oonf[ooo]Z
1?ookP08oookJP?oo`0n0_oonfX3o`2Bo`?o0?mI0_l0o``01Ooob@3o03Ooo`0goooob@3oolD000?o
o`1c00Cooo]Zo`3oo_l0ooko0?on0_oc0?l00ol0ookoo`3`o`3oh002o`3oh0?o0?mC0_oonfX01?oo
003oT?l0ool0^?oo0;P2ool000;ohol00_ooD@001?m4o`3oE@3ooeD0oomE0?l2oomi00;ooo]Z0_oo
9006o`1Oo`;o0?mM00CoolT0ool0DOooh`3oon<00_oob@001Ooonf[o04;oo`12oooo047ooo]Z00;o
0?o_00?o0;KooeGo0?oonfX00_oonfX2oooR00Sooo]Z00?oo`25ool0l_oo0?800_oonfX2ofl0o`03
oookJ_oo^P3ookX000;o0?mP00?ooo]Zool0Iooo06L01?oonfX2ool0[a;ooo]Z0_l0o`V<oookJP03
o`3o2Ooonf[ooo]Z017ooo]Z0_oo0:l3oookJP;oo`1W0_oonfX01?l0of3o0;Oooonj0?oo^P02ofl0
o`;ooo]Z0_oo0?800ooo08Gooo]ZoookJP06oookJP;oon800_oonfX3oeGo00?o0?o_00Cooo]Zool0
@Ol0@_oo04;o0_oonfX01_ooM03oon<0oooS0?oo057oeOl0ooWo00;oo`2@00?ooo]Zo`3o6?l0oaP0
0_oo9003oookJP;ooah00_mE0?l01?l0ocKo05OooomA0?ooD@02on?o0005oomX0?ooS03oo`2hool0
^?l0oi400_oonfX2o`3oD`03ool06ooonf[o0?oP00;o0?oP0_oo0?02oo<0o`;ooe<00_oonfX3ool0
L`04ooo50?l0=ooo03Ooo`0go`;oo`3=0_oonfX2o`3oF@03o`3o9Ol0T_oo09;o00;ooo]Z1Ooo03h8
oookJP;oonh00ooonfX00olX0?oo0?l/ooo/0003ooo/00Cooah000?oRol0ool10?oo0@000_oo0@0?
ool030;ooo]Z0_l0A?l;ool030;o04Co1?oo0@001?n;o`3ooah0oolN0?oo7P05ooo/00;o:03o0_oo
nfX4ooo^00Sooo]Z0ooo03h00ooJo`3ooo]Zo`2Bo`02o`2Bo`?o0?mI0_oonfX2ool0c@;o03Oo0_oo
a@02ool0L`;ooo]Z0_ooD`03oo<0o`;oo`3`0_l0on001ooonf[o0?mCo`3oDooo01_ooo]Zool00ol0
oi400ooo0;P00oooS03ohol0on?o0002oomA0003o`1Gool0ocKoE@3o00;oE@3o0_oo7P02oookJP03
oolT0?oonf[ooo]Z00;o0?lH00Cooo]Zool0T?oio`3onOl00_oEo`02oooS0003oomd0?oonf[ooo]Z
00?o04;o00Cooo]Zo`3okol0onoo0;Ko0_mEo`02oookJP;oon802OoonfX2ool0lP?ooo]Z0_m_0?l2
oonj00;o0?mP0_oonfX2ool0I`?ooo]Z0_oo0:lBoookJP;o0?l9CooonfX0043ooo]Z00?oogT0o`3o
2Ol0o`T04_oonfX2ool0[`?ooo]Z00?oo`1WonGo0?oonfX00ol0of02oonj0003o`3oGOoUo`3ooo]Z
00;ooo]Z00?oA?l0ool0QOoonfX02?oonfX01?oohP3ooo]ZoookJ_oonfX2oeGo0003oiCo0?l0onoo
0?o_00;oobP00_l0@_l2oookJP03oomd0?ooh`3oon<000?o0;3o0_oo0904o`2`o`;oob@00_l0o``0
1?l0/?oo0?l<oeD0oomE0?l2o`3o30;ooe400_oSo`001?ooJ03ooh`0ool0^?oo0;P2o`3oT@;oobP0
0_l0oe<00ooonf[o0?oPo`3oh002o`3oh005o`3o3?oc0?ool`3ooo<0ool0o``00ooob@03ool0L`Co
03Oo00?oo`3=oookJ_oonfX00ol0oeT00ol0/?oo0?l<o`3o3003o`3o30Oo0?on00CoolT0oookJ_oo
nf[oogT01?ookP02oookJP;o:03o00Co0?l/ooo/0?ook03oon`00ooo:002onGo00?oRol000?ooo]Z
ool10?oo0@001?oo0@001?l0A?ooo`0<ool03?oo00`@ool000Co05oo2Ol0oed3onGo0003obP0oooo
nf[ooo]Z00Coonh02OoonfX3ool0?P;ooo]Z00Co09;oo`2`ool0/?oo`03o0ol0oeT3o`3o30;o03Oo
0_ooa@03ool0L`04oookJ_ooD`3o0?ono`3ooP;ol`3o0_oo0?03o`3oh0?o0?mC00Cooo]Zool00ooo
003oT?l00_oo0;P2ool000;ohol00_ooD@001_l0ocKoE@3ooeD0oomE0?ooogT0oolN00;ooo]Z0ooo
9006o`1Oo`03o`3hoooob@3oo`1A00;oon<00_oob@001Ooonf[o04;oo`12oooo047ooo]Z00;o0?o_
00?o0;KooeGo0?mEo`000ooonfX2oooR00Oooo]Z00Coo`25ool0l_oo0?;oo`3b0_oonfX2ofl0o`;o
okX00_l0of000ooonf[oo`1Wool0I`04oookJP;oo`2_4_oonfX2o`3o2Hgooo]Z0_l0o`TCoookJP04
ool0[ooonf[ooo]ZoookJP;oo`1W0_oonfX2o`3oH004o`2goooo^P3oK`3oofl0o`?ooo]Z0_oo0?89
oookJP;oon800_oonfX2oeGo0005o`2fool0onoo0?o_oookJ_oo04400ol0@_l01ooonf[oog@0oooS
0?ooh`3oo`1AomGo0?l0n?l00_oo0902oookJP04o`3o6?oonf[oob@0oolT00?ooo]Z0_oo7P02oeD0
o`;o05Oo0_ooD@02on?o00;ooh`00_oo0;P00ol0oi7ooo]ZoookJP02o`3oD`;ooo]Z0ol0on02ool0
l0;ol`3o0_ooD`02oookJP?oo`1c00CoolD0o`0gool0=ooo03Oo0_oo0<d2oookJP;o0?mI00Co`03o
o`3o9Ol0T_oo09;o0_oonfX4ool0?PSooo]Z1?ookP02oookJP03obP0ool0obcoon`000Goon`00ooo
7P02oh_o0003oookJ_oo0@3oo`4000Coo`4000?o04Coool03?oo00`03ooo00`7ool100Gooah01Ooo
k002obP0o`?ooo]Z0oookP09oookJP?oo`0n00?of_l0oookJ_l0T_l00_l0T_l01Oo00?oo0?mIo`3o
FOl0oeWooo]Z00;oo`3=0_l0=ol2ooo500?oo`1c0_oonfX2oomC00?ol`3o0_oo0?02o`3oh007oook
J_l0oe?o0?mCool06ooonf[oo`03o`3oT@03ool0^003oon<0?oSo`3ohol000;ooe4000?o05Ooo`3o
=_mE0?l00_mE0?l2oolN00;ooo]Z0_oo9003o`3o6004oookJ_oo093oo`2@ooWo00;oeOl00_ooh`00
0oooM03ooo]ZoookJP03o`12o`04oookJ_l0onoo0?o_ool0QP;oEOl00ooonfX2oooR00Sooo]Z0ooo
0?83oookJP05ofl0oooo^P3ookX0oonj0?l0of000_oonfX2ool0I`?ooo]Z0ooo0:lBoookJP03o`3o
2Ooonf[ooo]Z04kooo]Z0010oookJP03oomi0?oonf[o0?l901;ooo]Z0_oo0:l4oookJP03onGo0?oo
nf[ooo]Z00;o0?mP0_oo^P000ooonf[o0?mMoookJP02oookJP03odCo0?ooN@3oo`2500Sooo]Z0_oo
hP02oookJP03oiCo0?mEo`3o0;Ko00;o0?o_0_oo:002o`12o`?ooo]Z00?oog@0oooS0?ooh`000ol0
/?l2ool0T0Co0;3o00Koob@0o`3o3?l0o`co0?l<o`2`ool0o``2oeD0o`04ooo90?l0/?oooe40oomA
00;ohol000CoofP0oon<0?oo0;Soo`2h0_l0oi42oookJP;o0?mC00?ooo]Zo`3oh?l0on000_l0on00
1Ol0o`col`3ooo<0oooc0?oo0?l<00?oolT00ooo07<4o`0go`03ool0cOoonf[ooo]Z00?o0?mI00?o
`03oo`3o3?l0o``00ol0o``;o`3ooP;ooo]Z0oookP03oookJP05obP0ool0oego:03oo`3o;?oo:000
1?ook003oolN00GoRol02Ooo0@0<ool000Co05oo1_l0oed6onGo00Coonh02OoonfX4ool0?P;ooo]Z
0_l0T_l00ol0/?oo`03oo`3oF@02o`3oF@?o0?l<0ol0=ol2ooo500;oo`1c0_oonfX00oooD`3o0?on
oo<0o`02oo<0o`;oo`3`0_l0on002?oonf[o0?mCo`3oDol0oe?ooo]Zool00ol0oi7oT?l00_oo0;P0
1?oo003ohol0on?o0?oSo`02oomA0006oomi0?mE0?ooE@3ooeD0ooooN@3ooah00_oonfX3oolT00So
05oo00Coo`1AoooS0?ooh`3oolT00_oonfX2o`12o`03ool0@Ooonf[o0?o_00;o0?o_0_mEo`03oook
JP;oon802?oonfX00ooo08Goo`3bool0lP02oookJP;oK`3o0ooo^P000ol0of3ooo]ZoookJP02ool0
I`Cooo]Z00?oo`2_oookJ_oonfX04OoonfX2o`3o2Hgooo]Z0_l0o`TCoookJP;oo`2_0ooonfX2ool0
I`;ooo]Z00Go0?mPo`2goooo^P3ookX0ofl0o`03oookJP;oo`3b00?oo`25oookJ_oonfX01_oonfX2
oooR00?ooo]Z0_mEo`001Ooo08Ko0?o_o`3okooonf[oo`1100;o04;o0_oonfX01_ooM03oon<0oooS
0?oo057oeOl0o`3ho`;oo`2@00Cooo]Zo`3o6?l0oaSooo]Z0_oo9003oookJP04oolN0?oonf[oE@3o
oookJP;o05Oo00Gooe40on?o0?oSo`3ohol0oon<0003ool0^003o`3oTOoonf[ooo]Z00?o0?mC00Co
oo]Zo`3oh?l0on3o0?oP0_oo0?02oo<0o`;ooe<00_oonfX4ool0L`?o03Oo0_oo0<d2oookJP;o0?mI
00Co`03ooookJ_l0T_oo09;o0_oonfX00ooJo`3oo`0nool0?P02ool0?PWooo]Z0oookP03oookJP;o
:03o00?o0?l/ooo/0?ook0001?ook003oolN00CoRol05?oo0@07oolN00Goon`000?o0?l/obP0oolX
0?l00ooonfX3ooo^00[ooo]Z0ooo03h00ooJo`3ooo]Zo`2Bo`02o`2Bo`04o`3o9Ol0oeWo0?mIo`3o
F@;ooo]Z0_oo0<d2o`0go`;oolD00_oo07<3oookJP;ooe<00ooc0?l01Ooo0?3o0?oPo`3oh?o:0?oo
oo]Z00;o0?mC0_oonfX01?oo00?o0?nAool0^?oo0;P2oon<00;ohol00_ooD@000ol0Eooo0?lfoeD0
o`02oeD0o`;ooah00_oonfX2oolT00?o0?lH00Cooo]Zool0T?oo093onOl00_oEo`02oooS0003oomd
0?oonf[ooo]Z00?o04;o0_oonfX2o`3ok`;oEOl000?o0;KooookJ_oonfX00_oohP08oookJP03ool0
QOoo0?;oo`3b00?ooo]Z00CoK`3ooonj0?oo^P3ookX00_l0of02oookJP;oo`1W0ooonfX2ool0[a;o
oo]Z0_l0o`U@oookJP00@OoonfX00oooN@3o0?l9oookJP0BoookJP03ool0[ooonf[ooo]Z00;ooo]Z
00?oiOl0ool0IooonfX00ol0of02oonj0007o`3oGOoonf[ooo]ZoookJ_m4o`3oogT0ool0Q@08oook
JP;oon800ooonfX2oeGo0003o`2fool0onoo0?o_00;oobP00_l0@_l2oookJP03oomd0?ooh`3oon<0
00?o0;3o0_oo0902o`2`o`;oiOl00_oo9003o`3o3006o`2`ool0o`coE@3ooeD0oooob@3o0;3o0_oo
D@02on?o0004oomX0?ooS03oo`2hool0^0;o0?nA00Goo`03oookJ_l0oe?o0?mCool06`04o`3oh005
ooo90?oc0?ool`3ooo<0ool0o``00ooob@03ool0L`05ooo50?l0=ooo03Ooo`0goooo0<d00_oonfX4
o`3oF@Go0?l<3?l0ooh2oookJPgo0;3o1_ook006oolN00GoRol01?oo7P000ol0Goooo`00ool00005
ool000Oo05oo1?l0oed6onGo00[ooo]Z1?oo03h00ooJo`3ooo]Zo`2Bo`02o`2Bo`03o`2`ooo00?oo
0?mI00;o0?mI0_l0o``3o`0go`?oolD000?oo`1coookJ_oonfX00_ooD`001Ol0ookol`3ooo<0oooc
0?ooo`3`00?o0?oP00?ooo]Zo`3oDol0oe<00_oonfX00ooo00?o0?nAool0^002ool0^007ool00?oS
o`3ohol0on?o0?ooD@3oA?l0oomi0003oeD0o`04oomi0?oo7P3ooo]ZoookJP?oob@000?o0?lHo`1O
ool0Gol01_l0Gol2oooS0003oomd0?oonf[ooo]Z00;o04;o00?oo`11oookJ_oonfX00_l0onl2oeGo
00?ooo]Z0_oohP08oookJP03ool0QOoo0?;oo`3b00;ooo]Z0om_0?l2oonj00;o0?mP00?ooo]Zool0
Iooo06L01?oonfX00ooo0:oooo]ZoookJP0AoookJP;o0?l9SooonfX00ol0o`Wooo]ZoookJP0Boook
JP04ool0[ooonf[ooo]ZoookJP;oo`1W0_oonfX2o`3oH0;ookX00_m_0?l2oookJP?oo`3b2?oonfX3
oooR00;ooo]Z0_mEo`000ol0]_oo0?o_o`3ok`02oookJP04ool0@Ol0@_oo04;ooookJP;oog@00_oo
h`02omGo00?oo`2@00Gooo]Zo`3o6?oonf[ooo]ZoolT0003oookJP;ooah00_mE0?l01?l0ocKo05Oo
o`1GooooD@02on?o0003oomX0?ooS03oo`2h00;oo`2h00?o0?nAool00ooonfX00ol0oe<01?oonf[o
0?oPo`3oh?l0on02ool0l0;ol`3o0oooD`000ooonf[oo`1cool0L`02ool0L`03ooo50?l0=ooo03Oo
00;oo`3=0_oonfX3o`3oF@06oookJ_l0obGo09;oo`2Boooonf[of_l01Ooo03h9oookJPCoonh00_oo
nfX3obP0o`?o0?l/1oook006oolN00CoRol03Ooo7P07ooo/00?o:03o0_oonfX4ooo^00_ooo]Z0ooo
03h00ooJo`3ooo]Zo`2Bo`03o`2Bo`05ol00ool0oeWo0?mIo`3oFOoonfX00_oo0<d2o`0go`?oolD0
0_oo07<2oookJP;ooe<01?oc0?l01ooo0?3o0?oPo`3oh?o:0?oooo]Zo`3oDooo01/00_oonfX01?l0
oi7oT?l0ool0^?oo0;P2oon<00;ohol00_ooD@000ol0Eooo0?lfoeD0o`02oeD0o`;ooah00_oonfX2
oolT00?o0?lH00Cooo]Zool0T?oo093onOl00_oEo`02oooS0003oomd0?oonf[ooo]Z00?o04;o00Co
o`11oookJ_l0onoo0?o_0_mEo`000ol0]_oooo]ZoookJP02oooR00Sooo]Z00Coo`25ool0l_oo0?;o
on@00_oonfX2ofl0o`;ookX00_l0of02oookJP;oo`1W0ooonfX2ool0[a;ooo]Z0_l0o`UAoookJP00
@OoonfX00oooN@3o0?l9oookJP0BoookJP;oo`2_1?oonfX00ooUo`3ooo]ZoookJP02o`3oH0;ookX0
00?o0?mMonGo0?oonfX00_oonfX00om4o`3oogT0oookJP08oookJP;oon800ooonfX01?mEo`3o0;Ko
o`3okol0onl2oolX00;o04;o0ooonfX00oooM03oon<0oooS0003o`2`o`;oo`2@0ol0o``00ooonf[o
ob@0o`3o3002o`3o3004o`2`ool0o`coolT0oeD0o`?oolT00_ooD@02on?o0004oomX0?ooS03oo`2h
ool0^0;o0?nA00Goo`03oookJ_l0oe?o0?mCool06`04o`3oh0;oolT00_oc0?l01Ol0o`coolT0ooo9
0?oob@3ooo]Z00?oo`1c0ol0=ol2ool0c@;ooo]Z0ol0oeT00oo00?oo0?l<o`3o3002ooo900_o0?on
00CoA?l0oookJ_oonf[ooo]Z3ol0/?l00ol0o`coon`0ooo/000:ooo/00;ooah02?l0Gol2ool000Go
05oo1_l0oed6onGo00Sooo]Z1?oo03h00ooJo`3ooo]ZoookJP02o`2Bo`03o`3o9Oo00?oo0?mI00;o
0?mI0ol0/?l3o`0go`;oolD00_oo07<01?l0o`cooo]ZoomC0?ooD`03oo<0o`;oo`3`0ol0on000ooo
nf[o0?mCo`3oD`02oookJP03ool00ol0oi7oo`2h00;oo`2h00?oofP0on?o0?oSo`000_ooD@000om4
o`3oogT0oeD0o`02oeD0o`04oomi0?oo7P3ooo]ZoookJP?oob@000?o0?lHo`1Oool0Gol01_l0Gol2
oooS0004oomd0?oonf[ooo]ZoookJP;o04;o0_oonfX2o`3ok`03o`2foomEo`3oEOl000;ooo]Z0ooo
hP07oookJP04ool0QOoo0?;oo`00ool0lP;ooo]Z0_m_0?l2oonj0005oookJ_l0of3ooo]ZoookJ_oo
06L01?oonfX2ool0[a;ooo]Z0ol0o`V?oookJP;o0?l94ooonfX00ooo0:oooo]ZoookJP02oookJP03
ool0Iooonf[ooo]Z00;o0?mP00Co0;Oooonj0?oo^P3oK`3o0ooonfX2ool0lP03ool0QOoonf[ooo]Z
00Kooo]Z0_oohP03oookJP;oEOl00ol0onl01?oonf[oo`11o`12ool0@_l2oookJP;oog@000Coon<0
ool0DOoEo`3o0?So0_oo0902oookJP04o`3o6?oonf[ooo]ZoolT00?ooo]Z0_oo7P02oeD0o`04o`3o
=_l0Eooo05OooomA00;ohol00_ooJ002ool0^004oi3o0?l0oi7oo`03oookJP?o0?mC00Cooo]Zo`3o
h?l0on3o0?oP0_oo0?02oo<0o`?ooe<00_oonfX3ool0L`03ooo50?l0=ooo03Oo00?oo`3=0_oonfX2
o`3oF@03ol00ool0obGo0?lU00;o09;o0_oJo`04ool0?P_ooo]Z1?ookP04oookJP03obP0ool0obco
0?l/00?o0?l/3?ook005oolN00[oon`01?lX0?l2oookJPGoonh02ooonfX4ool0?P03om[o0?oonf[o
oo]Z00?o09;o00Co`03oo`3oFOl0oeWo0?mI0_oonfX01?oo0<go03Ooo`0gool0=ol2ooo500;oo`1c
0ooonfX2oomC00?ol`3o00Goo`3`o`3oh?l0on3o0?oPolX0o`02o`3oD`05ool06ooonf[oo`03o`3o
TOn@o`000_oo0;P00oooS03ohol0on?o0003oomA0004o`1Gool0ocKoE@3ooeD0o`?ooah00_oonfX2
oolT00?o0?lH00Cooo]Zool0T?oo093onOl00_oEo`03oooS0003oomd0?oonf[ooo]Z00;o04;o00Go
o`11oookJ_l0onoo0?o_o`2fo`02oeGo00;ooo]Z0ooohP08oookJP?oo`3b0ooonfX01?m_0?oookX0
oonj0?l0]ol2o`3oH003oookJ_oo06Ooo`1W00?ooo]Z0ooo0:lBoookJP;o0?l9DOoonfX0047ooo]Z
00?o0?l9oookJ_l0o`T04_oonfX2ool0[`Cooo]Z00?oiOl0oookJ_oonfX00_l0of001?oUo`3ookX0
oonj0?l0oed3oookJP03ool0l_ooN@3oo`2500Sooo]Z0_oohP03oookJP;oEOl000?o0;Koo`3okol0
onl00_oo:002o`12o`?ooo]Z0_ooh`03o`2`o`?oo`2@0ol0o``01ooo903o0?l<o`3o3?l0o`coolT0
o`2`oooob@000_mE0?l3ooo900;ooe400_oSo`001?ooJ03ooh`0ool0^?oo0;P2o`3oT@05ool00ooo
nf[o0?mCo`3oDooo01/01?l0on02ooo900;ol`3o0_oob@000oooD`3ooo]ZoookJP03ool0L`04ooo5
0?l0=ooo03Ooo`0go`;oo`3=0_oonfX2o`3oF@;o`03o0ooob@09o`3ooPKoA?l000?ooo]Zo`2`ool0
/?l02ol0/?l5o`3o3003ooo90?ook03oon`000Koon`04?l0Gol6o`3oG@_ooo]Z0_oo03h2ooo90003
ool0?_oJo`3ooo]Z00?o09;o00?o0?lUol00ool0oeT00_l0oeT00ol0/?ooogT0oomi0003o`0go`;o
olD000Coo`1coomi0?ooN@3ooo]Z0oooD`03oo<0o`03ool0l?lIo`3o0?oP00;o0?oP00Oooo]Zo`3o
Dol0oe?oiOl0oookJ_oo00?o0?nA00?oo`2h00?oofP0on?o0?oSo`000_ooD@000om4o`3oogT0oeD0
o`02oeD0o`04oomi0?oo7P3ooo]ZoookJP;oob@000?ooo]Zo`3o6?l0oaP01ol0Gol2oooS0004oomd
0?l0o`co0?l<oookJP;o04;o0_oonfX2o`3ok`03o`2foomEo`3oEOl000?ooo]Z0_oohP08oookJP03
ool0QOoo0?;oo`0000;ooo]Z0_m_0?l2oonj0004oookJ_l0of3ooo]ZoookJP;oo`1W1?oonfX00ooo
0:oooo]ZoookJP0AoookJP;o0?l9T?oonfX2o`3o2A?ooo]Z0_oo0:l3oookJP;oo`1W0_oonfX01?l0
of3o0;Oooonj0?oo^P02ofl0o`;ooo]Z0_oo0?800ooo08Gooo]ZoookJP06oookJP?oon800_oonfX2
oeGo0003o`2fool0onoo0?o_00;ooo]Z00?oo`11o`12ool0@_l00_oonfX01OooM03oon<0oooS0?oo
057oeOl000?oo`2@00Cooo]Zo`3o6?l0oaSooo]Z0_oo9002oookJP;ooah000Cooo]ZoeD0oomE0?oo
0?lf0_l0Eol01OooD@3ooo]Zon?o0?ooJ03ooh`000;oo`2h00CoT?l0o`3oTOoo00?ooo]Z0ol0oe<0
1?oonf[o0?oPo`3oh?l0on02ool0l0;ol`3o00?ooo]ZoomC0?ooD`000_oonfX3ool0L`;oolD00_l0
=ol2ool0c@;ooo]Z00Go`03oo`3oFOl0oeWo`03oo`3o9@03o`2Bo`?of_l00ooo03h;oookJPKoonh0
1OoonfX6obP0o`03o`3o;?ook03oon`000goon`01?lX0?l4oookJPKoonh02ooonfX5ool0?P03om[o
0?oonf[ooo]Z00?o09;o00Co0?lUo`3oFOl0oeWo0?mI0_oonfX01?oo0<go03Ooo`0gool0=ol3ooo5
00;oo`1c0_oonfX2oomC0003ool0eooc0?ool`3o00;oo`3`0ol0on002?oonf[o0?mCo`3oDooo01_o
oo]Zool00ol0oi7oT?l00_oo0;P00oooS03ohol0on?o0003oomA0004o`1GoomE0?ooE@3ooeD0o`?o
oah00_oonfX2oolT00?o0?lH00Cooo]Zool0T?oo093onOl00_oEo`03oooS0003oomd0?oonf[ooo]Z
00;o04;o00Goo`11oookJ_l0onoo0?o_o`2fo`02oeGo00?ooo]Z0_oohP08oookJP03ool0QOoo0?;o
o`3b00?ooo]Z00CoK`3ooonj0?oo^P3ookX00_l0of02oookJP03ool0Iooonf[ooo]Z00;ooo]Z0_oo
0:lBoookJP;o0?l9D_oonfX004;ooo]Z0_l0o`TCoookJP;oo`2_0ooonfX01?oUo`3oo`1WoookJ_oo
nfX2o`3oH0;ookX000?o0?mMonGo0?oonfX00_oonfX00ooo0?;oogT0oookJP08oookJP;oon800ooo
nfX01?mEo`3o0;Koo`3okol0onl2oolX00?o04;o0_oonfX01_oo003oon<0oooS0?l0/?ooiOl0o`3o
30;oo`2@1?l0o``00ooo903o0?l<oookJP02ooo90004o`3o3?oob@3oE@3ooeD0o`?oolT00_ooD@02
on?o00;ooh`00_oo0;P2o`3oT@06ool00ooonf[o0?mCo`3oDooo01_ooo]Z0ol0on02ooo900;ol`3o
00?ooo]Zooo90?ooD`000_oonfX3ool0L`;oolD00_l0=ol3ool0c@03oookJ_l03ooo00oo00;o00oo
00Co`03oooo90?oob@3oolT01ol0ooh6odCo00;oogT000?ooo]Zo`2`ool0/?l02?l0/?l6o`3o30Ko
olT000?o:03oo`1Oool0Gol04?l0Gol6o`3oG@Wooo]Z0ooo03h3ooo90006oookJ_l0T_oo09;oo`2B
ool0obGo`03o0ol0oeT2o`2`o`?oogT00_l0=ol01?ooa@3oo`1coomi0?ooN@02oookJP;ooe<000?o
o`3Goo<0oooc0?l00_oo0?04o`3oh003oookJ_l0oe?o0?mC00;oiOl00_l0oi43ool0^003oomX0?oS
o`3ohol000;ooe400_ooN@03oeD0o`04oomi0?oo7P3ooo]ZoookJP;oob@000?ooo]Zo`3o6?l0oaP0
1_l0Gol01?oo057oon<0oooS0?ooM003o`3o30;o04;o0_oonfX2o`3ok`03o`2foomEo`3oEOl000?o
oo]Z0_oohP08oookJP05ool0QOoo0?;oo`00ool0l_oonfX00om_0?l2oonj00;o0?mP00?ooo]Zool0
Iooo06L01?oonfX2ool0[a;ooo]Z0ol0o`VAoookJP03o`3o2Ooonf[ooo]Z01;ooo]Z00?oo`2_oook
J_oonfX00_oonfX00ooo06Oooo]ZoookJP02o`3oH0;ookX00_m_0?l3oookJP;oo`3b00?oo`25oook
J_oonfX01_oonfX2oooR00?ooo]Z0_mEo`03o`3ok`04oookJ_oo047o04;oo`12o`?ooo]Z00Goog@0
oooS0?ooh`3oeOl0o`3ho`03ool0T005oookJ_l0oaSooo]ZoookJ_oo90000ooonfX2oolN00?oE@3o
00Co0?lfo`1GooooD@3ooe400_oSo`002?ooJ03ooh`0ool0^?oo0;SoT?l0o`3oTOoo00?ooo]Z0ol0
oe<01?oonf[obP3oo`3oh?l0on02ool0l0?ol`3o0_ooD`03oookJP?oo`1c00CoolD0o`3o_Ol0=ooo
03Oo0_oo0<d2oookJP?o0?mI00?o`03oo`3o9Ol0T_l00_l0T_l00ooonf[of_l0om[o0004ool0?Pco
oo]Z1oookP09oookJPco:03o1?l00007ooo^00gooo]Z1?oo03h2om[o00;ooo]Z0ol0T_l01?l0obGo
0?mIo`3oFOl0oeT2oookJP03ool0cOl0=ooo03Oo00;o03Oo0_ooa@02ool0L`?ooo]Z0_ooD`03oo<0
o`;oo`3`0ol0on001Ooonf[o0?mCo`3oDooo01_ooo]Z00;o0?nA0ooo0;P00oooS03ohol0on?o0003
oomA0004o`1GoomE0?ooE@3ooeD0o`?ooah00_oonfX2oolT00?o0?lH00Cooo]Zool0T?oo093onOl0
0_oEo`03oooS0003oomd0?oonf[ooo]Z00;o04;o00Goo`11oookJ_oonf[o0?o_ool0QP02oeGo00?o
oo]Z0_oohP08oookJP04ool0QOoo0?;oo`3bool0lP;ooo]Z0_m_0?l2oonj00;o0?mP0_oonfX00ooo
06Oooo]ZoookJP02oookJP?oo`2_4_oonfX2o`3o2E;ooo]Z0012oookJP;o0?l94ooonfX2ool0[`Co
oo]Z00?oiOl0oookJ_oonfX00_l0of001?l0]ooookX0oonj0?oUo`03oookJP03ool0l_ooN@3oo`25
00Wooo]Z00Coon80oookJ_oonf[ooo]Z0_mEo`000ol0]_oo0?o_o`3ok`02oolX00;o04;o0ooonfX3
oooS0003ool00?l0o`co0?l<00;oo`2@1?l0o``2oolT0005oookJ_oob@3oolT0o`3o3?oob@000_mE
0?l2ooo900?ooe400_oSo`02oon<00;oo`2h0_l0oi401_oo00?ooo]Zo`3oDol0oe?oo`0KoookJP?o
0?oP0_oob@02oo<0o`03ool0eooob@3ooe<000;ooo]Z1?oo07<01?ooa@3o03Ooo`0gool0=ol3ool0
c@03oookJ_l03ooo00oo00Go00oo1ol0ooh4odCo00OoogT02Ol0/?l4o`3o30KoolT01?oonfX;ooo^
00Co05oo3?oonfX01Ooo03ko0?l<o`3o3?oo03kof_l000GoolT000?o09;oo`3o9Oo00?l00ol0oeT3
o`2`o`GoogT000?oolD0oomi0?ooN@000ooonfX2oomC00?ol`3o0_oo0?03o`3oh004oookJ_l0oe?o
0?mCo`3oD`;oiOl00_l0oi43ool0^0?ohol00_ooD@02oomi00?oE@3o0_m4o`02oookJP;oob@000Co
oo]Zo`3o6?l0oaSo0?lH1Ol0Gol01?oo057oon<0oooS0?ooM003o`3o30;o04;o0_oonfX2o`3ok`03
o`2foomEo`3oEOl000?ooo]Z0_oohP08oookJP04ool0QOoo0?;oo`00ool0lP;ooo]Z0_m_0?l2oonj
0005oookJ_l0of3ooo]ZoookJ_oo06L01?oonfX2ool0[a?ooo]Z0_l0o`VBoookJP;o0?l94ooonfX2
ool0[`?ooo]Z0_oo06L01?oonf[o0?mPo`3oH?l0of02oonj00;oK`3o0_oonfX00oooi03oo`3bool0
Q@09oookJP;oon800_oonfX3oeGo00?o0?o_00Cooo]Zool0@Ol0@_oo04;o0_oonfX01_ooM03oon<0
oooS0?oo057oeOl0ooWo00?oo`2@00?ooo]Zo`3o6?oonfX00_oo9003oookJP;ooah00_mE0?l00ooo
nf[o0?lfo`1Go`02oomA00;ohol000SoofP0oon<0?oo0;Soo`2hoi3o0?l0oi7oo`03oookJP?o0?mC
00Cooo]ZolX0ool0on3o0?oP0_oo0?03oo<0o`;ooe<00ooonfX3ool0L`;oolD00_l0=ol3ool0c@;o
oo]Z0ol0oeT00oo00?oo0?lUo`2Bo`02o`2Bo`;ooo]Z00?of_l0ool0?_oo03h00ooo03h?oookJP_o
onh01OoonfX;ooo^013ooo]Z1?oo03h3om[o0003oookJ_l0T_oo09;o00;o09;o00Co0?lUo`3oFOl0
oeWo0?mI0_oonfX2ool0c@?o03Oo0_ooa@02ool0L`?ooo]Z0_ooD`000ooonf[ol`3ooo<0o`02ool0
l0?o0?oP00Cooo]Zo`3oDol0oe?o0?mC0_oonfX2o`3oT@?oo`2h00OoofP0on?o0?oSo`3ooe40o`1G
ooooD@3o0?lf00?oE@3o0ooo7P02oookJP;oob@00ol0oaP01?oonf[oo`2@ool0T?oio`02omGo00?o
on<00ooonfX2o`12o`05ool0@Ooonf[ooo]Zo`3okooo08H00_mEo`03oookJP;oon802?oonfX01?oo
08Goo`3bool0l_oo0?83oookJP04ofl0oooo^P3ookX0o`2go`;o0?mP00?ooo]Zool0Iooo06L00ooo
nfX3ool0[a;ooo]Z0_l0o`UCoookJP00@ooonfX2o`3o2A;ooo]Z0_oo0:l4oookJP04onGo0?oo06Oo
oo]ZoookJP;o0?mP0_oo^P000om_0?ooiOl0oookJP02oookJP03oomi0?oo0?;ooo]Z00Sooo]Z0_oo
hP02oookJP03oolX0?oo003oo`0000?o0?o_00Cooo]Zool0@Ol0@_oo04;o0_oonfX01?oo003oon<0
oooS0?oo0002o`3o3003o`2`oooo093oo`2@00Co0?l<0_oo9003ooo90004o`3o3?oob@3oolT0oeD0
o`;oolT00oooD@02on?o00;ooh`00_oo0;P2o`3oT@06ool00ooonf[o0?mCo`3oDol0Gooooo]Z0ol0
on02ool0l0?ol`3o00?oolT0oomC0?ooD`000_oonfX3ool0L`;oolD00ol0=ol3ool0c@_o00oo0_m4
o`001?l0ookoA?l0odCo0?m4o`07oomi0003oookJ_l0/?oo0;3o00Co0;3o2?l0o``5ooo900Soonh0
00Gooo]Zo`000?l0Gooo05ooo`00000>oookJP?oo`0n0ol0o``8ooo900?o0?mI00Co0;3oodCo0?m4
o`3o0;3o1oooN@000ooo07?ooo]ZoookJP03oomC00;ol`3o0ooo0?02o`3oh005olX0oooonf[o0?mC
o`3oDooonfX00_oUo`001Ol0oi7oo`2hool0^?oo0;Sooh`000;ohol000?oA?l0oomA0?ooD@000_oo
N@03oeD0o`04odCo0?oo7P3ooo]ZoookJP;oob@000Cooo]Zo`3o6?l0oaSo0?lH1?l0Gol01OoEo`3o
o`1AoooS0?ooh`3oog@000?o0?l<00Co04;oool0@Ooonf[ooo]Z0_l0onl2o`2fo`04oeGo0?oonf[o
oo]ZoookJP;oon802?oonfX01?oo08Goo`3bool00?oo0?82oookJP;oK`3o0_oo^P001Ol0]ooo0?mP
oookJ_oonf[oo`1W00Gooo]Z0_oo0:lBoookJP;o0?l9U?oonfX00ol0o`Wooo]ZoookJP0AoookJP;o
o`2_1?oonfX00ooo06Oooo]ZoookJP02o`3oH0;ookX00_m_0?l3oookJP;oo`3b00?oo`25oookJ_oo
nfX01_oonfX3oooR00;ooo]Z0_mEo`03o`3ok`04oookJ_oo047oo`11o`12o`?ooo]Z00Koog@0oooS
0?ooh`3oo`1Ao`3hoooio`02ool0T0;ooo]Z00Co0?lHoookJ_oo903oob@00ooonfX2oolN0005oook
J_mE0?oo0?lfo`3o=_l0Eol00_ooD@02on?o0007oomX0?ooS03oo`2hool0^?n@o`3o0?nAool00`02
oookJP;o0?mC0_oonfX2o`3oh0;oo`3`0ooc0?l3oomC00?ooo]Z0_oo07<2ooo500?o03Oo0ooo0<d0
0ooonf[o`03oo`3oF@02o`3oF@03ol00ool0T_oo09;o00?o09;o0_oonfX5ool0?Q;ooo]Z4OookP04
o`0000kooo]Z1?oo03h3om[o00;ooo]Z0ol0T_l00ol0obGo`03oo`3oF@02o`3oF@;ooo]Z0_oo0<d4
o`0go`04ooo50?oo07?oo`1cool0L`?ooo]Z0_ooD`03oo<0o`;oo`3`0_l0on001Oo:0?oooo]Zo`3o
Dol0oe?oo`0K00;ooo]Z0_l0oi42ool0^004oon<0?ooJ03ohol0on?o00?ooe4000Cooo]ZoeD0oomE
0?ooE@3o0_oo7P03oookJP;oob@00ol0oaP01?oonf[oo`2@ool0T?oio`02omGo00;oon<00_ooM002
oookJP;o04;o00Ooo`11oookJ_oonf[o0?o_ool0Q_l0]_ooEOl000?ooo]Z0_oohP08oookJP04ool0
QOoo0?;oo`3bool0lP?ooo]Z00CoK`3ooonj0?oo^P3ookX00_l0of000ooonf[oo`1Wool0I`04oook
JP?oo`2_4OoonfX2o`3o2ECooo]Z0013oookJP;o0?l94ooonfX2ool0[`?ooo]Z0_oo06L2oookJP;o
0?mP0ooo^P001ooUo`3ooo]ZoookJ_oonf[oo`3boomi0?oo0?802OoonfX2oooR00;ooo]Z0ooo0002
o`3ok`03oookJ_oo047oo`1100;o04;o00?ooo]Zool00?ooh`000_ooh`001?oo003o0?l<o`3o3?l0
/?l2ool0T0Co0?l<0_oo9002ooo90003o`3o3?oob@3oolT000;oE@3o0_oob@03oomA00;o05oo0_oo
S002ool0^0;o0?nA00?oo`03oookJ_l0oe<00_l0oe<01?l0Gooo0?oPo`2`ool0/?l2ool0l004ool0
eooc0?ool`3ooookJP;ooe<00ooonfX2ool0L`;oolD00ol0=ol3ool0c@go00oo1?m4o`05oomi00Co
oo]Z0ol0/?l6o`3o30KoolT02ooonfX4o`0000Wooo]Z0ooo03h2o`2`o`03ool0?_l0o`co0?l<00Co
0?l<1Ooob@03o`3oF@03oiCo0?l0/?ooA?l000;oA?l01_ooN@02odCo0004oookJ_ooD`3ooe<0oomC
00?ol`3o0_oo0?03o`3oh004o`3oGOl0oe?o0?mCo`3oD`;ooo]Z00?oiOl0o`3oTOoo0;P00_oo0;P0
2?ooJ03ohol0on?o0?m4o`3ooe40o`3oo_m4o`3oogT00omE0?l01?m4o`3oogT0oookJ_oonfX2oolT
0005oookJ_l0oaSo0?lHo`3o6?oonfX00ol0Gol00ol0/?ooo`1AoooS0002oooS00;o0?l<00Gooo]Z
o`12ool0@_ooo`11oookJP02o`3ok`;o0;Ko00CoEOl0oookJ_oonf[ooo]Z0_oohP09oookJP03ool0
l_oo003oo`3b00;ooo]Z0om_0?l01Ooo^P3o0;Ooo`3oH?l0of3ooo]Z00;oo`1W1?oonfX2ool0[a;o
oo]Z0_l0o`VEoookJP;o0?l94ooonfX00ooo0:oooo]ZoookJP02oookJP03ool0Iooonf[ooo]Z00?o
0?mP0_oo^P02ofl0o`?ooo]Z0_oo0?800ooo08Gooo]ZoookJP06oookJP;oon800_oonfX3oeGo00?o
0?o_00Cooo]Zool0@Ooo047o04;o0ooonfX3oooS0003ool0DOl0n?oonOl000;oo`2@00Cooo]Zo`3o
6?l0oaSooo]Z0_oo9002oookJP?ooah00_mE0?l2o`3o=P03o`1GooooD@3ooe4000;ohol000?oofP0
oon<0?oo0;P00_oo0;P01?l0oi7oo`03oookJ_oonfX3o`3oD`04oookJ_l0on3o0?oPo`3oh0;oo`3`
0ooc0?l3oomC00?ooo]Z0_oo07<00oooa@3o03Ooo`0go`02o`0go`;oo`3=0_oonfX4o`3oF@03ol00
ool0obGo09;o00?o09;o0ooonfX5ool0?R3ooo]Z1?l00009oookJPKoo`0n0ooJo`02oookJPCo09;o
00?o0?lUol00ool0oeT00_l0oeT01?oonf[oo`3=ool0cOoo0<d4o`0go`03ooo50?oo07?oo`1c00;o
o`1c0_oonfX2oomC00?ol`3o00?ooj40ool0l?oo0?000_l0on001?o:0?oo0?mCo`3oDol0oe<3oook
JP08o`3oTOoo0;Soo`2hool0^?ooS03oofP0on?o0?oonfX2oomA0003o`1Gool0ocKoE@3o00;oE@3o
0_oo7P03oookJP;oob@00ol0oaP01?oonf[oo`2@ool0T?oio`02omGo00?oon<000?oog@0oookJ_oo
nfX00_l0@_l2ool0@@;o0?o_00?oo`26o`2foomEo`000ooonfX3oooR00Sooo]Z0ooo0?83oookJP;o
K`3o0_oo^P03o`3oH003oookJ_oo06Ooo`1W00?ooo]Z0ooo0:lBoookJP;o0?l9E?oonfX004Cooo]Z
0_l0o`TBoookJP;oo`2_1?oonfX2ool0I`;ooo]Z0_l0of02oonj0003ofl0oooUo`3ooo]Z00;ooo]Z
00?oogT0ool0l_oonfX02OoonfX01?oohP3ooo]ZoookJ_oo:003ool000;o0?o_00?ooo]Zool0@Ooo
04400_l0@_l00ooonf[oo`00oooS0002oooS00?o0?l<0_oo0902o`3o3004o`3o6?oonf[ooo]ZoolT
00?oolT000?o0?l<oolN0?oob@000_mE0?l2ooo90003o`3o3?ooD@3ooe4000?o05oo00?ooh`0ool0
^?oo0;P00_l0oi400ooo00?ooo]Zo`3oD`02o`3oD`03o`1Oool0/?oo0;3o00?o0;3o00Coo`3`oo<0
oooc0?ool`3o0_ooD`03oookJP?oo`1c0_ooa@03o`0go`?oo`3=2ol03ol01Ol0ojgoA?l0oomi0?oo
N@3oA?l000GoogT00_oo03h3oookJP04o`2`oooonf[ooo]ZoookJP?o0?l<1_oob@0;oookJPCo0000
1?oonfX7ool0?P?o0;3o1ol0o``2ooo900?o0?mI0_oob@000ooo0<go0;3oodCo0004odCo00?oogT0
0_m4o`03oomi0004oomC0?l0oegol`3ooo<0o`;oo`3`1?l0on001?oUo`3o0?mCo`3oDooo01/2oook
JP;o0?nA0_oo0;P01?ooS03oofP0on?o0?oSo`02oomA0003o`3oo_m4o`3oogT000;oE@3o0_m4o`03
oomi00;oob@000Gooo]Zoomi0?l0oaSo0?lHoookJP03o`1Oo`03o`2`oooo057oon<000;oon<00_l0
o``01Ooonf[o04;oo`12oooo047ooo]Z00;o0?o_0_l0]_l01?mEo`3ooo]ZoookJ_oonfX2oooR00Wo
oo]Z00?oo`25ool00?oo0?800_oonfX3ofl0o`;ookX00_l0of02oookJP03ool0Iooonf[ooo]Z00;o
oo]Z0_oo0:lCoookJP;o0?l9UOoonfX2o`3o2A?ooo]Z0_oo0:l4oookJP03ool0Iooonf[ooo]Z00;o
0?mP00Co0;Oooonj0?m_0?ooK`3o0ooonfX2ool0lP03ool0QOoonf[ooo]Z00Oooo]Z0_oohP02oook
JP?oEOl00_l0onl2oookJP03ool0@Ol0@_oo04;o00;ooo]Z00Koog@0oooS0?ooh`3oo`1AomGo0?l0
n?l3ool0T004oookJ_l0oaSo0?lHoookJP;oob@00_oonfX3oolN00;oE@3o00?o0?lfo`1Gool0Eol0
0_ooD@000ooonf[ohol0oomX0002oon<00;oo`2h00Co0?nAool00ooonf[ooo]Z0ol0oe<01?oonf[o
bP3oo`3oh?l0on02ool0l0?ol`3o00?ooo]ZoomC0?ooD`000ooonfX3ool0L`04ooo50?l0=ooo03Oo
o`0go`?oo`3=0ooonfX3o`3oF@03ol00ool0obGo0?lU00?o09;o1?oonfX7ool0?Q_ooo]Z1?l00005
oookJPOoo`0n0ooJo`02oookJPCo09;o00?o0?lUol00ool0oeT00ol0oeT01?oonf[oo`3=ool0cOoo
0<d5o`0go`04ooo50?oo07?oo`1cool0L`;ooo]Z0_ooD`001?oonf[ol`3ooo<0oooc0?l2ool0l0?o
0?oP00Cooo]Zo`3oDol0oe?oo`0K0_oonfX2o`3oT@?oo`2h00?oofP0on?o0?oSo`000oooD@001?l0
Eooo0?lfoeD0oomE0?l3oolN00;ooo]Z0ooo9003o`3o6004oookJ_oo093oo`2@ooWo00;oeOl00ooo
h`000oooM03ooo]ZoookJP02o`12o`;oo`110_l0onl00ooo08Ko0;KooeGo0003oookJP?oon802?oo
nfX00ooo08Goo`3bool0lP03oookJP;oK`3o0_oo^P03o`3oH003oookJ_oo06Ooo`1W00?ooo]Z0ooo
0:lBoookJP;o0?l9EOoonfX004Cooo]Z0_l0o`TCoookJP;oo`2_1?oonfX00ooo06Oooo]ZoookJP02
o`3oH0;ookX000?ooo]ZonGo0?m_0?l00_oonfX00ooo0?;oogT0ool0lP09oookJP;oon800_oonfX5
ool00003o`3okooonf[oo`1100;o04;o00?ooo]Zool00?oo00000oooh`02o`3o3003o`2`oooo093o
o`2@00;oolT000?o0?lHoookJ_oonfX00ooob@001?oonf[o0?l<ooo90?oonfX2oeD0o`;oolT000?o
0?l<oomA0?ooD@000ol0Gol02oooS03oo`2hool0^?n@o`3o0?nAool00ooonf[o0?mCo`1Oool0oe?o
05oo00Ko0;3o0ooc0?l3oomC00?ooo]Z0ooo07<2ooo500;o03Oo0ooo0<d9o`0?o`Ko0?n]0oooN@02
ool0?P03oomi0?oo03koo`0n00?oo`0n1OoonfX00ol0o`cooo]ZoookJP04ooo900_ooo]Z0ol00009
ool0?P;oo`001?l0/?l6o`3o30Co0?mI0_oob@02o`3ooP03o`0goom4o`3oA?l000CoA?l00_ooN@00
0om4o`3oogT0oomi0003oomi0003oo<0ooooN@3oogT000;oo`3`1?l0on03o`3oD`05ool06ol0oego
0?mMo`3oTOn@o`000_oo0;P01?ooJ03ohol0on?o0?oUo`02oomA00;oA?l00omE0?l00om4o`3oogT0
oomi0004oomi0004oookJ_l0oaSoogT0oomi00;oo`2@00Co05ooooWo0?l0/?ooo`1A0oooh`000ol0
o`cooo]ZoookJP02o`12o`05ool0@Ooonf[o0?o_o`3okooo08H00_mEo`03oookJP;oon802OoonfX0
0ooo08Goo`00ool0lP03oookJP;oK`3o0_oo^P001Ooonf[o0?mPoookJ_oonf[oo`1W00Cooo]Z0_oo
0:lCoookJP;o0?l9UooonfX00ol0o`Wooo]ZoookJP0BoookJP03ool0[ooonf[ooo]Z00;ooo]Z00Co
o`1WoookJ_oonf[ooo]Z0_l0of02oonj00;oK`3o0ooonfX2ool0lP03ool0QOoonf[ooo]Z00Kooo]Z
0_oohP03oookJP;oEOl000?o0;Koo`3okol0onl00_oonfX00ooo047o04;ooookJP02oookJP06oomd
0?ooh`3oon<0ool0DOoEo`3onOl00_oo0902oookJP03o`3o6?oonf[ooo]Z00;oob@00_oonfX3oolN
00;oE@3o00?ooo]Zo`1Gool0Eol00_ooD@000ooonf[ohol0on?o0002oon<00;oo`2h00CoT?l0o`3o
TOoonf[ooo]Z0ol0oe<01?oonf[obP3oo`3oh?l0on02ool0l0?ol`3o00Cooo]ZoomC0?ooD`3ooe<0
0ooonfX3ool0L`04ooo50?l0=ooo03Ooo`0go`?oo`3=0_oonfX5o`3oF@03ol00ool0obGo0?lU00?o
09;o1?oonfX00ooJo`3oo`0nool0?P05ool0?QOooo]Z1?l00009ool0?P?of_l000?ooo]Zo`2Bool0
T_l00ol0T_l00ol0obGo`03oo`3oF@04o`3oF@04oookJ_oo0<goo`3=ool0c@Go03Oo00CoolD0ool0
Looo07?oo`1c0_oonfX3oomC00Col`3o00?oo`3`o`3oh?l0on000_l0on03o`3oD`05ool06ooonf[o
oo]Zo`3oTOn@o`000ooo0;P00oooJ03ohol0on?o0002oomA00;o05Oo0omE0?l3oolN00;ooo]Z0_oo
90001Ooonf[o0?lHo`3o6?l0oaSooo]Z00;oo`2@00?onOl0omGo0?oEo`000oooh`000oooM03ooo]Z
oookJP02o`12o`;oo`110_l0onl00ooo08KoEOl0oeGo0004oookJP;oon802?oonfX00ooo08Goo`3b
ool0lP03oookJP;oK`3o0ooo^P02o`3oH003oookJ_oo06Ooo`1W00?ooo]Z0ooo0:lBoookJP?o0?l9
EOoonfX004Gooo]Z00?o0?l9oookJ_oonfX04_oonfX00ooo0:oooo]ZoookJP02oookJP;oo`1W0_oo
nfX2o`3oH0;ookX000OoiOl0ofl0oooonf[ooo]Zool0l_ooN@3oo`3b00[ooo]Z00Coon80oookJ_oo
nf[ooo]Z1Ooo0002oookJP03ool0@Ol0@_oo04;o00?oo`000_ooh`03o`3o3003o`2`oooo093oo`2@
00?oolT00_oonfX00ooob@3oob@0oookJP02oookJP;oolT00_mE0?l00ooonf[oolT0o`1Go`02oomA
00?o05oo00Oooh`0ool0^?oo0;Soo`2ho`3oTOoo00?ooo]Z00?o0?mC00?o05ooo`2`ool0/?l01?l0
/?l3oo<0o`Cooe<00_oonfX4ool0L`04ooo50?l0=ooo03Ooo`0go`;oo`3=2?l03ol6o`3o[@KoU?l0
0ooJo`0<ool0?P03oookJ_oob@3ooo]Z00;o0?l<4_oo03h4ool000Go0;3o00?o0?l<o`3oFOl0oeT0
1?l0oeT3ooo900?o0?on1Om4o`000ol0ookoogT0oomi0005oomi0005oo<0ooooN@3oogT0oo<0oooo
0?001?l0on001?oUo`3o0?mCo`3oDol0oe<2onGo0003o`3oGOl0oi7oo`2h00;oo`2h00CoobP0on?o
0?oSo`3o0?on0_ooD@02odCo00;oE@3o00?oogT0odCo0?ooN@001?ooN@02oookJP03o`3o6?ooN@3o
ogT000;oo`2@00Co05ooooWo0?l0/?ooo`1A0oooh`02o`2`o`05oookJ_l0@_oo04;oool0@OoonfX0
0ol0onl2oeGo00?ooo]Z0_oohP09oookJP04ool0QOoo003oo`3boooT00;ooo]Z0_m_0?l2oonj0004
o`2gool0of3ooo]ZoookJP;oo`1W1?oonfX2ool0[a;ooo]Z0_l0o`VHoookJP;o0?l94ooonfX2ool0
[`?ooo]Z0_oo06L2oookJP;o0?mP00Co0;Oooonj0?oonf[oK`3o0ooonfX2ool0lP03ool0QOoonf[o
oo]Z00Oooo]Z0_oohP03oookJP;oEOl000?oo`26o`3okol0onl00_oonfX2o`12o`?ooo]Z00Koog@0
oooS0?ooh`3oo`1AomGo0?oio`02ool0T0;ooo]Z00?o0?lHoookJ_oonfX00_oo9003oookJP;ooah0
0omE0?l01Ol0Eooo0?lfoomA0?ooD@3ooo]Z00;ohol00_ooS002ool0^004oi3o0?l0oi7ooo]Zoook
JP?o0?mC0_oonfX2o`3oh0;oo`3`1?oc0?l3oomC00?ooo]Z0ooo07<2ooo500?o03Oo0ooo0<d2oook
JPKo0?mI00?o`03oo`3o9Ol0obD01?l0T_l3oookJPCof_l03?oo03h5oookJQ7oo`0n0_oJo`02oook
JPGo09;o0_o00?l6o`3oF@03oookJ_oo0<goo`3=00Go03Oo0_ooa@03ool0L`;ooo]Z0oooD`03oo<0
o`03oonQ0?oc0?oo0?oP00?o0?oP00Cooo]Zo`3oDol0oe?o0?mC0_oonfX00ooo00?o0?nAool0^003
ool0^0?ohol00_ooD@02o`1Go`?oE@3o0ooo7P02oookJP;oob@000Gooo]Zo`3o6?l0oaSo0?lHoook
JP02ool0T003ooWo0?oEo`3oeOl000?oon<000?oog@0oookJ_oonfX00_l0@_l2ool0@@?o0?o_0omE
o`03oookJP03oooR0?oonf[ooo]Z00Oooo]Z00Coo`25ool0l_oo0?;oon@00ooonfX01?m_0?oookX0
oonj0?oo^P02o`3oH0;ooo]Z0_oo06L3oookJP;oo`2_4ooonfX2o`3o2EKooo]Z0015oookJP;o0?l9
4ooonfX2ool0[`Cooo]Z0_oo06L2oookJP06o`3oH?oo^P3ookX0oookJ_oUo`3oK`3o0_oonfX00ooo
0?;oogT0ool0lP09oookJP;oon800_oonfX6ool000;ooo]Z0ol0@_l00ooo003ooo]ZoookJP02oooS
00;o0?l<00CoolT0o`2`oooo093oo`2@1?oob@000ooonf[oob@0oolT0003oookJP;oolT00_mE0?l0
0ooonf[oolT0o`1Go`02oomA00?o05oo00Sooh`0ool0^?oo0;Soo`2ho`3oTOoo00?ooo]Zo`1Oo`?o
0?mC1ol0/?l3oo<0o`03o`2`ooooD`3ooe<000?ooo]Z1?oo07<00oooa@3o03Ooo`0go`02o`0go`So
00oo1Ol0ojd6oiCo00KoobP00ooJo`0Bool0?PKof_l00ooonfX6ool000?o0;3o1_l0oeT3o`3o3003
ooo90?l0ooko0?on00Co0?on00CoA?l0o`3oo_l0ooko0?on1OooN@001_ooD`3ol`3ooomi0?ooN@3o
0?mMool0l0Co0?oP00CoiOl0o`3oDol0oe?o0?mC0_oUo`000ol0oego0?nAoi3o0002ool0^004oon<
0?oo:03ohol0on?o00?ooe400_m4o`02oeD0o`;oA?l00_l0ooh2oomi0004oolT0?oonf[ooo]Zo`3o
60;oogT00_oo09001?m4o`3oogT0o`2`oooo0543oooS00?o0;3o0_l0@_l00ooo047ooo]Zo`3ok`02
o`3ok`;oEOl00ooonfX2oooR00[ooo]Z00?oo`00ool0l_ooi0000_oonfX2ofl0o`;ookX000Co0;Oo
o`3oH?l0of3ooo]Z0_oo06L4oookJP;oo`2_4ooonfX00ol0o`Wooo]ZoookJP2GoookJP;o0?l95?oo
nfX00ooo0:oooo]ZoookJP02oookJP;oo`1W0_oonfX2o`3oH0;ookX00_m_0?l3oookJP;oo`3b00?o
o`25oookJ_oonfX01_oonfX3oooR00;ooo]Z0_mEo`000ol0]_oo0?o_o`3ok`02oookJP03ool0@Ol0
@_oo04;o00?ooo]Z00?oog@0oooS0?ooh`000_oEo`000ooio`3oo`2@ool0T002oookJP03o`3o6?oo
nf[ooo]Z00;oob@00ooonfX2oolN00?oE@3o00Go05Ooo`3o=_ooD@3ooe40oookJP02on?o00;ooh`0
0_oo0;P01On@o`3o0?nAoookJ_oonf[oo`0K00?o0?mC00Cooo]Zo`3oh?l0on3o0?oP0_oo0?03oo<0
o`04oookJ_ooD`3ooe<0oomC00?ooo]Z0ooo07<2ooo500?o03Oo1?oo0<d2oookJPKo0?mI00?o`03o
o`3o9Ol0obD01Ol0T_l3oookJPGof_l04_oo03h6om[o00Cooo]Z1ol0T_l2ol00o`Ko0?mI0_oonfX2
ool0c@Co03Oo0oooa@03ool0L`;ooo]Z0oooD`03oo<0o`03ool0eooo0?3oo`3`00?o0?oP00CobP3o
ool06ol0oe?o0?mC0ooonfX00ol0oi7oT?l0ool0^002ool0^004oon<0?oSo`3ohol0on?o00;ooe40
00?o05Ooo`3o=_mE0?l00_mE0?l3oolN00;ooo]Z0_oo90001_oonf[o0?lHo`3o6?l0oaSooo]Zool0
T0;onOl00_oEo`03oooS0003oomd0?oonf[ooo]Z00;o04;o0_oo0443o`3ok`?oEOl00ooonfX00ooo
hP3ooo]ZoookJP08oookJP;oo`3b00Goon@0oookJ_oonf[ooo]Zofl0o`03oonj00;o0?mP0_oonfX2
ool0I`?ooo]Z0_oo0:lCoookJP;o0?l9EooonfX004Gooo]Z0_l0o`TCoookJP;oo`2_1?oonfX2ool0
I`;ooo]Z00Ko0?mPoonj0?oo^P3ookX0onGo0?m_0?l2oookJP?oo`3b00?oo`00oookJ_oonfX01ooo
nfX00ooohP3ooo]ZoookJP08ool00003ool0@Ol0@_oo04;o00?ooo]Z00Coog@0oooS0?ooh`3oo`1A
0_oob@000ol0o`coo`2@ool0T004ooo900?oob@00_oonfX00ooo7P3oolT0oookJP02oeD0o`03oook
J_oob@3o05Oo00;o0;3o0ol0Gol02?ooS03oo`2hool0^?oo0;SoT?l0o`3oTOoonf[o05oo0ol0oe<8
o`2`o`;ol`3o00Co0;3ooomC0?ooD`3ooe<00_oonfX5ool0L`;oolD00ol0=ol4o`0?o`;o0?n]00?o
00ooo`3o[Ol0ojd00ol0ojd5oiCo00KoobP01?l0/?lAom[o0004oookJ_l0003o0000o`0000;o09;o
2_oo00000ol0oeWoo`00ool00002ool000Ko0?l<1ol0ooh3odCo00SoogT000?o0?mMool0l?oo0?00
0ol0on002Ol0oego0?mCo`3oDol0oe?oo`0KoookJ_oo:03o0?mMo`3oT@02ool0^003oi3o0?oo:03o
hol000;ohol00_ooD@02o`3ooP?oE@3o0_m4o`000ol0ookoogT0oomi0002oolT0003oookJ_l0oaSo
0?lH00;oogT00_oo09001?m4o`3oogT0oomi0?ooN@03oooS00?o0;3o0_l0@_l00ooo047ooo]Zo`3o
k`02o`3ok`?oEOl00_oonfX2oooR00[ooo]Z00?oo`25ool00?oo0?800ooonfX2ofl0o`04oonj0?l0
]ooo0?mPo`3oH0;ooo]Z00?oo`1WoookJ_oonfX00_oonfX2ool0[a?ooo]Z0_l0o`VJoookJP;o0?l9
4ooonfX2ool0[`?ooo]Z0_oo06L2oookJP;o0?mP0_oo^P02ofl0o`?ooo]Z0_oo0?800ooo08Gooo]Z
oookJP07oookJP;oon800ooonfX2oeGo0003o`2fool0onoo0?o_00;ooo]Z00?oo`11o`12oooonfX0
0_oonfX2oomd00;oon<00_oEo`001?oio`3oo`2@ool0T?oonfX2o`3o6004oookJ_oo903oob@0oolT
00?ooo]Z0_oo7P03oeD0o`03o`1Gool0ocKooe4000;ooe400_oSo`02oon<00?oo`2h00Co0?nAoook
J_oonf[ooo]Z0ol0oe<2oookJP?o0?oP0_oo0?02oo<0o`03ool0eooonf[ooe<000;ooe<00_oonfX4
ool0L`;oolD00ol0=ol5ool0c@;ooo]Z1_l0oeT2ol00o`03o`3o9Ol0T_oo09;o00Co09;o1_oonfX@
om[o0004oookJ_l0003o0000o`0000Wo09;o0oo00?l5o`3oF@?ooo]Z0_oo0<d4o`0go`?oolD00ooo
07<3oookJP?ooe<00ooc0?l00ooo0=Ooo`3`ool0l004o`3oh004oookJ_l0oe?o0?mCool06`;ooo]Z
00?oo`03o`3oTOoo0;P00_oo0;P01?ooS03ohol0on?o0?oSo`02oomA00;o05Oo1?mE0?l2oolN00;o
oo]Z0ooo90001?oonf[o0?lHo`3o6?l0oaP2ool0T0;onOl00_oEo`03oooS00?ooo]Z0_l0@_l00ooo
047ooo]Zo`3ok`02o`3ok`?oEOl00ooonfX2oooR00Wooo]Z00?oo`25ool0l_oo0?800ooonfX2ofl0
o`;ookX00_l0of02oookJP;oo`1W0ooonfX3ool0[a?ooo]Z0_l0o`UGoookJP00A_oonfX00ol0o`Wo
oo]ZoookJP0BoookJP;oo`2_1?oonfX2ool0I`03oookJ_l0of3o0?mP00?ookX000CoiOl0ofl0oooo
nf[ooo]Z0ooo0?800ooo003ooo]ZoookJP07oookJP03oooR0?oonf[ooo]Z00Soo`0000?oo`11o`12
ool0@_l00ooonfX00oooM03oon<0ool00003ooo900?oo`2@1?oob@03oolT00;ooo]Z00?ooah0ooo9
0?oonfX00_mE0?l00ooonf[oolT0o`2`o`04o`2`o`;o05oo00Gooh`0ool0^?oo0;SoT?l0o`3oT@03
o`1Oo`;o0?mC2Ol0/?l2oo<0o`04ool0eoooD`3ooe<0oomC00;ooo]Z1?oo07<2ooo500?o03Oo0ol0
3ol6o`3o[@;oU?l000Co0?n]oiCo0?nDo`3oU?l01ooo:009o`2`o`Ko0?l<2_oob@0=ool000?o0;3o
1Ol0o``8o`3ooP?oA?l01_ooN@02odCo00;oo`3`1?l0on001?l0oego0?mCo`3oDooo01/2o`1Oo`;o
obP00ooo0;P01?ooS03oobP0on?o0?oSo`03oomA00;o0?on0_mE0?l2odCo00;o0?on00GoogT0oook
J_oo903oob@0oookJP03o`3o6003oomi0?oo093oo`2@00CoogT00_ooh`04o`2`o`04o`12oooo047o
o`11oookJP?o0?o_0omEo`02oookJP?oon802OoonfX00ooo08Goo`00ool0lP03oookJP;oK`3o00Co
okX0o`2gool0of3o0?mP0_oonfX2ool0I`?ooo]Z0ooo0:lBoookJP;o0?l9VooonfX2o`3o2ACooo]Z
00?oo`2_oookJ_oonfX00_oonfX2ool0I`04oookJ_l0of3o0?mPo`3oH0;ookX00_m_0?l3oookJP;o
o`3b00?oo`25oookJ_oonfX01ooonfX2oooR00?ooo]Z0_mEo`02o`3ok`?ooo]Z0_l0@_l3oookJP04
oomd0?ooh`3oon<0ool0D@;oeOl000ConOl0ool0T?oo093ooo]Z0_l0oaP01?oonf[oob@0oolT0?oo
9003oookJP;ooah00omE0?l00ol0Eooo0?lfo`1Go`02oomA0003oookJ_oSo`3oofP000;ooh`00_oo
0;P01?n@o`3oo`03oookJ_oonfX3o`3oD`;ooo]Z00KobP3oo`3oh?l0on3o0?oPool0l?oo0=L2oo<0
o`03ool0eoooD`3ooe<000;ooe<00_oonfX4ool0L`;oolD01?l0=ol5ool0c@?ooo]Z1_l0oeT5ol00
o`_o09;o1OoonfX<o`2Bo`;o0?lU0_o00?l7o`3oF@?ooo]Z0ooo0<d5o`0go`?oolD00ooo07<3oook
JPCooe<00ooc0?l2ool0l0Go0?oP0ol0oe<3oookJP;o0?nA0ooo0;P01?ooS03ohol0on?o0?oSo`02
oomA0003o`1Gool0ocKoE@3o00;oE@3o00?ooo]ZoolN0?oo7P000_oonfX3oolT0004oookJ_l0oaSo
0?lHo`3o60;oo`2@0_oio`02omGo00;oon<000Coog@0oookJ_oonf[ooo]Z0_l0@_l00ooo047ooo]Z
o`3ok`02o`3ok`?oEOl00ooonfX2oooR00Wooo]Z00?oo`25ool0l_oo0?800ooonfX2ofl0o`;ookX0
0_l0of02oookJP;oo`1W0ooonfX3ool0[a?ooo]Z0_l0o`UHoookJP00A_oonfX2o`3o2A?ooo]Z0_oo
0:l4oookJP;oo`1W0_oonfX2o`3oH0;ookX00_m_0?l3oookJP;oo`3b0ooo0007oookJP;oon8000?o
oo]Zool00?oo00001ooo00000ooo047o04;oo`12o`03oookJP03oomd0?ooh`3oo`0000?oolT00ooo
09001?oob@3o0?lHo`3o6?oonfX3oolT00;ooo]Z00?ooah0ooo90?oo7P000_mE0?l00ooonf[oolT0
o`2`o`05o`2`o`03o`1OooooS03oo`2h00;oo`2h00GoT?l0o`1Oool0Gooo05ooo`3oD`09o`2`o`;o
0?l<0_oc0?l01?l0o`cooe<0oomC0?ooD`03oookJPCoo`1c0_ooa@001?l0=ooo00ooo`0gool0=ol5
o`3o[@SoU?l01Ooo:004ol00o`So0;3o1_l0o``3ooo90003o`3o9Oo00?ooo`0000goo`001Ol0/?l3
o`0go`Oo0?on1Om4o`03oomi00?oA?l00_ooN@04o`3oh004o`3oGOl0oe?o0?mCo`3oD`;o0?mM00?o
05oooolX0?oo:0000ooo0;P01?oo:03ohol0on?o0?oSo`02oomA00?o0?on0_mE0?l2odCo0004o`3o
o_m4o`3oA?l0odCo00;oob@000Gooo]ZodCo0?l0oaSo0?lHoomi0002ool0T003o`3oo_ooN@3oogT0
00?oon<00ol0/?l01Ooonf[o04;oool0@Ooo047ooo]Z00?o0?o_0omEo`02oookJP?oon801?oonfX2
ool000?ooo]Z00?oo`25ool00?oo0?800ooonfX2ofl0o`;ookX00ol0of000ooonf[oo`1Wool0I`04
oookJP;oo`2_4ooonfX2o`3o2I_ooo]Z0ol0o`TCoookJP;oo`2_0ooonfX2ool0I`;ooo]Z0_l0of02
oonj00;oK`3o0ooonfX01?ooi03oo`3bool0QOoo08D9oookJP;oon800_oonfX2oeGo0003o`2fool0
onoo0?o_00;ooo]Z00?oo`11o`12ool0@_l00ooonfX01?ooM03oon<0oooS0?oo0542omGo0004ooWo
0?oo093oo`2@oookJP;o0?lH00Cooo]ZoolT0?oo903oob@00ooonfX2oolN00?oE@3o00?o05Ooo`3o
=_l0Eol00_ooD@000ooonf[ohol0on?o0002oon<00;oo`2h00CoT?l0o`3oTOoo00?ooo]Z0ol0oe<3
oookJP?o0?oP0_oo0?001?ooX@3ol`3ooo<0oooo0=L3oomC00Cooo]Z1?oo07<2ooo500Co03Oo1Ooo
0<d4oookJPWo0?mI1?o00?l@o`2Bo`04o`3o9Oo00?oo`03ool00o`Wo0?mI0ooonfX5ool0c@Co03Oo
0oooa@04ool0L`?ooo]Z0oooD`04oo<0o`;oo`3`1Ol0on04o`3oD`;ooo]Z00?oo`03o`3oTOoo0;P0
0_oo0;P01?ooS03ohol0on?o0?oSo`02oomA00;o05Oo00Ko0?lfoeD0oomE0?ooE@3ooookJ_oo7P03
oookJP?oob@000Cooo]Zo`3o6?l0oaSooo]Z0_oo0902ooWo0005omGo0?ooh`3oon<0oooS0?ooM000
0ooonfX2o`12o`03ool0@Ooonf[o0?o_00;o0?o_0omEo`03oookJP;oon802OoonfX00ooo08Goo`3b
ool0lP03oookJP;oK`3o0_oo^P001?l0]ooo0?mPo`3oH?oonfX2ool0I`Cooo]Z0_oo0:lCoookJP?o
0?l9F?oonfX004Oooo]Z00?o0?l9oookJ_oonfX04OoonfX3ool0[`?ooo]Z0ooo06L00ooonf[o0?mP
o`3oH003oonj00;oK`3o0ooonfX2ool0lP?oo`001ooonfX2oooR0003oookJ_oo003oo`0000Ooo`00
00?oo`11o`12oooonfX00_oonfX00ol0Goooog@0oooS0004ooo900;o00oo00Goo`2@oookJ_l0oaSo
0?lHoookJP03oolT00;ooo]Z0ooo7P03oeD0o`03ooo90?l0/?oo0;3o00Go0;3o00Gooh`0ool0^?oo
0;Soo`2hoi3o0004o`1Oo`So0;3o0ol0o``3oo<0o`05o`3o3?ooD`3ooe<0oomC0?l0Gol00ooonfX4
ool0L`;oolD00ol0/?l2o`3o[@03o`2`oonDo`3oU?l000CoU?l00_oo:002oiCo00;oobP000Co0?mI
oolX0?oo:03oobP04ol0oeT@ool000Co0;3o0_ooa@07o`3ooPWoA?l01OooN@000ol0on3o05ooo`3o
G@03o`3oD`05o`3oGOoonf[o05ooo`1Ooooo:0000ooo0;P00oooS03oobP0on?o0002on?o00;ooe40
0ol0ooh2oeD0o`03odCo0?l0ooko0?on00GoA?l000Gooo]Zo`3o6?m4o`3oA?l0oomi0002ool0T0?o
ogT00oooh`02o`2`o`;ooo]Z00Co04;oool0@Ooo047ooo]Z0ol0onl3oeGo00;ooo]Z0ooohP05oook
JP?oo`0000Cooo]Zool0QOoo003oo`3b0ooonfX2ofl0o`;ookX00ol0of000ooonf[oo`1Wool0I`04
oookJP;oo`2_4ooonfX2o`3o2Igooo]Z0_l0o`TCoookJP?oo`2_0_oonfX01?oo06Oooo]Zool0Iooo
nfX3o`3oH0;ookX00_m_0?l3oookJP03oooT0?oo0?;oo`2500[ooo]Z00Coon80oookJ_oonf[ooo]Z
0_mEo`000ol0]_oo0?o_o`3ok`02oookJP03ool0@Ol0@_oo04;o00?ooo]Z00Ooog@0oooS0?ooh`3o
o`1AomGo0?l0n?oonOl000;oo`2@00Cooo]Zo`3o6?l0oaSooo]Z0ooo9003oookJP;ooah01?mE0?l2
o`1Go`;ooe4000Gooo]Zon?o0?oSo`3oofP0oon<0002ool0^003oi3o0?l0oi7oo`0300;ooo]Z0ol0
oe<2oookJPCo0?oP0_oo0?03oo<0o`03ool0eoooD`3ooe<000;ooe<00ooonfX5ool0L`;oolD01Ol0
=ol4ool0c@Cooo]Z8ol0oeT3oookJPGoo`3=1?l0=ol4ooo500Coo`1c1?oonfX3oomC00?ol`3o0_oo
0=L00ooo0?3o0?oPo`3oh002o`3oh003olX0ool0oe?o0?mC00;o0?mC0ooonfX01?l0oi7oo`2hool0
^?oo0;P2oon<00?ohol00_ooD@02o`1Go`04oookJ_mE0?ooE@3ooookJP;ooah00ooonfX2oolT0005
oookJ_l0oaSo0?lHo`3o6?oonfX00_oo0902ooWo0005omGo0?ooh`3oon<0oooS0?ooM0000ooonfX2
o`12o`03ool0@Ooonf[o0?o_00;o0?o_0omEo`03oookJP;oon802OoonfX00ooo08Goo`3bool0lP04
oookJP04ofl0oooo^P3ookX0o`2go`;o0?mP0_oonfX00ooo06Oooo]ZoookJP02oookJP;oo`2_5?oo
nfX2o`3o2EWooo]Z0017oookJP;o0?l94ooonfX2ool0[`Cooo]Z0_oo06L2oookJP;o0?mP0_oo^P00
0ooonf[oK`3ooookJP02oookJP?oo`3b0ooo0007oookJP03oooR0?oonf[oo`0000Koo`0000?o0?o_
oookJ_oo04400_l0@_l3oookJP03o`1OooooM03oon<000?oolT01?l03ol01?oonf[o0?lHo`3o6?oo
nfX3oolT00;ooo]Z0ooo7P03oeD0o`03o`3o=_l0/?oo0;3o00Oo0;3o0ooo0;P4o`1Oo`Oo0;3o1Ol0
o``3oo<0o`05ool0eoooD`3ooe<0oomC0?l0Gol00ooonfX5ool0L`04ooo50?l0/?oo0;3oo`3o[@?o
0;3o0onDo`000ol0/?ooobP0oolX0004oolX00Go0?l<0_oob@0<o`3oF@?oolT000?ooo]Zo`000?l0
00000ol000001?oonf[oo`3=ool0cOoo0<d7ool00004o`0gooooa@3oolD0ooo500So0?on1_m4o`02
o`3ooPSoogT000So05ooo`3oDol0oe?oo`0Kooo90?nDo`3o05ooo`3oT@Coo`2h00CoobP0on?o0?oS
o`3ohol00oooD@02o`3ooP?oE@3o00?oA?l0o`3oo_m4o`001?m4o`02oookJP03o`3o6?m4o`3oA?l0
00?oo`2@0oooN@03oooS00;o0;3o0_oonfX01?l0@_ooo`11ool0@OoonfX2o`3ok`04o`2foomEo`3o
EOl0oeGo00;ooo]Z0ooohP05oookJPKoo`0000Coo`3boookJ_oonf[ooo]Z0_m_0?l2oonj0004o`2g
ool0of3o0?mPoookJP;oo`1W1?oonfX3ool0[a?ooo]Z0_l0o`VMoookJP?o0?l94ooonfX2ool0[`?o
oo]Z0_oo06L2oookJP;o0?mP00?o0;Oooonj0?oonfX00_m_0?l3oookJP;oo`3b00?oo`25oookJ_oo
nfX01ooonfX2oooR00?ooo]Z0_mEo`000ol0]_oo0?o_o`3ok`02oookJP?o04;o0ooonfX01OooM03o
on<0oooS0?oo057oeOl000;onOl00_oo09001?oonf[o0?lHo`3o6?oonfX3oolT00?ooo]Z0_oo7P04
oeD0o`;o05Oo0oooD@02on?o0003oomX0?ooS03oo`2h00;oo`2h0_l0oi400ooo00?ooo]ZoookJP03
o`3oD`;ooo]Z1?l0on02ool0l0?ol`3o00?oo`3GoomC0?ooD`000_ooD`04oookJPGoo`1c0_ooa@05
o`0go`Goo`3=3?oonfX<o`3oF@?ooo]Z1Ol00002oookJPGoo`3=1Ol0=ol3ooo500Koo`1c1?oonfX3
oomC00?ol`3o00Coo`3Gool0l?oo0?3oo`3`0ol0on000oo:0?oooo]Zo`3oD`02o`3oD`?ooo]Z0_l0
oi43ool0^0;ooh`00_oSo`03oomA0003o`1Gool0ocKoE@3o00;oE@3o00?ooo]ZoolN0?oo7P000_oo
nfX3oolT0005oookJ_l0oaSo0?lHo`3o6?oonfX00_oo09000ooio`3oeOl0omGo0003oooS0004oomd
0?oonf[ooo]ZoookJP;o04;o00?oo`11oookJ_l0onl00_l0onl3oeGo00?ooo]Z0_oohP0:oookJP;o
o`3b00Goon@0oookJ_oonf[ooo]Zofl0o`02oonj0003o`2gool0of3o0?mP00;ooo]Z00?oo`1Woook
J_oonfX00_oonfX3ool0[a?ooo]Z0ol0o`UIoookJP00B?oonfX00ol0o`Wooo]ZoookJP0AoookJP?o
o`2_0ooonfX3ool0I`04oookJ_l0of3o0?mPo`3oH0;ookX00_m_0?l2oookJP03ool00?oo0?;oo`3b
00Goo`001OoonfX2oooR0003oookJ_oo003oo`0000?oo`000_l0onl2oookJP03ool0@Ol0@_oo04;o
00;ooo]Z0_l0Gol2oooS00;oolT000?o05ooo`0?ool03ol00ol03ol2o`3o60;ooo]Z0_oo9002oook
JP?ooah000Cooo]ZoeD0oomE0?oo0?lf2_l0/?l2ool0^004oi3o0?l0Gooo05ooo`3oG@Co0;3o0_l0
o``2o`2`o`Co0?l<1Ooc0?l4oomC00?ooo]Z1_oo07<6o`2`o`04oiCo0?l0/?oo0;3oo`2`o`?oobP0
1_l0o``6ooo900?o0?l<1_oob@0:ool0c@Ko03Oo0oooa@03ool0L`Wo0?on0om4o`03o`3ooP;oA?l0
1OooN@02o`1Oo`;o0?mC0_oo:0001?oob@3oU?l0oiCo0?l0oi43ool0^005oi3o0?nDo`3ohol0on?o
0?oo:0000_ooD@03o`3ooP?oE@3o0_l0ooh3odCo00;oob@00_oonfX00ol0oaSoA?l0odCo0002ool0
T004o`3oo_m4o`3oogT0ool0D@?oon<000?o0;3ooookJ_oonfX00_l0@_l2ool0@@?o0?o_00Co0;Ko
oeGo0?mEo`3oEOl00_oonfX3oooR00Kooo]Z1_oo0003oookJP;oK`3o0_oo^P000ol0]ooo0?mPo`3o
H002oookJP;oo`1W0ooonfX3ool0[a?ooo]Z0_l0o`VOoookJP;o0?l94ooonfX3ool0[`;ooo]Z00Co
o`1WoookJ_oo06Oooo]Z0ol0of02oonj0003oookJ_m_0?oooo]Z00?ooo]Z00?oo`3bool0QOoo08D0
2OoonfX2oooR00?ooo]Z0_mEo`000ooo08Ko0?o_o`3ok`02oookJP?o04;o0ooonfX3oooS0004ool0
DOoEo`3onOl0ooWo00;oo`2@00?ooo]Zo`3o6?l0oaP00_oonfX2oolT00?ooo]Z0ooo7P03oeD0o`;o
05Oo0oooD@03on?o0007oomX0?oo0;Soo`2hool0^?n@o`3o0?nAool00`02oookJP?o0?mC0_oonfX5
o`3oh003ool0l?oc0?ool`3o00?ol`3o1?ooD`04oookJPKoo`1c0_ooa@07o`0go`[oo`3=3?oonfX<
ool0c@Oo03Oo0oooa@06ool0L`Cooo]Z0oooD`04oo<0o`04ool0eooo0?3oo`3`ool0l0?o0?oP0_oo
nfX3o`3oD`03ool06ooonf[ooo]Z00;o0?nA1?oo0;P01?ooS03ohol0on?o0?oSo`02oomA00;o05Oo
00Co0?lfoeD0oomE0?ooE@3o0_oo7P03oookJP;oob@00_oonfX3o`3o60;oo`2@0_oio`02omGo00?o
on<000Coog@0oookJ_oonf[ooo]Z0_l0@_l00ooo047ooo]Zo`3ok`02o`3ok`?oEOl00ooonfX2oooR
00[ooo]Z0ooo0?83oookJP04ofl0oooonf[ookX0o`2go`;o0?mP0_oonfX2ool0I`?ooo]Z0ooo0:lC
oookJP?o0?l9F_oonfX004Sooo]Z0_l0o`TCoookJP;oo`2_1?oonfX2ool0I`;ooo]Z0_l0of03oonj
00;oK`3o0_oonfX00ooo003oo`3bool0lP05ool000Gooo]Z0_oohP05ool00003o`2fool0onoo0?o_
00;ooo]Z00?oo`11o`12ool0@_l00_oonfX01?l0Goooog@0oooS0?ooh`02ool0D@03o`1Oool03ooo
00oo00Co00oo00?o0?lHoookJ_oonfX00ooo90000ooonf[ooah0oolN0002oolN00;oE@3o00?o05oo
o`2`ool0/?l02?l0/?l3ool0^003o`3oTOl0oego0?mM00?o0;3o1?l0o``01?l0/?oo0?l<o`3o3?l0
o``2ooo900Gol`3o1?ooD`05oookJPGoo`1c2Ol0/?l00ooo:03o0;3oo`2`o`04o`3o30KoolT00ol0
o``4ooo900go03Oo1Oooa@05ool0L`go0?on1_m4o`02o`3oh0;o05oo0ol0oe<3oolX00;oU?l01?oo
0;P01?oo:03ohol0on?o0?oSo`03oomA00;o0?on1?mE0?l2o`3ooP;oA?l00ooo90000ooonf[o0?lH
o`3o6002odCo00;oo`2@1?m4o`03oooS00?ooo]Z0_l0@_l2ool0@@?o0?o_00?o0;KooeGo0?mEo`00
0ooonfX3oooR00Kooo]Z2?oo00000ooonf[oK`3oofl0o`02oonj0003o`2gool0of3o0?mP00;ooo]Z
0_oo06L4oookJP;oo`2_4ooonfX2o`3o2J3ooo]Z0ol0o`TCoookJP;oo`2_0ooonfX3ool0I`04oook
J_l0of3o0?mPo`3oH0;ookX00_m_0?l3oookJP;oo`3b00?oo`25oookJ_oonfX02?oonfX00ooohP3o
oo]ZoookJP02oookJP03oeGo0?l0]_oo0?o_00;o0?o_00?ooo]Zool0@Ol0@_l00_l0@_l2oookJP06
oomd0?ooh`3oon<0oooS0?oo057oeOl00_oio`02ool0T003oookJ_l0oaSo0?lH00;ooo]Z0ooo9002
oookJP?ooah00omE0?l00ol0ocKo05Ooo`1Go`03oomA00;ohol000?oofP0oon<0?oo0;P00_oo0;P2
o`3oT@03ool00ooonf[o0?mC00?o0?mC0_oonfX5o`3oh003ool0l?oc0?ool`3o00?ol`3o00?ooo]Z
oomC0?ooD`000_ooD`04oookJPKoo`1c1?ooa@0=o`0go`coo`3=3?l0=ol6ooo500Koo`1c1?oonfX4
oomC00Col`3o00Coo`3Gool0l?oo0?3oo`3`1?l0on000ooonf[o0?mCo`3oD`02o`3oD`;ooo]Z00?o
o`03o`3oTOn@o`000ooo0;P01?ooS03ohol0on?o0?oSo`03oomA0003o`1Gool0ocKoE@3o00?oE@3o
0_oo7P03oookJP;oob@00_oonfX3o`3o60;oo`2@0_oio`02omGo00?oon<01?oonfX2o`12o`03ool0
@Ooonf[o0?o_00;o0?o_0omEo`03oookJP;oon802_oonfX3ool0lP?ooo]Z00CoK`3ooookJ_oo^P3o
0;Oo0_l0of02oookJP;oo`1W1?oonfX2ool0[aCooo]Z0_l0o`UKoookJP00BOoonfX00ol0o`Wooo]Z
oookJP0BoookJP;oo`2_1?oonfX2ool0I`;ooo]Z0_l0of02oonj00;oK`3o0_oonfX2ool000;oo`3b
1Ooo0004oookJP;oon800ooo0002oeGo0004ool00?oo08Ko0?o_o`3ok`;ooo]Z0_oo04401Ol0@_oo
oo]ZoookJ_l0Goooog@000;oon<00_oo0548o`0?o`;ooo]Z0ooo90000ooonf[ooah0oolN0002oolN
00;oE@3o2_l0/?l01On@o`3oo`2hool0^?oo0;SoT?l000;o0?mM00?o0;3oo`3oGOl0oe<01?l0o``0
1?l0/?oo0?l<ooo90?l0o``4ooo900Col`3o1OooD`05oookJPOoo`1c1?l0/?l3o`3o30;o0;3o1_l0
o``7ooo900Wo03Oo00?o0?nmooo50?ooa@000oooa@08ool0L`?o0;3o00?oiOl0o`3oo_l0ooh01ol0
ooh8odCo0003o`1Oool0oe?o0?mC00;o0?mC00?o05oooolX0?oo:0000_oo:005ool0^003o`3o[OoS
o`3ohol000?ooe400ooo:003oeD0o`Go0?on0ooo90001Ooonf[o0?lHo`3o6?l0oaSoA?l000;oo`2@
1?m4o`02oooS0004oomd0?oonf[ooo]ZoookJP;o04;o00?oo`11oookJ_l0onl00_l0onl00ol0]_oo
EOl0oeGo0003oookJP?oon801ooonfX9ool00004ofl0oooo^P3ookX0o`2go`;o0?mP0_oonfX2ool0
I`Cooo]Z0_oo0:lDoookJP03o`3o2Ooonf[ooo]Z0:3ooo]Z0_l0o`TDoookJP;oo`2_0ooonfX2ool0
I`;ooo]Z0_l0of03oonj0003ofl0oooonf[ooo]Z00;ooo]Z0_oo0?800ooo08Gooo]ZoookJP07oook
JP;oon800ooonfX2oeGo0005o`2fool0onoo0?o_o`3okooonfX00_oo0442o`12o`;ooo]Z00Soog@0
oooS0?ooh`3oon<0ool0DOoEo`3o0?SoooWo00;oo`2@00?ooo]Zo`3o6?l0oaP00_oonfX3oolT00;o
oo]Z0ooo7P03oeD0o`03oookJ_l0Eooo05Oo00?ooe400_oSo`02oomX0006oi3o0?oo0;Soo`2hoi3o
0?l0oi7oo`030_oonfX4o`3oD`03oookJ_l0on3o0?oP00?o0?oP0ooo0?04oo<0o`03ool0eoooD`3o
oe<000?ooe<01?oonfX7ool0L`OoolD06?l0=ol00ol0okgoolD0ooo50004ooo500Ooo`1c1OoonfX4
oomC00Gol`3o0ooo0?05o`3oh0Go0?mC0_oonfX00ooo00?o0?nAoi3o0004ool0^004oomX0?oSo`3o
hol0on?o00;ooe400_l0Eol01?l0ocKoE@3ooeD0oomE0?l2oolN00Cooo]Z0_oo90000ooonf[o0?lH
o`3o6002o`3o60;oo`2@0_oio`001OoEo`3oo`1AoooS0?ooh`3oog@000?ooo]Z0ol0@_l2oookJP?o
0?o_0omEo`03oookJP;oon802OoonfX01?oo08Goo`3bool0l_oo0?83oookJP;oK`3o00CookX0o`2g
ool0of3o0?mP0ooonfX00ooo06Oooo]ZoookJP02oookJP;oo`2_5?oonfX2o`3o2Ecooo]Z0019oook
JP;o0?l94ooonfX3ool0[`Cooo]Z00?oo`1WoookJ_oonfX00ol0of02oonj00;oK`3o0_oonfX00ooo
003oo`3bool0lP06ool000Cooo]Z0_oohP001ooo003ooo]ZoookJ_mEo`3oo`00oeGo0?oo08H00_l0
onl2oookJP04ool0@Ol0@_oo04;ooookJP;o05oo00?oog@0oooS0?ooh`000_oo0549o`0?o`05oook
J_oo903oob@0oolT0?oonfX01?oo7P02oeD0o`So0;3o0ol0o``4ool0^0Go0?mM1?l0o``3ooo900;o
0?l<0ooob@02ool0l0Col`3o1OooD`03onGo00?ooo]Z2?oo07<5o`3o30OoolT00ol0o``:ooo900[o
o`1c1_oonfX00oooD`3o0?ono`3ooP09o`3ooP?oA?l00ol0on001?l0Gooo0?mCo`3oDol0oe<2ool0
6`05o`3o[Ooo:03oobP0oolX0?n@o`001?oo0;P00ol0ojgohol0on?o0004oomA0003oolX0?l0ooko
E@3o00;oE@3o1ol0ooh2oolT0004oookJ_l0ooko0?lHoookJP?oo`2@0om4o`03oooS0004oomd0?oo
nf[ooo]ZoookJP;o04;o00?oo`11oookJ_l0onl00_l0onl00ol0]_ooEOl0oeGo0003oookJP?oon80
1ooonfX8ool00005oookJ_m_0?oookX0oonj0?l0]ol00_l0of02oookJP;oo`1W1?oonfX2ool0[aCo
oo]Z00?o0?l9oookJ_oonfX0XOoonfX2o`3o2ACooo]Z0ooo0:l3oookJP;oo`1W0_oonfX2o`3oH0;o
okX00_m_0?l3oookJP;oo`3b00?oo`25oookJ_oonfX02?oonfX2oooR00?ooo]Z0_mEo`000ol0]_oo
0?o_o`3ok`02oookJP;oo`110_l0@_l2oookJP;oog@00_ooh`001?oo057oeOl0o`3hoooio`02ool0
T005oookJ_l0oaSo0?lHo`3o6?oonfX00ooo9002oookJP?ooah01?mE0?l00ol0ocKo05Ooo`1Go`02
oomA0005oookJ_oSo`3ohol0oomX0?ooS0000ooo0;P2o`3oT@03ool00ooonf[ooo]Z00Co0?mC00?o
oo]Zo`3oh?l0on000ol0on04ool0l0Col`3o00?oo`3GoomC0?ooD`000_ooD`06oookJPWoo`1c6Ooo
a@09ool0L`Oooo]Z1?ooD`05oo<0o`03oonQ0?oo0?3oo`3`00Ko0?oP1?l0oe<01_oo01_ooo]Zoook
J_oo00?o0?nAoi3o00Coo`2h00Cooh`0on?o0?oSo`3ohol00oooD@02o`1Go`?oE@3o00?ooo]ZoolN
0?oo7P001?oonfX2oolT0004oookJ_l0oaSo0?lHo`3o60?oo`2@0_oio`001OoEo`3oon<0oooS0?oo
h`3oog@000?ooo]Z0_l0@_l00ooo047ooo]ZoookJP03o`3ok`?oEOl00_oonfX3oooR00Wooo]Z00Co
o`25ool0l_oo0?;oo`3b0ooonfX2ofl0o`04oonj0?l0]ooo0?mPo`3oH0?ooo]Z00?oo`1WoookJ_oo
nfX00_oonfX2ool0[aCooo]Z0_l0o`UMoookJP00BOoonfX2o`3o2ACooo]Z0_oo0:l4oookJP;oo`1W
0_oonfX2o`3oH0;ookX00_m_0?l2oookJP;oo`000_oo0?83ool000Oooo]Z0_oohP03oookJP04oeGo
0?oo003o0;Koool0QP;o0?o_0_oonfX01?oo047o04;oo`12oooonfX2o`1Oo`03oomd0?ooh`3oon<0
00;oo`1A2_l03ol3oolT00;ooo]Z0ooo7P02oeD0o`Oo0;3o1_l0o``2ool0^003onGo0?l0oego0?mM
00;oiOl00ol0o``00ol0oe?oolT0ooo90002ooo90004o`3o3?oob@3oolT0o`3oh0?oo`3`1Ooc0?l0
0ooo0=Oooe<0oomC0002oomC00Ko05oo1?l0/?l>ool0L`Go0?l<3Ooo07<5oookJP04o`3oGOooD`3o
oe<0oomC00ko0?on0_l0on000ol0Gooo0;3oo`3oD`02o`3oD`04ool06onDo`3oU?l0o`3o[@;oobP0
00?oT?l0ool0^?oo0;P00_oo0;P00ooo:03ohol0on?o0005oomA0003o`1Goooonf[oE@3o00;oE@3o
2Ol0ooh2o`3o6003o`3oo_oonf[oo`2@00;oo`2@0om4o`02oooS00;oog@00ooonfX2o`12o`03ool0
@Ooonf[o0?o_00;o0?o_00?o0;KooeGo0?mEo`000ooonfX3oooR00Sooo]Z1ooo00000ooonf[oK`3o
oonj0002oonj00;o0?mP0_oonfX2ool0I`Cooo]Z0_oo0:lDoookJP;o0?l9XooonfX3o`3o2ACooo]Z
0_oo0:l3oookJP;oo`1W0_oonfX2o`3oH0?ookX00_m_0?l3oookJP;oo`3b00?oo`25oookJ_oonfX0
2?oonfX00ooohP3ooo]ZoookJP02oookJP;oEOl000?oo`26o`3okol0onl00ooonfX2o`12o`?ooo]Z
00Soog@0oooS0?ooh`3oon<0ool0DOoEo`3o0?SoooWo00;oo`2@00Gooo]Zo`3o6?l0oaSo0?lHoook
JP03oolT00?ooo]Z0_oo7P04oeD0o`03o`3o=_l0Eooo05Oo00?ooe400_oSo`02oomX00Coo`2h0_l0
oi401?oo00?ooo]ZoookJ_oonfX3o`3oD`;ooo]Z1Ol0on04ool0l0Col`3o00?oo`3GoomC0?ooD`00
0oooD`09oookJPkoo`1c1_ooa@0<ool0L`Kooo]Z1_ooD`05oo<0o`03oonQ0?oo0?3oo`3`00Ko0?oP
00?ooo]Zo`3oDol0oe<00_l0oe<2ool06`04oookJ_oo00?o0?nAoi3o00Coo`2h00Cooh`0on?o0?oS
o`3ohol01?ooD@000ol0Eooo0?lfoeD0o`02oeD0o`?ooah00ooonfX2oolT00;ooo]Z0ol0oaP3ool0
T0;onOl000?oeOl0oooS0?ooh`000_ooM003oookJP;o04;o00?oo`11oookJ_oonfX00ol0onl3oeGo
00;ooo]Z0ooohP09oookJP04ool0QOoo0?;oo`3boooT00?ooo]Z0_m_0?l2oonj0003o`2gool0of3o
oo]Z00;ooo]Z00?oo`1WoookJ_oonfX00ooonfX00ooo0:oooo]ZoookJP0CoookJP03o`3o2Ooonf[o
oo]Z05cooo]Z001:oookJP;o0?l95?oonfX2ool0[`Cooo]Z00?oo`1WoookJ_oonfX00ol0of02oonj
00;oK`3o0_oonfX2ool00003ool0l_oo003oo`0000Wooo]Z0_oohP03oookJP04oeGo0?oo003o0;Ko
ool0QP;o0?o_0_oonfX00ooo047o04;oo`12o`03o`1Oo`03oomd0?ooh`3oon<000;oo`1A2_l03ol0
0ooonf[oob@0oolT0002oookJPCooah000?oE@3oo`2`ool0/?l00ol0/?l00ol0o`co0;3oo`2`o`05
o`3o30?oo`2h0_l0Gol2onGo0004o`3o3?oUo`3o0?mCo`3oD`GoolT000Co0?oPooo90?oob@3o0?oP
0ooo0?07oo<0o`Kooe<000Co05oooookJ_oonf[o0;3o0ol0oed3o`2`o`03o`3o3?l0/?ooo`1c01;o
o`1c0ooob@000ooonf[o05ooo`1Oo`02oookJPKooe<03ol0ooh2oookJP?o0?mC00?oo`0KoolX0?nD
o`000_nDo`000ooo:03oT?l0ool0^002ool0^005oi3o0?oo:03oobP0oolX0?oSo`001?ooD@000ol0
Eooo0?lfoeD0o`02oeD0o`Wo0?on00?ooo]Zo`3o6?l0oaP00_l0ooh3ool0T0?oA?l00_ooh`02oomd
00;ooo]Z0ol0@_l00ooo047ooo]Zo`3ok`02o`3ok`03o`2foomEo`3oEOl000?ooo]Z0ooohP08oook
JPKoo`000_oonfX01?m_0?oookX0oonj0?oo^P03o`3oH003oookJ_oo06Ooo`1W00Cooo]Z0_oo0:lD
oookJP;o0?l9YOoonfX2o`3o2ACooo]Z0ooo0:l3oookJP;oo`1W0_oonfX2o`3oH0?ookX000GoK`3o
oookJ_oonf[ooo]ZoooT0002ool0lP03ool0QOoonf[ooo]Z00Sooo]Z00?oon80oookJ_oonfX00_oo
nfX2oeGo0003o`2fool0onoo0?o_00;ooo]Z00?oo`11o`12ool0@_l00ooonfX02?ooM03oon<0oooS
0?ooh`3oo`1AomGo0?l0n?oonOl00_oo0902oookJP;o0?lH0_oonfX2oolT00?ooo]Z0ooo7P03oeD0
o`;o0?lf0_l0Eol2oomA0005oookJ_oSo`3ohol0oomX0?ooS0000ooo0;P01?n@o`3o0?nAool00ooo
00<2oookJP04ool06ol0oe?o0?mCo`3oD`?ooo]Z1Ol0on03ool0l0Kol`3o00?oo`3GoomC0?ooD`00
0oooD`0<oookJQ?oo`1c0ol00005oookJPKooe<01ooc0?l2ool0l0Go0?oP00?obP3ooookJ_oonfX0
0ol0oe<2ool06`;ooo]Z00?oo`03o`3oTOn@o`000ooo0;P00on@o`3ooh`0on?o0002on?o00Cooe40
00?o05Ooo`3o=_mE0?l00_mE0?l3oolN00Cooo]Z0_oo90001Ooonf[o0?lHo`3o6?l0oaSooo]Z00?o
o`2@00?onOl0omGo0?oEo`000_ooh`02oomd00?ooo]Z0_l0@_l00ooo047ooo]ZoookJP03o`3ok`?o
EOl00_oonfX3oooR00Wooo]Z00Coo`25ool0l_oo0?;oon@00ooonfX2ofl0o`;ookX000?o0;Ooo`3o
H?l0of000_oonfX00ooo06Oooo]ZoookJP03oookJP03ool0[ooonf[ooo]Z01?ooo]Z0_l0o`UNoook
JP00B_oonfX2o`3o2AGooo]Z00?oo`2_oookJ_oonfX00ooonfX00ooo06Oooo]ZoookJP02o`3oH0?o
okX00_m_0?l01_oonf[oo`00ool00?oo003oo`3bool000[ooo]Z0_oohP03oookJP04oeGo0?oo003o
0;Koool0QP;o0?o_0_oonfX00ooo047o04;oo`12o`03o`1Oo`04oomd0?ooh`3oon<0ool0D@[o00oo
0_oonfX2oolT00?ooo]Z0ooo7P001?oonf[o0;3oo`2`ool0/?l4o`3o3003o`2`ool0o`co0?l<00;o
0?l<00?oolT0oon<0?oo0;P00_oo0;P5o`1Oo`03onGo0?oonf[oolT000?oolT000?ooo]ZolX0ooo:
0?l00_oob@03o`3oh0?oo`3`1_oc0?l8oomC00?o0?mM00?ooo]ZonGo0?l0/?l01_l0/?l01?oob@3o
0;3oo`2`ool0/?l6o`3o30GoolT000?o05oooomC0?ooD`001OooD`04oo<0o`So0?on1?l0on000oo:
0?oo0?n]oookJP03o`3oD`;oo`0K1OnDo`04ool0^0GoobP01?ooD@02oiCo00?oE@3o00?ooo]Zo`3o
o_l0ooh01Ol0ooh00ooo903ooo]ZoookJP02o`3o6005o`3oo_oo093oo`2@ool0T?l0ooh00_m4o`00
0ooo057oon<0oooS0002oomd00;ooo]Z0ol0@_l01_oo047ooo]Zo`3okol0onooo`26o`2fo`;oEOl0
0ooonfX3oooR00Wooo]Z1Ooo0002oookJP04ofl0oooo^P3ookX0oonj00?o0?mP00?ooo]Zool0Iooo
06L01OoonfX2ool0[aCooo]Z00?o0?l9oookJ_oonfX0Y?oonfX3o`3o2ACooo]Z0_oo0:l4oookJP05
ool0Iooonf[ooo]ZoookJ_l0of000ooo^P02ofl0o`?ooo]Z00?oon@0ool0l_oo0?802ooonfX00ooo
hP3ooo]ZoookJP02oookJP;oEOl000?o0;Koo`3okol0onl00_oonfX00ooo047o04;oo`12o`03oook
JP08oomd0?ooh`3oon<0oooS0?oo057oeOl0o`3hoooio`03ool0T003oookJ_l0oaSo0?lH00;ooo]Z
0ooo9003oookJP;ooah000?ooo]ZoeD0oomE0?l00_l0ocH3o`1Go`;ooe4000Gooo]Zon?o0?oSo`3o
ofP0oon<0003ool0^004oi3o0?l0oi7oo`03ool00`?ooo]Z1?l0oe<2oookJP03olX0ool0on3o0?oP
00?o0?oP1?oo0?05oo<0o`03ool0eoooD`3ooe<000Gooe<06OoonfX4o`0000Kooe<02?oc0?l3ool0
l0Ko0?oP0_oonfX4o`3oD`07ool06ooonf[ooo]ZoookJ_oo00?o0?nAoi3o0003ool0^0;ooh`00ooS
o`04oomA0003o`1Gool0ocKo0?lf00?oE@3o0_oo7P04oookJP;oob@00_oonfX2o`3o6004oookJ_oo
093oo`2@ool0T0;onOl000CoeOl0ool0DOooh`3oon<00_ooM003oookJP;o04;o00?oo`11oookJ_oo
nfX00_l0onl01?l0]_ooEOl0oeGo0?mEo`02oookJP?oon802OoonfX01?oo08Goo`3bool0l_oo0?83
oookJP;oK`3o0_oo^P000ol0]ooo0?mPo`3oH002oookJP03ool0Iooonf[ooo]Z00?ooo]Z0_oo0:lD
oookJP;o0?l9GooonfX004[ooo]Z0ol0o`TDoookJP;oo`2_1?oonfX2ool0I`04oookJ_l0of3o0?mP
o`3oH0;ookX00om_0?l3ool000;oo`3b00?oo`25oookJ_oonfX01ooonfX3oooR00?ooo]Z00?oEOl0
ool00?l0]_l00ol0onl2oookJP03ool0@Ol0@_oo04;o00;o05oo00Go0?mMoomd0?ooh`3oon<0ool0
D@08o`0?o`04o`3o[Ol0oaSooo]ZoookJP;oob@00ooonfX3oolN0003oookJ_l0/?ooE@3o00Go0?l<
00?o0;3oo`3o3?l0o``01_oob@04o`0?o`Co05oo0ooob@03o`3oD`03o`3oGOo:0?ooolT000Go0?oP
0ooo0?08oo<0o`03ool0eoooD`3ooe<000_ooe<01Ol0/?l00ol0o`cooe<0oomC0009oomC00[ol`3o
1Ol0oed6o`3oh003oookJ_l0ojgo0?mC00?o0?mC00?oo`0Ko`3o[Ol0ojd01?nDo`04ool0^0;o0?n]
0ooo:004oomA0003oiCo0?l0ocKooo]Z00;oE@3o00?ooo]ZoolN0?l0ooh01?l0ooh3oolT0005oook
J_l0oaSo0?lHo`3o6?l0ooh00_oo0903o`3ooP04ool0DOooh`3oon<0oooS00;oog@00_oonfX3o`12
o`04ool0@Ooonf[o0?o_o`3ok`;o0;Ko0_mEo`03oookJP?oon802OoonfX4ool000?ooo]Z00CoK`3o
oonj0?oo^P3ookX00ol0of02oookJP03ool0Iooonf[ooo]Z00?ooo]Z0_oo0:lDoookJP;o0?l9Y_oo
nfX3o`3o2ACooo]Z0ooo0:l3oookJP;oo`1W0_oonfX2o`3oH0?ookX00_m_0?l3oookJP;oo`3b00?o
o`25oookJ_oonfX02?oonfX2oooR00Cooo]Z0_mEo`03o`3ok`;ooo]Z00?oo`11o`12ool0@_l00ooo
nfX01_ooM03oon<0oooS0?ooh`3oo`1AomGo00;o0?So0ooo09000ooonf[o0?lHo`3o6002oookJP?o
ob@00ooonfX2oolN0005oookJ_mE0?ooE@3ooookJ_l0ocH00ol0Eol2oomA0004oookJ_oSo`3ohol0
oomX00;ooh`00ooo0;P01?n@o`3o0?nAool00ooo00<3oookJPGo0?mC0_oonfX7o`3oh0?oo`3`1ooc
0?l2ool0e`gooe<01_oonfX;oomC00Wol`3o1Ooo0?06o`3oh003olX0oooonf[o0?mC00Co0?mC00Co
o`0KoookJ_oonf[oo`030_l0oi401?n@o`3oo`2hool0^?oo0;P2oon<00?ohol01?ooD@02o`1Go`04
o`3o=_mE0?ooE@3ooeD0o`?ooah01?oonfX2oolT0005oookJ_l0oaSo0?lHo`3o6?oonfX00ooo0900
1?oio`3oeOl0omGo0?oo0542oooS00;oog@00_oonfX3o`12o`03ool0@Ooonf[ooo]Z00;o0?o_00Co
0;KooeGo0?mEo`3oEOl00_oonfX3oooR00Wooo]Z00Coo`25ool0l_oo0?;oo`3b0ooonfX2ofl0o`;o
okX000?o0;Ooo`3oH?l0of000_oonfX2ool0I`Cooo]Z0_oo0:lDoookJP?o0?l9GooonfX004_ooo]Z
0_l0o`TEoookJP03ool0[ooonf[ooo]Z00?ooo]Z00?oo`1WoookJ_oonfX00ol0of02oonj00;oK`3o
00Cooo]Zool00?oonf[oon@00_oo0?8:oookJP;oon800ooonfX01?mEo`3oo`00oeGo0?l0]_l3o`3o
k`;ooo]Z00?oo`11o`12ool0@_l00_oonfX00ol0oegoog@0oooS0002oooS00Ko00oo1Ol0ojd00ooo
nf[oob@0oolT0004oookJP?ooah00_mE0?l5o`3o3003o`2`ool0o`coolT000OoolT02Ol03ol00ol0
Gooo0?mCo`3oD`03o`3oD`03oookJ_oUo`3o0?oP00Ko0?oP1Ooo0?0=oo<0o`gooe<03Ooc0?l00ol0
oego05ooo`1Oo`02o`1Oo`Oo0?oP0_oUo`04o`3oD`;oo`0K00GoU?l0o`3o[Ol0ojgo0?n]oiCo0005
ool0^0;o0?n]00?oU?l0oolX0?oo:0001?ooD@000ol0Eooo0?lfoookJP03oeD0o`;ooah00ol0ooh2
oookJP?oob@000Co0?l<o`3o6?l0oaSooo]Z0ooo0904o`3ooP;oon<00_ooM002oookJPCo04;o0_oo
nfX2o`3ok`03o`2foomEo`3oEOl000Cooo]Z0ooohP09oookJP04ool0QOoo003oo`00ool000?ooo]Z
00CoK`3ooonj0?oo^P3ookX00ol0of02oookJP;oo`1W1?oonfX2ool0[aCooo]Z0_l0o`VXoookJP?o
0?l95?oonfX2ool0[`Cooo]Z0_oo06L2oookJP;o0?mP0ooo^P000om_0?oooo]ZoookJP02oookJP;o
o`3b00?oo`25oookJ_oonfX02?oonfX2oooR00?ooo]Z0omEo`03o`3ok`;ooo]Z00?oo`11o`12ool0
@_l00ooonfX01OooM03oon<0oooS0?ooh`3oo`1A00;oeOl000Go0?Soool0T?oo093oo`2@oookJP02
o`3o60;ooo]Z0ooo9004oookJP;ooah00omE0?l01?oonf[o0?lfo`1Gool0Eol3oomA00?ohol000?o
ofP0oon<0?ooS0000ooo0;P00on@o`3o0?nAool00`02ool00`;ooo]Z1_l0oe<2oookJPOo0?oP1Ooo
0?0=oo<0o`gooe<03Ooc0?l6ool0l0Oo0?oP00?ooo]Zo`3oDol0oe<00ol0oe<01Ooo01_ooo]Zoook
J_oonf[oo`0300;o0?nA1?oo0;P2oon<00Cohol01?ooD@000ol0Eooo0?lfoeD0o`03oeD0o`;ooah0
1?oonfX3oolT0004oookJ_l0oaSo0?lHoookJP?oo`2@00ConOl0omGo0?oEo`3oo`1A0_ooh`02oomd
00?ooo]Z0ol0@_l2oookJP?o0?o_00?o0;KooeGo0?mEo`000ooonfX3oooR00Wooo]Z00Coo`25ool0
l_oo0?;oo`3b0ooonfX2ofl0o`;ookX000?o0;Ooo`3oH?l0of000_oonfX2ool0I`Cooo]Z0_oo0:lD
oookJP?o0?l9H?oonfX004_ooo]Z0ol0o`TDoookJP;oo`2_1?oonfX2ool0I`05oookJ_l0of3o0?mP
o`3oH?l0]ol00_oo^P02ofl0o`?ooo]Z0_oo0?800ooo003ooo]ZoookJP08oookJP;oon800ooonfX0
1?mEo`3oo`00oeGo0?l0]_l3o`3ok`;ooo]Z00Coo`11o`12ool0@_oooo]Z0_l0oed01?ooM03o0?mM
oooS0?ooh`04o`0?o`03o`3o[Ol03ooo0?n]00Go0?n]0ooo9003oookJP?ooah000?o00oooeD0ool0
o``01?l0o``00ooob@3o0?l<o`3o3006ooo900go00oo1Ol0oe<3onGo00Ko0?oP2?oo0?0Joo<0o`Oo
05oo2?l0on06onGo00;o00oo1ol0ojd5ool0^003o`3o[OnDo`3oU?l000;oU?l01?ooD@000ol0Eooo
0?lfo`3o=P03oeD0o`?ooah000Co0?onoookJ_oonf[ooo]Z0ooo90000ooonf[o0?lHo`3o3002oook
JP?oo`2@0ol0ooh3oooS00;oog@00_oonfX4o`12o`;ooo]Z0_l0onl00ol0]_ooEOl0oeGo0004oook
JP;oon802_oonfX01?oo08Goo`00ool00?oo0003oookJP04ofl0oooo^P3ookX0oonj00;o0?mP0ooo
nfX2ool0I`Cooo]Z00?oo`2_oookJ_oonfX04ooonfX2o`3o2JWooo]Z0ol0o`TDoookJP?oo`2_0ooo
nfX2ool0I`;ooo]Z0ol0of02oonj00;oK`3o0ooonfX3ool0lP_ooo]Z0_oohP03oookJP?oEOl00ol0
onl2oookJP03ool0@Ol0@_oo04;o00?ooo]Z00Goog@0oookJ_ooh`3oon<0ool0D@02omGo0005o`3h
oooo093oo`2@ool0T?oonfX00ol0oaP00ooonf[oob@0oolT0002oolT00?ooo]Z0_oo7P001Ooonf[o
E@3ooeD0oomE0?oooo]Z00?o05Oo0oooD@03on?o00;oofP000?oT?l0ool0^?oo0;P00_oo0;P2o`3o
T@;oo`030ooonfX6o`3oD`?ooo]Z1_l0on09ool0l1[ol`3o1_oo0?09o`3oh0;ooo]Z1_l0oe<3oook
JP03ool00ol0oi7o0?nA00Goo`2h00?ooh`0oomX0?oSo`000ooSo`04oomA00;o0?lf1?mE0?l3oolN
00?ooo]Z0ooo9002oookJP;o0?lH00Gooo]Zool0T?oo093oo`2@ooWo0002omGo0003ool0DOooh`3o
on<000;oog@00ooonfX3o`12o`;ooo]Z0ol0onl00ol0]_ooEOl0oeGo0003oookJP;oon802_oonfX0
1?oo08Goo`3bool0l_oo0?83oookJP;oK`3o0_oo^P000ol0]ooo0?mPo`3oH002oookJP;oo`1W1?oo
nfX2ool0[aCooo]Z0ol0o`UQoookJP00C?oonfX3o`3o2ACooo]Z0_oo0:l4oookJP;oo`1W00Oooo]Z
o`3oH?l0of3o0?mPo`2goooo^P3ooo]Z00;oK`3o0ooonfX2ool0lP03ool00?oonf[ooo]Z00Wooo]Z
00Soon80oookJ_oonf[ooo]ZoeGo0?oo003oEOl0o`2fo`?o0?o_0_oonfX01?oo047o04;oo`12oooo
nfX2o`3oG@;oog@00_ooh`02o`0?o`?o0?n]00?o00ooo`3o[Ol0ojd01?l0ojd3oolT00Cooo]Z0ooo
7P001?l03ooo0?l<o`3o3?l0o``4ooo900;o0?l<0ooob@000ooSo`3o05ooo`1Oo`0;o`0?o`Co0?mM
1?l0oe<00ooUo`3ooo]ZoookJP02olX0o`Wo0?oP4Ooo0?08o`1Oo`_o0?oP0ol0oed00ooonf[o0?mC
o`3oD`02ool000;oiOl00ol03ol4o`3o[@03oi3o0?oo0;Soo`2h00;oo`2h00?o00oooiCo0?nDo`00
0onDo`03oomA00?o0?n]00?o0?lfoeD0oomE0?l00_mE0?l3oolN00?ooo]Z0ooo9002oookJP03o`3o
6?l0o`co0?l<00Coo`2@0ol0ooh2oooS00;oog@00ooonfX3o`12o`;ooo]Z0ol0onl00ol0]_ooEOl0
oeGo0003oookJP?oon802OoonfX2ool0Q@03ool0l_oo003ooo]Z00?ooo]Z00CoK`3ooonj0?oo^P3o
okX00ol0of02oookJP;oo`1W1?oonfX00ooo0:oooo]ZoookJP0DoookJP;o0?l9Z_oonfX3o`3o2ACo
oo]Z0ooo0:l3oookJP;oo`1W0_oonfX2o`3oH003o`2goooo^P3ookX000;oK`3o0ooonfX3ool0lP_o
oo]Z0_oohP03oookJP?oEOl00ol0onl2oookJP04ool0@Ol0@_oo04;oo`12o`;ooo]Z0_ooM003oooS
0003oookJ_oEo`3oeOl000Coo`2@00Cooo]Zo`3o6?l0oaSooo]Z1?oo9004oookJP;ooah000Gooo]Z
oeD0oomE0?ooE@3oo`3o=P03o`1Go`?ooe400ooSo`02oomX00Goo`2h0_l0oi43ool00`;ooo]Z1ol0
oe<3oookJP;obP3o2Ol0on0Jool0l0[o0?oP1?oonfX7o`3oD`;ooo]Z0_oo00<3o`3oT@Coo`2h0_oo
S005on?o00?ooe400_l0Eol00ol0ocKoE@3ooeD0o`03oeD0o`;ooah01?oonfX2oolT00;ooo]Z0_l0
oaP00ooonf[oo`2@ool0T002ool0T0?oeOl000Coo`1AoooS0?ooM03oog@00ooonfX3o`12o`03ool0
@Ooonf[ooo]Z00?o0?o_0omEo`03oookJP;oon802_oonfX01?oo08Goo`3bool0l_oo0?83oookJP;o
K`3o0_oo^P000ol0]ooo0?mPo`3oH002oookJP;oo`1W1?oonfX2ool0[aGooo]Z0ol0o`UQoookJP00
COoonfX2o`3o2AGooo]Z00?oo`2_oookJ_oonfX00ooonfX00ooo06Oooo]ZoookJP03o`3oH004o`2g
oooo^P3oK`3oofl0o`?ooo]Z00Coon@0ool0l_oo0?;oo`252ooonfX02?oohP3ooo]ZoookJ_oonf[o
EOl0ool00?mEo`3o0;Ko0ol0onl2oookJP04ool0@Ol0@_oo04;ooookJP?o0?mM00Coog@0oooS0?oo
h`3oo`1A1?l0ojd00ol03ooo0?n]o`3o[@03o`3o[@;o0;3o0ooo9003oookJPCooah000?o0?l<oeD0
oomE0?l01Ooob@001?l0o`coolT0ooo90?oUo`02on?o0003o`1Oool03ooo00oo00So00oo1ol0ojd5
o`3oD`03oookJ_l0Gooo05oo00;ooo]Z4?l0on05ool0l0;o05oo3Ol0on000ol0Gooo0?mMo`3oG@05
o`3oG@03onGo0?oo003oo`0000;oo`001Ol03ol00ol0ojgoT?l0ool0^003ool0^003o`0?ool0ojgo
0?n]00CoU?l00oooD@02o`3o[@03o`1Goooonf[oE@3o00?oE@3o0ooo7P03oookJP?oob@00_oonfX2
o`3o60;o0?l<1?oo0903o`3ooP;oon<00_ooM002oookJPCo04;o0_oonfX3o`3ok`03o`2foomEo`3o
EOl000?ooo]Z0ooohP09oookJP;oo`2500?oo`3bool00?oonfX00ooonfX01?m_0?oookX0oonj0?oo
^P03o`3oH0;ooo]Z0_oo06L4oookJP03ool0[ooonf[ooo]Z01Cooo]Z0_l0o`V/oookJP;o0?l95Ooo
nfX2ool0[`Cooo]Z00Coo`1WoookJ_oonf[ooo]Z0_l0of000ol0]ooookX0oonj0002ofl0o`?ooo]Z
0_oo0?800ooo08Gooo]ZoookJP09oookJP;oon800ooonfX3oeGo0003o`2fool0onoo0?o_00;ooo]Z
00Coo`11o`12ool0@_oo04;o0ooonfX01OooM03oon<0oooS0?ooh`3ooo]Z00;oeOl000GonOl0ool0
T?oo093oo`2@oookJP03o`3o6003oookJ_oo903oob@000;oob@00ooonfX3oolN0004oookJ_mE0?oo
E@3ooeD0o`Co05Oo0oooD@03on?o00;oofP01_oo0;P3o`3oT@;oo`030ooonfX7o`3oD`Gooo]Z4?l0
on08ool0l0go0?oP1?oonfX7o`3oD`?ooo]Z0_oo00<3o`3oT@Goo`2h00?ooh`0oomX0?oSo`000ooS
o`03oomA00?o05Oo00?o0?lfoookJ_mE0?l00omE0?l2oolN00Cooo]Z0ooo90000ooonf[o0?lHo`3o
6002oookJPCoo`2@0_oEo`000ooo057oon<0oooS0002oomd00?ooo]Z0ol0@_l00ooo047ooo]Zoook
JP03o`3ok`;oEOl01?oonfX2oooR00[ooo]Z00Coo`25ool0l_oo0?;oo`3b0ooonfX2ofl0o`?ookX0
0_l0of02oookJP;oo`1W1?oonfX2ool0[aGooo]Z0ol0o`URoookJP00COoonfX3o`3o2AGooo]Z00?o
o`2_oookJ_oonfX00ooonfX00ooo06Oooo]ZoookJP02o`3oH003o`2goooo^P3ookX000;oK`3o0ooo
nfX00oooi03oo`3bool0lP0;oookJP;oon801?oonfX2oeGo0004o`2fool0onoo0?o_o`3ok`;ooo]Z
00?oo`11o`12ool0@_l01?l0oed01?ooM03oon<0oooS0?oo0544o`3o[@05o`0?ool0ojgo0?n]o`3o
[OnDo`001?l0/?l3oolT00;ooo]Z1Ooo7P02oeD0o`GoolT000Co0?l<oomA0?oob@3oiOl00_oSo`02
o`1Oo`Oo00oo2?l0ojd4onGo00Ko0?mC0_oonfX2o`3oGA[o0?oP1ol0Gol2onGo00Go0?mM1Ooo0003
o`0?o`04oi3o0?oo0;Soo`2hool0^0?oo`001?l0ojd00onDo`3ooe40oomA0002oomA00?o05Oo00Go
0?lfoeD0oomE0?ooE@3ooookJP03oolN00Cooo]Z0ooo9002oookJP;o0?lH00?o0?l<ool0T?oo0900
0_oo0903o`3ooP?oon<00_ooM002oookJP?o04;o00?oo`11oookJ_oonfX00ol0onl3oeGo00?ooo]Z
0ooohP09oookJP;oo`250_oo0?83oookJP;oK`3o0ooo^P03o`3oH0;ooo]Z00?oo`1WoookJ_oonfX0
0ooonfX2ool0[aGooo]Z0_l0o`V]oookJP?o0?l95OoonfX2ool0[`Cooo]Z00Coo`1WoookJ_oonf[o
oo]Z0_l0of02oonj00?oK`3o0ooonfX2ool0lP03ool0QOoonf[ooo]Z00Sooo]Z00?oon80oookJ_oo
hP000ooonfX3oeGo0006o`2fool0onoo0?o_o`3okooonf[oo`110ol0@_l3oookJP05oomd0?ooh`3o
on<0oooS0?oo05400_oEo`001?oio`3oo`2@ool0T?oo0902oookJP;o0?lH0_oonfX3oolT00?ooo]Z
1?oo7P04oeD0o`?o05Oo1?ooD@04on?o00;oofP01_oo0;P3o`3oT@;oo`030ooonfX9o`3oD`04ool0
6ooonf[ooo]ZoookJQ[o0?oP0ol00004oookJPOo0?mC1?oonfX00ooo00?o0?nAo`3oT@02o`3oT@Ko
o`2h0_ooJ003on?o00Cooe400ol0Eol00ol0ocKooo]ZoeD0o`02oeD0o`?ooah01?oonfX3oolT00;o
oo]Z0_l0oaP2oookJP?oo`2@00?onOl0omGo0?oEo`000oooh`02oomd00;ooo]Z0ol0@_l2ool0@@03
oookJ_oo08Ko0?o_00;o0?o_0_mEo`04oookJP;oon802_oonfX00ooo08Goo`3bool0lP04oookJP;o
K`3o0ooo^P02o`3oH0;ooo]Z0_oo06L4oookJP?oo`2_5?oonfX3o`3o2F?ooo]Z001>oookJP;o0?l9
5OoonfX2ool0[`Cooo]Z0_oo06L2oookJP;o0?mP00?o0;Oooonj0?oo^P000_m_0?l3oookJP03oooT
0?oo0?;oo`3b00_ooo]Z0_oohP04oookJP;oEOl000Co0;Koo`3okol0onoo0?o_0_oonfX01?oo047o
04;oo`12ool0@_l2o`3oG@;oiOl00oooh`04o`3o[@03o`0?ool0ojgo0?n]00CoU?l00_l0/?l3oolT
00;o0;3o00?ooo]ZoolN0?oo7P000_oo7P000ol0ojgoE@3oooo90003ooo900;o05Oo00Gooe40ooo9
0?oob@3ooe40on?o0002o`1Oo`Wo00oo1Ol0ojd7oiCo00Wo0?mC00?oo`0KoookJ_oonfX00ooonfX0
0ooUo`3ooo]ZoookJP02oookJP03o`1Oool0/?oo05oo00So05oo0_l0oed7o`1Oo`;o0?mM0ooUo`08
ool000;oo`2h1?oo0006o`3o[@Cooe4000Co00ooo`1Gool0Eooo0?lf1?mE0?l3oolN00Cooo]Z0ooo
9002o`2`o`;o0?lH00?ooo]Zool0T?oo09000_oo0902o`3ooP;o0?l<0oooh`02oomd00;ooo]Z0ol0
@_l00ooo047ooo]Zo`3ok`02o`3ok`04o`2foomEo`3oEOl0oeGo00?ooo]Z0ooohP09oookJP;oo`25
0_oo0?83oookJP;oK`3o0ooo^P03o`3oH0;ooo]Z00?oo`1WoookJ_oonfX00ooonfX2ool0[aGooo]Z
0_l0o`V_oookJP;o0?l95_oonfX00ooo0:oooo]ZoookJP02oookJP;oo`1W0ooonfX2o`3oH0;ookX0
0om_0?l3oookJP;oo`3b00?oo`25oookJ_oonfX02?oonfX3oooR00?ooo]Z0omEo`001_l0]_oo0?o_
o`3okol0onoooo]Zool0@@?o04;o1?oonfX3oooS0005ool0DOoEo`3oeOl0omGo0?oio`000ooo0900
1Ooonf[o0?lHo`3o6?l0oaSooo]Z00Coob@00ooonfX3oolN0003oookJ_mE0?ooE@3o00;oE@3o00?o
0?lfo`1Gool0Eol01OooD@03on?o00;oofP000?ooh`0oi3o0?oo0;P01?oo0;P4o`3oT@03ool00ooo
nf[ooo]Z00?ooo]Z2_l0oe<00ooo01_ooo]ZoookJP0DoookJP03o`000?l0oe?o0?mC00Oo0?mC00?o
o`0KoookJ_oonfX00ooonfX01Ooo00?o0?nAo`3oTOl0oi7oT?l000Koo`2h00?ooh`0oomX0?oSo`00
0ooSo`04oomA00?o05Oo00?o0?lfoookJ_mE0?l00omE0?l2oolN00Cooo]Z1?oo90000ooonf[o0?lH
o`3o6002oookJP?oo`2@00ConOl0omGo0?oEo`3oo`1A0oooh`02oomd00;ooo]Z0ol0@_l2ool0@@04
oookJ_l0onoo0?o_o`3ok`?oEOl01?oonfX2oooR00Wooo]Z0_oo08D2ool0lPCooo]Z0_m_0?l3oonj
00;o0?mP0_oonfX2ool0I`Cooo]Z0ooo0:lDoookJP?o0?l9I?oonfX004kooo]Z0ol0o`TEoookJP;o
o`2_1?oonfX2ool0I`;ooo]Z0_l0of03oonj00;oK`3o1?oonfX2ool0lP_ooo]Z0_oohP04oookJP;o
EOl000Co0;Koo`3okol0onoo0?o_0_oonfX2ool0@@;o04;o00Cooo]ZonGo0?oUo`3oiOl00oooh`04
o`3o[@03o`0?oonDo`3o0?n]00KoU?l01?oo90000ol0/?oooo]ZoookJP04oolN0006o`3o[Ooob@3o
olT0ooo90?nDo`3o0?n]0ol0Eol2ooo90003oomA0?l0Gooo05oo00Go00oo0ol0ojd3o`0?o`03o`3o
[OnDo`3oU?l000KoU?l01ooo:00:o`3oDa3o05oo1ol0oed00ooUo`3oolT0ooo9000<ool000?o00oo
1?l0ojd5oomA00?o00oo00?o0?lfoeD0oomE0?l00_mE0?l3oolN00Cooo]Z1?oo9003o`2`o`;ooo]Z
0ooo09001?l0ookonOl0o`3o3?l0o``3oooS00;oog@00_oonfX4o`12o`03ool0@Ooonf[o0?o_00;o
0?o_00Co0;KooeGo0?mEo`3oEOl00ooonfX3oooR00Wooo]Z00Coo`25ool0l_oo0?;oo`3b0ooonfX2
ofl0o`?ookX00ol0of02oookJP;oo`1W1?oonfX2ool0[aGooo]Z0_l0o`VaoookJP;o0?l95OoonfX2
ool0[`Cooo]Z0_oo06L2oookJP;o0?mP0ooo^P02ofl0o`Cooo]Z0_oo0?800ooo08Gooo]ZoookJP08
oookJP?oon800ooonfX3oeGo0005o`2fool0onoo0?o_o`3okooonfX00_oo0442o`12o`Cooo]Z1?oo
h`001?oo057oeOl0omGo0?oio`03ool0T004oookJ_l0oaSo0?lHo`3o60;ooo]Z0ooo9004oookJP?o
oah000Cooo]ZoeD0oomE0?ooE@3o0_l0ocH3o`1Go`Cooe400ooSo`02oomX00?ooh`01Ooo0;P5o`3o
T@03ool00ooonf[ooo]Z00Kooo]Z7Ol0oe<00ol0003ooo]ZoookJP04oookJP?oo`031?l0oi400on@
o`3oo`2hool0^003ool0^0;ooh`01OoSo`05oomA00?o05Oo00?o0?lfoookJ_mE0?l00omE0?l2oolN
00Cooo]Z1?oo90001Ooonf[o0?lHo`3o6?l0oaSooo]Z00?oo`2@0_oio`02omGo00?oon<00_ooM003
oookJP?o04;o0_oo04401?oonf[o0?o_o`3okol0onl3oeGo00?ooo]Z0ooohP09oookJP04ool0QOoo
0?;oo`3bool0lP?ooo]Z0om_0?l3oonj00;o0?mP0_oonfX2ool0I`Cooo]Z0ooo0:lDoookJP?o0?l9
IOoonfX004oooo]Z0_l0o`TFoookJP03ool0[ooonf[ooo]Z00;ooo]Z0_oo06L2oookJP;o0?mP00Co
0;Oooonj0?oo^P3ooo]Z0_m_0?l3oookJP;oo`3b00?oo`25oookJ_oonfX02OoonfX2oooR00Cooo]Z
0_mEo`000ol0]_oo0?o_o`3ok`02o`3ok`03oookJ_oo047oo`1100;o04;o00Gooo]ZonGo0?oUo`3o
iOl0oomd0003oooS00;o0?n]00CoU?l0o`0?oonDo`3o0?n]1_nDo`000ol0/?ooob@0oolT0002oolT
00?ooo]Z1?oo7P000ooob@3oE@3ooeD0o`02oeD0o`05o`3o[Ol0Eooo05Ooo`1Goooob@000oooD@00
1?oSo`3o00ooo`0?ool0oed6o`3o[@03o`0?ool0ojgo0?n]00KoU?l01ooo:006oookJP?o0?mC4?l0
Gol00ol0oego0?l<o`3o3003o`3oG@?oolT03?oo0005o`0?o`03o`3o[OooD@3ooe4000Cooe400ol0
Eol00ooonf[oE@3ooeD0o`02oeD0o`;ooah01OoonfX4oolT0003oookJ_l0/?oo0;3o00;o0;3o0ooo
0903ooWo00;o0?l<0_ooh`02oomd00?ooo]Z1?l0@_l01_oonf[o0?o_o`3okol0onoooo]Zo`2fo`;o
EOl00ooonfX4oooR00Wooo]Z00Coo`25ool0l_oo0?;oo`3b0ooonfX2ofl0o`?ookX00ol0of02oook
JP;oo`1W1?oonfX2ool0[aKooo]Z00?o0?l9oookJ_oonfX0/?oonfX2o`3o2AKooo]Z0_oo0:l4oook
JP04ool0Iooonf[ooo]ZoookJP;o0?mP0ooo^P02ofl0o`Cooo]Z0_oo0?8;oookJP?oon800ooonfX3
oeGo0005o`2fool0onoo0?o_o`3okooonfX00_oo0443o`12o`?ooo]Z00Goog@0oooS0?ooh`3oon<0
ool0D@02omGo0003ooWo0?oo093oo`2@00;oo`2@00Cooo]Zo`3o6?l0oaSo0?lH0_oonfX3oolT00Co
oo]Z0ooo7P000ooonf[oE@3ooeD0o`02oeD0o`;o0?lf0_l0Eol4oomA00Cohol00_ooJ004oon<00Go
o`2h00?oT?l0o`3oTOl0oi400_l0oi44ool00`Sooo]Z3ol0oe<01?oo01_ooo]ZoookJ_oonfX2o`00
00Koo`031?l0oi47ool0^0;ooh`000?oofP0on?o0?oSo`000ooSo`06oomA00?o05Oo00?ooo]ZoeD0
oomE0?l00_mE0?l3oolN00Cooo]Z1?oo90000ooonf[o0?lHo`3o6002o`3o60?oo`2@0ooio`001?oE
o`3oo`1AoooS0?ooh`02oomd00?ooo]Z1?l0@_l00ooo047ooo]Zo`3ok`02o`3ok`03o`2foomEo`3o
EOl000Cooo]Z0ooohP09oookJP04ool0QOoo0?;oo`3bool0lP?ooo]Z0_m_0?l01?oonf[ookX0oonj
0?oo^P02o`3oH0;ooo]Z0_oo06L4oookJP?oo`2_5OoonfX2o`3o2FKooo]Z001?oookJP?o0?l95Ooo
nfX2ool0[`Cooo]Z0_oo06L2oookJP;o0?mP00Co0;Oooonj0?oo^P3ooo]Z0_m_0?l3oookJP;oo`3b
00?oo`25oookJ_oonfX02OoonfX2oooR00Cooo]Z0_mEo`000ol0]_oo0?o_o`3ok`02o`3ok`03oook
J_oo047oo`1100;o04;o00?ooo]ZonGo0?oUo`000_oUo`03oooS0003ool0DOnDo`3oU?l000;oU?l0
0_l0ojd4oiCo00?o0;3o0ooo9003oookJPGooah01OmE0?l00ol0ojgoU?l0o`1Go`02o`1Go`Cooe40
00?ohol0o`3oGOl0ojd01Ol0ojd2oiCo00?o0?n]0onDo`07oolX00Goo`032OoonfX4o`1Oo`?o0;3o
0_l0Gol5o`3o3003o`3oGOoob@3oolT000;oo`2h3Ooo00000ol03oooogT0oomi0006oomA00?o05Oo
00?ooo]ZoeD0oomE0?l00_mE0?l4oolN00Cooo]Z0ooo9002oookJP04o`3o6?l0/?oo0;3oo`2`o`?o
o`2@0ooio`02o`3o30?oon<000?oog@0oookJ_oonfX00_oonfX3o`12o`;ooo]Z0ol0onl01?oonP3o
EOl0oeGo0?mEo`03oookJP?oon802_oonfX01?oo08Goo`3boookJ_oo0?83oookJP;oK`3o0ooo^P03
o`3oH0;ooo]Z0_oo06L4oookJP;oo`2_5_oonfX00ol0o`Wooo]ZoookJP2boookJP;o0?l95OoonfX2
ool0[`Cooo]Z0_oo06L3oookJP;o0?mP0_oo^P000ooonf[oK`3oofl0o`03oookJP?oo`3b2ooonfX3
oooR00?ooo]Z0omEo`001Ol0]_oo0?o_o`3okol0onoooo]Z00;oo`110ol0@_l4oookJP?oon<00_oo
05400ooEo`3onOl0ooWo0003ool0T0;ooo]Z0ol0oaP2oookJP;oob@01?oonfX4oolN00GoE@3o0_l0
ocH3o`1Go`Cooe401?oSo`000oooJ03ooh`0oon<0003oon<0003oi3o0?oo0;Soo`2h00Coo`2h00?o
T?l0o`3oTOl0oi401?l0oi45ool00`kooo]Z1_oo00<5o`3oT@[oo`2h00?ooh`0oomX0?ooJ0001OoS
o`06oomA00?o05Oo00?o0?lfoookJ_mE0?l00_mE0?l01?oonf[ooah0oolN0?oo7P04oookJP?oob@0
0_oonfX4o`3o60?oo`2@0ooio`000ooEo`3oo`1AoooS0002oooS00;oog@00ooonfX3o`12o`03ool0
@Ooonf[ooo]Z00?o0?o_0omEo`04oookJP;oon802_oonfX01?oo08Goo`3bool0l_oo0?83oookJP;o
K`3o0ooo^P03o`3oH0;ooo]Z0_oo06L4oookJP?oo`2_5OoonfX2o`3o2FOooo]Z001@oookJP?o0?l9
5OoonfX2ool0[`Cooo]Z0_oo06L2oookJP;o0?mP00Go0;Oooonj0?oo^P3ooo]Zofl0o`04oookJP;o
o`3b00?oo`25oookJ_oonfX02_oonfX00ooohP3ooo]ZoookJP02oookJP;oEOl000?oooX0o`2fool0
onl00_l0onl2oookJP04ool0@Ol0@_oo04;ooookJPCoiOl000Coog@0oooS0?ooh`3oo`1A1OnDo`00
0ol0ojgoU?l0oiCo0002oolX00;o0;3o0_l0o``3oolT0003o`3o3?oonf[ooo]Z00Gooah000?oU?l0
oeD0oomE0?l00_mE0?l2oolX00?o05Oo1_ooD@03o`3o[@03onGo0?nDo`3oU?l000?oU?l00_l0ojd0
0ooo:03oU?l0oiCo0003oiCo00;oobP00_n@o`0<o`3oT@Oo0;3o1?l0o``6ool0^0ooo`001OooD@00
1?l03ooo05Ooo`1Gool0Eol2oookJP?oogT000?ooo]ZoolN0?oo7P000_oo7P04oookJPCoob@000?o
oo]Zo`3o6?l0oaP00ol0/?l2ool0T0?onOl00_l0o``00ooo057oon<0oooS0002oomd00?ooo]Z0ol0
@_l00ooo047ooo]Zo`3ok`03o`3ok`03oooj0?mEo`3oEOl000Cooo]Z0ooohP09oookJP;oo`2500?o
o`3boooT0?oo0?800_oonfX3ofl0o`?ookX00_l0of02oookJP?oo`1W1?oonfX2ool0[aKooo]Z0_l0
o`VdoookJP?o0?l95OoonfX2ool0[`Cooo]Z0_oo06L2oookJP?o0?mP0_oo^P000ooonf[oK`3oofl0
o`03oookJP?oo`3b3?oonfX2oooR00?ooo]Z0omEo`001?l0]_ooo`26o`3okol0onl2oookJP04ool0
@Ol0@_oo04;oo`12o`Cooo]Z00Koog@0oooS0?ooh`3oon<0ool0DOoEo`03ooWo00?oo`2@0_oonfX2
o`3o60;ooo]Z0ooo9004oookJPCooah000?ooo]ZoeD0oomE0?l00_mE0?l2o`3o=PCo05Oo1OooD@05
on?o0003oomX0?ooS03ooh`000;ooh`02?oo0;P3oi3o01Oo0?nA3?oo0;P00oooS03oofP0oomX0006
on?o00Gooe401?l0Eol00ol0ocKooo]ZoeD0o`03oeD0o`Cooah01?oonfX4oolT0003oookJ_l0oaSo
0?lH00?o0?lH0ooo0902ooWo00;oeOl000?oo`1AoooS0?ooh`000_ooM003oookJP?o04;o0_oo0440
0ooonf[o0?o_o`3ok`02o`3ok`;oEOl01?oonfX3oooR00[ooo]Z00Coo`25ool0l_oo0?;oo`3b0ooo
nfX2ofl0o`?ookX00_l0of03oookJP;oo`1W1?oonfX3ool0[aGooo]Z0_l0o`UXoookJP00D?oonfX3
o`3o2AGooo]Z0_oo0:l4oookJP?oo`1W0_oonfX2o`3oH003o`2goooo^P3ookX000;oK`3o1?oonfX2
ool0lP03ool0QOoonf[ooo]Z00[ooo]Z0_oohP04oookJP;oEOl000Co0;Koo`3okol0onoo0?o_0_oo
nfX01?oo047o04;oo`12ool0@_l3onGo00;ooo]Z0oooh`05oiCo0003o`3o[OnDo`3oU?l000GoobP0
00Co0?l<oolT0?oo903oob@00_l0o``3oookJPCooah000?oU?l0oeD0oomE0?l00omE0?l01?oo:03o
05Ooo`1Gool0Eol7oomA0003on?o0?oUo`3oiOl000GoU?l01_oo:002oiCo00GoobP06Ooo0;P<ool0
00Gooe400_ooN@02o`1Go`;o0?lf00Gooo]Zoomi0?ooN@3oogT0oookJP04oolN00Gooo]Z1?oo9004
o`3o6004o`2`oooo093oo`2@ool0T0?onOl00ol0/?l3oooS00;oog@00ooonfX3o`12o`;ooo]Z1?l0
onl00ol0]_ooEOl0oeGo0004oookJP;oon802_oonfX2ool0Q@03ool0l_ooi03oo`3b00;ooo]Z0om_
0?l2oonj0003o`2gool0of3o0?mP00;ooo]Z0ooo06L4oookJP;oo`2_5_oonfX2o`3o2KKooo]Z0_l0
o`TEoookJP?oo`2_1?oonfX2ool0I`;ooo]Z0_l0of000ol0]ooookX0oonj0003ofl0o`?ooo]Z0ooo
0?8<oookJP?oon800ooonfX2oeGo0004o`2foooo08Ko0?o_o`3ok`;ooo]Z00Coo`11o`12ool0@_oo
04;o1OoonfX3oooS00;oo`1A00CoeOl0ooWo0?oio`3onOl00_oo0902oookJP?o0?lH0_oonfX3oolT
00Gooo]Z0ooo7P000ooonf[oE@3ooeD0o`03oeD0o`;o0?lf0ol0Eol6oomA00Kohol00oooJ005oon<
02?oo`2h00Cooh`0oomX0?ooJ03oofP01OoSo`06oomA00?o05Oo0_l0ocH00ooonf[oE@3ooeD0o`02
oeD0o`03oookJ_oo7P3ooah000;ooah01?oonfX4oolT00Ko0?lH0ooo0902ooWo00;oeOl000Coo`1A
oooS0?ooh`3oon<00_ooM003oookJP?o04;o00?oo`11oookJ_oonfX01?l0onl2oeGo00Cooo]Z0_oo
hP0;oookJP04ool0QOoo0?;oo`3bool0lP?ooo]Z0_m_0?l3oonj00;o0?mP0ooonfX2ool0I`Cooo]Z
0_oo0:lFoookJP?o0?l9J?oonfX0057ooo]Z0ol0o`TEoookJP;oo`2_1?oonfX2ool0I`?ooo]Z0_l0
of03oonj00;oK`3o1?oonfX2ool0lP03ool0QOoonf[ooo]Z00[ooo]Z0_oohP04oookJP;oEOl000Co
0;Koool0Q_l0onoo0?o_0ooonfX3o`12o`03onGo0?oonf[ooo]Z00;ooo]Z0oooh`05oiCo0003o`3o
[Ooo:03oU?l000KoobP000?o0?l<oolT0?oo90000_oo9005oookJP?ooah000?ooo]ZoeD0oomE0?l0
1?mE0?l00ooo:03o05Ooo`1Go`02o`1Go`Oooe4000Gohol0oiCo0?nDo`3oU?l0on?o0006oolX00Go
oh`000Coo`2hoolX0?oo:03oobP02ooo0;P2oi3o00Wooh`01ooSo`08oomA00WoogT000?oE@3ooook
J_oo7P000_oo7P05oookJPCoob@000?ooo]Zo`3o6?l0oaP00_l0oaP00ooonf[oo`2@ool0T002ool0
T0;onOl00ol0/?l3oooS00;oog@00ooonfX3o`12o`03ool0@Ooonf[o0?o_00?o0?o_00CoooX0o`2f
oomEo`3oEOl00ooonfX3oooR00[ooo]Z00?oo`25ool0l_oo0?800_oo0?82oookJP?oK`3o0_oo^P00
0ol0]ooo0?mPo`3oH002oookJP?oo`1W1?oonfX2ool0[aKooo]Z0_l0o`VgoookJP?o0?l95OoonfX2
ool0[`Gooo]Z0_oo06L2oookJP;o0?mP00?o0;Oooonj0?oo^P000om_0?l3oookJP03oooT0?oo0?;o
o`3b00cooo]Z0ooohP03oookJP?oEOl000?o0;Koo`3okol0onl00ooonfX4o`12o`Cooo]Z0oooh`02
ool0D@;oeOl00_oio`03ool0T0;ooo]Z0ol0oaP2oookJP?oob@01OoonfX4oolN00KoE@3o00?o0?lf
o`1Gool0Eol00ol0Eol6oomA00Oohol000?oofP0oon<0?ooS0001oooS00>ool0^0;oT?l02OooS007
on?o00Sooe400ol0Eol3o`3o=PGoE@3o1?oo7P05oookJPCoob@01Ol0oaP01?oonf[oo`2@ool0T?oo
0902ooWo00;oeOl000Coo`1AoooS0?ooh`3oon<00_ooM004oookJP;o04;o0_oo04400ooonf[o0?o_
o`3ok`02o`3ok`03o`2foomEo`3oEOl000?ooo]Z0ooohP0;oookJP04ool0QOoo0?;oo`3bool0lP?o
oo]Z0_m_0?l3oonj00;o0?mP0_oonfX3ool0I`Cooo]Z0_oo0:lFoookJP?o0?l9JOoonfX0057ooo]Z
0ol0o`TFoookJP;oo`2_1?oonfX2ool0I`?ooo]Z0_l0of02oonj0003oookJ_m_0?ooK`3o00Cooo]Z
0_oo0?800ooo08Gooo]ZoookJP0:oookJP;oon801?oonfX2oeGo00;o0;Ko0_l0onl3oookJP03ool0
@Ol0@_oo04;o00Gooo]Z00Coog@0oooS0?ooh`3oon<00_nDo`04oolX00;oU?l01?oo:0001?l0/?oo
0?l<o`3o3?oob@03oolT00;oolT00_oonfX00onDo`3ooo]ZoolN0002oolN0003oolX0?mE0?ooE@3o
00CoE@3o1_l0Eol7oomA00;ooo]Z0_oSo`03oolX00Wohol000?oofP0oon<0?ooS0001OooS0000ooo
J03ohol0on?o000<on?o0003o`3oo_ooD@3ooe4000Sooe401oooN@03odCo0003oookJ_oo7P3ooah0
00;ooah01?oonfX5oolT0003oookJ_l0oaSo0?lH00?o0?lH1?oo0902ooWo00?o0;3o0oooh`02oomd
00?ooo]Z0ol0@_l00ooo047ooo]ZoookJP03o`3ok`03o`3oGOl0]_ooEOl000;oEOl00ooonfX2oooR
00_ooo]Z00Coo`25ool0l_oo0?;oo`3b0ooonfX3ofl0o`;ookX000?o0;Ooo`3oH?l0of000_oonfX3
ool0I`Cooo]Z0_oo0:lFoookJP;o0?l9^OoonfX3o`3o2AGooo]Z0_oo0:l5oookJP;oo`1W0_oonfX2
o`3oH003o`2goooo^P3ooo]Z00?oK`3o0ooonfX00oooi03oo`3bool0lP0<oookJP?oon801?oonfX2
oeGo0004o`2fool0onoo0?o_o`3ok`;ooo]Z00Coo`11o`12ool0@_oo04;o1?oonfX01?ooM03oon<0
oooS0?ooh`02ool0D@;oeOl00_oio`03ool0T0;ooo]Z0ol0oaP2oookJP?oob@01_oonfX3oolN0003
oookJ_mE0?ooE@3o00CoE@3o00?o0?lfo`1Gool0Eol00ol0Eol8oomA0003oookJ_oSo`3ohol000go
hol02?ooS00?on?o00[ooe400ol0Eol2o`3o=PKoE@3o1?oo7P05oookJPGoob@01Ol0oaP00ooonf[o
o`2@ool0T002ool0T003ooWo0?oEo`3oeOl000;oo`1A0_ooh`02oomd00Cooo]Z0ol0@_l00ooo047o
oo]Zo`3ok`03o`3ok`04o`2foomEo`3oEOl0oeGo00?ooo]Z0ooohP0;oookJP03ool0QOoo0?;oo`3b
00Cooo]Z0_m_0?l3oonj00;o0?mP0_oonfX3ool0I`Cooo]Z0_oo0:lFoookJP?o0?l9J_oonfX005;o
oo]Z0ol0o`TFoookJP;oo`2_1?oonfX2ool0I`;ooo]Z0_l0of001?l0]ooookX0oonj0?oo^P02ofl0
o`Cooo]Z0_oo0?800ooo08Gooo]ZoookJP0:oookJP;oon801?oonfX3oeGo0004o`2fool0onoo0?o_
o`3ok`;ooo]Z00Coo`11o`12ool0@_oo04;o1OoonfX3oooS00;oo`1A00?o0;3ooolX0?oo:0000_oo
:002oiCo0005oolX0?l0/?oo0;3oo`2`ool0o``00_oob@04oolT00;oolT01?oonfX4oolN00;oobP0
1OmE0?l00ooo:03o05Ooo`1Go`05o`1Go`[ooe4000?ooo]Zon?o0?oSo`005ooSo`0;oomA00GoA?l0
0_ooN@05odCo0003oomi0?oo7P3ooah000;ooah01?oonfX6oolT0003oookJ_l0oaSo0?lH00?o0?lH
1?oo09000ooio`3o0;3oo`2`o`02o`2`o`?oon<00_ooM004oookJP;o04;o0_oUo`02oookJP?o0?o_
00Co0;KooeGo0?mEo`3oEOl00ooonfX3oooR00_ooo]Z00Coo`25ool0l_oo0?;oo`3b0ooonfX3ofl0
o`;ookX00ol0of02oookJP;oo`1W1OoonfX2ool0[aKooo]Z0_l0o`VkoookJP;o0?l95_oonfX2ool0
[`Gooo]Z0_oo06L2oookJP;o0?mP00?o0;Oooonj0?oo^P000_m_0?l4oookJP?oo`3b3?oonfX3oooR
00Cooo]Z0_mEo`001?l0]_oo0?o_o`3okol0onl2oookJP04ool0@Ol0@_oo04;oo`12o`Gooo]Z00?o
og@0oooS0?ooh`000_oo0542omGo0003o`3hoooio`3onOl000;oo`2@0ooonfX3o`3o6003oookJ_oo
903oob@000?oob@01_oonfX3oolN00;ooo]Z1OmE0?l2o`3o=PKo05Oo2_ooD@000ooonf[ohol0on?o
000Gon?o00_ooe401?l0Eol2o`3o=P03oookJ_mE0?ooE@3o00CoE@3o1?oo7P05oookJPKoob@01Ol0
oaP5ool0T003ooWo0?oEo`3oeOl000;oo`1A0oooh`02oomd00?ooo]Z0ol0@_l00ooo047ooo]Zoook
JP03o`3ok`;o0;Ko0_mEo`04oookJP?oon802_oonfX01?oo08Goo`3bool0l_oo0?83oookJP?oK`3o
0_oo^P000ol0]ooo0?mPo`3oH002oookJP;oo`1W1OoonfX2ool0[aKooo]Z0_l0o`U/oookJP00Dooo
nfX2o`3o2AOooo]Z00?oo`2_oookJ_oonfX00ooonfX2ool0I`;ooo]Z0_l0of02o`2go`;ookX00_m_
0?l3oookJP?oo`3b00?oo`25oookJ_oonfX02_oonfX2oooR00Cooo]Z0omEo`001?l0]_oo0?o_o`3o
kol0onl2ool00004oookJ_oo047o04;oo`12o`Gooo]Z00Coog@0oooS0?ooh`3oon<00_oo0545oolX
0003oiCo0?oo093o0;3o00;o0;3o0_l0o``2ooo900Goob@01OoonfX6oolN00;ooo]Z1OmE0?l3o`3o
=PWo05Oo7_ooD@05o`3ooPOoA?l01?l0ooh7oomi0003oolN0?oonf[ooo]Z00;ooo]Z1Ooo9002oook
JPGo0?lH1?oo09001Ooio`3o0;3oo`2`ool0/?ooo`1A00?oon<00_ooM004oookJP?o04;o0ooUo`03
o`3ok`04oooj0?l0]_ooEOl0oeGo00Cooo]Z0_oohP0<oookJP03ool0QOoo0?;oo`3b00Cooo]Z0om_
0?l2oonj00?o0?mP0_oonfX2ool0I`Gooo]Z0_oo0:lFoookJP;o0?l9_OoonfX2o`3o2AKooo]Z0_oo
0:l4oookJP;oo`1W0ooonfX2o`3oH005o`2goooo^P3ookX0oookJ_m_0?l01?oonfX3ool0lPcooo]Z
0ooohP04oookJP?oEOl01?l0onl2oookJP04ool0@Ol0@_oo04;oo`12o`Cooo]Z0_ooM002oooS00;o
o`1A00?oeOl0o`3hool0n?l00_oio`02ool0T0;ooo]Z1?l0oaP00ooonf[oob@0oolT0004oolT00Go
oo]Z1Ooo7P02oookJPGoE@3o1?l0ocH8o`1Goaoooe402Ol0Eol2oookJPGoE@3o00?ooo]ZoolN0?oo
7P001?oo7P04oookJPKoob@000?ooo]Zo`3o6?l0oaP00ol0oaP4ool0T004ooWo0?l0n?ooeOl0omGo
00;oo`1A0oooh`02oomd00?ooo]Z0ol0@_l00ooo047ooo]ZoookJP04o`3ok`03o`2foomEo`3oEOl0
00Cooo]Z0ooohP0;oookJP03ool0QOoo0?;oo`3b00Cooo]Z0om_0?l2oonj0003o`2gool0of3o0?mP
00;ooo]Z0_oo06L5oookJP;oo`2_5_oonfX2o`3o2Fgooo]Z001DoookJP;o0?l95ooonfX00ooo0:oo
oo]ZoookJP03oookJP;oo`1W0_oonfX2o`3oH0;o0;Oo0_oo^P02ofl0o`?ooo]Z0ooo0?800ooo08Go
oo]ZoookJP0;oookJP;oon800ooonfX3oeGo0003o`2foooo003o0?o_00;o0?o_0ooo0002o`12o`Ko
oo]Z1?ooh`000ooo057oobP0oolX0002oolX0005ooWo0?nDo`3oobP0ool0T?l0/?l00_oob@000ol0
o`coolT0ooo90002ooo900Goob@01OoonfX6oolN00;ooo]Z1omE0?l3o`3o=P_o05Oo3oooD@001?l0
/?oo05Ooo`1Gool0Eol9o`3ooP03odCo0?l0ooko0?on00Co0?on0_m4o`09oomi00;ooo]Z1Ooo9003
oookJPCo0?lH00?ooo]Zool0T?oo09000_oo09001Ooio`3o0;3oomGo0?oEo`3oo`1A00;oon<00_oo
0002oomd00?ooo]Z0ol0@_l00ooo047oiOl0onGo0004o`3ok`04o`2foomEo`3oEOl0oeGo00?ooo]Z
0ooohP0;oookJP;oo`250_oo0?83oookJP?oK`3o0ooo^P03o`3oH004oookJ_oo06Ooo`1Wool0I`Co
oo]Z0ooo0:lFoookJP;o0?l9__oonfX3o`3o2AKooo]Z0_oo0:l4oookJP;oo`1W0ooonfX00ol0of3o
0;Ooo`2go`02oonj00;oK`3o1?oonfX3ool0lP03ool0QOoonf[ooo]Z00[ooo]Z0_oohP04oookJP?o
EOl000Co0;Koo`3okol0onoo0?o_0ooonfX00ooo047o04;oo`12o`05oookJP05oomd0?ooh`3oon<0
oooS0?oo05400_oEo`02o`3ho`04ooWo0?oo093oo`2@ool0T0?ooo]Z1?l0oaP00ooonf[oob@0oolT
0003oolT00Kooo]Z1Ooo7P03oookJPKoE@3o0ol0ocH<o`1Go`oooe402Ol0Eol4o`3o=PKoE@3o00?o
oo]ZoolN0?oo7P001_oo7P04oookJPGoob@00ooonfX4o`3o6003oookJ_oo093oo`2@00;oo`2@00Co
nOl0o`3hoooEo`3oeOl00_oo0544oooS00;oog@00_oonfX3o`12o`04ool0@Ooonf[ooo]ZoookJP?o
0?o_00Co0;KooeGo0?mEo`3oEOl01?oonfX3oooR00_ooo]Z00?oo`25ool0l_oo0?801?oonfX2ofl0
o`?ookX000?o0;Ooo`3oH?l0of000_oonfX2ool0I`Gooo]Z0_oo0:lFoookJP;o0?l9K_oonfX005Go
oo]Z0_l0o`TFoookJP;oo`2_1OoonfX2ool0I`;ooo]Z0_l0of001?l0]ooookX0oonj0?oo^P02ofl0
o`?ooo]Z0ooo0?82ool0Q@cooo]Z0_oohP04oookJP?oEOl000Coo`00o`3okol0onoo0?o_0ooo0003
o`12o`Gooo]Z1Oooh`03oolX0003o`3hoooio`3onOl000;oobP000?oo`2@ooo90?oob@000_l0o``3
ooo90003oookJ_oo903oob@000?oob@01_oonfX2o`3ooPGooah000?o0?onoookJ_mE0?l02_mE0?l2
o`3o=QCo05Oo3Ol0ooh8odCo0003oomi0?oo7P3ooah000Cooo]Z1ooo9002oookJPCo0?lH00?ooo]Z
ool0T?oo09000ooo09001_oio`3oeOl0omGo0?oEo`3oo`1AoooS00?oo`000_ooM003oookJP?o04;o
0_oo0442onGo00?o0?o_00Co0;KooeGo0?mEo`3oEOl01?oonfX2oooR00cooo]Z00Coo`25ool0l_oo
0?;oo`3b0ooonfX3ofl0o`?ookX00ol0of001?oonf[oo`1Wool0Iooo06L4oookJP?oo`2_5_oonfX2
o`3o2L3ooo]Z0_l0o`TFoookJP?oo`2_1?oonfX2ool0I`?ooo]Z0_l0of03oonj00;oK`3o1?oonfX3
ool0lP03ool0QOoonf[ooo]Z00[ooo]Z0_oohP05oookJP;oEOl000Co0;Koool0Q_l0onoo0?o_0ooo
nfX01?oo047o04;oo`12ool0@_l4oookJP03oomd0?ooh`3oon<000;oon<000Koo`1AomGo0?oEo`3o
eOl0o`3hoooio`04ool0T003oookJ_l0oaSo0?lH00?o0?lH0_oonfX5oolT00Oooo]Z1_oo7P02oook
JP[oE@3o0_l0ocHFo`1Go`Co0?lf2_mE0?l8oolN00Cooo]Z1ooo9002oookJPCo0?lH0_oonfX4ool0
T003ooWo0?l0n?ooeOl000;oeOl000?oo`1AoooS0?ooh`000_ooh`02oomd00?ooo]Z0_l0@_l2ool0
@@;ooo]Z0ol0onl01?oo08Ko0;KooeGo0?mEo`05oookJP;oon803?oonfX00ooo08Goo`3bool0lP04
oookJP;oK`3o0ooo^P03o`3oH0;ooo]Z0_oo06L5oookJP;oo`2_5_oonfX2o`3o2Foooo]Z001Foook
JP;o0?l95_oonfX2ool0[`Gooo]Z0_oo06L2oookJP;o0?mP00Co0;Oooonj0?oo^P3ookX00_m_0?l3
oookJPCoo`3b00?oo`25oookJ_oonfX02_oonfX2oooR00Cooo]Z0omEo`000ol0]_ooo`00o`3ok`02
o`3ok`?oo`000ol0@_l4oookJP03oomd0?ooh`3oon<000;oon<000?oobP0ool0DOl0/?l00_l0/?l2
ooWo00;oobP00_oo09001?oob@3o0?l<o`3o3?l0oaP2ooo90003o`3o6?oo903o0?on00go0?on1_oo
7P000ooonf[oE@3ooeD0o`0=oeD0o`03o`3o=_oo003oo`0000Coo`001OmE0?l?o`3ooPWoA?l00ooo
nfX7oolT00;ooo]Z1?l0oaP2oookJP;oo`2@0_oo00000ooo093o0?SoomGo0002omGo0004ool0DOoo
h`3oo`00ool000;oog@01?oonfX4o`12o`03ool0@Ooonf[oiOl000?o0?o_00?oiOl0o`2foomEo`00
0_mEo`03oookJP?oon802ooonfX2ool0Q@?oo`3b0ooonfX2ofl0o`03oookJ_oo^P3ookX000?o0?mP
0_oonfX3ool0I`Cooo]Z0_oo00000ooo0:oooo]ZoookJP0DoookJP;o0?l9`_oonfX2o`3o2AKooo]Z
0ooo0:l4oookJP;oo`1W0ooonfX2o`3oH0?ookX00_m_0?l4oookJPCoo`3b3?oonfX2oooR00Gooo]Z
0omEo`001?l0]_oo0?o_o`3okol0onl2oookJP;oo`110ol0@_l3oookJP;oog@01?ooh`02ool0D@;o
eOl00_oio`04ool0T003oookJ_l0oaSo0?lH00Co0?lH00?ooo]ZoolT0?oo90000ooo9009oookJPOo
oah000?ooo]ZoeD0oomE0?l03?mE0?l8o`3o=PooE@3o0_oonfX:oolN00Cooo]Z1ooo9002oookJPCo
0?lH0ooonfX4ool0T003ooWo0?oEo`3oeOl000;oeOl000Coo`1AoooS0?ooh`3oon<00_ooM004oook
JP?o04;o00Coo`11oookJ_oonf[ooo]Z0_l0onl00ooo08Ko0;KooeGo0002oeGo00Cooo]Z0_oohP0<
oookJP04ool0QOoo0?;oo`3bool0lP?ooo]Z0_m_0?l01?oonf[ookX0oonj0?l0]ol2o`3oH0?ooo]Z
0_oo06L5oookJP;oo`2_5ooonfX2o`3o2Foooo]Z001FoookJP;o0?l95ooonfX2ool0[`Gooo]Z0_oo
06L2oookJP;o0?mP00Co0;Oooonj0?oo^P3ookX00_m_0?l3oookJPCoo`3b00?oo`25oookJ_oonfX0
2_oonfX3oooR00Cooo]Z0omEo`001?oo003o0?o_o`3okol0onl3ool00003ool0@Ol0@_oo04;o00Go
oo]Z0_ooM004oooS0006ool0DOl0/?oo0;3oo`3o3?l0n?ooo`2@0_oo:002ool0T0;o0?l<0_l0oaP3
ooo90003o`3o6?l0ooko0?on00co0?on00?oA?l0oolN0?oo7P001ooo7P03oookJQ;oE@3o4?l0ooh0
0ooo7P3oA?l0odCo0006odCo00Goob@01?oonfX4o`3o60;ooo]Z1?oo0903ool000?oeOl000Koo`1A
oooS0?oo003oo`00oooS0?ooM004oookJPCo04;o00?o0?mMoookJ_oonfX00ol0onl00ol0Gooo0;Ko
oeGo0003oeGo00;oiOl000Cooo]ZoooR0?oohP3oon802ooonfX2ool0Q@?oo`3b0ooonfX2ofl0o`?o
okX00ol0of02oookJP?oo`1W1?oonfX00ooo003oo`2_ool0[`0FoookJP?o0?l9`_oonfX3o`3o2AKo
oo]Z0_oo0:l6oookJP04ool0Iooonf[ooo]ZoookJP;o0?mP0ooo^P03ofl0o`?ooo]Z1?oo0?8<oook
JP?oon801?oonfX3oeGo0004o`2fool0onoo0?o_o`3ok`;ooo]Z0_oo0443o`12o`Cooo]Z0_ooM004
oooS00;oo`1A0_oEo`000ol0n?oonOl0ool0T003ool0T003oookJ_l0oaSo0?lH00Go0?lH00?ooo]Z
oolT0?oo90000ooo9009oookJP[ooah00ooonfXDoeD0o`Cooo]Z2ooo7P07oookJPKoob@00ooonfX4
o`3o60?ooo]Z1?oo0902ooWo00?oeOl00_oo0543oooS00;oog@01?oonfX3o`12o`04ool0@Ooonf[o
oo]ZoookJP;o0?o_0_oo08H4oeGo00?ooo]Z0ooohP0<oookJP04ool0QOoo0?;oo`3bool0lP?ooo]Z
0_m_0?l01?oonf[ookX0oonj0?l0]ol2o`3oH0?ooo]Z0_oo06L5oookJP;oo`2_5ooonfX2o`3o2G3o
oo]Z001GoookJP;o0?l95ooonfX2ool0[`Gooo]Z0_oo06L2oookJP;o0?mP00Co0;Oooonj0?oo^P3o
okX00_m_0?l4oookJP?oo`3b00?oo`25oookJ_oonfX02_oonfX3oooR00Cooo]Z0omEo`000ol0]_oo
0?o_o`3ok`02o`3ok`;ooo]Z0_oo0442o`12o`Kooo]Z00?oog@0oooS0?ooh`000_ooh`001ooo057o
0;3oo`2`ool0o`co0?Soool0T?oo:0001?oo09001?oonf[o0?lHo`3o6?l0oaP2ooo90003o`3o6?l0
ooko0?on00Wo0?on2Om4o`000ooonf[ooah0oolN000LoolN0003o`000?l0ooko0?on00Go0?on1?oo
nfX6oolT00Gooo]Z1?l0oaP2oookJPGoo`2@00?onOl0ool00?oo00000ooo00001Ooo057oo`00ool0
0?oo003oon<000;oog@00ooonfX4o`12o`?o0?mM0ol0onl2o`1Oo`CoEOl00_oUo`000ooonf[oon80
oooR0002oooR00_ooo]Z0_oo08D2ool0lP?ooo]Z0om_0?l3oonj00;o0?mP0ooonfX00ooo06Oooo]Z
ool0I`04oookJP03ool00?oo0:oooo]Z01Kooo]Z0ol0o`W4oookJP;o0?l96?oonfX00ooo0:oooo]Z
oookJP04oookJP03ool0Iooonf[ooo]Z00?o0?mP0ooo^P03ofl0o`?ooo]Z00Goon@0ool0l_oo0?;o
o`3bool0Q@0;oookJP?oon801?oonfX3oeGo0003o`2fool0onoo0?o_00;o0?o_0_oonfX2ool0@@?o
04;o1OoonfX00oooM03oon<0oooS0002oooS00;oo`1A0_oEo`02o`3ho`Goo`2@00?ooo]Zo`3o6?l0
oaP01Ol0oaP3oookJPGoob@03?oonfXOoolN00?o00002OoonfX6oolT00Cooo]Z1?l0oaP3oookJPCo
o`2@0ooio`03omGo0003ool0DOooh`3oon<000;oon<00_ooM004oookJP?o04;o00Coo`11oookJ_oo
nf[ooo]Z0ol0onl00ooo08KoEOl0oeGo0002oeGo00Cooo]Z0ooohP0<oookJP03ool0QOoo0?;oo`3b
00Cooo]Z0_m_0?l3oonj0003o`2gool0of3o0?mP00;ooo]Z0ooo06L4oookJP;oo`2_6?oonfX2o`3o
2G7ooo]Z001GoookJP?o0?l95ooonfX2ool0[`Gooo]Z0_oo06L2oookJP;o0?mP00Co0;Oooonj0?oo
^P3ookX00om_0?l3oookJP?oo`3b00?oo`25oookJ_oonfX02_oonfX3oooR00Cooo]Z1?mEo`001?l0
]_oo0?o_o`3okol0onl3oookJP04ool0@Ol0@_oo04;oo`12o`Kooo]Z1Oooh`001?oo057o0;3oo`2`
ool0o``2o`3ho`Koo`2@1?oob@02o`3o60co0?on1_m4o`08oomi00oooah01ooonfX4o`0000Cooo]Z
1ooo9005oookJPGo0?lH0_oonfX5ool0T0;onOl02?oo0002oooS0003oomd0?oonf[ooo]Z00;ooo]Z
1?l0@_l3o`3oG@Co0?o_00?o05oooeGo0?mEo`000_mEo`000ooUo`3ooo]ZoookJP04oooR00_ooo]Z
0_oo08D3ool0lP?ooo]Z0om_0?l2oonj0003o`2gool0of3o0?mP00?ooo]Z0ooo06L3oookJP03ool0
[ooo003oo`2_01Oooo]Z0ol0o`W5oookJP?o0?l96?oonfX00ooo0:oooo]ZoookJP03oookJP;oo`1W
0_oonfX3o`3oH0?ookX00om_0?l4oookJP?oo`3b00?oo`25oookJ_oonfX02OoonfX4oooR00?ooo]Z
1?mEo`000ol0]_oo0?o_o`3ok`02o`3ok`;ooo]Z00?oo`11o`12ool0@_l00_l0@_l5oookJPKoon<0
00?oo`1AomGo0?oEo`000_l0n?l00ooio`3oo`2@ool0T003ool0T0;ooo]Z1ol0oaP3oookJPKoob@0
3ooonfX>oolN00Oooo]Z1?l00005oookJPKoob@01OoonfX5o`3o60;ooo]Z1Ooo0903ooWo00?oeOl0
0_oo0544oooS00;oog@01?oonfX3o`12o`;oo`110_oonfX3o`3ok`03ool0Q_l0]_ooEOl000;oEOl0
1?oonfX3oooR00cooo]Z00Coo`25ool0l_oo0?;oo`3b1?oonfX2ofl0o`?ookX000?o0;Ooo`3oH?l0
of000_oonfX3ool0I`Cooo]Z0_oo0:lHoookJP;o0?l9L_oonfX005Sooo]Z0_l0o`THoookJP;oo`2_
1?oonfX3ool0I`;ooo]Z0_l0of001Ol0]ooookX0oonj0?oo^P3ooo]Z00;oK`3o0ooonfX3ool0lP03
ool0QOoonf[ooo]Z00_ooo]Z0ooohP03oookJPCoEOl000?o0;Koool0Q_l0onl00_l0onl2oookJP03
ool0@Ol0@_oo04;o00;o04;o1OoonfX2oomd00Coon<00_oo05400ol0/?oo0?l<o`3ho`02o`3ho`Go
o`2@0_oob@02oookJP;o0?lH1ol0ooh3odCo00Go0?on00?oA?l0oomi0?ooN@001_ooN@0FoookJP[o
ob@01_oonfX6o`3o60;ooo]Z1Ooo0903ooWo0003omGo0?oo003oo`0000Ooo`0000?oog@0oookJ_oo
nfX00_oonfX5o`12o`;o0?mM1?l0onl00ol0GoooEOl0oeGo0002oeGo00Cooo]Z0ooohP0<oookJP;o
o`250_oo0?84oookJP;oK`3o0ooo^P03o`3oH0;ooo]Z0ooo06L4oookJP;oo`0000?oo`2_oookJ_oo
nfX05OoonfX3o`3o2LOooo]Z0ol0o`THoookJP03ool0[ooonf[ooo]Z00?ooo]Z0_oo06L2oookJP?o
0?mP0ooo^P000ooonf[oK`3oofl0o`04oookJP?oo`3b00?oo`25oookJ_oonfX02_oonfX3oooR00?o
oo]Z1?mEo`02o`2fo`?o0?o_0ooonfX5o`12o`Cooo]Z0_ooM005oooS0003ool0DOoEo`3oeOl000?o
0?So00?onOl0ool0T?oo09000_oo0904oookJPKo0?lH0ooonfX:oolT01gooo]Z2ooo9005oookJPKo
0?lH0_oonfX5ool0T0?onOl01?oEo`02ool0D@?oon<00_ooM004oookJPGo04;o00?oo`11oookJ_oo
nfX00ol0onl00ooo08Ko0;KooeGo0002oeGo00Cooo]Z0ooohP0=oookJP03ool0QOoo0?;oo`3b00Co
oo]Z0om_0?l3oonj00?o0?mP0_oonfX2ool0I`Gooo]Z0_oo0:lGoookJP?o0?l9LooonfX005Sooo]Z
0ol0o`THoookJP;oo`2_1?oonfX3ool0I`;ooo]Z0_l0of001Ol0]ooookX0oonj0?oo^P3ooo]Z00;o
K`3o1?oonfX2ool0lP03ool0QOoonf[ooo]Z00cooo]Z0_oohP03oookJP03ool00?mEo`3oEOl000;o
EOl000Co0;Koo`3okol0onoo0?o_0ooonfX00ooo047o04;oo`12o`02o`12o`Kooo]Z0_ooM003oooS
00;oo`1A00?o0;3oooo90?l0o``00_l0n?l7ool0T0?ooo]Z1_l0ooh8odCo00;o0?on1Om4o`06oomi
00;oob@01ooonfX?oolT00Gooo]Z2?l0oaP00ooonf[oo`2@ool0T004ool0T0?onOl00ooEo`0:ool0
00?ooo]Z1Ol0@_l00ooo047o0?mMo`3ok`03o`3ok`03o`3oGOmEo`3oEOl000;oEOl01?oonfX3oooR
00cooo]Z0ooo08D00ooo0?;oon@0oookJP03oookJP;oK`3o0ooo^P03o`3oH0;ooo]Z0ooo06L4oook
JP03ool00?oo0:ooo`2_01Oooo]Z00?o0?l9ool00?oo0000b?oonfX4o`3o2AOooo]Z0_oo0:l5oook
JP;oo`1W0_oonfX3o`3oH004o`2goooo^P3ookX0oookJP;oK`3o1?oonfX3ool0lP03ool0QOoonf[o
oo]Z00_ooo]Z0ooohP03oookJPCoEOl000?o0;Koool0Q_l0onl00_l0onl3oookJPGo04;o1OoonfX2
oomd00Coon<00_oo0542omGo00?o0?So1_oo0905oookJPKo0?lH1_oonfX?oolT00Oooo]Z4?oo9005
oookJPOo0?lH00?ooo]Zool0T?oo09001?oo0903ooWo00CoeOl00_oo0544oooS00;oog@01?oonfX5
o`12o`03ool0@Ooonf[ooo]Z00?o0?o_00?oo`26o`2foomEo`000_mEo`04oookJPCoon803?oonfX2
ool0Q@;oo`3b1?oonfX2ofl0o`04oookJ_oo^P3ookX0oonj00?o0?mP0_oonfX2ool0I`Gooo]Z0_oo
0:lGoookJP?o0?l9M?oonfX005Wooo]Z0ol0o`TGoookJP?oo`2_1?oonfX3ool0I`;ooo]Z0ol0of04
oonj00;oK`3o1?oonfX3ool0lP03ool0QOoonf[ooo]Z00_ooo]Z0ooohP02oookJP03ool00?oonf[o
EOl000?oEOl000Co0;Koo`3okol0onoo0?o_0_oonfX3ool0@@?o04;o1_oonfX00ooo05Ooog@0oooS
0003oooS00;oo`1A00?oolT0o`3o3?l0o``00_l0n?l00ooio`3oo`2@ool0T004ool0T0;ooo]Z0ol0
ooh00ooonf[o0?lHo`3o6006odCo00OoogT00ooo0003oolT00KoogT02ooo90000ooonf[o0000o`00
0002o`000003oookJ_l0oaSo0?lH00So0?lH00?ooo]Zool0T?oo09001Ooo0903ooWo00CoeOl03?oo
0006o`12o`;o05oo1?l0onl00ol0oego0;KooeGo0003oeGo00;o0?mM00?ooo]ZoooR0?oohP000_oo
hP0<oookJP;oo`250_oo0?801?ooi03ooo]ZoookJ_oonfX3ofl0o`?ookX00ol0of02oookJP;oo`1W
1OoonfX00ooo003oo`2_ool0[`0GoookJP03o`3o2Ooo003ooo]Z0<[ooo]Z0ol0o`THoookJP;oo`2_
1OoonfX2ool0I`;ooo]Z1?l0of03oonj00?oK`3o0ooonfX4ool0lPgooo]Z0ooohP04oookJPCoEOl0
00Co0;Koo`3okol0onoo0?o_0ooonfX2ool0@@Co04;o1_oonfX00oooM03oon<0oooS0002oooS00;o
o`1A0ooEo`02o`3ho`;onOl01Ooo0906oookJPOo0?lH2OoonfXFoolT0003oookJ_l0003o000000;o
000000?ooo]Zo`3o6?l0oaP02?l0oaP2oookJPKoo`2@0ooio`04omGo00;oo`1A1Oooh`02oomd00Co
oo]Z1Ol0@_l3oookJP?o0?o_00?oo`26o`2foomEo`000omEo`04oookJPCoon803?oonfX01?oo08Go
o`3bool0l_oo0?83oookJP?oK`3o1?oo^P03o`3oH004oookJ_oo06Ooo`1Wool0I`Cooo]Z0ooo0:lG
oookJP;o0?l9M_oonfX005[ooo]Z0ol0o`TGoookJP?oo`2_1?oonfX3ool0I`;ooo]Z0ol0of04oonj
00;oK`3o1?oonfX3ool0lP03ool0QOoonf[ooo]Z00_ooo]Z0ooohP05oookJPCoEOl01Ol03ol01?oo
nf[oo`11ool0@Ooo0443o`12o`Kooo]Z00?o0?l<oomd0?ooM0001?ooh`02ool0D@03ooo90?l0o`co
0?So00?o0?So0_oio`06ool0T0Cooo]Z00?o0?lHodCo0?m4o`000_m4o`000ol0oaSoogT0ool00007
ool00003o`3o6?oonf[ooo]Z00kooo]Z3ol0oaP9ool0T003ooWo0?l0n?oo0?So00CoeOl000?oo`1A
oooS0?oo00003Ooo0002o`12o`;o05oo1_l0onl00ol0]_ooEOl0oeGo0002oeGo0004o`3oGOoonf[o
oo]ZoookJP?oon803?oonfX3ool0Q@;oobP01?oonfX2ofl0o`?ookX01?l0of02oookJP;oo`1W1?oo
nfX01?oo0:ooo`00oookJ_oo0:lGoookJP03o`3o2Ooo003ooo]Z0<cooo]Z0ol0o`THoookJP;oo`2_
1OoonfX2ool0I`;ooo]Z0_l0of000ooonf[o0?mPoonj0002oonj00?oK`3o0ooonfX4ool0lP03ool0
QOoonf[ooo]Z00[ooo]Z1?oohP04oookJPCoEOl01Ol0onl2oookJP;oo`111?l0@_l7oookJP03oomd
0?ooh`3oon<000;oon<00_oo0543omGo00?o0?So0_oio`06ool0T0Gooo]Z3ol0oaP@oookJPoo0?lH
2Ooo09000ooio`3o0?Soo`3ho`04omGo00;oo`1A1Oooh`02oomd00Cooo]Z1Ol0@_l00ooo047ooo]Z
oookJP05o`3ok`03o`2foomEo`3oEOl000;oEOl01?oonfX4oooR00cooo]Z0_oo08D3ool0lP?ooo]Z
0om_0?l3oonj00Co0?mP00?ooo]Zool0Iooo06L01OoonfX3ool0[aOooo]Z0_l0o`UgoookJP00Fooo
nfX3o`3o2AOooo]Z0ooo0:l4oookJP?oo`1W0ooonfX2o`3oH0CookX00_m_0?l4oookJP04oooT0?oo
0?;oo`3bool0Q@gooo]Z1?oohP05oookJPCoEOl02?l03ol4o`12o`Gooo]Z00Co0?l<oookJ_oonf[o
og@01Oooh`03ool0D@03o`3o3?oob@3o0?So00Wo00oo0ooo09000ooonf[oo`00ool0000;ool001So
0?lH00?o0000oookJ_oonfX02ooo0903o`3ho`;oiOl000?oeOl0oookJ_oUo`000oooh`0:ool000Go
04;o0_l0Gol6o`3ok`04o`2foomEo`3oEOl0oeGo00Gooo]Z1?oohP0;oookJP?oo`250_oo:0001?oo
0?;ooo]ZoookJ_oonfX2ofl0o`04oookJ_oo^P3ookX0oonj00?o0?mP0_oonfX3ool0I`Cooo]Z0_oo
00000ooonf[oo`2_oookJP0FoookJP03o`3o2Ooo003ooo]Z0<kooo]Z0ol0o`THoookJP;oo`2_1Ooo
nfX2ool0I`?ooo]Z00?o0?mPoookJ_l0of000ooo^P03ofl0o`?ooo]Z00Goon@0ool0l_oo0?;oo`3b
ool0Q@0<oookJPCoon801OoonfX4oeGo00Go0?o_0ooonfX5o`12o`Sooo]Z00?oog@0oooS0?ooh`00
0_ooh`03ool0D@?oeOl00ol0n?l2ooWo00Ooo`2@2?oonfXNo`3o6003o`000?oonf[ooo]Z00_oo`2@
0ol0n?l4omGo00;oo`1A1Oooh`02oomd00Gooo]Z1Ol0@_l00ooo047ooo]ZoookJP05o`3ok`03o`2f
oomEo`3oEOl000;oEOl01?oonfX5oooR00_ooo]Z0_oo08D4ool0lP;ooo]Z0om_0?l01?oonf[ookX0
oonj0?oo^P03o`3oH0;ooo]Z0_oo06L5oookJP03ool0[ooonf[oo`2_01Oooo]Z0_l0o`UhoookJP00
G?oonfX2o`3o2ASooo]Z0ooo0:l5oookJP;oo`1W0ooonfX2o`3oH0CookX00om_0?l3oookJP03oooT
0?oo0?;oo`3b00;oo`253?oonfX5oooR00Gooo]Z1?mEo`09o`0?o`Co04;o1ooonfX2oomd017o00oo
00?oo`2@ool00?oo00003_oo0002oookJPgo0?lH1OoonfX<ool0T003ooWo0?l0n?oo0?So00;o0?So
1OoUo`06oooS00Coo`001OoonfX5o`12o`;o05oo1_l0onl01?l0]_ooEOl0oeGo0?mEo`05oookJPCo
on803?oonfX2ool0Q@03ool0l_oo:03oo`3b00Cooo]Z0_m_0?l3oonj00Co0?mP0_oonfX2ool0I`Go
oo]Z00Coo`00ool0[ooo0:ooo`2_5_oonfX00ol0o`Woo`00ool0003AoookJP?o0?l96?oonfX2ool0
[`Kooo]Z00Ooo`1WoookJ_oonf[ooo]Zo`3oH?oonf[o0?mP00?ookX00om_0?l3oookJP05oooT0?oo
0?;oo`3bool0l_oo08D03?oonfX5oooR00Gooo]Z1?mEo`000ol0]_oo0?o_o`3ok`02o`3ok`Cooo]Z
1?l0@_l8oookJP03oomd0?ooh`3oon<000Coon<00ooo0543omGo00Co0?So00?onOl0ool0T?oo0900
1ooo090:oookJPko0?lH1?oonfX=ool0T0Co0?So0ooEo`02oookJP03ool0DOooh`3oon<000Coon<0
0_ooM006oookJPGo04;o0ooonfX5o`3ok`03o`2foomEo`3oEOl000;oEOl01?oonfX5oooR00cooo]Z
00?oo`25ool0l_oo0?800_oo0?83oookJP?oK`3o0ooo^P04o`3oH0;ooo]Z0_oo06L5oookJP?oo`2_
5ooonfX2o`3o2GWooo]Z001MoookJP;o0?l96?oonfX3ool0[`Gooo]Z0_oo06L3oookJP;o0?mP1?oo
^P03ofl0o`Cooo]Z00Coon@0ool0l_oo0?;oo`253OoonfX4oooR00Gooo]Z1?mEo`0;o`0?o`?o04;o
1ooonfX00ooob@3oog@0o`0?o`0>o`0?o`So0?n]1_oo0003oiCo00Goo`004_oo0903ooWo00;oogT0
00?onOl0o`3hool0n?l00_l0n?l00ol0oegoiOl0onGo0002onGo0003o`3oGOooh`3oon<000Coon<0
0oooM002ooo900Cooo]Z1Ol0@_l2oookJPKo0?o_0_l0]_l4oeGo00Cooo]Z1?oohP0<oookJP?oo`25
0_oo:004oookJP?oK`3o0ooo^P03o`3oH0?ooo]Z0_oo06L4oookJP04ool0[ooo003oo`2_ool0[aOo
oo]Z00?o0?l9ool00?l0o`T0dooonfX3o`3o2ASooo]Z0_oo0:l6oookJP04ool0Iooonf[ooo]Zoook
JP?o0?mP0ooo^P03ofl0o`Cooo]Z00?oon@0ool0l_oo0?800_oo08D<oookJPGoon801OoonfX3oeGo
00;o0;Ko1Ol0onl3oookJP03ool0@Ol0@_oo04;o00;o04;o2?oonfX2oomd00Koon<00_oo0545omGo
00;o0?So1_oio`0Qool0T0GonOl01?l0n?l3omGo00;ooo]Z00?oo`1AoooS0?ooh`001?ooh`03oomd
00Kooo]Z1Ol0@_l00ooo047ooo]ZoookJP05o`3ok`;o0;Ko1OmEo`04oookJPCoon803?oonfX2ool0
Q@?oo`3b0ooonfX4ofl0o`?ookX00ol0of02oookJP?oo`1W1?oonfX3ool0[aSooo]Z0_l0o`Ujoook
JP00GOoonfX3o`3o2ASooo]Z0ooo0:l5oookJP?oo`1W0_oonfX2o`3oH0CookX000?ooo]Zofl0oom_
0?l01?oonfX01?ooi03oo`3bool0l_oo08D>oookJPCoon801OoonfX4oeGo00So00oo0_l0ojd00ooo
047o0?ono`3ooP0:o`3ooPco00oo2Ol0ojd00ooo003oU?l0oiCo0006oiCo00Goo`2@00Koo`00oolX
0?oo:03oobP0o`3oo_oo0003ool0T0?onOl00_m4o`04ooWo00GoogT01Ol0oed8oooS00;oog@000?o
iOl0oookJ_oob@001?oob@000ooonf[o04;oo`12o`03o`12o`03ool0@Ooonf[ooo]Z00Go0?o_0_l0
]_l5oeGo00;o05oo0_oonfX4oooR00cooo]Z0ooo08D2oolX0003ool0l_oonf[ooo]Z00;ooo]Z00?o
K`3oooo90?oob@000_oo^P001?l0]ooo0?mPo`3oH?l0of02oookJP;oo`1W00?oo`00oookJ_oonfX0
0_oonfX2ool000;oo`2_5ooonfX00ol0o`Woo`00o`3o2@3EoookJP;o0?l96OoonfX2ool0[`Kooo]Z
0_oo06L2oookJP?o0?mP0ooo^P001?oonf[oK`3oofl0oom_0?l3oookJP05oooT0?oo0?;oo`3bool0
l_oo08D03OoonfX4oooR00Gooo]Z1?mEo`000ol0]_oo0?o_o`3ok`04o`3ok`?ooo]Z0_oo0444o`12
o`Wooo]Z0_ooM007oooS0003ool0DOoonf[oeOl000SoeOl000?o0?SoooWo0?oio`001?oio`0@ool0
T0WonOl01ooEo`000ooonf[oo`1Aool0D@07oooS00;oog@02OoonfX4o`12o`;oo`110_oonfX5o`3o
k`;o0;Ko1OmEo`04oookJP?oon803OoonfX2ool0Q@?oo`3b1?oonfX3ofl0o`?ookX000?o0;Ooo`3o
H?l0of000ooonfX2ool0I`Gooo]Z0ooo0:lHoookJP;o0?l9NooonfX005kooo]Z0ol0o`THoookJP?o
o`2_1OoonfX3ool0I`;ooo]Z0_l0of001Ol0]ooookX0oonj0?oo^P3ooo]Z00?oK`3o1?oonfX3ool0
lP03ool0QOoonf[ooo]Z00cooo]Z1?oohP05oookJP03oeGo0?oonf[oEOl000;oEOl01Ol03ol5o`3o
[@co0?on3Ol03ol6o`3o[@WoU?l000?oeOl0oolX0?oo:0001_oo:0000ol0ooko0?Soo`3ho`02o`3h
o`GoA?l000?o05oooomi0?ooN@001_ooN@08oooS0003oomi0?ooM03oiOl000GoiOl01?oob@04o`12
o`?o0?l<0_oonfX5o`3ok`;o0;Ko1OmEo`001?l0Gooooo]ZoookJ_oonfX4oooR00gooo]Z0_oo08D2
oolX0003ool0l_oonf[ooo]Z00;ooo]Z00?oK`3oooo90?oob@000ooo^P04o`3oH0;ooo]Z0_oo06L0
0ooonf[oo`00oookJP02oookJP03ool00?oo0:ooo`2_01Sooo]Z00?o0?l9ool00?l0o`T0eooonfX2
o`3o2AWooo]Z0ooo0:l5oookJP;oo`1W0_oonfX3o`3oH004oookJ_oo^P3ookX0oookJP?oK`3o1?oo
nfX3ool0lP03ool0QOoonf[ooo]Z00cooo]Z1?oohP05oookJPGoEOl000?o0;Koo`3okol0onl00ol0
onl3oookJP?oo`111Ol0@_l9oookJP?oog@01oooh`05ool0D@[oeOl000?o0?SoooWo0?oio`001Ooi
o`07o`3ho`SoeOl01?oo0548oooS00;oog@00_oo05L8oookJPGo04;o0ooo0442oookJPGo0?o_00?o
0;KooeGo0?mEo`001?mEo`04oookJP?oon803_oonfX01Ooo08Goo`3bool0l_oo0?;oon@000Cooo]Z
0om_0?l2oonj0004o`2gool0of3o0?mPo`3oH0;ooo]Z0ooo06L5oookJP;oo`2_6OoonfX2o`3o2Gco
oo]Z001OoookJP?o0?l96?oonfX3ool0[`Gooo]Z0ooo06L2oookJP?o0?mP1?oo^P03ofl0o`Cooo]Z
1?oo0?8?oookJPCoon801?oonfX6oeGo00;o00oo00Co0?n]o`0?ool03ooo00oo1?l0ojd<o`3ooPSo
00oo0ol0ojd5o`0?o`?o0?n]1onDo`09oolX0003o`3oo_oEo`3oA?l000OoA?l00_ooN@0:oooS0004
odCo0?ooM03oog@0o`3oG@WoiOl01Ol0@_l3o`3o30;ooo]Z1Ol0onl00ol0Gooo0;KooeGo0004oeGo
00Gooo]Z1OoohP07oookJP03oolX0?oonf[ooo]Z00;ooo]Z0ooo08D00ooo:03oo`3bool0lP03oook
JP;oK`3o00?oolT0oookJ_oo^P000_oo^P04o`3oH003oookJ_oo06Ooo`1W00;ooo]Z0ooo00001?oo
0:ooo`00ool0[ooo0:lHoookJP03o`3o2Ooo003o0?l90=Wooo]Z0_l0o`TIoookJP?oo`2_1OoonfX2
ool0I`;ooo]Z1?l0of03oonj0003oookJ_m_0?ooK`3o00Cooo]Z1?oo0?800ooo08Gooo]ZoookJP0=
oookJP?oon801?oonfX6oeGo00;o0;Ko1Ol0onl2oookJP?oo`111_l0@_l;oookJP;oog@02_ooh`0;
ool0D@_oeOl01ooo054:oooS00;oog@02_oonfX6o`12o`?oo`110_oonfX5o`3ok`;o0;Ko1OmEo`04
oookJPGoon803OoonfX2ool0Q@?oo`3b1?oonfX3ofl0o`?ookX000Co0;Ooo`3oH?l0of3o0?mP0_oo
nfX2ool0I`Gooo]Z0ooo0:lIoookJP;o0?l9OOoonfX0067ooo]Z0_l0o`THoookJP?oo`2_1OoonfX3
ool0I`;ooo]Z0ol0of001?l0]ooookX0oonj0?oo^P03ofl0o`Cooo]Z00Goon@0ool0l_oo0?;oo`3b
ool0Q@0?oookJPCoon801OoonfX5oeGo00Co0?n]0ol03ol3o`3o[@[o0?on0_m4o`06o`0?o`So0?n]
0ol03ol7o`3o[@GoU?l04?oo:002oooS00?oA?l00oooN@06o`3oG@Co0?l<1ol0@_l00ol0o`coolT0
ooo90002ooo90003oookJ_l0onoo0?o_00;o0?o_00?oo`26o`2foooob@000ooUo`02oeGo00Cooo]Z
1_oohP08oookJP;oobP00ooonfX2ool0Q@;oobP00_nDo`03oookJP03ofl0oooob@3oolT000?ookX0
00?o0;Ooo`3oH?l0of000_l0of000ooonf[oo`1Wool0I`02oookJPGoo`0000?oo`2_oookJ_oonfX0
5ooonfX2ool00003o`3o2Ooonf[ooo]Z0=Wooo]Z0_l0o`TIoookJP?oo`2_1OoonfX3ool0I`03oook
J_l0of3o0?mP00;o0?mP00Co0;Oooonj0?oo^P3ooo]Z0om_0?l3oookJP05oooT0?oo0?;oo`3bool0
l_oo08D04?oonfX3oooR00Gooo]Z1OmEo`02o`2fo`03ool0Q_l0onoo0?o_00;o0?o_0ooonfX3ool0
@@Oo04;o2_oonfX7oomd027oon<01OooM00:oookJPOo04;o0ooo0443oookJPGo0?o_0_l0]_l5oeGo
00Gooo]Z1OoohP0=oookJP;oo`251?oo0?83oookJP?oK`3o0ooo^P000ol0]ooo0?mPo`3oH002o`3o
H0;ooo]Z00?oo`1WoookJ_oonfX01?oonfX2ool0[aWooo]Z0ol0o`UnoookJP00H_oonfX2o`3o2ASo
oo]Z0ooo0:l5oookJP?oo`1W0ooonfX2o`3oH0;o0;Oo0_oo^P03ofl0o`Cooo]Z00?oon@0ool0l_oo
0?800_oo0?8@oookJPCoon801OoonfX00ol03oooEOl0oeGo0003oeGo00Co0?n]0_l03ol00ol0ojgo
U?l0oiCo000:o`3ooP;oA?l00ol03ol3odCo00Ko0?n]2OnDo`001?oo:03o0?n]o`3o[Ol0ojd2oolX
00OoU?l00oooh`08o`3ooPKoogT01_l0oed8o`12o`03ooo90?oUo`3oiOl000;oolT00_l0onl3ool0
0003ool0Q_l0]_ooolT000?oiOl00omEo`04oookJPGoon802_oonfX4oolX00;oo`250_oo:002oiCo
00?ooo]Z00?oK`3oooo90?oob@001?oo^P04o`3oH004oookJ_oo06Ooo`1Wool0I`;ooo]Z1ooo000H
oookJP03ool00?l0o`Wooo]Z0=gooo]Z0_l0o`TIoookJP?oo`2_1OoonfX3ool0I`;ooo]Z0ol0of00
1?l0]ooookX0oonj0?oonfX3ofl0o`?ooo]Z0_ooi003ool0lP03ool0QOoonf[ooo]Z00kooo]Z0ooo
hP06oookJPGoEOl00_l0]_l00ooo08Ko0?o_o`3ok`02o`3ok`Gooo]Z0_oo0446o`12o`oooo]Z2?oo
M00?oooS00Woog@000?o0000oookJ_oonfX02?oonfX8o`12o`?oo`110ooonfX4o`3ok`03ool0Q_l0
]_oo0;Ko00KoEOl01OoonfX4oooR00oooo]Z00?oo`25ool0l_oo0?800_oo0?84oookJP?oK`3o0ooo
^P001?l0]ooo0?mPo`3oH?l0of02oookJP;oo`1W1_oonfX2ool0[aWooo]Z0_l0o`V0oookJP00Hooo
nfX2o`3o2ASooo]Z0ooo0:l6oookJP?oo`1W0_oonfX3o`3oH003o`2goooo^P3ookX000CoK`3o1?oo
nfX01Oooi03oo`3bool0l_oo0?;oo`25013ooo]Z1?oohP04oookJP03o`0?oooonf[ooo]Z00CoEOl0
1?l0ojd3o`0?o`;oU?l01_l0ooh2odCo00Co0?on00?o00ooodCo0?m4o`001?ooN@03o`3o[@;oogT0
1onDo`000ol0ookoobP0oolX0007oolX0003o`3oo_m4o`3oA?l000SoA?l02OooN@000ol0/?oo04;o
o`12o`06o`12o`Co0?l<00CoolT0onGo0?oUo`3oiOl01?oo00000ooo08Ko0;Koo`3o3003onGo00?o
EOl01?oonfX5oooR00cooo]Z1_oo:003oiCo00Cooo]Z0_oob@001Ooonf[ookX0oonj0?oo^P3o0;Oo
00?o0?mP00Cooo]Zool0Iooo06Ooo`1W1?oonfX8ool001Kooo]Z00?oo`00o`3o2OoonfX0gooonfX2
o`3o2AWooo]Z0ooo0:l6oookJP;oo`1W0_oonfX3o`3oH004o`2goooo^P3ookX0oookJP?oK`3o1?oo
nfX01?ooi03oo`3bool0l_oo0?82ool0QA3ooo]Z1?oohP06oookJPCoEOl00ol0]_l00ooo08Ko0?o_
o`3ok`03o`3ok`Gooo]Z0_oo0448o`12oa7ooo]Z0_l007l7oomd00?ooo]Z0ol007l6oookJPKo0000
0ooonfX9o`12o`?oo`110ooonfX5o`3ok`04ool0Q_l0]_oo0;Koo`2fo`GoEOl01OoonfX5oooR00oo
oo]Z00?oo`25ool0l_oo0?800_oo0?84oookJP?oK`3o0ooo^P001?l0]ooo0?mPo`3oH?l0of02oook
JP?oo`1W1OoonfX3ool0[aWooo]Z0_l0o`V1oookJP00HooonfX3o`3o2ASooo]Z1?oo0:l5oookJP?o
o`1W0ooonfX2o`3oH004o`2goooo^P3ookX0oonj00?oK`3o1OoonfX4ool0lP03ool0QOoonf[ooo]Z
00kooo]Z1?oohP07oookJP04o`2foomEo`3oEOl0oeGo00;o0?n]0onDo`001?l03ooo0?n]o`3o[OnD
o`03o`3ooP03oolX0?m4o`3oA?l000CoA?l01?l0ooh4odCo0004oomi0?l0ojgoogT0oomi00?ooo]Z
1?nDo`001?oonf[o001oo`3oo_l0ooh6oolX0003o`3oo_m4o`3oA?l000SoA?l000Gooo]Zo`2`ool0
/?oo0;3oo`12o`04oomi00Go04;o00Coo`00o`3oGOl0oegoo`000ol0o``5onGo00;oolT00_l0o``3
onGo00?oEOl01OoonfX2oooR00?oogT02OoonfX2oomi00;ooo]Z1Ooo:002oiCo00Gooo]Z00?oK`3o
o`3o3?l0o``01?oo^P03o`3oH0;ooo]Z0ooo06L4oookJP[oo`005?oonfX00ooo003o0?l9oookJP3Q
oookJP;o0?l96OoonfX4ool0[`Gooo]Z0ooo06L2oookJP;o0?mP00Cooo]Zoonj0?oo^P3ookX01?m_
0?l4oookJP04oooT0?oo0?;oo`3bool0lP;oo`254?oonfX4oooR00Oooo]Z1?mEo`02o`2fo`;oo`26
1_l0onl4oookJPCoo`113?l0@_l8oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o0000
2ol0@_l3ool0@@Cooo]Z1Ol0onl00ooo08Ko0;Koo`2fo`06oeGo00Kooo]Z1OoohP0?oookJP03ool0
QOoo0?;oo`3b00;oo`3b1OoonfX2ofl0o`CookX00ol0of03oookJP?oo`1W1OoonfX2ool0[a[ooo]Z
0_l0o`V2oookJP00I?oonfX3o`3o2AWooo]Z0ooo0:l6oookJP;oo`1W0ooonfX2o`3oH0;o0;Oo0_oo
^P04ofl0o`Cooo]Z1Ooo0?800ooo08Gooo]ZoookJP0=oookJPKoon801ooonfX00ol0ojgoEOl0oeGo
0002oeGo00CoU?l00ol0ojd01?l0ookoU?l0oiCo0?oo:007odCo0003oomi0?l0ooko0?on00;oogT0
1Om4o`05oomi0003oiCo0?ooN@3o001o00;o001o00Cooo]Zo`3oo_l0ooko0?on0_oo:0000ol0ooko
04;oo`12o`04o`12o`CoA?l01Ol0@_l5o`2`o`?oo`001?l0oed2ool000[oiOl00ol0oed7oookJP04
oooR0?ooN@3oogT0oomi00Wooo]Z0_nDo`03oomi0003oookJ_oo:03oobP000;oobP00_nDo`03oolX
00;ooo]Z00?oK`3oo`3o3?l0o``01?oo^P000ol0]ooo0?mPo`3oH002oookJP?oo`1W1OoonfX9ool0
01Cooo]Z0_oo003ToookJP?o0?l96_oonfX3ool0[`Gooo]Z0ooo06L3oookJP;o0?mP00Co0;Oooonj
0?oo^P3ooo]Z1?m_0?l4oookJPCoo`3b00?oo`25oookJ_oonfX03_oonfX6oooR00Oooo]Z1?mEo`02
o`2fo`;oo`261_l0onl4oookJPGoo`114Ol0@_l2o`00O`?ooo]Z0ol007lAo`12o`Koo`111OoonfX7
o`3ok`?o0;Ko1_mEo`06oookJPGoon804?oonfX2ool0Q@;oo`3b0_ooi004oookJP?oK`3o0ooo^P00
1?l0]ooo0?mPo`3oH?l0of02oookJP?oo`1W1OoonfX2ool0[a_ooo]Z0_l0o`V3oookJP00IOoonfX3
o`3o2AWooo]Z0ooo0:l6oookJP?oo`1W0_oonfX3o`3oH004o`2goooo^P3ookX0oonj00CoK`3o0ooo
nfX5ool0lP;oo`254?oonfX6oooR00Gooo]Z00?o0?n]oookJ_oonfX01?mEo`04oiCo00?o0?n]1?nD
o`03odCo0003oookJ_ooN@3oogT000OoogT000Co04;oodCo0?m4o`3oA?l01?l0@_l5oomi00?o04;o
0_l0ooh7o`12o`So0;3o0_l0Gol01?l0/?ooo`00ool00?oo0006o`3oG@03ool00?oUo`3oiOl000Co
iOl01Ol0oed00ooob@3ooo]ZoookJP04oookJP05oooR0?ooN@3oogT0oomi0?oohP002_oonfX3oiCo
00?oogT00ooo:0000onDo`3o0?n]o`3o[@04oolX0003ofl0ool0o`co0?l<00GookX00ol0of000ooo
nf[oo`1Wool0I`02ool0I`Gooo]Z1ooo000AoookJP03ool00?oonf[ooo]Z00;ooo]Z00?oo`00o`3o
2OoonfX0iOoonfX3o`3o2A[ooo]Z0ooo0:l5oookJP?oo`1W0ooonfX2o`3oH0;o0;Oo0_oo^P001?oo
nf[oK`3oofl0oom_0?l4oookJPGoo`3b00?oo`25oookJ_oonfX03ooonfX5oooR00Sooo]Z1?mEo`03
o`2fo`03ool0Q_l0onoo0?o_00Oo0?o_1_oonfX6ool0@AWo04;o2_oo0445oookJPOo0?o_1?l0]_l6
oeGo00Oooo]Z1OoohP0@oookJP;oo`250ooo0?800oooi03ooo]ZoookJP02oookJP?oK`3o1?oo^P03
o`3oH0;ooo]Z1?oo06L5oookJP;oo`2_6ooonfX2o`3o2HCooo]Z001VoookJP?o0?l96_oonfX2ool0
[`Kooo]Z0ooo06L2oookJP?o0?mP0_l0]ol3oonj00?oK`3o1?oonfX5ool0lP03ool0QOoonf[ooo]Z
013ooo]Z1_oohP08oookJPGoEOl00ooo:0001?l0ojgoobP0oolX0?oo:002oiCo0003odCo0?nDo`3o
obP000;oobP01_ooN@03oookJQGoo`111_l0/?l5o`1Oo`;oo`002?l0oed2onGo00Go0?mM0ooUo`04
ooo900;ooo]Z0om4o`000oooN@3oon80oookJP0;oookJPGoU?l000?oo`25oolX0?oo:0000ol0ojd7
oolX00GookX00ol0of02oookJP?oo`1W1_oonfX00ooo0:ooo`00ool00003ool001?ooo]Z00Koo`00
oookJ_oonf[ooo]Zool00?l0o`WXoookJP?o0?l96_oonfX3ool0[`Gooo]Z00?oo`1WoookJ_oo06L0
0ooonfX2o`3oH003oookJ_l0]ooookX000;ookX000Cooo]Zofl0oom_0?ooK`3o1?oonfX5ool0lP03
ool0QOoonf[ooo]Z013ooo]Z1OoohP08oookJPGoEOl00ol0]_l<o`3ok`Sooo]Z6?oo0442oookJPCo
00000_oonfX8o`3ok`Go0;Ko1_mEo`08oookJPGoon804?oonfX3ool0Q@?oo`3b1OoonfX3ofl0o`Go
okX00ol0of02oookJP?oo`1W1OoonfX3ool0[a[ooo]Z0ol0o`V5oookJP00IooonfX3o`3o2A[ooo]Z
0_oo0:l6oookJPCoo`1W0_oonfX3o`3oH005o`2goooo^P3ookX0oonj0?oonfX00om_0?l5oookJPCo
o`3b00?oo`25oookJ_oonfX04OoonfX6oooR00Oooo]Z00?oU?l0oeGo0?mEo`001OmEo`04oolX00;o
0?o_0_nDo`02o`3ok`03oolX0?ooN@3oogT000;oogT01OoonfX6o`00O`?ooo]Z0ol007l3oookJP?o
001o0_oonfX3o`3ok`Oo05oo2ol0oed5o`1Oo`GoiOl00ooob@02odCo00?oon802OoonfX2odCo00;o
oo]Z1onDo`02o`3o[@OoobP000?o0?l<oonj0?oo^P000ooo^P03o`3oH0;ooo]Z0_oo06L00ooonf[o
o`1WoookJP05oookJP03ool0[ooo003oo`0000;oo`005?oonfX3ool00003oookJ_oo003o0?l90>[o
oo]Z0ol0o`TJoookJP?oo`2_1OoonfX01?oo06Oooo]Zool0Iooo06L3oookJP;o0?mP00Gooo]Zo`2g
oooo^P3ookX0oookJP04ofl0o`Cooo]Z00Goon@0ool0l_oo0?;oo`3bool0Q@0CoookJPKoon802?oo
nfX7oeGo00Co0;Ko2ol0onl5oookJPKo001o0ooonfX3o`00O`?ooo]Z0ol007l3oookJP_o0?o_1_l0
]_l8oeGo00Oooo]Z1ooohP0@oookJP?oo`250ooo0?85oookJP?oK`3o1Ooo^P03o`3oH0;ooo]Z1?oo
06L5oookJP;oo`2_6ooonfX3o`3o2HKooo]Z001XoookJP?o0?l96_oonfX3ool0[`Gooo]Z1?oo06L3
oookJP?o0?mP1?oo^P04ofl0o`Gooo]Z0ooo0?82ool0QACooo]Z1_oohP05oookJP03oiCo0?oonf[o
oo]Z00SoEOl01_l0]_l3ool0QP03o`3okoooN@3oobP000;oobP05ol0onl9o`1Oo`Co0?mM1ol0Gol:
onGo0003odCo0?ooN@3oogT000;oon802OoonfX2o`3o[@?oA?l000?ooo]ZoiCo0?nDo`000onDo`03
o`3o[@GoobP000CoolT0o`3o3?l0o`coolT01?oo^P03o`3oH0?ooo]Z1?oo06L5oookJP;oo`2_0_oo
000FoookJPGoo`0000?o0?l9oookJ_oonfX0j_oonfX3o`3o2A[ooo]Z1?oo0:l4oookJP;oo`1W00?o
oo]Zool0IooonfX00_oonfX3o`3oH004o`2goooo^P3ookX0oonj00GoK`3o1?oonfX4ool0lP03ool0
QOoonf[ooo]Z01;ooo]Z1_oohP08oookJPWoEOl01_l0]_l2ool0QR?o0?o_1Ol0]_l8oeGo00Sooo]Z
2?oohP0AoookJP;oo`251?oo0?800oooi03ooo]ZoookJP02oookJP?oK`3o00?ooo]Zoonj0?oo^P00
0_oo^P03o`3oH0?ooo]Z0ooo06L5oookJP?oo`2_6ooonfX3o`3o2HOooo]Z001YoookJP?o0?l96_oo
nfX3ool0[`Kooo]Z1?oo06L2oookJP?o0?mP1Ooo^P04ofl0o`Gooo]Z1?oo0?800ooo08Gooo]Zoook
JP0CoookJPKoon802_oonfX;oeGo00[o0;Ko4?l0onl@o`1Oo`Oo0?mM0_oUo`000ol0o`coogT0odCo
0003odCo00GoogT02_oonfX3o`3o[@;oA?l01?nDo`03o`3o[@?oU?l00_oo:0001OooN@3oolT0o`3o
3?l0o`co0;3o00CookX000CoolT0o`3oH?l0of3o0?mP0_oonfX2ool0I`03oookJ_oo06Oooo]Z00Co
oo]Z0ooo0:l00ooo003ooo]ZoookJP0EoookJPOoo`00kOoonfX3o`3o2A[ooo]Z1?oo0:l5oookJPCo
o`1W0_oonfX4o`3oH0CookX01Om_0?l4oookJPCoo`3b00?oo`25oookJ_oonfX05?oonfX5oooR00_o
oo]Z2_mEo`0:o`2foa7o0?o_1ol0]_l;oeGo00Sooo]Z2?oohP0CoookJP03ool0QOoo0?;oo`3b00?o
o`3b00?oon@0oookJ_oonfX00_oonfX4ofl0o`?ookX000Co0;Ooo`3oH?l0of3o0?mP0ooonfX4ool0
I`Cooo]Z1?oo0:lJoookJPCo0?l9R?oonfX006[ooo]Z0ol0o`TJoookJPCoo`2_1_oonfX3ool0I`?o
oo]Z0ol0of05oonj00CoK`3o1?oonfX5ool0lP03ool0QOoonf[ooo]Z01Cooo]Z1ooohP08oookJP03
oolX0?mEo`3oEOl0013oEOl02?l0]_l6oeGo00oo05oo2_l0oed3o`3o3003odCo0?l0ooko0?on00;o
0?on1_ooN@08oookJPGo0?n]0onDo`02o`3o[@?o00oo0onDo`04oomi0003o`2`oooo^P3ookX000;o
okX01?l0of02oookJP;oo`1W00?ooo]Zooo90?oob@001OoonfX3ool0[aWooo]Z2?oo003]oookJP?o
0?l96_oonfX4ool0[`Kooo]Z0ooo06L3oookJP?o0?mP00?o0;Oooonj0?oo^P000_oo^P04ofl0o`Co
oo]Z1Ooo0?82ool0QAKooo]Z1_oohP0:oookJQ7oEOl02?l0]_lBoeGo00kooo]Z2?oohP0CoookJP;o
o`251Ooo0?801?ooi03ooo]ZoookJ_oonfX5ofl0o`?ookX000Co0;Ooo`3oH?l0of3o0?mP0ooonfX5
ool0I`Cooo]Z0ooo0:lKoookJP?o0?l9R_oonfX006_ooo]Z0ol0o`TKoookJP?oo`2_1_oonfX4ool0
I`;ooo]Z1?l0of04oonj0003oookJ_m_0?ooK`3o00;oK`3o1?oonfX6ool0lQSooo]Z1ooohP0?oook
JQGoEOl04?l0Gol3o`2`o`Oo0?mM1?l0ooh:oomi00?ooo]Z0_l0ooh00ooonf[o0?n]o`3o[@07o`3o
[@?o00oo1onDo`02o`2`o`CookX01?l0of02oookJP;oo`1W00?ooo]Zooo90?oob@001OoonfX3ool0
[a[ooo]Z2_oo003]oookJPCo0?l96_oonfX4ool0[`Kooo]Z0ooo06L2oookJPCo0?mP00?o0;Oooonj
0?oo^P000_oo^P04ofl0o`Cooo]Z1_oo0?800ooo08Gooo]ZoookJP0FoookJPKoon803ooonfXIoeGo
00Gooo]Z1?l0000:oookJPSoon805OoonfX00ooo08Goo`3bool0lP03ool0lP03oooT0?oonf[ooo]Z
00;ooo]Z1?m_0?l00ooonf[ookX0oonj0002oonj00?o0?mP0ooonfX5ool0I`Cooo]Z0ooo0:lLoook
JP?o0?l9RooonfX006cooo]Z0ol0o`TLoookJP?oo`2_1_oonfX3ool0I`;ooo]Z1Ol0of001Ol0]ooo
okX0oonj0?oo^P3ooo]Z00CoK`3o1?oonfX00oooi03oo`3bool0lP03ool0lP03ool0QOoonf[ooo]Z
01Sooo]Z1ooohP0ToookJP_o05oo0ol0/?l5o`3ooPGoA?l00_ooN@09oookJP;o00oo0ol0ooh7o`3o
[@?o00oo1onDo`03ooo900CookX01Ol0of001?oonf[oo`1Wool0Iooo06L2ooo900Gooo]Z1?oo0:lJ
oookJPWoo`00l?oonfX4o`3o2A_ooo]Z0ooo0:l7oookJP;oo`1W0_oonfX5o`3oH003o`2goooo^P3o
okX000;ookX01?m_0?l4oookJP03oooT0?oo0?;oo`3b00?oo`3b0_oo08DIoookJPSoon809ooonfX4
o`0000Gooo]Z2?oohP0HoookJP03ool0QOoo0?;oo`3b00;oo`3b00?oon@0oookJ_oonfX00ooonfX5
ofl0o`CookX01?l0of02oookJPGoo`1W1?oonfX4ool0[a_ooo]Z0ol0o`V=oookJP00KOoonfX3o`3o
2Acooo]Z0ooo0:l6oookJPCoo`1W0_oonfX5o`3oH004o`2goooo^P3ookX0oonj00CoK`3o1_oonfX6
ool0lP03ool0QOoonf[ooo]Z01_ooo]Z2ooohP0KoookJPKo0?on1?l0Gol3o`3ooP_oA?l02OoonfX3
o`0?o`;o0?on1Ol0ojd3o`0?o`;o0?n]0onDo`02o`3o3004o`2`oooob@3oolT0ooo900?ookX000?o
0?l<o`3oH?l0of000ol0of001?oonf[oo`1Wool0Iooo06L2ooo900Gooo]Z1?oo0:lKoookJPOoo`00
m?oonfX4o`3o2Acooo]Z0_oo0:l7oookJP?oo`1W0_oonfX5o`3oH003o`2goooo^P3ookX000;ookX0
1?m_0?l5oookJPKoo`3b0_oo08DLoookJP_oon807OoonfX<oooR01_ooo]Z00?oo`25ool0l_oo0?80
0ooo0?86oookJPGoK`3o0ooo^P000ol0]ooo0?mPo`3oH002o`3oH0;ooo]Z1?oo06L6oookJP?oo`2_
7?oonfX3o`3o2Hkooo]Z001^oookJP03o`3o2Ooonf[o0?l901gooo]Z0_oo0:l6oookJPGoo`1W0_oo
nfX4o`3oH003o`2goooo^P3ookX000;ookX01Om_0?l5oookJPOoo`3b00?oo`25oookJ_oonfX07?oo
nfXAoooR00Wooo]Z1_oohP0?o`3ooP_oA?l00_oUo`05oookJPGo00oo1?l0ojd3o`0?o`Go0?n]1?m4
o`000ol0/?ooolT0ooo90004oonj00Co0?mP0_oonfX2ool0I`?oolT01OoonfX5ool0[acooo]Z1Ooo
003goookJPCo0?l97?oonfX3ool0[`Kooo]Z1?oo06L2oookJPGo0?mP1?oo^P05ofl0o`Gooo]Z1ooo
0?800ooo08Gooo]ZoookJP0LoookJQ7oon802OoonfXAoooR01gooo]Z00?oo`25ool0l_oo0?801?oo
0?85oookJPGoK`3o1?oo^P001?l0]ooo0?mPo`3oH?l0of03oookJPCoo`1W1_oonfX4ool0[acooo]Z
0ol0o`V?oookJP00KooonfX00ol0o`Wooo]Zo`3o2@0MoookJP?oo`2_1_oonfX5ool0I`?ooo]Z0ol0
of000ol0]ooookX0oonj0002oonj0003oookJ_m_0?ooK`3o00;oK`3o1OoonfX00oooi03oo`3bool0
lP04ool0lP;oo`259?oonfXFoooR013o0?on2OoonfX4onGo00?ooo]Z2ol03ol9o`3o[@04o`2`ool0
o`coolT0ooo900CookX01?l0of02oookJP;oo`1W0_l0o``6oookJPGoo`2_7?oonfX00ol0o`Woo`00
ool00002ool00?[ooo]Z1?l0o`TMoookJP?oo`2_1_oonfX4ool0I`?ooo]Z1?l0of05oonj00CoK`3o
1_oonfX6ool0lP;oo`259?oonfXIoooR00?ooo]Z1?l0000KoookJP;oo`251_oo0?86oookJPGoK`3o
1?oo^P000ol0]ooo0?mPo`3oH002o`3oH0;ooo]Z1?oo06L6oookJPCoo`2_7?oonfX4o`3o2I3ooo]Z
001`oookJP?o0?l97OoonfX4ool0[`Kooo]Z1Ooo06L3oookJP?o0?mP0_l0]ol3oonj00;ooo]Z0om_
0?l6oookJP;oon@01Ooo0?82ool0QCgooo]Z0ol00007o`3ooP;o0?mM1_oonfX5onGo00;ooo]Z2Ol0
3ol7o`3o[@Ko0?l<0_oo^P03ooo900Co0?mP0_oob@001?oonf[o0?l<o`3o3?l0o``6oookJPKoo`2_
7?oonfX00ol0o`Woo`00ool0003noookJPCo0?l97OoonfX3ool0[`Oooo]Z1?oo06L3oookJPCo0?mP
00?o0;Oooonj0?oo^P000_oo^P001?oonf[oK`3oofl0oom_0?l7oookJP03oooT0?oo0?;oo`3b00?o
o`3b0_oo08DmoookJPGo00005ooonfX2ool0Q@Koo`3b00?oon@0oookJ_oonfX00ooonfX5ofl0o`Go
okX000?o0;Ooo`3oH?l0of000_l0of03oookJP?oo`1W1_oonfX5ool0[acooo]Z1?l0o`VAoookJP00
LOoonfX4o`3o2Agooo]Z1?oo0:l7oookJPCoo`1W0_oonfX4o`3oH0;o0;Oo1?oo^P001?oonf[oK`3o
ofl0oom_0?l8oookJPGoo`3b0ooo08DjoookJPCo00001?oonfX4o`3oG@Cooo]Z1ooUo`0;o`0?o`Co
0?on0_l0/?l5o`3o3004oonj0?oob@3oolT0ooo900?o0?mP0_ooN@03ooo900;o0?l<00?oolT0oook
J_oonfX01?oonfX6ool0[acooo]Z0_l0o`T00ooo003o0?l9oookJP3ooookJPCo0?l97_oonfX3ool0
[`Oooo]Z1?oo06L2oookJPCo0?mP0_l0]ol4oonj0003oookJ_m_0?ooK`3o00;oK`3o2?oonfX5ool0
lP;oo`25>_oonfX4o`0001Cooo]Z0ooo08D7ool0lPGooo]Z1Om_0?l00ooonf[ookX0oonj0002oonj
0003o`2gool0of3o0?mP00?o0?mP0_oonfX4ool0I`Kooo]Z1Ooo0:lLoookJPGo0?l9T_oonfX007?o
oo]Z0ol0o`TNoookJP?oo`2_2?oonfX4ool0I`;ooo]Z1?l0of000ol0]ooookX0oonj0003oonj0003
oookJ_m_0?ooK`3o00;oK`3o2?oonfX6ool0lP;oo`25=ooonfX2o`1Oo`;o00000_oonfX6o`3oG@;o
oo]Z1ooUo`09o`0?o`;oolT00ol03ol3o`3ooP05o`2`ool0o`co0?l<o`3o3?oo^P000ooob@000ol0
/?oo0?mPo`3oH003oomi00;oolT00ol0o``00ooob@3ooo]ZoookJP05oookJPCoo`2_7_oonfX4o`3o
2Ooooo]Z1?oonfX3o`3o2Aoooo]Z0ooo0:l7oookJPCoo`1W0_oonfX5o`3oH0GookX00_oonfX4ofl0
o`Oooo]Z00?oon@0ool0l_oo0?800ooo0?82ool0QCOooo]Z1?l0000@oookJP;oo`252Ooo0?86oook
JPGoK`3o00Gooo]Zoonj0?oo^P3ookX0o`2go`06o`3oH0;ooo]Z0ooo06L7oookJPCoo`2_7_oonfX5
o`3o2I?ooo]Z001doookJP?o0?l97ooonfX3ool0[`Oooo]Z1Ooo06L3oookJP?o0?mP00?o0;Oooonj
0?oo^P001?oo^P000ooonf[oK`3oofl0o`02ofl0o`Wooo]Z00?oon@0ool0l_oo0?800ooo0?82ool0
QC3ooo]Z1Ol0Gol2o`0000Wo0?mM1?oUo`000ol0oegoo`3bool0lP09o`0?o`?oolT00ol03ol2o`2`
o`;o0?l<1?oob@000ol0o`co0;3oo`3oH003oomi00?oolT00_l0o``3ooo900Kooo]Z1?oo0:lNoook
JPCo0?l9oooonfX7oookJPCo0?l97_oonfX4ool0[`Kooo]Z1Ooo06L3oookJPCo0?mP1_oo^P000ooo
nf[oK`3oofl0o`03ofl0o`Sooo]Z00?oon@0ool0l_oo0?800ooo0?82ool0QC?ooo]Z1?l0000=oook
JP03ool0QOoo0?;oo`3b00Ooo`3b1ooonfX5ofl0o`CookX00_l0]ol5o`3oH0;ooo]Z1?oo06L7oook
JPCoo`2_7_oonfX5o`3o2IGooo]Z001foookJP;o0?l97ooonfX4ool0[`Oooo]Z1Ooo06L3oookJPCo
0?mP00?o0;Oooonj0?oo^P001?oo^P06ofl0o`Sooo]Z00?oon@0ool0l_oo0?801?oo0?84ool0QBSo
oo]Z1ol0Gol00ol0003o0?mMo`3oG@08o`3oG@Koo`3b2?l03ol5ooo900;oogT00_l0/?l2ooo900Co
0?l<00Go0?mPoomi0?ooN@3oogT0o`3o3002ooo900;o0?l<0_l0/?l4ooo900Cooo]Z1?oo0:lOoook
JP?o0?l9oooonfX;oookJP?o0?l97_oonfX4ool0[`Oooo]Z1Ooo06L4oookJP?o0?mP00?o0;Oooonj
0?oo^P001?oo^P000ooonf[oK`3oofl0o`03ofl0o`Sooo]Z00?oon@0ool0l_oo0?801Ooo0?84ool0
QBcooo]Z1?l00007oookJP?oo`252?oo0?800oooi03ooo]ZoookJP06oookJPGoK`3o1Ooo^P000ol0
]ooo0?mPo`3oH003o`3oH0?ooo]Z1?oo06L7oookJPCoo`2_7ooonfX4o`3o2IOooo]Z001goookJP;o
0?l98?oonfX4ool0[`Sooo]Z1?oo06L3oookJPCo0?mP0_l0]ol5oonj00OoK`3o2?oonfX3oooT00So
o`3b1?oo08DOoookJPWo05oo1Ol0oed9ool0lP?oiOl00_l0o``4onGo00KoolT00oooN@04o`3o3003
o`2`ool0o`coA?l000;oA?l01Ol0o``3o`2`o`KoolT000?ooo]Zool0[ooo0:l00ooo0:lOoookJPCo
0?l9oooonfX=oookJP?o0?l97ooonfX4ool0[`Sooo]Z1?oo06L4oookJPCo0?mP00?o0;Oooonj0?oo
^P001?oo^P07ofl0o`Oooo]Z0oooi008ool0lPCoo`259_oonfX4o`0000;ooo]Z00?oo`25ool0l_oo
0?802?oo0?800oooi03ooo]ZoookJP07oookJPKoK`3o1Ooo^P02o`2go`Co0?mP0ooonfX5ool0I`Ko
oo]Z1Ooo0:lPoookJP?o0?l9VOoonfX007Sooo]Z0ol0o`TOoookJPGoo`2_2?oonfX4ool0I`Cooo]Z
1?l0of02o`2go`GookX01om_0?l:oookJP;oon@02ooo0?83ool0QAKooo]Z2?l0Gol<ool0lP?o0?mM
0ooUo`000ooonf[o0?l<o`3o3002o`3o3003oookJ_m_0?ooK`3o00GoolT01_ooN@000ol0/?ooA?l0
odCo0002odCo00Go0?l<0ol0/?l8ooo900Goo`2_8?oonfX3o`3o2Ooooo]Z4?oonfX3o`3o2Aoooo]Z
1Ooo0:l9oookJP?oo`1W1OoonfX4o`3oH0;o0;Oo1Ooo^P07ofl0o`Wooo]Z0_ooi00;ool0lP?oo`25
7ooonfX<ool0lP;oon@02OoonfX8ofl0o`GookX00_l0]ol4o`3oH0?ooo]Z1_oo06L6oookJPGoo`2_
8?oonfX4o`3o2I[ooo]Z001ioookJP?o0?l98?oonfX5ool0[`Sooo]Z1Ooo06L3oookJPKo0?mP00?o
0;Oooonj0?oo^P000ooo^P02oookJPKoK`3o2_oonfX3oooT01Goo`3b1?oo08DEool0lP?o0?mM0_l0
/?l4o`3oG@03oookJ_l0o`co0?l<00Co0?l<0_m4o`03ooo90003o`3o3?ooN@3oogT000CoogT00om4
o`000oooN@3o0?l<o`3o3003o`3o30?o0;3o2Ooob@04ool0[b7ooo]Z0ol0o`WooookJQ?ooo]Z1?l0
o`TOoookJPGoo`2_2OoonfX4ool0I`Cooo]Z1Ol0of02o`2go`GookX000?ooo]Zofl0oom_0?l01?m_
0?l;oookJP?oon@05?oo0?84ool0QAKoo`3b0_ooi00:oookJPSoK`3o1ooo^P000ol0]ooo0?mPo`3o
H002o`3oH0Cooo]Z1Ooo06L7oookJPCoo`2_8_oonfX3o`3o2Icooo]Z001joookJP?o0?l98_oonfX4
ool0[`Wooo]Z1Ooo06L3oookJPKo0?mP0_l0]ol5oonj0003oookJ_m_0?ooK`3o00GoK`3o3_oonfXT
ool0lP?o05oo00?o0000oookJ_oonfX01?l0/?l3o`3oG@Ko0?l<1?m4o`03o`3o30?oogT01?m4o`03
oomi00?o0?l<0ol0/?l3o`3o30GoolT000?ooo]Zool0[ooo0:l00ooo0:lQoookJPCo0?l9oooonfXE
oookJPCo0?l98OoonfX4ool0[`[ooo]Z1?oo06L4oookJPGo0?mP0ol0]ol5oonj00OoK`3o3_oonfXU
ool0lP;oon@000?o0000oookJ_oonfX01ooonfX8ofl0o`WookX01_l0of03oookJP?oo`1W00?ooo]Z
ool0Iooo06L01_oonfX5ool0[b;ooo]Z0ol0o`VNoookJP00O?oonfX2o`3o2B?ooo]Z1?oo0:l:oook
JPCoo`1W0ooonfX8o`3oH003o`2goooo^P3ookX000GookX000?ooo]Zofl0oom_0?l01_m_0?lDoook
JPSoon@02?oonfX;o`1Oo`03o`000?l0/?oo0;3o00Co0;3o0_l0ooh5o`3o30KoA?l000?o0;3ooomi
0?m4o`000om4o`03o`3ooPCoogT00ol0/?l7o`3o30?ooo]Z1Ooo0:lRoookJPCo0?l9oooonfXHoook
JP?o0?l98ooonfX3ool0[`[ooo]Z1?oo06L4oookJPOo0?mP0_l0]ol7oonj00SoK`3o5?oonfX8oooT
013ooo]Z1?l00005oookJPSoK`3o2Ooo^P07o`3oH0?ooo]Z1ooo06L6oookJPGoo`2_8_oonfX4o`3o
2Ioooo]Z001noookJP;o0?l98_oonfX5ool0[`_ooo]Z1?oo06L3oookJPSo0?mP0_l0]ol8oonj00co
K`3o8ooonfX3o`1Oo`Ko0;3o1?l0ooh3o`3o30WoA?l01Ol0ooh7oomi00[o0?l<00?ooo]Zool0[ooo
0:l00ooo:00RoookJPCo0?l9oooonfXLoookJP;o0?l98ooonfX5ool0[`[ooo]Z1?oo06L4oookJPOo
0?mP0_l0]ol8oonj0003oookJ_m_0?ooK`3o00WoK`3o9?oonfX;ofl0o`;ooo]Z2?oo^P000ol0]ooo
0?mPo`3oH006o`3oH0?ooo]Z1ooo06L7oookJPGoo`2_8ooonfX3o`3o2J7ooo]Z001ooookJP;o0?l9
8ooonfX5ool0[`_ooo]Z1Ooo06L5oookJPKo0?mP0_l0]ol3oonj00;o0;Oo1_oo^P0>ofl0o`_ooo]Z
4Om_0?l6o`2`o`Ko0?on0_l0/?l5odCo00Go0?on3OooN@04o`3o30?ooo]Z0_oo0:l3oolX02?ooo]Z
1?l0o`WooookJQoooo]Z0ol0o`TSoookJPGoo`2_2_oonfX5ool0I`Gooo]Z1_l0of03o`2go`?ookX0
00?o0;Oooonj0?oo^P001Ooo^P0=ofl0o`_ooo]Z5_m_0?l:oonj00?o0;Oo2?l0of04oookJPKoo`1W
2?oonfX5ool0[bCooo]Z0ol0o`VSoookJP00POoonfX2o`3o2BCooo]Z1Ooo0:l;oookJPGoo`1W1Ooo
nfX7o`3oH003o`2goooo^P3ookX000cookX08Om_0?l00ooo^P3o0;3oo`2`o`04o`2`o`Wo0?on00?o
A?l0o`3oo_l0ooh00ol0ooh5odCo00CoogT01_l0/?l8oookJP04ool0[ooo:03oobP0oolX02Gooo]Z
0ol0o`WooookJR?ooo]Z0_l0o`TUoookJPGoo`2_2_oonfX6ool0I`Cooo]Z1ol0of02o`2go`kookX0
8?m_0?l=oonj00Co0;Oo2Ol0of04oookJPGoo`1W2_oonfX4ool0[bGooo]Z0ol0o`VUoookJP00P_oo
nfX2o`3o2BKooo]Z1Ooo0:l<oookJPGoo`1W1_oonfX8o`3oH0Go0;Oo5?oo^P000ooonf[ookX0oonj
000=oonj00Ko0;3o3?l0ooh;odCo00?o0;3o0_oo:005o`2`o`Cooo]Z00Coo`2_oolX0?oo:03oobP0
9_oonfX3o`3o2Ooooo]Z9_oonfX3o`3o2BKooo]Z1Ooo0:l<oookJPGoo`1W1OoonfX9o`3oH0Go0;Oo
4ooo^P02oookJQKookX00ol0]ol:o`3oH0Gooo]Z1ooo06L:oookJPCoo`2_9ooonfX2o`3o2JOooo]Z
0023oookJP?o0?l99_oonfX6ool0[`cooo]Z1ooo06L6oookJPco0?mP1ol0]olHoonj00Co0;3o00?o
0?mPo`3oo_l0ooh02ol0ooh<odCo00;o0;3o0ooo:005o`2`o`03oookJ_oo0:ooU?l000;oU?l09ooo
nfX4o`3o2Ooooo]Z:?oonfX4o`3o2BKooo]Z1_oo0:l<oookJPOoo`1W1OoonfX<o`3oH0Oo0;Oo7?oo
^P0<o`3oH0Oooo]Z1_oo06L<oookJPCoo`2_:?oonfX3o`3o2JSooo]Z0024oookJPCo0?l99_oonfX7
ool0[`gooo]Z2?oo06L7oookJQGo0?mP1Ol0]ol>o`3oH13o0?on1Ooo06L6o`2`o`GoobP00_oonfX0
0ooo0:ooU?l0oiCo0002oiCo02Wooo]Z0ol0o`WooookJR_ooo]Z1?l0o`TWoookJPOoo`2_3?oonfX8
ool0I`Oooo]Z5_l0of04o`2goaGo0?mP2?oonfX8ool0I`cooo]Z1?oo0:lYoookJP?o0?l9Z_oonfX0
08Kooo]Z0ol0o`TXoookJPOoo`2_3OoonfX3ool0I`03oookJ_oo06Ooo`1W00Koo`1W1OoonfXRo`3o
H17o0?on00?oo`1WoookJ_oonfX00_nDo`04oookJPKoobP01?nDo`000ooo0:oooo]ZoookJP0Xoook
JPCo0?l9oooonfX^oookJPCo0?l9:?oonfX7ool0[`cooo]Z1?oo06L00ooonf[oo`1Wool0I`05ool0
I`Gooo]Z9Ol0of04o`0000;ooo]Z2Ooo06L>oookJPKoo`2_:OoonfX4o`3o2J_ooo]Z0028oookJP?o
0?l9:_oonfX6ool0[`gooo]Z3ooo06LQoookJPcoo`1W1_oonfX4oiCo00?ooo]Z0ooo:004oiCo00;o
obP0:ooonfX4o`3o2Ooooo]Z<_oonfX4o`3o2B[ooo]Z1_oo0:l<oookJPooo`1W8OoonfX=ool0I`oo
oo]Z1ooo0:l[oookJP?o0?l9[OoonfX008[ooo]Z0ol0o`T/oookJPGoo`2_5OoonfXDool0I`;ooo]Z
5Ooo06L01?l0003ooo]Zo`3o[Ol0ojd6oookJPKoU?l000?ooo]ZoolX0?nDo`000_nDo`04o`3o[@?o
obP0:OoonfX4o`3o2Ooooo]Z=_oonfX3o`3o2Bgooo]Z1Ooo0:lDoookJQCoo`1W0_oonfXFool0Ia7o
oo]Z2?oo0:l/oookJP?o0?l9[ooonfX008_ooo]Z0ol0o`T_oookJPKoo`2_6ooonfXGool0I`;o00oo
0_oo06L2oookJP;o00001Ol0ojd4oookJPOoU?l01_l0ojd8oolX02Kooo]Z0ol0o`WooookJS[ooo]Z
1?l0o`T_oookJPKoo`2_6_oonfXLool0I`03oookJ_l0003o000000;o00003_oonfX7ool0[bkooo]Z
0_l0o`VboookJP00S?oonfX4o`3o2C7ooo]Z1ooo0:lZoookJPGo00oo1?oonfX7o`3o[@;ooo]Z0onD
o`06o`3o[@;oU?l03?oo:00ToookJP?o0?l9oooonfXmoookJPGo0?l9<?oonfX8ool0[c;ooo]Z1?l0
0008oookJPWoo`2_<?oonfX2o`3o2KCooo]Z002>oookJP04o`3o2Ooonf[o0?l9o`3o2C;ooo]Z2_oo
0:lQoookJPSo00oo0_oonfX;o`3o[@Oo00oo1?nDo`04oolX02[ooo]Z1?l0o`WooookJT3ooo]Z00?o
0?l9oookJ_l0o`T00_l0o`TaoookJP_oo`2_;?oonfX4o`0000?ooo]Z2ooo0:l`oookJPCo0?l9]Ooo
nfX008oooo]Z0_l0o`T00ooonf[o0?l9o`3o2@0goookJPcoo`2_5OoonfX;o`0?o`03o`3o[Ol03ooo
00oo00[o00oo2onDo`0/oookJP;o0?l90_oo:03ooookJT?ooo]Z0_l0o`T01?oonf[o0?l9o`3o2Ol0
o`TfoookJPgoo`2_8OoonfX<ool0[cKooo]Z1?l0o`VgoookJP00TOoonfX5o`3o2CWooo]Z5?oo0:l6
oookJPoo00oo2ol0ojd<oiCo02Wooo]Z0_l0o`T3oolX0?oooo]ZAooonfX6o`3o2CSooo]Z5?oo0:l:
oookJQCoo`2_>?oonfX4o`3o2KWooo]Z002DoookJPCo0?l9@OoonfX>ool0[a3o00oo3?l0ojdcoook
JP04o`3o2Ooo:03oobP0oolX0?oooo]ZCOoonfX4o`3o2D;ooo]Z7?oo0:l5oookJPCo0000=ooonfX5
o`3o2K_ooo]Z002FoookJPCo0?l9D_oonfX;o`0?o`Cooo]Z00?o0000o`3o[Ol0ojd01Ol0ojd`oook
JP05o`3o2Ooo:03oobP0oolX0?l0o`T0oooonfYAoookJPCo0?l9HOoonfX4o`0003Gooo]Z1Ol0o`Vm
oookJP00V?oonfX4o`3o2EOooo]Z1?l03ol4oookJPCo0000<_oonfX00ol0o`WoobP0oolX0002o`3o
2Ooooo]ZEOoonfX4o`3o2Eoooo]Z1?l0000coookJP;o0?l900?ooo]Zo`3o2Ol0o`T0_ooonfX009[o
oo]Z1?l0o`UMoookJPCo00009OoonfX2oolX00Sooo]Z00Co0?l9oolX0?oo:03oobP00_l0o`Wooook
JUWooo]Z1?l0o`UMoookJPCo0000<?oonfX3o`3o2@03oookJ_l0o`Wo0?l90<7ooo]Z002LoookJPCo
0?l9FooonfX5o`0002?ooo]Z0ooo:005oookJP04o`3o2Ooo:03oobP0oolX00?oU?l0oooonfYNoook
JP?o0?l9FooonfX5o`0002cooo]Z0ol0o`T01?oonf[o0?l9o`3o2Ol0o`W3oookJP00WooonfX4o`3o
2ESooo]Z1?l0000RoookJPGoobP00ooonfX00ol0o`WoobP0oolX0003oiCo0?oooo]ZHooonfX4o`3o
2ESooo]Z1?l0000[oookJPKo0?l9a_oonfX00:7ooo]Z1Ol0o`UEoookJPCo00008OoonfX8oolX00Co
U?l0oooonfYXoookJPGo0?l9EOoonfX4o`0002Sooo]Z1_l0o`W9oookJP00XooonfX6o`3o2E;ooo]Z
1?l0000HoookJP;oU?l01OoonfX7oolX00?oU?l0oooonfY^oookJPKo0?l9D_oonfX4o`0002Gooo]Z
1Ol0o`W=oookJP00YOoonfX7o`3o2Doooo]Z1?l0000GoookJP?oU?l01?oonfX4oolX00;oU?l00ol0
ojd00ooo:03ooo]ZoookJP3ooookJVoooo]Z1ol0o`U?oookJPCo00008_oonfX5o`3o2M3ooo]Z002X
oookJPOo0?l9C?oonfX4o`0001Gooo]Z1OnDo`03oookJP;oobP01Ol0ojd5oolX0?oooo]ZLooonfX7
o`3o2Dcooo]Z1?l0000OoookJPGo0?l9dooonfX00:cooo]Z1_l0o`U9oookJPCo00002ooonfX2o`3o
[@Kooo]Z2?nDo`04o`3o[@[oobP0oooonfYgoookJPKo0?l9BOoonfX4o`0001_ooo]Z1Ol0o`WGoook
JP00[_oonfX7o`3o2DKooo]Z1?l00009oookJPCo0?n]1OoonfX5oiCo00Co0?n]00?oU?l0oolX0?oo
:0001_oo:03ooookJWkooo]Z1ol0o`U6oookJPCo00005ooonfX6o`3o2M[ooo]Z002aoookJPSo0?l9
@_oonfX3o`0000;o00oo1_oonfX6o`3o[@?ooo]Z0_nDo`04o`3o[@Co00oo00?oU?l0oolX0?oo:000
oooonfZ8oookJPWo0?l9@OoonfX4o`0001;ooo]Z2?l0o`WMoookJP00]OoonfX8o`3o2Ckooo]Z1Ol0
3ol4oookJP[o0?n]1ol03ol6oiCo0?oooo]ZSOoonfX9o`3o2Cgooo]Z1?l0000>oookJPSo0?l9hOoo
nfX00;[ooo]Z2?l0o`TgoookJPOo00oo0ooonfX5o`3o[@Ko00oo3OnDo`3ooookJY?ooo]Z1ol0o`Ti
oookJPCo00002OoonfX8o`3o2NKooo]Z002moookJP_o0?l9;ooonfX9o`0?o`03o`3o2Ol03ooo00oo
00Go00oo1Ol0ojd6oiCo0?oooo]ZW_oonfX;o`3o2C;ooo]Z1?l00002oookJPco0?l9jOoonfX00<?o
oo]Z3?l0o`TUoookJPgo00oo3Ol0ojgooookJZWooo]Z2ol0o`T/oookJP_o0?l9l?oonfX00<Wooo]Z
5_l0o`T;oookJPSo0?l93ol03ol=o`3o[Ooooo]Z[_oonfXFo`3o2@cooo]Z5Ol0o`WfoookJP00e?oo
nfXMo`3o2A3o00oooooonf[7oookJQoo0?l91ooonfX5o`000?Kooo]Z003OoookJP[o0?l93OoonfX;
o`0?oooooo]Zd_oonfX9o`3o2A;ooo]Z1?l0003goookJP00nooonfX2o`0000Co00oooooonf[]oook
JPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]Z
kooonfX4o`000?Oooo]Z003koookJPCo0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003o
oookJ^oooo]Z1?l0003goookJP00nooonfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003koookJPCo
0000oooonf[_oookJPCo0000mooonfX00?_ooo]Z1?l0003ooookJ^oooo]Z1?l0003goookJP00nooo
nfX4o`000?oooo]ZkooonfX4o`000?Oooo]Z003VoookJP?o001o1OoonfX5o`00O`Sooo]Z1?l0003o
oookJ][ooo]Z0ol007l5oookJPGo001o2?oonfX4o`000?Oooo]Z003VoookJP?o001o1?oonfX7o`00
O`Oooo]Z1?l0003ooookJ][ooo]Z0ol007l4oookJPOo001o1ooonfX4o`000?Oooo]Z003VoookJP?o
001o0ooonfX4o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l0003ooookJ][ooo]Z0ol007l3oook
JPCo001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`000?Oooo]Z003VoookJP?o001o0ooonfX3o`00
O`?ooo]Z0ol007l6oookJPCo0000oooonf[JoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oook
JPCo0000mooonfX00>Kooo]Z0ol007l9oookJP?o001o1_oonfX6o`000?oooo]Zf?oonfX3o`00O`Wo
oo]Z0ol007l6oookJPKo0000mOoonfX00>Kooo]Z0ol007l9oookJP?o001o1_oonfX4o`000?oooo]Z
f_oonfX3o`00O`Wooo]Z0ol007l6oookJPCo0000mooonfX00>Kooo]Z0ol007l4oookJP;o001o0_oo
nfX4o`00O`Kooo]Z1?l0003ooookJ][ooo]Z0ol007l4oookJP;o001o0_oonfX4o`00O`Kooo]Z1?l0
003goookJP00i_oonfX3o`00O`Cooo]Z1ol007oooookJ^Gooo]Z0ol007l4oookJPOo001ooooonfX3
oookJP00i_oonfX3o`00O`Cooo]Z1_l007oooookJ^Kooo]Z0ol007l4oookJPKo001ooooonfX4oook
JP00hooonfX6o`00O`Cooo]Z0_l007oooookJ^Oooo]Z1_l007l4oookJP;o001ooooonfX8oookJP00
hooonfX6o`00O`Cooo]Z0_l007oooookJ^Oooo]Z1_l007l4oookJP;o001ooooonfX8oookJP00iOoo
nfX4o`00O`Gooo]Z1ol007oooookJ^?ooo]Z1?l007l5oookJPOo001ooooonfX2oookJP00i_oonfX3
o`00O`Gooo]Z1ol007oooookJ^Cooo]Z0ol007l5oookJPOo001ooooonfX2oookJP00oooonf[ooook
J_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooo
nf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oook
JP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooo
nf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oo
oo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003o
oookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[ooookJ^_o
oo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Zoooonf[o
oookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX00?oooo]Z
oooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]ZjooonfX0
0?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00oooonf[ooookJ_oooo]Z
jooonfX00?oooo]Zoooonf[ooookJ^_ooo]Z003ooookJ_oooo]Zoooonf[[oookJP00\
\>"],
  ImageRangeCache->{{{0, 999}, {999, 0}} -> {-0.0500105, -0.0500105, \
0.00210213, 0.00210213}, {{23.75, 476.812}, {975.188, 522.125}} -> {-1.17208, \
-1.15742, 0.00462332, 0.00462332}, {{522.125, 975.188}, {975.188, 522.125}} -> \
{-3.47623, -1.15742, 0.00462332, 0.00462332}, {{23.75, 476.812}, {476.812, \
23.75}} -> {-17.9973, -53.1523, 0.070991, 0.070991}, {{522.125, 975.188}, \
{476.812, 23.75}} -> {-53.3774, -53.1523, 0.070991, 0.070991}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{4, 1920}, {0, 1178}},
WindowSize->{1152, 688},
WindowMargins->{{52, Automatic}, {Automatic, 163}},
WindowTitle->"Lecture 25 MIT 3.016 (Fall 2005)   \[Copyright] W. Craig Carter \
2003-2005",
CellLabelAutoDelete->True,
StyleDefinitions -> "3016_Carter.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "mmtag:25:phase_plane_analysis"->{
    Cell[1754, 51, 115, 1, 64, "Title",
      CellTags->"mmtag:25:phase_plane_analysis"]},
  "mmtag:25:fixed_point__linearization_about"->{
    Cell[1872, 54, 166, 4, 48, "Subtitle",
      CellTags->"mmtag:25:fixed_point__linearization_about"]},
  "mmtag:25:warning_function__example"->{
    Cell[3266, 100, 300, 5, 67, "Input",
      CellTags->"mmtag:25:warning_function__example"]},
  "mmtag:25:fixed_point__function_to_determine_stability"->{
    Cell[3686, 112, 360, 6, 67, "Input",
      CellTags->"mmtag:25:fixed_point__function_to_determine_stability"]},
  "mmtag:25:fixed_point__function_to_determine_type"->{
    Cell[4155, 125, 425, 7, 67, "Input",
      CellTags->"mmtag:25:fixed_point__function_to_determine_type"]},
  "mmtag:25:EigenDescription[]__example_of_function_for_analysis_of_system_of_\
ODEs"->{
    Cell[4654, 136, 303, 7, 67, "Input",
      CellTags->
      "mmtag:25:EigenDescription[]__example_of_function_for_analysis_of_\
system_of_ODEs"]},
  "mmtag:25:LinearDescription[]__example_of_function_for_analysis_of_system_\
of_ODEs"->{
    Cell[5966, 181, 787, 13, 135, "Input",
      CellTags->
      "mmtag:25:LinearDescription[]__example_of_function_for_analysis_of_\
system_of_ODEs"]},
  "mmtag:25:fixed_point_stability__visualization"->{
    Cell[8163, 240, 143, 2, 48, "Subtitle",
      CellTags->"mmtag:25:fixed_point_stability__visualization"]},
  "mmtag:25:fixed_point__visualization_of_trajectories_near"->{
    Cell[45138, 1306, 2255, 41, 306, "Input",
      CellTags->"mmtag:25:fixed_point__visualization_of_trajectories_near"]},
  "mmtag:25:fixed_point__stable_attractive_node_visualization"->{
    Cell[48800, 1381, 158, 2, 50, "Input",
      CellTags->
      "mmtag:25:fixed_point__stable_attractive_node_visualization"]},
  "mmtag:25:fixed_point__unstable_node_visualization"->{
    Cell[2251807, 107465, 167, 3, 50, "Input",
      CellTags->"mmtag:25:fixed_point__unstable_node_visualization"]},
  "mmtag:25:fixed_point__saddle_node_visualization"->{
    Cell[4515218, 168171, 157, 3, 50, "Input",
      CellTags->"mmtag:25:fixed_point__saddle_node_visualization"]},
  "mmtag:25:fixed_point__unstable_focus_node_visualization"->{
    Cell[6016578, 221316, 156, 2, 50, "Input",
      CellTags->"mmtag:25:fixed_point__unstable_focus_node_visualization"]},
  "mmtag:25:fixed_point__stable_focus_node_visualization"->{
    Cell[8769164, 277717, 159, 2, 50, "Input",
      CellTags->"mmtag:25:fixed_point__stable_focus_node_visualization"]},
  "mmtag:25:fixed_point__circulation_node_visualization"->{
    Cell[11570005, 394152, 154, 2, 50, "Input",
      CellTags->"mmtag:25:fixed_point__circulation_node_visualization"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"mmtag:25:phase_plane_analysis", 13418416, 464338},
  {"mmtag:25:fixed_point__linearization_about", 13418556, 464341},
  {"mmtag:25:warning_function__example", 13418704, 464344},
  {"mmtag:25:fixed_point__function_to_determine_stability", 13418862, \
464347},
  {"mmtag:25:fixed_point__function_to_determine_type", 13419034, 464350},
  {"mmtag:25:EigenDescription[]__example_of_function_for_analysis_of_system_\
of_ODEs", 13419234, 464354},
  {"mmtag:25:LinearDescription[]__example_of_function_for_analysis_of_system_\
of_ODEs", 13419475, 464360},
  {"mmtag:25:fixed_point_stability__visualization", 13419682, 464365},
  {"mmtag:25:fixed_point__visualization_of_trajectories_near", 13419857, \
464368},
  {"mmtag:25:fixed_point__stable_attractive_node_visualization", 13420047, \
464371},
  {"mmtag:25:fixed_point__unstable_node_visualization", 13420234, 464375},
  {"mmtag:25:fixed_point__saddle_node_visualization", 13420407, 464378},
  {"mmtag:25:fixed_point__unstable_focus_node_visualization", 13420586, \
464381},
  {"mmtag:25:fixed_point__stable_focus_node_visualization", 13420771, \
464384},
  {"mmtag:25:fixed_point__circulation_node_visualization", 13420953, 464387}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 115, 1, 64, "Title",
  CellTags->"mmtag:25:phase_plane_analysis"],
Cell[1872, 54, 166, 4, 48, "Subtitle",
  CellTags->"mmtag:25:fixed_point__linearization_about"],
Cell[2041, 60, 438, 15, 71, "Text"],

Cell[CellGroupData[{
Cell[2504, 79, 449, 8, 66, "Subsubsection"],
Cell[2956, 89, 169, 4, 46, "Text"],
Cell[3128, 95, 135, 3, 46, "Text"],
Cell[3266, 100, 300, 5, 67, "Input",
  CellTags->"mmtag:25:warning_function__example"],
Cell[3569, 107, 114, 3, 46, "Text"],
Cell[3686, 112, 360, 6, 67, "Input",
  CellTags->"mmtag:25:fixed_point__function_to_determine_stability"],
Cell[4049, 120, 103, 3, 46, "Text"],
Cell[4155, 125, 425, 7, 67, "Input",
  CellTags->"mmtag:25:fixed_point__function_to_determine_type"],
Cell[4583, 134, 68, 0, 46, "Text"],
Cell[4654, 136, 303, 7, 67, "Input",
  CellTags->
  "mmtag:25:EigenDescription[]__example_of_function_for_analysis_of_system_of_\
ODEs"],

Cell[CellGroupData[{
Cell[4982, 147, 105, 2, 50, "Input"],
Cell[5090, 151, 56, 1, 24, "Print"],
Cell[5149, 154, 46, 1, 24, "Print"]
}, Open  ]],
Cell[5210, 158, 73, 1, 50, "Input"],
Cell[5286, 161, 112, 3, 46, "Text"],
Cell[5401, 166, 420, 8, 84, "Input"],
Cell[5824, 176, 139, 3, 46, "Text"],
Cell[5966, 181, 787, 13, 135, "Input",
  CellTags->
  "mmtag:25:LinearDescription[]__example_of_function_for_analysis_of_system_\
of_ODEs"],

Cell[CellGroupData[{
Cell[6778, 198, 69, 1, 50, "Input"],
Cell[6850, 201, 43, 1, 24, "Print"],
Cell[6896, 204, 41, 1, 24, "Print"],
Cell[6940, 207, 291, 6, 24, "Print"],
Cell[7234, 215, 349, 7, 24, "Print"],
Cell[7586, 224, 349, 7, 24, "Print"],
Cell[7938, 233, 210, 4, 68, "Output"]
}, Open  ]],
Cell[8163, 240, 143, 2, 48, "Subtitle",
  CellTags->"mmtag:25:fixed_point_stability__visualization"],
Cell[8309, 244, 172, 4, 46, "Text"],
Cell[8484, 250, 371, 6, 67, "Input"],
Cell[8858, 258, 431, 8, 101, "Input"],

Cell[CellGroupData[{
Cell[9314, 270, 56, 1, 50, "Input"],
Cell[9373, 273, 364, 7, 101, "Output"]
}, Open  ]],
Cell[9752, 283, 56, 0, 46, "Text"],
Cell[9811, 285, 202, 3, 50, "Input"],

Cell[CellGroupData[{
Cell[10038, 292, 75, 1, 50, "Input"],
Cell[10116, 295, 34487, 991, 364, 16378, 763, "GraphicsData", "PostScript", \
"Graphics"],
Cell[44606, 1288, 130, 3, 68, "Output"]
}, Open  ]],
Cell[44751, 1294, 308, 5, 66, "Text"],
Cell[45062, 1301, 51, 1, 50, "Input"],

Cell[CellGroupData[{
Cell[45138, 1306, 2255, 41, 306, "Input",
  CellTags->"mmtag:25:fixed_point__visualization_of_trajectories_near"],
Cell[47396, 1349, 360, 5, 24, "Message"],
Cell[47759, 1356, 361, 5, 24, "Message"],
Cell[48123, 1363, 368, 6, 24, "Message"]
}, Open  ]],
Cell[48506, 1372, 269, 5, 66, "Text"],

Cell[CellGroupData[{
Cell[48800, 1381, 158, 2, 50, "Input",
  CellTags->"mmtag:25:fixed_point__stable_attractive_node_visualization"],
Cell[48961, 1385, 56, 1, 24, "Print"],
Cell[49020, 1388, 39, 1, 24, "Print"],
Cell[49062, 1391, 298, 6, 24, "Print"],
Cell[49363, 1399, 351, 7, 24, "Print"],
Cell[49717, 1408, 350, 7, 24, "Print"],
Cell[50070, 1417, 163, 2, 24, "Print"],
Cell[50236, 1421, 2201134, 106027, 1008, 1655201, 99283, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2251373, 107450, 135, 3, 68, "Output"]
}, Open  ]],
Cell[2251523, 107456, 259, 5, 66, "Text"],

Cell[CellGroupData[{
Cell[2251807, 107465, 167, 3, 50, "Input",
  CellTags->"mmtag:25:fixed_point__unstable_node_visualization"],
Cell[2251977, 107470, 43, 1, 24, "Print"],
Cell[2252023, 107473, 39, 1, 24, "Print"],
Cell[2252065, 107476, 217, 4, 24, "Print"],
Cell[2252285, 107482, 285, 5, 24, "Print"],
Cell[2252573, 107489, 316, 7, 24, "Print"],
Cell[2252892, 107498, 153, 3, 24, "Print"],
Cell[2253048, 107503, 2261717, 60651, 1008, 980928, 44834, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4514768, 168156, 135, 3, 68, "Output"]
}, Open  ]],
Cell[4514918, 168162, 275, 5, 66, "Text"],

Cell[CellGroupData[{
Cell[4515218, 168171, 157, 3, 50, "Input",
  CellTags->"mmtag:25:fixed_point__saddle_node_visualization"],
Cell[4515378, 168176, 43, 1, 24, "Print"],
Cell[4515424, 168179, 41, 1, 24, "Print"],
Cell[4515468, 168182, 292, 6, 24, "Print"],
Cell[4515763, 168190, 349, 7, 24, "Print"],
Cell[4516115, 168199, 349, 7, 24, "Print"],
Cell[4516467, 168208, 209, 4, 24, "Print"],
Cell[4516679, 168214, 1499424, 53085, 1008, 1015688, 47109, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6016106, 221301, 135, 3, 68, "Output"]
}, Open  ]],
Cell[6016256, 221307, 297, 5, 66, "Text"],

Cell[CellGroupData[{
Cell[6016578, 221316, 156, 2, 50, "Input",
  CellTags->"mmtag:25:fixed_point__unstable_focus_node_visualization"],
Cell[6016737, 221320, 43, 1, 24, "Print"],
Cell[6016783, 221323, 46, 1, 24, "Print"],
Cell[6016832, 221326, 520, 9, 24, "Print"],
Cell[6017355, 221337, 535, 8, 24, "Print"],
Cell[6017893, 221347, 2750786, 56353, 1008, 607437, 29888, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8768682, 277702, 135, 3, 68, "Output"]
}, Open  ]],
Cell[8768832, 277708, 307, 5, 66, "Text"],

Cell[CellGroupData[{
Cell[8769164, 277717, 159, 2, 50, "Input",
  CellTags->"mmtag:25:fixed_point__stable_focus_node_visualization"],
Cell[8769326, 277721, 56, 1, 24, "Print"],
Cell[8769385, 277724, 46, 1, 24, "Print"],
Cell[8769434, 277727, 409, 7, 24, "Print"],
Cell[8769846, 277736, 517, 9, 24, "Print"],
Cell[8770366, 277747, 2799176, 116388, 1008, 1509946, 100467, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11569545, 394137, 135, 3, 68, "Output"]
}, Open  ]],
Cell[11569695, 394143, 285, 5, 66, "Text"],

Cell[CellGroupData[{
Cell[11570005, 394152, 154, 2, 50, "Input",
  CellTags->"mmtag:25:fixed_point__circulation_node_visualization"],
Cell[11570162, 394156, 66, 1, 24, "Print"],
Cell[11570231, 394159, 46, 1, 24, "Print"],
Cell[11570280, 394162, 363, 7, 24, "Print"],
Cell[11570646, 394171, 493, 7, 28, "Print"],
Cell[11571142, 394180, 1846341, 70130, 1008, 1103315, 60953, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13417486, 464312, 135, 3, 68, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

